from rantanplan.core import syllabify

"""
Words syllabification have been extracted from educalingo dict
as there is no official resource on word syllabification
https://educalingo.com/es/dic-es

Some words were incorrectly syllabified and for this purpose DIRAE
https://dirae.es/ and the FUNDEU https://www.fundeu.es/dudas/ website
have been consulted to resolve these cases.
"""

DICT_TEST = {
    "aarónica": "aa-ró-ni-ca",
    "aarónico": "aa-ró-ni-co",
    "aaronita": "aa-ro-ni-ta",
    "aba": "a-ba",
    "ababa": "a-ba-ba",
    "ababillar": "a-ba-bi-llar",
    "ababillarse": "a-ba-bi-llar-se",
    "ababol": "a-ba-bol",
    "abacá": "a-ba-cá",
    "abacal": "a-ba-cal",
    "abacalera": "a-ba-ca-le-ra",
    "abacalero": "a-ba-ca-le-ro",
    "abacera": "a-ba-ce-ra",
    "abacería": "a-ba-ce-rí-a",
    "abacero": "a-ba-ce-ro",
    "abachar": "a-ba-char",
    "abacial": "a-ba-cial",
    "ábaco": "á-ba-co",
    "abacora": "a-ba-co-ra",
    "abacorar": "a-ba-co-rar",
    "abad": "a-bad",
    "abada": "a-ba-da",
    "abadejo": "a-ba-de-jo",
    "abadenga": "a-ba-den-ga",
    "abadengo": "a-ba-den-go",
    "abadernar": "a-ba-der-nar",
    "abadesa": "a-ba-de-sa",
    "abadí": "a-ba-dí",
    "abadía": "a-ba-dí-a",
    "abadiado": "a-ba-dia-do",
    "abadiato": "a-ba-dia-to",
    "abajadero": "a-ba-ja-de-ro",
    "abajamiento": "a-ba-ja-mien-to",
    "abajar": "a-ba-jar",
    "abajeña": "a-ba-je-ña",
    "abajeño": "a-ba-je-ño",
    "abajera": "a-ba-je-ra",
    "abajo": "a-ba-jo",
    "abakuá": "a-ba-kuá",
    "abalada": "a-ba-la-da",
    "abalado": "a-ba-la-do",
    "abalanzar": "a-ba-lan-zar",
    "abalar": "a-ba-lar",
    "abalaustrada": "a-ba-laus-tra-da",
    "abalaustrado": "a-ba-laus-tra-do",
    "abalconado": "a-bal-co-na-do",
    "abaldonadamente": "a-bal-do-na-da-men-te",
    "abaldonamiento": "a-bal-do-na-mien-to",
    "abaldonar": "a-bal-do-nar",
    "abaleador": "a-ba-le-a-dor",
    "abaleadora": "a-ba-le-a-do-ra",
    "abaleadura": "a-ba-le-a-du-ra",
    "abalear": "a-ba-le-ar",
    "abaleo": "a-ba-le-o",
    "abalizamiento": "a-ba-li-za-mien-to",
    "abalizar": "a-ba-li-zar",
    "aballar": "a-ba-llar",
    "aballestar": "a-ba-lles-tar",
    "abalorio": "a-ba-lo-rio",
    "abaluartar": "a-ba-luar-tar",
    "abanador": "a-ba-na-dor",
    "abañador": "a-ba-ña-dor",
    "abañadora": "a-ba-ña-do-ra",
    "abañadura": "a-ba-ña-du-ra",
    "abanar": "a-ba-nar",
    "abañar": "a-ba-ñar",
    "abancalar": "a-ban-ca-lar",
    "abanda": "a-ban-da",
    "abanderada": "a-ban-de-ra-da",
    "abanderado": "a-ban-de-ra-do",
    "abanderamiento": "a-ban-de-ra-mien-to",
    "abanderar": "a-ban-de-rar",
    "abanderizador": "a-ban-de-ri-za-dor",
    "abanderizadora": "a-ban-de-ri-za-do-ra",
    "abanderizar": "a-ban-de-ri-zar",
    "abandonada": "a-ban-do-na-da",
    "abandonado": "a-ban-do-na-do",
    "abandonamiento": "a-ban-do-na-mien-to",
    "abandonar": "a-ban-do-nar",
    "abandonismo": "a-ban-do-nis-mo",
    "abandonista": "a-ban-do-nis-ta",
    "abandono": "a-ban-do-no",
    "abanear": "a-ba-ne-ar",
    "abanicador": "a-ba-ni-ca-dor",
    "abanicar": "a-ba-ni-car",
    "abanicazo": "a-ba-ni-ca-zo",
    "abanico": "a-ba-ni-co",
    "abanillo": "a-ba-ni-llo",
    "abanino": "a-ba-ni-no",
    "abaniqueo": "a-ba-ni-que-o",
    "abaniquera": "a-ba-ni-que-ra",
    "abaniquería": "a-ba-ni-que-rí-a",
    "abaniquero": "a-ba-ni-que-ro",
    "abano": "a-ba-no",
    "abanquina": "a-ban-qui-na",
    "abanquino": "a-ban-qui-no",
    "abanto": "a-ban-to",
    "abar": "a-bar",
    "abarajar": "a-ba-ra-jar",
    "abarañar": "a-ba-ra-ñar",
    "abaratamiento": "a-ba-ra-ta-mien-to",
    "abaratar": "a-ba-ra-tar",
    "abarbechar": "a-bar-be-char",
    "abarbetar": "a-bar-be-tar",
    "abarca": "a-bar-ca",
    "abarcable": "a-bar-ca-ble",
    "abarcada": "a-bar-ca-da",
    "abarcado": "a-bar-ca-do",
    "abarcador": "a-bar-ca-dor",
    "abarcadora": "a-bar-ca-do-ra",
    "abarcadura": "a-bar-ca-du-ra",
    "abarcamiento": "a-bar-ca-mien-to",
    "abarcar": "a-bar-car",
    "abarcón": "a-bar-cón",
    "abarcuzar": "a-bar-cu-zar",
    "abareque": "a-ba-re-que",
    "abaritonada": "a-ba-ri-to-na-da",
    "abaritonado": "a-ba-ri-to-na-do",
    "abarloar": "a-bar-lo-ar",
    "abarquera": "a-bar-que-ra",
    "abarquero": "a-bar-que-ro",
    "abarquillada": "a-bar-qui-lla-da",
    "abarquillado": "a-bar-qui-lla-do",
    "abarquillamiento": "a-bar-qui-lla-mien-to",
    "abarquillar": "a-bar-qui-llar",
    "abarracar": "a-ba-rra-car",
    "abarrada": "a-ba-rra-da",
    "abarrado": "a-ba-rra-do",
    "abarraganamiento": "a-ba-rra-ga-na-mien-to",
    "abarraganar": "a-ba-rra-ga-nar",
    "abarraganarse": "a-ba-rra-ga-nar-se",
    "abarrajada": "a-ba-rra-ja-da",
    "abarrajado": "a-ba-rra-ja-do",
    "abarrajar": "a-ba-rra-jar",
    "abarramiento": "a-ba-rra-mien-to",
    "abarrancadero": "a-ba-rran-ca-de-ro",
    "abarrancado": "a-ba-rran-ca-do",
    "abarrancamiento": "a-ba-rran-ca-mien-to",
    "abarrancar": "a-ba-rran-car",
    "abarrar": "a-ba-rrar",
    "abarraz": "a-ba-rraz",
    "abarredera": "a-ba-rre-de-ra",
    "abarrenar": "a-ba-rre-nar",
    "abarrer": "a-ba-rrer",
    "abarrisco": "a-ba-rris-co",
    "abarrocado": "a-ba-rro-ca-do",
    "abarrotamiento": "a-ba-rro-ta-mien-to",
    "abarrotar": "a-ba-rro-tar",
    "abarrote": "a-ba-rro-te",
    "abarrotera": "a-ba-rro-te-ra",
    "abarrotería": "a-ba-rro-te-rí-a",
    "abarrotero": "a-ba-rro-te-ro",
    "abarse": "a-bar-se",
    "abasí": "a-ba-sí",
    "abasida": "a-ba-si-da",
    "abastadamente": "a-bas-ta-da-men-te",
    "abastamiento": "a-bas-ta-mien-to",
    "abastante": "a-bas-tan-te",
    "abastanza": "a-bas-tan-za",
    "abastar": "a-bas-tar",
    "abastardar": "a-bas-tar-dar",
    "abastecedor": "a-bas-te-ce-dor",
    "abastecedora": "a-bas-te-ce-do-ra",
    "abastecer": "a-bas-te-cer",
    "abastecimiento": "a-bas-te-ci-mien-to",
    "abastera": "a-bas-te-ra",
    "abastero": "a-bas-te-ro",
    "abastimiento": "a-bas-ti-mien-to",
    "abastionar": "a-bas-tio-nar",
    "abasto": "a-bas-to",
    "abatanado": "a-ba-ta-na-do",
    "abatanar": "a-ba-ta-nar",
    "abatatamiento": "a-ba-ta-ta-mien-to",
    "abatatar": "a-ba-ta-tar",
    "abate": "a-ba-te",
    "abatí": "a-ba-tí",
    "abatible": "a-ba-ti-ble",
    "abatida": "a-ba-ti-da",
    "abatidero": "a-ba-ti-de-ro",
    "abatido": "a-ba-ti-do",
    "abatidura": "a-ba-ti-du-ra",
    "abatimiento": "a-ba-ti-mien-to",
    "abatir": "a-ba-tir",
    "abatismo": "a-ba-tis-mo",
    "abatojar": "a-ba-to-jar",
    "abayada": "a-ba-ya-da",
    "abayado": "a-ba-ya-do",
    "abazón": "a-ba-zón",
    "abbevillense": "ab-be-vi-llen-se",
    "abderitana": "ab-de-ri-ta-na",
    "abderitano": "ab-de-ri-ta-no",
    "abdicación": "ab-di-ca-ción",
    "abdicar": "ab-di-car",
    "abdicativa": "ab-di-ca-ti-va",
    "abdicativamente": "ab-di-ca-ti-va-men-te",
    "abdicativo": "ab-di-ca-ti-vo",
    "abdomen": "ab-do-men",
    "abdominal": "ab-do-mi-nal",
    "abducción": "ab-duc-ción",
    "abductor": "ab-duc-tor",
    "abductora": "ab-duc-to-ra",
    "abecé": "a-be-cé",
    "abecedario": "a-be-ce-da-rio",
    "abedul": "a-be-dul",
    "abeja": "a-be-ja",
    "abejar": "a-be-jar",
    "abejarrón": "a-be-ja-rrón",
    "abejaruco": "a-be-ja-ru-co",
    "abejear": "a-be-je-ar",
    "abejeo": "a-be-je-o",
    "abejera": "a-be-je-ra",
    "abejero": "a-be-je-ro",
    "abejón": "a-be-jón",
    "abejonear": "a-be-jo-ne-ar",
    "abejoneo": "a-be-jo-ne-o",
    "abejorrear": "a-be-jo-rre-ar",
    "abejorreo": "a-be-jo-rre-o",
    "abejorro": "a-be-jo-rro",
    "abejuna": "a-be-ju-na",
    "abejuno": "a-be-ju-no",
    "abeldar": "a-bel-dar",
    "abellacada": "a-be-lla-ca-da",
    "abellacado": "a-be-lla-ca-do",
    "abellacar": "a-be-lla-car",
    "abellota": "a-be-llo-ta",
    "abellotada": "a-be-llo-ta-da",
    "abellotado": "a-be-llo-ta-do",
    "abelmosco": "a-bel-mos-co",
    "abemoladamente": "a-be-mo-la-da-men-te",
    "abemolar": "a-be-mo-lar",
    "abencerraje": "a-ben-ce-rra-je",
    "abéñola": "a-bé-ño-la",
    "abéñula": "a-bé-ñu-la",
    "abenuz": "a-be-nuz",
    "aberenjenada": "a-be-ren-je-na-da",
    "aberenjenado": "a-be-ren-je-na-do",
    "aberración": "a-be-rra-ción",
    "aberrante": "a-be-rran-te",
    "aberrantemente": "a-be-rran-te-men-te",
    "aberrar": "a-be-rrar",
    "abertal": "a-ber-tal",
    "abertura": "a-ber-tu-ra",
    "abertzale": "a-bert-za-le",
    "aberzale": "a-ber-za-le",
    "abés": "a-bés",
    "abesana": "a-be-sa-na",
    "abesón": "a-be-són",
    "abestiada": "a-bes-tia-da",
    "abestiado": "a-bes-tia-do",
    "abestializada": "a-bes-tia-li-za-da",
    "abestializado": "a-bes-tia-li-za-do",
    "abéstola": "a-bés-to-la",
    "abetal": "a-be-tal",
    "abetar": "a-be-tar",
    "abete": "a-be-te",
    "abetinote": "a-be-ti-no-te",
    "abeto": "a-be-to",
    "abetuna": "a-be-tu-na",
    "abetunada": "a-be-tu-na-da",
    "abetunado": "a-be-tu-na-do",
    "abetunar": "a-be-tu-nar",
    "abey": "a-bey",
    "abia": "a-bia",
    "abiar": "a-biar",
    "abibollo": "a-bi-bo-llo",
    "abichar": "a-bi-char",
    "abierta": "a-bier-ta",
    "abiertamente": "a-bier-ta-men-te",
    "abierto": "a-bier-to",
    "abietácea": "a-bie-tá-ce-a",
    "abietáceas": "a-bie-tá-ce-as",
    "abietáceo": "a-bie-tá-ce-o",
    "abiete": "a-bie-te",
    "abietina": "a-bie-ti-na",
    "abietínea": "a-bie-tí-ne-a",
    "abietíneo": "a-bie-tí-ne-o",
    "abietino": "a-bie-ti-no",
    "abigarrada": "a-bi-ga-rra-da",
    "abigarradamente": "a-bi-ga-rra-da-men-te",
    "abigarrado": "a-bi-ga-rra-do",
    "abigarramiento": "a-bi-ga-rra-mien-to",
    "abigarrar": "a-bi-ga-rrar",
    "abigeato": "a-bi-ge-a-to",
    "abigeo": "a-bi-ge-o",
    "abigotada": "a-bi-go-ta-da",
    "abigotado": "a-bi-go-ta-do",
    "abinar": "a-bi-nar",
    "abintestato": "a-bin-tes-ta-to",
    "abiogénesis": "a-bio-gé-ne-sis",
    "abiótico": "a-bió-ti-co",
    "abipón": "a-bi-pón",
    "abipona": "a-bi-po-na",
    "abisagrar": "a-bi-sa-grar",
    "abisal": "a-bi-sal",
    "abisalmente": "a-bi-sal-men-te",
    "abiselar": "a-bi-se-lar",
    "abisina": "a-bi-si-na",
    "abisinia": "a-bi-si-nia",
    "abisinio": "a-bi-si-nio",
    "abisino": "a-bi-si-no",
    "abismada": "a-bis-ma-da",
    "abismado": "a-bis-ma-do",
    "abismal": "a-bis-mal",
    "abismalmente": "a-bis-mal-men-te",
    "abismar": "a-bis-mar",
    "abismática": "a-bis-má-ti-ca",
    "abismático": "a-bis-má-ti-co",
    "abismo": "a-bis-mo",
    "abiso": "a-bi-so",
    "abisopelágico": "a-bi-so-pe-lá-gi-co",
    "abita": "a-bi-ta",
    "abitadura": "a-bi-ta-du-ra",
    "abitaque": "a-bi-ta-que",
    "abitar": "a-bi-tar",
    "abitón": "a-bi-tón",
    "abizcochada": "a-biz-co-cha-da",
    "abizcochado": "a-biz-co-cha-do",
    "abjuración": "ab-ju-ra-ción",
    "abjurar": "ab-ju-rar",
    "ablación": "a-bla-ción",
    "ablandabrevas": "a-blan-da-bre-vas",
    "ablandador": "a-blan-da-dor",
    "ablandadora": "a-blan-da-do-ra",
    "ablandahígos": "a-blan-da-hí-gos",
    "ablandamiento": "a-blan-da-mien-to",
    "ablandar": "a-blan-dar",
    "ablandativa": "a-blan-da-ti-va",
    "ablandativo": "a-blan-da-ti-vo",
    "ablande": "a-blan-de",
    "ablandecer": "a-blan-de-cer",
    "ablanedo": "a-bla-ne-do",
    "ablanero": "a-bla-ne-ro",
    "ablano": "a-bla-no",
    "ablativo": "a-bla-ti-vo",
    "ablatorio": "a-bla-to-rio",
    "ablegado": "a-ble-ga-do",
    "ablentador": "a-blen-ta-dor",
    "ablentar": "a-blen-tar",
    "ablución": "a-blu-ción",
    "ablusada": "a-blu-sa-da",
    "ablusado": "a-blu-sa-do",
    "abnegación": "ab-ne-ga-ción",
    "abnegada": "ab-ne-ga-da",
    "abnegadamente": "ab-ne-ga-da-men-te",
    "abnegado": "ab-ne-ga-do",
    "abnegar": "ab-ne-gar",
    "abobada": "a-bo-ba-da",
    "abobadamente": "a-bo-ba-da-men-te",
    "abobado": "a-bo-ba-do",
    "abobamiento": "a-bo-ba-mien-to",
    "abobar": "a-bo-bar",
    "abobra": "a-bo-bra",
    "abocadear": "a-bo-ca-de-ar",
    "abocado": "a-bo-ca-do",
    "abocamiento": "a-bo-ca-mien-to",
    "abocanar": "a-bo-ca-nar",
    "abocar": "a-bo-car",
    "abocardada": "a-bo-car-da-da",
    "abocardado": "a-bo-car-da-do",
    "abocardar": "a-bo-car-dar",
    "abocardo": "a-bo-car-do",
    "abocelada": "a-bo-ce-la-da",
    "abocelado": "a-bo-ce-la-do",
    "abocetada": "a-bo-ce-ta-da",
    "abocetadamente": "a-bo-ce-ta-da-men-te",
    "abocetado": "a-bo-ce-ta-do",
    "abocetamiento": "a-bo-ce-ta-mien-to",
    "abocetar": "a-bo-ce-tar",
    "abochornada": "a-bo-chor-na-da",
    "abochornado": "a-bo-chor-na-do",
    "abochornar": "a-bo-chor-nar",
    "abocinada": "a-bo-ci-na-da",
    "abocinado": "a-bo-ci-na-do",
    "abocinamiento": "a-bo-ci-na-mien-to",
    "abocinar": "a-bo-ci-nar",
    "abofado": "a-bo-fa-do",
    "abofar": "a-bo-far",
    "abofeteador": "a-bo-fe-te-a-dor",
    "abofeteadora": "a-bo-fe-te-a-do-ra",
    "abofetear": "a-bo-fe-te-ar",
    "abogacía": "a-bo-ga-cí-a",
    "abogada": "a-bo-ga-da",
    "abogaderas": "a-bo-ga-de-ras",
    "abogadesca": "a-bo-ga-des-ca",
    "abogadesco": "a-bo-ga-des-co",
    "abogadil": "a-bo-ga-dil",
    "abogadismo": "a-bo-ga-dis-mo",
    "abogado": "a-bo-ga-do",
    "abogador": "a-bo-ga-dor",
    "abogadora": "a-bo-ga-do-ra",
    "abogamiento": "a-bo-ga-mien-to",
    "abogar": "a-bo-gar",
    "abohetada": "a-bo-he-ta-da",
    "abohetado": "a-bo-he-ta-do",
    "abolaga": "a-bo-la-ga",
    "abolengo": "a-bo-len-go",
    "abolición": "a-bo-li-ción",
    "abolicionismo": "a-bo-li-cio-nis-mo",
    "abolicionista": "a-bo-li-cio-nis-ta",
    "abolir": "a-bo-lir",
    "abollada": "a-bo-lla-da",
    "abollado": "a-bo-lla-do",
    "abolladura": "a-bo-lla-du-ra",
    "abollar": "a-bo-llar",
    "abollón": "a-bo-llón",
    "abollonar": "a-bo-llo-nar",
    "abolorio": "a-bo-lo-rio",
    "abolsado": "a-bol-sa-do",
    "abolsar": "a-bol-sar",
    "abolsarse": "a-bol-sar-se",
    "abomaso": "a-bo-ma-so",
    "abombada": "a-bom-ba-da",
    "abombado": "a-bom-ba-do",
    "abombamiento": "a-bom-ba-mien-to",
    "abombar": "a-bom-bar",
    "abombe": "a-bom-be",
    "abominable": "a-bo-mi-na-ble",
    "abominablemente": "a-bo-mi-na-ble-men-te",
    "abominación": "a-bo-mi-na-ción",
    "abominar": "a-bo-mi-nar",
    "abonable": "a-bo-na-ble",
    "abonada": "a-bo-na-da",
    "abonado": "a-bo-na-do",
    "abonador": "a-bo-na-dor",
    "abonadora": "a-bo-na-do-ra",
    "abonanza": "a-bo-nan-za",
    "abonanzar": "a-bo-nan-zar",
    "abonar": "a-bo-nar",
    "abonaré": "a-bo-na-ré",
    "abondada": "a-bon-da-da",
    "abondado": "a-bon-da-do",
    "abondamiento": "a-bon-da-mien-to",
    "abondar": "a-bon-dar",
    "abondo": "a-bon-do",
    "abondosa": "a-bon-do-sa",
    "abondoso": "a-bon-do-so",
    "abonera": "a-bo-ne-ra",
    "abonero": "a-bo-ne-ro",
    "abono": "a-bo-no",
    "aboquillada": "a-bo-qui-lla-da",
    "aboquillado": "a-bo-qui-lla-do",
    "aboquillar": "a-bo-qui-llar",
    "aboral": "a-bo-ral",
    "abordable": "a-bor-da-ble",
    "abordador": "a-bor-da-dor",
    "abordadora": "a-bor-da-do-ra",
    "abordaje": "a-bor-da-je",
    "abordar": "a-bor-dar",
    "abordo": "a-bor-do",
    "abordonar": "a-bor-do-nar",
    "aborigen": "a-bo-ri-gen",
    "aborlonada": "a-bor-lo-na-da",
    "aborlonado": "a-bor-lo-na-do",
    "aborrachada": "a-bo-rra-cha-da",
    "aborrachado": "a-bo-rra-cha-do",
    "aborrajar": "a-bo-rra-jar",
    "aborrajarse": "a-bo-rra-jar-se",
    "aborrascar": "a-bo-rras-car",
    "aborrascarse": "a-bo-rras-car-se",
    "aborrecedor": "a-bo-rre-ce-dor",
    "aborrecedora": "a-bo-rre-ce-do-ra",
    "aborrecer": "a-bo-rre-cer",
    "aborrecible": "a-bo-rre-ci-ble",
    "aborrecimiento": "a-bo-rre-ci-mien-to",
    "aborregado": "a-bo-rre-ga-do",
    "aborregar": "a-bo-rre-gar",
    "aborregarse": "a-bo-rre-gar-se",
    "aborrible": "a-bo-rri-ble",
    "aborrir": "a-bo-rrir",
    "aborronar": "a-bo-rro-nar",
    "aborso": "a-bor-so",
    "abortadura": "a-bor-ta-du-ra",
    "abortamiento": "a-bor-ta-mien-to",
    "abortar": "a-bor-tar",
    "abortista": "a-bor-tis-ta",
    "abortiva": "a-bor-ti-va",
    "abortivo": "a-bor-ti-vo",
    "aborto": "a-bor-to",
    "abortón": "a-bor-tón",
    "aborujar": "a-bo-ru-jar",
    "abotagamiento": "a-bo-ta-ga-mien-to",
    "abotagar": "a-bo-ta-gar",
    "abotagarse": "a-bo-ta-gar-se",
    "abotargamiento": "a-bo-tar-ga-mien-to",
    "abotargar": "a-bo-tar-gar",
    "abotargarse": "a-bo-tar-gar-se",
    "abotinada": "a-bo-ti-na-da",
    "abotinado": "a-bo-ti-na-do",
    "abotonador": "a-bo-to-na-dor",
    "abotonadura": "a-bo-to-na-du-ra",
    "abotonar": "a-bo-to-nar",
    "abovedada": "a-bo-ve-da-da",
    "abovedado": "a-bo-ve-da-do",
    "abovedamiento": "a-bo-ve-da-mien-to",
    "abovedar": "a-bo-ve-dar",
    "aboyada": "a-bo-ya-da",
    "aboyado": "a-bo-ya-do",
    "aboyar": "a-bo-yar",
    "abozalar": "a-bo-za-lar",
    "abozo": "a-bo-zo",
    "abra": "a-bra",
    "abracadabra": "a-bra-ca-da-bra",
    "abracadabrante": "a-bra-ca-da-bran-te",
    "abracar": "a-bra-car",
    "abracijar": "a-bra-ci-jar",
    "abracijarse": "a-bra-ci-jar-se",
    "abracijo": "a-bra-ci-jo",
    "abraham": "a-bra-ham",
    "abrasadamente": "a-bra-sa-da-men-te",
    "abrasador": "a-bra-sa-dor",
    "abrasadora": "a-bra-sa-do-ra",
    "abrasamiento": "a-bra-sa-mien-to",
    "abrasar": "a-bra-sar",
    "abrasilada": "a-bra-si-la-da",
    "abrasilado": "a-bra-si-la-do",
    "abrasión": "a-bra-sión",
    "abrasiva": "a-bra-si-va",
    "abrasivo": "a-bra-si-vo",
    "abravar": "a-bra-var",
    "abravecer": "a-bra-ve-cer",
    "abraxas": "a-bra-xas",
    "abrazada": "a-bra-za-da",
    "abrazadera": "a-bra-za-de-ra",
    "abrazador": "a-bra-za-dor",
    "abrazadora": "a-bra-za-do-ra",
    "abrazamiento": "a-bra-za-mien-to",
    "abrazar": "a-bra-zar",
    "abrazo": "a-bra-zo",
    "abreboca": "a-bre-bo-ca",
    "abrebotellas": "a-bre-bo-te-llas",
    "abrecartas": "a-bre-car-tas",
    "abrecoches": "a-bre-co-ches",
    "abrefácil": "a-bre-fá-cil",
    "abregancias": "a-bre-gan-cias",
    "ábrego": "á-bre-go",
    "abrelatas": "a-bre-la-tas",
    "abrenunciar": "a-bre-nun-ciar",
    "abrenuncio": "a-bre-nun-cio",
    "abreojos": "a-bre-o-jos",
    "abrepuño": "a-bre-pu-ño",
    "abretonar": "a-bre-to-nar",
    "abrevadero": "a-bre-va-de-ro",
    "abrevador": "a-bre-va-dor",
    "abrevadora": "a-bre-va-do-ra",
    "abrevar": "a-bre-var",
    "abreviación": "a-bre-via-ción",
    "abreviada": "a-bre-via-da",
    "abreviadamente": "a-bre-via-da-men-te",
    "abreviado": "a-bre-via-do",
    "abreviador": "a-bre-via-dor",
    "abreviadora": "a-bre-via-do-ra",
    "abreviaduría": "a-bre-via-du-rí-a",
    "abreviamiento": "a-bre-via-mien-to",
    "abreviar": "a-bre-viar",
    "abreviatura": "a-bre-via-tu-ra",
    "abreviaturía": "a-bre-via-tu-rí-a",
    "abrezar": "a-bre-zar",
    "abriboca": "a-bri-bo-ca",
    "abribonada": "a-bri-bo-na-da",
    "abribonado": "a-bri-bo-na-do",
    "abribonar": "a-bri-bo-nar",
    "abribonarse": "a-bri-bo-nar-se",
    "abridera": "a-bri-de-ra",
    "abridero": "a-bri-de-ro",
    "abridor": "a-bri-dor",
    "abridora": "a-bri-do-ra",
    "abrigada": "a-bri-ga-da",
    "abrigadero": "a-bri-ga-de-ro",
    "abrigado": "a-bri-ga-do",
    "abrigador": "a-bri-ga-dor",
    "abrigadora": "a-bri-ga-do-ra",
    "abrigadura": "a-bri-ga-du-ra",
    "abrigamiento": "a-bri-ga-mien-to",
    "abrigaño": "a-bri-ga-ño",
    "abrigar": "a-bri-gar",
    "abrigo": "a-bri-go",
    "ábrigo": "á-bri-go",
    "abril": "a-bril",
    "abrileña": "a-bri-le-ña",
    "abrileño": "a-bri-le-ño",
    "abrillantado": "a-bri-llan-ta-do",
    "abrillantador": "a-bri-llan-ta-dor",
    "abrillantadora": "a-bri-llan-ta-do-ra",
    "abrillantamiento": "a-bri-llan-ta-mien-to",
    "abrillantar": "a-bri-llan-tar",
    "abrimiento": "a-bri-mien-to",
    "abriolar": "a-brio-lar",
    "abrir": "a-brir",
    "abrochador": "a-bro-cha-dor",
    "abrochadora": "a-bro-cha-do-ra",
    "abrochadura": "a-bro-cha-du-ra",
    "abrochamiento": "a-bro-cha-mien-to",
    "abrochar": "a-bro-char",
    "abrogación": "a-bro-ga-ción",
    "abrogar": "a-bro-gar",
    "abrojal": "a-bro-jal",
    "abrojillo": "a-bro-ji-llo",
    "abrojín": "a-bro-jín",
    "abrojo": "a-bro-jo",
    "abroma": "a-bro-ma",
    "abromada": "a-bro-ma-da",
    "abromado": "a-bro-ma-do",
    "abromar": "a-bro-mar",
    "abroncar": "a-bron-car",
    "abroquelada": "a-bro-que-la-da",
    "abroquelado": "a-bro-que-la-do",
    "abroquelar": "a-bro-que-lar",
    "abrótano": "a-bró-ta-no",
    "abrotoñar": "a-bro-to-ñar",
    "abrumación": "a-bru-ma-ción",
    "abrumador": "a-bru-ma-dor",
    "abrumadora": "a-bru-ma-do-ra",
    "abrumar": "a-bru-mar",
    "abrumarse": "a-bru-mar-se",
    "abrunal": "a-bru-nal",
    "abruñal": "a-bru-ñal",
    "abruno": "a-bru-no",
    "abruño": "a-bru-ño",
    "abrupción": "a-brup-ción",
    "abrupta": "a-brup-ta",
    "abruptamente": "a-brup-ta-men-te",
    "abrupto": "a-brup-to",
    "abrutada": "a-bru-ta-da",
    "abrutado": "a-bru-ta-do",
    "abruza": "a-bru-za",
    "abruzar": "a-bru-zar",
    "abruzo": "a-bru-zo",
    "absceso": "abs-ce-so",
    "abscisa": "abs-ci-sa",
    "abscisión": "abs-ci-sión",
    "absconder": "abs-con-der",
    "absencia": "ab-sen-cia",
    "absenta": "ab-sen-ta",
    "absentar": "ab-sen-tar",
    "absentarse": "ab-sen-tar-se",
    "absente": "ab-sen-te",
    "absentismo": "ab-sen-tis-mo",
    "absentista": "ab-sen-tis-ta",
    "ábsida": "áb-si-da",
    "absidal": "ab-si-dal",
    "ábside": "áb-si-de",
    "absidial": "ab-si-dial",
    "absidiola": "ab-si-dio-la",
    "absidiolo": "ab-si-dio-lo",
    "absintio": "ab-sin-tio",
    "ábsit": "áb-sit",
    "absolución": "ab-so-lu-ción",
    "absoluta": "ab-so-lu-ta",
    "absolutamente": "ab-so-lu-ta-men-te",
    "absolutez": "ab-so-lu-tez",
    "absolutidad": "ab-so-lu-ti-dad",
    "absolutismo": "ab-so-lu-tis-mo",
    "absolutista": "ab-so-lu-tis-ta",
    "absoluto": "ab-so-lu-to",
    "absolutoria": "ab-so-lu-to-ria",
    "absolutorio": "ab-so-lu-to-rio",
    "absolvederas": "ab-sol-ve-de-ras",
    "absolvedor": "ab-sol-ve-dor",
    "absolvedora": "ab-sol-ve-do-ra",
    "absolver": "ab-sol-ver",
    "absorbancia": "ab-sor-ban-cia",
    "absorbencia": "ab-sor-ben-cia",
    "absorbente": "ab-sor-ben-te",
    "absorber": "ab-sor-ber",
    "absorbible": "ab-sor-bi-ble",
    "absorbimiento": "ab-sor-bi-mien-to",
    "absorciómetro": "ab-sor-ció-me-tro",
    "absorción": "ab-sor-ción",
    "absorta": "ab-sor-ta",
    "absortar": "ab-sor-tar",
    "absorto": "ab-sor-to",
    "abstemia": "abs-te-mia",
    "abstemio": "abs-te-mio",
    "abstención": "abs-ten-ción",
    "abstencionismo": "abs-ten-cio-nis-mo",
    "abstencionista": "abs-ten-cio-nis-ta",
    "abstener": "abs-te-ner",
    "abstergente": "abs-ter-gen-te",
    "absterger": "abs-ter-ger",
    "abstersión": "abs-ter-sión",
    "abstersiva": "abs-ter-si-va",
    "abstersivo": "abs-ter-si-vo",
    "abstinencia": "abs-ti-nen-cia",
    "abstinencial": "abs-ti-nen-cial",
    "abstinente": "abs-ti-nen-te",
    "abstracción": "abs-trac-ción",
    "abstracta": "abs-trac-ta",
    "abstractamente": "abs-trac-ta-men-te",
    "abstractiva": "abs-trac-ti-va",
    "abstractivamente": "abs-trac-ti-va-men-te",
    "abstractivo": "abs-trac-ti-vo",
    "abstractizante": "abs-trac-ti-zan-te",
    "abstracto": "abs-trac-to",
    "abstraer": "abs-tra-er",
    "abstraído": "abs-tra-í-do",
    "abstrusa": "abs-tru-sa",
    "abstruso": "abs-tru-so",
    "absuelta": "ab-suel-ta",
    "absuelto": "ab-suel-to",
    "absurda": "ab-sur-da",
    "absurdamente": "ab-sur-da-men-te",
    "absurdidad": "ab-sur-di-dad",
    "absurdo": "ab-sur-do",
    "abubilla": "a-bu-bi-lla",
    "abubo": "a-bu-bo",
    "abuchear": "a-bu-che-ar",
    "abucheo": "a-bu-che-o",
    "abudabita": "a-bu-da-bi-ta",
    "abuela": "a-bue-la",
    "abuelastra": "a-bue-las-tra",
    "abuelastro": "a-bue-las-tro",
    "abuelazón": "a-bue-la-zón",
    "abuelo": "a-bue-lo",
    "abuenar": "a-bue-nar",
    "abuhada": "a-buha-da",
    "abuhado": "a-buha-do",
    "abuhamiento": "a-buha-mien-to",
    "abuhardillada": "a-buhar-di-lla-da",
    "abuhardillado": "a-buhar-di-lla-do",
    "abujardar": "a-bu-jar-dar",
    "abuje": "a-bu-je",
    "abulaga": "a-bu-la-ga",
    "abulagar": "a-bu-la-gar",
    "abulencia": "a-bu-len-cia",
    "abulense": "a-bu-len-se",
    "abulensismo": "a-bu-len-sis-mo",
    "abulia": "a-bu-lia",
    "abúlica": "a-bú-li-ca",
    "abúlicamente": "a-bú-li-ca-men-te",
    "abúlico": "a-bú-li-co",
    "abullonar": "a-bu-llo-nar",
    "abulón": "a-bu-lón",
    "abulonar": "a-bu-lo-nar",
    "abultada": "a-bul-ta-da",
    "abultadamente": "a-bul-ta-da-men-te",
    "abultado": "a-bul-ta-do",
    "abultamiento": "a-bul-ta-mien-to",
    "abultar": "a-bul-tar",
    "abundada": "a-bun-da-da",
    "abundado": "a-bun-da-do",
    "abundamiento": "a-bun-da-mien-to",
    "abundancia": "a-bun-dan-cia",
    "abundancial": "a-bun-dan-cial",
    "abundante": "a-bun-dan-te",
    "abundantemente": "a-bun-dan-te-men-te",
    "abundar": "a-bun-dar",
    "abundo": "a-bun-do",
    "abundosa": "a-bun-do-sa",
    "abundoso": "a-bun-do-so",
    "abuñolado": "a-bu-ño-la-do",
    "abuñolar": "a-bu-ño-lar",
    "abuñuelada": "a-bu-ñue-la-da",
    "abuñuelado": "a-bu-ñue-la-do",
    "abuñuelar": "a-bu-ñue-lar",
    "abur": "a-bur",
    "aburar": "a-bu-rar",
    "aburelada": "a-bu-re-la-da",
    "aburelado": "a-bu-re-la-do",
    "aburguesamiento": "a-bur-gue-sa-mien-to",
    "aburguesar": "a-bur-gue-sar",
    "aburguesarse": "a-bur-gue-sar-se",
    "aburrada": "a-bu-rra-da",
    "aburrado": "a-bu-rra-do",
    "aburrar": "a-bu-rrar",
    "aburrarse": "a-bu-rrar-se",
    "aburrición": "a-bu-rri-ción",
    "aburrida": "a-bu-rri-da",
    "aburridamente": "a-bu-rri-da-men-te",
    "aburrido": "a-bu-rri-do",
    "aburridor": "a-bu-rri-dor",
    "aburridora": "a-bu-rri-do-ra",
    "aburrimiento": "a-bu-rri-mien-to",
    "aburrir": "a-bu-rrir",
    "aburujar": "a-bu-ru-jar",
    "abusada": "a-bu-sa-da",
    "abusado": "a-bu-sa-do",
    "abusador": "a-bu-sa-dor",
    "abusadora": "a-bu-sa-do-ra",
    "abusar": "a-bu-sar",
    "abusión": "a-bu-sión",
    "abusionera": "a-bu-sio-ne-ra",
    "abusionero": "a-bu-sio-ne-ro",
    "abusiva": "a-bu-si-va",
    "abusivamente": "a-bu-si-va-men-te",
    "abusivo": "a-bu-si-vo",
    "abuso": "a-bu-so",
    "abusón": "a-bu-són",
    "abusona": "a-bu-so-na",
    "abutagar": "a-bu-ta-gar",
    "abuzar": "a-bu-zar",
    "abuzarse": "a-bu-zar-se",
    "abyección": "ab-yec-ción",
    "abyecta": "ab-yec-ta",
    "abyectamente": "ab-yec-ta-men-te",
    "abyecto": "ab-yec-to",
    "aca": "a-ca",
    "acá": "a-cá",
    "acabable": "a-ca-ba-ble",
    "acabada": "a-ca-ba-da",
    "acabadamente": "a-ca-ba-da-men-te",
    "acabado": "a-ca-ba-do",
    "acabador": "a-ca-ba-dor",
    "acabadora": "a-ca-ba-do-ra",
    "acabadura": "a-ca-ba-du-ra",
    "acabalar": "a-ca-ba-lar",
    "acaballada": "a-ca-ba-lla-da",
    "acaballadero": "a-ca-ba-lla-de-ro",
    "acaballado": "a-ca-ba-lla-do",
    "acaballar": "a-ca-ba-llar",
    "acaballerada": "a-ca-ba-lle-ra-da",
    "acaballerado": "a-ca-ba-lle-ra-do",
    "acaballerar": "a-ca-ba-lle-rar",
    "acaballonar": "a-ca-ba-llo-nar",
    "acabamiento": "a-ca-ba-mien-to",
    "acabañar": "a-ca-ba-ñar",
    "acabangado": "a-ca-ban-ga-do",
    "acabangar": "a-ca-ban-gar",
    "acabar": "a-ca-bar",
    "acabe": "a-ca-be",
    "acabellada": "a-ca-be-lla-da",
    "acabellado": "a-ca-be-lla-do",
    "acabestrillar": "a-ca-bes-tri-llar",
    "acabijo": "a-ca-bi-jo",
    "acabildar": "a-ca-bil-dar",
    "acabo": "a-ca-bo",
    "acabose": "a-ca-bo-se",
    "acabronada": "a-ca-bro-na-da",
    "acabronado": "a-ca-bro-na-do",
    "acachar": "a-ca-char",
    "acacharse": "a-ca-char-se",
    "acachetar": "a-ca-che-tar",
    "acachetear": "a-ca-che-te-ar",
    "acachorrar": "a-ca-cho-rrar",
    "acacia": "a-ca-cia",
    "acaciana": "a-ca-cia-na",
    "acaciano": "a-ca-cia-no",
    "academia": "a-ca-de-mia",
    "académica": "a-ca-dé-mi-ca",
    "académicamente": "a-ca-dé-mi-ca-men-te",
    "academicismo": "a-ca-de-mi-cis-mo",
    "academicista": "a-ca-de-mi-cis-ta",
    "académico": "a-ca-dé-mi-co",
    "academio": "a-ca-de-mio",
    "academismo": "a-ca-de-mis-mo",
    "academista": "a-ca-de-mis-ta",
    "academización": "a-ca-de-mi-za-ción",
    "academizar": "a-ca-de-mi-zar",
    "acadia": "a-ca-dia",
    "acadio": "a-ca-dio",
    "acaecedera": "a-ca-e-ce-de-ra",
    "acaecedero": "a-ca-e-ce-de-ro",
    "acaecer": "a-ca-e-cer",
    "acaecimiento": "a-ca-e-ci-mien-to",
    "acafresna": "a-ca-fres-na",
    "acaguasar": "a-ca-gua-sar",
    "acahual": "a-ca-hual",
    "acairelar": "a-cai-re-lar",
    "acal": "a-cal",
    "acalabrotar": "a-ca-la-bro-tar",
    "acalambrar": "a-ca-lam-brar",
    "acaldar": "a-cal-dar",
    "acalefo": "a-ca-le-fo",
    "acalentada": "a-ca-len-ta-da",
    "acalentado": "a-ca-len-ta-do",
    "acalenturada": "a-ca-len-tu-ra-da",
    "acalenturado": "a-ca-len-tu-ra-do",
    "acalenturar": "a-ca-len-tu-rar",
    "acalenturarse": "a-ca-len-tu-rar-se",
    "acalia": "a-ca-lia",
    "acallador": "a-ca-lla-dor",
    "acalladora": "a-ca-lla-do-ra",
    "acallamiento": "a-ca-lla-mien-to",
    "acallantar": "a-ca-llan-tar",
    "acallar": "a-ca-llar",
    "acalmar": "a-cal-mar",
    "acaloñar": "a-ca-lo-ñar",
    "acaloradamente": "a-ca-lo-ra-da-men-te",
    "acalorado": "a-ca-lo-ra-do",
    "acaloramiento": "a-ca-lo-ra-mien-to",
    "acalorar": "a-ca-lo-rar",
    "acalórico": "a-ca-ló-ri-co",
    "acaloro": "a-ca-lo-ro",
    "acalugar": "a-ca-lu-gar",
    "acalumniador": "a-ca-lum-nia-dor",
    "acalumniadora": "a-ca-lum-nia-do-ra",
    "acalumniar": "a-ca-lum-niar",
    "acamado": "a-ca-ma-do",
    "acamalar": "a-ca-ma-lar",
    "acamar": "a-ca-mar",
    "acamaya": "a-ca-ma-ya",
    "acambrayada": "a-cam-bra-ya-da",
    "acambrayado": "a-cam-bra-ya-do",
    "acamellada": "a-ca-me-lla-da",
    "acamellado": "a-ca-me-lla-do",
    "acamellonar": "a-ca-me-llo-nar",
    "acampada": "a-cam-pa-da",
    "acampamento": "a-cam-pa-men-to",
    "acampanada": "a-cam-pa-na-da",
    "acampanado": "a-cam-pa-na-do",
    "acampanar": "a-cam-pa-nar",
    "acampar": "a-cam-par",
    "acampo": "a-cam-po",
    "acamuzada": "a-ca-mu-za-da",
    "acamuzado": "a-ca-mu-za-do",
    "ácana": "á-ca-na",
    "acanalada": "a-ca-na-la-da",
    "acanalado": "a-ca-na-la-do",
    "acanalador": "a-ca-na-la-dor",
    "acanaladura": "a-ca-na-la-du-ra",
    "acanalar": "a-ca-na-lar",
    "acanallada": "a-ca-na-lla-da",
    "acanallado": "a-ca-na-lla-do",
    "acanallar": "a-ca-na-llar",
    "acañaverear": "a-ca-ña-ve-re-ar",
    "acandilada": "a-can-di-la-da",
    "acandilado": "a-can-di-la-do",
    "acanelada": "a-ca-ne-la-da",
    "acanelado": "a-ca-ne-la-do",
    "acanelonar": "a-ca-ne-lo-nar",
    "acanillada": "a-ca-ni-lla-da",
    "acanillado": "a-ca-ni-lla-do",
    "acanilladura": "a-ca-ni-lla-du-ra",
    "acañonear": "a-ca-ño-ne-ar",
    "acantácea": "a-can-tá-ce-a",
    "acantáceo": "a-can-tá-ce-o",
    "acantalear": "a-can-ta-le-ar",
    "acantarar": "a-can-ta-rar",
    "acantear": "a-can-te-ar",
    "acantilada": "a-can-ti-la-da",
    "acantilado": "a-can-ti-la-do",
    "acantilar": "a-can-ti-lar",
    "acantinflado": "a-can-tin-fla-do",
    "acantio": "a-can-tio",
    "acanto": "a-can-to",
    "acantocéfalo": "a-can-to-cé-fa-lo",
    "acantocito": "a-can-to-ci-to",
    "acantocitosis": "a-can-to-ci-to-sis",
    "acantonamiento": "a-can-to-na-mien-to",
    "acantonar": "a-can-to-nar",
    "acantopterigio": "a-can-top-te-ri-gio",
    "acañutada": "a-ca-ñu-ta-da",
    "acañutado": "a-ca-ñu-ta-do",
    "acapaneca": "a-ca-pa-ne-ca",
    "acaparador": "a-ca-pa-ra-dor",
    "acaparadora": "a-ca-pa-ra-do-ra",
    "acaparamiento": "a-ca-pa-ra-mien-to",
    "acaparar": "a-ca-pa-rar",
    "acaparrar": "a-ca-pa-rrar",
    "acaparrarse": "a-ca-pa-rrar-se",
    "acaparrosada": "a-ca-pa-rro-sa-da",
    "acaparrosado": "a-ca-pa-rro-sa-do",
    "acapillar": "a-ca-pi-llar",
    "acápite": "a-cá-pi-te",
    "acapizar": "a-ca-pi-zar",
    "acapizarse": "a-ca-pi-zar-se",
    "acaponada": "a-ca-po-na-da",
    "acaponado": "a-ca-po-na-do",
    "acapujar": "a-ca-pu-jar",
    "acapullar": "a-ca-pu-llar",
    "acapullarse": "a-ca-pu-llar-se",
    "acapulqueña": "a-ca-pul-que-ña",
    "acapulqueño": "a-ca-pul-que-ño",
    "acaracolada": "a-ca-ra-co-la-da",
    "acaracolado": "a-ca-ra-co-la-do",
    "acarambanada": "a-ca-ram-ba-na-da",
    "acarambanado": "a-ca-ram-ba-na-do",
    "acaramelado": "a-ca-ra-me-la-do",
    "acaramelar": "a-ca-ra-me-lar",
    "acarar": "a-ca-rar",
    "acarcavar": "a-car-ca-var",
    "acardenalar": "a-car-de-na-lar",
    "acareamiento": "a-ca-re-a-mien-to",
    "acarear": "a-ca-re-ar",
    "acariciador": "a-ca-ri-cia-dor",
    "acariciadora": "a-ca-ri-cia-do-ra",
    "acariciante": "a-ca-ri-cian-te",
    "acariciar": "a-ca-ri-ciar",
    "acaricida": "a-ca-ri-ci-da",
    "acárido": "a-cá-ri-do",
    "acarminado": "a-car-mi-na-do",
    "acarnerada": "a-car-ne-ra-da",
    "acarnerado": "a-car-ne-ra-do",
    "ácaro": "á-ca-ro",
    "acaronar": "a-ca-ro-nar",
    "acarralado": "a-ca-rra-la-do",
    "acarraladura": "a-ca-rra-la-du-ra",
    "acarralar": "a-ca-rra-lar",
    "acarrar": "a-ca-rrar",
    "acarrarse": "a-ca-rrar-se",
    "acarrascada": "a-ca-rras-ca-da",
    "acarrascado": "a-ca-rras-ca-do",
    "acarrazar": "a-ca-rra-zar",
    "acarrazarse": "a-ca-rra-zar-se",
    "acarreada": "a-ca-rre-a-da",
    "acarreadiza": "a-ca-rre-a-di-za",
    "acarreadizo": "a-ca-rre-a-di-zo",
    "acarreado": "a-ca-rre-a-do",
    "acarreador": "a-ca-rre-a-dor",
    "acarreadora": "a-ca-rre-a-do-ra",
    "acarreamiento": "a-ca-rre-a-mien-to",
    "acarrear": "a-ca-rre-ar",
    "acarreo": "a-ca-rre-o",
    "acarretar": "a-ca-rre-tar",
    "acarreto": "a-ca-rre-to",
    "acartelado": "a-car-te-la-do",
    "acartonada": "a-car-to-na-da",
    "acartonado": "a-car-to-na-do",
    "acartonar": "a-car-to-nar",
    "acartonarse": "a-car-to-nar-se",
    "acasamatada": "a-ca-sa-ma-ta-da",
    "acasamatado": "a-ca-sa-ma-ta-do",
    "acasarado": "a-ca-sa-ra-do",
    "acaserada": "a-ca-se-ra-da",
    "acaserado": "a-ca-se-ra-do",
    "acaserar": "a-ca-se-rar",
    "acaserarse": "a-ca-se-rar-se",
    "acaso": "a-ca-so",
    "acastañada": "a-cas-ta-ña-da",
    "acastañado": "a-cas-ta-ña-do",
    "acastillada": "a-cas-ti-lla-da",
    "acastillado": "a-cas-ti-lla-do",
    "acastorada": "a-cas-to-ra-da",
    "acastorado": "a-cas-to-ra-do",
    "acatable": "a-ca-ta-ble",
    "acatadamente": "a-ca-ta-da-men-te",
    "acatadura": "a-ca-ta-du-ra",
    "acatalecta": "a-ca-ta-lec-ta",
    "acataléctico": "a-ca-ta-léc-ti-co",
    "acatalecto": "a-ca-ta-lec-to",
    "acatamiento": "a-ca-ta-mien-to",
    "acatanca": "a-ca-tan-ca",
    "acatar": "a-ca-tar",
    "acatarrar": "a-ca-ta-rrar",
    "acateca": "a-ca-te-ca",
    "acates": "a-ca-tes",
    "acato": "a-ca-to",
    "acatólica": "a-ca-tó-li-ca",
    "acatólicamente": "a-ca-tó-li-ca-men-te",
    "acatólico": "a-ca-tó-li-co",
    "acaudalada": "a-cau-da-la-da",
    "acaudalado": "a-cau-da-la-do",
    "acaudalador": "a-cau-da-la-dor",
    "acaudaladora": "a-cau-da-la-do-ra",
    "acaudalar": "a-cau-da-lar",
    "acaudillador": "a-cau-di-lla-dor",
    "acaudilladora": "a-cau-di-lla-do-ra",
    "acaudillamiento": "a-cau-di-lla-mien-to",
    "acaudillar": "a-cau-di-llar",
    "acaule": "a-cau-le",
    "acautelar": "a-cau-te-lar",
    "acautelarse": "a-cau-te-lar-se",
    "acceder": "ac-ce-der",
    "accesibilidad": "ac-ce-si-bi-li-dad",
    "accesible": "ac-ce-si-ble",
    "accesión": "ac-ce-sión",
    "accesional": "ac-ce-sio-nal",
    "accésit": "ac-cé-sit",
    "acceso": "ac-ce-so",
    "accesoria": "ac-ce-so-ria",
    "accesoriamente": "ac-ce-so-ria-men-te",
    "accesorio": "ac-ce-so-rio",
    "accidentabilidad": "ac-ci-den-ta-bi-li-dad",
    "accidentada": "ac-ci-den-ta-da",
    "accidentadamente": "ac-ci-den-ta-da-men-te",
    "accidentado": "ac-ci-den-ta-do",
    "accidental": "ac-ci-den-tal",
    "accidentalidad": "ac-ci-den-ta-li-dad",
    "accidentalmente": "ac-ci-den-tal-men-te",
    "accidentar": "ac-ci-den-tar",
    "accidentaria": "ac-ci-den-ta-ria",
    "accidentariamente": "ac-ci-den-ta-ria-men-te",
    "accidentario": "ac-ci-den-ta-rio",
    "accidente": "ac-ci-den-te",
    "acción": "ac-ción",
    "accionable": "ac-cio-na-ble",
    "accionado": "ac-cio-na-do",
    "accionamiento": "ac-cio-na-mien-to",
    "accionar": "ac-cio-nar",
    "accionaria": "ac-cio-na-ria",
    "accionariado": "ac-cio-na-ria-do",
    "accionarial": "ac-cio-na-rial",
    "accionario": "ac-cio-na-rio",
    "accionista": "ac-cio-nis-ta",
    "accisa": "ac-ci-sa",
    "accitana": "ac-ci-ta-na",
    "accitano": "ac-ci-ta-no",
    "ace": "a-ce",
    "acebadamiento": "a-ce-ba-da-mien-to",
    "acebadar": "a-ce-ba-dar",
    "acebal": "a-ce-bal",
    "acebeda": "a-ce-be-da",
    "acebedo": "a-ce-be-do",
    "acebibe": "a-ce-bi-be",
    "acebo": "a-ce-bo",
    "acebollada": "a-ce-bo-lla-da",
    "acebollado": "a-ce-bo-lla-do",
    "acebolladura": "a-ce-bo-lla-du-ra",
    "acebrada": "a-ce-bra-da",
    "acebrado": "a-ce-bra-do",
    "acebuchal": "a-ce-bu-chal",
    "acebuche": "a-ce-bu-che",
    "acebuchena": "a-ce-bu-che-na",
    "acebucheno": "a-ce-bu-che-no",
    "acebuchina": "a-ce-bu-chi-na",
    "acechadera": "a-ce-cha-de-ra",
    "acechadero": "a-ce-cha-de-ro",
    "acechador": "a-ce-cha-dor",
    "acechadora": "a-ce-cha-do-ra",
    "acechamiento": "a-ce-cha-mien-to",
    "acechante": "a-ce-chan-te",
    "acechanza": "a-ce-chan-za",
    "acechar": "a-ce-char",
    "aceche": "a-ce-che",
    "acecho": "a-ce-cho",
    "acechón": "a-ce-chón",
    "acechona": "a-ce-cho-na",
    "acecido": "a-ce-ci-do",
    "acecinar": "a-ce-ci-nar",
    "aceda": "a-ce-da",
    "acedamente": "a-ce-da-men-te",
    "acedar": "a-ce-dar",
    "acedera": "a-ce-de-ra",
    "acederaque": "a-ce-de-ra-que",
    "acederilla": "a-ce-de-ri-lla",
    "acederón": "a-ce-de-rón",
    "acedía": "a-ce-dí-a",
    "acedia": "a-ce-dia",
    "acedo": "a-ce-do",
    "acedura": "a-ce-du-ra",
    "acéfala": "a-cé-fa-la",
    "acefalía": "a-ce-fa-lí-a",
    "acefalismo": "a-ce-fa-lis-mo",
    "acéfalo": "a-cé-fa-lo",
    "aceifa": "a-cei-fa",
    "aceitada": "a-cei-ta-da",
    "aceitar": "a-cei-tar",
    "aceitazo": "a-cei-ta-zo",
    "aceite": "a-cei-te",
    "aceitera": "a-cei-te-ra",
    "aceitería": "a-cei-te-rí-a",
    "aceitero": "a-cei-te-ro",
    "aceitón": "a-cei-tón",
    "aceitosa": "a-cei-to-sa",
    "aceitoso": "a-cei-to-so",
    "aceituna": "a-cei-tu-na",
    "aceitunada": "a-cei-tu-na-da",
    "aceitunado": "a-cei-tu-na-do",
    "aceitunera": "a-cei-tu-ne-ra",
    "aceitunero": "a-cei-tu-ne-ro",
    "aceituní": "a-cei-tu-ní",
    "aceitunil": "a-cei-tu-nil",
    "aceitunillo": "a-cei-tu-ni-llo",
    "aceituno": "a-cei-tu-no",
    "acejero": "a-ce-je-ro",
    "acelajada": "a-ce-la-ja-da",
    "acelajado": "a-ce-la-ja-do",
    "aceleración": "a-ce-le-ra-ción",
    "acelerada": "a-ce-le-ra-da",
    "aceleradamente": "a-ce-le-ra-da-men-te",
    "acelerado": "a-ce-le-ra-do",
    "acelerador": "a-ce-le-ra-dor",
    "aceleramiento": "a-ce-le-ra-mien-to",
    "acelerar": "a-ce-le-rar",
    "aceleratriz": "a-ce-le-ra-triz",
    "acelere": "a-ce-le-re",
    "acelerómetro": "a-ce-le-ró-me-tro",
    "acelerón": "a-ce-le-rón",
    "acelga": "a-cel-ga",
    "acelomado": "a-ce-lo-ma-do",
    "acema": "a-ce-ma",
    "acémila": "a-cé-mi-la",
    "acemilada": "a-ce-mi-la-da",
    "acemilado": "a-ce-mi-la-do",
    "acemilar": "a-ce-mi-lar",
    "acemilera": "a-ce-mi-le-ra",
    "acemilería": "a-ce-mi-le-rí-a",
    "acemilero": "a-ce-mi-le-ro",
    "acemita": "a-ce-mi-ta",
    "acemite": "a-ce-mi-te",
    "aceña": "a-ce-ña",
    "acender": "a-cen-der",
    "acendrada": "a-cen-dra-da",
    "acendradamente": "a-cen-dra-da-men-te",
    "acendrado": "a-cen-dra-do",
    "acendramiento": "a-cen-dra-mien-to",
    "acendrar": "a-cen-drar",
    "acenefa": "a-ce-ne-fa",
    "aceñero": "a-ce-ñe-ro",
    "acenoria": "a-ce-no-ria",
    "acensar": "a-cen-sar",
    "acensuador": "a-cen-sua-dor",
    "acensuar": "a-cen-suar",
    "acento": "a-cen-to",
    "acentuación": "a-cen-tua-ción",
    "acentuadamente": "a-cen-tua-da-men-te",
    "acentuado": "a-cen-tua-do",
    "acentual": "a-cen-tual",
    "acentuamiento": "a-cen-tua-mien-to",
    "acentuar": "a-cen-tuar",
    "acepar": "a-ce-par",
    "acepción": "a-cep-ción",
    "acepilladura": "a-ce-pi-lla-du-ra",
    "acepillar": "a-ce-pi-llar",
    "acepta": "a-cep-ta",
    "aceptabilidad": "a-cep-ta-bi-li-dad",
    "aceptable": "a-cep-ta-ble",
    "aceptablemente": "a-cep-ta-ble-men-te",
    "aceptación": "a-cep-ta-ción",
    "aceptadamente": "a-cep-ta-da-men-te",
    "aceptador": "a-cep-ta-dor",
    "aceptadora": "a-cep-ta-do-ra",
    "aceptante": "a-cep-tan-te",
    "aceptar": "a-cep-tar",
    "acepto": "a-cep-to",
    "aceptor": "a-cep-tor",
    "acequia": "a-ce-quia",
    "acequiaje": "a-ce-quia-je",
    "acequiar": "a-ce-quiar",
    "acequiero": "a-ce-quie-ro",
    "acera": "a-ce-ra",
    "acerácea": "a-ce-rá-ce-a",
    "aceráceo": "a-ce-rá-ce-o",
    "aceración": "a-ce-ra-ción",
    "acerada": "a-ce-ra-da",
    "aceradamente": "a-ce-ra-da-men-te",
    "acerado": "a-ce-ra-do",
    "acerar": "a-ce-rar",
    "acerba": "a-cer-ba",
    "acerbamente": "a-cer-ba-men-te",
    "acerbidad": "a-cer-bi-dad",
    "acerbo": "a-cer-bo",
    "acerca": "a-cer-ca",
    "acercador": "a-cer-ca-dor",
    "acercadora": "a-cer-ca-do-ra",
    "acercamiento": "a-cer-ca-mien-to",
    "acercanza": "a-cer-can-za",
    "acercar": "a-cer-car",
    "ácere": "á-ce-re",
    "acerería": "a-ce-re-rí-a",
    "acería": "a-ce-rí-a",
    "acerico": "a-ce-ri-co",
    "acerillo": "a-ce-ri-llo",
    "acerina": "a-ce-ri-na",
    "acerínea": "a-ce-rí-ne-a",
    "aceríneo": "a-ce-rí-ne-o",
    "acerino": "a-ce-ri-no",
    "acerista": "a-ce-ris-ta",
    "acernadar": "a-cer-na-dar",
    "acero": "a-ce-ro",
    "acerola": "a-ce-ro-la",
    "acerolo": "a-ce-ro-lo",
    "acérrimamente": "a-cé-rri-ma-men-te",
    "acérrimo": "a-cé-rri-mo",
    "acerrojar": "a-ce-rro-jar",
    "acertada": "a-cer-ta-da",
    "acertadamente": "a-cer-ta-da-men-te",
    "acertado": "a-cer-ta-do",
    "acertador": "a-cer-ta-dor",
    "acertadora": "a-cer-ta-do-ra",
    "acertajo": "a-cer-ta-jo",
    "acertajón": "a-cer-ta-jón",
    "acertajona": "a-cer-ta-jo-na",
    "acertamiento": "a-cer-ta-mien-to",
    "acertante": "a-cer-tan-te",
    "acertar": "a-cer-tar",
    "acertero": "a-cer-te-ro",
    "acertijo": "a-cer-ti-jo",
    "aceruelo": "a-ce-rue-lo",
    "acervar": "a-cer-var",
    "acervo": "a-cer-vo",
    "acescencia": "a-ces-cen-cia",
    "acescente": "a-ces-cen-te",
    "aceta": "a-ce-ta",
    "acetábulo": "a-ce-tá-bu-lo",
    "acetal": "a-ce-tal",
    "acetaldehído": "a-ce-tal-de-hí-do",
    "acetamida": "a-ce-ta-mi-da",
    "acetar": "a-ce-tar",
    "acetato": "a-ce-ta-to",
    "acetazolamida": "a-ce-ta-zo-la-mi-da",
    "acética": "a-cé-ti-ca",
    "acético": "a-cé-ti-co",
    "acetificación": "a-ce-ti-fi-ca-ción",
    "acetificador": "a-ce-ti-fi-ca-dor",
    "acetificar": "a-ce-ti-fi-car",
    "acetilar": "a-ce-ti-lar",
    "acetilcolina": "a-ce-til-co-li-na",
    "acetileno": "a-ce-ti-le-no",
    "acetilo": "a-ce-ti-lo",
    "acetilsalicílico": "a-ce-til-sa-li-cí-li-co",
    "acetimetría": "a-ce-ti-me-trí-a",
    "acetímetro": "a-ce-tí-me-tro",
    "acetín": "a-ce-tín",
    "acetite": "a-ce-ti-te",
    "aceto": "a-ce-to",
    "acetona": "a-ce-to-na",
    "acetosa": "a-ce-to-sa",
    "acetosidad": "a-ce-to-si-dad",
    "acetosilla": "a-ce-to-si-lla",
    "acetoso": "a-ce-to-so",
    "acetre": "a-ce-tre",
    "acetrería": "a-ce-tre-rí-a",
    "acetrero": "a-ce-tre-ro",
    "acetrinar": "a-ce-tri-nar",
    "acevilar": "a-ce-vi-lar",
    "acezante": "a-ce-zan-te",
    "acezar": "a-ce-zar",
    "acezo": "a-ce-zo",
    "acezosa": "a-ce-zo-sa",
    "acezoso": "a-ce-zo-so",
    "achabacanamiento": "a-cha-ba-ca-na-mien-to",
    "achabacanar": "a-cha-ba-ca-nar",
    "achacable": "a-cha-ca-ble",
    "achacacheña": "a-cha-ca-che-ña",
    "achacacheño": "a-cha-ca-che-ño",
    "achacar": "a-cha-car",
    "achachairú": "a-cha-chai-rú",
    "achachay": "a-cha-chay",
    "achachi": "a-cha-chi",
    "achacosa": "a-cha-co-sa",
    "achacoso": "a-cha-co-so",
    "achacual": "a-cha-cual",
    "achaflanar": "a-cha-fla-nar",
    "achajuanado": "a-cha-jua-na-do",
    "achajuanar": "a-cha-jua-nar",
    "achajuanarse": "a-cha-jua-nar-se",
    "achalay": "a-cha-lay",
    "achambergada": "a-cham-ber-ga-da",
    "achambergado": "a-cham-ber-ga-do",
    "achampañada": "a-cham-pa-ña-da",
    "achampanado": "a-cham-pa-na-do",
    "achampañado": "a-cham-pa-ña-do",
    "achancar": "a-chan-car",
    "achanchar": "a-chan-char",
    "achantada": "a-chan-ta-da",
    "achantado": "a-chan-ta-do",
    "achantar": "a-chan-tar",
    "achaparrada": "a-cha-pa-rra-da",
    "achaparrado": "a-cha-pa-rra-do",
    "achaparrar": "a-cha-pa-rrar",
    "achaparrarse": "a-cha-pa-rrar-se",
    "achaplinar": "a-cha-pli-nar",
    "achaque": "a-cha-que",
    "achaquero": "a-cha-que-ro",
    "achaquienta": "a-cha-quien-ta",
    "achaquiento": "a-cha-quien-to",
    "achara": "a-cha-ra",
    "achará": "a-cha-rá",
    "acharar": "a-cha-rar",
    "achares": "a-cha-res",
    "acharolada": "a-cha-ro-la-da",
    "acharolado": "a-cha-ro-la-do",
    "acharolar": "a-cha-ro-lar",
    "achatamiento": "a-cha-ta-mien-to",
    "achatar": "a-cha-tar",
    "achatarramiento": "a-cha-ta-rra-mien-to",
    "achatarrar": "a-cha-ta-rrar",
    "achechar": "a-che-char",
    "achelense": "a-che-len-se",
    "achí": "a-chí",
    "achicada": "a-chi-ca-da",
    "achicado": "a-chi-ca-do",
    "achicador": "a-chi-ca-dor",
    "achicadora": "a-chi-ca-do-ra",
    "achicadura": "a-chi-ca-du-ra",
    "achicalar": "a-chi-ca-lar",
    "achicamiento": "a-chi-ca-mien-to",
    "achicar": "a-chi-car",
    "achichada": "a-chi-cha-da",
    "achichado": "a-chi-cha-do",
    "achicharradero": "a-chi-cha-rra-de-ro",
    "achicharramiento": "a-chi-cha-rra-mien-to",
    "achicharrante": "a-chi-cha-rran-te",
    "achicharrar": "a-chi-cha-rrar",
    "achicharre": "a-chi-cha-rre",
    "achicharronar": "a-chi-cha-rro-nar",
    "achichiguar": "a-chi-chi-guar",
    "achichinar": "a-chi-chi-nar",
    "achichincle": "a-chi-chin-cle",
    "achichinque": "a-chi-chin-que",
    "achichintle": "a-chi-chin-tle",
    "achicopalar": "a-chi-co-pa-lar",
    "achicorera": "a-chi-co-re-ra",
    "achicorero": "a-chi-co-re-ro",
    "achicoria": "a-chi-co-ria",
    "achiguar": "a-chi-guar",
    "achiguarse": "a-chi-guar-se",
    "achilado": "a-chi-la-do",
    "achimero": "a-chi-me-ro",
    "achín": "a-chín",
    "achinada": "a-chi-na-da",
    "achinado": "a-chi-na-do",
    "achinamiento": "a-chi-na-mien-to",
    "achinar": "a-chi-nar",
    "achinelada": "a-chi-ne-la-da",
    "achinelado": "a-chi-ne-la-do",
    "achinera": "a-chi-ne-ra",
    "achinería": "a-chi-ne-rí-a",
    "achinero": "a-chi-ne-ro",
    "achiotado": "a-chio-ta-do",
    "achiotal": "a-chio-tal",
    "achiote": "a-chio-te",
    "achiotera": "a-chio-te-ra",
    "achiotero": "a-chio-te-ro",
    "achiotillo": "a-chio-ti-llo",
    "achipilar": "a-chi-pi-lar",
    "achique": "a-chi-que",
    "achiquillada": "a-chi-qui-lla-da",
    "achiquillado": "a-chi-qui-lla-do",
    "achiquitar": "a-chi-qui-tar",
    "achira": "a-chi-ra",
    "achirlar": "a-chir-lar",
    "achís": "a-chís",
    "achispado": "a-chis-pa-do",
    "achispar": "a-chis-par",
    "achitabla": "a-chi-ta-bla",
    "achivar": "a-chi-var",
    "achocadura": "a-cho-ca-du-ra",
    "achocar": "a-cho-car",
    "achochar": "a-cho-char",
    "achocharse": "a-cho-char-se",
    "achoclonar": "a-cho-clo-nar",
    "achocolatada": "a-cho-co-la-ta-da",
    "achocolatado": "a-cho-co-la-ta-do",
    "achogcha": "a-chog-cha",
    "achojcha": "a-choj-cha",
    "acholada": "a-cho-la-da",
    "acholado": "a-cho-la-do",
    "acholar": "a-cho-lar",
    "acholole": "a-cho-lo-le",
    "achololera": "a-cho-lo-le-ra",
    "achorcholar": "a-chor-cho-lar",
    "achote": "a-cho-te",
    "achuar": "a-chuar",
    "achubascar": "a-chu-bas-car",
    "achubascarse": "a-chu-bas-car-se",
    "achuchado": "a-chu-cha-do",
    "achuchar": "a-chu-char",
    "achucharrar": "a-chu-cha-rrar",
    "achuchón": "a-chu-chón",
    "achucuyar": "a-chu-cu-yar",
    "achuela": "a-chue-la",
    "achulada": "a-chu-la-da",
    "achulado": "a-chu-la-do",
    "achulamiento": "a-chu-la-mien-to",
    "achulapadamente": "a-chu-la-pa-da-men-te",
    "achulapado": "a-chu-la-pa-do",
    "achulapar": "a-chu-la-par",
    "achulaparse": "a-chu-la-par-se",
    "achular": "a-chu-lar",
    "achularse": "a-chu-lar-se",
    "achumicar": "a-chu-mi-car",
    "achumpipado": "a-chum-pi-pa-do",
    "achunchar": "a-chun-char",
    "achuntar": "a-chun-tar",
    "achupalla": "a-chu-pa-lla",
    "achura": "a-chu-ra",
    "achurar": "a-chu-rar",
    "achurrascar": "a-chu-rras-car",
    "achusemado": "a-chu-se-ma-do",
    "aciaga": "a-cia-ga",
    "aciago": "a-cia-go",
    "acial": "a-cial",
    "aciano": "a-cia-no",
    "acianos": "a-cia-nos",
    "aciar": "a-ciar",
    "acíbar": "a-cí-bar",
    "acibarar": "a-ci-ba-rar",
    "acibarrar": "a-ci-ba-rrar",
    "aciberar": "a-ci-be-rar",
    "acicalada": "a-ci-ca-la-da",
    "acicalado": "a-ci-ca-la-do",
    "acicalador": "a-ci-ca-la-dor",
    "acicaladora": "a-ci-ca-la-do-ra",
    "acicaladura": "a-ci-ca-la-du-ra",
    "acicalamiento": "a-ci-ca-la-mien-to",
    "acicalar": "a-ci-ca-lar",
    "acicate": "a-ci-ca-te",
    "acicatear": "a-ci-ca-te-ar",
    "aciche": "a-ci-che",
    "acícula": "a-cí-cu-la",
    "acicular": "a-ci-cu-lar",
    "acida": "a-ci-da",
    "ácida": "á-ci-da",
    "acidalia": "a-ci-da-lia",
    "acidalio": "a-ci-da-lio",
    "ácidamente": "á-ci-da-men-te",
    "acidaque": "a-ci-da-que",
    "acidemia": "a-ci-de-mia",
    "acidez": "a-ci-dez",
    "acidia": "a-ci-dia",
    "acidificación": "a-ci-di-fi-ca-ción",
    "acidificar": "a-ci-di-fi-car",
    "acidimetría": "a-ci-di-me-trí-a",
    "acidímetro": "a-ci-dí-me-tro",
    "acidiosa": "a-ci-dio-sa",
    "acidioso": "a-ci-dio-so",
    "ácido": "á-ci-do",
    "acidorresistente": "a-ci-do-rre-sis-ten-te",
    "acidosis": "a-ci-do-sis",
    "acídula": "a-cí-du-la",
    "acidulado": "a-ci-du-la-do",
    "acidulante": "a-ci-du-lan-te",
    "acidular": "a-ci-du-lar",
    "acídulo": "a-cí-du-lo",
    "aciduria": "a-ci-du-ria",
    "aciemar": "a-cie-mar",
    "acientíficamente": "a-cien-tí-fi-ca-men-te",
    "acientífico": "a-cien-tí-fi-co",
    "acierto": "a-cier-to",
    "ácigos": "á-ci-gos",
    "aciguatada": "a-ci-gua-ta-da",
    "aciguatado": "a-ci-gua-ta-do",
    "aciguatar": "a-ci-gua-tar",
    "aciguatarse": "a-ci-gua-tar-se",
    "acijada": "a-ci-ja-da",
    "acijado": "a-ci-ja-do",
    "acije": "a-ci-je",
    "acijosa": "a-ci-jo-sa",
    "acijoso": "a-ci-jo-so",
    "acilo": "a-ci-lo",
    "acimboga": "a-cim-bo-ga",
    "acimentar": "a-ci-men-tar",
    "acimentarse": "a-ci-men-tar-se",
    "ácimo": "á-ci-mo",
    "acimut": "a-ci-mut",
    "acimutal": "a-ci-mu-tal",
    "acinesia": "a-ci-ne-sia",
    "acintado": "a-cin-ta-do",
    "acinturar": "a-cin-tu-rar",
    "ación": "a-ción",
    "acionera": "a-cio-ne-ra",
    "acionero": "a-cio-ne-ro",
    "acipado": "a-ci-pa-do",
    "aciprés": "a-ci-prés",
    "acirate": "a-ci-ra-te",
    "acirón": "a-ci-rón",
    "acitara": "a-ci-ta-ra",
    "acitrón": "a-ci-trón",
    "acivilar": "a-ci-vi-lar",
    "aclamación": "a-cla-ma-ción",
    "aclamador": "a-cla-ma-dor",
    "aclamadora": "a-cla-ma-do-ra",
    "aclamar": "a-cla-mar",
    "aclamatorio": "a-cla-ma-to-rio",
    "aclamídeo": "a-cla-mí-de-o",
    "aclaración": "a-cla-ra-ción",
    "aclarada": "a-cla-ra-da",
    "aclarado": "a-cla-ra-do",
    "aclarador": "a-cla-ra-dor",
    "aclaradora": "a-cla-ra-do-ra",
    "aclaramiento": "a-cla-ra-mien-to",
    "aclarar": "a-cla-rar",
    "aclaratoria": "a-cla-ra-to-ria",
    "aclaratorio": "a-cla-ra-to-rio",
    "aclarecer": "a-cla-re-cer",
    "aclareo": "a-cla-re-o",
    "aclavelada": "a-cla-ve-la-da",
    "aclavelado": "a-cla-ve-la-do",
    "acle": "a-cle",
    "acleida": "a-clei-da",
    "acleido": "a-clei-do",
    "aclimatable": "a-cli-ma-ta-ble",
    "aclimatación": "a-cli-ma-ta-ción",
    "aclimatar": "a-cli-ma-tar",
    "aclla": "ac-lla",
    "aclocar": "a-clo-car",
    "aclorhidria": "a-clo-rhi-dria",
    "aclorhídrica": "a-clo-rhí-dri-ca",
    "aclorhídrico": "a-clo-rhí-dri-co",
    "acmé": "ac-mé",
    "acné": "ac-né",
    "acobambina": "a-co-bam-bi-na",
    "acobambino": "a-co-bam-bi-no",
    "acobardada": "a-co-bar-da-da",
    "acobardado": "a-co-bar-da-do",
    "acobardamiento": "a-co-bar-da-mien-to",
    "acobardar": "a-co-bar-dar",
    "acobijar": "a-co-bi-jar",
    "acobijo": "a-co-bi-jo",
    "acobrada": "a-co-bra-da",
    "acobrado": "a-co-bra-do",
    "acocar": "a-co-car",
    "acocarse": "a-co-car-se",
    "acoceador": "a-co-ce-a-dor",
    "acoceadora": "a-co-ce-a-do-ra",
    "acoceamiento": "a-co-ce-a-mien-to",
    "acocear": "a-co-ce-ar",
    "acochambrar": "a-co-cham-brar",
    "acochar": "a-co-char",
    "acocharse": "a-co-char-se",
    "acochinado": "a-co-chi-na-do",
    "acochinar": "a-co-chi-nar",
    "acocil": "a-co-cil",
    "acoclar": "a-co-clar",
    "acoclarse": "a-co-clar-se",
    "acocotar": "a-co-co-tar",
    "acocote": "a-co-co-te",
    "acodado": "a-co-da-do",
    "acodadura": "a-co-da-du-ra",
    "acodalamiento": "a-co-da-la-mien-to",
    "acodalar": "a-co-da-lar",
    "acodamiento": "a-co-da-mien-to",
    "acodar": "a-co-dar",
    "acoderamiento": "a-co-de-ra-mien-to",
    "acoderar": "a-co-de-rar",
    "acodiciar": "a-co-di-ciar",
    "acodillado": "a-co-di-lla-do",
    "acodillar": "a-co-di-llar",
    "acodo": "a-co-do",
    "acogediza": "a-co-ge-di-za",
    "acogedizo": "a-co-ge-di-zo",
    "acogedor": "a-co-ge-dor",
    "acogedora": "a-co-ge-do-ra",
    "acogedoramente": "a-co-ge-do-ra-men-te",
    "acoger": "a-co-ger",
    "acogeta": "a-co-ge-ta",
    "acogida": "a-co-gi-da",
    "acogido": "a-co-gi-do",
    "acogimiento": "a-co-gi-mien-to",
    "acogollado": "a-co-go-lla-do",
    "acogollar": "a-co-go-llar",
    "acogombradura": "a-co-gom-bra-du-ra",
    "acogombrar": "a-co-gom-brar",
    "acogotamiento": "a-co-go-ta-mien-to",
    "acogotar": "a-co-go-tar",
    "acogullada": "a-co-gu-lla-da",
    "acogullado": "a-co-gu-lla-do",
    "acohombrar": "a-co-hom-brar",
    "acoitar": "a-coi-tar",
    "acojinamiento": "a-co-ji-na-mien-to",
    "acojinar": "a-co-ji-nar",
    "acojonada": "a-co-jo-na-da",
    "acojonado": "a-co-jo-na-do",
    "acojonante": "a-co-jo-nan-te",
    "acojonar": "a-co-jo-nar",
    "acojone": "a-co-jo-ne",
    "acojono": "a-co-jo-no",
    "acolada": "a-co-la-da",
    "acolar": "a-co-lar",
    "acolchado": "a-col-cha-do",
    "acolchamiento": "a-col-cha-mien-to",
    "acolchar": "a-col-char",
    "acolchonar": "a-col-cho-nar",
    "acolgar": "a-col-gar",
    "acolhua": "a-col-hua",
    "acolhuaque": "a-col-hua-que",
    "acolitado": "a-co-li-ta-do",
    "acolitar": "a-co-li-tar",
    "acólito": "a-có-li-to",
    "acollador": "a-co-lla-dor",
    "acollar": "a-co-llar",
    "acollarada": "a-co-lla-ra-da",
    "acollarado": "a-co-lla-ra-do",
    "acollaramiento": "a-co-lla-ra-mien-to",
    "acollarar": "a-co-lla-rar",
    "acolleramiento": "a-co-lle-ra-mien-to",
    "acollonamiento": "a-co-llo-na-mien-to",
    "acollonante": "a-co-llo-nan-te",
    "acollonar": "a-co-llo-nar",
    "acolmillado": "a-col-mi-lla-do",
    "acomayina": "a-co-ma-yi-na",
    "acomayino": "a-co-ma-yi-no",
    "acombar": "a-com-bar",
    "acomedida": "a-co-me-di-da",
    "acomedido": "a-co-me-di-do",
    "acomedir": "a-co-me-dir",
    "acomedirse": "a-co-me-dir-se",
    "acomendar": "a-co-men-dar",
    "acometedor": "a-co-me-te-dor",
    "acometedora": "a-co-me-te-do-ra",
    "acometer": "a-co-me-ter",
    "acometida": "a-co-me-ti-da",
    "acometimiento": "a-co-me-ti-mien-to",
    "acometividad": "a-co-me-ti-vi-dad",
    "acomodable": "a-co-mo-da-ble",
    "acomodación": "a-co-mo-da-ción",
    "acomodada": "a-co-mo-da-da",
    "acomodadamente": "a-co-mo-da-da-men-te",
    "acomodadiza": "a-co-mo-da-di-za",
    "acomodadizo": "a-co-mo-da-di-zo",
    "acomodado": "a-co-mo-da-do",
    "acomodador": "a-co-mo-da-dor",
    "acomodadora": "a-co-mo-da-do-ra",
    "acomodamiento": "a-co-mo-da-mien-to",
    "acomodar": "a-co-mo-dar",
    "acomodaticia": "a-co-mo-da-ti-cia",
    "acomodaticio": "a-co-mo-da-ti-cio",
    "acomodo": "a-co-mo-do",
    "acompañada": "a-com-pa-ña-da",
    "acompañado": "a-com-pa-ña-do",
    "acompañador": "a-com-pa-ña-dor",
    "acompañadora": "a-com-pa-ña-do-ra",
    "acompañamiento": "a-com-pa-ña-mien-to",
    "acompañanta": "a-com-pa-ñan-ta",
    "acompañante": "a-com-pa-ñan-te",
    "acompañar": "a-com-pa-ñar",
    "acompasada": "a-com-pa-sa-da",
    "acompasadamente": "a-com-pa-sa-da-men-te",
    "acompasado": "a-com-pa-sa-do",
    "acompasamiento": "a-com-pa-sa-mien-to",
    "acompasar": "a-com-pa-sar",
    "acomplejada": "a-com-ple-ja-da",
    "acomplejado": "a-com-ple-ja-do",
    "acomplejamiento": "a-com-ple-ja-mien-to",
    "acomplejar": "a-com-ple-jar",
    "acomplexionada": "a-com-ple-xio-na-da",
    "acomplexionado": "a-com-ple-xio-na-do",
    "acomunalar": "a-co-mu-na-lar",
    "acomunar": "a-co-mu-nar",
    "aconcagüina": "a-con-ca-güi-na",
    "aconcagüino": "a-con-ca-güi-no",
    "aconchabar": "a-con-cha-bar",
    "aconchabarse": "a-con-cha-bar-se",
    "aconchadillo": "a-con-cha-di-llo",
    "aconchar": "a-con-char",
    "acondicionada": "a-con-di-cio-na-da",
    "acondicionado": "a-con-di-cio-na-do",
    "acondicionador": "a-con-di-cio-na-dor",
    "acondicionamiento": "a-con-di-cio-na-mien-to",
    "acondicionar": "a-con-di-cio-nar",
    "acondroplasia": "a-con-dro-pla-sia",
    "acondroplásico": "a-con-dro-plá-si-co",
    "aconduchar": "a-con-du-char",
    "aconfesional": "a-con-fe-sio-nal",
    "aconfesionalidad": "a-con-fe-sio-na-li-dad",
    "acongojadamente": "a-con-go-ja-da-men-te",
    "acongojado": "a-con-go-ja-do",
    "acongojador": "a-con-go-ja-dor",
    "acongojadora": "a-con-go-ja-do-ra",
    "acongojante": "a-con-go-jan-te",
    "acongojar": "a-con-go-jar",
    "aconhortar": "a-con-hor-tar",
    "aconitina": "a-co-ni-ti-na",
    "acónito": "a-có-ni-to",
    "aconsejable": "a-con-se-ja-ble",
    "aconsejada": "a-con-se-ja-da",
    "aconsejado": "a-con-se-ja-do",
    "aconsejador": "a-con-se-ja-dor",
    "aconsejadora": "a-con-se-ja-do-ra",
    "aconsejar": "a-con-se-jar",
    "aconsonantar": "a-con-so-nan-tar",
    "aconstitucional": "a-cons-ti-tu-cio-nal",
    "acontar": "a-con-tar",
    "acontecedera": "a-con-te-ce-de-ra",
    "acontecedero": "a-con-te-ce-de-ro",
    "acontecer": "a-con-te-cer",
    "acontecida": "a-con-te-ci-da",
    "acontecido": "a-con-te-ci-do",
    "acontecimiento": "a-con-te-ci-mien-to",
    "acontiada": "a-con-tia-da",
    "acontiado": "a-con-tia-do",
    "acopada": "a-co-pa-da",
    "acopado": "a-co-pa-do",
    "acopar": "a-co-par",
    "acopetada": "a-co-pe-ta-da",
    "acopetado": "a-co-pe-ta-do",
    "acopiador": "a-co-pia-dor",
    "acopiadora": "a-co-pia-do-ra",
    "acopiamiento": "a-co-pia-mien-to",
    "acopiar": "a-co-piar",
    "acopio": "a-co-pio",
    "acoplado": "a-co-pla-do",
    "acoplador": "a-co-pla-dor",
    "acopladura": "a-co-pla-du-ra",
    "acoplamiento": "a-co-pla-mien-to",
    "acoplar": "a-co-plar",
    "acople": "a-co-ple",
    "acoquinamiento": "a-co-qui-na-mien-to",
    "acoquinar": "a-co-qui-nar",
    "acorar": "a-co-rar",
    "acorazada": "a-co-ra-za-da",
    "acorazado": "a-co-ra-za-do",
    "acorazamiento": "a-co-ra-za-mien-to",
    "acorazar": "a-co-ra-zar",
    "acorazonada": "a-co-ra-zo-na-da",
    "acorazonado": "a-co-ra-zo-na-do",
    "acorchada": "a-cor-cha-da",
    "acorchado": "a-cor-cha-do",
    "acorchamiento": "a-cor-cha-mien-to",
    "acorchar": "a-cor-char",
    "acorcharse": "a-cor-char-se",
    "acordación": "a-cor-da-ción",
    "acordada": "a-cor-da-da",
    "acordadamente": "a-cor-da-da-men-te",
    "acordado": "a-cor-da-do",
    "acordamiento": "a-cor-da-mien-to",
    "acordante": "a-cor-dan-te",
    "acordanza": "a-cor-dan-za",
    "acordar": "a-cor-dar",
    "acorde": "a-cor-de",
    "acordelar": "a-cor-de-lar",
    "acordemente": "a-cor-de-men-te",
    "acordeón": "a-cor-de-ón",
    "acordeonista": "a-cor-de-o-nis-ta",
    "acordonada": "a-cor-do-na-da",
    "acordonado": "a-cor-do-na-do",
    "acordonamiento": "a-cor-do-na-mien-to",
    "acordonar": "a-cor-do-nar",
    "acores": "a-co-res",
    "acornada": "a-cor-na-da",
    "acornado": "a-cor-na-do",
    "acornar": "a-cor-nar",
    "acorneador": "a-cor-ne-a-dor",
    "acorneadora": "a-cor-ne-a-do-ra",
    "acornear": "a-cor-ne-ar",
    "ácoro": "á-co-ro",
    "acorralamiento": "a-co-rra-la-mien-to",
    "acorralar": "a-co-rra-lar",
    "acorredor": "a-co-rre-dor",
    "acorredora": "a-co-rre-do-ra",
    "acorrer": "a-co-rrer",
    "acorrimiento": "a-co-rri-mien-to",
    "acorro": "a-co-rro",
    "acorrucar": "a-co-rru-car",
    "acorrucarse": "a-co-rru-car-se",
    "acortamiento": "a-cor-ta-mien-to",
    "acortar": "a-cor-tar",
    "acortejar": "a-cor-te-jar",
    "acorullar": "a-co-ru-llar",
    "acorvar": "a-cor-var",
    "acorzar": "a-cor-zar",
    "acosador": "a-co-sa-dor",
    "acosadora": "a-co-sa-do-ra",
    "acosamiento": "a-co-sa-mien-to",
    "acosar": "a-co-sar",
    "acose": "a-co-se",
    "acosijar": "a-co-si-jar",
    "acosil": "a-co-sil",
    "acosmismo": "a-cos-mis-mo",
    "acoso": "a-co-so",
    "acostada": "a-cos-ta-da",
    "acostado": "a-cos-ta-do",
    "acostadote": "a-cos-ta-do-te",
    "acostamiento": "a-cos-ta-mien-to",
    "acostar": "a-cos-tar",
    "acostumbrado": "a-cos-tum-bra-do",
    "acostumbrar": "a-cos-tum-brar",
    "acotación": "a-co-ta-ción",
    "acotada": "a-co-ta-da",
    "acotamiento": "a-co-ta-mien-to",
    "acotar": "a-co-tar",
    "acotejar": "a-co-te-jar",
    "acotejo": "a-co-te-jo",
    "acotiledón": "a-co-ti-le-dón",
    "acotiledónea": "a-co-ti-le-dó-ne-a",
    "acotiledóneo": "a-co-ti-le-dó-ne-o",
    "acotillo": "a-co-ti-llo",
    "acotolar": "a-co-to-lar",
    "acototar": "a-co-to-tar",
    "acoyundar": "a-co-yun-dar",
    "acoyuntar": "a-co-yun-tar",
    "acoyuntero": "a-co-yun-te-ro",
    "acracia": "a-cra-cia",
    "ácrata": "á-cra-ta",
    "acrática": "a-crá-ti-ca",
    "acrático": "a-crá-ti-co",
    "acre": "a-cre",
    "acrebite": "a-cre-bi-te",
    "acrecencia": "a-cre-cen-cia",
    "acrecentador": "a-cre-cen-ta-dor",
    "acrecentadora": "a-cre-cen-ta-do-ra",
    "acrecentamiento": "a-cre-cen-ta-mien-to",
    "acrecentar": "a-cre-cen-tar",
    "acrecer": "a-cre-cer",
    "acrecimiento": "a-cre-ci-mien-to",
    "acreción": "a-cre-ción",
    "acreditación": "a-cre-di-ta-ción",
    "acreditada": "a-cre-di-ta-da",
    "acreditado": "a-cre-di-ta-do",
    "acreditar": "a-cre-di-tar",
    "acreditativa": "a-cre-di-ta-ti-va",
    "acreditativo": "a-cre-di-ta-ti-vo",
    "acreedor": "a-cre-e-dor",
    "acreedora": "a-cre-e-do-ra",
    "acreencia": "a-cre-en-cia",
    "acreer": "a-cre-er",
    "acremente": "a-cre-men-te",
    "acrescente": "a-cres-cen-te",
    "acrianzar": "a-crian-zar",
    "acribador": "a-cri-ba-dor",
    "acribadora": "a-cri-ba-do-ra",
    "acribadura": "a-cri-ba-du-ra",
    "acribar": "a-cri-bar",
    "acribia": "a-cri-bia",
    "acribillar": "a-cri-bi-llar",
    "acrídido": "a-crí-di-do",
    "acrilato": "a-cri-la-to",
    "acrílico": "a-crí-li-co",
    "acriminación": "a-cri-mi-na-ción",
    "acriminador": "a-cri-mi-na-dor",
    "acriminadora": "a-cri-mi-na-do-ra",
    "acriminar": "a-cri-mi-nar",
    "acrimonia": "a-cri-mo-nia",
    "acriollada": "a-crio-lla-da",
    "acriollado": "a-crio-lla-do",
    "acriollar": "a-crio-llar",
    "acriollarse": "a-crio-llar-se",
    "acrisoladamente": "a-cri-so-la-da-men-te",
    "acrisolado": "a-cri-so-la-do",
    "acrisolador": "a-cri-so-la-dor",
    "acrisoladora": "a-cri-so-la-do-ra",
    "acrisolar": "a-cri-so-lar",
    "acristalado": "a-cris-ta-la-do",
    "acristalamiento": "a-cris-ta-la-mien-to",
    "acristalar": "a-cris-ta-lar",
    "acristianada": "a-cris-tia-na-da",
    "acristianado": "a-cris-tia-na-do",
    "acristianar": "a-cris-tia-nar",
    "acritud": "a-cri-tud",
    "acroamática": "a-cro-a-má-ti-ca",
    "acroamático": "a-cro-a-má-ti-co",
    "acrobacia": "a-cro-ba-cia",
    "acróbata": "a-cró-ba-ta",
    "acrobática": "a-cro-bá-ti-ca",
    "acrobáticamente": "a-cro-bá-ti-ca-men-te",
    "acrobático": "a-cro-bá-ti-co",
    "acrobatismo": "a-cro-ba-tis-mo",
    "acrocefalia": "a-cro-ce-fa-lia",
    "acroe": "a-cro-e",
    "acrofobia": "a-cro-fo-bia",
    "acroleína": "a-cro-le-í-na",
    "acromada": "a-cro-ma-da",
    "acromado": "a-cro-ma-do",
    "acromática": "a-cro-má-ti-ca",
    "acromático": "a-cro-má-ti-co",
    "acromatismo": "a-cro-ma-tis-mo",
    "acromatizar": "a-cro-ma-ti-zar",
    "acromatopsia": "a-cro-ma-top-sia",
    "acromegalia": "a-cro-me-ga-lia",
    "acromegálica": "a-cro-me-gá-li-ca",
    "acromegálico": "a-cro-me-gá-li-co",
    "acromial": "a-cro-mial",
    "acromiana": "a-cro-mia-na",
    "acromiano": "a-cro-mia-no",
    "acromio": "a-cro-mio",
    "acromion": "a-cro-mion",
    "acrónica": "a-cró-ni-ca",
    "acrónico": "a-cró-ni-co",
    "acronimia": "a-cro-ni-mia",
    "acrónimo": "a-cró-ni-mo",
    "ácrono": "á-cro-no",
    "acrópolis": "a-cró-po-lis",
    "acróstica": "a-crós-ti-ca",
    "acróstico": "a-crós-ti-co",
    "acrostolio": "a-cros-to-lio",
    "acrotera": "a-cro-te-ra",
    "acroteria": "a-cro-te-ria",
    "acroterio": "a-cro-te-rio",
    "acroy": "a-croy",
    "acta": "ac-ta",
    "actante": "ac-tan-te",
    "actea": "ac-te-a",
    "actinia": "ac-ti-nia",
    "actínica": "ac-tí-ni-ca",
    "actínico": "ac-tí-ni-co",
    "actínido": "ac-tí-ni-do",
    "actinio": "ac-ti-nio",
    "actinismo": "ac-ti-nis-mo",
    "actinógrafo": "ac-ti-nó-gra-fo",
    "actinología": "ac-ti-no-lo-gí-a",
    "actinometría": "ac-ti-no-me-trí-a",
    "actinométrica": "ac-ti-no-mé-tri-ca",
    "actinométrico": "ac-ti-no-mé-tri-co",
    "actinómetro": "ac-ti-nó-me-tro",
    "actinomices": "ac-ti-no-mi-ces",
    "actinomicosis": "ac-ti-no-mi-co-sis",
    "actinomorfa": "ac-ti-no-mor-fa",
    "actinomorfo": "ac-ti-no-mor-fo",
    "actinopterigio": "ac-ti-nop-te-ri-gio",
    "actinota": "ac-ti-no-ta",
    "actitud": "ac-ti-tud",
    "actitudinal": "ac-ti-tu-di-nal",
    "activa": "ac-ti-va",
    "activación": "ac-ti-va-ción",
    "activador": "ac-ti-va-dor",
    "activadora": "ac-ti-va-do-ra",
    "activamente": "ac-ti-va-men-te",
    "activar": "ac-ti-var",
    "actividad": "ac-ti-vi-dad",
    "activismo": "ac-ti-vis-mo",
    "activista": "ac-ti-vis-ta",
    "activo": "ac-ti-vo",
    "acto": "ac-to",
    "actor": "ac-tor",
    "actora": "ac-to-ra",
    "actoral": "ac-to-ral",
    "actriz": "ac-triz",
    "actuación": "ac-tua-ción",
    "actuada": "ac-tua-da",
    "actuado": "ac-tua-do",
    "actual": "ac-tual",
    "actualidad": "ac-tua-li-dad",
    "actualización": "ac-tua-li-za-ción",
    "actualizador": "ac-tua-li-za-dor",
    "actualizadora": "ac-tua-li-za-do-ra",
    "actualizar": "ac-tua-li-zar",
    "actualmente": "ac-tual-men-te",
    "actuante": "ac-tuan-te",
    "actuar": "ac-tuar",
    "actuaria": "ac-tua-ria",
    "actuarial": "ac-tua-rial",
    "actuario": "ac-tua-rio",
    "actuosa": "ac-tuo-sa",
    "actuosidad": "ac-tuo-si-dad",
    "actuoso": "ac-tuo-so",
    "acuache": "a-cua-che",
    "acuadrillar": "a-cua-dri-llar",
    "acuantiar": "a-cuan-tiar",
    "acuarela": "a-cua-re-la",
    "acuarelado": "a-cua-re-la-do",
    "acuarelista": "a-cua-re-lis-ta",
    "acuarelística": "a-cua-re-lís-ti-ca",
    "acuarelístico": "a-cua-re-lís-ti-co",
    "acuariana": "a-cua-ria-na",
    "acuariano": "a-cua-ria-no",
    "acuario": "a-cua-rio",
    "acuartar": "a-cuar-tar",
    "acuartelado": "a-cuar-te-la-do",
    "acuartelamiento": "a-cuar-te-la-mien-to",
    "acuartelar": "a-cuar-te-lar",
    "acuartillar": "a-cuar-ti-llar",
    "acuática": "a-cuá-ti-ca",
    "acuático": "a-cuá-ti-co",
    "acuátil": "a-cuá-til",
    "acuatizaje": "a-cua-ti-za-je",
    "acuatizar": "a-cua-ti-zar",
    "acubada": "a-cu-ba-da",
    "acubado": "a-cu-ba-do",
    "acubilar": "a-cu-bi-lar",
    "acucharada": "a-cu-cha-ra-da",
    "acucharado": "a-cu-cha-ra-do",
    "acuchillada": "a-cu-chi-lla-da",
    "acuchilladizo": "a-cu-chi-lla-di-zo",
    "acuchillado": "a-cu-chi-lla-do",
    "acuchillador": "a-cu-chi-lla-dor",
    "acuchilladora": "a-cu-chi-lla-do-ra",
    "acuchillamiento": "a-cu-chi-lla-mien-to",
    "acuchillar": "a-cu-chi-llar",
    "acucia": "a-cu-cia",
    "acuciadamente": "a-cu-cia-da-men-te",
    "acuciador": "a-cu-cia-dor",
    "acuciadora": "a-cu-cia-do-ra",
    "acuciamiento": "a-cu-cia-mien-to",
    "acuciante": "a-cu-cian-te",
    "acuciantemente": "a-cu-cian-te-men-te",
    "acuciar": "a-cu-ciar",
    "acuciosa": "a-cu-cio-sa",
    "acuciosamente": "a-cu-cio-sa-men-te",
    "acuciosidad": "a-cu-cio-si-dad",
    "acucioso": "a-cu-cio-so",
    "acuclillar": "a-cu-cli-llar",
    "acuclillarse": "a-cu-cli-llar-se",
    "acudiciar": "a-cu-di-ciar",
    "acudiente": "a-cu-dien-te",
    "acudimiento": "a-cu-di-mien-to",
    "acudir": "a-cu-dir",
    "ácuea": "á-cue-a",
    "acueducto": "a-cue-duc-to",
    "ácueo": "á-cue-o",
    "acuerdo": "a-cuer-do",
    "acuerpar": "a-cuer-par",
    "acuesto": "a-cues-to",
    "acuícola": "a-cuí-co-la",
    "acuicultivo": "a-cui-cul-ti-vo",
    "acuicultura": "a-cui-cul-tu-ra",
    "acuidad": "a-cui-dad",
    "acuífero": "a-cuí-fe-ro",
    "acuitadamente": "a-cui-ta-da-men-te",
    "acuitamiento": "a-cui-ta-mien-to",
    "acuitar": "a-cui-tar",
    "ácula": "á-cu-la",
    "aculada": "a-cu-la-da",
    "aculado": "a-cu-la-do",
    "acular": "a-cu-lar",
    "aculatar": "a-cu-la-tar",
    "aculebrinada": "a-cu-le-bri-na-da",
    "aculebrinado": "a-cu-le-bri-na-do",
    "acúleo": "a-cú-le-o",
    "aculillar": "a-cu-li-llar",
    "acullá": "a-cu-llá",
    "acullicar": "a-cu-lli-car",
    "acullico": "a-cu-lli-co",
    "aculturación": "a-cul-tu-ra-ción",
    "acultural": "a-cul-tu-ral",
    "aculturar": "a-cul-tu-rar",
    "acumen": "a-cu-men",
    "acuminada": "a-cu-mi-na-da",
    "acuminado": "a-cu-mi-na-do",
    "acumíneo": "a-cu-mí-ne-o",
    "acuminosa": "a-cu-mi-no-sa",
    "acuminoso": "a-cu-mi-no-so",
    "acumulable": "a-cu-mu-la-ble",
    "acumulación": "a-cu-mu-la-ción",
    "acumulado": "a-cu-mu-la-do",
    "acumulador": "a-cu-mu-la-dor",
    "acumuladora": "a-cu-mu-la-do-ra",
    "acumulamiento": "a-cu-mu-la-mien-to",
    "acumular": "a-cu-mu-lar",
    "acumulativa": "a-cu-mu-la-ti-va",
    "acumulativamente": "a-cu-mu-la-ti-va-men-te",
    "acumulativo": "a-cu-mu-la-ti-vo",
    "acúmulo": "a-cú-mu-lo",
    "acuñación": "a-cu-ña-ción",
    "acuñador": "a-cu-ña-dor",
    "acuñadora": "a-cu-ña-do-ra",
    "acunar": "a-cu-nar",
    "acuñar": "a-cu-ñar",
    "acundangar": "a-cun-dan-gar",
    "acuntir": "a-cun-tir",
    "acuosa": "a-cuo-sa",
    "acuosidad": "a-cuo-si-dad",
    "acuoso": "a-cuo-so",
    "acupe": "a-cu-pe",
    "acupuntor": "a-cu-pun-tor",
    "acupuntora": "a-cu-pun-to-ra",
    "acupuntura": "a-cu-pun-tu-ra",
    "acupunturista": "a-cu-pun-tu-ris-ta",
    "acurada": "a-cu-ra-da",
    "acuradamente": "a-cu-ra-da-men-te",
    "acurado": "a-cu-ra-do",
    "acurdar": "a-cur-dar",
    "acure": "a-cu-re",
    "acurrucar": "a-cu-rru-car",
    "acurrucarse": "a-cu-rru-car-se",
    "acurrullar": "a-cu-rru-llar",
    "acusable": "a-cu-sa-ble",
    "acusación": "a-cu-sa-ción",
    "acusada": "a-cu-sa-da",
    "acusadamente": "a-cu-sa-da-men-te",
    "acusado": "a-cu-sa-do",
    "acusador": "a-cu-sa-dor",
    "acusadora": "a-cu-sa-do-ra",
    "acusar": "a-cu-sar",
    "acusativo": "a-cu-sa-ti-vo",
    "acusatoria": "a-cu-sa-to-ria",
    "acusatoriamente": "a-cu-sa-to-ria-men-te",
    "acusatorio": "a-cu-sa-to-rio",
    "acuse": "a-cu-se",
    "acuseta": "a-cu-se-ta",
    "acusetas": "a-cu-se-tas",
    "acusete": "a-cu-se-te",
    "acusica": "a-cu-si-ca",
    "acusique": "a-cu-si-que",
    "acusón": "a-cu-són",
    "acusona": "a-cu-so-na",
    "acústica": "a-cús-ti-ca",
    "acústico": "a-cús-ti-co",
    "acuta": "a-cu-ta",
    "acutángulo": "a-cu-tán-gu-lo",
    "acutí": "a-cu-tí",
    "acuto": "a-cu-to",
    "acuyo": "a-cu-yo",
    "adacilla": "a-da-ci-lla",
    "adafina": "a-da-fi-na",
    "adagial": "a-da-gial",
    "adagio": "a-da-gio",
    "adaguar": "a-da-guar",
    "adahala": "a-da-ha-la",
    "adala": "a-da-la",
    "adalid": "a-da-lid",
    "adamada": "a-da-ma-da",
    "adamadamente": "a-da-ma-da-men-te",
    "adamado": "a-da-ma-do",
    "adamadura": "a-da-ma-du-ra",
    "adamamiento": "a-da-ma-mien-to",
    "adamante": "a-da-man-te",
    "adamantina": "a-da-man-ti-na",
    "adamantino": "a-da-man-ti-no",
    "adamar": "a-da-mar",
    "adamarse": "a-da-mar-se",
    "adamascada": "a-da-mas-ca-da",
    "adamascado": "a-da-mas-ca-do",
    "adamascar": "a-da-mas-car",
    "adámico": "a-dá-mi-co",
    "adamismo": "a-da-mis-mo",
    "adamita": "a-da-mi-ta",
    "adamsita": "a-dam-si-ta",
    "adán": "a-dán",
    "adánico": "a-dá-ni-co",
    "adanida": "a-da-ni-da",
    "adanismo": "a-da-nis-mo",
    "adaptabilidad": "a-dap-ta-bi-li-dad",
    "adaptable": "a-dap-ta-ble",
    "adaptación": "a-dap-ta-ción",
    "adaptadamente": "a-dap-ta-da-men-te",
    "adaptador": "a-dap-ta-dor",
    "adaptadora": "a-dap-ta-do-ra",
    "adaptar": "a-dap-tar",
    "adaptativo": "a-dap-ta-ti-vo",
    "adáraga": "a-dá-ra-ga",
    "adaraja": "a-da-ra-ja",
    "adárame": "a-dá-ra-me",
    "adarce": "a-dar-ce",
    "adardear": "a-dar-de-ar",
    "adarga": "a-dar-ga",
    "adárgama": "a-dár-ga-ma",
    "adargar": "a-dar-gar",
    "adarguero": "a-dar-gue-ro",
    "adarme": "a-dar-me",
    "adarvar": "a-dar-var",
    "adarve": "a-dar-ve",
    "adaza": "a-da-za",
    "addenda": "ad-den-da",
    "adecenamiento": "a-de-ce-na-mien-to",
    "adecenar": "a-de-ce-nar",
    "adecentamiento": "a-de-cen-ta-mien-to",
    "adecentar": "a-de-cen-tar",
    "adecuación": "a-de-cua-ción",
    "adecuada": "a-de-cua-da",
    "adecuadamente": "a-de-cua-da-men-te",
    "adecuado": "a-de-cua-do",
    "adecuar": "a-de-cuar",
    "adefera": "a-de-fe-ra",
    "adefesio": "a-de-fe-sio",
    "adefina": "a-de-fi-na",
    "adefuera": "a-de-fue-ra",
    "adehala": "a-de-ha-la",
    "adehesamiento": "a-de-he-sa-mien-to",
    "adehesar": "a-de-he-sar",
    "adelantada": "a-de-lan-ta-da",
    "adelantadamente": "a-de-lan-ta-da-men-te",
    "adelantado": "a-de-lan-ta-do",
    "adelantador": "a-de-lan-ta-dor",
    "adelantadora": "a-de-lan-ta-do-ra",
    "adelantamiento": "a-de-lan-ta-mien-to",
    "adelantar": "a-de-lan-tar",
    "adelante": "a-de-lan-te",
    "adelanto": "a-de-lan-to",
    "adelfa": "a-del-fa",
    "adelfal": "a-del-fal",
    "adélfica": "a-dél-fi-ca",
    "adélfico": "a-dél-fi-co",
    "adelfilla": "a-del-fi-lla",
    "adelfo": "a-del-fo",
    "adelgazador": "a-del-ga-za-dor",
    "adelgazadora": "a-del-ga-za-do-ra",
    "adelgazamiento": "a-del-ga-za-mien-to",
    "adelgazante": "a-del-ga-zan-te",
    "adelgazar": "a-del-ga-zar",
    "adeliñar": "a-de-li-ñar",
    "adeliño": "a-de-li-ño",
    "adelita": "a-de-li-ta",
    "adema": "a-de-ma",
    "ademador": "a-de-ma-dor",
    "ademán": "a-de-mán",
    "ademar": "a-de-mar",
    "además": "a-de-más",
    "ademe": "a-de-me",
    "adempribio": "a-dem-pri-bio",
    "ademprío": "a-dem-prí-o",
    "ademprio": "a-dem-prio",
    "adenda": "a-den-da",
    "adenia": "a-de-nia",
    "adenina": "a-de-ni-na",
    "adenitis": "a-de-ni-tis",
    "adenoide": "a-de-noi-de",
    "adenoidea": "a-de-noi-de-a",
    "adenoideo": "a-de-noi-de-o",
    "adenoides": "a-de-noi-des",
    "adenología": "a-de-no-lo-gí-a",
    "adenoma": "a-de-no-ma",
    "adenopatía": "a-de-no-pa-tí-a",
    "adenopático": "a-de-no-pá-ti-co",
    "adenosa": "a-de-no-sa",
    "adenoso": "a-de-no-so",
    "adenovirus": "a-de-no-vi-rus",
    "adensar": "a-den-sar",
    "adentellar": "a-den-te-llar",
    "adentramiento": "a-den-tra-mien-to",
    "adentrar": "a-den-trar",
    "adentrarse": "a-den-trar-se",
    "adentro": "a-den-tro",
    "adepta": "a-dep-ta",
    "adepto": "a-dep-to",
    "aderezada": "a-de-re-za-da",
    "aderezado": "a-de-re-za-do",
    "aderezamiento": "a-de-re-za-mien-to",
    "aderezar": "a-de-re-zar",
    "aderezo": "a-de-re-zo",
    "aderra": "a-de-rra",
    "aderredor": "a-de-rre-dor",
    "adestrada": "a-des-tra-da",
    "adestrado": "a-des-tra-do",
    "adestrador": "a-des-tra-dor",
    "adestradora": "a-des-tra-do-ra",
    "adestramiento": "a-des-tra-mien-to",
    "adestrar": "a-des-trar",
    "adestría": "a-des-trí-a",
    "adeudar": "a-deu-dar",
    "adeudo": "a-deu-do",
    "adherecer": "a-dhe-re-cer",
    "adherencia": "a-dhe-ren-cia",
    "adherente": "a-dhe-ren-te",
    "adherir": "a-dhe-rir",
    "adhesión": "a-dhe-sión",
    "adhesiva": "a-dhe-si-va",
    "adhesividad": "a-dhe-si-vi-dad",
    "adhesivo": "a-dhe-si-vo",
    "adhortar": "a-dhor-tar",
    "adiabático": "a-dia-bá-ti-co",
    "adiado": "a-dia-do",
    "adiafa": "a-dia-fa",
    "adiáfora": "a-diá-fo-ra",
    "adiaforesis": "a-dia-fo-re-sis",
    "adiamantada": "a-dia-man-ta-da",
    "adiamantado": "a-dia-man-ta-do",
    "adiamiento": "a-dia-mien-to",
    "adiana": "a-dia-na",
    "adiano": "a-dia-no",
    "adiar": "a-diar",
    "adicción": "a-dic-ción",
    "adición": "a-di-ción",
    "adicionador": "a-di-cio-na-dor",
    "adicionadora": "a-di-cio-na-do-ra",
    "adicional": "a-di-cio-nal",
    "adicionalmente": "a-di-cio-nal-men-te",
    "adicionar": "a-di-cio-nar",
    "adicta": "a-dic-ta",
    "adictivo": "a-dic-ti-vo",
    "adicto": "a-dic-to",
    "adieso": "a-die-so",
    "adiestrada": "a-dies-tra-da",
    "adiestrado": "a-dies-tra-do",
    "adiestrador": "a-dies-tra-dor",
    "adiestradora": "a-dies-tra-do-ra",
    "adiestramiento": "a-dies-tra-mien-to",
    "adiestrar": "a-dies-trar",
    "adietar": "a-die-tar",
    "adimensional": "a-di-men-sio-nal",
    "adinamia": "a-di-na-mia",
    "adinámica": "a-di-ná-mi-ca",
    "adinámico": "a-di-ná-mi-co",
    "adinerada": "a-di-ne-ra-da",
    "adinerado": "a-di-ne-ra-do",
    "adinerar": "a-di-ne-rar",
    "adintelado": "a-din-te-la-do",
    "adiós": "a-diós",
    "adipocira": "a-di-po-ci-ra",
    "adiposa": "a-di-po-sa",
    "adiposidad": "a-di-po-si-dad",
    "adiposis": "a-di-po-sis",
    "adiposo": "a-di-po-so",
    "adipsia": "a-dip-sia",
    "adir": "a-dir",
    "aditamento": "a-di-ta-men-to",
    "aditicia": "a-di-ti-cia",
    "aditicio": "a-di-ti-cio",
    "aditivo": "a-di-ti-vo",
    "adiva": "a-di-va",
    "adivas": "a-di-vas",
    "adive": "a-di-ve",
    "adivina": "a-di-vi-na",
    "adivinable": "a-di-vi-na-ble",
    "adivinación": "a-di-vi-na-ción",
    "adivinador": "a-di-vi-na-dor",
    "adivinadora": "a-di-vi-na-do-ra",
    "adivinaja": "a-di-vi-na-ja",
    "adivinamiento": "a-di-vi-na-mien-to",
    "adivinanza": "a-di-vi-nan-za",
    "adivinar": "a-di-vi-nar",
    "adivinatoria": "a-di-vi-na-to-ria",
    "adivinatorio": "a-di-vi-na-to-rio",
    "adivino": "a-di-vi-no",
    "adjetiva": "ad-je-ti-va",
    "adjetivación": "ad-je-ti-va-ción",
    "adjetivador": "ad-je-ti-va-dor",
    "adjetival": "ad-je-ti-val",
    "adjetivamente": "ad-je-ti-va-men-te",
    "adjetivar": "ad-je-ti-var",
    "adjetivo": "ad-je-ti-vo",
    "adjudicación": "ad-ju-di-ca-ción",
    "adjudicador": "ad-ju-di-ca-dor",
    "adjudicadora": "ad-ju-di-ca-do-ra",
    "adjudicar": "ad-ju-di-car",
    "adjudicataria": "ad-ju-di-ca-ta-ria",
    "adjudicatario": "ad-ju-di-ca-ta-rio",
    "adjunción": "ad-jun-ción",
    "adjunta": "ad-jun-ta",
    "adjuntar": "ad-jun-tar",
    "adjuntía": "ad-jun-tí-a",
    "adjunto": "ad-jun-to",
    "adjurable": "ad-ju-ra-ble",
    "adjuración": "ad-ju-ra-ción",
    "adjurado": "ad-ju-ra-do",
    "adjurador": "ad-ju-ra-dor",
    "adjurar": "ad-ju-rar",
    "adjutor": "ad-ju-tor",
    "adjutora": "ad-ju-to-ra",
    "adjutorio": "ad-ju-to-rio",
    "adlátere": "ad-lá-te-re",
    "adlativo": "ad-la-ti-vo",
    "adminicular": "ad-mi-ni-cu-lar",
    "adminículo": "ad-mi-ní-cu-lo",
    "administración": "ad-mi-nis-tra-ción",
    "administrada": "ad-mi-nis-tra-da",
    "administrado": "ad-mi-nis-tra-do",
    "administrador": "ad-mi-nis-tra-dor",
    "administradora": "ad-mi-nis-tra-do-ra",
    "administrar": "ad-mi-nis-trar",
    "administrativa": "ad-mi-nis-tra-ti-va",
    "administrativamente": "ad-mi-nis-tra-ti-va-men-te",
    "administrativista": "ad-mi-nis-tra-ti-vis-ta",
    "administrativo": "ad-mi-nis-tra-ti-vo",
    "administratoria": "ad-mi-nis-tra-to-ria",
    "administratorio": "ad-mi-nis-tra-to-rio",
    "admirable": "ad-mi-ra-ble",
    "admirablemente": "ad-mi-ra-ble-men-te",
    "admiración": "ad-mi-ra-ción",
    "admirador": "ad-mi-ra-dor",
    "admiradora": "ad-mi-ra-do-ra",
    "admirar": "ad-mi-rar",
    "admirativa": "ad-mi-ra-ti-va",
    "admirativamente": "ad-mi-ra-ti-va-men-te",
    "admirativo": "ad-mi-ra-ti-vo",
    "admisibilidad": "ad-mi-si-bi-li-dad",
    "admisible": "ad-mi-si-ble",
    "admisiblemente": "ad-mi-si-ble-men-te",
    "admisión": "ad-mi-sión",
    "admitancia": "ad-mi-tan-cia",
    "admitencia": "ad-mi-ten-cia",
    "admitir": "ad-mi-tir",
    "admixtión": "ad-mix-tión",
    "admonición": "ad-mo-ni-ción",
    "admonitor": "ad-mo-ni-tor",
    "admonitoriamente": "ad-mo-ni-to-ria-men-te",
    "admonitorio": "ad-mo-ni-to-rio",
    "adnada": "ad-na-da",
    "adnado": "ad-na-do",
    "adnata": "ad-na-ta",
    "adnato": "ad-na-to",
    "adnominal": "ad-no-mi-nal",
    "adoba": "a-do-ba",
    "adobado": "a-do-ba-do",
    "adobador": "a-do-ba-dor",
    "adobadora": "a-do-ba-do-ra",
    "adobar": "a-do-bar",
    "adobasillas": "a-do-ba-si-llas",
    "adobe": "a-do-be",
    "adobera": "a-do-be-ra",
    "adobería": "a-do-be-rí-a",
    "adobío": "a-do-bí-o",
    "adobo": "a-do-bo",
    "adobón": "a-do-bón",
    "adocenada": "a-do-ce-na-da",
    "adocenado": "a-do-ce-na-do",
    "adocenamiento": "a-do-ce-na-mien-to",
    "adocenar": "a-do-ce-nar",
    "adocilar": "a-do-ci-lar",
    "adoctrinador": "a-doc-tri-na-dor",
    "adoctrinamiento": "a-doc-tri-na-mien-to",
    "adoctrinar": "a-doc-tri-nar",
    "adolecer": "a-do-le-cer",
    "adoleciente": "a-do-le-cien-te",
    "adolescencia": "a-do-les-cen-cia",
    "adolescente": "a-do-les-cen-te",
    "adolorada": "a-do-lo-ra-da",
    "adolorado": "a-do-lo-ra-do",
    "adolorar": "a-do-lo-rar",
    "adolorida": "a-do-lo-ri-da",
    "adolorido": "a-do-lo-ri-do",
    "adonada": "a-do-na-da",
    "adonado": "a-do-na-do",
    "adonaí": "a-do-na-í",
    "adonar": "a-do-nar",
    "adonarse": "a-do-nar-se",
    "adonay": "a-do-nay",
    "adonde": "a-don-de",
    "adónde": "a-dón-de",
    "adondequiera": "a-don-de-quie-ra",
    "adonecer": "a-do-ne-cer",
    "adónico": "a-dó-ni-co",
    "adonio": "a-do-nio",
    "adonis": "a-do-nis",
    "adonizar": "a-do-ni-zar",
    "adonizarse": "a-do-ni-zar-se",
    "adopción": "a-dop-ción",
    "adopcionismo": "a-dop-cio-nis-mo",
    "adopcionista": "a-dop-cio-nis-ta",
    "adoptable": "a-dop-ta-ble",
    "adoptación": "a-dop-ta-ción",
    "adoptador": "a-dop-ta-dor",
    "adoptadora": "a-dop-ta-do-ra",
    "adoptando": "a-dop-tan-do",
    "adoptante": "a-dop-tan-te",
    "adoptar": "a-dop-tar",
    "adoptiva": "a-dop-ti-va",
    "adoptivo": "a-dop-ti-vo",
    "adoquier": "a-do-quier",
    "adoquiera": "a-do-quie-ra",
    "adoquín": "a-do-quín",
    "adoquinado": "a-do-qui-na-do",
    "adoquinador": "a-do-qui-na-dor",
    "adoquinar": "a-do-qui-nar",
    "ador": "a-dor",
    "adorable": "a-do-ra-ble",
    "adoración": "a-do-ra-ción",
    "adorador": "a-do-ra-dor",
    "adoradora": "a-do-ra-do-ra",
    "adorante": "a-do-ran-te",
    "adorar": "a-do-rar",
    "adoratorio": "a-do-ra-to-rio",
    "adoratriz": "a-do-ra-triz",
    "adormecedor": "a-dor-me-ce-dor",
    "adormecedora": "a-dor-me-ce-do-ra",
    "adormecer": "a-dor-me-cer",
    "adormecimiento": "a-dor-me-ci-mien-to",
    "adormentar": "a-dor-men-tar",
    "adormidera": "a-dor-mi-de-ra",
    "adormilamiento": "a-dor-mi-la-mien-to",
    "adormilar": "a-dor-mi-lar",
    "adormilarse": "a-dor-mi-lar-se",
    "adormimiento": "a-dor-mi-mien-to",
    "adormir": "a-dor-mir",
    "adormitar": "a-dor-mi-tar",
    "adormitarse": "a-dor-mi-tar-se",
    "adornador": "a-dor-na-dor",
    "adornadora": "a-dor-na-do-ra",
    "adornamiento": "a-dor-na-mien-to",
    "adornar": "a-dor-nar",
    "adornista": "a-dor-nis-ta",
    "adorno": "a-dor-no",
    "adoro": "a-do-ro",
    "adosada": "a-do-sa-da",
    "adosado": "a-do-sa-do",
    "adosamiento": "a-do-sa-mien-to",
    "adosar": "a-do-sar",
    "adotrinar": "a-do-tri-nar",
    "adovelada": "a-do-ve-la-da",
    "adovelado": "a-do-ve-la-do",
    "adquirente": "ad-qui-ren-te",
    "adquirible": "ad-qui-ri-ble",
    "adquirido": "ad-qui-ri-do",
    "adquiridor": "ad-qui-ri-dor",
    "adquiridora": "ad-qui-ri-do-ra",
    "adquiriente": "ad-qui-rien-te",
    "adquirir": "ad-qui-rir",
    "adquisición": "ad-qui-si-ción",
    "adquisidor": "ad-qui-si-dor",
    "adquisidora": "ad-qui-si-do-ra",
    "adquisitiva": "ad-qui-si-ti-va",
    "adquisitivo": "ad-qui-si-ti-vo",
    "adra": "a-dra",
    "adrada": "a-dra-da",
    "adrado": "a-dra-do",
    "adragante": "a-dra-gan-te",
    "adraganto": "a-dra-gan-to",
    "adral": "a-dral",
    "adrar": "a-drar",
    "adrede": "a-dre-de",
    "adredemente": "a-dre-de-men-te",
    "adredista": "a-dre-dis-ta",
    "adrenal": "a-dre-nal",
    "adrenalina": "a-dre-na-li-na",
    "adrenérgico": "a-dre-nér-gi-co",
    "adrezar": "a-dre-zar",
    "adrezo": "a-dre-zo",
    "adrián": "a-drián",
    "adriática": "a-driá-ti-ca",
    "adriático": "a-driá-ti-co",
    "adrizamiento": "a-dri-za-mien-to",
    "adrizar": "a-dri-zar",
    "adrolla": "a-dro-lla",
    "adrollero": "a-dro-lle-ro",
    "adscribible": "ads-cri-bi-ble",
    "adscribir": "ads-cri-bir",
    "adscripción": "ads-crip-ción",
    "adscripta": "ads-crip-ta",
    "adscripto": "ads-crip-to",
    "adscrita": "ads-cri-ta",
    "adscrito": "ads-cri-to",
    "adsorbente": "ad-sor-ben-te",
    "adsorber": "ad-sor-ber",
    "adsorción": "ad-sor-ción",
    "adstrato": "ads-tra-to",
    "adstricción": "ads-tric-ción",
    "adstringente": "ads-trin-gen-te",
    "adstringir": "ads-trin-gir",
    "aduana": "a-dua-na",
    "aduanal": "a-dua-nal",
    "aduanar": "a-dua-nar",
    "aduanera": "a-dua-ne-ra",
    "aduanero": "a-dua-ne-ro",
    "aduar": "a-duar",
    "adúcar": "a-dú-car",
    "aducción": "a-duc-ción",
    "aducir": "a-du-cir",
    "aductor": "a-duc-tor",
    "aductora": "a-duc-to-ra",
    "adueñar": "a-due-ñar",
    "adueñarse": "a-due-ñar-se",
    "aduendada": "a-duen-da-da",
    "aduendado": "a-duen-da-do",
    "adufe": "a-du-fe",
    "adufera": "a-du-fe-ra",
    "adufero": "a-du-fe-ro",
    "adufre": "a-du-fre",
    "aduja": "a-du-ja",
    "adujar": "a-du-jar",
    "adul": "a-dul",
    "adula": "a-du-la",
    "adulación": "a-du-la-ción",
    "adulador": "a-du-la-dor",
    "aduladora": "a-du-la-do-ra",
    "adulante": "a-du-lan-te",
    "adular": "a-du-lar",
    "adularia": "a-du-la-ria",
    "adulatoria": "a-du-la-to-ria",
    "adulatorio": "a-du-la-to-rio",
    "adulciguar": "a-dul-ci-guar",
    "adulcir": "a-dul-cir",
    "adulete": "a-du-le-te",
    "adulón": "a-du-lón",
    "adulona": "a-du-lo-na",
    "adulonería": "a-du-lo-ne-rí-a",
    "adulta": "a-dul-ta",
    "adúltera": "a-dúl-te-ra",
    "adulteración": "a-dul-te-ra-ción",
    "adulterador": "a-dul-te-ra-dor",
    "adulteradora": "a-dul-te-ra-do-ra",
    "adulterante": "a-dul-te-ran-te",
    "adulterar": "a-dul-te-rar",
    "adulterina": "a-dul-te-ri-na",
    "adulterino": "a-dul-te-ri-no",
    "adulterio": "a-dul-te-rio",
    "adúltero": "a-dúl-te-ro",
    "adultez": "a-dul-tez",
    "adulto": "a-dul-to",
    "adulzar": "a-dul-zar",
    "adulzorar": "a-dul-zo-rar",
    "adumbración": "a-dum-bra-ción",
    "adumbrar": "a-dum-brar",
    "adunación": "a-du-na-ción",
    "adunar": "a-du-nar",
    "adunca": "a-dun-ca",
    "adunco": "a-dun-co",
    "adundado": "a-dun-da-do",
    "adundar": "a-dun-dar",
    "adunia": "a-du-nia",
    "adurir": "a-du-rir",
    "aduro": "a-du-ro",
    "adusta": "a-dus-ta",
    "adustez": "a-dus-tez",
    "adustible": "a-dus-ti-ble",
    "adustión": "a-dus-tión",
    "adustiva": "a-dus-ti-va",
    "adustivo": "a-dus-ti-vo",
    "adusto": "a-dus-to",
    "adutaque": "a-du-ta-que",
    "advección": "ad-vec-ción",
    "advenediza": "ad-ve-ne-di-za",
    "advenedizo": "ad-ve-ne-di-zo",
    "advenidera": "ad-ve-ni-de-ra",
    "advenidero": "ad-ve-ni-de-ro",
    "advenimiento": "ad-ve-ni-mien-to",
    "advenir": "ad-ve-nir",
    "adventicia": "ad-ven-ti-cia",
    "adventiciamente": "ad-ven-ti-cia-men-te",
    "adventicio": "ad-ven-ti-cio",
    "adventismo": "ad-ven-tis-mo",
    "adventista": "ad-ven-tis-ta",
    "adveración": "ad-ve-ra-ción",
    "adverado": "ad-ve-ra-do",
    "adverar": "ad-ve-rar",
    "adverbial": "ad-ver-bial",
    "adverbialización": "ad-ver-bia-li-za-ción",
    "adverbializar": "ad-ver-bia-li-zar",
    "adverbio": "ad-ver-bio",
    "adversa": "ad-ver-sa",
    "adversador": "ad-ver-sa-dor",
    "adversamente": "ad-ver-sa-men-te",
    "adversar": "ad-ver-sar",
    "adversaria": "ad-ver-sa-ria",
    "adversario": "ad-ver-sa-rio",
    "adversativa": "ad-ver-sa-ti-va",
    "adversativo": "ad-ver-sa-ti-vo",
    "adversidad": "ad-ver-si-dad",
    "adversión": "ad-ver-sión",
    "adverso": "ad-ver-so",
    "advertencia": "ad-ver-ten-cia",
    "advertida": "ad-ver-ti-da",
    "advertidamente": "ad-ver-ti-da-men-te",
    "advertido": "ad-ver-ti-do",
    "advertimiento": "ad-ver-ti-mien-to",
    "advertir": "ad-ver-tir",
    "adviento": "ad-vien-to",
    "advocación": "ad-vo-ca-ción",
    "advocar": "ad-vo-car",
    "advocatoria": "ad-vo-ca-to-ria",
    "advocatorio": "ad-vo-ca-to-rio",
    "adyacencia": "ad-ya-cen-cia",
    "adyacente": "ad-ya-cen-te",
    "adyuvante": "ad-yu-van-te",
    "aeda": "a-e-da",
    "aedo": "a-e-do",
    "aeración": "a-e-ra-ción",
    "aérea": "a-é-re-a",
    "aéreamente": "a-é-re-a-men-te",
    "aéreo": "a-é-re-o",
    "aerícola": "a-e-rí-co-la",
    "aerífera": "a-e-rí-fe-ra",
    "aerífero": "a-e-rí-fe-ro",
    "aeriforme": "a-e-ri-for-me",
    "aerobia": "a-e-ro-bia",
    "aerobic": "a-e-ro-bic",
    "aeróbic": "a-e-ró-bic",
    "aeróbico": "a-e-ró-bi-co",
    "aerobio": "a-e-ro-bio",
    "aerobiosis": "a-e-ro-bio-sis",
    "aerobismo": "a-e-ro-bis-mo",
    "aerobús": "a-e-ro-bús",
    "aerocarril": "a-e-ro-ca-rril",
    "aeroclub": "a-e-ro-club",
    "aerocriptografía": "a-e-ro-crip-to-gra-fí-a",
    "aerocriptográfico": "a-e-ro-crip-to-grá-fi-co",
    "aerodeslizador": "a-e-ro-des-li-za-dor",
    "aerodeslizante": "a-e-ro-des-li-zan-te",
    "aerodinámica": "a-e-ro-di-ná-mi-ca",
    "aerodinámico": "a-e-ro-di-ná-mi-co",
    "aerodinamismo": "a-e-ro-di-na-mis-mo",
    "aerodino": "a-e-ro-di-no",
    "aeródromo": "a-e-ró-dro-mo",
    "aeroespacial": "a-e-ro-es-pa-cial",
    "aerofagia": "a-e-ro-fa-gia",
    "aerofaro": "a-e-ro-fa-ro",
    "aerofobia": "a-e-ro-fo-bia",
    "aerófobo": "a-e-ró-fo-bo",
    "aerófono": "a-e-ró-fo-no",
    "aerofotografía": "a-e-ro-fo-to-gra-fí-a",
    "aerogenerador": "a-e-ro-ge-ne-ra-dor",
    "aerografía": "a-e-ro-gra-fí-a",
    "aerógrafo": "a-e-ró-gra-fo",
    "aerograma": "a-e-ro-gra-ma",
    "aerolínea": "a-e-ro-lí-ne-a",
    "aerolítica": "a-e-ro-lí-ti-ca",
    "aerolítico": "a-e-ro-lí-ti-co",
    "aerolito": "a-e-ro-li-to",
    "aerología": "a-e-ro-lo-gí-a",
    "aerológico": "a-e-ro-ló-gi-co",
    "aeromancía": "a-e-ro-man-cí-a",
    "aeromancia": "a-e-ro-man-cia",
    "aeromántica": "a-e-ro-mán-ti-ca",
    "aeromántico": "a-e-ro-mán-ti-co",
    "aerómetro": "a-e-ró-me-tro",
    "aeromodelismo": "a-e-ro-mo-de-lis-mo",
    "aeromodelista": "a-e-ro-mo-de-lis-ta",
    "aeromodelo": "a-e-ro-mo-de-lo",
    "aeromotor": "a-e-ro-mo-tor",
    "aeromóvil": "a-e-ro-mó-vil",
    "aeromoza": "a-e-ro-mo-za",
    "aeromozo": "a-e-ro-mo-zo",
    "aeronata": "a-e-ro-na-ta",
    "aeronato": "a-e-ro-na-to",
    "aeronauta": "a-e-ro-nau-ta",
    "aeronáutica": "a-e-ro-náu-ti-ca",
    "aeronáutico": "a-e-ro-náu-ti-co",
    "aeronaval": "a-e-ro-na-val",
    "aeronave": "a-e-ro-na-ve",
    "aeronavegabilidad": "a-e-ro-na-ve-ga-bi-li-dad",
    "aeronavegación": "a-e-ro-na-ve-ga-ción",
    "aeroparque": "a-e-ro-par-que",
    "aeropirata": "a-e-ro-pi-ra-ta",
    "aeroplano": "a-e-ro-pla-no",
    "aeroportuario": "a-e-ro-por-tua-rio",
    "aeropostal": "a-e-ro-pos-tal",
    "aeropuerto": "a-e-ro-puer-to",
    "aerosilla": "a-e-ro-si-lla",
    "aerosol": "a-e-ro-sol",
    "aerostación": "a-e-ros-ta-ción",
    "aerostática": "a-e-ros-tá-ti-ca",
    "aerostático": "a-e-ros-tá-ti-co",
    "aerostato": "a-e-ros-ta-to",
    "aeróstato": "a-e-rós-ta-to",
    "aerostero": "a-e-ros-te-ro",
    "aerotaxi": "a-e-ro-ta-xi",
    "aerotecnia": "a-e-ro-tec-nia",
    "aerotécnica": "a-e-ro-téc-ni-ca",
    "aerotécnico": "a-e-ro-téc-ni-co",
    "aeroterapia": "a-e-ro-te-ra-pia",
    "aeroterrestre": "a-e-ro-te-rres-tre",
    "aerotransportar": "a-e-ro-trans-por-tar",
    "aerotransporte": "a-e-ro-trans-por-te",
    "aerotrén": "a-e-ro-trén",
    "aeroturbina": "a-e-ro-tur-bi-na",
    "aerovía": "a-e-ro-ví-a",
    "aeta": "a-e-ta",
    "afabilidad": "a-fa-bi-li-dad",
    "afable": "a-fa-ble",
    "afablemente": "a-fa-ble-men-te",
    "afabulación": "a-fa-bu-la-ción",
    "áfaca": "á-fa-ca",
    "afaccionada": "a-fac-cio-na-da",
    "afaccionado": "a-fac-cio-na-do",
    "afacer": "a-fa-cer",
    "afacimiento": "a-fa-ci-mien-to",
    "afalagar": "a-fa-la-gar",
    "afamada": "a-fa-ma-da",
    "afamado": "a-fa-ma-do",
    "afamar": "a-fa-mar",
    "afán": "a-fán",
    "afanada": "a-fa-na-da",
    "afanado": "a-fa-na-do",
    "afanador": "a-fa-na-dor",
    "afanadora": "a-fa-na-do-ra",
    "afanar": "a-fa-nar",
    "afaníptero": "a-fa-níp-te-ro",
    "afanita": "a-fa-ni-ta",
    "afano": "a-fa-no",
    "afanosa": "a-fa-no-sa",
    "afanosamente": "a-fa-no-sa-men-te",
    "afanoso": "a-fa-no-so",
    "afantasmar": "a-fan-tas-mar",
    "afarallonada": "a-fa-ra-llo-na-da",
    "afarallonado": "a-fa-ra-llo-na-do",
    "afarolada": "a-fa-ro-la-da",
    "afarolado": "a-fa-ro-la-do",
    "afarolar": "a-fa-ro-lar",
    "afascalar": "a-fas-ca-lar",
    "afasia": "a-fa-sia",
    "afásica": "a-fá-si-ca",
    "afásico": "a-fá-si-co",
    "afatar": "a-fa-tar",
    "afate": "a-fa-te",
    "afeador": "a-fe-a-dor",
    "afeadora": "a-fe-a-do-ra",
    "afeamiento": "a-fe-a-mien-to",
    "afear": "a-fe-ar",
    "afeblecer": "a-fe-ble-cer",
    "afeblecerse": "a-fe-ble-cer-se",
    "afebril": "a-fe-bril",
    "afección": "a-fec-ción",
    "afeccionar": "a-fec-cio-nar",
    "afecha": "a-fe-cha",
    "afecho": "a-fe-cho",
    "afecta": "a-fec-ta",
    "afectable": "a-fec-ta-ble",
    "afectación": "a-fec-ta-ción",
    "afectada": "a-fec-ta-da",
    "afectadamente": "a-fec-ta-da-men-te",
    "afectado": "a-fec-ta-do",
    "afectador": "a-fec-ta-dor",
    "afectadora": "a-fec-ta-do-ra",
    "afectar": "a-fec-tar",
    "afectísimo": "a-fec-tí-si-mo",
    "afectiva": "a-fec-ti-va",
    "afectivamente": "a-fec-ti-va-men-te",
    "afectividad": "a-fec-ti-vi-dad",
    "afectivo": "a-fec-ti-vo",
    "afecto": "a-fec-to",
    "afectuosa": "a-fec-tuo-sa",
    "afectuosamente": "a-fec-tuo-sa-men-te",
    "afectuosidad": "a-fec-tuo-si-dad",
    "afectuoso": "a-fec-tuo-so",
    "afeitada": "a-fei-ta-da",
    "afeitadamente": "a-fei-ta-da-men-te",
    "afeitadera": "a-fei-ta-de-ra",
    "afeitado": "a-fei-ta-do",
    "afeitador": "a-fei-ta-dor",
    "afeitadora": "a-fei-ta-do-ra",
    "afeitamiento": "a-fei-ta-mien-to",
    "afeitar": "a-fei-tar",
    "afeite": "a-fei-te",
    "afelio": "a-fe-lio",
    "afelpada": "a-fel-pa-da",
    "afelpado": "a-fel-pa-do",
    "afelpar": "a-fel-par",
    "afeminación": "a-fe-mi-na-ción",
    "afeminada": "a-fe-mi-na-da",
    "afeminadamente": "a-fe-mi-na-da-men-te",
    "afeminado": "a-fe-mi-na-do",
    "afeminamiento": "a-fe-mi-na-mien-to",
    "afeminar": "a-fe-mi-nar",
    "afer": "a-fer",
    "aferencia": "a-fe-ren-cia",
    "aferente": "a-fe-ren-te",
    "aféresis": "a-fé-re-sis",
    "aferidor": "a-fe-ri-dor",
    "aferidora": "a-fe-ri-do-ra",
    "aferir": "a-fe-rir",
    "aferradamente": "a-fe-rra-da-men-te",
    "aferrado": "a-fe-rra-do",
    "aferrador": "a-fe-rra-dor",
    "aferradora": "a-fe-rra-do-ra",
    "aferramiento": "a-fe-rra-mien-to",
    "aferrar": "a-fe-rrar",
    "aferruzada": "a-fe-rru-za-da",
    "aferruzado": "a-fe-rru-za-do",
    "afervorar": "a-fer-vo-rar",
    "afervorizar": "a-fer-vo-ri-zar",
    "afestonada": "a-fes-to-na-da",
    "afestonado": "a-fes-to-na-do",
    "affaire": "af-fai-re",
    "affidávit": "af-fi-dá-vit",
    "afgana": "af-ga-na",
    "afgano": "af-ga-no",
    "afianzador": "a-fian-za-dor",
    "afianzadora": "a-fian-za-do-ra",
    "afianzamiento": "a-fian-za-mien-to",
    "afianzar": "a-fian-zar",
    "afiar": "a-fiar",
    "afiatada": "a-fia-ta-da",
    "afiatado": "a-fia-ta-do",
    "afiblar": "a-fi-blar",
    "afiche": "a-fi-che",
    "afición": "a-fi-ción",
    "aficionada": "a-fi-cio-na-da",
    "aficionado": "a-fi-cio-na-do",
    "aficionador": "a-fi-cio-na-dor",
    "aficionar": "a-fi-cio-nar",
    "áfido": "á-fi-do",
    "afiebrado": "a-fie-bra-do",
    "afiebrar": "a-fie-brar",
    "afiebrarse": "a-fie-brar-se",
    "afielar": "a-fie-lar",
    "afija": "a-fi-ja",
    "afijación": "a-fi-ja-ción",
    "afijada": "a-fi-ja-da",
    "afijado": "a-fi-ja-do",
    "afijamiento": "a-fi-ja-mien-to",
    "afijar": "a-fi-jar",
    "afijo": "a-fi-jo",
    "áfila": "á-fi-la",
    "afiladamente": "a-fi-la-da-men-te",
    "afiladera": "a-fi-la-de-ra",
    "afiladero": "a-fi-la-de-ro",
    "afilado": "a-fi-la-do",
    "afilador": "a-fi-la-dor",
    "afiladora": "a-fi-la-do-ra",
    "afiladura": "a-fi-la-du-ra",
    "afilalápices": "a-fi-la-lá-pi-ces",
    "afilamiento": "a-fi-la-mien-to",
    "afilar": "a-fi-lar",
    "afiliación": "a-fi-lia-ción",
    "afiliada": "a-fi-lia-da",
    "afiliado": "a-fi-lia-do",
    "afiliar": "a-fi-liar",
    "afiligranada": "a-fi-li-gra-na-da",
    "afiligranado": "a-fi-li-gra-na-do",
    "afiligranar": "a-fi-li-gra-nar",
    "áfilo": "á-fi-lo",
    "afilón": "a-fi-lón",
    "afilorar": "a-fi-lo-rar",
    "afilosofada": "a-fi-lo-so-fa-da",
    "afilosofado": "a-fi-lo-so-fa-do",
    "afín": "a-fín",
    "afinación": "a-fi-na-ción",
    "afinadamente": "a-fi-na-da-men-te",
    "afinado": "a-fi-na-do",
    "afinador": "a-fi-na-dor",
    "afinadora": "a-fi-na-do-ra",
    "afinadura": "a-fi-na-du-ra",
    "afinamiento": "a-fi-na-mien-to",
    "afinar": "a-fi-nar",
    "afincada": "a-fin-ca-da",
    "afincadamente": "a-fin-ca-da-men-te",
    "afincado": "a-fin-ca-do",
    "afincamiento": "a-fin-ca-mien-to",
    "afincar": "a-fin-car",
    "afinidad": "a-fi-ni-dad",
    "afino": "a-fi-no",
    "afinojar": "a-fi-no-jar",
    "afirmación": "a-fir-ma-ción",
    "afirmadamente": "a-fir-ma-da-men-te",
    "afirmado": "a-fir-ma-do",
    "afirmador": "a-fir-ma-dor",
    "afirmadora": "a-fir-ma-do-ra",
    "afirmamiento": "a-fir-ma-mien-to",
    "afirmar": "a-fir-mar",
    "afirmativa": "a-fir-ma-ti-va",
    "afirmativamente": "a-fir-ma-ti-va-men-te",
    "afirmativo": "a-fir-ma-ti-vo",
    "afirolar": "a-fi-ro-lar",
    "afistolar": "a-fis-to-lar",
    "afistular": "a-fis-tu-lar",
    "afiuciar": "a-fiu-ciar",
    "aflacar": "a-fla-car",
    "aflamar": "a-fla-mar",
    "aflamencado": "a-fla-men-ca-do",
    "aflaquecer": "a-fla-que-cer",
    "aflaquecerse": "a-fla-que-cer-se",
    "aflatar": "a-fla-tar",
    "aflato": "a-fla-to",
    "aflatoxina": "a-fla-to-xi-na",
    "aflautada": "a-flau-ta-da",
    "aflautado": "a-flau-ta-do",
    "aflautar": "a-flau-tar",
    "aflechada": "a-fle-cha-da",
    "aflechado": "a-fle-cha-do",
    "afletar": "a-fle-tar",
    "aflicción": "a-flic-ción",
    "aflicta": "a-flic-ta",
    "aflictiva": "a-flic-ti-va",
    "aflictivo": "a-flic-ti-vo",
    "aflicto": "a-flic-to",
    "afligible": "a-fli-gi-ble",
    "afligida": "a-fli-gi-da",
    "afligidamente": "a-fli-gi-da-men-te",
    "afligido": "a-fli-gi-do",
    "afligimiento": "a-fli-gi-mien-to",
    "afligir": "a-fli-gir",
    "aflojamiento": "a-flo-ja-mien-to",
    "aflojar": "a-flo-jar",
    "afloración": "a-flo-ra-ción",
    "aflorado": "a-flo-ra-do",
    "afloramiento": "a-flo-ra-mien-to",
    "aflorar": "a-flo-rar",
    "afluencia": "a-fluen-cia",
    "afluente": "a-fluen-te",
    "afluentemente": "a-fluen-te-men-te",
    "afluir": "a-fluir",
    "aflujo": "a-flu-jo",
    "afluyente": "a-flu-yen-te",
    "afocar": "a-fo-car",
    "afofar": "a-fo-far",
    "afogar": "a-fo-gar",
    "afogarar": "a-fo-ga-rar",
    "afogonadura": "a-fo-go-na-du-ra",
    "afollado": "a-fo-lla-do",
    "afollar": "a-fo-llar",
    "áfona": "á-fo-na",
    "afondar": "a-fon-dar",
    "afonía": "a-fo-ní-a",
    "afónica": "a-fó-ni-ca",
    "afónico": "a-fó-ni-co",
    "áfono": "á-fo-no",
    "aforada": "a-fo-ra-da",
    "aforado": "a-fo-ra-do",
    "aforador": "a-fo-ra-dor",
    "aforamiento": "a-fo-ra-mien-to",
    "aforar": "a-fo-rar",
    "aforcar": "a-for-car",
    "afore": "a-fo-re",
    "aforisma": "a-fo-ris-ma",
    "aforismo": "a-fo-ris-mo",
    "aforística": "a-fo-rís-ti-ca",
    "aforísticamente": "a-fo-rís-ti-ca-men-te",
    "aforístico": "a-fo-rís-ti-co",
    "aforo": "a-fo-ro",
    "aforrada": "a-fo-rra-da",
    "aforrado": "a-fo-rra-do",
    "aforrador": "a-fo-rra-dor",
    "aforradora": "a-fo-rra-do-ra",
    "aforradura": "a-fo-rra-du-ra",
    "aforramiento": "a-fo-rra-mien-to",
    "aforrar": "a-fo-rrar",
    "aforrecha": "a-fo-rre-cha",
    "aforrecho": "a-fo-rre-cho",
    "aforro": "a-fo-rro",
    "afortalar": "a-for-ta-lar",
    "afortunada": "a-for-tu-na-da",
    "afortunadamente": "a-for-tu-na-da-men-te",
    "afortunado": "a-for-tu-na-do",
    "afortunar": "a-for-tu-nar",
    "afosar": "a-fo-sar",
    "afosarse": "a-fo-sar-se",
    "afoscar": "a-fos-car",
    "afoscarse": "a-fos-car-se",
    "afótico": "a-fó-ti-co",
    "afra": "a-fra",
    "afrailada": "a-frai-la-da",
    "afrailado": "a-frai-la-do",
    "afrailamiento": "a-frai-la-mien-to",
    "afrailar": "a-frai-lar",
    "afrancar": "a-fran-car",
    "afrancesada": "a-fran-ce-sa-da",
    "afrancesado": "a-fran-ce-sa-do",
    "afrancesamiento": "a-fran-ce-sa-mien-to",
    "afrancesar": "a-fran-ce-sar",
    "afranjada": "a-fran-ja-da",
    "afranjado": "a-fran-ja-do",
    "afrechar": "a-fre-char",
    "afrecharse": "a-fre-char-se",
    "afrechero": "a-fre-che-ro",
    "afrecho": "a-fre-cho",
    "afrenillar": "a-fre-ni-llar",
    "afreñir": "a-fre-ñir",
    "afrenta": "a-fren-ta",
    "afrentador": "a-fren-ta-dor",
    "afrentadora": "a-fren-ta-do-ra",
    "afrentar": "a-fren-tar",
    "afrentosa": "a-fren-to-sa",
    "afrentoso": "a-fren-to-so",
    "afresado": "a-fre-sa-do",
    "afretar": "a-fre-tar",
    "áfrica": "á-fri-ca",
    "africada": "a-fri-ca-da",
    "africado": "a-fri-ca-do",
    "africana": "a-fri-ca-na",
    "africanidad": "a-fri-ca-ni-dad",
    "africanismo": "a-fri-ca-nis-mo",
    "africanista": "a-fri-ca-nis-ta",
    "africanizar": "a-fri-ca-ni-zar",
    "africano": "a-fri-ca-no",
    "áfrico": "á-fri-co",
    "afrijolar": "a-fri-jo-lar",
    "afrikáans": "a-fri-ká-ans",
    "afrikáner": "a-fri-ká-ner",
    "afrisonada": "a-fri-so-na-da",
    "afrisonado": "a-fri-so-na-do",
    "afro": "a-fro",
    "afroamericana": "a-fro-a-me-ri-ca-na",
    "afroamericano": "a-fro-a-me-ri-ca-no",
    "afroantillano": "a-fro-an-ti-lla-no",
    "afroasiático": "a-fro-a-siá-ti-co",
    "afrocubana": "a-fro-cu-ba-na",
    "afrocubano": "a-fro-cu-ba-no",
    "afrodisiaca": "a-fro-di-sia-ca",
    "afrodisíaco": "a-fro-di-sí-a-co",
    "afrodisiaco": "a-fro-di-sia-co",
    "afrodita": "a-fro-di-ta",
    "afronegrismo": "a-fro-ne-gris-mo",
    "afronegro": "a-fro-ne-gro",
    "afronitro": "a-fro-ni-tro",
    "afronorteamericana": "a-fro-nor-te-a-me-ri-ca-na",
    "afronorteamericano": "a-fro-nor-te-a-me-ri-ca-no",
    "afrontación": "a-fron-ta-ción",
    "afrontada": "a-fron-ta-da",
    "afrontado": "a-fron-ta-do",
    "afrontamiento": "a-fron-ta-mien-to",
    "afrontar": "a-fron-tar",
    "afruenta": "a-fruen-ta",
    "afrutado": "a-fru-ta-do",
    "afta": "af-ta",
    "afterhours": "af-te-rhours",
    "aftershave": "af-ters-ha-ve",
    "aftosa": "af-to-sa",
    "aftoso": "af-to-so",
    "afuciada": "a-fu-cia-da",
    "afuciado": "a-fu-cia-do",
    "afuciar": "a-fu-ciar",
    "afuera": "a-fue-ra",
    "afuereña": "a-fue-re-ña",
    "afuereño": "a-fue-re-ño",
    "afuerina": "a-fue-ri-na",
    "afuerino": "a-fue-ri-no",
    "afuerita": "a-fue-ri-ta",
    "afuero": "a-fue-ro",
    "afufa": "a-fu-fa",
    "afufar": "a-fu-far",
    "afufón": "a-fu-fón",
    "afumada": "a-fu-ma-da",
    "afumado": "a-fu-ma-do",
    "afumar": "a-fu-mar",
    "afusión": "a-fu-sión",
    "afuste": "a-fus-te",
    "agá": "a-gá",
    "agabachar": "a-ga-ba-char",
    "agace": "a-ga-ce",
    "agachada": "a-ga-cha-da",
    "agachadera": "a-ga-cha-de-ra",
    "agachadita": "a-ga-cha-di-ta",
    "agachadiza": "a-ga-cha-di-za",
    "agachado": "a-ga-cha-do",
    "agachapar": "a-ga-cha-par",
    "agachaparse": "a-ga-cha-par-se",
    "agachar": "a-ga-char",
    "agache": "a-ga-che",
    "agachón": "a-ga-chón",
    "agachona": "a-ga-cho-na",
    "agadón": "a-ga-dón",
    "agalactia": "a-ga-lac-tia",
    "agalbanada": "a-gal-ba-na-da",
    "agalbanado": "a-gal-ba-na-do",
    "agalerar": "a-ga-le-rar",
    "agalgado": "a-gal-ga-do",
    "agalla": "a-ga-lla",
    "agallada": "a-ga-lla-da",
    "agallado": "a-ga-lla-do",
    "agalladura": "a-ga-lla-du-ra",
    "agallar": "a-ga-llar",
    "agállara": "a-gá-lla-ra",
    "agallegada": "a-ga-lle-ga-da",
    "agallegado": "a-ga-lle-ga-do",
    "agallo": "a-ga-llo",
    "agallón": "a-ga-llón",
    "agallonada": "a-ga-llo-na-da",
    "agallonado": "a-ga-llo-na-do",
    "agallú": "a-ga-llú",
    "agalluda": "a-ga-llu-da",
    "agalludo": "a-ga-llu-do",
    "agáloco": "a-gá-lo-co",
    "agama": "a-ga-ma",
    "agamí": "a-ga-mí",
    "agámido": "a-gá-mi-do",
    "agamitar": "a-ga-mi-tar",
    "agamuzada": "a-ga-mu-za-da",
    "agamuzado": "a-ga-mu-za-do",
    "aganar": "a-ga-nar",
    "agangrenar": "a-gan-gre-nar",
    "agangrenarse": "a-gan-gre-nar-se",
    "aganipea": "a-ga-ni-pe-a",
    "aganipeo": "a-ga-ni-pe-o",
    "agañotar": "a-ga-ño-tar",
    "agapando": "a-ga-pan-do",
    "agapanto": "a-ga-pan-to",
    "ágape": "á-ga-pe",
    "agar": "a-gar",
    "agarabatada": "a-ga-ra-ba-ta-da",
    "agarabatado": "a-ga-ra-ba-ta-do",
    "agaragar": "a-ga-ra-gar",
    "agarbada": "a-gar-ba-da",
    "agarbado": "a-gar-ba-do",
    "agarbanzada": "a-gar-ban-za-da",
    "agarbanzado": "a-gar-ban-za-do",
    "agarbanzar": "a-gar-ban-zar",
    "agarbar": "a-gar-bar",
    "agarbarse": "a-gar-bar-se",
    "agarbillar": "a-gar-bi-llar",
    "agardamar": "a-gar-da-mar",
    "agardamarse": "a-gar-da-mar-se",
    "agarena": "a-ga-re-na",
    "agareno": "a-ga-re-no",
    "agaricácea": "a-ga-ri-cá-ce-a",
    "agaricáceo": "a-ga-ri-cá-ce-o",
    "agárico": "a-gá-ri-co",
    "agarrada": "a-ga-rra-da",
    "agarradera": "a-ga-rra-de-ra",
    "agarradero": "a-ga-rra-de-ro",
    "agarrado": "a-ga-rra-do",
    "agarrador": "a-ga-rra-dor",
    "agarradora": "a-ga-rra-do-ra",
    "agarrafador": "a-ga-rra-fa-dor",
    "agarrafadora": "a-ga-rra-fa-do-ra",
    "agarrafar": "a-ga-rra-far",
    "agarrante": "a-ga-rran-te",
    "agarrar": "a-ga-rrar",
    "agarre": "a-ga-rre",
    "agarro": "a-ga-rro",
    "agarrochador": "a-ga-rro-cha-dor",
    "agarrochar": "a-ga-rro-char",
    "agarrochear": "a-ga-rro-che-ar",
    "agarrón": "a-ga-rrón",
    "agarrotado": "a-ga-rro-ta-do",
    "agarrotamiento": "a-ga-rro-ta-mien-to",
    "agarrotar": "a-ga-rro-tar",
    "agarrotear": "a-ga-rro-te-ar",
    "agasajable": "a-ga-sa-ja-ble",
    "agasajada": "a-ga-sa-ja-da",
    "agasajado": "a-ga-sa-ja-do",
    "agasajador": "a-ga-sa-ja-dor",
    "agasajadora": "a-ga-sa-ja-do-ra",
    "agasajar": "a-ga-sa-jar",
    "agasajo": "a-ga-sa-jo",
    "ágata": "á-ga-ta",
    "agateador": "a-ga-te-a-dor",
    "agatina": "a-ga-ti-na",
    "agatino": "a-ga-ti-no",
    "agatizar": "a-ga-ti-zar",
    "agatizarse": "a-ga-ti-zar-se",
    "agauchado": "a-gau-cha-do",
    "agauchar": "a-gau-char",
    "agavanza": "a-ga-van-za",
    "agavanzo": "a-ga-van-zo",
    "agave": "a-ga-ve",
    "agavillador": "a-ga-vi-lla-dor",
    "agavilladora": "a-ga-vi-lla-do-ra",
    "agavillar": "a-ga-vi-llar",
    "agazapado": "a-ga-za-pa-do",
    "agazapar": "a-ga-za-par",
    "agencia": "a-gen-cia",
    "agenciar": "a-gen-ciar",
    "agenciera": "a-gen-cie-ra",
    "agenciero": "a-gen-cie-ro",
    "agenciosa": "a-gen-cio-sa",
    "agencioso": "a-gen-cio-so",
    "agenda": "a-gen-da",
    "agenesia": "a-ge-ne-sia",
    "agente": "a-gen-te",
    "agerasia": "a-ge-ra-sia",
    "agérato": "a-gé-ra-to",
    "agermanar": "a-ger-ma-nar",
    "agermanarse": "a-ger-ma-nar-se",
    "agestada": "a-ges-ta-da",
    "agestado": "a-ges-ta-do",
    "agestar": "a-ges-tar",
    "agestarse": "a-ges-tar-se",
    "agestión": "a-ges-tión",
    "ageusia": "a-geu-sia",
    "agibílibus": "a-gi-bí-li-bus",
    "agible": "a-gi-ble",
    "agigantada": "a-gi-gan-ta-da",
    "agigantado": "a-gi-gan-ta-do",
    "agigantamiento": "a-gi-gan-ta-mien-to",
    "agigantar": "a-gi-gan-tar",
    "agigolón": "a-gi-go-lón",
    "agigotar": "a-gi-go-tar",
    "ágil": "á-gil",
    "agílibus": "a-gí-li-bus",
    "agilidad": "a-gi-li-dad",
    "agilipollado": "a-gi-li-po-lla-do",
    "agilipollar": "a-gi-li-po-llar",
    "agilitar": "a-gi-li-tar",
    "agilización": "a-gi-li-za-ción",
    "agilizar": "a-gi-li-zar",
    "ágilmente": "á-gil-men-te",
    "agio": "a-gio",
    "agiotador": "a-gio-ta-dor",
    "agiotaje": "a-gio-ta-je",
    "agiotista": "a-gio-tis-ta",
    "agitable": "a-gi-ta-ble",
    "agitación": "a-gi-ta-ción",
    "agitadamente": "a-gi-ta-da-men-te",
    "agitado": "a-gi-ta-do",
    "agitador": "a-gi-ta-dor",
    "agitadora": "a-gi-ta-do-ra",
    "agitanada": "a-gi-ta-na-da",
    "agitanado": "a-gi-ta-na-do",
    "agitanar": "a-gi-ta-nar",
    "agitante": "a-gi-tan-te",
    "agitar": "a-gi-tar",
    "aglomeración": "a-glo-me-ra-ción",
    "aglomerado": "a-glo-me-ra-do",
    "aglomerante": "a-glo-me-ran-te",
    "aglomerar": "a-glo-me-rar",
    "aglutinación": "a-glu-ti-na-ción",
    "aglutinador": "a-glu-ti-na-dor",
    "aglutinadora": "a-glu-ti-na-do-ra",
    "aglutinante": "a-glu-ti-nan-te",
    "aglutinar": "a-glu-ti-nar",
    "aglutinina": "a-glu-ti-ni-na",
    "aglutinógeno": "a-glu-ti-nó-ge-no",
    "agnación": "ag-na-ción",
    "agnada": "ag-na-da",
    "agnado": "ag-na-do",
    "agnaticia": "ag-na-ti-cia",
    "agnaticio": "ag-na-ti-cio",
    "agnato": "ag-na-to",
    "agnición": "ag-ni-ción",
    "agnocasto": "ag-no-cas-to",
    "agnombre": "ag-nom-bre",
    "agnomento": "ag-no-men-to",
    "agnominación": "ag-no-mi-na-ción",
    "agnosia": "ag-no-sia",
    "agnósica": "ag-nó-si-ca",
    "agnósico": "ag-nó-si-co",
    "agnóstica": "ag-nós-ti-ca",
    "agnosticismo": "ag-nos-ti-cis-mo",
    "agnóstico": "ag-nós-ti-co",
    "agnus": "ag-nus",
    "agnusdéi": "ag-nus-déi",
    "agobiada": "a-go-bia-da",
    "agobiado": "a-go-bia-do",
    "agobiador": "a-go-bia-dor",
    "agobiante": "a-go-bian-te",
    "agobiar": "a-go-biar",
    "agobio": "a-go-bio",
    "agogía": "a-go-gí-a",
    "agógica": "a-gó-gi-ca",
    "agógico": "a-gó-gi-co",
    "agolar": "a-go-lar",
    "agolletar": "a-go-lle-tar",
    "agolpamiento": "a-gol-pa-mien-to",
    "agolpar": "a-gol-par",
    "agonal": "a-go-nal",
    "agonía": "a-go-ní-a",
    "agonías": "a-go-ní-as",
    "agónica": "a-gó-ni-ca",
    "agónico": "a-gó-ni-co",
    "agoniosa": "a-go-nio-sa",
    "agonioso": "a-go-nio-so",
    "agonismo": "a-go-nis-mo",
    "agonista": "a-go-nis-ta",
    "agonística": "a-go-nís-ti-ca",
    "agonístico": "a-go-nís-ti-co",
    "agonizante": "a-go-ni-zan-te",
    "agonizar": "a-go-ni-zar",
    "ágono": "á-go-no",
    "agora": "a-go-ra",
    "ágora": "á-go-ra",
    "agorador": "a-go-ra-dor",
    "agoradora": "a-go-ra-do-ra",
    "agorafobia": "a-go-ra-fo-bia",
    "agorar": "a-go-rar",
    "agorera": "a-go-re-ra",
    "agorería": "a-go-re-rí-a",
    "agorero": "a-go-re-ro",
    "agorgojar": "a-gor-go-jar",
    "agorgojarse": "a-gor-go-jar-se",
    "agosta": "a-gos-ta",
    "agostadero": "a-gos-ta-de-ro",
    "agostado": "a-gos-ta-do",
    "agostador": "a-gos-ta-dor",
    "agostamiento": "a-gos-ta-mien-to",
    "agostar": "a-gos-tar",
    "agosteña": "a-gos-te-ña",
    "agosteño": "a-gos-te-ño",
    "agostera": "a-gos-te-ra",
    "agostero": "a-gos-te-ro",
    "agostía": "a-gos-tí-a",
    "agostinas": "a-gos-ti-nas",
    "agostio": "a-gos-tio",
    "agostiza": "a-gos-ti-za",
    "agostizo": "a-gos-ti-zo",
    "agosto": "a-gos-to",
    "agotable": "a-go-ta-ble",
    "agotado": "a-go-ta-do",
    "agotador": "a-go-ta-dor",
    "agotadora": "a-go-ta-do-ra",
    "agotamiento": "a-go-ta-mien-to",
    "agotante": "a-go-tan-te",
    "agotar": "a-go-tar",
    "agote": "a-go-te",
    "agovía": "a-go-ví-a",
    "agozcada": "a-goz-ca-da",
    "agozcado": "a-goz-ca-do",
    "agra": "a-gra",
    "agracejina": "a-gra-ce-ji-na",
    "agracejo": "a-gra-ce-jo",
    "agraceña": "a-gra-ce-ña",
    "agraceño": "a-gra-ce-ño",
    "agracera": "a-gra-ce-ra",
    "agracero": "a-gra-ce-ro",
    "agraciada": "a-gra-cia-da",
    "agraciadamente": "a-gra-cia-da-men-te",
    "agraciado": "a-gra-cia-do",
    "agraciar": "a-gra-ciar",
    "agracillo": "a-gra-ci-llo",
    "agradabilísimo": "a-gra-da-bi-lí-si-mo",
    "agradable": "a-gra-da-ble",
    "agradablemente": "a-gra-da-ble-men-te",
    "agradador": "a-gra-da-dor",
    "agradadora": "a-gra-da-do-ra",
    "agradamiento": "a-gra-da-mien-to",
    "agradar": "a-gra-dar",
    "agradecer": "a-gra-de-cer",
    "agradecida": "a-gra-de-ci-da",
    "agradecidamente": "a-gra-de-ci-da-men-te",
    "agradecido": "a-gra-de-ci-do",
    "agradecimiento": "a-gra-de-ci-mien-to",
    "agrado": "a-gra-do",
    "ágrafa": "á-gra-fa",
    "agrafía": "a-gra-fí-a",
    "agrafia": "a-gra-fia",
    "ágrafo": "á-gra-fo",
    "agramadera": "a-gra-ma-de-ra",
    "agramado": "a-gra-ma-do",
    "agramador": "a-gra-ma-dor",
    "agramadora": "a-gra-ma-do-ra",
    "agramante": "a-gra-man-te",
    "agramar": "a-gra-mar",
    "agramatical": "a-gra-ma-ti-cal",
    "agramaticalidad": "a-gra-ma-ti-ca-li-dad",
    "agramente": "a-gra-men-te",
    "agramilar": "a-gra-mi-lar",
    "agramiza": "a-gra-mi-za",
    "agramontés": "a-gra-mon-tés",
    "agramontesa": "a-gra-mon-te-sa",
    "agramontina": "a-gra-mon-ti-na",
    "agramontino": "a-gra-mon-ti-no",
    "agrandada": "a-gran-da-da",
    "agrandado": "a-gran-da-do",
    "agrandamiento": "a-gran-da-mien-to",
    "agrandar": "a-gran-dar",
    "agranujada": "a-gra-nu-ja-da",
    "agranujado": "a-gra-nu-ja-do",
    "agranulocito": "a-gra-nu-lo-ci-to",
    "agranulocitosis": "a-gra-nu-lo-ci-to-sis",
    "agraria": "a-gra-ria",
    "agrario": "a-gra-rio",
    "agrarismo": "a-gra-ris-mo",
    "agrarista": "a-gra-ris-ta",
    "agrás": "a-grás",
    "agravación": "a-gra-va-ción",
    "agravador": "a-gra-va-dor",
    "agravadora": "a-gra-va-do-ra",
    "agravamiento": "a-gra-va-mien-to",
    "agravante": "a-gra-van-te",
    "agravantemente": "a-gra-van-te-men-te",
    "agravar": "a-gra-var",
    "agravatoria": "a-gra-va-to-ria",
    "agravatorio": "a-gra-va-to-rio",
    "agraviada": "a-gra-via-da",
    "agraviadamente": "a-gra-via-da-men-te",
    "agraviado": "a-gra-via-do",
    "agraviador": "a-gra-via-dor",
    "agraviadora": "a-gra-via-do-ra",
    "agraviamiento": "a-gra-via-mien-to",
    "agraviante": "a-gra-vian-te",
    "agraviar": "a-gra-viar",
    "agravio": "a-gra-vio",
    "agraviosa": "a-gra-vio-sa",
    "agravioso": "a-gra-vio-so",
    "agraz": "a-graz",
    "agrazada": "a-gra-za-da",
    "agrazar": "a-gra-zar",
    "agrazón": "a-gra-zón",
    "agre": "a-gre",
    "agrear": "a-gre-ar",
    "agrecillo": "a-gre-ci-llo",
    "agredida": "a-gre-di-da",
    "agredido": "a-gre-di-do",
    "agredir": "a-gre-dir",
    "agregación": "a-gre-ga-ción",
    "agregada": "a-gre-ga-da",
    "agregado": "a-gre-ga-do",
    "agregaduría": "a-gre-ga-du-rí-a",
    "agregar": "a-gre-gar",
    "agregativa": "a-gre-ga-ti-va",
    "agregativo": "a-gre-ga-ti-vo",
    "agremán": "a-gre-mán",
    "agremiación": "a-gre-mia-ción",
    "agremiar": "a-gre-miar",
    "agresión": "a-gre-sión",
    "agresiva": "a-gre-si-va",
    "agresivamente": "a-gre-si-va-men-te",
    "agresividad": "a-gre-si-vi-dad",
    "agresivo": "a-gre-si-vo",
    "agresor": "a-gre-sor",
    "agresora": "a-gre-so-ra",
    "agreste": "a-gres-te",
    "agreta": "a-gre-ta",
    "agreza": "a-gre-za",
    "agria": "a-gria",
    "agriado": "a-gria-do",
    "agriamente": "a-gria-men-te",
    "agriar": "a-griar",
    "agriaz": "a-griaz",
    "agrícola": "a-grí-co-la",
    "agricultor": "a-gri-cul-tor",
    "agricultora": "a-gri-cul-to-ra",
    "agricultura": "a-gri-cul-tu-ra",
    "agridulce": "a-gri-dul-ce",
    "agridulcemente": "a-gri-dul-ce-men-te",
    "agriera": "a-grie-ra",
    "agrietado": "a-grie-ta-do",
    "agrietamiento": "a-grie-ta-mien-to",
    "agrietar": "a-grie-tar",
    "agrifada": "a-gri-fa-da",
    "agrifolio": "a-gri-fo-lio",
    "agrilla": "a-gri-lla",
    "agrillar": "a-gri-llar",
    "agrillarse": "a-gri-llar-se",
    "agrimensor": "a-gri-men-sor",
    "agrimensora": "a-gri-men-so-ra",
    "agrimensura": "a-gri-men-su-ra",
    "agrimonia": "a-gri-mo-nia",
    "agringado": "a-grin-ga-do",
    "agringar": "a-grin-gar",
    "agrio": "a-grio",
    "agriodulce": "a-grio-dul-ce",
    "agrión": "a-grión",
    "agriotipo": "a-grio-ti-po",
    "agripalma": "a-gri-pal-ma",
    "agripar": "a-gri-par",
    "agrisada": "a-gri-sa-da",
    "agrisado": "a-gri-sa-do",
    "agrisar": "a-gri-sar",
    "agrisetada": "a-gri-se-ta-da",
    "agrisetado": "a-gri-se-ta-do",
    "agro": "a-gro",
    "agroalimentación": "a-gro-a-li-men-ta-ción",
    "agroalimentario": "a-gro-a-li-men-ta-rio",
    "agroforestal": "a-gro-fo-res-tal",
    "agrogenética": "a-gro-ge-né-ti-ca",
    "agroindustria": "a-groin-dus-tria",
    "agroindustrial": "a-groin-dus-trial",
    "agrología": "a-gro-lo-gí-a",
    "agrológica": "a-gro-ló-gi-ca",
    "agrológico": "a-gro-ló-gi-co",
    "agrónoma": "a-gró-no-ma",
    "agronomía": "a-gro-no-mí-a",
    "agronómica": "a-gro-nó-mi-ca",
    "agronómico": "a-gro-nó-mi-co",
    "agrónomo": "a-gró-no-mo",
    "agropecuaria": "a-gro-pe-cua-ria",
    "agropecuario": "a-gro-pe-cua-rio",
    "agroquímica": "a-gro-quí-mi-ca",
    "agroquímico": "a-gro-quí-mi-co",
    "agror": "a-gror",
    "agroturismo": "a-gro-tu-ris-mo",
    "agrumar": "a-gru-mar",
    "agrupable": "a-gru-pa-ble",
    "agrupación": "a-gru-pa-ción",
    "agrupador": "a-gru-pa-dor",
    "agrupadora": "a-gru-pa-do-ra",
    "agrupamiento": "a-gru-pa-mien-to",
    "agrupar": "a-gru-par",
    "agrura": "a-gru-ra",
    "agua": "a-gua",
    "aguacal": "a-gua-cal",
    "aguacatal": "a-gua-ca-tal",
    "aguacate": "a-gua-ca-te",
    "aguacateca": "a-gua-ca-te-ca",
    "aguacatero": "a-gua-ca-te-ro",
    "aguacatillo": "a-gua-ca-ti-llo",
    "aguacatón": "a-gua-ca-tón",
    "aguacero": "a-gua-ce-ro",
    "aguacha": "a-gua-cha",
    "aguachacha": "a-gua-cha-cha",
    "aguachar": "a-gua-char",
    "aguachas": "a-gua-chas",
    "aguachenta": "a-gua-chen-ta",
    "aguachento": "a-gua-chen-to",
    "aguachile": "a-gua-chi-le",
    "aguachinar": "a-gua-chi-nar",
    "aguachinoso": "a-gua-chi-no-so",
    "aguachirle": "a-gua-chir-le",
    "aguacibera": "a-gua-ci-be-ra",
    "aguacil": "a-gua-cil",
    "aguada": "a-gua-da",
    "aguadar": "a-gua-dar",
    "aguadera": "a-gua-de-ra",
    "aguaderas": "a-gua-de-ras",
    "aguadero": "a-gua-de-ro",
    "aguadija": "a-gua-di-ja",
    "aguadilla": "a-gua-di-lla",
    "aguadillana": "a-gua-di-lla-na",
    "aguadillano": "a-gua-di-lla-no",
    "aguado": "a-gua-do",
    "aguadón": "a-gua-dón",
    "aguador": "a-gua-dor",
    "aguadora": "a-gua-do-ra",
    "aguaducho": "a-gua-du-cho",
    "aguadulce": "a-gua-dul-ce",
    "aguadura": "a-gua-du-ra",
    "aguafiestas": "a-gua-fies-tas",
    "aguafuerte": "a-gua-fuer-te",
    "aguafuertista": "a-gua-fuer-tis-ta",
    "aguagoma": "a-gua-go-ma",
    "aguaí": "a-gua-í",
    "aguaitacaimán": "a-guai-ta-cai-mán",
    "aguaitacamino": "a-guai-ta-ca-mi-no",
    "aguaitador": "a-guai-ta-dor",
    "aguaitadora": "a-guai-ta-do-ra",
    "aguaitamiento": "a-guai-ta-mien-to",
    "aguaitar": "a-guai-tar",
    "aguaite": "a-guai-te",
    "aguajaque": "a-gua-ja-que",
    "aguaje": "a-gua-je",
    "aguajera": "a-gua-je-ra",
    "aguajero": "a-gua-je-ro",
    "aguají": "a-gua-jí",
    "aguajirado": "a-gua-ji-ra-do",
    "agualate": "a-gua-la-te",
    "agualoja": "a-gua-lo-ja",
    "agualotal": "a-gua-lo-tal",
    "agualotoso": "a-gua-lo-to-so",
    "aguamala": "a-gua-ma-la",
    "aguamanil": "a-gua-ma-nil",
    "aguamanos": "a-gua-ma-nos",
    "aguamar": "a-gua-mar",
    "aguamarina": "a-gua-ma-ri-na",
    "aguambado": "a-guam-ba-do",
    "aguamelada": "a-gua-me-la-da",
    "aguamelado": "a-gua-me-la-do",
    "aguamiel": "a-gua-miel",
    "aguamielera": "a-gua-mie-le-ra",
    "aguamielero": "a-gua-mie-le-ro",
    "aguanal": "a-gua-nal",
    "aguanieve": "a-gua-nie-ve",
    "aguanieves": "a-gua-nie-ves",
    "aguañón": "a-gua-ñón",
    "aguanosa": "a-gua-no-sa",
    "aguanosidad": "a-gua-no-si-dad",
    "aguanoso": "a-gua-no-so",
    "aguantable": "a-guan-ta-ble",
    "aguantada": "a-guan-ta-da",
    "aguantaderas": "a-guan-ta-de-ras",
    "aguantadero": "a-guan-ta-de-ro",
    "aguantador": "a-guan-ta-dor",
    "aguantar": "a-guan-tar",
    "aguante": "a-guan-te",
    "aguantón": "a-guan-tón",
    "aguantona": "a-guan-to-na",
    "aguapanela": "a-gua-pa-ne-la",
    "aguapé": "a-gua-pé",
    "aguapey": "a-gua-pey",
    "aguapié": "a-gua-pié",
    "aguar": "a-guar",
    "aguará": "a-gua-rá",
    "aguaraibá": "a-gua-rai-bá",
    "aguarapar": "a-gua-ra-par",
    "aguardada": "a-guar-da-da",
    "aguardadero": "a-guar-da-de-ro",
    "aguardador": "a-guar-da-dor",
    "aguardamiento": "a-guar-da-mien-to",
    "aguardar": "a-guar-dar",
    "aguardentera": "a-guar-den-te-ra",
    "aguardentería": "a-guar-den-te-rí-a",
    "aguardentero": "a-guar-den-te-ro",
    "aguardentosa": "a-guar-den-to-sa",
    "aguardentoso": "a-guar-den-to-so",
    "aguardiente": "a-guar-dien-te",
    "aguardillada": "a-guar-di-lla-da",
    "aguardillado": "a-guar-di-lla-do",
    "aguardo": "a-guar-do",
    "aguaribay": "a-gua-ri-bay",
    "aguarico": "a-gua-ri-co",
    "aguarrada": "a-gua-rra-da",
    "aguarrás": "a-gua-rrás",
    "aguasada": "a-gua-sa-da",
    "aguasado": "a-gua-sa-do",
    "aguasal": "a-gua-sal",
    "aguascalentense": "a-guas-ca-len-ten-se",
    "aguasol": "a-gua-sol",
    "aguatar": "a-gua-tar",
    "aguate": "a-gua-te",
    "aguatera": "a-gua-te-ra",
    "aguatero": "a-gua-te-ro",
    "aguatinta": "a-gua-tin-ta",
    "aguatocha": "a-gua-to-cha",
    "aguatocho": "a-gua-to-cho",
    "aguaturma": "a-gua-tur-ma",
    "aguaucle": "a-guau-cle",
    "aguautle": "a-guau-tle",
    "aguaverde": "a-gua-ver-de",
    "aguaviento": "a-gua-vien-to",
    "aguavientos": "a-gua-vien-tos",
    "aguavilla": "a-gua-vi-lla",
    "aguaviva": "a-gua-vi-va",
    "aguay": "a-guay",
    "aguayo": "a-gua-yo",
    "aguayón": "a-gua-yón",
    "aguaza": "a-gua-za",
    "aguazal": "a-gua-zal",
    "aguazar": "a-gua-zar",
    "aguazo": "a-gua-zo",
    "aguazol": "a-gua-zol",
    "aguazosa": "a-gua-zo-sa",
    "aguazoso": "a-gua-zo-so",
    "aguazul": "a-gua-zul",
    "aguazur": "a-gua-zur",
    "agucia": "a-gu-cia",
    "aguciar": "a-gu-ciar",
    "aguciosa": "a-gu-cio-sa",
    "agucioso": "a-gu-cio-so",
    "aguda": "a-gu-da",
    "agudamente": "a-gu-da-men-te",
    "agudez": "a-gu-dez",
    "agudeza": "a-gu-de-za",
    "agudización": "a-gu-di-za-ción",
    "agudizamiento": "a-gu-di-za-mien-to",
    "agudizar": "a-gu-di-zar",
    "agudo": "a-gu-do",
    "águedas": "á-gue-das",
    "aguedita": "a-gue-di-ta",
    "agüela": "a-güe-la",
    "agüera": "a-güe-ra",
    "agüerar": "a-güe-rar",
    "agüería": "a-güe-rí-a",
    "agüero": "a-güe-ro",
    "aguerrida": "a-gue-rri-da",
    "aguerrido": "a-gue-rri-do",
    "aguerrir": "a-gue-rrir",
    "agüevado": "a-güe-va-do",
    "agüevar": "a-güe-var",
    "aguija": "a-gui-ja",
    "aguijada": "a-gui-ja-da",
    "aguijadera": "a-gui-ja-de-ra",
    "aguijador": "a-gui-ja-dor",
    "aguijadora": "a-gui-ja-do-ra",
    "aguijadura": "a-gui-ja-du-ra",
    "aguijar": "a-gui-jar",
    "aguijón": "a-gui-jón",
    "aguijonada": "a-gui-jo-na-da",
    "aguijonamiento": "a-gui-jo-na-mien-to",
    "aguijonar": "a-gui-jo-nar",
    "aguijonazo": "a-gui-jo-na-zo",
    "aguijoneador": "a-gui-jo-ne-a-dor",
    "aguijoneadora": "a-gui-jo-ne-a-do-ra",
    "aguijoneamiento": "a-gui-jo-ne-a-mien-to",
    "aguijonear": "a-gui-jo-ne-ar",
    "aguijoneo": "a-gui-jo-ne-o",
    "águila": "á-gui-la",
    "aguilando": "a-gui-lan-do",
    "aguileña": "a-gui-le-ña",
    "aguileño": "a-gui-le-ño",
    "aguilera": "a-gui-le-ra",
    "aguililla": "a-gui-li-lla",
    "agüilla": "a-güi-lla",
    "aguilón": "a-gui-lón",
    "aguilonia": "a-gui-lo-nia",
    "aguilucho": "a-gui-lu-cho",
    "aguín": "a-guín",
    "aguinaldo": "a-gui-nal-do",
    "agüío": "a-güí-o",
    "aguisada": "a-gui-sa-da",
    "aguisado": "a-gui-sa-do",
    "aguisamiento": "a-gui-sa-mien-to",
    "aguisar": "a-gui-sar",
    "agüista": "a-güis-ta",
    "agüita": "a-güi-ta",
    "agüitar": "a-güi-tar",
    "agüite": "a-güi-te",
    "aguizgar": "a-guiz-gar",
    "agüizote": "a-güi-zo-te",
    "aguja": "a-gu-ja",
    "agujadera": "a-gu-ja-de-ra",
    "agujal": "a-gu-jal",
    "agujar": "a-gu-jar",
    "agujazo": "a-gu-ja-zo",
    "agujerar": "a-gu-je-rar",
    "agujerear": "a-gu-je-re-ar",
    "agujero": "a-gu-je-ro",
    "agujeta": "a-gu-je-ta",
    "agujetera": "a-gu-je-te-ra",
    "agujetería": "a-gu-je-te-rí-a",
    "agujetero": "a-gu-je-te-ro",
    "agujón": "a-gu-jón",
    "agujuela": "a-gu-jue-la",
    "aguosa": "a-guo-sa",
    "aguosidad": "a-guo-si-dad",
    "aguoso": "a-guo-so",
    "agur": "a-gur",
    "agusanamiento": "a-gu-sa-na-mien-to",
    "agusanar": "a-gu-sa-nar",
    "agusanarse": "a-gu-sa-nar-se",
    "agustín": "a-gus-tín",
    "agustina": "a-gus-ti-na",
    "agustiniana": "a-gus-ti-nia-na",
    "agustinianamente": "a-gus-ti-nia-na-men-te",
    "agustinianismo": "a-gus-ti-nia-nis-mo",
    "agustiniano": "a-gus-ti-nia-no",
    "agustinismo": "a-gus-ti-nis-mo",
    "agustino": "a-gus-ti-no",
    "agutí": "a-gu-tí",
    "aguzada": "a-gu-za-da",
    "aguzadera": "a-gu-za-de-ra",
    "aguzadero": "a-gu-za-de-ro",
    "aguzado": "a-gu-za-do",
    "aguzador": "a-gu-za-dor",
    "aguzadora": "a-gu-za-do-ra",
    "aguzadura": "a-gu-za-du-ra",
    "aguzamiento": "a-gu-za-mien-to",
    "aguzanieves": "a-gu-za-nie-ves",
    "aguzar": "a-gu-zar",
    "aguzo": "a-gu-zo",
    "aguzonazo": "a-gu-zo-na-zo",
    "ahacado": "a-ha-ca-do",
    "ahajar": "a-ha-jar",
    "ahé": "a-hé",
    "ahebrada": "a-he-bra-da",
    "ahebrado": "a-he-bra-do",
    "ahechadero": "a-he-cha-de-ro",
    "ahechador": "a-he-cha-dor",
    "ahechadora": "a-he-cha-do-ra",
    "ahechadura": "a-he-cha-du-ra",
    "ahechar": "a-he-char",
    "ahecho": "a-he-cho",
    "ahelear": "a-he-le-ar",
    "ahelgada": "a-hel-ga-da",
    "ahelgado": "a-hel-ga-do",
    "ahembrada": "a-hem-bra-da",
    "ahembrado": "a-hem-bra-do",
    "aherir": "a-he-rir",
    "ahermanar": "a-her-ma-nar",
    "aherrojamiento": "a-he-rro-ja-mien-to",
    "aherrojar": "a-he-rro-jar",
    "aherrumbrar": "a-he-rrum-brar",
    "aherventar": "a-her-ven-tar",
    "ahervoradamente": "a-her-vo-ra-da-men-te",
    "ahervorar": "a-her-vo-rar",
    "ahervorarse": "a-her-vo-rar-se",
    "ahetrar": "a-he-trar",
    "ahí": "a-hí",
    "ahidalgada": "ahi-dal-ga-da",
    "ahidalgado": "ahi-dal-ga-do",
    "ahidalgar": "ahi-dal-gar",
    "ahigadada": "ahi-ga-da-da",
    "ahigadado": "ahi-ga-da-do",
    "ahijada": "ahi-ja-da",
    "ahijadera": "ahi-ja-de-ra",
    "ahijadero": "ahi-ja-de-ro",
    "ahijado": "ahi-ja-do",
    "ahijador": "ahi-ja-dor",
    "ahijamiento": "ahi-ja-mien-to",
    "ahijar": "ahi-jar",
    "ahijuna": "ahi-ju-na",
    "ahilada": "ahi-la-da",
    "ahilado": "ahi-la-do",
    "ahilamiento": "ahi-la-mien-to",
    "ahilar": "ahi-lar",
    "ahílo": "a-hí-lo",
    "ahína": "a-hí-na",
    "ahincada": "ahin-ca-da",
    "ahincadamente": "ahin-ca-da-men-te",
    "ahincado": "ahin-ca-do",
    "ahincamiento": "ahin-ca-mien-to",
    "ahincanza": "ahin-can-za",
    "ahincar": "ahin-car",
    "ahínco": "a-hín-co",
    "ahinojar": "ahi-no-jar",
    "ahirmar": "ahir-mar",
    "ahíta": "a-hí-ta",
    "ahitamiento": "ahi-ta-mien-to",
    "ahitar": "ahi-tar",
    "ahitera": "ahi-te-ra",
    "ahíto": "a-hí-to",
    "ahó": "a-hó",
    "ahobachonada": "a-ho-ba-cho-na-da",
    "ahobachonado": "a-ho-ba-cho-na-do",
    "ahocicar": "a-ho-ci-car",
    "ahocinar": "a-ho-ci-nar",
    "ahocinarse": "a-ho-ci-nar-se",
    "ahogada": "a-ho-ga-da",
    "ahogadamente": "a-ho-ga-da-men-te",
    "ahogadera": "a-ho-ga-de-ra",
    "ahogadero": "a-ho-ga-de-ro",
    "ahogadilla": "a-ho-ga-di-lla",
    "ahogadiza": "a-ho-ga-di-za",
    "ahogadizo": "a-ho-ga-di-zo",
    "ahogado": "a-ho-ga-do",
    "ahogador": "a-ho-ga-dor",
    "ahogadora": "a-ho-ga-do-ra",
    "ahogamiento": "a-ho-ga-mien-to",
    "ahogar": "a-ho-gar",
    "ahogaviejas": "a-ho-ga-vie-jas",
    "ahogo": "a-ho-go",
    "ahoguío": "a-ho-guí-o",
    "ahombrada": "a-hom-bra-da",
    "ahombrado": "a-hom-bra-do",
    "ahondamiento": "a-hon-da-mien-to",
    "ahondar": "a-hon-dar",
    "ahonde": "a-hon-de",
    "ahora": "a-ho-ra",
    "ahorcable": "a-hor-ca-ble",
    "ahorcada": "a-hor-ca-da",
    "ahorcadiza": "a-hor-ca-di-za",
    "ahorcadizo": "a-hor-ca-di-zo",
    "ahorcado": "a-hor-ca-do",
    "ahorcadora": "a-hor-ca-do-ra",
    "ahorcadura": "a-hor-ca-du-ra",
    "ahorcajar": "a-hor-ca-jar",
    "ahorcajarse": "a-hor-ca-jar-se",
    "ahorcamiento": "a-hor-ca-mien-to",
    "ahorcaperros": "a-hor-ca-pe-rros",
    "ahorcar": "a-hor-car",
    "ahorita": "a-ho-ri-ta",
    "ahoritica": "a-ho-ri-ti-ca",
    "ahoritita": "a-ho-ri-ti-ta",
    "ahormar": "a-hor-mar",
    "ahornagamiento": "a-hor-na-ga-mien-to",
    "ahornagar": "a-hor-na-gar",
    "ahornagarse": "a-hor-na-gar-se",
    "ahornar": "a-hor-nar",
    "ahorquillada": "a-hor-qui-lla-da",
    "ahorquillado": "a-hor-qui-lla-do",
    "ahorquillar": "a-hor-qui-llar",
    "ahorrada": "a-ho-rra-da",
    "ahorradamente": "a-ho-rra-da-men-te",
    "ahorrado": "a-ho-rra-do",
    "ahorrador": "a-ho-rra-dor",
    "ahorradora": "a-ho-rra-do-ra",
    "ahorramiento": "a-ho-rra-mien-to",
    "ahorrar": "a-ho-rrar",
    "ahorrativa": "a-ho-rra-ti-va",
    "ahorrativo": "a-ho-rra-ti-vo",
    "ahorría": "a-ho-rrí-a",
    "ahorrista": "a-ho-rris-ta",
    "ahorro": "a-ho-rro",
    "ahorroso": "a-ho-rro-so",
    "ahotada": "a-ho-ta-da",
    "ahotado": "a-ho-ta-do",
    "ahotar": "a-ho-tar",
    "ahotas": "a-ho-tas",
    "ahoyadura": "a-ho-ya-du-ra",
    "ahoyar": "a-ho-yar",
    "ahuachapaneca": "a-hua-cha-pa-ne-ca",
    "ahuachapaneco": "a-hua-cha-pa-ne-co",
    "ahuatar": "a-hua-tar",
    "ahuate": "a-hua-te",
    "ahuautle": "a-huau-tle",
    "ahuchador": "ahu-cha-dor",
    "ahuchadora": "ahu-cha-do-ra",
    "ahuchar": "ahu-char",
    "ahuchear": "ahu-che-ar",
    "ahucheo": "ahu-che-o",
    "ahuciar": "ahu-ciar",
    "ahuecado": "a-hue-ca-do",
    "ahuecador": "a-hue-ca-dor",
    "ahuecadora": "a-hue-ca-do-ra",
    "ahuecamiento": "a-hue-ca-mien-to",
    "ahuecar": "a-hue-car",
    "ahuejote": "a-hue-jo-te",
    "ahuesada": "a-hue-sa-da",
    "ahuesado": "a-hue-sa-do",
    "ahuesar": "a-hue-sar",
    "ahuevada": "a-hue-va-da",
    "ahuevado": "a-hue-va-do",
    "ahuevar": "a-hue-var",
    "ahuevazón": "a-hue-va-zón",
    "ahuevonar": "a-hue-vo-nar",
    "ahuevonear": "a-hue-vo-ne-ar",
    "ahuizotada": "a-hui-zo-ta-da",
    "ahuizotar": "a-hui-zo-tar",
    "ahuizote": "a-hui-zo-te",
    "ahulada": "ahu-la-da",
    "ahulado": "ahu-la-do",
    "ahumada": "ahu-ma-da",
    "ahumado": "ahu-ma-do",
    "ahumar": "ahu-mar",
    "ahurragada": "ahu-rra-ga-da",
    "ahurragado": "ahu-rra-ga-do",
    "ahusada": "ahu-sa-da",
    "ahusado": "ahu-sa-do",
    "ahusar": "ahu-sar",
    "ahuyama": "ahu-ya-ma",
    "ahuyentador": "ahu-yen-ta-dor",
    "ahuyentadora": "ahu-yen-ta-do-ra",
    "ahuyentar": "ahu-yen-tar",
    "aiguaste": "ai-guas-te",
    "aijada": "ai-ja-da",
    "aikido": "ai-ki-do",
    "aikidoka": "ai-ki-do-ka",
    "ailanto": "ai-lan-to",
    "aíllo": "a-í-llo",
    "aillu": "ai-llu",
    "aimara": "ai-ma-ra",
    "aína": "a-í-na",
    "aínas": "a-í-nas",
    "aindamáis": "ain-da-máis",
    "aindiada": "ain-dia-da",
    "aindiado": "ain-dia-do",
    "aindiar": "ain-diar",
    "aiquileña": "ai-qui-le-ña",
    "aiquileño": "ai-qui-le-ño",
    "airada": "ai-ra-da",
    "airadamente": "ai-ra-da-men-te",
    "airado": "ai-ra-do",
    "airamiento": "ai-ra-mien-to",
    "airampo": "ai-ram-po",
    "airar": "ai-rar",
    "airbag": "air-bag",
    "airbus": "air-bus",
    "aire": "ai-re",
    "aireación": "ai-re-a-ción",
    "aireamiento": "ai-re-a-mien-to",
    "airear": "ai-re-ar",
    "airedale": "ai-re-da-le",
    "aireo": "ai-re-o",
    "airón": "ai-rón",
    "aironazo": "ai-ro-na-zo",
    "airosa": "ai-ro-sa",
    "airosamente": "ai-ro-sa-men-te",
    "airosidad": "ai-ro-si-dad",
    "airoso": "ai-ro-so",
    "aisa": "ai-sa",
    "aisenina": "ai-se-ni-na",
    "aisenino": "ai-se-ni-no",
    "aislable": "ais-la-ble",
    "aislacionismo": "ais-la-cio-nis-mo",
    "aislacionista": "ais-la-cio-nis-ta",
    "aislada": "ais-la-da",
    "aisladamente": "ais-la-da-men-te",
    "aislado": "ais-la-do",
    "aislador": "ais-la-dor",
    "aisladora": "ais-la-do-ra",
    "aislamiento": "ais-la-mien-to",
    "aislante": "ais-lan-te",
    "aislar": "ais-lar",
    "aité": "ai-té",
    "aitinal": "ai-ti-nal",
    "aizcolari": "aiz-co-la-ri",
    "aizoácea": "ai-zo-á-ce-a",
    "aizoáceo": "ai-zo-á-ce-o",
    "aja": "a-ja",
    "ajá": "a-já",
    "ajabeba": "a-ja-be-ba",
    "ajacho": "a-ja-cho",
    "ajada": "a-ja-da",
    "ajado": "a-ja-do",
    "ajadura": "a-ja-du-ra",
    "ajajá": "a-ja-já",
    "ajajay": "a-ja-jay",
    "ajambado": "a-jam-ba-do",
    "ajamiento": "a-ja-mien-to",
    "ajamonado": "a-ja-mo-na-do",
    "ajamonar": "a-ja-mo-nar",
    "ajamonarse": "a-ja-mo-nar-se",
    "ajango": "a-jan-go",
    "ajaqueca": "a-ja-que-ca",
    "ajaquecar": "a-ja-que-car",
    "ajaquecarse": "a-ja-que-car-se",
    "ajaquefa": "a-ja-que-fa",
    "ajar": "a-jar",
    "ajaraca": "a-ja-ra-ca",
    "ajaracado": "a-ja-ra-ca-do",
    "ajarafe": "a-ja-ra-fe",
    "ajardinado": "a-jar-di-na-do",
    "ajardinamiento": "a-jar-di-na-mien-to",
    "ajardinar": "a-jar-di-nar",
    "ajaspajas": "a-jas-pa-jas",
    "aje": "a-je",
    "ajea": "a-je-a",
    "ajear": "a-je-ar",
    "ajebe": "a-je-be",
    "ajedrea": "a-je-dre-a",
    "ajedrecista": "a-je-dre-cis-ta",
    "ajedrecística": "a-je-dre-cís-ti-ca",
    "ajedrecístico": "a-je-dre-cís-ti-co",
    "ajedrez": "a-je-drez",
    "ajedrezada": "a-je-dre-za-da",
    "ajedrezado": "a-je-dre-za-do",
    "ajena": "a-je-na",
    "ajenabe": "a-je-na-be",
    "ajenable": "a-je-na-ble",
    "ajenabo": "a-je-na-bo",
    "ajenación": "a-je-na-ción",
    "ajenador": "a-je-na-dor",
    "ajenadora": "a-je-na-do-ra",
    "ajenamiento": "a-je-na-mien-to",
    "ajenar": "a-je-nar",
    "ajengibre": "a-jen-gi-bre",
    "ajenidad": "a-je-ni-dad",
    "ajenjo": "a-jen-jo",
    "ajeno": "a-je-no",
    "ajenuz": "a-je-nuz",
    "ajeo": "a-je-o",
    "ajera": "a-je-ra",
    "ajerezado": "a-je-re-za-do",
    "ajero": "a-je-ro",
    "ajete": "a-je-te",
    "ajetreadamente": "a-je-tre-a-da-men-te",
    "ajetreado": "a-je-tre-a-do",
    "ajetrear": "a-je-tre-ar",
    "ajetreo": "a-je-tre-o",
    "ají": "a-jí",
    "ajiaceite": "a-jia-cei-te",
    "ajiaco": "a-jia-co",
    "ajicera": "a-ji-ce-ra",
    "ajicero": "a-ji-ce-ro",
    "ajicola": "a-ji-co-la",
    "ajicomino": "a-ji-co-mi-no",
    "ajicuervo": "a-ji-cuer-vo",
    "ajigolón": "a-ji-go-lón",
    "ajilar": "a-ji-lar",
    "ajilimoje": "a-ji-li-mo-je",
    "ajilimójili": "a-ji-li-mó-ji-li",
    "ajillo": "a-ji-llo",
    "ajimez": "a-ji-mez",
    "ajimezado": "a-ji-me-za-do",
    "ajipa": "a-ji-pa",
    "ajipuerro": "a-ji-pue-rro",
    "ajironar": "a-ji-ro-nar",
    "ajiseco": "a-ji-se-co",
    "ajizal": "a-ji-zal",
    "ajizar": "a-ji-zar",
    "ajo": "a-jo",
    "ajó": "a-jó",
    "ajoaceite": "a-jo-a-cei-te",
    "ajoarriero": "a-jo-a-rrie-ro",
    "ajobar": "a-jo-bar",
    "ajobera": "a-jo-be-ra",
    "ajobero": "a-jo-be-ro",
    "ajobilla": "a-jo-bi-lla",
    "ajoblanco": "a-jo-blan-co",
    "ajobo": "a-jo-bo",
    "ajochar": "a-jo-char",
    "ajofaina": "a-jo-fai-na",
    "ajolín": "a-jo-lín",
    "ajolio": "a-jo-lio",
    "ajolotado": "a-jo-lo-ta-do",
    "ajolote": "a-jo-lo-te",
    "ajomate": "a-jo-ma-te",
    "ajonje": "a-jon-je",
    "ajonjear": "a-jon-je-ar",
    "ajonjera": "a-jon-je-ra",
    "ajonjero": "a-jon-je-ro",
    "ajonjo": "a-jon-jo",
    "ajonjolí": "a-jon-jo-lí",
    "ajonuez": "a-jo-nuez",
    "ajoqueso": "a-jo-que-so",
    "ajorar": "a-jo-rar",
    "ajorca": "a-jor-ca",
    "ajornalar": "a-jor-na-lar",
    "ajoro": "a-jo-ro",
    "ajorrar": "a-jo-rrar",
    "ajorro": "a-jo-rro",
    "ajotar": "a-jo-tar",
    "ajote": "a-jo-te",
    "ajotrino": "a-jo-tri-no",
    "ajuagas": "a-jua-gas",
    "ajuanetada": "a-jua-ne-ta-da",
    "ajuanetado": "a-jua-ne-ta-do",
    "ajuar": "a-juar",
    "ajuarar": "a-jua-rar",
    "ajudiada": "a-ju-dia-da",
    "ajudiado": "a-ju-dia-do",
    "ajuglarada": "a-ju-gla-ra-da",
    "ajuglarado": "a-ju-gla-ra-do",
    "ajuglarar": "a-ju-gla-rar",
    "ajuiciada": "a-jui-cia-da",
    "ajuiciado": "a-jui-cia-do",
    "ajuiciar": "a-jui-ciar",
    "ajumar": "a-ju-mar",
    "ajuna": "a-ju-na",
    "ajuno": "a-ju-no",
    "ajuntamiento": "a-jun-ta-mien-to",
    "ajuntar": "a-jun-tar",
    "ajustable": "a-jus-ta-ble",
    "ajustada": "a-jus-ta-da",
    "ajustadamente": "a-jus-ta-da-men-te",
    "ajustado": "a-jus-ta-do",
    "ajustador": "a-jus-ta-dor",
    "ajustadora": "a-jus-ta-do-ra",
    "ajustamiento": "a-jus-ta-mien-to",
    "ajustar": "a-jus-tar",
    "ajuste": "a-jus-te",
    "ajustera": "a-jus-te-ra",
    "ajustero": "a-jus-te-ro",
    "ajusticiada": "a-jus-ti-cia-da",
    "ajusticiado": "a-jus-ti-cia-do",
    "ajusticiamiento": "a-jus-ti-cia-mien-to",
    "ajusticiar": "a-jus-ti-ciar",
    "ajustón": "a-jus-tón",
    "akalché": "a-kal-ché",
    "ala": "a-la",
    "alá": "a-lá",
    "alabable": "a-la-ba-ble",
    "alabado": "a-la-ba-do",
    "alabador": "a-la-ba-dor",
    "alabadora": "a-la-ba-do-ra",
    "alabamiento": "a-la-ba-mien-to",
    "alabancera": "a-la-ban-ce-ra",
    "alabancero": "a-la-ban-ce-ro",
    "alabancia": "a-la-ban-cia",
    "alabanciosa": "a-la-ban-cio-sa",
    "alabancioso": "a-la-ban-cio-so",
    "alabandina": "a-la-ban-di-na",
    "alabanza": "a-la-ban-za",
    "alabar": "a-la-bar",
    "alabarda": "a-la-bar-da",
    "alabardada": "a-la-bar-da-da",
    "alabardado": "a-la-bar-da-do",
    "alabardazo": "a-la-bar-da-zo",
    "alabardero": "a-la-bar-de-ro",
    "alabastrada": "a-la-bas-tra-da",
    "alabastrado": "a-la-bas-tra-do",
    "alabastrina": "a-la-bas-tri-na",
    "alabastrino": "a-la-bas-tri-no",
    "alabastrita": "a-la-bas-tri-ta",
    "alabastrites": "a-la-bas-tri-tes",
    "alabastro": "a-la-bas-tro",
    "álabe": "á-la-be",
    "alabeada": "a-la-be-a-da",
    "alabeado": "a-la-be-a-do",
    "alabear": "a-la-be-ar",
    "alabeo": "a-la-be-o",
    "alabiada": "a-la-bia-da",
    "alabiado": "a-la-bia-do",
    "alabradorado": "a-la-bra-do-ra-do",
    "alacaluf": "a-la-ca-luf",
    "alacalufe": "a-la-ca-lu-fe",
    "alacate": "a-la-ca-te",
    "alacayo": "a-la-ca-yo",
    "alacayuela": "a-la-ca-yue-la",
    "alacena": "a-la-ce-na",
    "alacet": "a-la-cet",
    "alacha": "a-la-cha",
    "alache": "a-la-che",
    "alaciar": "a-la-ciar",
    "alaciarse": "a-la-ciar-se",
    "alaco": "a-la-co",
    "alacrán": "a-la-crán",
    "alacranada": "a-la-cra-na-da",
    "alacranado": "a-la-cra-na-do",
    "alacrancillo": "a-la-cran-ci-llo",
    "alacranear": "a-la-cra-ne-ar",
    "alacranera": "a-la-cra-ne-ra",
    "alacranero": "a-la-cra-ne-ro",
    "alacre": "a-la-cre",
    "alacridad": "a-la-cri-dad",
    "alada": "a-la-da",
    "aladar": "a-la-dar",
    "aladierna": "a-la-dier-na",
    "aladierno": "a-la-dier-no",
    "alado": "a-la-do",
    "aladrada": "a-la-dra-da",
    "aladrar": "a-la-drar",
    "aladrero": "a-la-dre-ro",
    "aladro": "a-la-dro",
    "aladroque": "a-la-dro-que",
    "alafa": "a-la-fa",
    "alafia": "a-la-fia",
    "alafre": "a-la-fre",
    "álaga": "á-la-ga",
    "alagadiza": "a-la-ga-di-za",
    "alagadizo": "a-la-ga-di-zo",
    "alagar": "a-la-gar",
    "alagartada": "a-la-gar-ta-da",
    "alagartado": "a-la-gar-ta-do",
    "alagartar": "a-la-gar-tar",
    "alagartarse": "a-la-gar-tar-se",
    "alaguna": "a-la-gu-na",
    "alahílca": "a-la-híl-ca",
    "alairito": "a-lai-ri-to",
    "alajor": "a-la-jor",
    "alajú": "a-la-jú",
    "alajuelense": "a-la-jue-len-se",
    "alalá": "a-la-lá",
    "álala": "á-la-la",
    "alaláu": "a-la-láu",
    "alalay": "a-la-lay",
    "alalia": "a-la-lia",
    "alalimón": "a-la-li-món",
    "álalo": "á-la-lo",
    "alama": "a-la-ma",
    "alamar": "a-la-mar",
    "alámbar": "a-lám-bar",
    "alambicada": "a-lam-bi-ca-da",
    "alambicado": "a-lam-bi-ca-do",
    "alambicamiento": "a-lam-bi-ca-mien-to",
    "alambicar": "a-lam-bi-car",
    "alambique": "a-lam-bi-que",
    "alambiquera": "a-lam-bi-que-ra",
    "alambiquero": "a-lam-bi-que-ro",
    "alambor": "a-lam-bor",
    "alamborada": "a-lam-bo-ra-da",
    "alamborado": "a-lam-bo-ra-do",
    "alambrada": "a-lam-bra-da",
    "alambrado": "a-lam-bra-do",
    "alambrar": "a-lam-brar",
    "alambre": "a-lam-bre",
    "alambrear": "a-lam-bre-ar",
    "alambrera": "a-lam-bre-ra",
    "alambrilla": "a-lam-bri-lla",
    "alambrista": "a-lam-bris-ta",
    "alameda": "a-la-me-da",
    "alamín": "a-la-mín",
    "alamina": "a-la-mi-na",
    "alaminazgo": "a-la-mi-naz-go",
    "alamirré": "a-la-mi-rré",
    "álamo": "á-la-mo",
    "alampar": "a-lam-par",
    "alamud": "a-la-mud",
    "alán": "a-lán",
    "alana": "a-la-na",
    "alanceador": "a-lan-ce-a-dor",
    "alanceadora": "a-lan-ce-a-do-ra",
    "alanceamiento": "a-lan-ce-a-mien-to",
    "alancear": "a-lan-ce-ar",
    "alandrear": "a-lan-dre-ar",
    "alandrearse": "a-lan-dre-ar-se",
    "alangiácea": "a-lan-giá-ce-a",
    "alangiáceo": "a-lan-giá-ce-o",
    "alangiea": "a-lan-gie-a",
    "alangieo": "a-lan-gie-o",
    "alano": "a-la-no",
    "alantoideo": "a-lan-toi-de-o",
    "alantoides": "a-lan-toi-des",
    "alantoína": "a-lan-to-í-na",
    "alanzar": "a-lan-zar",
    "alaqueca": "a-la-que-ca",
    "alaqueque": "a-la-que-que",
    "alar": "a-lar",
    "alárabe": "a-lá-ra-be",
    "alaraca": "a-la-ra-ca",
    "alaraco": "a-la-ra-co",
    "alarbe": "a-lar-be",
    "alarconiana": "a-lar-co-nia-na",
    "alarconiano": "a-lar-co-nia-no",
    "alarde": "a-lar-de",
    "alardear": "a-lar-de-ar",
    "alardosa": "a-lar-do-sa",
    "alardoso": "a-lar-do-so",
    "alargable": "a-lar-ga-ble",
    "alargadamente": "a-lar-ga-da-men-te",
    "alargadera": "a-lar-ga-de-ra",
    "alargado": "a-lar-ga-do",
    "alargador": "a-lar-ga-dor",
    "alargadora": "a-lar-ga-do-ra",
    "alárgama": "a-lár-ga-ma",
    "alargamiento": "a-lar-ga-mien-to",
    "alargar": "a-lar-gar",
    "alargas": "a-lar-gas",
    "alargue": "a-lar-gue",
    "alarguez": "a-lar-guez",
    "alaria": "a-la-ria",
    "alarida": "a-la-ri-da",
    "alaridar": "a-la-ri-dar",
    "alarido": "a-la-ri-do",
    "alarifazgo": "a-la-ri-faz-go",
    "alarife": "a-la-ri-fe",
    "alarije": "a-la-ri-je",
    "alarma": "a-lar-ma",
    "alarmador": "a-lar-ma-dor",
    "alarmadora": "a-lar-ma-do-ra",
    "alarmante": "a-lar-man-te",
    "alarmantemente": "a-lar-man-te-men-te",
    "alarmar": "a-lar-mar",
    "alármega": "a-lár-me-ga",
    "alarmismo": "a-lar-mis-mo",
    "alarmista": "a-lar-mis-ta",
    "alaroz": "a-la-roz",
    "alaroza": "a-la-ro-za",
    "alasita": "a-la-si-ta",
    "alaskeña": "a-las-ke-ña",
    "alaskeño": "a-las-ke-ño",
    "alasqueño": "a-las-que-ño",
    "alaste": "a-las-te",
    "alastoso": "a-las-to-so",
    "alastrar": "a-las-trar",
    "alatar": "a-la-tar",
    "alaterno": "a-la-ter-no",
    "alatés": "a-la-tés",
    "alatinada": "a-la-ti-na-da",
    "alatinadamente": "a-la-ti-na-da-men-te",
    "alatinado": "a-la-ti-na-do",
    "alatón": "a-la-tón",
    "alatonero": "a-la-to-ne-ro",
    "alatrón": "a-la-trón",
    "alauda": "a-lau-da",
    "alaude": "a-lau-de",
    "alauí": "a-lauí",
    "alauita": "a-laui-ta",
    "alauseña": "a-lau-se-ña",
    "alauseño": "a-lau-se-ño",
    "alavanco": "a-la-van-co",
    "alavense": "a-la-ven-se",
    "alavés": "a-la-vés",
    "alavesa": "a-la-ve-sa",
    "alazán": "a-la-zán",
    "alazana": "a-la-za-na",
    "alazano": "a-la-za-no",
    "alazo": "a-la-zo",
    "alazor": "a-la-zor",
    "alba": "al-ba",
    "albaca": "al-ba-ca",
    "albacara": "al-ba-ca-ra",
    "albacea": "al-ba-ce-a",
    "albaceato": "al-ba-ce-a-to",
    "albaceazgo": "al-ba-ce-az-go",
    "albaceteña": "al-ba-ce-te-ña",
    "albaceteño": "al-ba-ce-te-ño",
    "albacetense": "al-ba-ce-ten-se",
    "albacora": "al-ba-co-ra",
    "albacorón": "al-ba-co-rón",
    "albada": "al-ba-da",
    "albadena": "al-ba-de-na",
    "albahaca": "al-ba-ha-ca",
    "albahaquero": "al-ba-ha-que-ro",
    "albahaquilla": "al-ba-ha-qui-lla",
    "albahío": "al-ba-hí-o",
    "albaida": "al-bai-da",
    "albalá": "al-ba-lá",
    "albalaero": "al-ba-la-e-ro",
    "albana": "al-ba-na",
    "albanada": "al-ba-na-da",
    "albanado": "al-ba-na-do",
    "albañal": "al-ba-ñal",
    "albañalera": "al-ba-ña-le-ra",
    "albañalero": "al-ba-ña-le-ro",
    "albanar": "al-ba-nar",
    "albañar": "al-ba-ñar",
    "albando": "al-ban-do",
    "albañear": "al-ba-ñe-ar",
    "albanecar": "al-ba-ne-car",
    "albanega": "al-ba-ne-ga",
    "albañería": "al-ba-ñe-rí-a",
    "albanés": "al-ba-nés",
    "albanesa": "al-ba-ne-sa",
    "albañí": "al-ba-ñí",
    "albañil": "al-ba-ñil",
    "albañila": "al-ba-ñi-la",
    "albañilear": "al-ba-ñi-le-ar",
    "albañilería": "al-ba-ñi-le-rí-a",
    "albañir": "al-ba-ñir",
    "albano": "al-ba-no",
    "albaquía": "al-ba-quí-a",
    "albar": "al-bar",
    "albarán": "al-ba-rán",
    "albarazada": "al-ba-ra-za-da",
    "albarazado": "al-ba-ra-za-do",
    "albarazo": "al-ba-ra-zo",
    "albarca": "al-bar-ca",
    "albarcoque": "al-bar-co-que",
    "albarcoquero": "al-bar-co-que-ro",
    "albarda": "al-bar-da",
    "albardada": "al-bar-da-da",
    "albardado": "al-bar-da-do",
    "albardán": "al-bar-dán",
    "albardanería": "al-bar-da-ne-rí-a",
    "albardanía": "al-bar-da-ní-a",
    "albardar": "al-bar-dar",
    "albardear": "al-bar-de-ar",
    "albardela": "al-bar-de-la",
    "albardera": "al-bar-de-ra",
    "albardería": "al-bar-de-rí-a",
    "albardero": "al-bar-de-ro",
    "albardilla": "al-bar-di-lla",
    "albardín": "al-bar-dín",
    "albardinar": "al-bar-di-nar",
    "albardón": "al-bar-dón",
    "albardonería": "al-bar-do-ne-rí-a",
    "albardonero": "al-bar-do-ne-ro",
    "albarejo": "al-ba-re-jo",
    "albarelo": "al-ba-re-lo",
    "albareque": "al-ba-re-que",
    "albaricoque": "al-ba-ri-co-que",
    "albaricoquero": "al-ba-ri-co-que-ro",
    "albarigo": "al-ba-ri-go",
    "albarillo": "al-ba-ri-llo",
    "albarino": "al-ba-ri-no",
    "albariño": "al-ba-ri-ño",
    "albariza": "al-ba-ri-za",
    "albarizo": "al-ba-ri-zo",
    "albarrada": "al-ba-rra-da",
    "albarrán": "al-ba-rrán",
    "albarrana": "al-ba-rra-na",
    "albarránea": "al-ba-rrá-ne-a",
    "albarráneo": "al-ba-rrá-ne-o",
    "albarranía": "al-ba-rra-ní-a",
    "albarraniega": "al-ba-rra-nie-ga",
    "albarraniego": "al-ba-rra-nie-go",
    "albarranilla": "al-ba-rra-ni-lla",
    "albarraz": "al-ba-rraz",
    "albarrazada": "al-ba-rra-za-da",
    "albarrazado": "al-ba-rra-za-do",
    "albarsa": "al-bar-sa",
    "albatoza": "al-ba-to-za",
    "albatros": "al-ba-tros",
    "albayaldada": "al-ba-yal-da-da",
    "albayaldado": "al-ba-yal-da-do",
    "albayalde": "al-ba-yal-de",
    "albayana": "al-ba-ya-na",
    "albayano": "al-ba-ya-no",
    "albazana": "al-ba-za-na",
    "albazano": "al-ba-za-no",
    "albazo": "al-ba-zo",
    "albear": "al-be-ar",
    "albedo": "al-be-do",
    "albedriador": "al-be-dria-dor",
    "albedriadora": "al-be-dria-do-ra",
    "albedriar": "al-be-driar",
    "albedrío": "al-be-drí-o",
    "albéitar": "al-béi-tar",
    "albeitería": "al-bei-te-rí-a",
    "albeldadero": "al-bel-da-de-ro",
    "albeldar": "al-bel-dar",
    "albeldense": "al-bel-den-se",
    "albellanino": "al-be-lla-ni-no",
    "albellón": "al-be-llón",
    "albenda": "al-ben-da",
    "albendera": "al-ben-de-ra",
    "albengala": "al-ben-ga-la",
    "albéntola": "al-bén-to-la",
    "albeo": "al-be-o",
    "albera": "al-be-ra",
    "alberca": "al-ber-ca",
    "albérchiga": "al-bér-chi-ga",
    "alberchigal": "al-ber-chi-gal",
    "albérchigo": "al-bér-chi-go",
    "alberchiguero": "al-ber-chi-gue-ro",
    "albercoque": "al-ber-co-que",
    "albercoquero": "al-ber-co-que-ro",
    "albergada": "al-ber-ga-da",
    "albergador": "al-ber-ga-dor",
    "albergadora": "al-ber-ga-do-ra",
    "albergadura": "al-ber-ga-du-ra",
    "albergar": "al-ber-gar",
    "alberge": "al-ber-ge",
    "albergero": "al-ber-ge-ro",
    "albergo": "al-ber-go",
    "albergue": "al-ber-gue",
    "alberguera": "al-ber-gue-ra",
    "alberguería": "al-ber-gue-rí-a",
    "alberguero": "al-ber-gue-ro",
    "alberguista": "al-ber-guis-ta",
    "albericoque": "al-be-ri-co-que",
    "alberja": "al-ber-ja",
    "albero": "al-be-ro",
    "alberque": "al-ber-que",
    "alberquera": "al-ber-que-ra",
    "alberquero": "al-ber-que-ro",
    "albicante": "al-bi-can-te",
    "albiceleste": "al-bi-ce-les-te",
    "albigense": "al-bi-gen-se",
    "albihar": "al-bihar",
    "albilla": "al-bi-lla",
    "albillo": "al-bi-llo",
    "albín": "al-bín",
    "albina": "al-bi-na",
    "albinismo": "al-bi-nis-mo",
    "albino": "al-bi-no",
    "albita": "al-bi-ta",
    "albitana": "al-bi-ta-na",
    "albivioleta": "al-bi-vio-le-ta",
    "albo": "al-bo",
    "alboaire": "al-bo-ai-re",
    "albogón": "al-bo-gón",
    "albogue": "al-bo-gue",
    "alboguear": "al-bo-gue-ar",
    "alboguera": "al-bo-gue-ra",
    "alboguero": "al-bo-gue-ro",
    "alboheza": "al-bo-he-za",
    "albohol": "al-bo-hol",
    "albollón": "al-bo-llón",
    "albóndiga": "al-bón-di-ga",
    "albondiguilla": "al-bon-di-gui-lla",
    "alboquerón": "al-bo-que-rón",
    "albor": "al-bor",
    "alborada": "al-bo-ra-da",
    "albórbola": "al-bór-bo-la",
    "alboreada": "al-bo-re-a-da",
    "alborear": "al-bo-re-ar",
    "alborecer": "al-bo-re-cer",
    "alboreo": "al-bo-re-o",
    "alborga": "al-bor-ga",
    "albornía": "al-bor-ní-a",
    "alborno": "al-bor-no",
    "albornoz": "al-bor-noz",
    "alborocera": "al-bo-ro-ce-ra",
    "alboronía": "al-bo-ro-ní-a",
    "alboroque": "al-bo-ro-que",
    "alborotada": "al-bo-ro-ta-da",
    "alborotadamente": "al-bo-ro-ta-da-men-te",
    "alborotadiza": "al-bo-ro-ta-di-za",
    "alborotadizo": "al-bo-ro-ta-di-zo",
    "alborotado": "al-bo-ro-ta-do",
    "alborotador": "al-bo-ro-ta-dor",
    "alborotadora": "al-bo-ro-ta-do-ra",
    "alborotapueblos": "al-bo-ro-ta-pue-blos",
    "alborotar": "al-bo-ro-tar",
    "alborote": "al-bo-ro-te",
    "alborotera": "al-bo-ro-te-ra",
    "alborotero": "al-bo-ro-te-ro",
    "alborotista": "al-bo-ro-tis-ta",
    "alboroto": "al-bo-ro-to",
    "alborotosa": "al-bo-ro-to-sa",
    "alborotoso": "al-bo-ro-to-so",
    "alborozadamente": "al-bo-ro-za-da-men-te",
    "alborozado": "al-bo-ro-za-do",
    "alborozador": "al-bo-ro-za-dor",
    "alborozadora": "al-bo-ro-za-do-ra",
    "alborozamiento": "al-bo-ro-za-mien-to",
    "alborozar": "al-bo-ro-zar",
    "alborozo": "al-bo-ro-zo",
    "alborto": "al-bor-to",
    "alborzo": "al-bor-zo",
    "albotín": "al-bo-tín",
    "albricia": "al-bri-cia",
    "albriciar": "al-bri-ciar",
    "albricias": "al-bri-cias",
    "albudeca": "al-bu-de-ca",
    "albuérbola": "al-buér-bo-la",
    "albufera": "al-bu-fe-ra",
    "albugínea": "al-bu-gí-ne-a",
    "albugíneo": "al-bu-gí-ne-o",
    "albugo": "al-bu-go",
    "albuhera": "al-buhe-ra",
    "álbum": "ál-bum",
    "albumen": "al-bu-men",
    "albúmina": "al-bú-mi-na",
    "albuminada": "al-bu-mi-na-da",
    "albuminado": "al-bu-mi-na-do",
    "albuminar": "al-bu-mi-nar",
    "albuminoide": "al-bu-mi-noi-de",
    "albuminoidea": "al-bu-mi-noi-de-a",
    "albuminoideo": "al-bu-mi-noi-de-o",
    "albuminómetro": "al-bu-mi-nó-me-tro",
    "albuminosa": "al-bu-mi-no-sa",
    "albuminoso": "al-bu-mi-no-so",
    "albuminuria": "al-bu-mi-nu-ria",
    "albur": "al-bur",
    "albura": "al-bu-ra",
    "albureado": "al-bu-re-a-do",
    "albureador": "al-bu-re-a-dor",
    "albureadora": "al-bu-re-a-do-ra",
    "alburear": "al-bu-re-ar",
    "alburente": "al-bu-ren-te",
    "alburera": "al-bu-re-ra",
    "alburero": "al-bu-re-ro",
    "alburno": "al-bur-no",
    "alca": "al-ca",
    "alcabala": "al-ca-ba-la",
    "alcabalatoria": "al-ca-ba-la-to-ria",
    "alcabalatorio": "al-ca-ba-la-to-rio",
    "alcabalero": "al-ca-ba-le-ro",
    "alcabor": "al-ca-bor",
    "alcabota": "al-ca-bo-ta",
    "alcabtea": "al-cab-te-a",
    "alcabuz": "al-ca-buz",
    "alcacel": "al-ca-cel",
    "alcaceña": "al-ca-ce-ña",
    "alcacer": "al-ca-cer",
    "alcachofa": "al-ca-cho-fa",
    "alcachofada": "al-ca-cho-fa-da",
    "alcachofado": "al-ca-cho-fa-do",
    "alcachofal": "al-ca-cho-fal",
    "alcachofar": "al-ca-cho-far",
    "alcachofera": "al-ca-cho-fe-ra",
    "alcachofero": "al-ca-cho-fe-ro",
    "alcací": "al-ca-cí",
    "alcacil": "al-ca-cil",
    "alcaduz": "al-ca-duz",
    "alcaecería": "al-ca-e-ce-rí-a",
    "alcafar": "al-ca-far",
    "alcahaz": "al-ca-haz",
    "alcahazada": "al-ca-ha-za-da",
    "alcahazar": "al-ca-ha-zar",
    "alcahotar": "al-ca-ho-tar",
    "alcahotería": "al-ca-ho-te-rí-a",
    "alcahueta": "al-ca-hue-ta",
    "alcahuetar": "al-ca-hue-tar",
    "alcahuetazgo": "al-ca-hue-taz-go",
    "alcahuete": "al-ca-hue-te",
    "alcahuetear": "al-ca-hue-te-ar",
    "alcahueteo": "al-ca-hue-te-o",
    "alcahuetería": "al-ca-hue-te-rí-a",
    "alcaicería": "al-cai-ce-rí-a",
    "alcaico": "al-cai-co",
    "alcaide": "al-cai-de",
    "alcaidesa": "al-cai-de-sa",
    "alcaidía": "al-cai-dí-a",
    "alcaidiado": "al-cai-dia-do",
    "alcairía": "al-cai-rí-a",
    "alcaladina": "al-ca-la-di-na",
    "alcaladino": "al-ca-la-di-no",
    "alcalaeña": "al-ca-la-e-ña",
    "alcalaeño": "al-ca-la-e-ño",
    "alcalaína": "al-ca-la-í-na",
    "alcalaina": "al-ca-lai-na",
    "alcalaíno": "al-ca-la-í-no",
    "alcalareña": "al-ca-la-re-ña",
    "alcalareño": "al-ca-la-re-ño",
    "alcaldable": "al-cal-da-ble",
    "alcaldada": "al-cal-da-da",
    "alcalde": "al-cal-de",
    "alcaldesa": "al-cal-de-sa",
    "alcaldía": "al-cal-dí-a",
    "alcalemia": "al-ca-le-mia",
    "alcalescencia": "al-ca-les-cen-cia",
    "álcali": "ál-ca-li",
    "alcalifa": "al-ca-li-fa",
    "alcalifaje": "al-ca-li-fa-je",
    "alcalímetro": "al-ca-lí-me-tro",
    "alcalinidad": "al-ca-li-ni-dad",
    "alcalinización": "al-ca-li-ni-za-ción",
    "alcalinizar": "al-ca-li-ni-zar",
    "alcalino": "al-ca-li-no",
    "alcalinotérreo": "al-ca-li-no-té-rre-o",
    "alcalización": "al-ca-li-za-ción",
    "alcalizar": "al-ca-li-zar",
    "alcaller": "al-ca-ller",
    "alcallería": "al-ca-lle-rí-a",
    "alcaloide": "al-ca-loi-de",
    "alcaloidea": "al-ca-loi-de-a",
    "alcaloideo": "al-ca-loi-de-o",
    "alcalometría": "al-ca-lo-me-trí-a",
    "alcalosis": "al-ca-lo-sis",
    "alcamar": "al-ca-mar",
    "alcamiz": "al-ca-miz",
    "alcamonías": "al-ca-mo-ní-as",
    "alcana": "al-ca-na",
    "alcaná": "al-ca-ná",
    "alcance": "al-can-ce",
    "alcancía": "al-can-cí-a",
    "alcanciazo": "al-can-cia-zo",
    "alcándara": "al-cán-da-ra",
    "alcandía": "al-can-dí-a",
    "alcandial": "al-can-dial",
    "alcandora": "al-can-do-ra",
    "alcándora": "al-cán-do-ra",
    "alcanería": "al-ca-ne-rí-a",
    "alcanfor": "al-can-for",
    "alcanforada": "al-can-fo-ra-da",
    "alcanforado": "al-can-fo-ra-do",
    "alcanforar": "al-can-fo-rar",
    "alcanforero": "al-can-fo-re-ro",
    "alcañizana": "al-ca-ñi-za-na",
    "alcañizano": "al-ca-ñi-za-no",
    "alcano": "al-ca-no",
    "alcántara": "al-cán-ta-ra",
    "alcantarilla": "al-can-ta-ri-lla",
    "alcantarillado": "al-can-ta-ri-lla-do",
    "alcantarillar": "al-can-ta-ri-llar",
    "alcantarillero": "al-can-ta-ri-lle-ro",
    "alcantarina": "al-can-ta-ri-na",
    "alcantarino": "al-can-ta-ri-no",
    "alcanzable": "al-can-za-ble",
    "alcanzada": "al-can-za-da",
    "alcanzadiza": "al-can-za-di-za",
    "alcanzadizo": "al-can-za-di-zo",
    "alcanzado": "al-can-za-do",
    "alcanzador": "al-can-za-dor",
    "alcanzadora": "al-can-za-do-ra",
    "alcanzadura": "al-can-za-du-ra",
    "alcanzamiento": "al-can-za-mien-to",
    "alcanzar": "al-can-zar",
    "alcanzativo": "al-can-za-ti-vo",
    "alcaparra": "al-ca-pa-rra",
    "alcaparrada": "al-ca-pa-rra-da",
    "alcaparrado": "al-ca-pa-rra-do",
    "alcaparral": "al-ca-pa-rral",
    "alcaparrera": "al-ca-pa-rre-ra",
    "alcaparro": "al-ca-pa-rro",
    "alcaparrón": "al-ca-pa-rrón",
    "alcaparrosa": "al-ca-pa-rro-sa",
    "alcaptonuria": "al-cap-to-nu-ria",
    "alcapurria": "al-ca-pu-rria",
    "alcaraceña": "al-ca-ra-ce-ña",
    "alcaraceño": "al-ca-ra-ce-ño",
    "alcaraván": "al-ca-ra-ván",
    "alcaravanero": "al-ca-ra-va-ne-ro",
    "alcaravea": "al-ca-ra-ve-a",
    "alcarceña": "al-car-ce-ña",
    "alcarceñal": "al-car-ce-ñal",
    "alcarchofa": "al-car-cho-fa",
    "alcarchofada": "al-car-cho-fa-da",
    "alcarchofado": "al-car-cho-fa-do",
    "alcarchofar": "al-car-cho-far",
    "alcarcil": "al-car-cil",
    "alcaría": "al-ca-rí-a",
    "alcarracera": "al-ca-rra-ce-ra",
    "alcarracero": "al-ca-rra-ce-ro",
    "alcarraza": "al-ca-rra-za",
    "alcarreña": "al-ca-rre-ña",
    "alcarreño": "al-ca-rre-ño",
    "alcarria": "al-ca-rria",
    "alcartaz": "al-car-taz",
    "alcatara": "al-ca-ta-ra",
    "alcatenes": "al-ca-te-nes",
    "alcatifa": "al-ca-ti-fa",
    "alcatifar": "al-ca-ti-far",
    "alcatraz": "al-ca-traz",
    "alcaucí": "al-cau-cí",
    "alcaucil": "al-cau-cil",
    "alcaudón": "al-cau-dón",
    "alcavela": "al-ca-ve-la",
    "alcavera": "al-ca-ve-ra",
    "alcayata": "al-ca-ya-ta",
    "alcayatar": "al-ca-ya-tar",
    "alcazaba": "al-ca-za-ba",
    "alcázar": "al-cá-zar",
    "alcazareña": "al-ca-za-re-ña",
    "alcazareño": "al-ca-za-re-ño",
    "alcazuz": "al-ca-zuz",
    "alce": "al-ce",
    "alcea": "al-ce-a",
    "alcedo": "al-ce-do",
    "alcedón": "al-ce-dón",
    "alcíbar": "al-cí-bar",
    "alcino": "al-ci-no",
    "alción": "al-ción",
    "alcionio": "al-cio-nio",
    "alcionito": "al-cio-ni-to",
    "alcireña": "al-ci-re-ña",
    "alcireño": "al-ci-re-ño",
    "alcista": "al-cis-ta",
    "alcitrón": "al-ci-trón",
    "alcoba": "al-co-ba",
    "alcobilla": "al-co-bi-lla",
    "alcocarra": "al-co-ca-rra",
    "alcofol": "al-co-fol",
    "alcohela": "al-co-he-la",
    "alcohol": "al-co-hol",
    "alcoholada": "al-co-ho-la-da",
    "alcoholado": "al-co-ho-la-do",
    "alcoholador": "al-co-ho-la-dor",
    "alcoholadora": "al-co-ho-la-do-ra",
    "alcoholar": "al-co-ho-lar",
    "alcoholato": "al-co-ho-la-to",
    "alcoholaturo": "al-co-ho-la-tu-ro",
    "alcoholemia": "al-co-ho-le-mia",
    "alcoholera": "al-co-ho-le-ra",
    "alcoholero": "al-co-ho-le-ro",
    "alcohólica": "al-co-hó-li-ca",
    "alcohólico": "al-co-hó-li-co",
    "alcoholimetría": "al-co-ho-li-me-trí-a",
    "alcoholímetro": "al-co-ho-lí-me-tro",
    "alcoholisis": "al-co-ho-li-sis",
    "alcoholismo": "al-co-ho-lis-mo",
    "alcoholización": "al-co-ho-li-za-ción",
    "alcoholizada": "al-co-ho-li-za-da",
    "alcoholizado": "al-co-ho-li-za-do",
    "alcoholizar": "al-co-ho-li-zar",
    "alcohometría": "al-co-ho-me-trí-a",
    "alcohómetro": "al-co-hó-me-tro",
    "alcojolado": "al-co-jo-la-do",
    "alcolla": "al-co-lla",
    "alcomenías": "al-co-me-ní-as",
    "alconcilla": "al-con-ci-lla",
    "alcor": "al-cor",
    "alcorán": "al-co-rán",
    "alcoránica": "al-co-rá-ni-ca",
    "alcoránico": "al-co-rá-ni-co",
    "alcoranista": "al-co-ra-nis-ta",
    "alcorce": "al-cor-ce",
    "alcorcí": "al-cor-cí",
    "alcornocal": "al-cor-no-cal",
    "alcornoque": "al-cor-no-que",
    "alcornoqueña": "al-cor-no-que-ña",
    "alcornoqueño": "al-cor-no-que-ño",
    "alcorque": "al-cor-que",
    "alcorza": "al-cor-za",
    "alcorzada": "al-cor-za-da",
    "alcorzado": "al-cor-za-do",
    "alcorzar": "al-cor-zar",
    "alcotán": "al-co-tán",
    "alcotana": "al-co-ta-na",
    "alcoyana": "al-co-ya-na",
    "alcoyano": "al-co-ya-no",
    "alcrebite": "al-cre-bi-te",
    "alcribís": "al-cri-bís",
    "alcribite": "al-cri-bi-te",
    "alcubilla": "al-cu-bi-lla",
    "alcucera": "al-cu-ce-ra",
    "alcucero": "al-cu-ce-ro",
    "alcuña": "al-cu-ña",
    "alcuño": "al-cu-ño",
    "alcurnia": "al-cur-nia",
    "alcuza": "al-cu-za",
    "alcuzada": "al-cu-za-da",
    "alcuzcucero": "al-cuz-cu-ce-ro",
    "alcuzcuz": "al-cuz-cuz",
    "alcuzcuzu": "al-cuz-cu-zu",
    "aldaba": "al-da-ba",
    "aldabada": "al-da-ba-da",
    "aldabazo": "al-da-ba-zo",
    "aldabear": "al-da-be-ar",
    "aldabeo": "al-da-be-o",
    "aldabía": "al-da-bí-a",
    "aldabilla": "al-da-bi-lla",
    "aldabón": "al-da-bón",
    "aldabonazo": "al-da-bo-na-zo",
    "aldea": "al-de-a",
    "aldeana": "al-de-a-na",
    "aldeanamente": "al-de-a-na-men-te",
    "aldeanería": "al-de-a-ne-rí-a",
    "aldeaniega": "al-de-a-nie-ga",
    "aldeaniego": "al-de-a-nie-go",
    "aldeanismo": "al-de-a-nis-mo",
    "aldeano": "al-de-a-no",
    "aldehídico": "al-de-hí-di-co",
    "aldehído": "al-de-hí-do",
    "aldeón": "al-de-ón",
    "aldeorrio": "al-de-o-rrio",
    "aldeorro": "al-de-o-rro",
    "alderredor": "al-de-rre-dor",
    "aldina": "al-di-na",
    "aldino": "al-di-no",
    "aldiza": "al-di-za",
    "aldohexosa": "al-do-he-xo-sa",
    "aldopentosa": "al-do-pen-to-sa",
    "aldorta": "al-dor-ta",
    "aldosterona": "al-dos-te-ro-na",
    "aldúcar": "al-dú-car",
    "ale": "a-le",
    "alea": "a-le-a",
    "aleación": "a-le-a-ción",
    "alear": "a-le-ar",
    "aleas": "a-le-as",
    "aleatoria": "a-le-a-to-ria",
    "aleatoriamente": "a-le-a-to-ria-men-te",
    "aleatoriedad": "a-le-a-to-rie-dad",
    "aleatorio": "a-le-a-to-rio",
    "alebrar": "a-le-brar",
    "alebrarse": "a-le-brar-se",
    "alebrastar": "a-le-bras-tar",
    "alebrastarse": "a-le-bras-tar-se",
    "alebrestado": "a-le-bres-ta-do",
    "alebrestar": "a-le-bres-tar",
    "alebrestarse": "a-le-bres-tar-se",
    "alebrije": "a-le-bri-je",
    "alebronar": "a-le-bro-nar",
    "alebronarse": "a-le-bro-nar-se",
    "aleccionador": "a-lec-cio-na-dor",
    "aleccionadora": "a-lec-cio-na-do-ra",
    "aleccionamiento": "a-lec-cio-na-mien-to",
    "aleccionar": "a-lec-cio-nar",
    "alece": "a-le-ce",
    "aleche": "a-le-che",
    "alechigar": "a-le-chi-gar",
    "alechugado": "a-le-chu-ga-do",
    "alechugar": "a-le-chu-gar",
    "alecrín": "a-le-crín",
    "alectomancía": "a-lec-to-man-cí-a",
    "alectomancia": "a-lec-to-man-cia",
    "alectoria": "a-lec-to-ria",
    "aleda": "a-le-da",
    "aledaña": "a-le-da-ña",
    "aledaño": "a-le-da-ño",
    "álef": "á-lef",
    "alefangina": "a-le-fan-gi-na",
    "alefato": "a-le-fa-to",
    "alefriz": "a-le-friz",
    "alegación": "a-le-ga-ción",
    "alegador": "a-le-ga-dor",
    "alegal": "a-le-gal",
    "alegalidad": "a-le-ga-li-dad",
    "alegalmente": "a-le-gal-men-te",
    "alegamar": "a-le-ga-mar",
    "aleganar": "a-le-ga-nar",
    "aleganarse": "a-le-ga-nar-se",
    "alegar": "a-le-gar",
    "alegato": "a-le-ga-to",
    "alegatorio": "a-le-ga-to-rio",
    "alegón": "a-le-gón",
    "alegoría": "a-le-go-rí-a",
    "alegórica": "a-le-gó-ri-ca",
    "alegóricamente": "a-le-gó-ri-ca-men-te",
    "alegórico": "a-le-gó-ri-co",
    "alegorismo": "a-le-go-ris-mo",
    "alegorización": "a-le-go-ri-za-ción",
    "alegorizar": "a-le-go-ri-zar",
    "alegra": "a-le-gra",
    "alegrador": "a-le-gra-dor",
    "alegradora": "a-le-gra-do-ra",
    "alegradura": "a-le-gra-du-ra",
    "alegranza": "a-le-gran-za",
    "alegrar": "a-le-grar",
    "alegre": "a-le-gre",
    "alegremente": "a-le-gre-men-te",
    "alegreto": "a-le-gre-to",
    "alegría": "a-le-grí-a",
    "alegro": "a-le-gro",
    "alegrón": "a-le-grón",
    "alegrosa": "a-le-gro-sa",
    "alegroso": "a-le-gro-so",
    "aleja": "a-le-ja",
    "alejado": "a-le-ja-do",
    "alejamiento": "a-le-ja-mien-to",
    "alejandría": "a-le-jan-drí-a",
    "alejandrina": "a-le-jan-dri-na",
    "alejandrinismo": "a-le-jan-dri-nis-mo",
    "alejandrino": "a-le-jan-dri-no",
    "alejandrita": "a-le-jan-dri-ta",
    "alejar": "a-le-jar",
    "alejija": "a-le-ji-ja",
    "alejur": "a-le-jur",
    "alelado": "a-le-la-do",
    "alelamiento": "a-le-la-mien-to",
    "alelar": "a-le-lar",
    "aleleví": "a-le-le-ví",
    "alelí": "a-le-lí",
    "alélico": "a-lé-li-co",
    "alelo": "a-le-lo",
    "alelomórfico": "a-le-lo-mór-fi-co",
    "alelomorfo": "a-le-lo-mor-fo",
    "aleluya": "a-le-lu-ya",
    "alema": "a-le-ma",
    "alemán": "a-le-mán",
    "alemana": "a-le-ma-na",
    "alemanda": "a-le-man-da",
    "alemanés": "a-le-ma-nés",
    "alemanesa": "a-le-ma-ne-sa",
    "alemanesca": "a-le-ma-nes-ca",
    "alemanesco": "a-le-ma-nes-co",
    "alemánica": "a-le-má-ni-ca",
    "alemánico": "a-le-má-ni-co",
    "alemanisca": "a-le-ma-nis-ca",
    "alemanisco": "a-le-ma-nis-co",
    "alenguamiento": "a-len-gua-mien-to",
    "alenguar": "a-len-guar",
    "alentada": "a-len-ta-da",
    "alentadamente": "a-len-ta-da-men-te",
    "alentado": "a-len-ta-do",
    "alentador": "a-len-ta-dor",
    "alentadora": "a-len-ta-do-ra",
    "alentar": "a-len-tar",
    "alentosa": "a-len-to-sa",
    "alentoso": "a-len-to-so",
    "aleonada": "a-le-o-na-da",
    "aleonado": "a-le-o-na-do",
    "aleonar": "a-le-o-nar",
    "alepato": "a-le-pa-to",
    "aleph": "a-leph",
    "alepín": "a-le-pín",
    "alerce": "a-ler-ce",
    "alergénico": "a-ler-gé-ni-co",
    "alérgeno": "a-lér-ge-no",
    "alergia": "a-ler-gia",
    "alérgica": "a-lér-gi-ca",
    "alérgico": "a-lér-gi-co",
    "alergista": "a-ler-gis-ta",
    "alergizante": "a-ler-gi-zan-te",
    "alergóloga": "a-ler-gó-lo-ga",
    "alergología": "a-ler-go-lo-gí-a",
    "alergólogo": "a-ler-gó-lo-go",
    "alero": "a-le-ro",
    "alerón": "a-le-rón",
    "alerta": "a-ler-ta",
    "alertado": "a-ler-ta-do",
    "alertador": "a-ler-ta-dor",
    "alertamente": "a-ler-ta-men-te",
    "alertar": "a-ler-tar",
    "alertear": "a-ler-te-ar",
    "alerto": "a-ler-to",
    "alerzal": "a-ler-zal",
    "alesna": "a-les-na",
    "alesnada": "a-les-na-da",
    "alesnado": "a-les-na-do",
    "aleta": "a-le-ta",
    "aletada": "a-le-ta-da",
    "aletargamiento": "a-le-tar-ga-mien-to",
    "aletargar": "a-le-tar-gar",
    "aletazo": "a-le-ta-zo",
    "aletear": "a-le-te-ar",
    "aleteo": "a-le-te-o",
    "aleto": "a-le-to",
    "aletría": "a-le-trí-a",
    "aleudar": "a-leu-dar",
    "aleutiana": "a-leu-tia-na",
    "aleutiano": "a-leu-tia-no",
    "alevantadiza": "a-le-van-ta-di-za",
    "alevantadizo": "a-le-van-ta-di-zo",
    "alevantar": "a-le-van-tar",
    "aleve": "a-le-ve",
    "aleviar": "a-le-viar",
    "alevilla": "a-le-vi-lla",
    "alevín": "a-le-vín",
    "alevino": "a-le-vi-no",
    "alevosa": "a-le-vo-sa",
    "alevosamente": "a-le-vo-sa-men-te",
    "alevosía": "a-le-vo-sí-a",
    "alevoso": "a-le-vo-so",
    "alexia": "a-le-xia",
    "alexifármaca": "a-le-xi-fár-ma-ca",
    "alexifármaco": "a-le-xi-fár-ma-co",
    "aleya": "a-le-ya",
    "alezna": "a-lez-na",
    "aleznada": "a-lez-na-da",
    "aleznado": "a-lez-na-do",
    "aleznar": "a-lez-nar",
    "alezo": "a-le-zo",
    "alfa": "al-fa",
    "alfaba": "al-fa-ba",
    "alfábega": "al-fá-be-ga",
    "alfabeta": "al-fa-be-ta",
    "alfabetear": "al-fa-be-te-ar",
    "alfabética": "al-fa-bé-ti-ca",
    "alfabéticamente": "al-fa-bé-ti-ca-men-te",
    "alfabético": "al-fa-bé-ti-co",
    "alfabetismo": "al-fa-be-tis-mo",
    "alfabetizable": "al-fa-be-ti-za-ble",
    "alfabetización": "al-fa-be-ti-za-ción",
    "alfabetizada": "al-fa-be-ti-za-da",
    "alfabetizado": "al-fa-be-ti-za-do",
    "alfabetizador": "al-fa-be-ti-za-dor",
    "alfabetizadora": "al-fa-be-ti-za-do-ra",
    "alfabetizanda": "al-fa-be-ti-zan-da",
    "alfabetizando": "al-fa-be-ti-zan-do",
    "alfabetizar": "al-fa-be-ti-zar",
    "alfabeto": "al-fa-be-to",
    "alfadía": "al-fa-dí-a",
    "alfaguara": "al-fa-gua-ra",
    "alfahar": "al-fa-har",
    "alfaharería": "al-fa-ha-re-rí-a",
    "alfaharero": "al-fa-ha-re-ro",
    "alfaida": "al-fai-da",
    "alfaja": "al-fa-ja",
    "alfajeme": "al-fa-je-me",
    "alfajía": "al-fa-jí-a",
    "alfajor": "al-fa-jor",
    "alfalfa": "al-fal-fa",
    "alfalfal": "al-fal-fal",
    "alfalfar": "al-fal-far",
    "alfalfe": "al-fal-fe",
    "alfalfez": "al-fal-fez",
    "alfama": "al-fa-ma",
    "alfamar": "al-fa-mar",
    "alfamarada": "al-fa-ma-ra-da",
    "alfana": "al-fa-na",
    "alfandoque": "al-fan-do-que",
    "alfaneque": "al-fa-ne-que",
    "alfanjada": "al-fan-ja-da",
    "alfanjado": "al-fan-ja-do",
    "alfanjazo": "al-fan-ja-zo",
    "alfanje": "al-fan-je",
    "alfanumérico": "al-fa-nu-mé-ri-co",
    "alfanúmero": "al-fa-nú-me-ro",
    "alfaque": "al-fa-que",
    "alfaqueque": "al-fa-que-que",
    "alfaquí": "al-fa-quí",
    "alfaquín": "al-fa-quín",
    "alfar": "al-far",
    "alfaraz": "al-fa-raz",
    "alfarda": "al-far-da",
    "alfardilla": "al-far-di-lla",
    "alfardón": "al-far-dón",
    "alfareme": "al-fa-re-me",
    "alfareña": "al-fa-re-ña",
    "alfareño": "al-fa-re-ño",
    "alfarera": "al-fa-re-ra",
    "alfarería": "al-fa-re-rí-a",
    "alfarero": "al-fa-re-ro",
    "alfarje": "al-far-je",
    "alfarjía": "al-far-jí-a",
    "alfarma": "al-far-ma",
    "alfarnate": "al-far-na-te",
    "alfarrazador": "al-fa-rra-za-dor",
    "alfarrazadora": "al-fa-rra-za-do-ra",
    "alfarrazar": "al-fa-rra-zar",
    "alfaya": "al-fa-ya",
    "alfayata": "al-fa-ya-ta",
    "alfayate": "al-fa-ya-te",
    "alfayatería": "al-fa-ya-te-rí-a",
    "alfazaque": "al-fa-za-que",
    "alfeiza": "al-fei-za",
    "alfeizar": "al-fei-zar",
    "alféizar": "al-féi-zar",
    "alfeñar": "al-fe-ñar",
    "alfendoz": "al-fen-doz",
    "alfeñicar": "al-fe-ñi-car",
    "alfeñicarse": "al-fe-ñi-car-se",
    "alfeñique": "al-fe-ñi-que",
    "alferazgo": "al-fe-raz-go",
    "alferecía": "al-fe-re-cí-a",
    "alférez": "al-fé-rez",
    "alferraz": "al-fe-rraz",
    "alferza": "al-fer-za",
    "alficoz": "al-fi-coz",
    "alfil": "al-fil",
    "alfilel": "al-fi-lel",
    "alfiler": "al-fi-ler",
    "alfilerazo": "al-fi-le-ra-zo",
    "alfilerera": "al-fi-le-re-ra",
    "alfileresca": "al-fi-le-res-ca",
    "alfileresco": "al-fi-le-res-co",
    "alfilerillo": "al-fi-le-ri-llo",
    "alfiletero": "al-fi-le-te-ro",
    "alfilitero": "al-fi-li-te-ro",
    "alfinge": "al-fin-ge",
    "alfitete": "al-fi-te-te",
    "alfiz": "al-fiz",
    "alfócigo": "al-fó-ci-go",
    "alfolí": "al-fo-lí",
    "alfoliero": "al-fo-lie-ro",
    "alfolinero": "al-fo-li-ne-ro",
    "alfombra": "al-fom-bra",
    "alfombrado": "al-fom-bra-do",
    "alfombrar": "al-fom-brar",
    "alfombrera": "al-fom-bre-ra",
    "alfombrero": "al-fom-bre-ro",
    "alfombrilla": "al-fom-bri-lla",
    "alfombrista": "al-fom-bris-ta",
    "alfóncigo": "al-fón-ci-go",
    "alfóndiga": "al-fón-di-ga",
    "alfondoque": "al-fon-do-que",
    "alfonsario": "al-fon-sa-rio",
    "alfonsear": "al-fon-se-ar",
    "alfonsearse": "al-fon-se-ar-se",
    "alfonsí": "al-fon-sí",
    "alfónsigo": "al-fón-si-go",
    "alfonsina": "al-fon-si-na",
    "alfonsino": "al-fon-si-no",
    "alfonsismo": "al-fon-sis-mo",
    "alforfón": "al-for-fón",
    "alforín": "al-fo-rín",
    "alforja": "al-for-ja",
    "alforjera": "al-for-je-ra",
    "alforjero": "al-for-je-ro",
    "alforjón": "al-for-jón",
    "alforre": "al-fo-rre",
    "alforrochar": "al-fo-rro-char",
    "alforrocho": "al-fo-rro-cho",
    "alforza": "al-for-za",
    "alforzar": "al-for-zar",
    "alfóstiga": "al-fós-ti-ga",
    "alfoz": "al-foz",
    "alga": "al-ga",
    "algaba": "al-ga-ba",
    "algabeña": "al-ga-be-ña",
    "algabeño": "al-ga-be-ño",
    "algadara": "al-ga-da-ra",
    "algaida": "al-gai-da",
    "algaido": "al-gai-do",
    "algalia": "al-ga-lia",
    "algaliar": "al-ga-liar",
    "algaliera": "al-ga-lie-ra",
    "algaliero": "al-ga-lie-ro",
    "algar": "al-gar",
    "algara": "al-ga-ra",
    "algarabía": "al-ga-ra-bí-a",
    "algarabiada": "al-ga-ra-bia-da",
    "algarabiado": "al-ga-ra-bia-do",
    "algarabío": "al-ga-ra-bí-o",
    "algaracear": "al-ga-ra-ce-ar",
    "algarada": "al-ga-ra-da",
    "algarazo": "al-ga-ra-zo",
    "algareador": "al-ga-re-a-dor",
    "algareadora": "al-ga-re-a-do-ra",
    "algarear": "al-ga-re-ar",
    "algarera": "al-ga-re-ra",
    "algarero": "al-ga-re-ro",
    "algariva": "al-ga-ri-va",
    "algarivo": "al-ga-ri-vo",
    "algarrada": "al-ga-rra-da",
    "algarroba": "al-ga-rro-ba",
    "algarrobal": "al-ga-rro-bal",
    "algarrobera": "al-ga-rro-be-ra",
    "algarrobero": "al-ga-rro-be-ro",
    "algarrobilla": "al-ga-rro-bi-lla",
    "algarrobina": "al-ga-rro-bi-na",
    "algarrobo": "al-ga-rro-bo",
    "algavaro": "al-ga-va-ro",
    "algazara": "al-ga-za-ra",
    "algazul": "al-ga-zul",
    "álgebra": "ál-ge-bra",
    "algebraica": "al-ge-brai-ca",
    "algebraicamente": "al-ge-brai-ca-men-te",
    "algebraico": "al-ge-brai-co",
    "algébrica": "al-gé-bri-ca",
    "algébricamente": "al-gé-bri-ca-men-te",
    "algébrico": "al-gé-bri-co",
    "algebrista": "al-ge-bris-ta",
    "algecireña": "al-ge-ci-re-ña",
    "algecireño": "al-ge-ci-re-ño",
    "algente": "al-gen-te",
    "algidez": "al-gi-dez",
    "álgido": "ál-gi-do",
    "algo": "al-go",
    "algodón": "al-go-dón",
    "algodonal": "al-go-do-nal",
    "algodonar": "al-go-do-nar",
    "algodoncillo": "al-go-don-ci-llo",
    "algodoncito": "al-go-don-ci-to",
    "algodonera": "al-go-do-ne-ra",
    "algodonero": "al-go-do-ne-ro",
    "algodonosa": "al-go-do-no-sa",
    "algodonoso": "al-go-do-no-so",
    "algol": "al-gol",
    "algonquina": "al-gon-qui-na",
    "algonquino": "al-gon-qui-no",
    "algorfa": "al-gor-fa",
    "algorín": "al-go-rín",
    "algoritmia": "al-go-rit-mia",
    "algorítmica": "al-go-rít-mi-ca",
    "algorítmico": "al-go-rít-mi-co",
    "algoritmo": "al-go-rit-mo",
    "algorto": "al-gor-to",
    "algorza": "al-gor-za",
    "algosa": "al-go-sa",
    "algoso": "al-go-so",
    "algotro": "al-go-tro",
    "alguacil": "al-gua-cil",
    "alguacila": "al-gua-ci-la",
    "alguaciladgo": "al-gua-ci-lad-go",
    "alguacilazgo": "al-gua-ci-laz-go",
    "alguacilería": "al-gua-ci-le-rí-a",
    "alguacilesca": "al-gua-ci-les-ca",
    "alguacilesco": "al-gua-ci-les-co",
    "alguacilillo": "al-gua-ci-li-llo",
    "alguandre": "al-guan-dre",
    "alguaquida": "al-gua-qui-da",
    "alguaquidero": "al-gua-qui-de-ro",
    "alguarín": "al-gua-rín",
    "alguarismo": "al-gua-ris-mo",
    "alguaza": "al-gua-za",
    "alguera": "al-gue-ra",
    "alguerés": "al-gue-rés",
    "alguero": "al-gue-ro",
    "alguese": "al-gue-se",
    "alguicida": "al-gui-ci-da",
    "alguien": "al-guien",
    "alguinio": "al-gui-nio",
    "algún": "al-gún",
    "alguna": "al-gu-na",
    "algunamente": "al-gu-na-men-te",
    "algund": "al-gund",
    "alguno": "al-gu-no",
    "alhábega": "al-há-be-ga",
    "alhacena": "al-ha-ce-na",
    "alhaite": "al-hai-te",
    "alhaja": "al-ha-ja",
    "alhajar": "al-ha-jar",
    "alhajera": "al-ha-je-ra",
    "alhajero": "al-ha-je-ro",
    "alhajita": "al-ha-ji-ta",
    "alhajito": "al-ha-ji-to",
    "alhajú": "al-ha-jú",
    "alhamar": "al-ha-mar",
    "alhámega": "al-há-me-ga",
    "alhamel": "al-ha-mel",
    "alhamí": "al-ha-mí",
    "alhandal": "al-han-dal",
    "alhanía": "al-ha-ní-a",
    "alhaquín": "al-ha-quín",
    "alharaca": "al-ha-ra-ca",
    "alharaquero": "al-ha-ra-que-ro",
    "alharaquienta": "al-ha-ra-quien-ta",
    "alharaquiento": "al-ha-ra-quien-to",
    "alhareme": "al-ha-re-me",
    "alhárgama": "al-hár-ga-ma",
    "alharma": "al-har-ma",
    "alhavara": "al-ha-va-ra",
    "alhelí": "al-he-lí",
    "alheña": "al-he-ña",
    "alheñar": "al-he-ñar",
    "alhidada": "al-hi-da-da",
    "alhócigo": "al-hó-ci-go",
    "alholí": "al-ho-lí",
    "alholía": "al-ho-lí-a",
    "alholva": "al-hol-va",
    "alholvar": "al-hol-var",
    "alhombra": "al-hom-bra",
    "alhombrar": "al-hom-brar",
    "alhóndiga": "al-hón-di-ga",
    "alhondiguero": "al-hon-di-gue-ro",
    "alhorí": "al-ho-rí",
    "alhorín": "al-ho-rín",
    "alhorra": "al-ho-rra",
    "alhorre": "al-ho-rre",
    "alhorría": "al-ho-rrí-a",
    "alhorro": "al-ho-rro",
    "alhorza": "al-hor-za",
    "alhoz": "al-hoz",
    "alhucema": "al-hu-ce-ma",
    "alhucemilla": "al-hu-ce-mi-lla",
    "alhuceña": "al-hu-ce-ña",
    "alhumajo": "al-hu-ma-jo",
    "alhurreca": "al-hu-rre-ca",
    "ali": "a-li",
    "aliabierta": "a-lia-bier-ta",
    "aliabierto": "a-lia-bier-to",
    "aliacán": "a-lia-cán",
    "aliacanada": "a-lia-ca-na-da",
    "aliacanado": "a-lia-ca-na-do",
    "aliácea": "a-liá-ce-a",
    "aliáceo": "a-liá-ce-o",
    "aliada": "a-lia-da",
    "aliado": "a-lia-do",
    "aliadófila": "a-lia-dó-fi-la",
    "aliadófilo": "a-lia-dó-fi-lo",
    "aliaga": "a-lia-ga",
    "aliagar": "a-lia-gar",
    "aliancista": "a-lian-cis-ta",
    "alianza": "a-lian-za",
    "alianzar": "a-lian-zar",
    "alianzarse": "a-lian-zar-se",
    "aliar": "a-liar",
    "aliara": "a-lia-ra",
    "aliaria": "a-lia-ria",
    "alias": "a-lias",
    "álibi": "á-li-bi",
    "aliblanca": "a-li-blan-ca",
    "alible": "a-li-ble",
    "alibriestar": "a-li-bries-tar",
    "álica": "á-li-ca",
    "alicaída": "a-li-ca-í-da",
    "alicaído": "a-li-ca-í-do",
    "alicántara": "a-li-cán-ta-ra",
    "alicante": "a-li-can-te",
    "alicantina": "a-li-can-ti-na",
    "alicantino": "a-li-can-ti-no",
    "alicanto": "a-li-can-to",
    "alicatado": "a-li-ca-ta-do",
    "alicatar": "a-li-ca-tar",
    "alicate": "a-li-ca-te",
    "alicer": "a-li-cer",
    "aliciente": "a-li-cien-te",
    "alicionar": "a-li-cio-nar",
    "alicortar": "a-li-cor-tar",
    "alicorto": "a-li-cor-to",
    "alicrejo": "a-li-cre-jo",
    "alicuanta": "a-li-cuan-ta",
    "alícuota": "a-lí-cuo-ta",
    "alicurca": "a-li-cur-ca",
    "alicurco": "a-li-cur-co",
    "alidada": "a-li-da-da",
    "alidona": "a-li-do-na",
    "aliebrestar": "a-lie-bres-tar",
    "alienabilidad": "a-lie-na-bi-li-dad",
    "alienable": "a-lie-na-ble",
    "alienación": "a-lie-na-ción",
    "alienada": "a-lie-na-da",
    "alienado": "a-lie-na-do",
    "alienante": "a-lie-nan-te",
    "alienar": "a-lie-nar",
    "aliende": "a-lien-de",
    "alienígena": "a-lie-ní-ge-na",
    "alienígeno": "a-lie-ní-ge-no",
    "alienismo": "a-lie-nis-mo",
    "alienista": "a-lie-nis-ta",
    "aliento": "a-lien-to",
    "alier": "a-lier",
    "alifa": "a-li-fa",
    "alifafe": "a-li-fa-fe",
    "alifara": "a-li-fa-ra",
    "alifático": "a-li-fá-ti-co",
    "alifato": "a-li-fa-to",
    "alífera": "a-lí-fe-ra",
    "alífero": "a-lí-fe-ro",
    "aligación": "a-li-ga-ción",
    "aligamiento": "a-li-ga-mien-to",
    "aligar": "a-li-gar",
    "aligátor": "a-li-gá-tor",
    "áliger": "á-li-ger",
    "aligeramiento": "a-li-ge-ra-mien-to",
    "aligerar": "a-li-ge-rar",
    "alígero": "a-lí-ge-ro",
    "aligonero": "a-li-go-ne-ro",
    "aligote": "a-li-go-te",
    "aligui": "a-li-gui",
    "aligustre": "a-li-gus-tre",
    "alijador": "a-li-ja-dor",
    "alijadora": "a-li-ja-do-ra",
    "alijar": "a-li-jar",
    "alijarar": "a-li-ja-rar",
    "alijarero": "a-li-ja-re-ro",
    "alijariega": "a-li-ja-rie-ga",
    "alijariego": "a-li-ja-rie-go",
    "alijo": "a-li-jo",
    "alilaya": "a-li-la-ya",
    "alim": "a-lim",
    "alimaña": "a-li-ma-ña",
    "alimañero": "a-li-ma-ñe-ro",
    "alimania": "a-li-ma-nia",
    "alimanisca": "a-li-ma-nis-ca",
    "alimanisco": "a-li-ma-nis-co",
    "alimara": "a-li-ma-ra",
    "alimentación": "a-li-men-ta-ción",
    "alimentador": "a-li-men-ta-dor",
    "alimentadora": "a-li-men-ta-do-ra",
    "alimental": "a-li-men-tal",
    "alimentante": "a-li-men-tan-te",
    "alimentar": "a-li-men-tar",
    "alimentario": "a-li-men-ta-rio",
    "alimenticia": "a-li-men-ti-cia",
    "alimenticio": "a-li-men-ti-cio",
    "alimentista": "a-li-men-tis-ta",
    "alimento": "a-li-men-to",
    "alimentosa": "a-li-men-to-sa",
    "alimentoso": "a-li-men-to-so",
    "álimo": "á-li-mo",
    "alimoche": "a-li-mo-che",
    "alimón": "a-li-món",
    "alimonar": "a-li-mo-nar",
    "alimonarse": "a-li-mo-nar-se",
    "alimpiador": "a-lim-pia-dor",
    "alimpiadora": "a-lim-pia-do-ra",
    "alimpiamiento": "a-lim-pia-mien-to",
    "alimpiar": "a-lim-piar",
    "aliñada": "a-li-ña-da",
    "aliñado": "a-li-ña-do",
    "aliñador": "a-li-ña-dor",
    "aliñadora": "a-li-ña-do-ra",
    "aliñamiento": "a-li-ña-mien-to",
    "aliñar": "a-li-ñar",
    "alindada": "a-lin-da-da",
    "alindado": "a-lin-da-do",
    "alindamiento": "a-lin-da-mien-to",
    "alindar": "a-lin-dar",
    "alinde": "a-lin-de",
    "alinderar": "a-lin-de-rar",
    "alineación": "a-li-ne-a-ción",
    "alineado": "a-li-ne-a-do",
    "alineamiento": "a-li-ne-a-mien-to",
    "alinear": "a-li-ne-ar",
    "aliño": "a-li-ño",
    "aliñosa": "a-li-ño-sa",
    "aliñoso": "a-li-ño-so",
    "alioj": "a-lioj",
    "alioli": "a-lio-li",
    "alionín": "a-lio-nín",
    "alipata": "a-li-pa-ta",
    "alípeda": "a-lí-pe-da",
    "alípede": "a-lí-pe-de",
    "alípedo": "a-lí-pe-do",
    "alipegar": "a-li-pe-gar",
    "alipego": "a-li-pe-go",
    "alipori": "a-li-po-ri",
    "alipús": "a-li-pús",
    "aliquebrada": "a-li-que-bra-da",
    "aliquebrado": "a-li-que-bra-do",
    "aliquebrar": "a-li-que-brar",
    "alirón": "a-li-rón",
    "alirroja": "a-li-rro-ja",
    "alirrojo": "a-li-rro-jo",
    "aliruzar": "a-li-ru-zar",
    "alisado": "a-li-sa-do",
    "alisador": "a-li-sa-dor",
    "alisadora": "a-li-sa-do-ra",
    "alisadura": "a-li-sa-du-ra",
    "alisal": "a-li-sal",
    "alisamiento": "a-li-sa-mien-to",
    "alisar": "a-li-sar",
    "alíscafo": "a-lís-ca-fo",
    "aliseda": "a-li-se-da",
    "alisio": "a-li-sio",
    "alisios": "a-li-sios",
    "alisma": "a-lis-ma",
    "alismácea": "a-lis-má-ce-a",
    "alismáceo": "a-lis-má-ce-o",
    "alismatácea": "a-lis-ma-tá-ce-a",
    "alismatáceo": "a-lis-ma-tá-ce-o",
    "aliso": "a-li-so",
    "alistada": "a-lis-ta-da",
    "alistado": "a-lis-ta-do",
    "alistador": "a-lis-ta-dor",
    "alistamiento": "a-lis-ta-mien-to",
    "alistana": "a-lis-ta-na",
    "alistano": "a-lis-ta-no",
    "alistar": "a-lis-tar",
    "alitán": "a-li-tán",
    "aliteración": "a-li-te-ra-ción",
    "aliterada": "a-li-te-ra-da",
    "aliterado": "a-li-te-ra-do",
    "alitierno": "a-li-tier-no",
    "alitranco": "a-li-tran-co",
    "aliviadero": "a-li-via-de-ro",
    "aliviador": "a-li-via-dor",
    "aliviadora": "a-li-via-do-ra",
    "aliviamiento": "a-li-via-mien-to",
    "alivianar": "a-li-via-nar",
    "aliviane": "a-li-via-ne",
    "aliviar": "a-li-viar",
    "alivio": "a-li-vio",
    "aliviosa": "a-li-vio-sa",
    "alivioso": "a-li-vio-so",
    "alizace": "a-li-za-ce",
    "alizar": "a-li-zar",
    "alizarina": "a-li-za-ri-na",
    "aljaba": "al-ja-ba",
    "aljabibe": "al-ja-bi-be",
    "aljáfana": "al-já-fa-na",
    "aljama": "al-ja-ma",
    "aljamel": "al-ja-mel",
    "aljamía": "al-ja-mí-a",
    "aljamiada": "al-ja-mia-da",
    "aljamiado": "al-ja-mia-do",
    "aljarafe": "al-ja-ra-fe",
    "aljaraz": "al-ja-raz",
    "aljarfa": "al-jar-fa",
    "aljarfe": "al-jar-fe",
    "aljébana": "al-jé-ba-na",
    "aljecería": "al-je-ce-rí-a",
    "aljecero": "al-je-ce-ro",
    "aljemifao": "al-je-mi-fa-o",
    "aljerife": "al-je-ri-fe",
    "aljerifero": "al-je-ri-fe-ro",
    "aljez": "al-jez",
    "aljezar": "al-je-zar",
    "aljezón": "al-je-zón",
    "aljibe": "al-ji-be",
    "aljibero": "al-ji-be-ro",
    "aljofaina": "al-jo-fai-na",
    "aljófar": "al-jó-far",
    "aljofarar": "al-jo-fa-rar",
    "aljofifa": "al-jo-fi-fa",
    "aljofifar": "al-jo-fi-far",
    "aljonje": "al-jon-je",
    "aljonjera": "al-jon-je-ra",
    "aljonjero": "al-jon-je-ro",
    "aljonjolí": "al-jon-jo-lí",
    "aljor": "al-jor",
    "aljorca": "al-jor-ca",
    "aljuba": "al-ju-ba",
    "aljuma": "al-ju-ma",
    "alkermes": "al-ker-mes",
    "allá": "a-llá",
    "allanabarrancos": "a-lla-na-ba-rran-cos",
    "allanador": "a-lla-na-dor",
    "allanadora": "a-lla-na-do-ra",
    "allanamiento": "a-lla-na-mien-to",
    "allanar": "a-lla-nar",
    "allariz": "a-lla-riz",
    "allegada": "a-lle-ga-da",
    "allegadera": "a-lle-ga-de-ra",
    "allegadiza": "a-lle-ga-di-za",
    "allegadizo": "a-lle-ga-di-zo",
    "allegado": "a-lle-ga-do",
    "allegador": "a-lle-ga-dor",
    "allegadora": "a-lle-ga-do-ra",
    "allegamiento": "a-lle-ga-mien-to",
    "alleganza": "a-lle-gan-za",
    "allegar": "a-lle-gar",
    "allegretto": "a-lle-gret-to",
    "allegro": "a-lle-gro",
    "allén": "a-llén",
    "allende": "a-llen-de",
    "allí": "a-llí",
    "allora": "a-llo-ra",
    "alloza": "a-llo-za",
    "allozar": "a-llo-zar",
    "allozo": "a-llo-zo",
    "allú": "a-llú",
    "alludel": "a-llu-del",
    "alma": "al-ma",
    "almacabra": "al-ma-ca-bra",
    "almacén": "al-ma-cén",
    "almacena": "al-ma-ce-na",
    "almacenaje": "al-ma-ce-na-je",
    "almacenamiento": "al-ma-ce-na-mien-to",
    "almacenar": "al-ma-ce-nar",
    "almacenera": "al-ma-ce-ne-ra",
    "almacenero": "al-ma-ce-ne-ro",
    "almacenista": "al-ma-ce-nis-ta",
    "almaceno": "al-ma-ce-no",
    "almacería": "al-ma-ce-rí-a",
    "almáciga": "al-má-ci-ga",
    "almacigada": "al-ma-ci-ga-da",
    "almacigado": "al-ma-ci-ga-do",
    "almacigar": "al-ma-ci-gar",
    "almácigo": "al-má-ci-go",
    "almaciguera": "al-ma-ci-gue-ra",
    "almaciguero": "al-ma-ci-gue-ro",
    "almádana": "al-má-da-na",
    "almadear": "al-ma-de-ar",
    "almadearse": "al-ma-de-ar-se",
    "almadén": "al-ma-dén",
    "almádena": "al-má-de-na",
    "almadía": "al-ma-dí-a",
    "almadiar": "al-ma-diar",
    "almadiero": "al-ma-die-ro",
    "almádina": "al-má-di-na",
    "almadraba": "al-ma-dra-ba",
    "almadrabera": "al-ma-dra-be-ra",
    "almadrabero": "al-ma-dra-be-ro",
    "almadraque": "al-ma-dra-que",
    "almadreña": "al-ma-dre-ña",
    "almadreñero": "al-ma-dre-ñe-ro",
    "almagacén": "al-ma-ga-cén",
    "almágana": "al-má-ga-na",
    "almagra": "al-ma-gra",
    "almagradura": "al-ma-gra-du-ra",
    "almagral": "al-ma-gral",
    "almagrar": "al-ma-grar",
    "almagre": "al-ma-gre",
    "almagreña": "al-ma-gre-ña",
    "almagreño": "al-ma-gre-ño",
    "almagrera": "al-ma-gre-ra",
    "almagrero": "al-ma-gre-ro",
    "almahala": "al-ma-ha-la",
    "almaizal": "al-mai-zal",
    "almaizar": "al-mai-zar",
    "almaizo": "al-mai-zo",
    "almaja": "al-ma-ja",
    "almajal": "al-ma-jal",
    "almajaneque": "al-ma-ja-ne-que",
    "almajar": "al-ma-jar",
    "almajara": "al-ma-ja-ra",
    "almaje": "al-ma-je",
    "almajo": "al-ma-jo",
    "almalafa": "al-ma-la-fa",
    "almanac": "al-ma-nac",
    "almanaca": "al-ma-na-ca",
    "almanaque": "al-ma-na-que",
    "almanaquera": "al-ma-na-que-ra",
    "almanaquero": "al-ma-na-que-ro",
    "almancebe": "al-man-ce-be",
    "almandina": "al-man-di-na",
    "almandino": "al-man-di-no",
    "almanta": "al-man-ta",
    "almarada": "al-ma-ra-da",
    "almarbatar": "al-mar-ba-tar",
    "almarbate": "al-mar-ba-te",
    "almarcha": "al-mar-cha",
    "almario": "al-ma-rio",
    "almarjal": "al-mar-jal",
    "almarjo": "al-mar-jo",
    "almaro": "al-ma-ro",
    "almarrá": "al-ma-rrá",
    "almarraja": "al-ma-rra-ja",
    "almarraza": "al-ma-rra-za",
    "almártaga": "al-már-ta-ga",
    "almartigón": "al-mar-ti-gón",
    "almástiga": "al-más-ti-ga",
    "almastigada": "al-mas-ti-ga-da",
    "almastigado": "al-mas-ti-ga-do",
    "almática": "al-má-ti-ca",
    "almatriche": "al-ma-tri-che",
    "almatroque": "al-ma-tro-que",
    "almatroste": "al-ma-tros-te",
    "almazara": "al-ma-za-ra",
    "almazarero": "al-ma-za-re-ro",
    "almazarrón": "al-ma-za-rrón",
    "almea": "al-me-a",
    "almecina": "al-me-ci-na",
    "almecino": "al-me-ci-no",
    "almeja": "al-me-ja",
    "almejar": "al-me-jar",
    "almejí": "al-me-jí",
    "almejía": "al-me-jí-a",
    "almena": "al-me-na",
    "almenada": "al-me-na-da",
    "almenado": "al-me-na-do",
    "almenaje": "al-me-na-je",
    "almenar": "al-me-nar",
    "almenara": "al-me-na-ra",
    "almendra": "al-men-dra",
    "almendrada": "al-men-dra-da",
    "almendrado": "al-men-dra-do",
    "almendral": "al-men-dral",
    "almendrar": "al-men-drar",
    "almendrate": "al-men-dra-te",
    "almendrera": "al-men-dre-ra",
    "almendrero": "al-men-dre-ro",
    "almendrilla": "al-men-dri-lla",
    "almendro": "al-men-dro",
    "almendrolón": "al-men-dro-lón",
    "almendrón": "al-men-drón",
    "almendruco": "al-men-dru-co",
    "almenilla": "al-me-ni-lla",
    "almeriense": "al-me-rien-se",
    "almete": "al-me-te",
    "almez": "al-mez",
    "almeza": "al-me-za",
    "almezo": "al-me-zo",
    "almiar": "al-miar",
    "almiarar": "al-mia-rar",
    "almíbar": "al-mí-bar",
    "almibarada": "al-mi-ba-ra-da",
    "almibarado": "al-mi-ba-ra-do",
    "almibarar": "al-mi-ba-rar",
    "almicantarat": "al-mi-can-ta-rat",
    "almidón": "al-mi-dón",
    "almidonada": "al-mi-do-na-da",
    "almidonado": "al-mi-do-na-do",
    "almidonar": "al-mi-do-nar",
    "almidonería": "al-mi-do-ne-rí-a",
    "almijar": "al-mi-jar",
    "almijara": "al-mi-ja-ra",
    "almijarero": "al-mi-ja-re-ro",
    "almijarra": "al-mi-ja-rra",
    "almilla": "al-mi-lla",
    "almimbar": "al-mim-bar",
    "alminar": "al-mi-nar",
    "almiquí": "al-mi-quí",
    "almiranta": "al-mi-ran-ta",
    "almirantazgo": "al-mi-ran-taz-go",
    "almirante": "al-mi-ran-te",
    "almirantesa": "al-mi-ran-te-sa",
    "almirantía": "al-mi-ran-tí-a",
    "almirez": "al-mi-rez",
    "almirón": "al-mi-rón",
    "almizate": "al-mi-za-te",
    "almizcate": "al-miz-ca-te",
    "almizclado": "al-miz-cla-do",
    "almizclar": "al-miz-clar",
    "almizcle": "al-miz-cle",
    "almizcleña": "al-miz-cle-ña",
    "almizcleño": "al-miz-cle-ño",
    "almizclera": "al-miz-cle-ra",
    "almizclero": "al-miz-cle-ro",
    "almizque": "al-miz-que",
    "almizquera": "al-miz-que-ra",
    "almo": "al-mo",
    "almocadén": "al-mo-ca-dén",
    "almocafre": "al-mo-ca-fre",
    "almocárabe": "al-mo-cá-ra-be",
    "almocarbe": "al-mo-car-be",
    "almocatracía": "al-mo-ca-tra-cí-a",
    "almocela": "al-mo-ce-la",
    "almocrebe": "al-mo-cre-be",
    "almocrí": "al-mo-crí",
    "almodí": "al-mo-dí",
    "almodón": "al-mo-dón",
    "almodovareña": "al-mo-do-va-re-ña",
    "almodovareño": "al-mo-do-va-re-ño",
    "almodrote": "al-mo-dro-te",
    "almofalla": "al-mo-fa-lla",
    "almófar": "al-mó-far",
    "almofariz": "al-mo-fa-riz",
    "almofía": "al-mo-fí-a",
    "almoflate": "al-mo-fla-te",
    "almofrej": "al-mo-frej",
    "almofrez": "al-mo-frez",
    "almogama": "al-mo-ga-ma",
    "almogávar": "al-mo-gá-var",
    "almogavarear": "al-mo-ga-va-re-ar",
    "almogavaría": "al-mo-ga-va-rí-a",
    "almogavería": "al-mo-ga-ve-rí-a",
    "almohada": "al-mo-ha-da",
    "almohadada": "al-mo-ha-da-da",
    "almohadado": "al-mo-ha-da-do",
    "almohadazo": "al-mo-ha-da-zo",
    "almohade": "al-mo-ha-de",
    "almohadilla": "al-mo-ha-di-lla",
    "almohadillada": "al-mo-ha-di-lla-da",
    "almohadillado": "al-mo-ha-di-lla-do",
    "almohadillar": "al-mo-ha-di-llar",
    "almohadillazo": "al-mo-ha-di-lla-zo",
    "almohadillera": "al-mo-ha-di-lle-ra",
    "almohadillero": "al-mo-ha-di-lle-ro",
    "almohadón": "al-mo-ha-dón",
    "almoharrefa": "al-mo-ha-rre-fa",
    "almoháter": "al-mo-há-ter",
    "almohatre": "al-mo-ha-tre",
    "almohaza": "al-mo-ha-za",
    "almohazador": "al-mo-ha-za-dor",
    "almohazar": "al-mo-ha-zar",
    "almojábana": "al-mo-já-ba-na",
    "almojama": "al-mo-ja-ma",
    "almojarifadgo": "al-mo-ja-ri-fad-go",
    "almojarifalgo": "al-mo-ja-ri-fal-go",
    "almojarifazgo": "al-mo-ja-ri-faz-go",
    "almojarife": "al-mo-ja-ri-fe",
    "almojáter": "al-mo-já-ter",
    "almojatre": "al-mo-ja-tre",
    "almojaya": "al-mo-ja-ya",
    "almojerifazgo": "al-mo-je-ri-faz-go",
    "almojerife": "al-mo-je-ri-fe",
    "almona": "al-mo-na",
    "almóndiga": "al-món-di-ga",
    "almondiguilla": "al-mon-di-gui-lla",
    "almoneda": "al-mo-ne-da",
    "almonedar": "al-mo-ne-dar",
    "almonedear": "al-mo-ne-de-ar",
    "almonedera": "al-mo-ne-de-ra",
    "almonedero": "al-mo-ne-de-ro",
    "almonedista": "al-mo-ne-dis-ta",
    "almora": "al-mo-ra",
    "almorabú": "al-mo-ra-bú",
    "almoraduj": "al-mo-ra-duj",
    "almoradux": "al-mo-ra-dux",
    "almorávide": "al-mo-rá-vi-de",
    "almorejo": "al-mo-re-jo",
    "almorí": "al-mo-rí",
    "almoronía": "al-mo-ro-ní-a",
    "almorraja": "al-mo-rra-ja",
    "almorrana": "al-mo-rra-na",
    "almorranienta": "al-mo-rra-nien-ta",
    "almorraniento": "al-mo-rra-nien-to",
    "almorrefa": "al-mo-rre-fa",
    "almorriña": "al-mo-rri-ña",
    "almorrón": "al-mo-rrón",
    "almorta": "al-mor-ta",
    "almorzada": "al-mor-za-da",
    "almorzado": "al-mor-za-do",
    "almorzar": "al-mor-zar",
    "almosna": "al-mos-na",
    "almosnar": "al-mos-nar",
    "almotacén": "al-mo-ta-cén",
    "almotacenadgo": "al-mo-ta-ce-nad-go",
    "almotacenalgo": "al-mo-ta-ce-nal-go",
    "almotacenazgo": "al-mo-ta-ce-naz-go",
    "almotacenía": "al-mo-ta-ce-ní-a",
    "almotalafe": "al-mo-ta-la-fe",
    "almotazaf": "al-mo-ta-zaf",
    "almotazán": "al-mo-ta-zán",
    "almotazanía": "al-mo-ta-za-ní-a",
    "almozada": "al-mo-za-da",
    "almozala": "al-mo-za-la",
    "almozalla": "al-mo-za-lla",
    "almozárabe": "al-mo-zá-ra-be",
    "almud": "al-mud",
    "almudada": "al-mu-da-da",
    "almudejo": "al-mu-de-jo",
    "almudero": "al-mu-de-ro",
    "almudí": "al-mu-dí",
    "almudín": "al-mu-dín",
    "almuecín": "al-mue-cín",
    "almuédano": "al-mué-da-no",
    "almuedén": "al-mue-dén",
    "almuercera": "al-muer-ce-ra",
    "almuercería": "al-muer-ce-rí-a",
    "almuercero": "al-muer-ce-ro",
    "almuérdago": "al-muér-da-go",
    "almuerza": "al-muer-za",
    "almuerzo": "al-muer-zo",
    "almueza": "al-mue-za",
    "almuezada": "al-mue-za-da",
    "almugávar": "al-mu-gá-var",
    "almunia": "al-mu-nia",
    "almutacén": "al-mu-ta-cén",
    "almutazaf": "al-mu-ta-zaf",
    "almuzala": "al-mu-za-la",
    "almuzalla": "al-mu-za-lla",
    "alna": "al-na",
    "alnada": "al-na-da",
    "alnado": "al-na-do",
    "alnafe": "al-na-fe",
    "alnedo": "al-ne-do",
    "alno": "al-no",
    "aló": "a-ló",
    "aloaria": "a-lo-a-ria",
    "alobada": "a-lo-ba-da",
    "alobadada": "a-lo-ba-da-da",
    "alobadado": "a-lo-ba-da-do",
    "alobado": "a-lo-ba-do",
    "alobar": "a-lo-bar",
    "alobreguecer": "a-lo-bre-gue-cer",
    "alóbroge": "a-ló-bro-ge",
    "alobrógica": "a-lo-bró-gi-ca",
    "alobrógico": "a-lo-bró-gi-co",
    "alóbrogo": "a-ló-bro-go",
    "alobunada": "a-lo-bu-na-da",
    "alobunado": "a-lo-bu-na-do",
    "alocada": "a-lo-ca-da",
    "alocadamente": "a-lo-ca-da-men-te",
    "alocado": "a-lo-ca-do",
    "alocar": "a-lo-car",
    "alóctono": "a-lóc-to-no",
    "alocución": "a-lo-cu-ción",
    "alodial": "a-lo-dial",
    "alodio": "a-lo-dio",
    "aloe": "a-lo-e",
    "áloe": "á-lo-e",
    "aloes": "a-lo-es",
    "aloeta": "a-lo-e-ta",
    "aloética": "a-lo-é-ti-ca",
    "aloético": "a-lo-é-ti-co",
    "alófono": "a-ló-fo-no",
    "aloforma": "a-lo-for-ma",
    "alogador": "a-lo-ga-dor",
    "alogadora": "a-lo-ga-do-ra",
    "alogamiento": "a-lo-ga-mien-to",
    "alogar": "a-lo-gar",
    "alógena": "a-ló-ge-na",
    "alógeno": "a-ló-ge-no",
    "alógico": "a-ló-gi-co",
    "aloguer": "a-lo-guer",
    "aloína": "a-lo-í-na",
    "aloja": "a-lo-ja",
    "alojada": "a-lo-ja-da",
    "alojado": "a-lo-ja-do",
    "alojamiento": "a-lo-ja-mien-to",
    "alojar": "a-lo-jar",
    "alojera": "a-lo-je-ra",
    "alojería": "a-lo-je-rí-a",
    "alojero": "a-lo-je-ro",
    "alolar": "a-lo-lar",
    "alomada": "a-lo-ma-da",
    "alomado": "a-lo-ma-do",
    "alomar": "a-lo-mar",
    "alombar": "a-lom-bar",
    "alombra": "a-lom-bra",
    "alomorfo": "a-lo-mor-fo",
    "alón": "a-lón",
    "alondra": "a-lon-dra",
    "alongada": "a-lon-ga-da",
    "alongado": "a-lon-ga-do",
    "alongamiento": "a-lon-ga-mien-to",
    "alongar": "a-lon-gar",
    "alonso": "a-lon-so",
    "alópata": "a-ló-pa-ta",
    "alopatía": "a-lo-pa-tí-a",
    "alopática": "a-lo-pá-ti-ca",
    "alopático": "a-lo-pá-ti-co",
    "alopecia": "a-lo-pe-cia",
    "alopécica": "a-lo-pé-ci-ca",
    "alopécico": "a-lo-pé-ci-co",
    "alopecuro": "a-lo-pe-cu-ro",
    "alopiada": "a-lo-pia-da",
    "alopiado": "a-lo-pia-do",
    "alopicia": "a-lo-pi-cia",
    "aloque": "a-lo-que",
    "aloquecer": "a-lo-que-cer",
    "aloquín": "a-lo-quín",
    "alora": "a-lo-ra",
    "alosa": "a-lo-sa",
    "alosna": "a-los-na",
    "alotar": "a-lo-tar",
    "alotropía": "a-lo-tro-pí-a",
    "alotrópica": "a-lo-tró-pi-ca",
    "alotrópico": "a-lo-tró-pi-co",
    "aloya": "a-lo-ya",
    "alpaca": "al-pa-ca",
    "alpamato": "al-pa-ma-to",
    "alpamisqui": "al-pa-mis-qui",
    "alpañata": "al-pa-ña-ta",
    "alparcear": "al-par-ce-ar",
    "alparcera": "al-par-ce-ra",
    "alparcería": "al-par-ce-rí-a",
    "alparcero": "al-par-ce-ro",
    "alpargata": "al-par-ga-ta",
    "alpargatada": "al-par-ga-ta-da",
    "alpargatado": "al-par-ga-ta-do",
    "alpargatar": "al-par-ga-tar",
    "alpargate": "al-par-ga-te",
    "alpargatera": "al-par-ga-te-ra",
    "alpargatería": "al-par-ga-te-rí-a",
    "alpargatero": "al-par-ga-te-ro",
    "alpargatilla": "al-par-ga-ti-lla",
    "alpartaz": "al-par-taz",
    "alpataco": "al-pa-ta-co",
    "alpatana": "al-pa-ta-na",
    "alpechín": "al-pe-chín",
    "alpechinera": "al-pe-chi-ne-ra",
    "alpende": "al-pen-de",
    "alpendre": "al-pen-dre",
    "alpes": "al-pes",
    "alpestre": "al-pes-tre",
    "alpicoz": "al-pi-coz",
    "alpina": "al-pi-na",
    "alpinismo": "al-pi-nis-mo",
    "alpinista": "al-pi-nis-ta",
    "alpino": "al-pi-no",
    "alpiste": "al-pis-te",
    "alpistela": "al-pis-te-la",
    "alpistera": "al-pis-te-ra",
    "alpistero": "al-pis-te-ro",
    "alpujarreña": "al-pu-ja-rre-ña",
    "alpujarreño": "al-pu-ja-rre-ño",
    "alquequenje": "al-que-quen-je",
    "alquería": "al-que-rí-a",
    "alquermes": "al-quer-mes",
    "alquerque": "al-quer-que",
    "alquez": "al-quez",
    "alquezar": "al-que-zar",
    "alquibla": "al-qui-bla",
    "alquicel": "al-qui-cel",
    "alquicer": "al-qui-cer",
    "alquifol": "al-qui-fol",
    "alquila": "al-qui-la",
    "alquilable": "al-qui-la-ble",
    "alquilación": "al-qui-la-ción",
    "alquiladiza": "al-qui-la-di-za",
    "alquiladizo": "al-qui-la-di-zo",
    "alquilador": "al-qui-la-dor",
    "alquiladora": "al-qui-la-do-ra",
    "alquilamiento": "al-qui-la-mien-to",
    "alquilar": "al-qui-lar",
    "alquilate": "al-qui-la-te",
    "alquilé": "al-qui-lé",
    "alquiler": "al-qui-ler",
    "alquilo": "al-qui-lo",
    "alquilón": "al-qui-lón",
    "alquilona": "al-qui-lo-na",
    "alquimia": "al-qui-mia",
    "alquímica": "al-quí-mi-ca",
    "alquímico": "al-quí-mi-co",
    "alquimila": "al-qui-mi-la",
    "alquimista": "al-qui-mis-ta",
    "alquinal": "al-qui-nal",
    "alquitara": "al-qui-ta-ra",
    "alquitarar": "al-qui-ta-rar",
    "alquitifa": "al-qui-ti-fa",
    "alquitira": "al-qui-ti-ra",
    "alquitrabe": "al-qui-tra-be",
    "alquitrán": "al-qui-trán",
    "alquitranada": "al-qui-tra-na-da",
    "alquitranado": "al-qui-tra-na-do",
    "alquitranar": "al-qui-tra-nar",
    "alrededor": "al-re-de-dor",
    "alrevesado": "al-re-ve-sa-do",
    "alrota": "al-ro-ta",
    "alsaciana": "al-sa-cia-na",
    "alsaciano": "al-sa-cia-no",
    "álsine": "ál-si-ne",
    "alta": "al-ta",
    "altabaca": "al-ta-ba-ca",
    "altabaque": "al-ta-ba-que",
    "altabaquilla": "al-ta-ba-qui-lla",
    "altabaquillo": "al-ta-ba-qui-llo",
    "altaica": "al-tai-ca",
    "altaico": "al-tai-co",
    "altamandría": "al-ta-man-drí-a",
    "altamente": "al-ta-men-te",
    "altamía": "al-ta-mí-a",
    "altamisa": "al-ta-mi-sa",
    "altana": "al-ta-na",
    "altanera": "al-ta-ne-ra",
    "altaneramente": "al-ta-ne-ra-men-te",
    "altanería": "al-ta-ne-rí-a",
    "altanero": "al-ta-ne-ro",
    "altanez": "al-ta-nez",
    "altano": "al-ta-no",
    "altar": "al-tar",
    "altarero": "al-ta-re-ro",
    "altaricón": "al-ta-ri-cón",
    "altaricona": "al-ta-ri-co-na",
    "altarreina": "al-ta-rrei-na",
    "altavoz": "al-ta-voz",
    "altea": "al-te-a",
    "altear": "al-te-ar",
    "alteña": "al-te-ña",
    "alteño": "al-te-ño",
    "alterabilidad": "al-te-ra-bi-li-dad",
    "alterable": "al-te-ra-ble",
    "alteración": "al-te-ra-ción",
    "alteradiza": "al-te-ra-di-za",
    "alteradizo": "al-te-ra-di-zo",
    "alterado": "al-te-ra-do",
    "alterador": "al-te-ra-dor",
    "alteradora": "al-te-ra-do-ra",
    "alterante": "al-te-ran-te",
    "alterar": "al-te-rar",
    "alterativa": "al-te-ra-ti-va",
    "alterativo": "al-te-ra-ti-vo",
    "altercación": "al-ter-ca-ción",
    "altercado": "al-ter-ca-do",
    "altercador": "al-ter-ca-dor",
    "altercadora": "al-ter-ca-do-ra",
    "altercar": "al-ter-car",
    "alteridad": "al-te-ri-dad",
    "alterna": "al-ter-na",
    "alternación": "al-ter-na-ción",
    "alternada": "al-ter-na-da",
    "alternadamente": "al-ter-na-da-men-te",
    "alternado": "al-ter-na-do",
    "alternador": "al-ter-na-dor",
    "alternancia": "al-ter-nan-cia",
    "alternante": "al-ter-nan-te",
    "alternar": "al-ter-nar",
    "alternativa": "al-ter-na-ti-va",
    "alternativamente": "al-ter-na-ti-va-men-te",
    "alternativo": "al-ter-na-ti-vo",
    "alterne": "al-ter-ne",
    "alterno": "al-ter-no",
    "altero": "al-te-ro",
    "alterosa": "al-te-ro-sa",
    "alteroso": "al-te-ro-so",
    "alteza": "al-te-za",
    "altibajo": "al-ti-ba-jo",
    "altillo": "al-ti-llo",
    "altílocua": "al-tí-lo-cua",
    "altilocuencia": "al-ti-lo-cuen-cia",
    "altilocuente": "al-ti-lo-cuen-te",
    "altílocuo": "al-tí-lo-cuo",
    "altímetra": "al-tí-me-tra",
    "altimetría": "al-ti-me-trí-a",
    "altímetro": "al-tí-me-tro",
    "altipampa": "al-ti-pam-pa",
    "altiplánica": "al-ti-plá-ni-ca",
    "altiplanicie": "al-ti-pla-ni-cie",
    "altiplánico": "al-ti-plá-ni-co",
    "altiplano": "al-ti-pla-no",
    "altiricón": "al-ti-ri-cón",
    "altiro": "al-ti-ro",
    "altísimo": "al-tí-si-mo",
    "altísona": "al-tí-so-na",
    "altisonancia": "al-ti-so-nan-cia",
    "altisonante": "al-ti-so-nan-te",
    "altisonantemente": "al-ti-so-nan-te-men-te",
    "altísono": "al-tí-so-no",
    "altitonante": "al-ti-to-nan-te",
    "altitud": "al-ti-tud",
    "altitudinal": "al-ti-tu-di-nal",
    "altiva": "al-ti-va",
    "altivamente": "al-ti-va-men-te",
    "altivar": "al-ti-var",
    "altivecer": "al-ti-ve-cer",
    "altivez": "al-ti-vez",
    "altiveza": "al-ti-ve-za",
    "altividad": "al-ti-vi-dad",
    "altivo": "al-ti-vo",
    "alto": "al-to",
    "altoaragonés": "al-to-a-ra-go-nés",
    "altoaragonesa": "al-to-a-ra-go-ne-sa",
    "altocúmulo": "al-to-cú-mu-lo",
    "altomedieval": "al-to-me-die-val",
    "altonavarra": "al-to-na-va-rra",
    "altonavarro": "al-to-na-va-rro",
    "altoparaguayiense": "al-to-pa-ra-gua-yien-se",
    "altoparanaense": "al-to-pa-ra-na-en-se",
    "altoparlante": "al-to-par-lan-te",
    "altoperuano": "al-to-pe-rua-no",
    "altor": "al-tor",
    "altorrelieve": "al-to-rre-lie-ve",
    "altostrato": "al-tos-tra-to",
    "altozano": "al-to-za-no",
    "altramucera": "al-tra-mu-ce-ra",
    "altramucero": "al-tra-mu-ce-ro",
    "altramuz": "al-tra-muz",
    "altruismo": "al-truis-mo",
    "altruista": "al-truis-ta",
    "altruistamente": "al-truis-ta-men-te",
    "altura": "al-tu-ra",
    "alúa": "a-lú-a",
    "alubia": "a-lu-bia",
    "alubial": "a-lu-bial",
    "alubiar": "a-lu-biar",
    "aluchar": "a-lu-char",
    "aluche": "a-lu-che",
    "aluciar": "a-lu-ciar",
    "alucín": "a-lu-cín",
    "alucinación": "a-lu-ci-na-ción",
    "alucinada": "a-lu-ci-na-da",
    "alucinadamente": "a-lu-ci-na-da-men-te",
    "alucinado": "a-lu-ci-na-do",
    "alucinador": "a-lu-ci-na-dor",
    "alucinadora": "a-lu-ci-na-do-ra",
    "alucinamiento": "a-lu-ci-na-mien-to",
    "alucinante": "a-lu-ci-nan-te",
    "alucinantemente": "a-lu-ci-nan-te-men-te",
    "alucinar": "a-lu-ci-nar",
    "alucinatorio": "a-lu-ci-na-to-rio",
    "alucine": "a-lu-ci-ne",
    "alucinógeno": "a-lu-ci-nó-ge-no",
    "alucón": "a-lu-cón",
    "alud": "a-lud",
    "aluda": "a-lu-da",
    "aludel": "a-lu-del",
    "aludida": "a-lu-di-da",
    "aludido": "a-lu-di-do",
    "aludir": "a-lu-dir",
    "aludo": "a-lu-do",
    "alueñar": "a-lue-ñar",
    "alufrar": "a-lu-frar",
    "alugar": "a-lu-gar",
    "alujar": "a-lu-jar",
    "álula": "á-lu-la",
    "alumbrada": "a-lum-bra-da",
    "alumbrado": "a-lum-bra-do",
    "alumbrador": "a-lum-bra-dor",
    "alumbradora": "a-lum-bra-do-ra",
    "alumbramiento": "a-lum-bra-mien-to",
    "alumbrante": "a-lum-bran-te",
    "alumbrar": "a-lum-brar",
    "alumbre": "a-lum-bre",
    "alumbrera": "a-lum-bre-ra",
    "alumbrosa": "a-lum-bro-sa",
    "alumbroso": "a-lum-bro-so",
    "alúmina": "a-lú-mi-na",
    "aluminada": "a-lu-mi-na-da",
    "aluminado": "a-lu-mi-na-do",
    "aluminar": "a-lu-mi-nar",
    "aluminato": "a-lu-mi-na-to",
    "aluminio": "a-lu-mi-nio",
    "aluminita": "a-lu-mi-ni-ta",
    "aluminizar": "a-lu-mi-ni-zar",
    "aluminosa": "a-lu-mi-no-sa",
    "aluminosis": "a-lu-mi-no-sis",
    "aluminoso": "a-lu-mi-no-so",
    "aluminotermia": "a-lu-mi-no-ter-mia",
    "alumna": "a-lum-na",
    "alumnado": "a-lum-na-do",
    "alumno": "a-lum-no",
    "alunada": "a-lu-na-da",
    "alunado": "a-lu-na-do",
    "alunamiento": "a-lu-na-mien-to",
    "alunar": "a-lu-nar",
    "alunarada": "a-lu-na-ra-da",
    "alunarado": "a-lu-na-ra-do",
    "alunarse": "a-lu-nar-se",
    "alunizaje": "a-lu-ni-za-je",
    "alunizar": "a-lu-ni-zar",
    "alusión": "a-lu-sión",
    "alusiva": "a-lu-si-va",
    "alusivamente": "a-lu-si-va-men-te",
    "alusivo": "a-lu-si-vo",
    "alustrar": "a-lus-trar",
    "aluvial": "a-lu-vial",
    "aluvión": "a-lu-vión",
    "aluzar": "a-lu-zar",
    "alvareque": "al-va-re-que",
    "alveario": "al-ve-a-rio",
    "álveo": "ál-ve-o",
    "alveolado": "al-ve-o-la-do",
    "alveolar": "al-ve-o-lar",
    "alveolo": "al-ve-o-lo",
    "alvéolo": "al-vé-o-lo",
    "alveopalatal": "al-ve-o-pa-la-tal",
    "alverja": "al-ver-ja",
    "alverjado": "al-ver-ja-do",
    "alverjana": "al-ver-ja-na",
    "alverjilla": "al-ver-ji-lla",
    "alverjón": "al-ver-jón",
    "alvina": "al-vi-na",
    "alvino": "al-vi-no",
    "alza": "al-za",
    "alzacola": "al-za-co-la",
    "alzacuello": "al-za-cue-llo",
    "alzacuellos": "al-za-cue-llos",
    "alzada": "al-za-da",
    "alzadamente": "al-za-da-men-te",
    "alzadera": "al-za-de-ra",
    "alzadero": "al-za-de-ro",
    "alzadiza": "al-za-di-za",
    "alzadizo": "al-za-di-zo",
    "alzado": "al-za-do",
    "alzador": "al-za-dor",
    "alzadora": "al-za-do-ra",
    "alzadura": "al-za-du-ra",
    "alzafuelles": "al-za-fue-lles",
    "alzamiento": "al-za-mien-to",
    "alzapaño": "al-za-pa-ño",
    "alzapié": "al-za-pié",
    "alzapón": "al-za-pón",
    "alzaprima": "al-za-pri-ma",
    "alzaprimar": "al-za-pri-mar",
    "alzapuertas": "al-za-puer-tas",
    "alzar": "al-zar",
    "alzheimer": "al-zhei-mer",
    "alzhéimer": "al-zhéi-mer",
    "alzo": "al-zo",
    "ama": "a-ma",
    "amabilidad": "a-ma-bi-li-dad",
    "amabilísimo": "a-ma-bi-lí-si-mo",
    "amable": "a-ma-ble",
    "amablemente": "a-ma-ble-men-te",
    "amacayo": "a-ma-ca-yo",
    "amacena": "a-ma-ce-na",
    "amaceno": "a-ma-ce-no",
    "amachar": "a-ma-char",
    "amachetear": "a-ma-che-te-ar",
    "amachinar": "a-ma-chi-nar",
    "amachinarse": "a-ma-chi-nar-se",
    "amacho": "a-ma-cho",
    "amachorrar": "a-ma-cho-rrar",
    "amacigada": "a-ma-ci-ga-da",
    "amacigado": "a-ma-ci-ga-do",
    "amación": "a-ma-ción",
    "amacizar": "a-ma-ci-zar",
    "amacollar": "a-ma-co-llar",
    "amada": "a-ma-da",
    "amadeo": "a-ma-de-o",
    "amado": "a-ma-do",
    "amador": "a-ma-dor",
    "amadora": "a-ma-do-ra",
    "amadrigar": "a-ma-dri-gar",
    "amadrinamiento": "a-ma-dri-na-mien-to",
    "amadrinar": "a-ma-dri-nar",
    "amadroñada": "a-ma-dro-ña-da",
    "amadroñado": "a-ma-dro-ña-do",
    "amaestrada": "a-ma-es-tra-da",
    "amaestradamente": "a-ma-es-tra-da-men-te",
    "amaestrado": "a-ma-es-tra-do",
    "amaestrador": "a-ma-es-tra-dor",
    "amaestradora": "a-ma-es-tra-do-ra",
    "amaestradura": "a-ma-es-tra-du-ra",
    "amaestramiento": "a-ma-es-tra-mien-to",
    "amaestrar": "a-ma-es-trar",
    "amagamiento": "a-ma-ga-mien-to",
    "amagar": "a-ma-gar",
    "amagatorio": "a-ma-ga-to-rio",
    "amago": "a-ma-go",
    "ámago": "á-ma-go",
    "amainador": "a-mai-na-dor",
    "amainar": "a-mai-nar",
    "amaine": "a-mai-ne",
    "amaitinar": "a-mai-ti-nar",
    "amajadar": "a-ma-ja-dar",
    "amajanar": "a-ma-ja-nar",
    "ámala": "á-ma-la",
    "amalar": "a-ma-lar",
    "amalaya": "a-ma-la-ya",
    "amalayar": "a-ma-la-yar",
    "amalear": "a-ma-le-ar",
    "amalecita": "a-ma-le-ci-ta",
    "amalequita": "a-ma-le-qui-ta",
    "amalfitana": "a-mal-fi-ta-na",
    "amalfitano": "a-mal-fi-ta-no",
    "amalgama": "a-mal-ga-ma",
    "amalgamación": "a-mal-ga-ma-ción",
    "amalgamador": "a-mal-ga-ma-dor",
    "amalgamadora": "a-mal-ga-ma-do-ra",
    "amalgamamiento": "a-mal-ga-ma-mien-to",
    "amalgamar": "a-mal-ga-mar",
    "amalladar": "a-ma-lla-dar",
    "amallar": "a-ma-llar",
    "amallarse": "a-ma-llar-se",
    "ámalo": "á-ma-lo",
    "amamantador": "a-ma-man-ta-dor",
    "amamantadora": "a-ma-man-ta-do-ra",
    "amamantamiento": "a-ma-man-ta-mien-to",
    "amamantar": "a-ma-man-tar",
    "amambaiense": "a-mam-baien-se",
    "amán": "a-mán",
    "amanal": "a-ma-nal",
    "amanar": "a-ma-nar",
    "amañar": "a-ma-ñar",
    "amancay": "a-man-cay",
    "amancayo": "a-man-ca-yo",
    "amancebamiento": "a-man-ce-ba-mien-to",
    "amancebar": "a-man-ce-bar",
    "amancebarse": "a-man-ce-bar-se",
    "amancillar": "a-man-ci-llar",
    "amanear": "a-ma-ne-ar",
    "amanecer": "a-ma-ne-cer",
    "amanecida": "a-ma-ne-ci-da",
    "amanecido": "a-ma-ne-ci-do",
    "amanerada": "a-ma-ne-ra-da",
    "amanerado": "a-ma-ne-ra-do",
    "amaneramiento": "a-ma-ne-ra-mien-to",
    "amanerar": "a-ma-ne-rar",
    "amanesquera": "a-ma-nes-que-ra",
    "amanezca": "a-ma-nez-ca",
    "amanezco": "a-ma-nez-co",
    "amangualar": "a-man-gua-lar",
    "amaniatar": "a-ma-nia-tar",
    "amanita": "a-ma-ni-ta",
    "amaño": "a-ma-ño",
    "amanojada": "a-ma-no-ja-da",
    "amanojado": "a-ma-no-ja-do",
    "amanojar": "a-ma-no-jar",
    "amansaburros": "a-man-sa-bu-rros",
    "amansado": "a-man-sa-do",
    "amansador": "a-man-sa-dor",
    "amansadora": "a-man-sa-do-ra",
    "amansamiento": "a-man-sa-mien-to",
    "amansar": "a-man-sar",
    "amantar": "a-man-tar",
    "amante": "a-man-te",
    "amantero": "a-man-te-ro",
    "amantillar": "a-man-ti-llar",
    "amantillo": "a-man-ti-llo",
    "amanuense": "a-ma-nuen-se",
    "amanzanamiento": "a-man-za-na-mien-to",
    "amanzanar": "a-man-za-nar",
    "amapola": "a-ma-po-la",
    "amapolar": "a-ma-po-lar",
    "amar": "a-mar",
    "amara": "a-ma-ra",
    "amaracina": "a-ma-ra-ci-na",
    "amaracino": "a-ma-ra-ci-no",
    "amáraco": "a-má-ra-co",
    "amaraje": "a-ma-ra-je",
    "amarañar": "a-ma-ra-ñar",
    "amarantácea": "a-ma-ran-tá-ce-a",
    "amarantáceo": "a-ma-ran-tá-ce-o",
    "amarantina": "a-ma-ran-ti-na",
    "amaranto": "a-ma-ran-to",
    "amarar": "a-ma-rar",
    "amarcar": "a-mar-car",
    "amarchantar": "a-mar-chan-tar",
    "amarcigado": "a-mar-ci-ga-do",
    "amarecer": "a-ma-re-cer",
    "amarfilado": "a-mar-fi-la-do",
    "amarga": "a-mar-ga",
    "amargada": "a-mar-ga-da",
    "amargado": "a-mar-ga-do",
    "amargaleja": "a-mar-ga-le-ja",
    "amargamente": "a-mar-ga-men-te",
    "amargar": "a-mar-gar",
    "amargazón": "a-mar-ga-zón",
    "amargo": "a-mar-go",
    "amargón": "a-mar-gón",
    "amargor": "a-mar-gor",
    "amargosa": "a-mar-go-sa",
    "amargoso": "a-mar-go-so",
    "amarguera": "a-mar-gue-ra",
    "amarguero": "a-mar-gue-ro",
    "amarguillo": "a-mar-gui-llo",
    "amargura": "a-mar-gu-ra",
    "amaricada": "a-ma-ri-ca-da",
    "amaricado": "a-ma-ri-ca-do",
    "amariconado": "a-ma-ri-co-na-do",
    "amariconar": "a-ma-ri-co-nar",
    "amarilidácea": "a-ma-ri-li-dá-ce-a",
    "amarilidáceo": "a-ma-ri-li-dá-ce-o",
    "amarilídea": "a-ma-ri-lí-de-a",
    "amarilídeo": "a-ma-ri-lí-de-o",
    "amarilis": "a-ma-ri-lis",
    "amarilla": "a-ma-ri-lla",
    "amarillear": "a-ma-ri-lle-ar",
    "amarillecer": "a-ma-ri-lle-cer",
    "amarilleja": "a-ma-ri-lle-ja",
    "amarillejo": "a-ma-ri-lle-jo",
    "amarillenta": "a-ma-ri-llen-ta",
    "amarillento": "a-ma-ri-llen-to",
    "amarilleo": "a-ma-ri-lle-o",
    "amarillez": "a-ma-ri-llez",
    "amarillismo": "a-ma-ri-llis-mo",
    "amarillista": "a-ma-ri-llis-ta",
    "amarillo": "a-ma-ri-llo",
    "amarillor": "a-ma-ri-llor",
    "amarilloso": "a-ma-ri-llo-so",
    "amarillura": "a-ma-ri-llu-ra",
    "amarinar": "a-ma-ri-nar",
    "amariposada": "a-ma-ri-po-sa-da",
    "amariposado": "a-ma-ri-po-sa-do",
    "amaritud": "a-ma-ri-tud",
    "amarizaje": "a-ma-ri-za-je",
    "amarizar": "a-ma-ri-zar",
    "amarizarse": "a-ma-ri-zar-se",
    "amaro": "a-ma-ro",
    "amaromar": "a-ma-ro-mar",
    "amarra": "a-ma-rra",
    "amarraco": "a-ma-rra-co",
    "amarrada": "a-ma-rra-da",
    "amarradero": "a-ma-rra-de-ro",
    "amarradijo": "a-ma-rra-di-jo",
    "amarradillo": "a-ma-rra-di-llo",
    "amarrado": "a-ma-rra-do",
    "amarradura": "a-ma-rra-du-ra",
    "amarraje": "a-ma-rra-je",
    "amarrar": "a-ma-rrar",
    "amarre": "a-ma-rre",
    "amarreco": "a-ma-rre-co",
    "amarrequear": "a-ma-rre-que-ar",
    "amarreta": "a-ma-rre-ta",
    "amarrete": "a-ma-rre-te",
    "amarrida": "a-ma-rri-da",
    "amarrido": "a-ma-rri-do",
    "amarro": "a-ma-rro",
    "amarrocar": "a-ma-rro-car",
    "amarrón": "a-ma-rrón",
    "amarronado": "a-ma-rro-na-do",
    "amarroso": "a-ma-rro-so",
    "amartelada": "a-mar-te-la-da",
    "amarteladamente": "a-mar-te-la-da-men-te",
    "amartelado": "a-mar-te-la-do",
    "amartelamiento": "a-mar-te-la-mien-to",
    "amartelar": "a-mar-te-lar",
    "amartillar": "a-mar-ti-llar",
    "amarulencia": "a-ma-ru-len-cia",
    "amasadera": "a-ma-sa-de-ra",
    "amasadero": "a-ma-sa-de-ro",
    "amasado": "a-ma-sa-do",
    "amasador": "a-ma-sa-dor",
    "amasadora": "a-ma-sa-do-ra",
    "amasadura": "a-ma-sa-du-ra",
    "amasamiento": "a-ma-sa-mien-to",
    "amasandera": "a-ma-san-de-ra",
    "amasandería": "a-ma-san-de-rí-a",
    "amasandero": "a-ma-san-de-ro",
    "amasar": "a-ma-sar",
    "amasia": "a-ma-sia",
    "amasiato": "a-ma-sia-to",
    "amasijar": "a-ma-si-jar",
    "amasije": "a-ma-si-je",
    "amasijo": "a-ma-si-jo",
    "amasio": "a-ma-sio",
    "amatador": "a-ma-ta-dor",
    "amatadora": "a-ma-ta-do-ra",
    "amatal": "a-ma-tal",
    "amatar": "a-ma-tar",
    "amate": "a-ma-te",
    "amatera": "a-ma-te-ra",
    "amateur": "a-ma-teur",
    "amateurismo": "a-ma-teu-ris-mo",
    "amatista": "a-ma-tis-ta",
    "amatiste": "a-ma-tis-te",
    "amativa": "a-ma-ti-va",
    "amatividad": "a-ma-ti-vi-dad",
    "amativo": "a-ma-ti-vo",
    "amatonar": "a-ma-to-nar",
    "amatoria": "a-ma-to-ria",
    "amatorio": "a-ma-to-rio",
    "amaurosis": "a-mau-ro-sis",
    "amauta": "a-mau-ta",
    "amayorazgar": "a-ma-yo-raz-gar",
    "amayuela": "a-ma-yue-la",
    "amazacotada": "a-ma-za-co-ta-da",
    "amazacotado": "a-ma-za-co-ta-do",
    "amazona": "a-ma-zo-na",
    "amazonas": "a-ma-zo-nas",
    "amazonense": "a-ma-zo-nen-se",
    "amazonia": "a-ma-zo-nia",
    "amazónica": "a-ma-zó-ni-ca",
    "amazónico": "a-ma-zó-ni-co",
    "amazonio": "a-ma-zo-nio",
    "ambages": "am-ba-ges",
    "ambagiosa": "am-ba-gio-sa",
    "ambagioso": "am-ba-gio-so",
    "ámbar": "ám-bar",
    "ambarar": "am-ba-rar",
    "ambarina": "am-ba-ri-na",
    "ambarino": "am-ba-ri-no",
    "ambas": "am-bas",
    "ambateña": "am-ba-te-ña",
    "ambateño": "am-ba-te-ño",
    "amberina": "am-be-ri-na",
    "amberino": "am-be-ri-no",
    "ambición": "am-bi-ción",
    "ambicionar": "am-bi-cio-nar",
    "ambicionear": "am-bi-cio-ne-ar",
    "ambiciosa": "am-bi-cio-sa",
    "ambiciosamente": "am-bi-cio-sa-men-te",
    "ambicioso": "am-bi-cio-so",
    "ambidextra": "am-bi-dex-tra",
    "ambidextro": "am-bi-dex-tro",
    "ambidiestra": "am-bi-dies-tra",
    "ambidiestro": "am-bi-dies-tro",
    "ambientación": "am-bien-ta-ción",
    "ambientador": "am-bien-ta-dor",
    "ambientadora": "am-bien-ta-do-ra",
    "ambiental": "am-bien-tal",
    "ambientalismo": "am-bien-ta-lis-mo",
    "ambientar": "am-bien-tar",
    "ambiente": "am-bien-te",
    "ambigú": "am-bi-gú",
    "ambigua": "am-bi-gua",
    "ambiguamente": "am-bi-gua-men-te",
    "ambigüedad": "am-bi-güe-dad",
    "ambiguo": "am-bi-guo",
    "ámbito": "ám-bi-to",
    "ambivalencia": "am-bi-va-len-cia",
    "ambivalente": "am-bi-va-len-te",
    "ambivalentemente": "am-bi-va-len-te-men-te",
    "amblador": "am-bla-dor",
    "ambladora": "am-bla-do-ra",
    "ambladura": "am-bla-du-ra",
    "amblar": "am-blar",
    "ambleo": "am-ble-o",
    "ambligonio": "am-bli-go-nio",
    "ambliope": "am-blio-pe",
    "ambliopía": "am-blio-pí-a",
    "ambo": "am-bo",
    "ambón": "am-bón",
    "ambos": "am-bos",
    "ambrolla": "am-bro-lla",
    "ambrollar": "am-bro-llar",
    "ambrosía": "am-bro-sí-a",
    "ambrosiana": "am-bro-sia-na",
    "ambrosiano": "am-bro-sia-no",
    "ambuesta": "am-bues-ta",
    "ambueza": "am-bue-za",
    "ambulación": "am-bu-la-ción",
    "ambulacral": "am-bu-la-cral",
    "ambulacro": "am-bu-la-cro",
    "ambulancia": "am-bu-lan-cia",
    "ambulantaje": "am-bu-lan-ta-je",
    "ambulante": "am-bu-lan-te",
    "ambulantemente": "am-bu-lan-te-men-te",
    "ambular": "am-bu-lar",
    "ambulativa": "am-bu-la-ti-va",
    "ambulativo": "am-bu-la-ti-vo",
    "ambulatorio": "am-bu-la-to-rio",
    "ameba": "a-me-ba",
    "amebeo": "a-me-be-o",
    "amebiano": "a-me-bia-no",
    "amebiasis": "a-me-bia-sis",
    "amebiosis": "a-me-bio-sis",
    "amechar": "a-me-char",
    "amedrantar": "a-me-dran-tar",
    "amedrentador": "a-me-dren-ta-dor",
    "amedrentadora": "a-me-dren-ta-do-ra",
    "amedrentamiento": "a-me-dren-ta-mien-to",
    "amedrentar": "a-me-dren-tar",
    "amejoramiento": "a-me-jo-ra-mien-to",
    "ámel": "á-mel",
    "amelar": "a-me-lar",
    "amelarchiar": "a-me-lar-chiar",
    "amelcochado": "a-mel-co-cha-do",
    "amelcochar": "a-mel-co-char",
    "amelga": "a-mel-ga",
    "amelgada": "a-mel-ga-da",
    "amelgado": "a-mel-ga-do",
    "amelgador": "a-mel-ga-dor",
    "amelgar": "a-mel-gar",
    "amelía": "a-me-lí-a",
    "amellar": "a-me-llar",
    "amelo": "a-me-lo",
    "amelocotonada": "a-me-lo-co-to-na-da",
    "amelocotonado": "a-me-lo-co-to-na-do",
    "amelonada": "a-me-lo-na-da",
    "amelonado": "a-me-lo-na-do",
    "amembrillada": "a-mem-bri-lla-da",
    "amembrillado": "a-mem-bri-lla-do",
    "amén": "a-mén",
    "amena": "a-me-na",
    "amenamente": "a-me-na-men-te",
    "amenaza": "a-me-na-za",
    "amenazador": "a-me-na-za-dor",
    "amenazadora": "a-me-na-za-do-ra",
    "amenazante": "a-me-na-zan-te",
    "amenazar": "a-me-na-zar",
    "amencia": "a-men-cia",
    "amenguadamente": "a-men-gua-da-men-te",
    "amenguadera": "a-men-gua-de-ra",
    "amenguadero": "a-men-gua-de-ro",
    "amenguamiento": "a-men-gua-mien-to",
    "amenguar": "a-men-guar",
    "amenidad": "a-me-ni-dad",
    "amenizar": "a-me-ni-zar",
    "ameno": "a-me-no",
    "amenorar": "a-me-no-rar",
    "amenorgar": "a-me-nor-gar",
    "amenorrea": "a-me-no-rre-a",
    "amentácea": "a-men-tá-ce-a",
    "amentáceo": "a-men-tá-ce-o",
    "amente": "a-men-te",
    "amento": "a-men-to",
    "ameos": "a-me-os",
    "amerar": "a-me-rar",
    "amercear": "a-mer-ce-ar",
    "amercearse": "a-mer-ce-ar-se",
    "amercendear": "a-mer-cen-de-ar",
    "amercendearse": "a-mer-cen-de-ar-se",
    "amerengada": "a-me-ren-ga-da",
    "amerengado": "a-me-ren-ga-do",
    "américa": "a-mé-ri-ca",
    "americana": "a-me-ri-ca-na",
    "americanada": "a-me-ri-ca-na-da",
    "americanismo": "a-me-ri-ca-nis-mo",
    "americanista": "a-me-ri-ca-nis-ta",
    "americanización": "a-me-ri-ca-ni-za-ción",
    "americanizar": "a-me-ri-ca-ni-zar",
    "americano": "a-me-ri-ca-no",
    "americio": "a-me-ri-cio",
    "américo": "a-mé-ri-co",
    "amerindia": "a-me-rin-dia",
    "amerindio": "a-me-rin-dio",
    "ameritado": "a-me-ri-ta-do",
    "ameritar": "a-me-ri-tar",
    "amerizaje": "a-me-ri-za-je",
    "amerizar": "a-me-ri-zar",
    "amero": "a-me-ro",
    "amesnador": "a-mes-na-dor",
    "amesnar": "a-mes-nar",
    "amestizada": "a-mes-ti-za-da",
    "amestizado": "a-mes-ti-za-do",
    "amesurar": "a-me-su-rar",
    "ametalada": "a-me-ta-la-da",
    "ametalado": "a-me-ta-la-do",
    "ametalar": "a-me-ta-lar",
    "ametista": "a-me-tis-ta",
    "ametisto": "a-me-tis-to",
    "ametrallador": "a-me-tra-lla-dor",
    "ametralladora": "a-me-tra-lla-do-ra",
    "ametrallamiento": "a-me-tra-lla-mien-to",
    "ametrallar": "a-me-tra-llar",
    "ametría": "a-me-trí-a",
    "amétrico": "a-mé-tri-co",
    "amétrope": "a-mé-tro-pe",
    "ametropía": "a-me-tro-pí-a",
    "amezquindar": "a-mez-quin-dar",
    "amezquindarse": "a-mez-quin-dar-se",
    "ami": "a-mi",
    "amia": "a-mia",
    "amianta": "a-mian-ta",
    "amianto": "a-mian-to",
    "amiba": "a-mi-ba",
    "amibo": "a-mi-bo",
    "amicicia": "a-mi-ci-cia",
    "amicísima": "a-mi-cí-si-ma",
    "amicísimo": "a-mi-cí-si-mo",
    "amida": "a-mi-da",
    "amidos": "a-mi-dos",
    "amiento": "a-mien-to",
    "amiésgado": "a-miés-ga-do",
    "amiga": "a-mi-ga",
    "amigabilidad": "a-mi-ga-bi-li-dad",
    "amigable": "a-mi-ga-ble",
    "amigablemente": "a-mi-ga-ble-men-te",
    "amigacha": "a-mi-ga-cha",
    "amigacho": "a-mi-ga-cho",
    "amigajada": "a-mi-ga-ja-da",
    "amigajado": "a-mi-ga-ja-do",
    "amiganza": "a-mi-gan-za",
    "amigar": "a-mi-gar",
    "amígdala": "a-míg-da-la",
    "amigdalácea": "a-mig-da-lá-ce-a",
    "amigdaláceo": "a-mig-da-lá-ce-o",
    "amigdalina": "a-mig-da-li-na",
    "amigdalitis": "a-mig-da-li-tis",
    "amigo": "a-mi-go",
    "amigota": "a-mi-go-ta",
    "amigote": "a-mi-go-te",
    "amiguera": "a-mi-gue-ra",
    "amiguero": "a-mi-gue-ro",
    "amiguete": "a-mi-gue-te",
    "amiguismo": "a-mi-guis-mo",
    "amilácea": "a-mi-lá-ce-a",
    "amiláceo": "a-mi-lá-ce-o",
    "amilamia": "a-mi-la-mia",
    "amilanamiento": "a-mi-la-na-mien-to",
    "amilanar": "a-mi-la-nar",
    "amilasa": "a-mi-la-sa",
    "amílico": "a-mí-li-co",
    "amillaramiento": "a-mi-lla-ra-mien-to",
    "amillarar": "a-mi-lla-rar",
    "amillonada": "a-mi-llo-na-da",
    "amillonado": "a-mi-llo-na-do",
    "amiloideo": "a-mi-loi-de-o",
    "amilosa": "a-mi-lo-sa",
    "amimia": "a-mi-mia",
    "amín": "a-mín",
    "amina": "a-mi-na",
    "aminar": "a-mi-nar",
    "amínico": "a-mí-ni-co",
    "amino": "a-mi-no",
    "aminoácido": "a-mi-no-á-ci-do",
    "aminoración": "a-mi-no-ra-ción",
    "aminorar": "a-mi-no-rar",
    "amir": "a-mir",
    "amirí": "a-mi-rí",
    "amisión": "a-mi-sión",
    "amistad": "a-mis-tad",
    "amistanza": "a-mis-tan-za",
    "amistar": "a-mis-tar",
    "amistosa": "a-mis-to-sa",
    "amistosamente": "a-mis-to-sa-men-te",
    "amistoso": "a-mis-to-so",
    "amito": "a-mi-to",
    "amitosis": "a-mi-to-sis",
    "amitótica": "a-mi-tó-ti-ca",
    "amitótico": "a-mi-tó-ti-co",
    "ammaní": "am-ma-ní",
    "amnesia": "am-ne-sia",
    "amnésica": "am-né-si-ca",
    "amnésico": "am-né-si-co",
    "amnestía": "am-nes-tí-a",
    "amniocentesis": "am-nio-cen-te-sis",
    "amnios": "am-nios",
    "amnioscopia": "am-nios-co-pia",
    "amnioscopio": "am-nios-co-pio",
    "amniota": "am-nio-ta",
    "amniótica": "am-nió-ti-ca",
    "amniótico": "am-nió-ti-co",
    "amnistía": "am-nis-tí-a",
    "amnistiar": "am-nis-tiar",
    "amo": "a-mo",
    "amoblar": "a-mo-blar",
    "amochar": "a-mo-char",
    "amochiguar": "a-mo-chi-guar",
    "amodita": "a-mo-di-ta",
    "amodorrada": "a-mo-do-rra-da",
    "amodorrado": "a-mo-do-rra-do",
    "amodorramiento": "a-mo-do-rra-mien-to",
    "amodorrar": "a-mo-do-rrar",
    "amodorrarse": "a-mo-do-rrar-se",
    "amodorrecer": "a-mo-do-rre-cer",
    "amodorrida": "a-mo-do-rri-da",
    "amodorrido": "a-mo-do-rri-do",
    "amogotada": "a-mo-go-ta-da",
    "amogotado": "a-mo-go-ta-do",
    "amohecer": "a-mo-he-cer",
    "amohinamiento": "a-mohi-na-mien-to",
    "amohinar": "a-mohi-nar",
    "amohosar": "a-mo-ho-sar",
    "amojamamiento": "a-mo-ja-ma-mien-to",
    "amojamar": "a-mo-ja-mar",
    "amojelar": "a-mo-je-lar",
    "amojonador": "a-mo-jo-na-dor",
    "amojonamiento": "a-mo-jo-na-mien-to",
    "amojonar": "a-mo-jo-nar",
    "amok": "a-mok",
    "amol": "a-mol",
    "amolada": "a-mo-la-da",
    "amoladera": "a-mo-la-de-ra",
    "amolado": "a-mo-la-do",
    "amoladón": "a-mo-la-dón",
    "amolador": "a-mo-la-dor",
    "amoladora": "a-mo-la-do-ra",
    "amoladura": "a-mo-la-du-ra",
    "amolanchín": "a-mo-lan-chín",
    "amolar": "a-mo-lar",
    "amoldable": "a-mol-da-ble",
    "amoldador": "a-mol-da-dor",
    "amoldadora": "a-mol-da-do-ra",
    "amoldamiento": "a-mol-da-mien-to",
    "amoldar": "a-mol-dar",
    "amole": "a-mo-le",
    "amollador": "a-mo-lla-dor",
    "amolladora": "a-mo-lla-do-ra",
    "amollar": "a-mo-llar",
    "amollecer": "a-mo-lle-cer",
    "amollentadura": "a-mo-llen-ta-du-ra",
    "amollentar": "a-mo-llen-tar",
    "amollentativa": "a-mo-llen-ta-ti-va",
    "amollentativo": "a-mo-llen-ta-ti-vo",
    "amolletada": "a-mo-lle-ta-da",
    "amolletado": "a-mo-lle-ta-do",
    "amolotar": "a-mo-lo-tar",
    "amomo": "a-mo-mo",
    "amón": "a-món",
    "amonal": "a-mo-nal",
    "amonar": "a-mo-nar",
    "amondongada": "a-mon-don-ga-da",
    "amondongado": "a-mon-don-ga-do",
    "amonedación": "a-mo-ne-da-ción",
    "amonedar": "a-mo-ne-dar",
    "amonestación": "a-mo-nes-ta-ción",
    "amonestador": "a-mo-nes-ta-dor",
    "amonestadora": "a-mo-nes-ta-do-ra",
    "amonestamiento": "a-mo-nes-ta-mien-to",
    "amonestar": "a-mo-nes-tar",
    "amoniacal": "a-mo-nia-cal",
    "amoníaco": "a-mo-ní-a-co",
    "amoniaco": "a-mo-nia-co",
    "amónica": "a-mó-ni-ca",
    "amónico": "a-mó-ni-co",
    "amonio": "a-mo-nio",
    "amonita": "a-mo-ni-ta",
    "amonites": "a-mo-ni-tes",
    "amononar": "a-mo-no-nar",
    "amonotélico": "a-mo-no-té-li-co",
    "amontadgar": "a-mon-tad-gar",
    "amontar": "a-mon-tar",
    "amontazgar": "a-mon-taz-gar",
    "amontillado": "a-mon-ti-lla-do",
    "amontonadamente": "a-mon-to-na-da-men-te",
    "amontonador": "a-mon-to-na-dor",
    "amontonadora": "a-mon-to-na-do-ra",
    "amontonamiento": "a-mon-to-na-mien-to",
    "amontonar": "a-mon-to-nar",
    "amor": "a-mor",
    "amoragar": "a-mo-ra-gar",
    "amoral": "a-mo-ral",
    "amoralidad": "a-mo-ra-li-dad",
    "amoralismo": "a-mo-ra-lis-mo",
    "amoralista": "a-mo-ra-lis-ta",
    "amoralmente": "a-mo-ral-men-te",
    "amoratada": "a-mo-ra-ta-da",
    "amoratado": "a-mo-ra-ta-do",
    "amoratar": "a-mo-ra-tar",
    "amoratarse": "a-mo-ra-tar-se",
    "amorbar": "a-mor-bar",
    "amorcar": "a-mor-car",
    "amorcillado": "a-mor-ci-lla-do",
    "amorcillo": "a-mor-ci-llo",
    "amordazador": "a-mor-da-za-dor",
    "amordazadora": "a-mor-da-za-do-ra",
    "amordazamiento": "a-mor-da-za-mien-to",
    "amordazar": "a-mor-da-zar",
    "amorecada": "a-mo-re-ca-da",
    "amorecer": "a-mo-re-cer",
    "amorfa": "a-mor-fa",
    "amorfia": "a-mor-fia",
    "amorfismo": "a-mor-fis-mo",
    "amorfo": "a-mor-fo",
    "amorgonar": "a-mor-go-nar",
    "amoricones": "a-mo-ri-co-nes",
    "amorillar": "a-mo-ri-llar",
    "amorío": "a-mo-rí-o",
    "amoriscada": "a-mo-ris-ca-da",
    "amoriscado": "a-mo-ris-ca-do",
    "amormada": "a-mor-ma-da",
    "amormado": "a-mor-ma-do",
    "amormío": "a-mor-mí-o",
    "amorochar": "a-mo-ro-char",
    "amorosa": "a-mo-ro-sa",
    "amorosamente": "a-mo-ro-sa-men-te",
    "amorosiento": "a-mo-ro-sien-to",
    "amoroso": "a-mo-ro-so",
    "amorrar": "a-mo-rrar",
    "amorrea": "a-mo-rre-a",
    "amorreo": "a-mo-rre-o",
    "amorriñar": "a-mo-rri-ñar",
    "amorrionada": "a-mo-rrio-na-da",
    "amorrionado": "a-mo-rrio-na-do",
    "amorronar": "a-mo-rro-nar",
    "amortajador": "a-mor-ta-ja-dor",
    "amortajadora": "a-mor-ta-ja-do-ra",
    "amortajamiento": "a-mor-ta-ja-mien-to",
    "amortajar": "a-mor-ta-jar",
    "amortecer": "a-mor-te-cer",
    "amortecimiento": "a-mor-te-ci-mien-to",
    "amortiguación": "a-mor-ti-gua-ción",
    "amortiguador": "a-mor-ti-gua-dor",
    "amortiguadora": "a-mor-ti-gua-do-ra",
    "amortiguamiento": "a-mor-ti-gua-mien-to",
    "amortiguar": "a-mor-ti-guar",
    "amortizable": "a-mor-ti-za-ble",
    "amortización": "a-mor-ti-za-ción",
    "amortizar": "a-mor-ti-zar",
    "amos": "a-mos",
    "amosal": "a-mo-sal",
    "amoscador": "a-mos-ca-dor",
    "amoscamiento": "a-mos-ca-mien-to",
    "amoscar": "a-mos-car",
    "amosquilar": "a-mos-qui-lar",
    "amosquilarse": "a-mos-qui-lar-se",
    "amostachada": "a-mos-ta-cha-da",
    "amostachado": "a-mos-ta-cha-do",
    "amostazar": "a-mos-ta-zar",
    "amostramiento": "a-mos-tra-mien-to",
    "amostrar": "a-mos-trar",
    "amotetar": "a-mo-te-tar",
    "amotinada": "a-mo-ti-na-da",
    "amotinado": "a-mo-ti-na-do",
    "amotinador": "a-mo-ti-na-dor",
    "amotinadora": "a-mo-ti-na-do-ra",
    "amotinamiento": "a-mo-ti-na-mien-to",
    "amotinar": "a-mo-ti-nar",
    "amover": "a-mo-ver",
    "amovible": "a-mo-vi-ble",
    "amovilidad": "a-mo-vi-li-dad",
    "amoyote": "a-mo-yo-te",
    "ampalaba": "am-pa-la-ba",
    "ampalagua": "am-pa-la-gua",
    "amparador": "am-pa-ra-dor",
    "amparadora": "am-pa-ra-do-ra",
    "amparamiento": "am-pa-ra-mien-to",
    "amparar": "am-pa-rar",
    "amparo": "am-pa-ro",
    "ampay": "am-pay",
    "ampayar": "am-pa-yar",
    "ampelídea": "am-pe-lí-de-a",
    "ampelídeo": "am-pe-lí-de-o",
    "ampelita": "am-pe-li-ta",
    "ampelógrafa": "am-pe-ló-gra-fa",
    "ampelografía": "am-pe-lo-gra-fí-a",
    "ampelográfico": "am-pe-lo-grá-fi-co",
    "ampelógrafo": "am-pe-ló-gra-fo",
    "amperaje": "am-pe-ra-je",
    "ampere": "am-pe-re",
    "amperímetro": "am-pe-rí-me-tro",
    "amperio": "am-pe-rio",
    "ampervuelta": "am-per-vuel-ta",
    "ampicilina": "am-pi-ci-li-na",
    "ampla": "am-pla",
    "amplexicaulo": "am-ple-xi-cau-lo",
    "amplexo": "am-ple-xo",
    "amplia": "am-plia",
    "ampliable": "am-plia-ble",
    "ampliación": "am-plia-ción",
    "ampliador": "am-plia-dor",
    "ampliadora": "am-plia-do-ra",
    "ampliamente": "am-plia-men-te",
    "ampliar": "am-pliar",
    "ampliativa": "am-plia-ti-va",
    "ampliativo": "am-plia-ti-vo",
    "ampliatorio": "am-plia-to-rio",
    "amplificación": "am-pli-fi-ca-ción",
    "amplificador": "am-pli-fi-ca-dor",
    "amplificadora": "am-pli-fi-ca-do-ra",
    "amplificar": "am-pli-fi-car",
    "amplificativa": "am-pli-fi-ca-ti-va",
    "amplificativo": "am-pli-fi-ca-ti-vo",
    "amplio": "am-plio",
    "amplitud": "am-pli-tud",
    "amplo": "am-plo",
    "ampo": "am-po",
    "ampolla": "am-po-lla",
    "ampollar": "am-po-llar",
    "ampolleta": "am-po-lle-ta",
    "ampón": "am-pón",
    "ampona": "am-po-na",
    "amprar": "am-prar",
    "ámpula": "ám-pu-la",
    "ampulosa": "am-pu-lo-sa",
    "ampulosamente": "am-pu-lo-sa-men-te",
    "ampulosidad": "am-pu-lo-si-dad",
    "ampuloso": "am-pu-lo-so",
    "ampurdanés": "am-pur-da-nés",
    "ampurdanesa": "am-pur-da-ne-sa",
    "amputación": "am-pu-ta-ción",
    "amputar": "am-pu-tar",
    "amsterdamés": "ams-ter-da-més",
    "amsterdamesa": "ams-ter-da-me-sa",
    "amuchachada": "a-mu-cha-cha-da",
    "amuchachado": "a-mu-cha-cha-do",
    "amuchar": "a-mu-char",
    "amuchiguar": "a-mu-chi-guar",
    "amueblada": "a-mue-bla-da",
    "amueblado": "a-mue-bla-do",
    "amueblamiento": "a-mue-bla-mien-to",
    "amueblar": "a-mue-blar",
    "amuelar": "a-mue-lar",
    "amuermado": "a-muer-ma-do",
    "amuermar": "a-muer-mar",
    "amufar": "a-mu-far",
    "amugamiento": "a-mu-ga-mien-to",
    "amugar": "a-mu-gar",
    "amugronador": "a-mu-gro-na-dor",
    "amugronadora": "a-mu-gro-na-do-ra",
    "amugronamiento": "a-mu-gro-na-mien-to",
    "amugronar": "a-mu-gro-nar",
    "amuinar": "a-mui-nar",
    "amujerada": "a-mu-je-ra-da",
    "amujerado": "a-mu-je-ra-do",
    "amujeramiento": "a-mu-je-ra-mien-to",
    "amular": "a-mu-lar",
    "amulatada": "a-mu-la-ta-da",
    "amulatado": "a-mu-la-ta-do",
    "amuleto": "a-mu-le-to",
    "amuñecada": "a-mu-ñe-ca-da",
    "amuñecado": "a-mu-ñe-ca-do",
    "amunicionar": "a-mu-ni-cio-nar",
    "amuñuñar": "a-mu-ñu-ñar",
    "amura": "a-mu-ra",
    "amurada": "a-mu-ra-da",
    "amurallada": "a-mu-ra-lla-da",
    "amurallado": "a-mu-ra-lla-do",
    "amurallar": "a-mu-ra-llar",
    "amurar": "a-mu-rar",
    "amurca": "a-mur-ca",
    "amurcar": "a-mur-car",
    "amurco": "a-mur-co",
    "amurillar": "a-mu-ri-llar",
    "amurrar": "a-mu-rrar",
    "amurriñar": "a-mu-rri-ñar",
    "amurriñarse": "a-mu-rri-ñar-se",
    "amusca": "a-mus-ca",
    "amusco": "a-mus-co",
    "amusepar": "a-mu-se-par",
    "amusga": "a-mus-ga",
    "amusgar": "a-mus-gar",
    "amusgo": "a-mus-go",
    "amuso": "a-mu-so",
    "amustiar": "a-mus-tiar",
    "amuzga": "a-muz-ga",
    "amuzgo": "a-muz-go",
    "ana": "a-na",
    "aña": "a-ña",
    "anabaptismo": "a-na-bap-tis-mo",
    "anabaptista": "a-na-bap-tis-ta",
    "anabatista": "a-na-ba-tis-ta",
    "anabí": "a-na-bí",
    "anabolena": "a-na-bo-le-na",
    "anabólica": "a-na-bó-li-ca",
    "anabólico": "a-na-bó-li-co",
    "anabolismo": "a-na-bo-lis-mo",
    "anabolizante": "a-na-bo-li-zan-te",
    "anacahuita": "a-na-ca-hui-ta",
    "anacahuite": "a-na-ca-hui-te",
    "añacal": "a-ña-cal",
    "anacala": "a-na-ca-la",
    "añacalero": "a-ña-ca-le-ro",
    "anacalo": "a-na-ca-lo",
    "anacanto": "a-na-can-to",
    "anacarada": "a-na-ca-ra-da",
    "anacarado": "a-na-ca-ra-do",
    "anacardiácea": "a-na-car-diá-ce-a",
    "anacardiáceo": "a-na-car-diá-ce-o",
    "anacardina": "a-na-car-di-na",
    "anacardino": "a-na-car-di-no",
    "anacardo": "a-na-car-do",
    "añacea": "a-ña-ce-a",
    "añacear": "a-ña-ce-ar",
    "anaco": "a-na-co",
    "anacoluto": "a-na-co-lu-to",
    "anaconda": "a-na-con-da",
    "anacora": "a-na-co-ra",
    "anacoresis": "a-na-co-re-sis",
    "anacoreta": "a-na-co-re-ta",
    "anacorética": "a-na-co-ré-ti-ca",
    "anacorético": "a-na-co-ré-ti-co",
    "anacorita": "a-na-co-ri-ta",
    "anacreóntica": "a-na-cre-ón-ti-ca",
    "anacreóntico": "a-na-cre-ón-ti-co",
    "anacrónica": "a-na-cró-ni-ca",
    "anacrónicamente": "a-na-cró-ni-ca-men-te",
    "anacrónico": "a-na-cró-ni-co",
    "anacronismo": "a-na-cro-nis-mo",
    "anacrusa": "a-na-cru-sa",
    "añada": "a-ña-da",
    "ánade": "á-na-de",
    "anadear": "a-na-de-ar",
    "añadida": "a-ña-di-da",
    "añadido": "a-ña-di-do",
    "añadidura": "a-ña-di-du-ra",
    "añadimiento": "a-ña-di-mien-to",
    "anadina": "a-na-di-na",
    "anadino": "a-na-di-no",
    "anadiplosis": "a-na-di-plo-sis",
    "añadir": "a-ña-dir",
    "anadón": "a-na-dón",
    "anádroma": "a-ná-dro-ma",
    "anádromo": "a-ná-dro-mo",
    "anaeróbica": "a-na-e-ró-bi-ca",
    "anaeróbico": "a-na-e-ró-bi-co",
    "anaerobio": "a-na-e-ro-bio",
    "anaerobiosis": "a-na-e-ro-bio-sis",
    "anafaga": "a-na-fa-ga",
    "anafalla": "a-na-fa-lla",
    "anafase": "a-na-fa-se",
    "anafaya": "a-na-fa-ya",
    "anafe": "a-na-fe",
    "añafea": "a-ña-fe-a",
    "añafil": "a-ña-fil",
    "anafiláctico": "a-na-fi-lác-ti-co",
    "anafilaxia": "a-na-fi-la-xia",
    "anafilaxis": "a-na-fi-la-xis",
    "añafilera": "a-ña-fi-le-ra",
    "añafilero": "a-ña-fi-le-ro",
    "anáfora": "a-ná-fo-ra",
    "anafórica": "a-na-fó-ri-ca",
    "anafóricamente": "a-na-fó-ri-ca-men-te",
    "anafórico": "a-na-fó-ri-co",
    "anafre": "a-na-fre",
    "anafrodisia": "a-na-fro-di-sia",
    "anafrodisíaca": "a-na-fro-di-sí-a-ca",
    "anafrodisiaca": "a-na-fro-di-sia-ca",
    "anafrodisíaco": "a-na-fro-di-sí-a-co",
    "anafrodisiaco": "a-na-fro-di-sia-co",
    "anafrodita": "a-na-fro-di-ta",
    "añagaza": "a-ña-ga-za",
    "anaglífica": "a-na-glí-fi-ca",
    "anaglífico": "a-na-glí-fi-co",
    "anaglifo": "a-na-gli-fo",
    "anagnórisis": "a-nag-nó-ri-sis",
    "anagoge": "a-na-go-ge",
    "anagogía": "a-na-go-gí-a",
    "anagógica": "a-na-gó-gi-ca",
    "anagógico": "a-na-gó-gi-co",
    "anagrama": "a-na-gra-ma",
    "anagramática": "a-na-gra-má-ti-ca",
    "anagramático": "a-na-gra-má-ti-co",
    "anagramatista": "a-na-gra-ma-tis-ta",
    "anagramista": "a-na-gra-mis-ta",
    "anahuaca": "a-na-hua-ca",
    "anahuacense": "a-na-hua-cen-se",
    "anaiboa": "a-nai-bo-a",
    "anal": "a-nal",
    "añal": "a-ñal",
    "analco": "a-nal-co",
    "analectas": "a-na-lec-tas",
    "añalejo": "a-ña-le-jo",
    "analepsis": "a-na-lep-sis",
    "analéptica": "a-na-lép-ti-ca",
    "analéptico": "a-na-lép-ti-co",
    "analfabeta": "a-nal-fa-be-ta",
    "analfabetismo": "a-nal-fa-be-tis-mo",
    "analfabeto": "a-nal-fa-be-to",
    "analgesia": "a-nal-ge-sia",
    "analgésica": "a-nal-gé-si-ca",
    "analgésico": "a-nal-gé-si-co",
    "análisis": "a-ná-li-sis",
    "analista": "a-na-lis-ta",
    "analística": "a-na-lís-ti-ca",
    "analístico": "a-na-lís-ti-co",
    "analítica": "a-na-lí-ti-ca",
    "analíticamente": "a-na-lí-ti-ca-men-te",
    "analítico": "a-na-lí-ti-co",
    "analizable": "a-na-li-za-ble",
    "analizador": "a-na-li-za-dor",
    "analizadora": "a-na-li-za-do-ra",
    "analizar": "a-na-li-zar",
    "análoga": "a-ná-lo-ga",
    "análogamente": "a-ná-lo-ga-men-te",
    "analogía": "a-na-lo-gí-a",
    "analógica": "a-na-ló-gi-ca",
    "analógicamente": "a-na-ló-gi-ca-men-te",
    "analógico": "a-na-ló-gi-co",
    "análogo": "a-ná-lo-go",
    "anamita": "a-na-mi-ta",
    "anamnesis": "a-nam-ne-sis",
    "anamniota": "a-nam-nio-ta",
    "anamniótico": "a-nam-nió-ti-co",
    "anamórfico": "a-na-mór-fi-co",
    "anamorfosis": "a-na-mor-fo-sis",
    "anamú": "a-na-mú",
    "ananá": "a-na-ná",
    "ananás": "a-na-nás",
    "ananay": "a-na-nay",
    "añañay": "a-ña-ñay",
    "añangotar": "a-ñan-go-tar",
    "anapelo": "a-na-pe-lo",
    "anapéstica": "a-na-pés-ti-ca",
    "anapéstico": "a-na-pés-ti-co",
    "anapesto": "a-na-pes-to",
    "anaplasia": "a-na-pla-sia",
    "anaplastia": "a-na-plas-tia",
    "anaptixis": "a-nap-ti-xis",
    "anaquel": "a-na-quel",
    "anaquelería": "a-na-que-le-rí-a",
    "anaranjada": "a-na-ran-ja-da",
    "anaranjado": "a-na-ran-ja-do",
    "anaranjear": "a-na-ran-je-ar",
    "anarco": "a-nar-co",
    "anarcosindicalismo": "a-nar-co-sin-di-ca-lis-mo",
    "anarcosindicalista": "a-nar-co-sin-di-ca-lis-ta",
    "añares": "a-ña-res",
    "anarquía": "a-nar-quí-a",
    "anárquica": "a-nár-qui-ca",
    "anárquicamente": "a-nár-qui-ca-men-te",
    "anárquico": "a-nár-qui-co",
    "anarquismo": "a-nar-quis-mo",
    "anarquista": "a-nar-quis-ta",
    "anarquizante": "a-nar-qui-zan-te",
    "anarquizar": "a-nar-qui-zar",
    "añás": "a-ñás",
    "anasarca": "a-na-sar-ca",
    "añascar": "a-ñas-car",
    "anascote": "a-nas-co-te",
    "anastasia": "a-nas-ta-sia",
    "anastigmática": "a-nas-tig-má-ti-ca",
    "anastigmático": "a-nas-tig-má-ti-co",
    "anastomizar": "a-nas-to-mi-zar",
    "anastomizarse": "a-nas-to-mi-zar-se",
    "anastomosar": "a-nas-to-mo-sar",
    "anastomosarse": "a-nas-to-mo-sar-se",
    "anastomosis": "a-nas-to-mo-sis",
    "anástrofe": "a-nás-tro-fe",
    "anata": "a-na-ta",
    "anatada": "a-na-ta-da",
    "anatado": "a-na-ta-do",
    "anatema": "a-na-te-ma",
    "anatematismo": "a-na-te-ma-tis-mo",
    "anatematizador": "a-na-te-ma-ti-za-dor",
    "anatematizadora": "a-na-te-ma-ti-za-do-ra",
    "anatematizar": "a-na-te-ma-ti-zar",
    "anatemizar": "a-na-te-mi-zar",
    "anátida": "a-ná-ti-da",
    "anátidas": "a-ná-ti-das",
    "anátido": "a-ná-ti-do",
    "anatiforme": "a-na-ti-for-me",
    "anatista": "a-na-tis-ta",
    "anatolio": "a-na-to-lio",
    "anatomía": "a-na-to-mí-a",
    "anatómica": "a-na-tó-mi-ca",
    "anatómicamente": "a-na-tó-mi-ca-men-te",
    "anatómico": "a-na-tó-mi-co",
    "anatomista": "a-na-to-mis-ta",
    "anatomizar": "a-na-to-mi-zar",
    "anatomopatóloga": "a-na-to-mo-pa-tó-lo-ga",
    "anatomopatológico": "a-na-to-mo-pa-to-ló-gi-co",
    "anatomopatólogo": "a-na-to-mo-pa-tó-lo-go",
    "anavia": "a-na-via",
    "anay": "a-nay",
    "añazme": "a-ñaz-me",
    "anca": "an-ca",
    "ancada": "an-ca-da",
    "ancado": "an-ca-do",
    "ancashina": "an-cas-hi-na",
    "ancashino": "an-cas-hi-no",
    "ancestral": "an-ces-tral",
    "ancestralmente": "an-ces-tral-men-te",
    "ancestro": "an-ces-tro",
    "ancha": "an-cha",
    "anchamente": "an-cha-men-te",
    "anchar": "an-char",
    "ancharia": "an-cha-ria",
    "ancheta": "an-che-ta",
    "ancheza": "an-che-za",
    "anchicorta": "an-chi-cor-ta",
    "anchicorto": "an-chi-cor-to",
    "ancho": "an-cho",
    "anchoa": "an-cho-a",
    "anchoar": "an-cho-ar",
    "anchor": "an-chor",
    "anchova": "an-cho-va",
    "anchoveta": "an-cho-ve-ta",
    "anchuelo": "an-chue-lo",
    "anchura": "an-chu-ra",
    "anchurón": "an-chu-rón",
    "anchurosa": "an-chu-ro-sa",
    "anchuroso": "an-chu-ro-so",
    "anciana": "an-cia-na",
    "ancianamente": "an-cia-na-men-te",
    "ancianato": "an-cia-na-to",
    "ancianía": "an-cia-ní-a",
    "ancianidad": "an-cia-ni-dad",
    "ancianismo": "an-cia-nis-mo",
    "anciano": "an-cia-no",
    "ancila": "an-ci-la",
    "ancilar": "an-ci-lar",
    "ancilario": "an-ci-la-rio",
    "ancla": "an-cla",
    "ancladero": "an-cla-de-ro",
    "anclaje": "an-cla-je",
    "anclar": "an-clar",
    "anclear": "an-cle-ar",
    "anclote": "an-clo-te",
    "ancoche": "an-co-che",
    "ancón": "an-cón",
    "anconada": "an-co-na-da",
    "anconitana": "an-co-ni-ta-na",
    "anconitano": "an-co-ni-ta-no",
    "áncora": "án-co-ra",
    "ancorado": "an-co-ra-do",
    "ancoraje": "an-co-ra-je",
    "ancorar": "an-co-rar",
    "ancorca": "an-cor-ca",
    "ancorel": "an-co-rel",
    "ancorería": "an-co-re-rí-a",
    "ancorero": "an-co-re-ro",
    "ancua": "an-cua",
    "ancuco": "an-cu-co",
    "ancuda": "an-cu-da",
    "ancudo": "an-cu-do",
    "ancusa": "an-cu-sa",
    "ancuviña": "an-cu-vi-ña",
    "anda": "an-da",
    "andábata": "an-dá-ba-ta",
    "andaboba": "an-da-bo-ba",
    "andada": "an-da-da",
    "andadera": "an-da-de-ra",
    "andadero": "an-da-de-ro",
    "andado": "an-da-do",
    "andador": "an-da-dor",
    "andadora": "an-da-do-ra",
    "andadura": "an-da-du-ra",
    "andahuailina": "an-da-huai-li-na",
    "andahuailino": "an-da-huai-li-no",
    "andalia": "an-da-lia",
    "andalón": "an-da-lón",
    "andalotera": "an-da-lo-te-ra",
    "andalotero": "an-da-lo-te-ro",
    "andalucismo": "an-da-lu-cis-mo",
    "andalucista": "an-da-lu-cis-ta",
    "andalucita": "an-da-lu-ci-ta",
    "andalusí": "an-da-lu-sí",
    "andaluz": "an-da-luz",
    "andaluza": "an-da-lu-za",
    "andaluzada": "an-da-lu-za-da",
    "andamiada": "an-da-mia-da",
    "andamiaje": "an-da-mia-je",
    "andamiar": "an-da-miar",
    "andamiento": "an-da-mien-to",
    "andamio": "an-da-mio",
    "andana": "an-da-na",
    "andanada": "an-da-na-da",
    "andancia": "an-dan-cia",
    "andancio": "an-dan-cio",
    "andaniño": "an-da-ni-ño",
    "andante": "an-dan-te",
    "andantesca": "an-dan-tes-ca",
    "andantesco": "an-dan-tes-co",
    "andantino": "an-dan-ti-no",
    "andanza": "an-dan-za",
    "andar": "an-dar",
    "andaraje": "an-da-ra-je",
    "andarica": "an-da-ri-ca",
    "andariega": "an-da-rie-ga",
    "andariego": "an-da-rie-go",
    "andarín": "an-da-rín",
    "andarina": "an-da-ri-na",
    "andarivel": "an-da-ri-vel",
    "andarraya": "an-da-rra-ya",
    "andarríos": "an-da-rrí-os",
    "andas": "an-das",
    "andavete": "an-da-ve-te",
    "andel": "an-del",
    "andén": "an-dén",
    "andenería": "an-de-ne-rí-a",
    "andero": "an-de-ro",
    "andesina": "an-de-si-na",
    "andesita": "an-de-si-ta",
    "andestre": "an-des-tre",
    "andina": "an-di-na",
    "andinismo": "an-di-nis-mo",
    "andinista": "an-di-nis-ta",
    "andino": "an-di-no",
    "ándito": "án-di-to",
    "andoba": "an-do-ba",
    "andóbal": "an-dó-bal",
    "andobas": "an-do-bas",
    "andola": "an-do-la",
    "andolencia": "an-do-len-cia",
    "andolina": "an-do-li-na",
    "andón": "an-dón",
    "andona": "an-do-na",
    "andorga": "an-dor-ga",
    "andorina": "an-do-ri-na",
    "andorra": "an-do-rra",
    "andorrana": "an-do-rra-na",
    "andorrano": "an-do-rra-no",
    "andorrear": "an-do-rre-ar",
    "andorrera": "an-do-rre-ra",
    "andorrero": "an-do-rre-ro",
    "andosca": "an-dos-ca",
    "andosco": "an-dos-co",
    "andova": "an-do-va",
    "andóval": "an-dó-val",
    "andrada": "an-dra-da",
    "andrado": "an-dra-do",
    "andrajera": "an-dra-je-ra",
    "andrajero": "an-dra-je-ro",
    "andrajo": "an-dra-jo",
    "andrajosa": "an-dra-jo-sa",
    "andrajosamente": "an-dra-jo-sa-men-te",
    "andrajoso": "an-dra-jo-so",
    "andrés": "an-drés",
    "andriana": "an-dria-na",
    "andrina": "an-dri-na",
    "andrino": "an-dri-no",
    "androcéntrico": "an-dro-cén-tri-co",
    "androcentrismo": "an-dro-cen-tris-mo",
    "androceo": "an-dro-ce-o",
    "andrófoba": "an-dró-fo-ba",
    "androfobia": "an-dro-fo-bia",
    "andrófobo": "an-dró-fo-bo",
    "androgénesis": "an-dro-gé-ne-sis",
    "androgénico": "an-dro-gé-ni-co",
    "andrógeno": "an-dró-ge-no",
    "andrógina": "an-dró-gi-na",
    "androginia": "an-dro-gi-nia",
    "andrógino": "an-dró-gi-no",
    "androide": "an-droi-de",
    "andróloga": "an-dró-lo-ga",
    "andrología": "an-dro-lo-gí-a",
    "andrológico": "an-dro-ló-gi-co",
    "andrólogo": "an-dró-lo-go",
    "andrómina": "an-dró-mi-na",
    "andropausia": "an-dro-pau-sia",
    "androsemo": "an-dro-se-mo",
    "andujareña": "an-du-ja-re-ña",
    "andujareño": "an-du-ja-re-ño",
    "andulario": "an-du-la-rio",
    "andulencia": "an-du-len-cia",
    "andullo": "an-du-llo",
    "andurrial": "an-du-rrial",
    "anea": "a-ne-a",
    "aneaje": "a-ne-a-je",
    "anear": "a-ne-ar",
    "aneblar": "a-ne-blar",
    "anécdota": "a-néc-do-ta",
    "anecdotario": "a-nec-do-ta-rio",
    "anecdótica": "a-nec-dó-ti-ca",
    "anecdóticamente": "a-nec-dó-ti-ca-men-te",
    "anecdótico": "a-nec-dó-ti-co",
    "anecdotismo": "a-nec-do-tis-mo",
    "anecdotista": "a-nec-do-tis-ta",
    "aneciar": "a-ne-ciar",
    "aneciarse": "a-ne-ciar-se",
    "anecoico": "a-ne-coi-co",
    "añedir": "a-ñe-dir",
    "anegable": "a-ne-ga-ble",
    "anegación": "a-ne-ga-ción",
    "anegadiza": "a-ne-ga-di-za",
    "anegadizo": "a-ne-ga-di-zo",
    "anegamiento": "a-ne-ga-mien-to",
    "anegar": "a-ne-gar",
    "anegociada": "a-ne-go-cia-da",
    "anegociado": "a-ne-go-cia-do",
    "aneja": "a-ne-ja",
    "añeja": "a-ñe-ja",
    "añejado": "a-ñe-ja-do",
    "añejamiento": "a-ñe-ja-mien-to",
    "anejar": "a-ne-jar",
    "añejar": "a-ñe-jar",
    "añejez": "a-ñe-jez",
    "anejir": "a-ne-jir",
    "anejo": "a-ne-jo",
    "añejo": "a-ñe-jo",
    "aneldo": "a-nel-do",
    "anélido": "a-né-li-do",
    "anemia": "a-ne-mia",
    "anémica": "a-né-mi-ca",
    "anémico": "a-né-mi-co",
    "anemocordio": "a-ne-mo-cor-dio",
    "anemófila": "a-ne-mó-fi-la",
    "anemofilia": "a-ne-mo-fi-lia",
    "anemófilo": "a-ne-mó-fi-lo",
    "anemógrafa": "a-ne-mó-gra-fa",
    "anemografía": "a-ne-mo-gra-fí-a",
    "anemográfica": "a-ne-mo-grá-fi-ca",
    "anemográfico": "a-ne-mo-grá-fi-co",
    "anemógrafo": "a-ne-mó-gra-fo",
    "anemometría": "a-ne-mo-me-trí-a",
    "anemométrica": "a-ne-mo-mé-tri-ca",
    "anemométrico": "a-ne-mo-mé-tri-co",
    "anemómetro": "a-ne-mó-me-tro",
    "anemona": "a-ne-mo-na",
    "anémona": "a-né-mo-na",
    "anemone": "a-ne-mo-ne",
    "anemoscopio": "a-ne-mos-co-pio",
    "aneota": "a-ne-o-ta",
    "anepigráfica": "a-ne-pi-grá-fi-ca",
    "anepigráfico": "a-ne-pi-grá-fi-co",
    "añera": "a-ñe-ra",
    "añero": "a-ñe-ro",
    "aneroide": "a-ne-roi-de",
    "anestesia": "a-nes-te-sia",
    "anestesiar": "a-nes-te-siar",
    "anestésica": "a-nes-té-si-ca",
    "anestésico": "a-nes-té-si-co",
    "anestesióloga": "a-nes-te-sió-lo-ga",
    "anestesiología": "a-nes-te-sio-lo-gí-a",
    "anestesiólogo": "a-nes-te-sió-lo-go",
    "anestesista": "a-nes-te-sis-ta",
    "aneto": "a-ne-to",
    "aneurisma": "a-neu-ris-ma",
    "anexa": "a-ne-xa",
    "anexar": "a-ne-xar",
    "anexidad": "a-ne-xi-dad",
    "anexión": "a-ne-xión",
    "anexionar": "a-ne-xio-nar",
    "anexionismo": "a-ne-xio-nis-mo",
    "anexionista": "a-ne-xio-nis-ta",
    "anexitis": "a-ne-xi-tis",
    "anexo": "a-ne-xo",
    "anfesibena": "an-fe-si-be-na",
    "anfeta": "an-fe-ta",
    "anfetamina": "an-fe-ta-mi-na",
    "anfetamínico": "an-fe-ta-mí-ni-co",
    "anfi": "an-fi",
    "anfibia": "an-fi-bia",
    "anfibio": "an-fi-bio",
    "anfíbol": "an-fí-bol",
    "anfibolita": "an-fi-bo-li-ta",
    "anfibología": "an-fi-bo-lo-gí-a",
    "anfibológica": "an-fi-bo-ló-gi-ca",
    "anfibológicamente": "an-fi-bo-ló-gi-ca-men-te",
    "anfibológico": "an-fi-bo-ló-gi-co",
    "anfíbraco": "an-fí-bra-co",
    "anfictión": "an-fic-tión",
    "anfictionado": "an-fic-tio-na-do",
    "anfictionía": "an-fic-tio-ní-a",
    "anfictiónica": "an-fic-tió-ni-ca",
    "anfictiónico": "an-fic-tió-ni-co",
    "anfígeno": "an-fí-ge-no",
    "anfímacro": "an-fí-ma-cro",
    "anfineuro": "an-fi-neu-ro",
    "anfión": "an-fión",
    "anfioxo": "an-fio-xo",
    "anfípodo": "an-fí-po-do",
    "anfipróstilo": "an-fi-prós-ti-lo",
    "anfisbena": "an-fis-be-na",
    "anfiscia": "an-fis-cia",
    "anfiscio": "an-fis-cio",
    "anfisibena": "an-fi-si-be-na",
    "anfiteatro": "an-fi-te-a-tro",
    "anfitrión": "an-fi-trión",
    "anfitriona": "an-fi-trio-na",
    "ánfora": "án-fo-ra",
    "anfótero": "an-fó-te-ro",
    "anfractuosa": "an-frac-tuo-sa",
    "anfractuosidad": "an-frac-tuo-si-dad",
    "anfractuoso": "an-frac-tuo-so",
    "anganillas": "an-ga-ni-llas",
    "angaria": "an-ga-ria",
    "angarilla": "an-ga-ri-lla",
    "angarillada": "an-ga-ri-lla-da",
    "angarillar": "an-ga-ri-llar",
    "angarillas": "an-ga-ri-llas",
    "angarillero": "an-ga-ri-lle-ro",
    "angarillo": "an-ga-ri-llo",
    "angaripola": "an-ga-ri-po-la",
    "ángaro": "án-ga-ro",
    "angazo": "an-ga-zo",
    "ángel": "án-gel",
    "ángela": "án-ge-la",
    "angélica": "an-gé-li-ca",
    "angelical": "an-ge-li-cal",
    "angelicalmente": "an-ge-li-cal-men-te",
    "angelico": "an-ge-li-co",
    "angélico": "an-gé-li-co",
    "angelín": "an-ge-lín",
    "angelina": "an-ge-li-na",
    "angelino": "an-ge-li-no",
    "angelito": "an-ge-li-to",
    "angelizar": "an-ge-li-zar",
    "angelología": "an-ge-lo-lo-gí-a",
    "angelón": "an-ge-lón",
    "angelopolitana": "an-ge-lo-po-li-ta-na",
    "angelopolitano": "an-ge-lo-po-li-ta-no",
    "angelota": "an-ge-lo-ta",
    "angelote": "an-ge-lo-te",
    "ángelus": "án-ge-lus",
    "angevino": "an-ge-vi-no",
    "angina": "an-gi-na",
    "anginosa": "an-gi-no-sa",
    "anginoso": "an-gi-no-so",
    "angiogénesis": "an-gio-gé-ne-sis",
    "angiografía": "an-gio-gra-fí-a",
    "angiográfico": "an-gio-grá-fi-co",
    "angiograma": "an-gio-gra-ma",
    "angióloga": "an-gió-lo-ga",
    "angiología": "an-gio-lo-gí-a",
    "angiológico": "an-gio-ló-gi-co",
    "angiólogo": "an-gió-lo-go",
    "angioma": "an-gio-ma",
    "angioplastia": "an-gio-plas-tia",
    "angiosperma": "an-gios-per-ma",
    "angiospermas": "an-gios-per-mas",
    "angiospermo": "an-gios-per-mo",
    "angitis": "an-gi-tis",
    "angla": "an-gla",
    "anglesita": "an-gle-si-ta",
    "anglicado": "an-gli-ca-do",
    "anglicana": "an-gli-ca-na",
    "anglicanismo": "an-gli-ca-nis-mo",
    "anglicanizada": "an-gli-ca-ni-za-da",
    "anglicanizado": "an-gli-ca-ni-za-do",
    "anglicanizante": "an-gli-ca-ni-zan-te",
    "anglicano": "an-gli-ca-no",
    "anglicismo": "an-gli-cis-mo",
    "anglicista": "an-gli-cis-ta",
    "ánglico": "án-gli-co",
    "angliparla": "an-gli-par-la",
    "anglista": "an-glis-ta",
    "anglística": "an-glís-ti-ca",
    "anglístico": "an-glís-ti-co",
    "anglo": "an-glo",
    "angloamericana": "an-glo-a-me-ri-ca-na",
    "angloamericanismo": "an-glo-a-me-ri-ca-nis-mo",
    "angloamericano": "an-glo-a-me-ri-ca-no",
    "anglocanadiense": "an-glo-ca-na-dien-se",
    "anglófila": "an-gló-fi-la",
    "anglofilia": "an-glo-fi-lia",
    "anglófilo": "an-gló-fi-lo",
    "anglófoba": "an-gló-fo-ba",
    "anglofobia": "an-glo-fo-bia",
    "anglófobo": "an-gló-fo-bo",
    "anglófono": "an-gló-fo-no",
    "anglohablante": "an-glo-ha-blan-te",
    "angloíndio": "an-glo-ín-dio",
    "anglómana": "an-gló-ma-na",
    "anglomanía": "an-glo-ma-ní-a",
    "anglómano": "an-gló-ma-no",
    "anglonormanda": "an-glo-nor-man-da",
    "anglonormando": "an-glo-nor-man-do",
    "angloparlante": "an-glo-par-lan-te",
    "anglosajón": "an-glo-sa-jón",
    "anglosajona": "an-glo-sa-jo-na",
    "angoja": "an-go-ja",
    "angojosa": "an-go-jo-sa",
    "angojoso": "an-go-jo-so",
    "angolán": "an-go-lán",
    "angoleña": "an-go-le-ña",
    "angoleño": "an-go-le-ño",
    "angolina": "an-go-li-na",
    "angolino": "an-go-li-no",
    "angor": "an-gor",
    "ángor": "án-gor",
    "angora": "an-go-ra",
    "angorina": "an-go-ri-na",
    "angorra": "an-go-rra",
    "angosta": "an-gos-ta",
    "angostamente": "an-gos-ta-men-te",
    "angostamiento": "an-gos-ta-mien-to",
    "angostar": "an-gos-tar",
    "angosto": "an-gos-to",
    "angostura": "an-gos-tu-ra",
    "angra": "an-gra",
    "angrelada": "an-gre-la-da",
    "angrelado": "an-gre-la-do",
    "angstrom": "angs-trom",
    "angstromio": "angs-tro-mio",
    "anguarina": "an-gua-ri-na",
    "angüejo": "an-güe-jo",
    "anguera": "an-gue-ra",
    "anguila": "an-gui-la",
    "anguilazo": "an-gui-la-zo",
    "anguilera": "an-gui-le-ra",
    "anguilero": "an-gui-le-ro",
    "anguilla": "an-gui-lla",
    "anguilo": "an-gui-lo",
    "anguina": "an-gui-na",
    "angula": "an-gu-la",
    "angulada": "an-gu-la-da",
    "angulado": "an-gu-la-do",
    "angular": "an-gu-lar",
    "angularmente": "an-gu-lar-men-te",
    "angulema": "an-gu-le-ma",
    "ángulo": "án-gu-lo",
    "angulosa": "an-gu-lo-sa",
    "angulosidad": "an-gu-lo-si-dad",
    "anguloso": "an-gu-lo-so",
    "anguria": "an-gu-ria",
    "angurria": "an-gu-rria",
    "angurrienta": "an-gu-rrien-ta",
    "angurriento": "an-gu-rrien-to",
    "angustia": "an-gus-tia",
    "angustiada": "an-gus-tia-da",
    "angustiadamente": "an-gus-tia-da-men-te",
    "angustiado": "an-gus-tia-do",
    "angustiador": "an-gus-tia-dor",
    "angustiadora": "an-gus-tia-do-ra",
    "angustiante": "an-gus-tian-te",
    "angustiar": "an-gus-tiar",
    "angustiosa": "an-gus-tio-sa",
    "angustiosamente": "an-gus-tio-sa-men-te",
    "angustioso": "an-gus-tio-so",
    "anhelación": "an-he-la-ción",
    "anhelante": "an-he-lan-te",
    "anhelar": "an-he-lar",
    "anhélito": "an-hé-li-to",
    "anhelo": "an-he-lo",
    "anhelosa": "an-he-lo-sa",
    "anhelosamente": "an-he-lo-sa-men-te",
    "anheloso": "an-he-lo-so",
    "anhidra": "an-hi-dra",
    "anhídrido": "an-hí-dri-do",
    "anhidrita": "an-hi-dri-ta",
    "anhidro": "an-hi-dro",
    "anhidrosis": "an-hi-dro-sis",
    "aniaga": "a-nia-ga",
    "añicos": "a-ñi-cos",
    "anidación": "a-ni-da-ción",
    "anidamiento": "a-ni-da-mien-to",
    "anidar": "a-ni-dar",
    "anidiar": "a-ni-diar",
    "anidio": "a-ni-dio",
    "añidir": "a-ñi-dir",
    "anieblar": "a-nie-blar",
    "aniego": "a-nie-go",
    "anieja": "a-nie-ja",
    "aniejar": "a-nie-jar",
    "aniejo": "a-nie-jo",
    "anihilación": "a-nihi-la-ción",
    "anihilamiento": "a-nihi-la-mien-to",
    "anihilar": "a-nihi-lar",
    "añil": "a-ñil",
    "añilar": "a-ñi-lar",
    "añilería": "a-ñi-le-rí-a",
    "anilina": "a-ni-li-na",
    "anilla": "a-ni-lla",
    "anillada": "a-ni-lla-da",
    "anillado": "a-ni-lla-do",
    "anillamiento": "a-ni-lla-mien-to",
    "anillar": "a-ni-llar",
    "anillo": "a-ni-llo",
    "ánima": "á-ni-ma",
    "animación": "a-ni-ma-ción",
    "animadamente": "a-ni-ma-da-men-te",
    "animado": "a-ni-ma-do",
    "animador": "a-ni-ma-dor",
    "animadora": "a-ni-ma-do-ra",
    "animadversión": "a-ni-mad-ver-sión",
    "animadvertencia": "a-ni-mad-ver-ten-cia",
    "animal": "a-ni-mal",
    "animalada": "a-ni-ma-la-da",
    "animalaje": "a-ni-ma-la-je",
    "animalario": "a-ni-ma-la-rio",
    "animálculo": "a-ni-mál-cu-lo",
    "animalero": "a-ni-ma-le-ro",
    "animalesco": "a-ni-ma-les-co",
    "animalia": "a-ni-ma-lia",
    "animalias": "a-ni-ma-lias",
    "animalidad": "a-ni-ma-li-dad",
    "animalismo": "a-ni-ma-lis-mo",
    "animalista": "a-ni-ma-lis-ta",
    "animalístico": "a-ni-ma-lís-ti-co",
    "animalización": "a-ni-ma-li-za-ción",
    "animalizar": "a-ni-ma-li-zar",
    "animalmente": "a-ni-mal-men-te",
    "animalucho": "a-ni-ma-lu-cho",
    "animante": "a-ni-man-te",
    "animar": "a-ni-mar",
    "anime": "a-ni-me",
    "animero": "a-ni-me-ro",
    "anímica": "a-ní-mi-ca",
    "anímicamente": "a-ní-mi-ca-men-te",
    "anímico": "a-ní-mi-co",
    "animismo": "a-ni-mis-mo",
    "animista": "a-ni-mis-ta",
    "animita": "a-ni-mi-ta",
    "animizar": "a-ni-mi-zar",
    "ánimo": "á-ni-mo",
    "animosa": "a-ni-mo-sa",
    "animosamente": "a-ni-mo-sa-men-te",
    "animosidad": "a-ni-mo-si-dad",
    "animoso": "a-ni-mo-so",
    "añina": "a-ñi-na",
    "aniñada": "a-ni-ña-da",
    "aniñadamente": "a-ni-ña-da-men-te",
    "aniñado": "a-ni-ña-do",
    "aniñamiento": "a-ni-ña-mien-to",
    "aniñar": "a-ni-ñar",
    "aniñarse": "a-ni-ñar-se",
    "añinero": "a-ñi-ne-ro",
    "añino": "a-ñi-no",
    "anión": "a-nión",
    "aniónico": "a-nió-ni-co",
    "aniquilable": "a-ni-qui-la-ble",
    "aniquilación": "a-ni-qui-la-ción",
    "aniquilador": "a-ni-qui-la-dor",
    "aniquiladora": "a-ni-qui-la-do-ra",
    "aniquilamiento": "a-ni-qui-la-mien-to",
    "aniquilante": "a-ni-qui-lan-te",
    "aniquilar": "a-ni-qui-lar",
    "añir": "a-ñir",
    "anís": "a-nís",
    "anisada": "a-ni-sa-da",
    "anisado": "a-ni-sa-do",
    "anisal": "a-ni-sal",
    "anisar": "a-ni-sar",
    "anisete": "a-ni-se-te",
    "anisodonte": "a-ni-so-don-te",
    "anisofila": "a-ni-so-fi-la",
    "anisofilo": "a-ni-so-fi-lo",
    "anisómero": "a-ni-só-me-ro",
    "anisopétala": "a-ni-so-pé-ta-la",
    "anisopétalo": "a-ni-so-pé-ta-lo",
    "anisosilábico": "a-ni-so-si-lá-bi-co",
    "anisosilabismo": "a-ni-so-si-la-bis-mo",
    "anisotropía": "a-ni-so-tro-pí-a",
    "anisótropo": "a-ni-só-tro-po",
    "anito": "a-ni-to",
    "anivelar": "a-ni-ve-lar",
    "aniversaria": "a-ni-ver-sa-ria",
    "aniversario": "a-ni-ver-sa-rio",
    "anjeo": "an-je-o",
    "anjova": "an-jo-va",
    "annamita": "an-na-mi-ta",
    "ano": "a-no",
    "año": "a-ño",
    "anoa": "a-no-a",
    "anobio": "a-no-bio",
    "anoche": "a-no-che",
    "anochecedor": "a-no-che-ce-dor",
    "anochecedora": "a-no-che-ce-do-ra",
    "anochecer": "a-no-che-cer",
    "anochecida": "a-no-che-ci-da",
    "anochecido": "a-no-che-ci-do",
    "anódico": "a-nó-di-co",
    "anodina": "a-no-di-na",
    "anodinamente": "a-no-di-na-men-te",
    "anodinia": "a-no-di-nia",
    "anodino": "a-no-di-no",
    "anodizar": "a-no-di-zar",
    "ánodo": "á-no-do",
    "anofeles": "a-no-fe-les",
    "añoja": "a-ño-ja",
    "añojada": "a-ño-ja-da",
    "añojal": "a-ño-jal",
    "añojo": "a-ño-jo",
    "anolar": "a-no-lar",
    "anómala": "a-nó-ma-la",
    "anómalamente": "a-nó-ma-la-men-te",
    "anomalía": "a-no-ma-lí-a",
    "anomalidad": "a-no-ma-li-dad",
    "anomalístico": "a-no-ma-lís-ti-co",
    "anómalo": "a-nó-ma-lo",
    "anomia": "a-no-mia",
    "anomuro": "a-no-mu-ro",
    "anón": "a-nón",
    "anona": "a-no-na",
    "anonácea": "a-no-ná-ce-a",
    "anonáceo": "a-no-ná-ce-o",
    "anonadación": "a-no-na-da-ción",
    "anonadador": "a-no-na-da-dor",
    "anonadamiento": "a-no-na-da-mien-to",
    "anonadante": "a-no-na-dan-te",
    "anonadar": "a-no-na-dar",
    "anónima": "a-nó-ni-ma",
    "anónimamente": "a-nó-ni-ma-men-te",
    "anonimato": "a-no-ni-ma-to",
    "anonimia": "a-no-ni-mia",
    "anónimo": "a-nó-ni-mo",
    "anopluro": "a-no-plu-ro",
    "anopsia": "a-nop-sia",
    "anorak": "a-no-rak",
    "añorante": "a-ño-ran-te",
    "añoranza": "a-ño-ran-za",
    "añorar": "a-ño-rar",
    "anorexia": "a-no-re-xia",
    "anoréxica": "a-no-ré-xi-ca",
    "anoréxico": "a-no-ré-xi-co",
    "anorgasmia": "a-nor-gas-mia",
    "anoria": "a-no-ria",
    "anormal": "a-nor-mal",
    "anormalidad": "a-nor-ma-li-dad",
    "anormalmente": "a-nor-mal-men-te",
    "anorza": "a-nor-za",
    "añosa": "a-ño-sa",
    "anosmia": "a-nos-mia",
    "añoso": "a-ño-so",
    "anosognosia": "a-no-sog-no-sia",
    "anotación": "a-no-ta-ción",
    "anotado": "a-no-ta-do",
    "anotador": "a-no-ta-dor",
    "anotadora": "a-no-ta-do-ra",
    "anotar": "a-no-tar",
    "anoticiar": "a-no-ti-ciar",
    "anotomía": "a-no-to-mí-a",
    "anotómica": "a-no-tó-mi-ca",
    "anotómico": "a-no-tó-mi-co",
    "anovelada": "a-no-ve-la-da",
    "anovelado": "a-no-ve-la-do",
    "anovulación": "a-no-vu-la-ción",
    "anovulatorio": "a-no-vu-la-to-rio",
    "anoxia": "a-no-xia",
    "anquear": "an-que-ar",
    "anquera": "an-que-ra",
    "anqueta": "an-que-ta",
    "anquialmendrada": "an-quial-men-dra-da",
    "anquialmendrado": "an-quial-men-dra-do",
    "anquiboyuna": "an-qui-bo-yu-na",
    "anquiboyuno": "an-qui-bo-yu-no",
    "anquiderribada": "an-qui-de-rri-ba-da",
    "anquiderribado": "an-qui-de-rri-ba-do",
    "anquilosamiento": "an-qui-lo-sa-mien-to",
    "anquilosar": "an-qui-lo-sar",
    "anquilosaurio": "an-qui-lo-sau-rio",
    "anquilosis": "an-qui-lo-sis",
    "anquilostoma": "an-qui-los-to-ma",
    "anquilostomiasis": "an-qui-los-to-mia-sis",
    "anquirredonda": "an-qui-rre-don-da",
    "anquirredondo": "an-qui-rre-don-do",
    "anquiseca": "an-qui-se-ca",
    "anquiseco": "an-qui-se-co",
    "ansa": "an-sa",
    "ánsar": "án-sar",
    "ansarera": "an-sa-re-ra",
    "ansarería": "an-sa-re-rí-a",
    "ansarero": "an-sa-re-ro",
    "ansarina": "an-sa-ri-na",
    "ansarino": "an-sa-ri-no",
    "ansarón": "an-sa-rón",
    "anseática": "an-se-á-ti-ca",
    "anseático": "an-se-á-ti-co",
    "anseriforme": "an-se-ri-for-me",
    "ansí": "an-sí",
    "ansia": "an-sia",
    "ansiar": "an-siar",
    "ansiedad": "an-sie-dad",
    "ansimesmo": "an-si-mes-mo",
    "ansimismo": "an-si-mis-mo",
    "ansina": "an-si-na",
    "ansiolítico": "an-sio-lí-ti-co",
    "ansión": "an-sión",
    "ansiosa": "an-sio-sa",
    "ansiosamente": "an-sio-sa-men-te",
    "ansiosidad": "an-sio-si-dad",
    "ansioso": "an-sio-so",
    "ansotana": "an-so-ta-na",
    "ansotano": "an-so-ta-no",
    "anta": "an-ta",
    "antagalla": "an-ta-ga-lla",
    "antagallar": "an-ta-ga-llar",
    "antagónica": "an-ta-gó-ni-ca",
    "antagónicamente": "an-ta-gó-ni-ca-men-te",
    "antagónico": "an-ta-gó-ni-co",
    "antagonismo": "an-ta-go-nis-mo",
    "antagonista": "an-ta-go-nis-ta",
    "antamilla": "an-ta-mi-lla",
    "antana": "an-ta-na",
    "antañada": "an-ta-ña-da",
    "antañazo": "an-ta-ña-zo",
    "antaño": "an-ta-ño",
    "antañón": "an-ta-ñón",
    "antañona": "an-ta-ño-na",
    "antarca": "an-tar-ca",
    "antarquear": "an-tar-que-ar",
    "antártica": "an-tár-ti-ca",
    "antártico": "an-tár-ti-co",
    "ante": "an-te",
    "anteada": "an-te-a-da",
    "anteado": "an-te-a-do",
    "antealtar": "an-te-al-tar",
    "anteanoche": "an-te-a-no-che",
    "anteanteanoche": "an-te-an-te-a-no-che",
    "anteanteayer": "an-te-an-te-a-yer",
    "anteantenoche": "an-te-an-te-no-che",
    "anteantier": "an-te-an-tier",
    "anteayer": "an-te-a-yer",
    "antebrazo": "an-te-bra-zo",
    "anteca": "an-te-ca",
    "antecama": "an-te-ca-ma",
    "antecámara": "an-te-cá-ma-ra",
    "antecapilla": "an-te-ca-pi-lla",
    "antecedencia": "an-te-ce-den-cia",
    "antecedente": "an-te-ce-den-te",
    "antecedentemente": "an-te-ce-den-te-men-te",
    "anteceder": "an-te-ce-der",
    "antecesor": "an-te-ce-sor",
    "antecesora": "an-te-ce-so-ra",
    "antecessor": "an-te-ces-sor",
    "anteclásica": "an-te-clá-si-ca",
    "anteclásico": "an-te-clá-si-co",
    "anteco": "an-te-co",
    "antecocina": "an-te-co-ci-na",
    "antecoger": "an-te-co-ger",
    "antecomedor": "an-te-co-me-dor",
    "antecopretérito": "an-te-co-pre-té-ri-to",
    "antecoro": "an-te-co-ro",
    "antecristo": "an-te-cris-to",
    "antecuarto": "an-te-cuar-to",
    "antedata": "an-te-da-ta",
    "antedatar": "an-te-da-tar",
    "antedespacho": "an-te-des-pa-cho",
    "antedía": "an-te-dí-a",
    "antedicha": "an-te-di-cha",
    "antedicho": "an-te-di-cho",
    "antediluviana": "an-te-di-lu-via-na",
    "antediluviano": "an-te-di-lu-via-no",
    "anteferir": "an-te-fe-rir",
    "antefija": "an-te-fi-ja",
    "antefirma": "an-te-fir-ma",
    "antefoso": "an-te-fo-so",
    "antefuturo": "an-te-fu-tu-ro",
    "anteguerra": "an-te-gue-rra",
    "antehistórica": "an-tehis-tó-ri-ca",
    "antehistórico": "an-tehis-tó-ri-co",
    "anteiglesia": "an-tei-gle-sia",
    "anteislámica": "an-teis-lá-mi-ca",
    "anteislámico": "an-teis-lá-mi-co",
    "antejardín": "an-te-jar-dín",
    "antejo": "an-te-jo",
    "antejuicio": "an-te-jui-cio",
    "antelación": "an-te-la-ción",
    "antelar": "an-te-lar",
    "antelina": "an-te-li-na",
    "antelucana": "an-te-lu-ca-na",
    "antelucano": "an-te-lu-ca-no",
    "antemano": "an-te-ma-no",
    "antemeridiana": "an-te-me-ri-dia-na",
    "antemeridiano": "an-te-me-ri-dia-no",
    "antemural": "an-te-mu-ral",
    "antemuralla": "an-te-mu-ra-lla",
    "antemuro": "an-te-mu-ro",
    "antena": "an-te-na",
    "antenacida": "an-te-na-ci-da",
    "antenacido": "an-te-na-ci-do",
    "antenada": "an-te-na-da",
    "antenado": "an-te-na-do",
    "antenista": "an-te-nis-ta",
    "antenoche": "an-te-no-che",
    "antenombre": "an-te-nom-bre",
    "antenotar": "an-te-no-tar",
    "antenupcial": "an-te-nup-cial",
    "anteojera": "an-te-o-je-ra",
    "anteojeras": "an-te-o-je-ras",
    "anteojero": "an-te-o-je-ro",
    "anteojo": "an-te-o-jo",
    "anteojuda": "an-te-o-ju-da",
    "anteojudo": "an-te-o-ju-do",
    "anteón": "an-te-ón",
    "antepagar": "an-te-pa-gar",
    "antepalco": "an-te-pal-co",
    "antepasada": "an-te-pa-sa-da",
    "antepasado": "an-te-pa-sa-do",
    "antepasar": "an-te-pa-sar",
    "antepechada": "an-te-pe-cha-da",
    "antepechado": "an-te-pe-cha-do",
    "antepecho": "an-te-pe-cho",
    "antepenúltima": "an-te-pe-núl-ti-ma",
    "antepenúltimo": "an-te-pe-núl-ti-mo",
    "antepié": "an-te-pié",
    "anteponer": "an-te-po-ner",
    "anteporta": "an-te-por-ta",
    "anteportada": "an-te-por-ta-da",
    "anteportón": "an-te-por-tón",
    "anteposición": "an-te-po-si-ción",
    "antepospretérito": "an-te-pos-pre-té-ri-to",
    "antepresente": "an-te-pre-sen-te",
    "antepretérito": "an-te-pre-té-ri-to",
    "anteproyecto": "an-te-pro-yec-to",
    "antepuerta": "an-te-puer-ta",
    "antepuerto": "an-te-puer-to",
    "antepuesta": "an-te-pues-ta",
    "antepuesto": "an-te-pues-to",
    "antequerana": "an-te-que-ra-na",
    "antequerano": "an-te-que-ra-no",
    "antequino": "an-te-qui-no",
    "antera": "an-te-ra",
    "anterior": "an-te-rior",
    "anterioridad": "an-te-rio-ri-dad",
    "anteriormente": "an-te-rior-men-te",
    "antero": "an-te-ro",
    "anterozoide": "an-te-ro-zoi-de",
    "anterrollo": "an-te-rro-llo",
    "antes": "an-tes",
    "antesacristía": "an-te-sa-cris-tí-a",
    "antesala": "an-te-sa-la",
    "anteseña": "an-te-se-ña",
    "antetecho": "an-te-te-cho",
    "antetemplo": "an-te-tem-plo",
    "antetítulo": "an-te-tí-tu-lo",
    "antevedimiento": "an-te-ve-di-mien-to",
    "antevenir": "an-te-ve-nir",
    "antever": "an-te-ver",
    "antevisa": "an-te-vi-sa",
    "anteviso": "an-te-vi-so",
    "antevíspera": "an-te-vís-pe-ra",
    "antevista": "an-te-vis-ta",
    "antevisto": "an-te-vis-to",
    "antevocálico": "an-te-vo-cá-li-co",
    "anti": "an-ti",
    "antia": "an-tia",
    "antiabortista": "an-tia-bor-tis-ta",
    "antiaborto": "an-tia-bor-to",
    "antiacadémico": "an-tia-ca-dé-mi-co",
    "antiácida": "an-tiá-ci-da",
    "antiácido": "an-tiá-ci-do",
    "antiacné": "an-tiac-né",
    "antiadherente": "an-tia-dhe-ren-te",
    "antiaérea": "an-tia-é-re-a",
    "antiaéreo": "an-tia-é-re-o",
    "antiafrodisíaco": "an-tia-fro-di-sí-a-co",
    "antiafrodisiaco": "an-tia-fro-di-sia-co",
    "antiálcali": "an-tiál-ca-li",
    "antialcalino": "an-tial-ca-li-no",
    "antialcohólica": "an-tial-co-hó-li-ca",
    "antialcohólico": "an-tial-co-hó-li-co",
    "antialérgico": "an-tia-lér-gi-co",
    "antiálgico": "an-tiál-gi-co",
    "antiamericanismo": "an-tia-me-ri-ca-nis-mo",
    "antiamericano": "an-tia-me-ri-ca-no",
    "antiandrógeno": "an-tian-dró-ge-no",
    "antiarrugas": "an-tia-rru-gas",
    "antiartístico": "an-tiar-tís-ti-co",
    "antiartrítico": "an-tiar-trí-ti-co",
    "antiasmático": "an-tias-má-ti-co",
    "antiatómico": "an-tia-tó-mi-co",
    "antibaby": "an-ti-baby",
    "antibacteriano": "an-ti-bac-te-ria-no",
    "antibalas": "an-ti-ba-las",
    "antibaquio": "an-ti-ba-quio",
    "antibelicista": "an-ti-be-li-cis-ta",
    "antibiograma": "an-ti-bio-gra-ma",
    "antibiosis": "an-ti-bio-sis",
    "antibioterapia": "an-ti-bio-te-ra-pia",
    "antibiótica": "an-ti-bió-ti-ca",
    "antibiótico": "an-ti-bió-ti-co",
    "antibloqueo": "an-ti-blo-que-o",
    "anticadencia": "an-ti-ca-den-cia",
    "anticancerígeno": "an-ti-can-ce-rí-ge-no",
    "anticanceroso": "an-ti-can-ce-ro-so",
    "anticanónica": "an-ti-ca-nó-ni-ca",
    "anticanónico": "an-ti-ca-nó-ni-co",
    "anticapitalista": "an-ti-ca-pi-ta-lis-ta",
    "anticariense": "an-ti-ca-rien-se",
    "anticarro": "an-ti-ca-rro",
    "anticaspa": "an-ti-cas-pa",
    "anticatarral": "an-ti-ca-ta-rral",
    "anticatarro": "an-ti-ca-ta-rro",
    "anticátodo": "an-ti-cá-to-do",
    "anticatólica": "an-ti-ca-tó-li-ca",
    "anticatólico": "an-ti-ca-tó-li-co",
    "anticiclón": "an-ti-ci-clón",
    "anticiclónico": "an-ti-ci-cló-ni-co",
    "anticientífico": "an-ti-cien-tí-fi-co",
    "anticipación": "an-ti-ci-pa-ción",
    "anticipada": "an-ti-ci-pa-da",
    "anticipadamente": "an-ti-ci-pa-da-men-te",
    "anticipado": "an-ti-ci-pa-do",
    "anticipador": "an-ti-ci-pa-dor",
    "anticipadora": "an-ti-ci-pa-do-ra",
    "anticipamiento": "an-ti-ci-pa-mien-to",
    "anticipante": "an-ti-ci-pan-te",
    "anticipar": "an-ti-ci-par",
    "anticipativamente": "an-ti-ci-pa-ti-va-men-te",
    "anticipatorio": "an-ti-ci-pa-to-rio",
    "anticipo": "an-ti-ci-po",
    "anticlerical": "an-ti-cle-ri-cal",
    "anticlericalismo": "an-ti-cle-ri-ca-lis-mo",
    "anticlímax": "an-ti-clí-max",
    "anticlinal": "an-ti-cli-nal",
    "anticoagulante": "an-ti-co-a-gu-lan-te",
    "anticodón": "an-ti-co-dón",
    "anticolegialista": "an-ti-co-le-gia-lis-ta",
    "anticolinérgico": "an-ti-co-li-nér-gi-co",
    "anticolisión": "an-ti-co-li-sión",
    "anticolonial": "an-ti-co-lo-nial",
    "anticolonialista": "an-ti-co-lo-nia-lis-ta",
    "anticomunismo": "an-ti-co-mu-nis-mo",
    "anticomunista": "an-ti-co-mu-nis-ta",
    "anticoncepción": "an-ti-con-cep-ción",
    "anticoncepcional": "an-ti-con-cep-cio-nal",
    "anticoncepcionismo": "an-ti-con-cep-cio-nis-mo",
    "anticonceptivo": "an-ti-con-cep-ti-vo",
    "anticongelante": "an-ti-con-ge-lan-te",
    "anticongestivo": "an-ti-con-ges-ti-vo",
    "anticonstitucional": "an-ti-cons-ti-tu-cio-nal",
    "anticonstitucionalidad": "an-ti-cons-ti-tu-cio-na-li-dad",
    "anticonvencional": "an-ti-con-ven-cio-nal",
    "anticorrosivo": "an-ti-co-rro-si-vo",
    "anticorrupción": "an-ti-co-rrup-ción",
    "anticresis": "an-ti-cre-sis",
    "anticresista": "an-ti-cre-sis-ta",
    "anticrética": "an-ti-cré-ti-ca",
    "anticrético": "an-ti-cré-ti-co",
    "anticristiana": "an-ti-cris-tia-na",
    "anticristianamente": "an-ti-cris-tia-na-men-te",
    "anticristiano": "an-ti-cris-tia-no",
    "anticristo": "an-ti-cris-to",
    "anticrítico": "an-ti-crí-ti-co",
    "anticuada": "an-ti-cua-da",
    "anticuadamente": "an-ti-cua-da-men-te",
    "anticuado": "an-ti-cua-do",
    "anticuar": "an-ti-cuar",
    "anticuaria": "an-ti-cua-ria",
    "anticuario": "an-ti-cua-rio",
    "anticucho": "an-ti-cu-cho",
    "anticuco": "an-ti-cu-co",
    "anticuerpo": "an-ti-cuer-po",
    "anticultura": "an-ti-cul-tu-ra",
    "antidáctilo": "an-ti-dác-ti-lo",
    "antidemocrático": "an-ti-de-mo-crá-ti-co",
    "antideportivo": "an-ti-de-por-ti-vo",
    "antidepresivo": "an-ti-de-pre-si-vo",
    "antideslizante": "an-ti-des-li-zan-te",
    "antidetonante": "an-ti-de-to-nan-te",
    "antidiabético": "an-ti-dia-bé-ti-co",
    "antidiarreico": "an-ti-dia-rrei-co",
    "antidictatorial": "an-ti-dic-ta-to-rial",
    "antidiftérico": "an-ti-dif-té-ri-co",
    "antidinástica": "an-ti-di-nás-ti-ca",
    "antidinástico": "an-ti-di-nás-ti-co",
    "antidisturbios": "an-ti-dis-tur-bios",
    "antidiurético": "an-ti-diu-ré-ti-co",
    "antidopaje": "an-ti-do-pa-je",
    "antidoping": "an-ti-do-ping",
    "antidotario": "an-ti-do-ta-rio",
    "antídoto": "an-tí-do-to",
    "antidroga": "an-ti-dro-ga",
    "antieconómico": "an-tie-co-nó-mi-co",
    "antielectrón": "an-tie-lec-trón",
    "antiemética": "an-tie-mé-ti-ca",
    "antiemético": "an-tie-mé-ti-co",
    "antiepiléptico": "an-tie-pi-lép-ti-co",
    "antier": "an-tier",
    "antiescorbútica": "an-ties-cor-bú-ti-ca",
    "antiescorbútico": "an-ties-cor-bú-ti-co",
    "antiespañol": "an-ties-pa-ñol",
    "antiespañola": "an-ties-pa-ño-la",
    "antiespasmódica": "an-ties-pas-mó-di-ca",
    "antiespasmódico": "an-ties-pas-mó-di-co",
    "antiespumante": "an-ties-pu-man-te",
    "antiestático": "an-ties-tá-ti-co",
    "antiestética": "an-ties-té-ti-ca",
    "antiestético": "an-ties-té-ti-co",
    "antiestrés": "an-ties-trés",
    "antieuropeísmo": "an-tieu-ro-pe-ís-mo",
    "antieuropeísta": "an-tieu-ro-pe-ís-ta",
    "antieuropeo": "an-tieu-ro-pe-o",
    "antievangélico": "an-tie-van-gé-li-co",
    "antifascismo": "an-ti-fas-cis-mo",
    "antifascista": "an-ti-fas-cis-ta",
    "antifaz": "an-ti-faz",
    "antifebril": "an-ti-fe-bril",
    "antifeminismo": "an-ti-fe-mi-nis-mo",
    "antifeminista": "an-ti-fe-mi-nis-ta",
    "antiflatulento": "an-ti-fla-tu-len-to",
    "antiflogística": "an-ti-flo-gís-ti-ca",
    "antiflogístico": "an-ti-flo-gís-ti-co",
    "antífona": "an-tí-fo-na",
    "antifonal": "an-ti-fo-nal",
    "antifonario": "an-ti-fo-na-rio",
    "antifonera": "an-ti-fo-ne-ra",
    "antifonero": "an-ti-fo-ne-ro",
    "antifrancés": "an-ti-fran-cés",
    "antifranquista": "an-ti-fran-quis-ta",
    "antífrasis": "an-tí-fra-sis",
    "antifricción": "an-ti-fric-ción",
    "antifúngico": "an-ti-fún-gi-co",
    "antigás": "an-ti-gás",
    "antigénico": "an-ti-gé-ni-co",
    "antígeno": "an-tí-ge-no",
    "antiglobalización": "an-ti-glo-ba-li-za-ción",
    "antigramatical": "an-ti-gra-ma-ti-cal",
    "antigrasa": "an-ti-gra-sa",
    "antigripal": "an-ti-gri-pal",
    "antigua": "an-ti-gua",
    "antigualla": "an-ti-gua-lla",
    "antiguamente": "an-ti-gua-men-te",
    "antiguamiento": "an-ti-gua-mien-to",
    "antiguana": "an-ti-gua-na",
    "antiguano": "an-ti-gua-no",
    "antiguar": "an-ti-guar",
    "antigubernamental": "an-ti-gu-ber-na-men-tal",
    "antigüedad": "an-ti-güe-dad",
    "antigüeña": "an-ti-güe-ña",
    "antigüeño": "an-ti-güe-ño",
    "antiguo": "an-ti-guo",
    "antihelmíntica": "an-tihel-mín-ti-ca",
    "antihelmíntico": "an-tihel-mín-ti-co",
    "antihemorrágico": "an-tihe-mo-rrá-gi-co",
    "antihemorroidal": "an-tihe-mo-rroi-dal",
    "antihéroe": "an-tihé-ro-e",
    "antiheroico": "an-tihe-roi-co",
    "antihiático": "an-ti-hiá-ti-co",
    "antihidrópica": "an-tihi-dró-pi-ca",
    "antihidrópico": "an-tihi-dró-pi-co",
    "antihigiénica": "an-tihi-gié-ni-ca",
    "antihigiénico": "an-tihi-gié-ni-co",
    "antihipertensivo": "an-tihi-per-ten-si-vo",
    "antihistamínico": "an-tihis-ta-mí-ni-co",
    "antihistérica": "an-tihis-té-ri-ca",
    "antihistérico": "an-tihis-té-ri-co",
    "antihistórico": "an-tihis-tó-ri-co",
    "antihuelga": "an-ti-huel-ga",
    "antihumano": "an-tihu-ma-no",
    "antiimperialismo": "an-tiim-pe-ria-lis-mo",
    "antiimperialista": "an-tiim-pe-ria-lis-ta",
    "antiinflacionario": "an-tiin-fla-cio-na-rio",
    "antiinflacionista": "an-tiin-fla-cio-nis-ta",
    "antiinflamatorio": "an-tiin-fla-ma-to-rio",
    "antijurídica": "an-ti-ju-rí-di-ca",
    "antijurídico": "an-ti-ju-rí-di-co",
    "antiliberal": "an-ti-li-be-ral",
    "antiliberalismo": "an-ti-li-be-ra-lis-mo",
    "antillana": "an-ti-lla-na",
    "antillanismo": "an-ti-lla-nis-mo",
    "antillano": "an-ti-lla-no",
    "antilogaritmo": "an-ti-lo-ga-rit-mo",
    "antilogía": "an-ti-lo-gí-a",
    "antilógica": "an-ti-ló-gi-ca",
    "antilógico": "an-ti-ló-gi-co",
    "antílope": "an-tí-lo-pe",
    "antilopino": "an-ti-lo-pi-no",
    "antimacasar": "an-ti-ma-ca-sar",
    "antimafia": "an-ti-ma-fia",
    "antimagnético": "an-ti-mag-né-ti-co",
    "antimasónico": "an-ti-ma-só-ni-co",
    "antimateria": "an-ti-ma-te-ria",
    "antimeridiano": "an-ti-me-ri-dia-no",
    "antimicótico": "an-ti-mi-có-ti-co",
    "antimicrobiano": "an-ti-mi-cro-bia-no",
    "antimilitarismo": "an-ti-mi-li-ta-ris-mo",
    "antimilitarista": "an-ti-mi-li-ta-ris-ta",
    "antimisil": "an-ti-mi-sil",
    "antimonárquica": "an-ti-mo-nár-qui-ca",
    "antimonárquico": "an-ti-mo-nár-qui-co",
    "antimonial": "an-ti-mo-nial",
    "antimónico": "an-ti-mó-ni-co",
    "antimonio": "an-ti-mo-nio",
    "antimonioso": "an-ti-mo-nio-so",
    "antimonita": "an-ti-mo-ni-ta",
    "antimoniuro": "an-ti-mo-niu-ro",
    "antimoral": "an-ti-mo-ral",
    "antinacional": "an-ti-na-cio-nal",
    "antinacionalista": "an-ti-na-cio-na-lis-ta",
    "antinatura": "an-ti-na-tu-ra",
    "antinatural": "an-ti-na-tu-ral",
    "antineoplásico": "an-ti-ne-o-plá-si-co",
    "antineurálgico": "an-ti-neu-rál-gi-co",
    "antineutrino": "an-ti-neu-tri-no",
    "antineutrón": "an-ti-neu-trón",
    "antiniebla": "an-ti-nie-bla",
    "antinomia": "an-ti-no-mia",
    "antinómica": "an-ti-nó-mi-ca",
    "antinómico": "an-ti-nó-mi-co",
    "antinorteamericanismo": "an-ti-nor-te-a-me-ri-ca-nis-mo",
    "antinorteamericano": "an-ti-nor-te-a-me-ri-ca-no",
    "antinovela": "an-ti-no-ve-la",
    "antinuclear": "an-ti-nu-cle-ar",
    "antioccidental": "an-tioc-ci-den-tal",
    "antioquena": "an-tio-que-na",
    "antioqueña": "an-tio-que-ña",
    "antioqueno": "an-tio-que-no",
    "antioqueño": "an-tio-que-ño",
    "antioxidante": "an-tio-xi-dan-te",
    "antipalúdica": "an-ti-pa-lú-di-ca",
    "antipalúdico": "an-ti-pa-lú-di-co",
    "antipapa": "an-ti-pa-pa",
    "antipapado": "an-ti-pa-pa-do",
    "antipapista": "an-ti-pa-pis-ta",
    "antipara": "an-ti-pa-ra",
    "antiparasitario": "an-ti-pa-ra-si-ta-rio",
    "antiparásito": "an-ti-pa-rá-si-to",
    "antiparero": "an-ti-pa-re-ro",
    "antiparlamentaria": "an-ti-par-la-men-ta-ria",
    "antiparlamentario": "an-ti-par-la-men-ta-rio",
    "antiparlamentarismo": "an-ti-par-la-men-ta-ris-mo",
    "antiparras": "an-ti-pa-rras",
    "antipartícula": "an-ti-par-tí-cu-la",
    "antipasto": "an-ti-pas-to",
    "antipatía": "an-ti-pa-tí-a",
    "antipática": "an-ti-pá-ti-ca",
    "antipáticamente": "an-ti-pá-ti-ca-men-te",
    "antipático": "an-ti-pá-ti-co",
    "antipatizar": "an-ti-pa-ti-zar",
    "antipatria": "an-ti-pa-tria",
    "antipatriota": "an-ti-pa-trio-ta",
    "antipatriótica": "an-ti-pa-trió-ti-ca",
    "antipatriótico": "an-ti-pa-trió-ti-co",
    "antipatriotismo": "an-ti-pa-trio-tis-mo",
    "antipedagógica": "an-ti-pe-da-gó-gi-ca",
    "antipedagógico": "an-ti-pe-da-gó-gi-co",
    "antipendio": "an-ti-pen-dio",
    "antiperistáltica": "an-ti-pe-ris-tál-ti-ca",
    "antiperistáltico": "an-ti-pe-ris-tál-ti-co",
    "antiperístasis": "an-ti-pe-rís-ta-sis",
    "antiperistática": "an-ti-pe-ris-tá-ti-ca",
    "antiperistático": "an-ti-pe-ris-tá-ti-co",
    "antipersona": "an-ti-per-so-na",
    "antipersonal": "an-ti-per-so-nal",
    "antipirético": "an-ti-pi-ré-ti-co",
    "antipirina": "an-ti-pi-ri-na",
    "antípoda": "an-tí-po-da",
    "antipodia": "an-ti-po-dia",
    "antipodio": "an-ti-po-dio",
    "antipoética": "an-ti-po-é-ti-ca",
    "antipoético": "an-ti-po-é-ti-co",
    "antipolilla": "an-ti-po-li-lla",
    "antipolio": "an-ti-po-lio",
    "antipontificado": "an-ti-pon-ti-fi-ca-do",
    "antiprotón": "an-ti-pro-tón",
    "antipsicótico": "an-tip-si-có-ti-co",
    "antipútrida": "an-ti-pú-tri-da",
    "antipútrido": "an-ti-pú-tri-do",
    "antiquísima": "an-ti-quí-si-ma",
    "antiquísimo": "an-ti-quí-si-mo",
    "antiquismo": "an-ti-quis-mo",
    "antirrábica": "an-ti-rrá-bi-ca",
    "antirrábico": "an-ti-rrá-bi-co",
    "antirracional": "an-ti-rra-cio-nal",
    "antirracionalismo": "an-ti-rra-cio-na-lis-mo",
    "antirracista": "an-ti-rra-cis-ta",
    "antirradar": "an-ti-rra-dar",
    "antirreeleccionismo": "an-ti-rre-e-lec-cio-nis-mo",
    "antirreeleccionista": "an-ti-rre-e-lec-cio-nis-ta",
    "antirreflectante": "an-ti-rre-flec-tan-te",
    "antirreglamentaria": "an-ti-rre-gla-men-ta-ria",
    "antirreglamentario": "an-ti-rre-gla-men-ta-rio",
    "antirreligiosa": "an-ti-rre-li-gio-sa",
    "antirreligioso": "an-ti-rre-li-gio-so",
    "antirrepublicano": "an-ti-rre-pu-bli-ca-no",
    "antirreumática": "an-ti-rreu-má-ti-ca",
    "antirreumático": "an-ti-rreu-má-ti-co",
    "antirrevolucionario": "an-ti-rre-vo-lu-cio-na-rio",
    "antirrobo": "an-ti-rro-bo",
    "antisatélite": "an-ti-sa-té-li-te",
    "antiscio": "an-tis-cio",
    "antisemita": "an-ti-se-mi-ta",
    "antisemítico": "an-ti-se-mí-ti-co",
    "antisemitismo": "an-ti-se-mi-tis-mo",
    "antisepsia": "an-ti-sep-sia",
    "antiséptico": "an-ti-sép-ti-co",
    "antisida": "an-ti-si-da",
    "antisifilítica": "an-ti-si-fi-lí-ti-ca",
    "antisifilítico": "an-ti-si-fi-lí-ti-co",
    "antisindical": "an-ti-sin-di-cal",
    "antisísmico": "an-ti-sís-mi-co",
    "antisistema": "an-ti-sis-te-ma",
    "antisocial": "an-ti-so-cial",
    "antisolar": "an-ti-so-lar",
    "antisoviético": "an-ti-so-vié-ti-co",
    "antisovietismo": "an-ti-so-vie-tis-mo",
    "antispasto": "an-tis-pas-to",
    "antistrofa": "an-tis-tro-fa",
    "antisubmarino": "an-ti-sub-ma-ri-no",
    "antisudoral": "an-ti-su-do-ral",
    "antisuero": "an-ti-sue-ro",
    "antitabaco": "an-ti-ta-ba-co",
    "antitanque": "an-ti-tan-que",
    "antitérmico": "an-ti-tér-mi-co",
    "antiterrorismo": "an-ti-te-rro-ris-mo",
    "antiterrorista": "an-ti-te-rro-ris-ta",
    "antítesis": "an-tí-te-sis",
    "antitetánica": "an-ti-te-tá-ni-ca",
    "antitetánico": "an-ti-te-tá-ni-co",
    "antitética": "an-ti-té-ti-ca",
    "antitéticamente": "an-ti-té-ti-ca-men-te",
    "antitético": "an-ti-té-ti-co",
    "antitóxico": "an-ti-tó-xi-co",
    "antitoxina": "an-ti-to-xi-na",
    "antitrago": "an-ti-tra-go",
    "antitranspirante": "an-ti-trans-pi-ran-te",
    "antitrinitaria": "an-ti-tri-ni-ta-ria",
    "antitrinitario": "an-ti-tri-ni-ta-rio",
    "antitrust": "an-ti-trust",
    "antituberculosa": "an-ti-tu-ber-cu-lo-sa",
    "antituberculoso": "an-ti-tu-ber-cu-lo-so",
    "antitumoral": "an-ti-tu-mo-ral",
    "antitusígeno": "an-ti-tu-sí-ge-no",
    "antitusivo": "an-ti-tu-si-vo",
    "antivariólico": "an-ti-va-rió-li-co",
    "antivenenoso": "an-ti-ve-ne-no-so",
    "antivenérea": "an-ti-ve-né-re-a",
    "antivenéreo": "an-ti-ve-né-re-o",
    "antiviolencia": "an-ti-vio-len-cia",
    "antiviperino": "an-ti-vi-pe-ri-no",
    "antiviral": "an-ti-vi-ral",
    "antivírico": "an-ti-ví-ri-co",
    "antivirus": "an-ti-vi-rus",
    "antixeroftálmico": "an-ti-xe-rof-tál-mi-co",
    "antociana": "an-to-cia-na",
    "antocianina": "an-to-cia-ni-na",
    "antófaga": "an-tó-fa-ga",
    "antofagastina": "an-to-fa-gas-ti-na",
    "antofagastino": "an-to-fa-gas-ti-no",
    "antófago": "an-tó-fa-go",
    "antófilo": "an-tó-fi-lo",
    "antojada": "an-to-ja-da",
    "antojadiza": "an-to-ja-di-za",
    "antojadizamente": "an-to-ja-di-za-men-te",
    "antojadizo": "an-to-ja-di-zo",
    "antojado": "an-to-ja-do",
    "antojamiento": "an-to-ja-mien-to",
    "antojana": "an-to-ja-na",
    "antojanza": "an-to-jan-za",
    "antojar": "an-to-jar",
    "antojarse": "an-to-jar-se",
    "antojera": "an-to-je-ra",
    "antojito": "an-to-ji-to",
    "antojitos": "an-to-ji-tos",
    "antojo": "an-to-jo",
    "antóloga": "an-tó-lo-ga",
    "antologador": "an-to-lo-ga-dor",
    "antologadora": "an-to-lo-ga-do-ra",
    "antología": "an-to-lo-gí-a",
    "antológicamente": "an-to-ló-gi-ca-men-te",
    "antológico": "an-to-ló-gi-co",
    "antologista": "an-to-lo-gis-ta",
    "antologizar": "an-to-lo-gi-zar",
    "antólogo": "an-tó-lo-go",
    "antón": "an-tón",
    "antoniana": "an-to-nia-na",
    "antoniano": "an-to-nia-no",
    "antónima": "an-tó-ni-ma",
    "antonimia": "an-to-ni-mia",
    "antonímico": "an-to-ní-mi-co",
    "antónimo": "an-tó-ni-mo",
    "antonina": "an-to-ni-na",
    "antoniniana": "an-to-ni-nia-na",
    "antoniniano": "an-to-ni-nia-no",
    "antonino": "an-to-ni-no",
    "antonomasia": "an-to-no-ma-sia",
    "antonomástica": "an-to-no-más-ti-ca",
    "antonomásticamente": "an-to-no-más-ti-ca-men-te",
    "antonomástico": "an-to-no-más-ti-co",
    "antorcha": "an-tor-cha",
    "antorchar": "an-tor-char",
    "antorchero": "an-tor-che-ro",
    "antosta": "an-tos-ta",
    "antozoo": "an-to-zo-o",
    "antracita": "an-tra-ci-ta",
    "antracosis": "an-tra-co-sis",
    "ántrax": "án-trax",
    "antro": "an-tro",
    "antropocéntrica": "an-tro-po-cén-tri-ca",
    "antropocéntrico": "an-tro-po-cén-tri-co",
    "antropocentrismo": "an-tro-po-cen-tris-mo",
    "antropófaga": "an-tro-pó-fa-ga",
    "antropofagia": "an-tro-po-fa-gia",
    "antropófago": "an-tro-pó-fa-go",
    "antropografía": "an-tro-po-gra-fí-a",
    "antropográfica": "an-tro-po-grá-fi-ca",
    "antropográfico": "an-tro-po-grá-fi-co",
    "antropoide": "an-tro-poi-de",
    "antropoideo": "an-tro-poi-de-o",
    "antropóloga": "an-tro-pó-lo-ga",
    "antropología": "an-tro-po-lo-gí-a",
    "antropológica": "an-tro-po-ló-gi-ca",
    "antropológico": "an-tro-po-ló-gi-co",
    "antropologismo": "an-tro-po-lo-gis-mo",
    "antropólogo": "an-tro-pó-lo-go",
    "antropómetra": "an-tro-pó-me-tra",
    "antropometría": "an-tro-po-me-trí-a",
    "antropométrica": "an-tro-po-mé-tri-ca",
    "antropométrico": "an-tro-po-mé-tri-co",
    "antropomorfa": "an-tro-po-mor-fa",
    "antropomórfica": "an-tro-po-mór-fi-ca",
    "antropomórficamente": "an-tro-po-mór-fi-ca-men-te",
    "antropomórfico": "an-tro-po-mór-fi-co",
    "antropomorfismo": "an-tro-po-mor-fis-mo",
    "antropomorfita": "an-tro-po-mor-fi-ta",
    "antropomorfo": "an-tro-po-mor-fo",
    "antroponimia": "an-tro-po-ni-mia",
    "antroponímica": "an-tro-po-ní-mi-ca",
    "antroponímico": "an-tro-po-ní-mi-co",
    "antropónimo": "an-tro-pó-ni-mo",
    "antropopiteco": "an-tro-po-pi-te-co",
    "antropósofa": "an-tro-pó-so-fa",
    "antroposofía": "an-tro-po-so-fí-a",
    "antropósofo": "an-tro-pó-so-fo",
    "antropozoico": "an-tro-po-zoi-co",
    "antruejada": "an-true-ja-da",
    "antruejar": "an-true-jar",
    "antruejo": "an-true-jo",
    "antruido": "an-trui-do",
    "antuerpiense": "an-tuer-pien-se",
    "antuviada": "an-tu-via-da",
    "antuviado": "an-tu-via-do",
    "antuviador": "an-tu-via-dor",
    "antuviadora": "an-tu-via-do-ra",
    "antuviar": "an-tu-viar",
    "antuvio": "an-tu-vio",
    "antuvión": "an-tu-vión",
    "antuzano": "an-tu-za-no",
    "anua": "a-nua",
    "anual": "a-nual",
    "anualidad": "a-nua-li-dad",
    "anualizado": "a-nua-li-za-do",
    "anualizar": "a-nua-li-zar",
    "anualmente": "a-nual-men-te",
    "anuario": "a-nua-rio",
    "anúbada": "a-nú-ba-da",
    "anubado": "a-nu-ba-do",
    "anubarrada": "a-nu-ba-rra-da",
    "anubarrado": "a-nu-ba-rra-do",
    "anublar": "a-nu-blar",
    "añublar": "a-ñu-blar",
    "anublo": "a-nu-blo",
    "añublo": "a-ñu-blo",
    "anudador": "a-nu-da-dor",
    "añudador": "a-ñu-da-dor",
    "anudadora": "a-nu-da-do-ra",
    "añudadora": "a-ñu-da-do-ra",
    "anudadura": "a-nu-da-du-ra",
    "añudadura": "a-ñu-da-du-ra",
    "anudamiento": "a-nu-da-mien-to",
    "añudamiento": "a-ñu-da-mien-to",
    "anudar": "a-nu-dar",
    "añudar": "a-ñu-dar",
    "anuencia": "a-nuen-cia",
    "anuente": "a-nuen-te",
    "anulabilidad": "a-nu-la-bi-li-dad",
    "anulable": "a-nu-la-ble",
    "anulación": "a-nu-la-ción",
    "anulador": "a-nu-la-dor",
    "anuladora": "a-nu-la-do-ra",
    "anular": "a-nu-lar",
    "anulativa": "a-nu-la-ti-va",
    "anulativo": "a-nu-la-ti-vo",
    "anulatorio": "a-nu-la-to-rio",
    "anulete": "a-nu-le-te",
    "ánulo": "á-nu-lo",
    "anulosa": "a-nu-lo-sa",
    "anuloso": "a-nu-lo-so",
    "anumeración": "a-nu-me-ra-ción",
    "anumerar": "a-nu-me-rar",
    "anuncia": "a-nun-cia",
    "anunciación": "a-nun-cia-ción",
    "anunciador": "a-nun-cia-dor",
    "anunciadora": "a-nun-cia-do-ra",
    "anunciamiento": "a-nun-cia-mien-to",
    "anunciante": "a-nun-cian-te",
    "anunciar": "a-nun-ciar",
    "anuncio": "a-nun-cio",
    "anuo": "a-nuo",
    "anura": "a-nu-ra",
    "anuria": "a-nu-ria",
    "anuro": "a-nu-ro",
    "añusgar": "a-ñus-gar",
    "anúteba": "a-nú-te-ba",
    "anverso": "an-ver-so",
    "anzoateguiense": "an-zo-a-te-guien-se",
    "anzoatiguense": "an-zo-a-ti-guen-se",
    "anzolar": "an-zo-lar",
    "anzolero": "an-zo-le-ro",
    "anzuelo": "an-zue-lo",
    "aocar": "a-o-car",
    "aojador": "a-o-ja-dor",
    "aojadora": "a-o-ja-do-ra",
    "aojadura": "a-o-ja-du-ra",
    "aojamiento": "a-o-ja-mien-to",
    "aojar": "a-o-jar",
    "aojo": "a-o-jo",
    "aonia": "a-o-nia",
    "aónides": "a-ó-ni-des",
    "aonio": "a-o-nio",
    "aoristo": "a-o-ris-to",
    "aorta": "a-or-ta",
    "aórtica": "a-ór-ti-ca",
    "aórtico": "a-ór-ti-co",
    "aortitis": "a-or-ti-tis",
    "aovada": "a-o-va-da",
    "aovado": "a-o-va-do",
    "aovadolanceolada": "a-o-va-do-lan-ce-o-la-da",
    "aovar": "a-o-var",
    "aovillar": "a-o-vi-llar",
    "aovillarse": "a-o-vi-llar-se",
    "apa": "a-pa",
    "apá": "a-pá",
    "apabilado": "a-pa-bi-la-do",
    "apabilar": "a-pa-bi-lar",
    "apabullamiento": "a-pa-bu-lla-mien-to",
    "apabullante": "a-pa-bu-llan-te",
    "apabullantemente": "a-pa-bu-llan-te-men-te",
    "apabullar": "a-pa-bu-llar",
    "apabullo": "a-pa-bu-llo",
    "apacentadero": "a-pa-cen-ta-de-ro",
    "apacentador": "a-pa-cen-ta-dor",
    "apacentadora": "a-pa-cen-ta-do-ra",
    "apacentamiento": "a-pa-cen-ta-mien-to",
    "apacentar": "a-pa-cen-tar",
    "apacer": "a-pa-cer",
    "apachar": "a-pa-char",
    "apache": "a-pa-che",
    "apacheta": "a-pa-che-ta",
    "apachurrada": "a-pa-chu-rra-da",
    "apachurrar": "a-pa-chu-rrar",
    "apachurrón": "a-pa-chu-rrón",
    "apacibilidad": "a-pa-ci-bi-li-dad",
    "apacible": "a-pa-ci-ble",
    "apaciblemente": "a-pa-ci-ble-men-te",
    "apaciguador": "a-pa-ci-gua-dor",
    "apaciguadora": "a-pa-ci-gua-do-ra",
    "apaciguamiento": "a-pa-ci-gua-mien-to",
    "apaciguar": "a-pa-ci-guar",
    "apacorral": "a-pa-co-rral",
    "apadrinador": "a-pa-dri-na-dor",
    "apadrinadora": "a-pa-dri-na-do-ra",
    "apadrinamiento": "a-pa-dri-na-mien-to",
    "apadrinar": "a-pa-dri-nar",
    "apagable": "a-pa-ga-ble",
    "apagada": "a-pa-ga-da",
    "apagadamente": "a-pa-ga-da-men-te",
    "apagadiza": "a-pa-ga-di-za",
    "apagadizo": "a-pa-ga-di-zo",
    "apagado": "a-pa-ga-do",
    "apagador": "a-pa-ga-dor",
    "apagadora": "a-pa-ga-do-ra",
    "apagallamas": "a-pa-ga-lla-mas",
    "apagamiento": "a-pa-ga-mien-to",
    "apagapenol": "a-pa-ga-pe-nol",
    "apagar": "a-pa-gar",
    "apagavelas": "a-pa-ga-ve-las",
    "apagón": "a-pa-gón",
    "apainelado": "a-pai-ne-la-do",
    "apaisada": "a-pai-sa-da",
    "apaisado": "a-pai-sa-do",
    "apajuilado": "a-pa-jui-la-do",
    "apajuilar": "a-pa-jui-lar",
    "apalabrar": "a-pa-la-brar",
    "apalambrar": "a-pa-lam-brar",
    "apalancado": "a-pa-lan-ca-do",
    "apalancamiento": "a-pa-lan-ca-mien-to",
    "apalancar": "a-pa-lan-car",
    "ápale": "á-pa-le",
    "apaleador": "a-pa-le-a-dor",
    "apaleadora": "a-pa-le-a-do-ra",
    "apaleamiento": "a-pa-le-a-mien-to",
    "apalear": "a-pa-le-ar",
    "apaleo": "a-pa-le-o",
    "apaletado": "a-pa-le-ta-do",
    "apalmada": "a-pal-ma-da",
    "apalmado": "a-pal-ma-do",
    "apalpar": "a-pal-par",
    "apañada": "a-pa-ña-da",
    "apanado": "a-pa-na-do",
    "apañado": "a-pa-ña-do",
    "apañador": "a-pa-ña-dor",
    "apañadora": "a-pa-ña-do-ra",
    "apañadura": "a-pa-ña-du-ra",
    "apanalada": "a-pa-na-la-da",
    "apanalado": "a-pa-na-la-do",
    "apañamiento": "a-pa-ña-mien-to",
    "apañar": "a-pa-ñar",
    "apancle": "a-pan-cle",
    "apancora": "a-pan-co-ra",
    "apandar": "a-pan-dar",
    "apandillar": "a-pan-di-llar",
    "apangado": "a-pan-ga-do",
    "apaniaguada": "a-pa-nia-gua-da",
    "apaniaguado": "a-pa-nia-gua-do",
    "apaniguada": "a-pa-ni-gua-da",
    "apaniguado": "a-pa-ni-gua-do",
    "apaniguar": "a-pa-ni-guar",
    "apaño": "a-pa-ño",
    "apanojada": "a-pa-no-ja-da",
    "apanojado": "a-pa-no-ja-do",
    "apantallado": "a-pan-ta-lla-do",
    "apantallar": "a-pan-ta-llar",
    "apantanar": "a-pan-ta-nar",
    "apante": "a-pan-te",
    "apantle": "a-pan-tle",
    "apantuflada": "a-pan-tu-fla-da",
    "apantuflado": "a-pan-tu-fla-do",
    "apanucar": "a-pa-nu-car",
    "apañuscador": "a-pa-ñus-ca-dor",
    "apañuscadora": "a-pa-ñus-ca-do-ra",
    "apañuscar": "a-pa-ñus-car",
    "apapachar": "a-pa-pa-char",
    "apapacho": "a-pa-pa-cho",
    "apapagayada": "a-pa-pa-ga-ya-da",
    "apapagayado": "a-pa-pa-ga-ya-do",
    "apapuchar": "a-pa-pu-char",
    "apapuche": "a-pa-pu-che",
    "aparador": "a-pa-ra-dor",
    "aparadora": "a-pa-ra-do-ra",
    "aparadorista": "a-pa-ra-do-ris-ta",
    "aparadura": "a-pa-ra-du-ra",
    "aparamento": "a-pa-ra-men-to",
    "aparar": "a-pa-rar",
    "aparasolada": "a-pa-ra-so-la-da",
    "aparasolado": "a-pa-ra-so-la-do",
    "aparatar": "a-pa-ra-tar",
    "aparatera": "a-pa-ra-te-ra",
    "aparatero": "a-pa-ra-te-ro",
    "aparato": "a-pa-ra-to",
    "aparatosa": "a-pa-ra-to-sa",
    "aparatosamente": "a-pa-ra-to-sa-men-te",
    "aparatosidad": "a-pa-ra-to-si-dad",
    "aparatoso": "a-pa-ra-to-so",
    "aparcacoches": "a-par-ca-co-ches",
    "aparcadero": "a-par-ca-de-ro",
    "aparcamiento": "a-par-ca-mien-to",
    "aparcar": "a-par-car",
    "aparcera": "a-par-ce-ra",
    "aparcería": "a-par-ce-rí-a",
    "aparcero": "a-par-ce-ro",
    "aparchonar": "a-par-cho-nar",
    "aparcionera": "a-par-cio-ne-ra",
    "aparcionero": "a-par-cio-ne-ro",
    "apareamiento": "a-pa-re-a-mien-to",
    "aparear": "a-pa-re-ar",
    "aparecer": "a-pa-re-cer",
    "aparecida": "a-pa-re-ci-da",
    "aparecido": "a-pa-re-ci-do",
    "aparecimiento": "a-pa-re-ci-mien-to",
    "aparejada": "a-pa-re-ja-da",
    "aparejadamente": "a-pa-re-ja-da-men-te",
    "aparejado": "a-pa-re-ja-do",
    "aparejador": "a-pa-re-ja-dor",
    "aparejadora": "a-pa-re-ja-do-ra",
    "aparejamiento": "a-pa-re-ja-mien-to",
    "aparejar": "a-pa-re-jar",
    "aparejo": "a-pa-re-jo",
    "aparellaje": "a-pa-re-lla-je",
    "aparencial": "a-pa-ren-cial",
    "aparencialmente": "a-pa-ren-cial-men-te",
    "aparentador": "a-pa-ren-ta-dor",
    "aparentadora": "a-pa-ren-ta-do-ra",
    "aparentar": "a-pa-ren-tar",
    "aparente": "a-pa-ren-te",
    "aparentemente": "a-pa-ren-te-men-te",
    "aparición": "a-pa-ri-ción",
    "apariencia": "a-pa-rien-cia",
    "aparir": "a-pa-rir",
    "aparrada": "a-pa-rra-da",
    "aparrado": "a-pa-rra-do",
    "aparragar": "a-pa-rra-gar",
    "aparragarse": "a-pa-rra-gar-se",
    "aparrar": "a-pa-rrar",
    "aparroquiada": "a-pa-rro-quia-da",
    "aparroquiado": "a-pa-rro-quia-do",
    "aparroquiar": "a-pa-rro-quiar",
    "apartación": "a-par-ta-ción",
    "apartada": "a-par-ta-da",
    "apartadamente": "a-par-ta-da-men-te",
    "apartadero": "a-par-ta-de-ro",
    "apartadijo": "a-par-ta-di-jo",
    "apartadiza": "a-par-ta-di-za",
    "apartadizo": "a-par-ta-di-zo",
    "apartado": "a-par-ta-do",
    "apartador": "a-par-ta-dor",
    "apartadora": "a-par-ta-do-ra",
    "apartamento": "a-par-ta-men-to",
    "apartamiento": "a-par-ta-mien-to",
    "apartar": "a-par-tar",
    "aparte": "a-par-te",
    "apartidar": "a-par-ti-dar",
    "apartidismo": "a-par-ti-dis-mo",
    "apartijo": "a-par-ti-jo",
    "apartosuite": "a-par-to-sui-te",
    "apartotel": "a-par-to-tel",
    "aparvadera": "a-par-va-de-ra",
    "aparvadero": "a-par-va-de-ro",
    "aparvador": "a-par-va-dor",
    "aparvar": "a-par-var",
    "apasanca": "a-pa-san-ca",
    "apasionada": "a-pa-sio-na-da",
    "apasionadamente": "a-pa-sio-na-da-men-te",
    "apasionado": "a-pa-sio-na-do",
    "apasionamiento": "a-pa-sio-na-mien-to",
    "apasionante": "a-pa-sio-nan-te",
    "apasionar": "a-pa-sio-nar",
    "apastar": "a-pas-tar",
    "apaste": "a-pas-te",
    "apastle": "a-pas-tle",
    "apastragar": "a-pas-tra-gar",
    "apastrar": "a-pas-trar",
    "apasturar": "a-pas-tu-rar",
    "apatán": "a-pa-tán",
    "apatanada": "a-pa-ta-na-da",
    "apatanado": "a-pa-ta-na-do",
    "apatía": "a-pa-tí-a",
    "apática": "a-pá-ti-ca",
    "apáticamente": "a-pá-ti-ca-men-te",
    "apático": "a-pá-ti-co",
    "apátrida": "a-pá-tri-da",
    "apatrocinar": "a-pa-tro-ci-nar",
    "apatusca": "a-pa-tus-ca",
    "apatusco": "a-pa-tus-co",
    "apaular": "a-pau-lar",
    "apaularse": "a-pau-lar-se",
    "apaulillar": "a-pau-li-llar",
    "apaulillarse": "a-pau-li-llar-se",
    "apavorado": "a-pa-vo-ra-do",
    "apaxtle": "a-pax-tle",
    "apayasar": "a-pa-ya-sar",
    "apazguada": "a-paz-gua-da",
    "apazguado": "a-paz-gua-do",
    "apea": "a-pe-a",
    "apeadero": "a-pe-a-de-ro",
    "apeador": "a-pe-a-dor",
    "apeadora": "a-pe-a-do-ra",
    "apealar": "a-pe-a-lar",
    "apeamiento": "a-pe-a-mien-to",
    "apear": "a-pe-ar",
    "apechar": "a-pe-char",
    "apechugar": "a-pe-chu-gar",
    "apechusques": "a-pe-chus-ques",
    "apedazar": "a-pe-da-zar",
    "apedernalada": "a-pe-der-na-la-da",
    "apedernalado": "a-pe-der-na-la-do",
    "apedrar": "a-pe-drar",
    "apedrea": "a-pe-dre-a",
    "apedreada": "a-pe-dre-a-da",
    "apedreadero": "a-pe-dre-a-de-ro",
    "apedreado": "a-pe-dre-a-do",
    "apedreador": "a-pe-dre-a-dor",
    "apedreadora": "a-pe-dre-a-do-ra",
    "apedreamiento": "a-pe-dre-a-mien-to",
    "apedrear": "a-pe-dre-ar",
    "apedreo": "a-pe-dre-o",
    "apegadamente": "a-pe-ga-da-men-te",
    "apegaderas": "a-pe-ga-de-ras",
    "apegadiza": "a-pe-ga-di-za",
    "apegadizo": "a-pe-ga-di-zo",
    "apegamiento": "a-pe-ga-mien-to",
    "apegar": "a-pe-gar",
    "apego": "a-pe-go",
    "apegualar": "a-pe-gua-lar",
    "apelable": "a-pe-la-ble",
    "apelación": "a-pe-la-ción",
    "apelada": "a-pe-la-da",
    "apelado": "a-pe-la-do",
    "apelambrar": "a-pe-lam-brar",
    "apelante": "a-pe-lan-te",
    "apelar": "a-pe-lar",
    "apelativa": "a-pe-la-ti-va",
    "apelativo": "a-pe-la-ti-vo",
    "apeldar": "a-pel-dar",
    "apelde": "a-pel-de",
    "apelgarar": "a-pel-ga-rar",
    "apelgararse": "a-pel-ga-rar-se",
    "apeligrar": "a-pe-li-grar",
    "apellar": "a-pe-llar",
    "apellidador": "a-pe-lli-da-dor",
    "apellidadora": "a-pe-lli-da-do-ra",
    "apellidamiento": "a-pe-lli-da-mien-to",
    "apellidar": "a-pe-lli-dar",
    "apellidero": "a-pe-lli-de-ro",
    "apellido": "a-pe-lli-do",
    "apelmazada": "a-pel-ma-za-da",
    "apelmazadamente": "a-pel-ma-za-da-men-te",
    "apelmazado": "a-pel-ma-za-do",
    "apelmazamiento": "a-pel-ma-za-mien-to",
    "apelmazar": "a-pel-ma-zar",
    "apelotonamiento": "a-pe-lo-to-na-mien-to",
    "apelotonar": "a-pe-lo-to-nar",
    "apena": "a-pe-na",
    "apenar": "a-pe-nar",
    "apenas": "a-pe-nas",
    "apencar": "a-pen-car",
    "apendejamiento": "a-pen-de-ja-mien-to",
    "apendejar": "a-pen-de-jar",
    "apendejear": "a-pen-de-je-ar",
    "apendencia": "a-pen-den-cia",
    "apéndice": "a-pén-di-ce",
    "apendicitis": "a-pen-di-ci-tis",
    "apendicular": "a-pen-di-cu-lar",
    "apenitas": "a-pe-ni-tas",
    "apensionar": "a-pen-sio-nar",
    "apeñuscar": "a-pe-ñus-car",
    "apeo": "a-pe-o",
    "apeonar": "a-pe-o-nar",
    "apepinado": "a-pe-pi-na-do",
    "apepsia": "a-pep-sia",
    "aperada": "a-pe-ra-da",
    "aperado": "a-pe-ra-do",
    "aperador": "a-pe-ra-dor",
    "aperar": "a-pe-rar",
    "apercancar": "a-per-can-car",
    "apercebimiento": "a-per-ce-bi-mien-to",
    "apercebir": "a-per-ce-bir",
    "apercepción": "a-per-cep-ción",
    "aperchar": "a-per-char",
    "apercibimiento": "a-per-ci-bi-mien-to",
    "apercibir": "a-per-ci-bir",
    "apercibo": "a-per-ci-bo",
    "aperción": "a-per-ción",
    "apercollar": "a-per-co-llar",
    "aperdigar": "a-per-di-gar",
    "apereá": "a-pe-re-á",
    "apergaminada": "a-per-ga-mi-na-da",
    "apergaminado": "a-per-ga-mi-na-do",
    "apergaminar": "a-per-ga-mi-nar",
    "apergaminarse": "a-per-ga-mi-nar-se",
    "apergollar": "a-per-go-llar",
    "aperital": "a-pe-ri-tal",
    "aperitiva": "a-pe-ri-ti-va",
    "aperitivo": "a-pe-ri-ti-vo",
    "aperlado": "a-per-la-do",
    "apernador": "a-per-na-dor",
    "apernadora": "a-per-na-do-ra",
    "apernar": "a-per-nar",
    "apero": "a-pe-ro",
    "aperrar": "a-pe-rrar",
    "aperreada": "a-pe-rre-a-da",
    "aperreado": "a-pe-rre-a-do",
    "aperreador": "a-pe-rre-a-dor",
    "aperreadora": "a-pe-rre-a-do-ra",
    "aperrear": "a-pe-rre-ar",
    "aperreo": "a-pe-rre-o",
    "apersogar": "a-per-so-gar",
    "apersonada": "a-per-so-na-da",
    "apersonado": "a-per-so-na-do",
    "apersonamiento": "a-per-so-na-mien-to",
    "apersonar": "a-per-so-nar",
    "apersonarse": "a-per-so-nar-se",
    "apertar": "a-per-tar",
    "apertrechar": "a-per-tre-char",
    "apertura": "a-per-tu-ra",
    "aperturismo": "a-per-tu-ris-mo",
    "aperturista": "a-per-tu-ris-ta",
    "apesadumbrado": "a-pe-sa-dum-bra-do",
    "apesadumbrar": "a-pe-sa-dum-brar",
    "apesaradamente": "a-pe-sa-ra-da-men-te",
    "apesarar": "a-pe-sa-rar",
    "apesgamiento": "a-pes-ga-mien-to",
    "apesgar": "a-pes-gar",
    "apestada": "a-pes-ta-da",
    "apestado": "a-pes-ta-do",
    "apestar": "a-pes-tar",
    "apestillar": "a-pes-ti-llar",
    "apestosa": "a-pes-to-sa",
    "apestoso": "a-pes-to-so",
    "apétala": "a-pé-ta-la",
    "apétalo": "a-pé-ta-lo",
    "apetecedor": "a-pe-te-ce-dor",
    "apetecedora": "a-pe-te-ce-do-ra",
    "apetecer": "a-pe-te-cer",
    "apetecible": "a-pe-te-ci-ble",
    "apetencia": "a-pe-ten-cia",
    "apetente": "a-pe-ten-te",
    "apetición": "a-pe-ti-ción",
    "apetite": "a-pe-ti-te",
    "apetitiva": "a-pe-ti-ti-va",
    "apetitivo": "a-pe-ti-ti-vo",
    "apetito": "a-pe-ti-to",
    "apetitosa": "a-pe-ti-to-sa",
    "apetitoso": "a-pe-ti-to-so",
    "ápex": "á-pex",
    "apezonada": "a-pe-zo-na-da",
    "apezonado": "a-pe-zo-na-do",
    "apezuñar": "a-pe-zu-ñar",
    "api": "a-pi",
    "apiadador": "a-pia-da-dor",
    "apiadadora": "a-pia-da-do-ra",
    "apiadar": "a-pia-dar",
    "apiado": "a-pia-do",
    "apianar": "a-pia-nar",
    "apiaradero": "a-pia-ra-de-ro",
    "apiario": "a-pia-rio",
    "apiastro": "a-pias-tro",
    "apical": "a-pi-cal",
    "apicarar": "a-pi-ca-rar",
    "apicararse": "a-pi-ca-rar-se",
    "ápice": "á-pi-ce",
    "apicectomía": "a-pi-cec-to-mí-a",
    "apichonado": "a-pi-cho-na-do",
    "apichonar": "a-pi-cho-nar",
    "apicoalveolar": "a-pi-co-al-ve-o-lar",
    "apícola": "a-pí-co-la",
    "apículo": "a-pí-cu-lo",
    "apicultor": "a-pi-cul-tor",
    "apicultora": "a-pi-cul-to-ra",
    "apicultura": "a-pi-cul-tu-ra",
    "apilable": "a-pi-la-ble",
    "apilada": "a-pi-la-da",
    "apilado": "a-pi-la-do",
    "apilador": "a-pi-la-dor",
    "apiladora": "a-pi-la-do-ra",
    "apilamiento": "a-pi-la-mien-to",
    "apilar": "a-pi-lar",
    "apimplar": "a-pim-plar",
    "apimpollar": "a-pim-po-llar",
    "apimpollarse": "a-pim-po-llar-se",
    "apiñada": "a-pi-ña-da",
    "apiñado": "a-pi-ña-do",
    "apiñadura": "a-pi-ña-du-ra",
    "apiñamiento": "a-pi-ña-mien-to",
    "apiñar": "a-pi-ñar",
    "apiñonada": "a-pi-ño-na-da",
    "apiñonado": "a-pi-ño-na-do",
    "apinto": "a-pin-to",
    "apio": "a-pio",
    "apiojar": "a-pio-jar",
    "apiojarse": "a-pio-jar-se",
    "apiolar": "a-pio-lar",
    "apipar": "a-pi-par",
    "apiparse": "a-pi-par-se",
    "apipisca": "a-pi-pis-ca",
    "apipizca": "a-pi-piz-ca",
    "apiporrar": "a-pi-po-rrar",
    "apiramidado": "a-pi-ra-mi-da-do",
    "apirética": "a-pi-ré-ti-ca",
    "apirético": "a-pi-ré-ti-co",
    "apirexia": "a-pi-re-xia",
    "apirgüinar": "a-pir-güi-nar",
    "apirgüinarse": "a-pir-güi-nar-se",
    "apiri": "a-pi-ri",
    "apirular": "a-pi-ru-lar",
    "apisonado": "a-pi-so-na-do",
    "apisonadora": "a-pi-so-na-do-ra",
    "apisonamiento": "a-pi-so-na-mien-to",
    "apisonar": "a-pi-so-nar",
    "apitar": "a-pi-tar",
    "apitiguar": "a-pi-ti-guar",
    "apitonada": "a-pi-to-na-da",
    "apitonado": "a-pi-to-na-do",
    "apitonamiento": "a-pi-to-na-mien-to",
    "apitonar": "a-pi-to-nar",
    "apitucar": "a-pi-tu-car",
    "apitutado": "a-pi-tu-ta-do",
    "apitutar": "a-pi-tu-tar",
    "apizarrada": "a-pi-za-rra-da",
    "apizarrado": "a-pi-za-rra-do",
    "aplacable": "a-pla-ca-ble",
    "aplacación": "a-pla-ca-ción",
    "aplacador": "a-pla-ca-dor",
    "aplacadora": "a-pla-ca-do-ra",
    "aplacamiento": "a-pla-ca-mien-to",
    "aplacar": "a-pla-car",
    "aplacentar": "a-pla-cen-tar",
    "aplacer": "a-pla-cer",
    "aplacerada": "a-pla-ce-ra-da",
    "aplacerado": "a-pla-ce-ra-do",
    "aplacible": "a-pla-ci-ble",
    "aplaciente": "a-pla-cien-te",
    "aplacimiento": "a-pla-ci-mien-to",
    "aplacóforo": "a-pla-có-fo-ro",
    "aplagar": "a-pla-gar",
    "aplanacalles": "a-pla-na-ca-lles",
    "aplanadera": "a-pla-na-de-ra",
    "aplanado": "a-pla-na-do",
    "aplanador": "a-pla-na-dor",
    "aplanadora": "a-pla-na-do-ra",
    "aplanamiento": "a-pla-na-mien-to",
    "aplanar": "a-pla-nar",
    "aplanchado": "a-plan-cha-do",
    "aplanchador": "a-plan-cha-dor",
    "aplanchadora": "a-plan-cha-do-ra",
    "aplanchar": "a-plan-char",
    "aplanética": "a-pla-né-ti-ca",
    "aplanético": "a-pla-né-ti-co",
    "aplantillar": "a-plan-ti-llar",
    "aplasia": "a-pla-sia",
    "aplásico": "a-plá-si-co",
    "aplastamiento": "a-plas-ta-mien-to",
    "aplastante": "a-plas-tan-te",
    "aplastantemente": "a-plas-tan-te-men-te",
    "aplastar": "a-plas-tar",
    "aplatanado": "a-pla-ta-na-do",
    "aplatanamiento": "a-pla-ta-na-mien-to",
    "aplatanar": "a-pla-ta-nar",
    "aplaudidor": "a-plau-di-dor",
    "aplaudidora": "a-plau-di-do-ra",
    "aplaudir": "a-plau-dir",
    "aplauso": "a-plau-so",
    "aplayar": "a-pla-yar",
    "aplazable": "a-pla-za-ble",
    "aplazada": "a-pla-za-da",
    "aplazado": "a-pla-za-do",
    "aplazamiento": "a-pla-za-mien-to",
    "aplazar": "a-pla-zar",
    "aplebeyar": "a-ple-be-yar",
    "aplegar": "a-ple-gar",
    "aplicabilidad": "a-pli-ca-bi-li-dad",
    "aplicable": "a-pli-ca-ble",
    "aplicación": "a-pli-ca-ción",
    "aplicada": "a-pli-ca-da",
    "aplicadamente": "a-pli-ca-da-men-te",
    "aplicadera": "a-pli-ca-de-ra",
    "aplicadero": "a-pli-ca-de-ro",
    "aplicado": "a-pli-ca-do",
    "aplicador": "a-pli-ca-dor",
    "aplicar": "a-pli-car",
    "aplicativa": "a-pli-ca-ti-va",
    "aplicativo": "a-pli-ca-ti-vo",
    "aplique": "a-pli-que",
    "aplomada": "a-plo-ma-da",
    "aplomado": "a-plo-ma-do",
    "aplomar": "a-plo-mar",
    "aplomo": "a-plo-mo",
    "apnea": "ap-ne-a",
    "apoastro": "a-po-as-tro",
    "apocada": "a-po-ca-da",
    "apocadamente": "a-po-ca-da-men-te",
    "apocado": "a-po-ca-do",
    "apocador": "a-po-ca-dor",
    "apocadora": "a-po-ca-do-ra",
    "apocalipsis": "a-po-ca-lip-sis",
    "apocalíptica": "a-po-ca-líp-ti-ca",
    "apocalípticamente": "a-po-ca-líp-ti-ca-men-te",
    "apocalíptico": "a-po-ca-líp-ti-co",
    "apocamiento": "a-po-ca-mien-to",
    "apocar": "a-po-car",
    "apocatástasis": "a-po-ca-tás-ta-sis",
    "apócema": "a-pó-ce-ma",
    "apochar": "a-po-char",
    "apócima": "a-pó-ci-ma",
    "apocinácea": "a-po-ci-ná-ce-a",
    "apocináceo": "a-po-ci-ná-ce-o",
    "apócopa": "a-pó-co-pa",
    "apocopar": "a-po-co-par",
    "apócope": "a-pó-co-pe",
    "apocoyado": "a-po-co-ya-do",
    "apócrifa": "a-pó-cri-fa",
    "apócrifamente": "a-pó-cri-fa-men-te",
    "apócrifo": "a-pó-cri-fo",
    "apocrisiario": "a-po-cri-sia-rio",
    "apocromática": "a-po-cro-má-ti-ca",
    "apocromático": "a-po-cro-má-ti-co",
    "ápoda": "á-po-da",
    "apodador": "a-po-da-dor",
    "apodadora": "a-po-da-do-ra",
    "apodamiento": "a-po-da-mien-to",
    "apodar": "a-po-dar",
    "apodencada": "a-po-den-ca-da",
    "apodencado": "a-po-den-ca-do",
    "apoderada": "a-po-de-ra-da",
    "apoderadamente": "a-po-de-ra-da-men-te",
    "apoderado": "a-po-de-ra-do",
    "apoderamiento": "a-po-de-ra-mien-to",
    "apoderar": "a-po-de-rar",
    "apodíctica": "a-po-díc-ti-ca",
    "apodíctico": "a-po-díc-ti-co",
    "apodiforme": "a-po-di-for-me",
    "apodo": "a-po-do",
    "ápodo": "á-po-do",
    "apódosis": "a-pó-do-sis",
    "apófige": "a-pó-fi-ge",
    "apófisis": "a-pó-fi-sis",
    "apofonía": "a-po-fo-ní-a",
    "apogeo": "a-po-ge-o",
    "apógrafo": "a-pó-gra-fo",
    "apolar": "a-po-lar",
    "apoleña": "a-po-le-ña",
    "apoleño": "a-po-le-ño",
    "apolillado": "a-po-li-lla-do",
    "apolilladura": "a-po-li-lla-du-ra",
    "apolillamiento": "a-po-li-lla-mien-to",
    "apolillar": "a-po-li-llar",
    "apolillo": "a-po-li-llo",
    "apolinar": "a-po-li-nar",
    "apolinarismo": "a-po-li-na-ris-mo",
    "apolinarista": "a-po-li-na-ris-ta",
    "apolínea": "a-po-lí-ne-a",
    "apolíneo": "a-po-lí-ne-o",
    "apolismado": "a-po-lis-ma-do",
    "apolismar": "a-po-lis-mar",
    "apolítica": "a-po-lí-ti-ca",
    "apoliticismo": "a-po-li-ti-cis-mo",
    "apolítico": "a-po-lí-ti-co",
    "apollerar": "a-po-lle-rar",
    "apolo": "a-po-lo",
    "apóloga": "a-pó-lo-ga",
    "apologética": "a-po-lo-gé-ti-ca",
    "apologéticamente": "a-po-lo-gé-ti-ca-men-te",
    "apologético": "a-po-lo-gé-ti-co",
    "apología": "a-po-lo-gí-a",
    "apológica": "a-po-ló-gi-ca",
    "apológico": "a-po-ló-gi-co",
    "apologista": "a-po-lo-gis-ta",
    "apologizar": "a-po-lo-gi-zar",
    "apólogo": "a-pó-lo-go",
    "apolonida": "a-po-lo-ni-da",
    "apolónida": "a-po-ló-ni-da",
    "apoltronado": "a-pol-tro-na-do",
    "apoltronamiento": "a-pol-tro-na-mien-to",
    "apoltronar": "a-pol-tro-nar",
    "apoltronarse": "a-pol-tro-nar-se",
    "apolvillar": "a-pol-vi-llar",
    "apolvillarse": "a-pol-vi-llar-se",
    "apomazar": "a-po-ma-zar",
    "aponer": "a-po-ner",
    "aponeurosis": "a-po-neu-ro-sis",
    "aponeurótica": "a-po-neu-ró-ti-ca",
    "aponeurótico": "a-po-neu-ró-ti-co",
    "apontocar": "a-pon-to-car",
    "aponzoñar": "a-pon-zo-ñar",
    "apoplejía": "a-po-ple-jí-a",
    "apopléjica": "a-po-plé-ji-ca",
    "apopléjico": "a-po-plé-ji-co",
    "apoplética": "a-po-plé-ti-ca",
    "apoplético": "a-po-plé-ti-co",
    "apoptosis": "a-pop-to-sis",
    "apoquinar": "a-po-qui-nar",
    "aporca": "a-por-ca",
    "aporcador": "a-por-ca-dor",
    "aporcadora": "a-por-ca-do-ra",
    "aporcadura": "a-por-ca-du-ra",
    "aporcar": "a-por-car",
    "aporco": "a-por-co",
    "aporético": "a-po-ré-ti-co",
    "aporía": "a-po-rí-a",
    "aporisma": "a-po-ris-ma",
    "aporismar": "a-po-ris-mar",
    "aporismarse": "a-po-ris-mar-se",
    "aporque": "a-por-que",
    "aporracear": "a-po-rra-ce-ar",
    "aporrar": "a-po-rrar",
    "aporrarse": "a-po-rrar-se",
    "aporreada": "a-po-rre-a-da",
    "aporreado": "a-po-rre-a-do",
    "aporreador": "a-po-rre-a-dor",
    "aporreadora": "a-po-rre-a-do-ra",
    "aporreadura": "a-po-rre-a-du-ra",
    "aporreamiento": "a-po-rre-a-mien-to",
    "aporrear": "a-po-rre-ar",
    "aporreo": "a-po-rre-o",
    "aporretado": "a-po-rre-ta-do",
    "aporrillar": "a-po-rri-llar",
    "aporrillarse": "a-po-rri-llar-se",
    "aportación": "a-por-ta-ción",
    "aportadera": "a-por-ta-de-ra",
    "aportadero": "a-por-ta-de-ro",
    "aportar": "a-por-tar",
    "aporte": "a-por-te",
    "aportellado": "a-por-te-lla-do",
    "aportillado": "a-por-ti-lla-do",
    "aportillar": "a-por-ti-llar",
    "após": "a-pós",
    "aposar": "a-po-sar",
    "aposentador": "a-po-sen-ta-dor",
    "aposentadora": "a-po-sen-ta-do-ra",
    "aposentaduría": "a-po-sen-ta-du-rí-a",
    "aposentamiento": "a-po-sen-ta-mien-to",
    "aposentar": "a-po-sen-tar",
    "aposento": "a-po-sen-to",
    "aposesionada": "a-po-se-sio-na-da",
    "aposesionado": "a-po-se-sio-na-do",
    "aposesionar": "a-po-se-sio-nar",
    "aposición": "a-po-si-ción",
    "aposicional": "a-po-si-cio-nal",
    "aposiopesis": "a-po-sio-pe-sis",
    "apositiva": "a-po-si-ti-va",
    "apositivo": "a-po-si-ti-vo",
    "apósito": "a-pó-si-to",
    "aposta": "a-pos-ta",
    "apostadamente": "a-pos-ta-da-men-te",
    "apostadero": "a-pos-ta-de-ro",
    "apostador": "a-pos-ta-dor",
    "apostadora": "a-pos-ta-do-ra",
    "apostante": "a-pos-tan-te",
    "apostar": "a-pos-tar",
    "apostasía": "a-pos-ta-sí-a",
    "apóstata": "a-pós-ta-ta",
    "apostatar": "a-pos-ta-tar",
    "apostema": "a-pos-te-ma",
    "apostemación": "a-pos-te-ma-ción",
    "apostemar": "a-pos-te-mar",
    "apostemero": "a-pos-te-me-ro",
    "apostemosa": "a-pos-te-mo-sa",
    "apostemoso": "a-pos-te-mo-so",
    "apostilla": "a-pos-ti-lla",
    "apostillar": "a-pos-ti-llar",
    "apostillarse": "a-pos-ti-llar-se",
    "apostiza": "a-pos-ti-za",
    "apostizo": "a-pos-ti-zo",
    "apóstol": "a-pós-tol",
    "apostolada": "a-pos-to-la-da",
    "apostolado": "a-pos-to-la-do",
    "apostolazgo": "a-pos-to-laz-go",
    "apostólica": "a-pos-tó-li-ca",
    "apostolical": "a-pos-to-li-cal",
    "apostólicamente": "a-pos-tó-li-ca-men-te",
    "apostolicidad": "a-pos-to-li-ci-dad",
    "apostólico": "a-pos-tó-li-co",
    "apostóliga": "a-pos-tó-li-ga",
    "apostóligo": "a-pos-tó-li-go",
    "apóstolo": "a-pós-to-lo",
    "apostrofar": "a-pos-tro-far",
    "apóstrofe": "a-pós-tro-fe",
    "apóstrofo": "a-pós-tro-fo",
    "apostura": "a-pos-tu-ra",
    "apoteca": "a-po-te-ca",
    "apotecario": "a-po-te-ca-rio",
    "apotecio": "a-po-te-cio",
    "apotegma": "a-po-teg-ma",
    "apotema": "a-po-te-ma",
    "apoteósica": "a-po-te-ó-si-ca",
    "apoteósicamente": "a-po-te-ó-si-ca-men-te",
    "apoteósico": "a-po-te-ó-si-co",
    "apoteosis": "a-po-te-o-sis",
    "apoteótica": "a-po-te-ó-ti-ca",
    "apoteótico": "a-po-te-ó-ti-co",
    "apoticario": "a-po-ti-ca-rio",
    "apotrerar": "a-po-tre-rar",
    "apotropaico": "a-po-tro-pai-co",
    "apoyabrazos": "a-po-ya-bra-zos",
    "apoyacabeza": "a-po-ya-ca-be-za",
    "apoyadero": "a-po-ya-de-ro",
    "apoyadura": "a-po-ya-du-ra",
    "apoyanuca": "a-po-ya-nu-ca",
    "apoyar": "a-po-yar",
    "apoyatura": "a-po-ya-tu-ra",
    "apoyavasos": "a-po-ya-va-sos",
    "apoyo": "a-po-yo",
    "apozar": "a-po-zar",
    "apozarse": "a-po-zar-se",
    "apozolar": "a-po-zo-lar",
    "apraxia": "a-pra-xia",
    "apreciabilidad": "a-pre-cia-bi-li-dad",
    "apreciable": "a-pre-cia-ble",
    "apreciablemente": "a-pre-cia-ble-men-te",
    "apreciación": "a-pre-cia-ción",
    "apreciadamente": "a-pre-cia-da-men-te",
    "apreciador": "a-pre-cia-dor",
    "apreciadora": "a-pre-cia-do-ra",
    "apreciar": "a-pre-ciar",
    "apreciativa": "a-pre-cia-ti-va",
    "apreciativo": "a-pre-cia-ti-vo",
    "aprecio": "a-pre-cio",
    "aprehender": "a-pre-hen-der",
    "aprehensión": "a-pre-hen-sión",
    "aprehensiva": "a-pre-hen-si-va",
    "aprehensivo": "a-pre-hen-si-vo",
    "aprehensor": "a-pre-hen-sor",
    "aprehensora": "a-pre-hen-so-ra",
    "aprehensoria": "a-pre-hen-so-ria",
    "aprehensorio": "a-pre-hen-so-rio",
    "apremiadamente": "a-pre-mia-da-men-te",
    "apremiador": "a-pre-mia-dor",
    "apremiadora": "a-pre-mia-do-ra",
    "apremiamiento": "a-pre-mia-mien-to",
    "apremiante": "a-pre-mian-te",
    "apremiantemente": "a-pre-mian-te-men-te",
    "apremiar": "a-pre-miar",
    "apremio": "a-pre-mio",
    "apremir": "a-pre-mir",
    "aprendedor": "a-pren-de-dor",
    "aprendedora": "a-pren-de-do-ra",
    "aprender": "a-pren-der",
    "aprendiente": "a-pren-dien-te",
    "aprendiz": "a-pren-diz",
    "aprendiza": "a-pren-di-za",
    "aprendizaje": "a-pren-di-za-je",
    "aprensador": "a-pren-sa-dor",
    "aprensadora": "a-pren-sa-do-ra",
    "aprensadura": "a-pren-sa-du-ra",
    "aprensar": "a-pren-sar",
    "aprensión": "a-pren-sión",
    "aprensiva": "a-pren-si-va",
    "aprensivamente": "a-pren-si-va-men-te",
    "aprensivo": "a-pren-si-vo",
    "aprés": "a-prés",
    "apresa": "a-pre-sa",
    "apresador": "a-pre-sa-dor",
    "apresadora": "a-pre-sa-do-ra",
    "apresamiento": "a-pre-sa-mien-to",
    "apresar": "a-pre-sar",
    "apresivamente": "a-pre-si-va-men-te",
    "apreso": "a-pre-so",
    "aprestar": "a-pres-tar",
    "aprestigiar": "a-pres-ti-giar",
    "apresto": "a-pres-to",
    "apresura": "a-pre-su-ra",
    "apresuración": "a-pre-su-ra-ción",
    "apresurada": "a-pre-su-ra-da",
    "apresuradamente": "a-pre-su-ra-da-men-te",
    "apresurado": "a-pre-su-ra-do",
    "apresuramiento": "a-pre-su-ra-mien-to",
    "apresurar": "a-pre-su-rar",
    "apretada": "a-pre-ta-da",
    "apretadamente": "a-pre-ta-da-men-te",
    "apretadera": "a-pre-ta-de-ra",
    "apretadero": "a-pre-ta-de-ro",
    "apretadiza": "a-pre-ta-di-za",
    "apretadizo": "a-pre-ta-di-zo",
    "apretado": "a-pre-ta-do",
    "apretador": "a-pre-ta-dor",
    "apretadora": "a-pre-ta-do-ra",
    "apretadura": "a-pre-ta-du-ra",
    "apretamiento": "a-pre-ta-mien-to",
    "apretar": "a-pre-tar",
    "apretazón": "a-pre-ta-zón",
    "apretón": "a-pre-tón",
    "apretujamiento": "a-pre-tu-ja-mien-to",
    "apretujar": "a-pre-tu-jar",
    "apretujón": "a-pre-tu-jón",
    "apretura": "a-pre-tu-ra",
    "aprevenir": "a-pre-ve-nir",
    "apriesa": "a-prie-sa",
    "aprieto": "a-prie-to",
    "aprimar": "a-pri-mar",
    "apriorismo": "a-prio-ris-mo",
    "apriorística": "a-prio-rís-ti-ca",
    "apriorístico": "a-prio-rís-ti-co",
    "aprisa": "a-pri-sa",
    "apriscar": "a-pris-car",
    "aprisco": "a-pris-co",
    "aprisionamiento": "a-pri-sio-na-mien-to",
    "aprisionar": "a-pri-sio-nar",
    "aprismo": "a-pris-mo",
    "aprista": "a-pris-ta",
    "aproar": "a-pro-ar",
    "aprobación": "a-pro-ba-ción",
    "aprobado": "a-pro-ba-do",
    "aprobador": "a-pro-ba-dor",
    "aprobadora": "a-pro-ba-do-ra",
    "aprobante": "a-pro-ban-te",
    "aprobanza": "a-pro-ban-za",
    "aprobar": "a-pro-bar",
    "aprobativa": "a-pro-ba-ti-va",
    "aprobativo": "a-pro-ba-ti-vo",
    "aprobatoria": "a-pro-ba-to-ria",
    "aprobatoriamente": "a-pro-ba-to-ria-men-te",
    "aprobatorio": "a-pro-ba-to-rio",
    "aproches": "a-pro-ches",
    "aprodar": "a-pro-dar",
    "aprometer": "a-pro-me-ter",
    "aprontamiento": "a-pron-ta-mien-to",
    "aprontar": "a-pron-tar",
    "apronte": "a-pron-te",
    "apropiable": "a-pro-pia-ble",
    "apropiación": "a-pro-pia-ción",
    "apropiadamente": "a-pro-pia-da-men-te",
    "apropiado": "a-pro-pia-do",
    "apropiador": "a-pro-pia-dor",
    "apropiadora": "a-pro-pia-do-ra",
    "apropiar": "a-pro-piar",
    "apropicuar": "a-pro-pi-cuar",
    "apropincuación": "a-pro-pin-cua-ción",
    "apropincuar": "a-pro-pin-cuar",
    "apropincuarse": "a-pro-pin-cuar-se",
    "apropósito": "a-pro-pó-si-to",
    "aprovecer": "a-pro-ve-cer",
    "aprovechable": "a-pro-ve-cha-ble",
    "aprovechada": "a-pro-ve-cha-da",
    "aprovechadamente": "a-pro-ve-cha-da-men-te",
    "aprovechado": "a-pro-ve-cha-do",
    "aprovechador": "a-pro-ve-cha-dor",
    "aprovechadora": "a-pro-ve-cha-do-ra",
    "aprovechamiento": "a-pro-ve-cha-mien-to",
    "aprovechante": "a-pro-ve-chan-te",
    "aprovechar": "a-pro-ve-char",
    "aprovechón": "a-pro-ve-chón",
    "aprovecimiento": "a-pro-ve-ci-mien-to",
    "aprovisionamiento": "a-pro-vi-sio-na-mien-to",
    "aprovisionar": "a-pro-vi-sio-nar",
    "aproximación": "a-pro-xi-ma-ción",
    "aproximada": "a-pro-xi-ma-da",
    "aproximadamente": "a-pro-xi-ma-da-men-te",
    "aproximado": "a-pro-xi-ma-do",
    "aproximar": "a-pro-xi-mar",
    "aproximativa": "a-pro-xi-ma-ti-va",
    "aproximativo": "a-pro-xi-ma-ti-vo",
    "aproxis": "a-pro-xis",
    "apsara": "ap-sa-ra",
    "ápside": "áp-si-de",
    "apta": "ap-ta",
    "aptamente": "ap-ta-men-te",
    "aptar": "ap-tar",
    "áptera": "áp-te-ra",
    "apterigiforme": "ap-te-ri-gi-for-me",
    "áptero": "áp-te-ro",
    "aptitud": "ap-ti-tud",
    "apto": "ap-to",
    "apucuyar": "a-pu-cu-yar",
    "ápud": "á-pud",
    "apuesta": "a-pues-ta",
    "apuestamente": "a-pues-ta-men-te",
    "apuesto": "a-pues-to",
    "apulgarar": "a-pul-ga-rar",
    "apulgararse": "a-pul-ga-rar-se",
    "apulismar": "a-pu-lis-mar",
    "apulso": "a-pul-so",
    "apuñalada": "a-pu-ña-la-da",
    "apuñalado": "a-pu-ña-la-do",
    "apuñalamiento": "a-pu-ña-la-mien-to",
    "apuñalar": "a-pu-ña-lar",
    "apuñalear": "a-pu-ña-le-ar",
    "apunar": "a-pu-nar",
    "apuñar": "a-pu-ñar",
    "apunarse": "a-pu-nar-se",
    "apunchar": "a-pun-char",
    "apuñear": "a-pu-ñe-ar",
    "apuñetear": "a-pu-ñe-te-ar",
    "apuntación": "a-pun-ta-ción",
    "apuntada": "a-pun-ta-da",
    "apuntado": "a-pun-ta-do",
    "apuntador": "a-pun-ta-dor",
    "apuntadora": "a-pun-ta-do-ra",
    "apuntalamiento": "a-pun-ta-la-mien-to",
    "apuntalar": "a-pun-ta-lar",
    "apuntamiento": "a-pun-ta-mien-to",
    "apuntar": "a-pun-tar",
    "apunte": "a-pun-te",
    "apuntillar": "a-pun-ti-llar",
    "apuñuscar": "a-pu-ñus-car",
    "apuracabos": "a-pu-ra-ca-bos",
    "apuración": "a-pu-ra-ción",
    "apurada": "a-pu-ra-da",
    "apuradamente": "a-pu-ra-da-men-te",
    "apuradero": "a-pu-ra-de-ro",
    "apurado": "a-pu-ra-do",
    "apurador": "a-pu-ra-dor",
    "apuradora": "a-pu-ra-do-ra",
    "apuramiento": "a-pu-ra-mien-to",
    "apuranieves": "a-pu-ra-nie-ves",
    "apurar": "a-pu-rar",
    "apurativa": "a-pu-ra-ti-va",
    "apurativo": "a-pu-ra-ti-vo",
    "apure": "a-pu-re",
    "apureña": "a-pu-re-ña",
    "apureño": "a-pu-re-ño",
    "apurete": "a-pu-re-te",
    "apurimeña": "a-pu-ri-me-ña",
    "apurimeño": "a-pu-ri-me-ño",
    "apuro": "a-pu-ro",
    "apurón": "a-pu-rón",
    "apurona": "a-pu-ro-na",
    "apurrir": "a-pu-rrir",
    "apurruñar": "a-pu-rru-ñar",
    "aquaplaning": "a-qua-pla-ning",
    "aque": "a-que",
    "aquea": "a-que-a",
    "aquebrazar": "a-que-bra-zar",
    "aquebrazarse": "a-que-bra-zar-se",
    "aquedar": "a-que-dar",
    "aquejadamente": "a-que-ja-da-men-te",
    "aquejador": "a-que-ja-dor",
    "aquejadora": "a-que-ja-do-ra",
    "aquejamiento": "a-que-ja-mien-to",
    "aquejar": "a-que-jar",
    "aquejosa": "a-que-jo-sa",
    "aquejosamente": "a-que-jo-sa-men-te",
    "aquejoso": "a-que-jo-so",
    "aquel": "a-quel",
    "aquela": "a-que-la",
    "aquelarre": "a-que-la-rre",
    "aquele": "a-que-le",
    "aquella": "a-que-lla",
    "aquellar": "a-que-llar",
    "aquello": "a-que-llo",
    "aquellos": "a-que-llos",
    "aqueménida": "a-que-mé-ni-da",
    "aqueménide": "a-que-mé-ni-de",
    "aquende": "a-quen-de",
    "aquenio": "a-que-nio",
    "aqueo": "a-que-o",
    "aquerar": "a-que-rar",
    "aquerarse": "a-que-rar-se",
    "aquerenciada": "a-que-ren-cia-da",
    "aquerenciado": "a-que-ren-cia-do",
    "aquerenciar": "a-que-ren-ciar",
    "aquerenciarse": "a-que-ren-ciar-se",
    "aqueresar": "a-que-re-sar",
    "aquesa": "a-que-sa",
    "aquese": "a-que-se",
    "aqueso": "a-que-so",
    "aquesta": "a-ques-ta",
    "aqueste": "a-ques-te",
    "aquesto": "a-ques-to",
    "aquí": "a-quí",
    "aquiescencia": "a-quies-cen-cia",
    "aquiescente": "a-quies-cen-te",
    "aquietador": "a-quie-ta-dor",
    "aquietadora": "a-quie-ta-do-ra",
    "aquietamiento": "a-quie-ta-mien-to",
    "aquietar": "a-quie-tar",
    "aquifoliácea": "a-qui-fo-liá-ce-a",
    "aquifoliáceo": "a-qui-fo-liá-ce-o",
    "aquifolio": "a-qui-fo-lio",
    "aquilatamiento": "a-qui-la-ta-mien-to",
    "aquilatar": "a-qui-la-tar",
    "aquilea": "a-qui-le-a",
    "aquileña": "a-qui-le-ña",
    "aquileño": "a-qui-le-ño",
    "aquiles": "a-qui-les",
    "aquilífero": "a-qui-lí-fe-ro",
    "aquilina": "a-qui-li-na",
    "aquilino": "a-qui-li-no",
    "aquillada": "a-qui-lla-da",
    "aquillado": "a-qui-lla-do",
    "aquillotrar": "a-qui-llo-trar",
    "aquilón": "a-qui-lón",
    "aquilonal": "a-qui-lo-nal",
    "aquilonar": "a-qui-lo-nar",
    "aquintralar": "a-quin-tra-lar",
    "aquintralarse": "a-quin-tra-lar-se",
    "aquistador": "a-quis-ta-dor",
    "aquistadora": "a-quis-ta-do-ra",
    "aquistar": "a-quis-tar",
    "aquitana": "a-qui-ta-na",
    "aquitánica": "a-qui-tá-ni-ca",
    "aquitánico": "a-qui-tá-ni-co",
    "aquitano": "a-qui-ta-no",
    "aquiva": "a-qui-va",
    "aquivo": "a-qui-vo",
    "ara": "a-ra",
    "árabe": "á-ra-be",
    "arabesca": "a-ra-bes-ca",
    "arabesco": "a-ra-bes-co",
    "arabí": "a-ra-bí",
    "arabía": "a-ra-bí-a",
    "arabia": "a-ra-bia",
    "arábica": "a-rá-bi-ca",
    "arábico": "a-rá-bi-co",
    "arábiga": "a-rá-bi-ga",
    "arábigo": "a-rá-bi-go",
    "arabio": "a-ra-bio",
    "arabismo": "a-ra-bis-mo",
    "arabista": "a-ra-bis-ta",
    "arabización": "a-ra-bi-za-ción",
    "arabizar": "a-ra-bi-zar",
    "arable": "a-ra-ble",
    "arabo": "a-ra-bo",
    "arácea": "a-rá-ce-a",
    "aráceo": "a-rá-ce-o",
    "arachán": "a-ra-chán",
    "arachana": "a-ra-cha-na",
    "arácnida": "a-rác-ni-da",
    "arácnido": "a-rác-ni-do",
    "aracnoides": "a-rac-noi-des",
    "aracnóloga": "a-rac-nó-lo-ga",
    "aracnología": "a-rac-no-lo-gí-a",
    "aracnológica": "a-rac-no-ló-gi-ca",
    "aracnológico": "a-rac-no-ló-gi-co",
    "aracnólogo": "a-rac-nó-lo-go",
    "arada": "a-ra-da",
    "arado": "a-ra-do",
    "arador": "a-ra-dor",
    "aradora": "a-ra-do-ra",
    "aradro": "a-ra-dro",
    "aradura": "a-ra-du-ra",
    "aragón": "a-ra-gón",
    "aragonés": "a-ra-go-nés",
    "aragonesa": "a-ra-go-ne-sa",
    "aragonesismo": "a-ra-go-ne-sis-mo",
    "aragonito": "a-ra-go-ni-to",
    "araguaney": "a-ra-gua-ney",
    "araguato": "a-ra-gua-to",
    "aragüeña": "a-ra-güe-ña",
    "aragüeño": "a-ra-güe-ño",
    "aragüirá": "a-ra-güi-rá",
    "arahuaco": "a-ra-hua-co",
    "aralia": "a-ra-lia",
    "araliácea": "a-ra-liá-ce-a",
    "araliáceo": "a-ra-liá-ce-o",
    "arambel": "a-ram-bel",
    "arambol": "a-ram-bol",
    "arambre": "a-ram-bre",
    "aramea": "a-ra-me-a",
    "arameo": "a-ra-me-o",
    "aramida": "a-ra-mi-da",
    "aramio": "a-ra-mio",
    "arán": "a-rán",
    "arana": "a-ra-na",
    "araña": "a-ra-ña",
    "arañada": "a-ra-ña-da",
    "arañador": "a-ra-ña-dor",
    "arañadora": "a-ra-ña-do-ra",
    "arañamiento": "a-ra-ña-mien-to",
    "arañar": "a-ra-ñar",
    "arañazo": "a-ra-ña-zo",
    "arancel": "a-ran-cel",
    "arancelaria": "a-ran-ce-la-ria",
    "arancelario": "a-ran-ce-la-rio",
    "arandanedo": "a-ran-da-ne-do",
    "arándano": "a-rán-da-no",
    "arandela": "a-ran-de-la",
    "arandillo": "a-ran-di-llo",
    "arandina": "a-ran-di-na",
    "arandino": "a-ran-di-no",
    "araneido": "a-ra-nei-do",
    "araneña": "a-ra-ne-ña",
    "araneño": "a-ra-ne-ño",
    "aranera": "a-ra-ne-ra",
    "arañera": "a-ra-ñe-ra",
    "aranero": "a-ra-ne-ro",
    "arañero": "a-ra-ñe-ro",
    "aranés": "a-ra-nés",
    "aranesa": "a-ra-ne-sa",
    "arangorri": "a-ran-go-rri",
    "araniego": "a-ra-nie-go",
    "arañil": "a-ra-ñil",
    "araño": "a-ra-ño",
    "arañón": "a-ra-ñón",
    "aranosa": "a-ra-no-sa",
    "aranoso": "a-ra-no-so",
    "arañuela": "a-ra-ñue-la",
    "arañuelo": "a-ra-ñue-lo",
    "aranzada": "a-ran-za-da",
    "arao": "a-ra-o",
    "arar": "a-rar",
    "arasá": "a-ra-sá",
    "aratoria": "a-ra-to-ria",
    "aratorio": "a-ra-to-rio",
    "araucana": "a-rau-ca-na",
    "araucanista": "a-rau-ca-nis-ta",
    "araucano": "a-rau-ca-no",
    "araucaria": "a-rau-ca-ria",
    "arauja": "a-rau-ja",
    "aravico": "a-ra-vi-co",
    "arazá": "a-ra-zá",
    "arbalestrilla": "ar-ba-les-tri-lla",
    "arbelcorán": "ar-bel-co-rán",
    "arbellón": "ar-be-llón",
    "arbequín": "ar-be-quín",
    "árbitra": "ár-bi-tra",
    "arbitrable": "ar-bi-tra-ble",
    "arbitradera": "ar-bi-tra-de-ra",
    "arbitradero": "ar-bi-tra-de-ro",
    "arbitrador": "ar-bi-tra-dor",
    "arbitradora": "ar-bi-tra-do-ra",
    "arbitraje": "ar-bi-tra-je",
    "arbitral": "ar-bi-tral",
    "arbitrar": "ar-bi-trar",
    "arbitraria": "ar-bi-tra-ria",
    "arbitrariamente": "ar-bi-tra-ria-men-te",
    "arbitrariedad": "ar-bi-tra-rie-dad",
    "arbitrario": "ar-bi-tra-rio",
    "arbitrativa": "ar-bi-tra-ti-va",
    "arbitrativo": "ar-bi-tra-ti-vo",
    "arbitrera": "ar-bi-tre-ra",
    "arbitrero": "ar-bi-tre-ro",
    "arbitriano": "ar-bi-tria-no",
    "arbitrio": "ar-bi-trio",
    "arbitrismo": "ar-bi-tris-mo",
    "arbitrista": "ar-bi-tris-ta",
    "árbitro": "ár-bi-tro",
    "árbol": "ár-bol",
    "arbolada": "ar-bo-la-da",
    "arbolado": "ar-bo-la-do",
    "arboladura": "ar-bo-la-du-ra",
    "arbolar": "ar-bo-lar",
    "arbolaria": "ar-bo-la-ria",
    "arbolario": "ar-bo-la-rio",
    "arbolecer": "ar-bo-le-cer",
    "arboleda": "ar-bo-le-da",
    "arboledo": "ar-bo-le-do",
    "arbolete": "ar-bo-le-te",
    "arbolillo": "ar-bo-li-llo",
    "arbolista": "ar-bo-lis-ta",
    "arbollón": "ar-bo-llón",
    "árbor": "ár-bor",
    "arbórea": "ar-bó-re-a",
    "arborecer": "ar-bo-re-cer",
    "arbóreo": "ar-bó-re-o",
    "arborescencia": "ar-bo-res-cen-cia",
    "arborescente": "ar-bo-res-cen-te",
    "arboreto": "ar-bo-re-to",
    "arboricida": "ar-bo-ri-ci-da",
    "arborícola": "ar-bo-rí-co-la",
    "arboricultor": "ar-bo-ri-cul-tor",
    "arboricultora": "ar-bo-ri-cul-to-ra",
    "arboricultura": "ar-bo-ri-cul-tu-ra",
    "arboriforme": "ar-bo-ri-for-me",
    "arborización": "ar-bo-ri-za-ción",
    "arborizar": "ar-bo-ri-zar",
    "arbotante": "ar-bo-tan-te",
    "arbustiva": "ar-bus-ti-va",
    "arbustivo": "ar-bus-ti-vo",
    "arbusto": "ar-bus-to",
    "arca": "ar-ca",
    "arcabucear": "ar-ca-bu-ce-ar",
    "arcabucería": "ar-ca-bu-ce-rí-a",
    "arcabucero": "ar-ca-bu-ce-ro",
    "arcabuco": "ar-ca-bu-co",
    "arcabucosa": "ar-ca-bu-co-sa",
    "arcabucoso": "ar-ca-bu-co-so",
    "arcabuezo": "ar-ca-bue-zo",
    "arcabuz": "ar-ca-buz",
    "arcabuzal": "ar-ca-bu-zal",
    "arcabuzazo": "ar-ca-bu-za-zo",
    "arcacil": "ar-ca-cil",
    "arcada": "ar-ca-da",
    "árcade": "ár-ca-de",
    "arcadia": "ar-ca-dia",
    "arcádica": "ar-cá-di-ca",
    "arcádicamente": "ar-cá-di-ca-men-te",
    "arcádico": "ar-cá-di-co",
    "arcadio": "ar-ca-dio",
    "arcador": "ar-ca-dor",
    "arcaduz": "ar-ca-duz",
    "arcaduzar": "ar-ca-du-zar",
    "arcaica": "ar-cai-ca",
    "arcaico": "ar-cai-co",
    "arcaísmo": "ar-ca-ís-mo",
    "arcaísta": "ar-ca-ís-ta",
    "arcaizante": "ar-cai-zan-te",
    "arcaizar": "ar-cai-zar",
    "arcana": "ar-ca-na",
    "arcanamente": "ar-ca-na-men-te",
    "arcángel": "ar-cán-gel",
    "arcangélica": "ar-can-gé-li-ca",
    "arcangelical": "ar-can-ge-li-cal",
    "arcangélico": "ar-can-gé-li-co",
    "arcanidad": "ar-ca-ni-dad",
    "arcano": "ar-ca-no",
    "arcar": "ar-car",
    "arcatura": "ar-ca-tu-ra",
    "arcazón": "ar-ca-zón",
    "arce": "ar-ce",
    "arcea": "ar-ce-a",
    "arcedianato": "ar-ce-dia-na-to",
    "arcedianazgo": "ar-ce-dia-naz-go",
    "arcediano": "ar-ce-dia-no",
    "arcedo": "ar-ce-do",
    "arcén": "ar-cén",
    "arcense": "ar-cen-se",
    "archa": "ar-cha",
    "archero": "ar-che-ro",
    "archi": "ar-chi",
    "archí": "ar-chí",
    "archibebe": "ar-chi-be-be",
    "archibribón": "ar-chi-bri-bón",
    "archibribona": "ar-chi-bri-bo-na",
    "archibruta": "ar-chi-bru-ta",
    "archibruto": "ar-chi-bru-to",
    "archicofrade": "ar-chi-co-fra-de",
    "archicofradía": "ar-chi-co-fra-dí-a",
    "archidiácono": "ar-chi-diá-co-no",
    "archidiócesis": "ar-chi-dió-ce-sis",
    "archiducado": "ar-chi-du-ca-do",
    "archiducal": "ar-chi-du-cal",
    "archiduque": "ar-chi-du-que",
    "archiduquesa": "ar-chi-du-que-sa",
    "archifonema": "ar-chi-fo-ne-ma",
    "archilaúd": "ar-chi-la-úd",
    "archilexema": "ar-chi-le-xe-ma",
    "archimandrita": "ar-chi-man-dri-ta",
    "archimillonaria": "ar-chi-mi-llo-na-ria",
    "archimillonario": "ar-chi-mi-llo-na-rio",
    "archipámpano": "ar-chi-pám-pa-no",
    "archiperres": "ar-chi-pe-rres",
    "archipiélago": "ar-chi-pié-la-go",
    "archisabido": "ar-chi-sa-bi-do",
    "architriclino": "ar-chi-tri-cli-no",
    "archivador": "ar-chi-va-dor",
    "archivadora": "ar-chi-va-do-ra",
    "archivar": "ar-chi-var",
    "archivera": "ar-chi-ve-ra",
    "archivero": "ar-chi-ve-ro",
    "archivista": "ar-chi-vis-ta",
    "archivística": "ar-chi-vís-ti-ca",
    "archivístico": "ar-chi-vís-ti-co",
    "archivo": "ar-chi-vo",
    "archivóloga": "ar-chi-vó-lo-ga",
    "archivología": "ar-chi-vo-lo-gí-a",
    "archivológico": "ar-chi-vo-ló-gi-co",
    "archivólogo": "ar-chi-vó-lo-go",
    "archivolta": "ar-chi-vol-ta",
    "arcial": "ar-cial",
    "arcidriche": "ar-ci-dri-che",
    "arcifinia": "ar-ci-fi-nia",
    "arcifinio": "ar-ci-fi-nio",
    "arcilla": "ar-ci-lla",
    "arcillar": "ar-ci-llar",
    "arcillosa": "ar-ci-llo-sa",
    "arcilloso": "ar-ci-llo-so",
    "arcina": "ar-ci-na",
    "arcinar": "ar-ci-nar",
    "arción": "ar-ción",
    "arcionar": "ar-cio-nar",
    "arciprestado": "ar-ci-pres-ta-do",
    "arciprestal": "ar-ci-pres-tal",
    "arciprestazgo": "ar-ci-pres-taz-go",
    "arcipreste": "ar-ci-pres-te",
    "arco": "ar-co",
    "arcobricense": "ar-co-bri-cen-se",
    "arcón": "ar-cón",
    "arcontado": "ar-con-ta-do",
    "arconte": "ar-con-te",
    "arcosa": "ar-co-sa",
    "arcosolio": "ar-co-so-lio",
    "arcuación": "ar-cua-ción",
    "arcuada": "ar-cua-da",
    "arcuado": "ar-cua-do",
    "arcual": "ar-cual",
    "arda": "ar-da",
    "ardalear": "ar-da-le-ar",
    "árdea": "ár-de-a",
    "ardedor": "ar-de-dor",
    "ardedura": "ar-de-du-ra",
    "ardeiforme": "ar-dei-for-me",
    "ardentía": "ar-den-tí-a",
    "ardentilla": "ar-den-ti-lla",
    "ardentísima": "ar-den-tí-si-ma",
    "ardentísimamente": "ar-den-tí-si-ma-men-te",
    "ardentísimo": "ar-den-tí-si-mo",
    "arder": "ar-der",
    "ardero": "ar-de-ro",
    "ardeviejas": "ar-de-vie-jas",
    "ardicia": "ar-di-cia",
    "ardid": "ar-did",
    "ardida": "ar-di-da",
    "ardidamente": "ar-di-da-men-te",
    "ardideza": "ar-di-de-za",
    "ardido": "ar-di-do",
    "ardidosa": "ar-di-do-sa",
    "ardidoso": "ar-di-do-so",
    "ardiente": "ar-dien-te",
    "ardientemente": "ar-dien-te-men-te",
    "ardil": "ar-dil",
    "ardilla": "ar-di-lla",
    "ardiloso": "ar-di-lo-so",
    "ardimiento": "ar-di-mien-to",
    "ardínculo": "ar-dín-cu-lo",
    "ardionda": "ar-dion-da",
    "ardiondo": "ar-dion-do",
    "ardita": "ar-di-ta",
    "ardite": "ar-di-te",
    "ardor": "ar-dor",
    "ardora": "ar-do-ra",
    "ardorada": "ar-do-ra-da",
    "ardorosa": "ar-do-ro-sa",
    "ardorosamente": "ar-do-ro-sa-men-te",
    "ardoroso": "ar-do-ro-so",
    "ardua": "ar-dua",
    "arduamente": "ar-dua-men-te",
    "arduidad": "ar-dui-dad",
    "arduo": "ar-duo",
    "ardura": "ar-du-ra",
    "ardurán": "ar-du-rán",
    "área": "á-re-a",
    "areca": "a-re-ca",
    "arecer": "a-re-cer",
    "arecibeña": "a-re-ci-be-ña",
    "arecibeño": "a-re-ci-be-ño",
    "arefacción": "a-re-fac-ción",
    "aregüeño": "a-re-güe-ño",
    "aregüense": "a-re-güen-se",
    "areíto": "a-re-í-to",
    "areito": "a-rei-to",
    "arel": "a-rel",
    "arelar": "a-re-lar",
    "arena": "a-re-na",
    "arenácea": "a-re-ná-ce-a",
    "arenáceo": "a-re-ná-ce-o",
    "arenación": "a-re-na-ción",
    "arenal": "a-re-nal",
    "arenar": "a-re-nar",
    "arencar": "a-ren-car",
    "arencón": "a-ren-cón",
    "arenera": "a-re-ne-ra",
    "arenero": "a-re-ne-ro",
    "arenga": "a-ren-ga",
    "arengador": "a-ren-ga-dor",
    "arengadora": "a-ren-ga-do-ra",
    "arengar": "a-ren-gar",
    "arenilla": "a-re-ni-lla",
    "arenillero": "a-re-ni-lle-ro",
    "arenisca": "a-re-nis-ca",
    "arenisco": "a-re-nis-co",
    "arenosa": "a-re-no-sa",
    "arenoso": "a-re-no-so",
    "arenque": "a-ren-que",
    "arenzata": "a-ren-za-ta",
    "areola": "a-re-o-la",
    "aréola": "a-ré-o-la",
    "areolar": "a-re-o-lar",
    "areómetro": "a-re-ó-me-tro",
    "areopagita": "a-re-o-pa-gi-ta",
    "areópago": "a-re-ó-pa-go",
    "areosístilo": "a-re-o-sís-ti-lo",
    "areóstilo": "a-re-ós-ti-lo",
    "arepa": "a-re-pa",
    "arepazo": "a-re-pa-zo",
    "arepita": "a-re-pi-ta",
    "arepuela": "a-re-pue-la",
    "arequipa": "a-re-qui-pa",
    "arequipe": "a-re-qui-pe",
    "arequipeña": "a-re-qui-pe-ña",
    "arequipeño": "a-re-qui-pe-ño",
    "aresta": "a-res-ta",
    "arestil": "a-res-til",
    "arestín": "a-res-tín",
    "arestinada": "a-res-ti-na-da",
    "arestinado": "a-res-ti-na-do",
    "aretalogía": "a-re-ta-lo-gí-a",
    "aretalógico": "a-re-ta-ló-gi-co",
    "arete": "a-re-te",
    "aretina": "a-re-ti-na",
    "aretino": "a-re-ti-no",
    "arévaca": "a-ré-va-ca",
    "arévaco": "a-ré-va-co",
    "arfada": "ar-fa-da",
    "arfar": "ar-far",
    "arfil": "ar-fil",
    "argadijo": "ar-ga-di-jo",
    "argadillo": "ar-ga-di-llo",
    "argado": "ar-ga-do",
    "argalia": "ar-ga-lia",
    "argallera": "ar-ga-lle-ra",
    "argamandel": "ar-ga-man-del",
    "argamandijo": "ar-ga-man-di-jo",
    "argamasa": "ar-ga-ma-sa",
    "argamasar": "ar-ga-ma-sar",
    "argamasón": "ar-ga-ma-són",
    "argamula": "ar-ga-mu-la",
    "argán": "ar-gán",
    "argaña": "ar-ga-ña",
    "árgana": "ár-ga-na",
    "árganas": "ár-ga-nas",
    "arganda": "ar-gan-da",
    "argandeña": "ar-gan-de-ña",
    "argandeño": "ar-gan-de-ño",
    "arganel": "ar-ga-nel",
    "arganeo": "ar-ga-ne-o",
    "árgano": "ár-ga-no",
    "argavieso": "ar-ga-vie-so",
    "argaya": "ar-ga-ya",
    "argayar": "ar-ga-yar",
    "argayo": "ar-ga-yo",
    "argel": "ar-gel",
    "argelina": "ar-ge-li-na",
    "argelino": "ar-ge-li-no",
    "argemone": "ar-ge-mo-ne",
    "argén": "ar-gén",
    "argent": "ar-gent",
    "argentada": "ar-gen-ta-da",
    "argentado": "ar-gen-ta-do",
    "argentador": "ar-gen-ta-dor",
    "argentadora": "ar-gen-ta-do-ra",
    "argentar": "ar-gen-tar",
    "argentario": "ar-gen-ta-rio",
    "argente": "ar-gen-te",
    "argéntea": "ar-gén-te-a",
    "argénteo": "ar-gén-te-o",
    "argentería": "ar-gen-te-rí-a",
    "argentero": "ar-gen-te-ro",
    "argéntico": "ar-gén-ti-co",
    "argentífero": "ar-gen-tí-fe-ro",
    "argentina": "ar-gen-ti-na",
    "argentinamente": "ar-gen-ti-na-men-te",
    "argentinidad": "ar-gen-ti-ni-dad",
    "argentinismo": "ar-gen-ti-nis-mo",
    "argentino": "ar-gen-ti-no",
    "argentita": "ar-gen-ti-ta",
    "argento": "ar-gen-to",
    "argentometría": "ar-gen-to-me-trí-a",
    "argentosa": "ar-gen-to-sa",
    "argentoso": "ar-gen-to-so",
    "argentpel": "ar-gent-pel",
    "argila": "ar-gi-la",
    "argilla": "ar-gi-lla",
    "argilosa": "ar-gi-lo-sa",
    "argiloso": "ar-gi-lo-so",
    "argiva": "ar-gi-va",
    "argivo": "ar-gi-vo",
    "argólica": "ar-gó-li-ca",
    "argólico": "ar-gó-li-co",
    "argolla": "ar-go-lla",
    "argollón": "ar-go-llón",
    "árgoma": "ár-go-ma",
    "argomal": "ar-go-mal",
    "argón": "ar-gón",
    "argonauta": "ar-go-nau-ta",
    "argos": "ar-gos",
    "argot": "ar-got",
    "argucia": "ar-gu-cia",
    "argue": "ar-gue",
    "argüe": "ar-güe",
    "arguellar": "ar-gue-llar",
    "arguellarse": "ar-gue-llar-se",
    "arguello": "ar-gue-llo",
    "árguenas": "ár-gue-nas",
    "árgueñas": "ár-gue-ñas",
    "argüende": "ar-güen-de",
    "argüendear": "ar-güen-de-ar",
    "argüendera": "ar-güen-de-ra",
    "argüendero": "ar-güen-de-ro",
    "argüidor": "ar-güi-dor",
    "argüidora": "ar-güi-do-ra",
    "arguinas": "ar-gui-nas",
    "argüir": "ar-güir",
    "argüitiva": "ar-güi-ti-va",
    "argüitivo": "ar-güi-ti-vo",
    "argullo": "ar-gu-llo",
    "argullosa": "ar-gu-llo-sa",
    "argulloso": "ar-gu-llo-so",
    "argumentación": "ar-gu-men-ta-ción",
    "argumentador": "ar-gu-men-ta-dor",
    "argumentadora": "ar-gu-men-ta-do-ra",
    "argumental": "ar-gu-men-tal",
    "argumentalmente": "ar-gu-men-tal-men-te",
    "argumentar": "ar-gu-men-tar",
    "argumentativa": "ar-gu-men-ta-ti-va",
    "argumentativo": "ar-gu-men-ta-ti-vo",
    "argumentista": "ar-gu-men-tis-ta",
    "argumento": "ar-gu-men-to",
    "argumentosa": "ar-gu-men-to-sa",
    "argumentoso": "ar-gu-men-to-so",
    "arguyente": "ar-gu-yen-te",
    "aria": "a-ria",
    "ariana": "a-ria-na",
    "ariano": "a-ria-no",
    "aribibi": "a-ri-bi-bi",
    "aricado": "a-ri-ca-do",
    "aricar": "a-ri-car",
    "aricoma": "a-ri-co-ma",
    "árida": "á-ri-da",
    "aridecer": "a-ri-de-cer",
    "aridez": "a-ri-dez",
    "árido": "á-ri-do",
    "arienzo": "a-rien-zo",
    "aries": "a-ries",
    "arieta": "a-rie-ta",
    "arietar": "a-rie-tar",
    "arietaria": "a-rie-ta-ria",
    "arietario": "a-rie-ta-rio",
    "ariete": "a-rie-te",
    "arietina": "a-rie-ti-na",
    "arietino": "a-rie-ti-no",
    "arietta": "a-riet-ta",
    "arija": "a-ri-ja",
    "arije": "a-ri-je",
    "arijo": "a-ri-jo",
    "arilación": "a-ri-la-ción",
    "arílico": "a-rí-li-co",
    "arillo": "a-ri-llo",
    "arilo": "a-ri-lo",
    "arimaspe": "a-ri-mas-pe",
    "arimaspo": "a-ri-mas-po",
    "arimez": "a-ri-mez",
    "ario": "a-rio",
    "aríolo": "a-rí-o-lo",
    "arique": "a-ri-que",
    "ariqueña": "a-ri-que-ña",
    "ariqueño": "a-ri-que-ño",
    "arísaro": "a-rí-sa-ro",
    "arisblanca": "a-ris-blan-ca",
    "arisblanco": "a-ris-blan-co",
    "arisca": "a-ris-ca",
    "ariscar": "a-ris-car",
    "ariscarse": "a-ris-car-se",
    "arisco": "a-ris-co",
    "arismética": "a-ris-mé-ti-ca",
    "arismético": "a-ris-mé-ti-co",
    "arisnegra": "a-ris-ne-gra",
    "arisnegro": "a-ris-ne-gro",
    "arisprieta": "a-ris-prie-ta",
    "arisprieto": "a-ris-prie-to",
    "arisquear": "a-ris-que-ar",
    "arista": "a-ris-ta",
    "aristada": "a-ris-ta-da",
    "aristado": "a-ris-ta-do",
    "aristarco": "a-ris-tar-co",
    "aristín": "a-ris-tín",
    "aristino": "a-ris-ti-no",
    "aristocracia": "a-ris-to-cra-cia",
    "aristócrata": "a-ris-tó-cra-ta",
    "aristocrática": "a-ris-to-crá-ti-ca",
    "aristocráticamente": "a-ris-to-crá-ti-ca-men-te",
    "aristocrático": "a-ris-to-crá-ti-co",
    "aristocratizar": "a-ris-to-cra-ti-zar",
    "aristofanesco": "a-ris-to-fa-nes-co",
    "aristofánica": "a-ris-to-fá-ni-ca",
    "aristofánico": "a-ris-to-fá-ni-co",
    "aristoloquia": "a-ris-to-lo-quia",
    "aristoloquiácea": "a-ris-to-lo-quiá-ce-a",
    "aristoloquiáceo": "a-ris-to-lo-quiá-ce-o",
    "aristón": "a-ris-tón",
    "aristosa": "a-ris-to-sa",
    "aristoso": "a-ris-to-so",
    "aristotélica": "a-ris-to-té-li-ca",
    "aristotélicamente": "a-ris-to-té-li-ca-men-te",
    "aristotélico": "a-ris-to-té-li-co",
    "aristotelismo": "a-ris-to-te-lis-mo",
    "aritenoides": "a-ri-te-noi-des",
    "aritmética": "a-rit-mé-ti-ca",
    "aritméticamente": "a-rit-mé-ti-ca-men-te",
    "aritmético": "a-rit-mé-ti-co",
    "aritmomancia": "a-rit-mo-man-cia",
    "aritmómetro": "a-rit-mó-me-tro",
    "arjorán": "ar-jo-rán",
    "arlar": "ar-lar",
    "arlequín": "ar-le-quín",
    "arlequinada": "ar-le-qui-na-da",
    "arlequinado": "ar-le-qui-na-do",
    "arlequinesca": "ar-le-qui-nes-ca",
    "arlequinesco": "ar-le-qui-nes-co",
    "arlo": "ar-lo",
    "arlota": "ar-lo-ta",
    "arlote": "ar-lo-te",
    "arlotería": "ar-lo-te-rí-a",
    "arma": "ar-ma",
    "armable": "ar-ma-ble",
    "armada": "ar-ma-da",
    "armadera": "ar-ma-de-ra",
    "armadía": "ar-ma-dí-a",
    "armadija": "ar-ma-di-ja",
    "armadijo": "ar-ma-di-jo",
    "armadilla": "ar-ma-di-lla",
    "armadillo": "ar-ma-di-llo",
    "armado": "ar-ma-do",
    "armador": "ar-ma-dor",
    "armadora": "ar-ma-do-ra",
    "armadura": "ar-ma-du-ra",
    "armaduría": "ar-ma-du-rí-a",
    "armajal": "ar-ma-jal",
    "armajo": "ar-ma-jo",
    "armamentismo": "ar-ma-men-tis-mo",
    "armamentista": "ar-ma-men-tis-ta",
    "armamentístico": "ar-ma-men-tís-ti-co",
    "armamento": "ar-ma-men-to",
    "armamiento": "ar-ma-mien-to",
    "armañac": "ar-ma-ñac",
    "armandijo": "ar-man-di-jo",
    "armar": "ar-mar",
    "armario": "ar-ma-rio",
    "armatoste": "ar-ma-tos-te",
    "armatroste": "ar-ma-tros-te",
    "armazón": "ar-ma-zón",
    "armella": "ar-me-lla",
    "armenia": "ar-me-nia",
    "arménico": "ar-mé-ni-co",
    "armenio": "ar-me-nio",
    "armento": "ar-men-to",
    "armería": "ar-me-rí-a",
    "armero": "ar-me-ro",
    "armerol": "ar-me-rol",
    "armífera": "ar-mí-fe-ra",
    "armífero": "ar-mí-fe-ro",
    "armígera": "ar-mí-ge-ra",
    "armígero": "ar-mí-ge-ro",
    "armilar": "ar-mi-lar",
    "armilla": "ar-mi-lla",
    "armillaria": "ar-mi-lla-ria",
    "armiñada": "ar-mi-ña-da",
    "armiñado": "ar-mi-ña-do",
    "armiñar": "ar-mi-ñar",
    "arminio": "ar-mi-nio",
    "armiño": "ar-mi-ño",
    "armipotente": "ar-mi-po-ten-te",
    "armisonante": "ar-mi-so-nan-te",
    "armisticio": "ar-mis-ti-cio",
    "armón": "ar-món",
    "armonía": "ar-mo-ní-a",
    "armoníaco": "ar-mo-ní-a-co",
    "armoniaco": "ar-mo-nia-co",
    "armónica": "ar-mó-ni-ca",
    "armónicamente": "ar-mó-ni-ca-men-te",
    "armónico": "ar-mó-ni-co",
    "armonio": "ar-mo-nio",
    "armoniosa": "ar-mo-nio-sa",
    "armoniosamente": "ar-mo-nio-sa-men-te",
    "armonioso": "ar-mo-nio-so",
    "armonista": "ar-mo-nis-ta",
    "armónium": "ar-mó-nium",
    "armonizable": "ar-mo-ni-za-ble",
    "armonización": "ar-mo-ni-za-ción",
    "armonizador": "ar-mo-ni-za-dor",
    "armonizadora": "ar-mo-ni-za-do-ra",
    "armonizar": "ar-mo-ni-zar",
    "armoricana": "ar-mo-ri-ca-na",
    "armoricano": "ar-mo-ri-ca-no",
    "armos": "ar-mos",
    "armuelle": "ar-mue-lle",
    "arna": "ar-na",
    "arnacho": "ar-na-cho",
    "arnadí": "ar-na-dí",
    "arnasca": "ar-nas-ca",
    "arnaucho": "ar-nau-cho",
    "arnaúte": "ar-na-ú-te",
    "arnequín": "ar-ne-quín",
    "arnés": "ar-nés",
    "árnica": "ár-ni-ca",
    "arnillo": "ar-ni-llo",
    "aro": "a-ro",
    "aroca": "a-ro-ca",
    "aroidea": "a-roi-de-a",
    "aroideo": "a-roi-de-o",
    "aroma": "a-ro-ma",
    "aromar": "a-ro-mar",
    "aromaterapia": "a-ro-ma-te-ra-pia",
    "aromática": "a-ro-má-ti-ca",
    "aromáticamente": "a-ro-má-ti-ca-men-te",
    "aromaticidad": "a-ro-ma-ti-ci-dad",
    "aromático": "a-ro-má-ti-co",
    "aromatización": "a-ro-ma-ti-za-ción",
    "aromatizante": "a-ro-ma-ti-zan-te",
    "aromatizar": "a-ro-ma-ti-zar",
    "aromatoterapia": "a-ro-ma-to-te-ra-pia",
    "aromo": "a-ro-mo",
    "aromosa": "a-ro-mo-sa",
    "aromoso": "a-ro-mo-so",
    "aron": "a-ron",
    "arpa": "ar-pa",
    "arpada": "ar-pa-da",
    "arpado": "ar-pa-do",
    "arpadura": "ar-pa-du-ra",
    "arpar": "ar-par",
    "arpegiado": "ar-pe-gia-do",
    "arpegiar": "ar-pe-giar",
    "arpegio": "ar-pe-gio",
    "arpella": "ar-pe-lla",
    "arpende": "ar-pen-de",
    "arpeo": "ar-pe-o",
    "arpía": "ar-pí-a",
    "arpillera": "ar-pi-lle-ra",
    "arpista": "ar-pis-ta",
    "arpón": "ar-pón",
    "arponada": "ar-po-na-da",
    "arponado": "ar-po-na-do",
    "arponar": "ar-po-nar",
    "arponear": "ar-po-ne-ar",
    "arponera": "ar-po-ne-ra",
    "arponero": "ar-po-ne-ro",
    "arqueada": "ar-que-a-da",
    "arqueador": "ar-que-a-dor",
    "arqueaje": "ar-que-a-je",
    "arqueamiento": "ar-que-a-mien-to",
    "arquear": "ar-que-ar",
    "arqueo": "ar-que-o",
    "arqueoastronomía": "ar-que-o-as-tro-no-mí-a",
    "arqueolítica": "ar-que-o-lí-ti-ca",
    "arqueolítico": "ar-que-o-lí-ti-co",
    "arqueóloga": "ar-que-ó-lo-ga",
    "arqueología": "ar-que-o-lo-gí-a",
    "arqueológica": "ar-que-o-ló-gi-ca",
    "arqueológicamente": "ar-que-o-ló-gi-ca-men-te",
    "arqueológico": "ar-que-o-ló-gi-co",
    "arqueólogo": "ar-que-ó-lo-go",
    "arqueozoología": "ar-que-o-zo-o-lo-gí-a",
    "arquera": "ar-que-ra",
    "arquería": "ar-que-rí-a",
    "arquero": "ar-que-ro",
    "arqueta": "ar-que-ta",
    "arquetípica": "ar-que-tí-pi-ca",
    "arquetípico": "ar-que-tí-pi-co",
    "arquetipo": "ar-que-ti-po",
    "arquibanco": "ar-qui-ban-co",
    "arquiclamídea": "ar-qui-cla-mí-de-a",
    "arquiclamídeas": "ar-qui-cla-mí-de-as",
    "arquiclamídeo": "ar-qui-cla-mí-de-o",
    "arquidiócesis": "ar-qui-dió-ce-sis",
    "arquiepiscopal": "ar-quie-pis-co-pal",
    "arquímedes": "ar-quí-me-des",
    "arquimesa": "ar-qui-me-sa",
    "arquipéndola": "ar-qui-pén-do-la",
    "arquíptero": "ar-quíp-te-ro",
    "arquisinagogo": "ar-qui-si-na-go-go",
    "arquitecta": "ar-qui-tec-ta",
    "arquitecto": "ar-qui-tec-to",
    "arquitectónica": "ar-qui-tec-tó-ni-ca",
    "arquitectónicamente": "ar-qui-tec-tó-ni-ca-men-te",
    "arquitectónico": "ar-qui-tec-tó-ni-co",
    "arquitector": "ar-qui-tec-tor",
    "arquitectura": "ar-qui-tec-tu-ra",
    "arquitectural": "ar-qui-tec-tu-ral",
    "arquitrabado": "ar-qui-tra-ba-do",
    "arquitrabe": "ar-qui-tra-be",
    "arquivolta": "ar-qui-vol-ta",
    "arra": "a-rra",
    "arrabá": "a-rra-bá",
    "arrabal": "a-rra-bal",
    "arrabalera": "a-rra-ba-le-ra",
    "arrabalero": "a-rra-ba-le-ro",
    "arrabiatar": "a-rra-bia-tar",
    "arrabillado": "a-rra-bi-lla-do",
    "arrabio": "a-rra-bio",
    "arracacha": "a-rra-ca-cha",
    "arracachada": "a-rra-ca-cha-da",
    "arracache": "a-rra-ca-che",
    "arracacho": "a-rra-ca-cho",
    "arracada": "a-rra-ca-da",
    "arrachera": "a-rra-che-ra",
    "arracimada": "a-rra-ci-ma-da",
    "arracimado": "a-rra-ci-ma-do",
    "arracimar": "a-rra-ci-mar",
    "arracimarse": "a-rra-ci-mar-se",
    "arraclán": "a-rra-clán",
    "arráez": "a-rrá-ez",
    "arraezar": "a-rra-e-zar",
    "arrafiz": "a-rra-fiz",
    "arragocés": "a-rra-go-cés",
    "arragre": "a-rra-gre",
    "arraigada": "a-rrai-ga-da",
    "arraigadamente": "a-rrai-ga-da-men-te",
    "arraigadas": "a-rrai-ga-das",
    "arraigado": "a-rrai-ga-do",
    "arraigamiento": "a-rrai-ga-mien-to",
    "arraigar": "a-rrai-gar",
    "arraigo": "a-rrai-go",
    "arraiján": "a-rrai-ján",
    "arralar": "a-rra-lar",
    "arramblar": "a-rram-blar",
    "arramplar": "a-rram-plar",
    "arranado": "a-rra-na-do",
    "arranar": "a-rra-nar",
    "arrancaclavos": "a-rran-ca-cla-vos",
    "arrancada": "a-rran-ca-da",
    "arrancadera": "a-rran-ca-de-ra",
    "arrancadero": "a-rran-ca-de-ro",
    "arrancado": "a-rran-ca-do",
    "arrancador": "a-rran-ca-dor",
    "arrancadora": "a-rran-ca-do-ra",
    "arrancadura": "a-rran-ca-du-ra",
    "arrancamiento": "a-rran-ca-mien-to",
    "arrancamoños": "a-rran-ca-mo-ños",
    "arrancapinos": "a-rran-ca-pi-nos",
    "arrancar": "a-rran-car",
    "arrancasiega": "a-rran-ca-sie-ga",
    "arranchadera": "a-rran-cha-de-ra",
    "arranchar": "a-rran-char",
    "arranchón": "a-rran-chón",
    "arranciar": "a-rran-ciar",
    "arranciarse": "a-rran-ciar-se",
    "arrancón": "a-rran-cón",
    "arranque": "a-rran-que",
    "arranquera": "a-rran-que-ra",
    "arrapar": "a-rra-par",
    "arrapiezo": "a-rra-pie-zo",
    "arrapo": "a-rra-po",
    "arraquive": "a-rra-qui-ve",
    "arrarray": "a-rra-rray",
    "arras": "a-rras",
    "arrás": "a-rrás",
    "arrasada": "a-rra-sa-da",
    "arrasado": "a-rra-sa-do",
    "arrasador": "a-rra-sa-dor",
    "arrasadura": "a-rra-sa-du-ra",
    "arrasamiento": "a-rra-sa-mien-to",
    "arrasar": "a-rra-sar",
    "arrascar": "a-rras-car",
    "arrastracuero": "a-rras-tra-cue-ro",
    "arrastraculo": "a-rras-tra-cu-lo",
    "arrastrada": "a-rras-tra-da",
    "arrastradamente": "a-rras-tra-da-men-te",
    "arrastradera": "a-rras-tra-de-ra",
    "arrastradero": "a-rras-tra-de-ro",
    "arrastradiza": "a-rras-tra-di-za",
    "arrastradizo": "a-rras-tra-di-zo",
    "arrastrado": "a-rras-tra-do",
    "arrastramiento": "a-rras-tra-mien-to",
    "arrastrante": "a-rras-tran-te",
    "arrastrapiés": "a-rras-tra-piés",
    "arrastrar": "a-rras-trar",
    "arrastre": "a-rras-tre",
    "arrastrero": "a-rras-tre-ro",
    "arrate": "a-rra-te",
    "arratonada": "a-rra-to-na-da",
    "arratonado": "a-rra-to-na-do",
    "arratonamiento": "a-rra-to-na-mien-to",
    "arratonar": "a-rra-to-nar",
    "arrayán": "a-rra-yán",
    "arrayana": "a-rra-ya-na",
    "arrayanal": "a-rra-ya-nal",
    "arrayano": "a-rra-ya-no",
    "arrayaz": "a-rra-yaz",
    "arraz": "a-rraz",
    "arre": "a-rre",
    "arreada": "a-rre-a-da",
    "arreado": "a-rre-a-do",
    "arreador": "a-rre-a-dor",
    "arreala": "a-rre-a-la",
    "arrear": "a-rre-ar",
    "arrebañaderas": "a-rre-ba-ña-de-ras",
    "arrebañador": "a-rre-ba-ña-dor",
    "arrebañadora": "a-rre-ba-ña-do-ra",
    "arrebañadura": "a-rre-ba-ña-du-ra",
    "arrebañar": "a-rre-ba-ñar",
    "arrebatacapas": "a-rre-ba-ta-ca-pas",
    "arrebatada": "a-rre-ba-ta-da",
    "arrebatadamente": "a-rre-ba-ta-da-men-te",
    "arrebatadiza": "a-rre-ba-ta-di-za",
    "arrebatadizo": "a-rre-ba-ta-di-zo",
    "arrebatado": "a-rre-ba-ta-do",
    "arrebatador": "a-rre-ba-ta-dor",
    "arrebatadora": "a-rre-ba-ta-do-ra",
    "arrebatamiento": "a-rre-ba-ta-mien-to",
    "arrebatapuñadas": "a-rre-ba-ta-pu-ña-das",
    "arrebatar": "a-rre-ba-tar",
    "arrebatarse": "a-rre-ba-tar-se",
    "arrebatiña": "a-rre-ba-ti-ña",
    "arrebato": "a-rre-ba-to",
    "arrebatón": "a-rre-ba-tón",
    "arrebatosa": "a-rre-ba-to-sa",
    "arrebatoso": "a-rre-ba-to-so",
    "arrebiatar": "a-rre-bia-tar",
    "arrebiate": "a-rre-bia-te",
    "arrebol": "a-rre-bol",
    "arrebolada": "a-rre-bo-la-da",
    "arrebolar": "a-rre-bo-lar",
    "arrebolera": "a-rre-bo-le-ra",
    "arrebollar": "a-rre-bo-llar",
    "arrebollarse": "a-rre-bo-llar-se",
    "arrebozar": "a-rre-bo-zar",
    "arrebozo": "a-rre-bo-zo",
    "arrebujadamente": "a-rre-bu-ja-da-men-te",
    "arrebujar": "a-rre-bu-jar",
    "arrecadar": "a-rre-ca-dar",
    "arrecha": "a-rre-cha",
    "arrechar": "a-rre-char",
    "arrechera": "a-rre-che-ra",
    "arrecho": "a-rre-cho",
    "arrechuchar": "a-rre-chu-char",
    "arrechucho": "a-rre-chu-cho",
    "arrechura": "a-rre-chu-ra",
    "arreciar": "a-rre-ciar",
    "arrecifar": "a-rre-ci-far",
    "arrecife": "a-rre-ci-fe",
    "arrecir": "a-rre-cir",
    "arredilar": "a-rre-di-lar",
    "arredo": "a-rre-do",
    "arredomada": "a-rre-do-ma-da",
    "arredomado": "a-rre-do-ma-do",
    "arredondear": "a-rre-don-de-ar",
    "arredor": "a-rre-dor",
    "arredramiento": "a-rre-dra-mien-to",
    "arredrar": "a-rre-drar",
    "arredro": "a-rre-dro",
    "arregazada": "a-rre-ga-za-da",
    "arregazado": "a-rre-ga-za-do",
    "arregazar": "a-rre-ga-zar",
    "arreglada": "a-rre-gla-da",
    "arregladamente": "a-rre-gla-da-men-te",
    "arreglado": "a-rre-gla-do",
    "arreglador": "a-rre-gla-dor",
    "arregladora": "a-rre-gla-do-ra",
    "arreglar": "a-rre-glar",
    "arreglín": "a-rre-glín",
    "arreglista": "a-rre-glis-ta",
    "arreglo": "a-rre-glo",
    "arregostar": "a-rre-gos-tar",
    "arregostarse": "a-rre-gos-tar-se",
    "arregosto": "a-rre-gos-to",
    "arreísmo": "a-rre-ís-mo",
    "arrejacar": "a-rre-ja-car",
    "arrejaco": "a-rre-ja-co",
    "arrejada": "a-rre-ja-da",
    "arrejaque": "a-rre-ja-que",
    "arrejerar": "a-rre-je-rar",
    "arrejonada": "a-rre-jo-na-da",
    "arrejonado": "a-rre-jo-na-do",
    "arrejuntar": "a-rre-jun-tar",
    "arrelde": "a-rrel-de",
    "arrellanar": "a-rre-lla-nar",
    "arrellanarse": "a-rre-lla-nar-se",
    "arremangada": "a-rre-man-ga-da",
    "arremangado": "a-rre-man-ga-do",
    "arremangar": "a-rre-man-gar",
    "arremango": "a-rre-man-go",
    "arrematar": "a-rre-ma-tar",
    "arremedar": "a-rre-me-dar",
    "arremetedero": "a-rre-me-te-de-ro",
    "arremetedor": "a-rre-me-te-dor",
    "arremetedora": "a-rre-me-te-do-ra",
    "arremeter": "a-rre-me-ter",
    "arremetida": "a-rre-me-ti-da",
    "arremetimiento": "a-rre-me-ti-mien-to",
    "arremolinadamente": "a-rre-mo-li-na-da-men-te",
    "arremolinar": "a-rre-mo-li-nar",
    "arremolinarse": "a-rre-mo-li-nar-se",
    "arrempujar": "a-rrem-pu-jar",
    "arrempujón": "a-rrem-pu-jón",
    "arremueco": "a-rre-mue-co",
    "arremuesco": "a-rre-mues-co",
    "arrendable": "a-rren-da-ble",
    "arrendación": "a-rren-da-ción",
    "arrendadero": "a-rren-da-de-ro",
    "arrendador": "a-rren-da-dor",
    "arrendadora": "a-rren-da-do-ra",
    "arrendajo": "a-rren-da-jo",
    "arrendamiento": "a-rren-da-mien-to",
    "arrendar": "a-rren-dar",
    "arrendataria": "a-rren-da-ta-ria",
    "arrendatario": "a-rren-da-ta-rio",
    "arrendaticia": "a-rren-da-ti-cia",
    "arrendaticio": "a-rren-da-ti-cio",
    "arrentada": "a-rren-ta-da",
    "arrentado": "a-rren-ta-do",
    "arreo": "a-rre-o",
    "arrepanchigar": "a-rre-pan-chi-gar",
    "arrepanchigarse": "a-rre-pan-chi-gar-se",
    "arrepápalo": "a-rre-pá-pa-lo",
    "arrepasar": "a-rre-pa-sar",
    "arrepasarse": "a-rre-pa-sar-se",
    "arrepentida": "a-rre-pen-ti-da",
    "arrepentido": "a-rre-pen-ti-do",
    "arrepentimiento": "a-rre-pen-ti-mien-to",
    "arrepentir": "a-rre-pen-tir",
    "arrepentirse": "a-rre-pen-tir-se",
    "arrepisa": "a-rre-pi-sa",
    "arrepiso": "a-rre-pi-so",
    "arrepistar": "a-rre-pis-tar",
    "arrepisto": "a-rre-pis-to",
    "arrepticia": "a-rrep-ti-cia",
    "arrepticio": "a-rrep-ti-cio",
    "arrequesonar": "a-rre-que-so-nar",
    "arrequesonarse": "a-rre-que-so-nar-se",
    "arrequife": "a-rre-qui-fe",
    "arrequín": "a-rre-quín",
    "arrequintar": "a-rre-quin-tar",
    "arrequive": "a-rre-qui-ve",
    "arrestada": "a-rres-ta-da",
    "arrestado": "a-rres-ta-do",
    "arrestar": "a-rres-tar",
    "arresto": "a-rres-to",
    "arretín": "a-rre-tín",
    "arretranca": "a-rre-tran-ca",
    "arrevesada": "a-rre-ve-sa-da",
    "arrevesado": "a-rre-ve-sa-do",
    "arrevistado": "a-rre-vis-ta-do",
    "arrevolvedor": "a-rre-vol-ve-dor",
    "arrevolver": "a-rre-vol-ver",
    "arrezafe": "a-rre-za-fe",
    "arrezagar": "a-rre-za-gar",
    "arria": "a-rria",
    "arriacense": "a-rria-cen-se",
    "arriada": "a-rria-da",
    "arriado": "a-rria-do",
    "arrial": "a-rrial",
    "arriamiento": "a-rria-mien-to",
    "arriana": "a-rria-na",
    "arrianismo": "a-rria-nis-mo",
    "arriano": "a-rria-no",
    "arriar": "a-rriar",
    "arriata": "a-rria-ta",
    "arriate": "a-rria-te",
    "arriaz": "a-rriaz",
    "arriba": "a-rri-ba",
    "arribada": "a-rri-ba-da",
    "arribaje": "a-rri-ba-je",
    "arribar": "a-rri-bar",
    "arribazón": "a-rri-ba-zón",
    "arribeña": "a-rri-be-ña",
    "arribeño": "a-rri-be-ño",
    "arribes": "a-rri-bes",
    "arribismo": "a-rri-bis-mo",
    "arribista": "a-rri-bis-ta",
    "arribo": "a-rri-bo",
    "arricés": "a-rri-cés",
    "arricesa": "a-rri-ce-sa",
    "arricete": "a-rri-ce-te",
    "arridar": "a-rri-dar",
    "arriedro": "a-rrie-dro",
    "arriendo": "a-rrien-do",
    "arriera": "a-rrie-ra",
    "arriería": "a-rrie-rí-a",
    "arriero": "a-rrie-ro",
    "arriesgada": "a-rries-ga-da",
    "arriesgadamente": "a-rries-ga-da-men-te",
    "arriesgado": "a-rries-ga-do",
    "arriesgar": "a-rries-gar",
    "arriesgón": "a-rries-gón",
    "arrife": "a-rri-fe",
    "arrigir": "a-rri-gir",
    "arrigirse": "a-rri-gir-se",
    "arrima": "a-rri-ma",
    "arrimada": "a-rri-ma-da",
    "arrimadero": "a-rri-ma-de-ro",
    "arrimadillo": "a-rri-ma-di-llo",
    "arrimadiza": "a-rri-ma-di-za",
    "arrimadizo": "a-rri-ma-di-zo",
    "arrimado": "a-rri-ma-do",
    "arrimador": "a-rri-ma-dor",
    "arrimadura": "a-rri-ma-du-ra",
    "arrimar": "a-rri-mar",
    "arrime": "a-rri-me",
    "arrimo": "a-rri-mo",
    "arrimón": "a-rri-món",
    "arrincar": "a-rrin-car",
    "arrinconada": "a-rrin-co-na-da",
    "arrinconado": "a-rrin-co-na-do",
    "arrinconamiento": "a-rrin-co-na-mien-to",
    "arrinconar": "a-rrin-co-nar",
    "arriñonada": "a-rri-ño-na-da",
    "arriñonado": "a-rri-ño-na-do",
    "arriostrar": "a-rrios-trar",
    "arriscada": "a-rris-ca-da",
    "arriscadamente": "a-rris-ca-da-men-te",
    "arriscado": "a-rris-ca-do",
    "arriscador": "a-rris-ca-dor",
    "arriscadora": "a-rris-ca-do-ra",
    "arriscamiento": "a-rris-ca-mien-to",
    "arriscar": "a-rris-car",
    "arrisco": "a-rris-co",
    "arristranco": "a-rris-tran-co",
    "arritar": "a-rri-tar",
    "arritmia": "a-rrit-mia",
    "arrítmica": "a-rrít-mi-ca",
    "arrítmicamente": "a-rrít-mi-ca-men-te",
    "arrítmico": "a-rrít-mi-co",
    "arritranca": "a-rri-tran-ca",
    "arrizar": "a-rri-zar",
    "arroaz": "a-rro-az",
    "arroba": "a-rro-ba",
    "arrobadera": "a-rro-ba-de-ra",
    "arrobadizo": "a-rro-ba-di-zo",
    "arrobado": "a-rro-ba-do",
    "arrobador": "a-rro-ba-dor",
    "arrobadora": "a-rro-ba-do-ra",
    "arrobal": "a-rro-bal",
    "arrobamiento": "a-rro-ba-mien-to",
    "arrobar": "a-rro-bar",
    "arrobeña": "a-rro-be-ña",
    "arrobeño": "a-rro-be-ño",
    "arrobera": "a-rro-be-ra",
    "arrobero": "a-rro-be-ro",
    "arrobo": "a-rro-bo",
    "arrocabe": "a-rro-ca-be",
    "arrocada": "a-rro-ca-da",
    "arrocado": "a-rro-ca-do",
    "arrocera": "a-rro-ce-ra",
    "arrocería": "a-rro-ce-rí-a",
    "arrocero": "a-rro-ce-ro",
    "arrochar": "a-rro-char",
    "arroche": "a-rro-che",
    "arrochelar": "a-rro-che-lar",
    "arrocinada": "a-rro-ci-na-da",
    "arrocinado": "a-rro-ci-na-do",
    "arrocinar": "a-rro-ci-nar",
    "arrodajar": "a-rro-da-jar",
    "arrodajarse": "a-rro-da-jar-se",
    "arrodalado": "a-rro-da-la-do",
    "arrodeamiento": "a-rro-de-a-mien-to",
    "arrodear": "a-rro-de-ar",
    "arrodelar": "a-rro-de-lar",
    "arrodeo": "a-rro-de-o",
    "arrodillada": "a-rro-di-lla-da",
    "arrodilladura": "a-rro-di-lla-du-ra",
    "arrodillamiento": "a-rro-di-lla-mien-to",
    "arrodillar": "a-rro-di-llar",
    "arrodrigar": "a-rro-dri-gar",
    "arrodrigonar": "a-rro-dri-go-nar",
    "arrogación": "a-rro-ga-ción",
    "arrogador": "a-rro-ga-dor",
    "arrogadora": "a-rro-ga-do-ra",
    "arrogancia": "a-rro-gan-cia",
    "arrogante": "a-rro-gan-te",
    "arrogantemente": "a-rro-gan-te-men-te",
    "arrogar": "a-rro-gar",
    "arrojada": "a-rro-ja-da",
    "arrojadamente": "a-rro-ja-da-men-te",
    "arrojadiza": "a-rro-ja-di-za",
    "arrojadizo": "a-rro-ja-di-zo",
    "arrojado": "a-rro-ja-do",
    "arrojador": "a-rro-ja-dor",
    "arrojadora": "a-rro-ja-do-ra",
    "arrojamiento": "a-rro-ja-mien-to",
    "arrojar": "a-rro-jar",
    "arroje": "a-rro-je",
    "arrojo": "a-rro-jo",
    "arrollable": "a-rro-lla-ble",
    "arrollado": "a-rro-lla-do",
    "arrollador": "a-rro-lla-dor",
    "arrolladora": "a-rro-lla-do-ra",
    "arrollamiento": "a-rro-lla-mien-to",
    "arrollar": "a-rro-llar",
    "arromadizar": "a-rro-ma-di-zar",
    "arromanzar": "a-rro-man-zar",
    "arromar": "a-rro-mar",
    "arromper": "a-rrom-per",
    "arrompido": "a-rrom-pi-do",
    "arronjar": "a-rron-jar",
    "arronzar": "a-rron-zar",
    "arropamiento": "a-rro-pa-mien-to",
    "arropar": "a-rro-par",
    "arrope": "a-rro-pe",
    "arropera": "a-rro-pe-ra",
    "arropía": "a-rro-pí-a",
    "arropiera": "a-rro-pie-ra",
    "arropiero": "a-rro-pie-ro",
    "arroscar": "a-rros-car",
    "arrosquetado": "a-rros-que-ta-do",
    "arrostrada": "a-rros-tra-da",
    "arrostrado": "a-rros-tra-do",
    "arrostrar": "a-rros-trar",
    "arrotada": "a-rro-ta-da",
    "arrotado": "a-rro-ta-do",
    "arrotar": "a-rro-tar",
    "arroto": "a-rro-to",
    "arroyada": "a-rro-ya-da",
    "arroyadero": "a-rro-ya-de-ro",
    "arroyamiento": "a-rro-ya-mien-to",
    "arroyar": "a-rro-yar",
    "arroyarse": "a-rro-yar-se",
    "arroyato": "a-rro-ya-to",
    "arroyo": "a-rro-yo",
    "arroyuela": "a-rro-yue-la",
    "arroz": "a-rroz",
    "arrozal": "a-rro-zal",
    "arruar": "a-rruar",
    "arruchar": "a-rru-char",
    "arrufadía": "a-rru-fa-dí-a",
    "arrufadura": "a-rru-fa-du-ra",
    "arrufaldada": "a-rru-fal-da-da",
    "arrufaldado": "a-rru-fal-da-do",
    "arrufar": "a-rru-far",
    "arrufianada": "a-rru-fia-na-da",
    "arrufianado": "a-rru-fia-na-do",
    "arrufo": "a-rru-fo",
    "arruga": "a-rru-ga",
    "arrugable": "a-rru-ga-ble",
    "arrugación": "a-rru-ga-ción",
    "arrugamiento": "a-rru-ga-mien-to",
    "arrugar": "a-rru-gar",
    "arrugia": "a-rru-gia",
    "arruí": "a-rruí",
    "arruinado": "a-rrui-na-do",
    "arruinador": "a-rrui-na-dor",
    "arruinadora": "a-rrui-na-do-ra",
    "arruinamiento": "a-rrui-na-mien-to",
    "arruinar": "a-rrui-nar",
    "arrullador": "a-rru-lla-dor",
    "arrulladora": "a-rru-lla-do-ra",
    "arrullar": "a-rru-llar",
    "arrullo": "a-rru-llo",
    "arruma": "a-rru-ma",
    "arrumaco": "a-rru-ma-co",
    "arrumaje": "a-rru-ma-je",
    "arrumar": "a-rru-mar",
    "arrumazón": "a-rru-ma-zón",
    "arrumbación": "a-rrum-ba-ción",
    "arrumbada": "a-rrum-ba-da",
    "arrumbador": "a-rrum-ba-dor",
    "arrumbadora": "a-rrum-ba-do-ra",
    "arrumbamiento": "a-rrum-ba-mien-to",
    "arrumbar": "a-rrum-bar",
    "arrumueco": "a-rru-mue-co",
    "arrunflar": "a-rrun-flar",
    "arrurruz": "a-rru-rruz",
    "arruruz": "a-rru-ruz",
    "arrusticado": "a-rrus-ti-ca-do",
    "arrusticar": "a-rrus-ti-car",
    "arrutar": "a-rru-tar",
    "arrutinar": "a-rru-ti-nar",
    "arsafraga": "ar-sa-fra-ga",
    "arsenal": "ar-se-nal",
    "arsenalera": "ar-se-na-le-ra",
    "arsenalero": "ar-se-na-le-ro",
    "arseniato": "ar-se-nia-to",
    "arsenical": "ar-se-ni-cal",
    "arsénico": "ar-sé-ni-co",
    "arsenioso": "ar-se-nio-so",
    "arsenito": "ar-se-ni-to",
    "arseniuro": "ar-se-niu-ro",
    "arsolla": "ar-so-lla",
    "arta": "ar-ta",
    "ártabra": "ár-ta-bra",
    "ártabro": "ár-ta-bro",
    "artado": "ar-ta-do",
    "artal": "ar-tal",
    "artanica": "ar-ta-ni-ca",
    "artanita": "ar-ta-ni-ta",
    "arte": "ar-te",
    "artefacto": "ar-te-fac-to",
    "artejo": "ar-te-jo",
    "artellería": "ar-te-lle-rí-a",
    "artemisa": "ar-te-mi-sa",
    "artemisia": "ar-te-mi-sia",
    "artera": "ar-te-ra",
    "arteramente": "ar-te-ra-men-te",
    "artería": "ar-te-rí-a",
    "arteria": "ar-te-ria",
    "arterial": "ar-te-rial",
    "arterioesclerosis": "ar-te-rio-es-cle-ro-sis",
    "arteriografía": "ar-te-rio-gra-fí-a",
    "arteriola": "ar-te-rio-la",
    "arteriología": "ar-te-rio-lo-gí-a",
    "arteriosa": "ar-te-rio-sa",
    "arteriosclerósico": "ar-te-rios-cle-ró-si-co",
    "arteriosclerosis": "ar-te-rios-cle-ro-sis",
    "arteriosclerótica": "ar-te-rios-cle-ró-ti-ca",
    "arteriosclerótico": "ar-te-rios-cle-ró-ti-co",
    "arterioso": "ar-te-rio-so",
    "arteritis": "ar-te-ri-tis",
    "artero": "ar-te-ro",
    "artesa": "ar-te-sa",
    "artesana": "ar-te-sa-na",
    "artesanado": "ar-te-sa-na-do",
    "artesanal": "ar-te-sa-nal",
    "artesanalmente": "ar-te-sa-nal-men-te",
    "artesanía": "ar-te-sa-ní-a",
    "artesano": "ar-te-sa-no",
    "artesiana": "ar-te-sia-na",
    "artesiano": "ar-te-sia-no",
    "artesilla": "ar-te-si-lla",
    "artesón": "ar-te-són",
    "artesonada": "ar-te-so-na-da",
    "artesonado": "ar-te-so-na-do",
    "artesonar": "ar-te-so-nar",
    "artética": "ar-té-ti-ca",
    "artético": "ar-té-ti-co",
    "artica": "ar-ti-ca",
    "ártica": "ár-ti-ca",
    "ártico": "ár-ti-co",
    "articulación": "ar-ti-cu-la-ción",
    "articulada": "ar-ti-cu-la-da",
    "articuladamente": "ar-ti-cu-la-da-men-te",
    "articulado": "ar-ti-cu-la-do",
    "articulador": "ar-ti-cu-la-dor",
    "articuladora": "ar-ti-cu-la-do-ra",
    "articular": "ar-ti-cu-lar",
    "articularia": "ar-ti-cu-la-ria",
    "articulario": "ar-ti-cu-la-rio",
    "articulatoria": "ar-ti-cu-la-to-ria",
    "articulatorio": "ar-ti-cu-la-to-rio",
    "articulista": "ar-ti-cu-lis-ta",
    "artículo": "ar-tí-cu-lo",
    "artifara": "ar-ti-fa-ra",
    "artífice": "ar-tí-fi-ce",
    "artificial": "ar-ti-fi-cial",
    "artificialidad": "ar-ti-fi-cia-li-dad",
    "artificialmente": "ar-ti-fi-cial-men-te",
    "artificiar": "ar-ti-fi-ciar",
    "artificiera": "ar-ti-fi-cie-ra",
    "artificiero": "ar-ti-fi-cie-ro",
    "artificio": "ar-ti-fi-cio",
    "artificiosa": "ar-ti-fi-cio-sa",
    "artificiosamente": "ar-ti-fi-cio-sa-men-te",
    "artificiosidad": "ar-ti-fi-cio-si-dad",
    "artificioso": "ar-ti-fi-cio-so",
    "artiga": "ar-ti-ga",
    "artigar": "ar-ti-gar",
    "artiguense": "ar-ti-guen-se",
    "artillado": "ar-ti-lla-do",
    "artillar": "ar-ti-llar",
    "artillería": "ar-ti-lle-rí-a",
    "artillero": "ar-ti-lle-ro",
    "artilugio": "ar-ti-lu-gio",
    "artimaña": "ar-ti-ma-ña",
    "artimón": "ar-ti-món",
    "artina": "ar-ti-na",
    "artiodáctilo": "ar-tio-dác-ti-lo",
    "artista": "ar-tis-ta",
    "artística": "ar-tís-ti-ca",
    "artísticamente": "ar-tís-ti-ca-men-te",
    "artístico": "ar-tís-ti-co",
    "artizada": "ar-ti-za-da",
    "artizado": "ar-ti-za-do",
    "artizar": "ar-ti-zar",
    "arto": "ar-to",
    "artocarpácea": "ar-to-car-pá-ce-a",
    "artocarpáceo": "ar-to-car-pá-ce-o",
    "artocárpea": "ar-to-cár-pe-a",
    "artocárpeo": "ar-to-cár-pe-o",
    "artolas": "ar-to-las",
    "artos": "ar-tos",
    "artralgia": "ar-tral-gia",
    "artrítica": "ar-trí-ti-ca",
    "artrítico": "ar-trí-ti-co",
    "artritis": "ar-tri-tis",
    "artritismo": "ar-tri-tis-mo",
    "artrografía": "ar-tro-gra-fí-a",
    "artrología": "ar-tro-lo-gí-a",
    "artropatía": "ar-tro-pa-tí-a",
    "artrópodo": "ar-tró-po-do",
    "artroscopia": "ar-tros-co-pia",
    "artroscopio": "ar-tros-co-pio",
    "artrosis": "ar-tro-sis",
    "artuña": "ar-tu-ña",
    "artúrico": "ar-tú-ri-co",
    "aruera": "a-rue-ra",
    "arugas": "a-ru-gas",
    "árula": "á-ru-la",
    "aruñar": "a-ru-ñar",
    "aruñazo": "a-ru-ña-zo",
    "arundense": "a-run-den-se",
    "arundínea": "a-run-dí-ne-a",
    "arundíneo": "a-run-dí-ne-o",
    "aruño": "a-ru-ño",
    "aruñón": "a-ru-ñón",
    "arupo": "a-ru-po",
    "arúspice": "a-rús-pi-ce",
    "aruspicina": "a-rus-pi-ci-na",
    "arveja": "ar-ve-ja",
    "arvejal": "ar-ve-jal",
    "arvejana": "ar-ve-ja-na",
    "arvejar": "ar-ve-jar",
    "arvejera": "ar-ve-je-ra",
    "arvejo": "ar-ve-jo",
    "arvejón": "ar-ve-jón",
    "arvejona": "ar-ve-jo-na",
    "arvejote": "ar-ve-jo-te",
    "arvense": "ar-ven-se",
    "arzobispado": "ar-zo-bis-pa-do",
    "arzobispal": "ar-zo-bis-pal",
    "arzobispo": "ar-zo-bis-po",
    "arzolla": "ar-zo-lla",
    "arzón": "ar-zón",
    "asa": "a-sa",
    "asaborada": "a-sa-bo-ra-da",
    "asaborado": "a-sa-bo-ra-do",
    "asaborar": "a-sa-bo-rar",
    "asaborir": "a-sa-bo-rir",
    "asacador": "a-sa-ca-dor",
    "asacadora": "a-sa-ca-do-ra",
    "asacamiento": "a-sa-ca-mien-to",
    "asacar": "a-sa-car",
    "asación": "a-sa-ción",
    "asacristanada": "a-sa-cris-ta-na-da",
    "asacristanado": "a-sa-cris-ta-na-do",
    "asada": "a-sa-da",
    "asadera": "a-sa-de-ra",
    "asadero": "a-sa-de-ro",
    "asado": "a-sa-do",
    "asador": "a-sa-dor",
    "asadora": "a-sa-do-ra",
    "asadura": "a-sa-du-ra",
    "asaduría": "a-sa-du-rí-a",
    "asaetar": "a-sa-e-tar",
    "asaeteador": "a-sa-e-te-a-dor",
    "asaeteadora": "a-sa-e-te-a-do-ra",
    "asaetear": "a-sa-e-te-ar",
    "asaetinada": "a-sa-e-ti-na-da",
    "asaetinado": "a-sa-e-ti-na-do",
    "asafétida": "a-sa-fé-ti-da",
    "asainetada": "a-sai-ne-ta-da",
    "asainetado": "a-sai-ne-ta-do",
    "asainetear": "a-sai-ne-te-ar",
    "asalariada": "a-sa-la-ria-da",
    "asalariado": "a-sa-la-ria-do",
    "asalariar": "a-sa-la-riar",
    "asalir": "a-sa-lir",
    "asalmerar": "a-sal-me-rar",
    "asalmonada": "a-sal-mo-na-da",
    "asalmonado": "a-sal-mo-na-do",
    "asaltador": "a-sal-ta-dor",
    "asaltadora": "a-sal-ta-do-ra",
    "asaltante": "a-sal-tan-te",
    "asaltar": "a-sal-tar",
    "asalto": "a-sal-to",
    "asamblea": "a-sam-ble-a",
    "asambleario": "a-sam-ble-a-rio",
    "asambleísmo": "a-sam-ble-ís-mo",
    "asambleísta": "a-sam-ble-ís-ta",
    "asar": "a-sar",
    "asarabácara": "a-sa-ra-bá-ca-ra",
    "asáraca": "a-sá-ra-ca",
    "asardinada": "a-sar-di-na-da",
    "asardinado": "a-sar-di-na-do",
    "asarear": "a-sa-re-ar",
    "asarero": "a-sa-re-ro",
    "asargada": "a-sar-ga-da",
    "asargado": "a-sar-ga-do",
    "asarina": "a-sa-ri-na",
    "ásaro": "á-sa-ro",
    "asativa": "a-sa-ti-va",
    "asativo": "a-sa-ti-vo",
    "asayar": "a-sa-yar",
    "asaz": "a-saz",
    "asbestina": "as-bes-ti-na",
    "asbestino": "as-bes-ti-no",
    "asbesto": "as-bes-to",
    "asbestosis": "as-bes-to-sis",
    "asca": "as-ca",
    "ascalonia": "as-ca-lo-nia",
    "ascalonita": "as-ca-lo-ni-ta",
    "áscar": "ás-car",
    "áscari": "ás-ca-ri",
    "ascáride": "as-cá-ri-de",
    "ascarita": "as-ca-ri-ta",
    "ascendencia": "as-cen-den-cia",
    "ascendente": "as-cen-den-te",
    "ascender": "as-cen-der",
    "ascendiente": "as-cen-dien-te",
    "ascensión": "as-cen-sión",
    "ascensional": "as-cen-sio-nal",
    "ascensionista": "as-cen-sio-nis-ta",
    "ascenso": "as-cen-so",
    "ascensor": "as-cen-sor",
    "ascensorista": "as-cen-so-ris-ta",
    "ascesis": "as-ce-sis",
    "asceta": "as-ce-ta",
    "asceterio": "as-ce-te-rio",
    "ascética": "as-cé-ti-ca",
    "ascéticamente": "as-cé-ti-ca-men-te",
    "ascético": "as-cé-ti-co",
    "ascetismo": "as-ce-tis-mo",
    "ascia": "as-cia",
    "ascidia": "as-ci-dia",
    "ascio": "as-cio",
    "ásciro": "ás-ci-ro",
    "asciterio": "as-ci-te-rio",
    "ascítica": "as-cí-ti-ca",
    "ascítico": "as-cí-ti-co",
    "ascitis": "as-ci-tis",
    "asclepiadácea": "as-cle-pia-dá-ce-a",
    "asclepiadáceo": "as-cle-pia-dá-ce-o",
    "asclepiadea": "as-cle-pia-de-a",
    "asclepiadeo": "as-cle-pia-de-o",
    "asco": "as-co",
    "ascomicete": "as-co-mi-ce-te",
    "ascomiceto": "as-co-mi-ce-to",
    "asconder": "as-con-der",
    "ascondidamente": "as-con-di-da-men-te",
    "ascondido": "as-con-di-do",
    "ascondrijo": "as-con-dri-jo",
    "ascórbico": "as-cór-bi-co",
    "ascorosa": "as-co-ro-sa",
    "ascoroso": "as-co-ro-so",
    "ascosa": "as-co-sa",
    "ascosidad": "as-co-si-dad",
    "ascoso": "as-co-so",
    "ascrea": "as-cre-a",
    "ascreo": "as-cre-o",
    "ascua": "as-cua",
    "aseada": "a-se-a-da",
    "aseado": "a-se-a-do",
    "aseador": "a-se-a-dor",
    "aseadora": "a-se-a-do-ra",
    "asear": "a-se-ar",
    "asechador": "a-se-cha-dor",
    "asechadora": "a-se-cha-do-ra",
    "asechamiento": "a-se-cha-mien-to",
    "asechanza": "a-se-chan-za",
    "asechar": "a-se-char",
    "asecho": "a-se-cho",
    "asechosa": "a-se-cho-sa",
    "asechoso": "a-se-cho-so",
    "asecución": "a-se-cu-ción",
    "asedar": "a-se-dar",
    "asediador": "a-se-dia-dor",
    "asediadora": "a-se-dia-do-ra",
    "asediante": "a-se-dian-te",
    "asediar": "a-se-diar",
    "asedio": "a-se-dio",
    "aseglarar": "a-se-gla-rar",
    "aseglararse": "a-se-gla-rar-se",
    "aseglarizar": "a-se-gla-ri-zar",
    "asegundar": "a-se-gun-dar",
    "asegurable": "a-se-gu-ra-ble",
    "aseguración": "a-se-gu-ra-ción",
    "asegurada": "a-se-gu-ra-da",
    "asegurado": "a-se-gu-ra-do",
    "asegurador": "a-se-gu-ra-dor",
    "aseguradora": "a-se-gu-ra-do-ra",
    "aseguramiento": "a-se-gu-ra-mien-to",
    "aseguranza": "a-se-gu-ran-za",
    "asegurar": "a-se-gu-rar",
    "aseguro": "a-se-gu-ro",
    "aseidad": "a-sei-dad",
    "aseladero": "a-se-la-de-ro",
    "aselador": "a-se-la-dor",
    "aselar": "a-se-lar",
    "asemblar": "a-sem-blar",
    "asemejar": "a-se-me-jar",
    "asemillar": "a-se-mi-llar",
    "asencio": "a-sen-cio",
    "asendereada": "a-sen-de-re-a-da",
    "asendereado": "a-sen-de-re-a-do",
    "asenderear": "a-sen-de-re-ar",
    "asengladura": "a-sen-gla-du-ra",
    "asenjo": "a-sen-jo",
    "aseñorada": "a-se-ño-ra-da",
    "aseñorado": "a-se-ño-ra-do",
    "aseñoritado": "a-se-ño-ri-ta-do",
    "asensio": "a-sen-sio",
    "asenso": "a-sen-so",
    "asentación": "a-sen-ta-ción",
    "asentada": "a-sen-ta-da",
    "asentadamente": "a-sen-ta-da-men-te",
    "asentaderas": "a-sen-ta-de-ras",
    "asentadillas": "a-sen-ta-di-llas",
    "asentado": "a-sen-ta-do",
    "asentador": "a-sen-ta-dor",
    "asentadora": "a-sen-ta-do-ra",
    "asentadura": "a-sen-ta-du-ra",
    "asentamiento": "a-sen-ta-mien-to",
    "asentar": "a-sen-tar",
    "asentimiento": "a-sen-ti-mien-to",
    "asentir": "a-sen-tir",
    "asentista": "a-sen-tis-ta",
    "aseo": "a-se-o",
    "asépala": "a-sé-pa-la",
    "asépalo": "a-sé-pa-lo",
    "asepsia": "a-sep-sia",
    "aséptica": "a-sép-ti-ca",
    "asépticamente": "a-sép-ti-ca-men-te",
    "aséptico": "a-sép-ti-co",
    "asequi": "a-se-qui",
    "asequible": "a-se-qui-ble",
    "aserción": "a-ser-ción",
    "aserenar": "a-se-re-nar",
    "aseriar": "a-se-riar",
    "aseriarse": "a-se-riar-se",
    "asermonada": "a-ser-mo-na-da",
    "asermonado": "a-ser-mo-na-do",
    "aserrada": "a-se-rra-da",
    "aserradero": "a-se-rra-de-ro",
    "aserradiza": "a-se-rra-di-za",
    "aserradizo": "a-se-rra-di-zo",
    "aserrado": "a-se-rra-do",
    "aserrador": "a-se-rra-dor",
    "aserradora": "a-se-rra-do-ra",
    "aserradura": "a-se-rra-du-ra",
    "aserrar": "a-se-rrar",
    "aserrería": "a-se-rre-rí-a",
    "aserrín": "a-se-rrín",
    "aserrío": "a-se-rrí-o",
    "aserruchar": "a-se-rru-char",
    "asertiva": "a-ser-ti-va",
    "asertivo": "a-ser-ti-vo",
    "aserto": "a-ser-to",
    "asertor": "a-ser-tor",
    "asertora": "a-ser-to-ra",
    "asertórico": "a-ser-tó-ri-co",
    "asertorio": "a-ser-to-rio",
    "asesado": "a-se-sa-do",
    "asesar": "a-se-sar",
    "asesina": "a-se-si-na",
    "asesinar": "a-se-si-nar",
    "asesinato": "a-se-si-na-to",
    "asesino": "a-se-si-no",
    "asesor": "a-se-sor",
    "asesora": "a-se-so-ra",
    "asesoramiento": "a-se-so-ra-mien-to",
    "asesorar": "a-se-so-rar",
    "asesoría": "a-se-so-rí-a",
    "asestadero": "a-ses-ta-de-ro",
    "asestadura": "a-ses-ta-du-ra",
    "asestar": "a-ses-tar",
    "aseveración": "a-se-ve-ra-ción",
    "aseverar": "a-se-ve-rar",
    "aseverativa": "a-se-ve-ra-ti-va",
    "aseverativo": "a-se-ve-ra-ti-vo",
    "asexuado": "a-se-xua-do",
    "asexual": "a-se-xual",
    "asexualmente": "a-se-xual-men-te",
    "asfaltado": "as-fal-ta-do",
    "asfaltadora": "as-fal-ta-do-ra",
    "asfaltar": "as-fal-tar",
    "asfáltica": "as-fál-ti-ca",
    "asfáltico": "as-fál-ti-co",
    "asfalto": "as-fal-to",
    "asfíctica": "as-fíc-ti-ca",
    "asfíctico": "as-fíc-ti-co",
    "asfixia": "as-fi-xia",
    "asfixiado": "as-fi-xia-do",
    "asfixiante": "as-fi-xian-te",
    "asfixiar": "as-fi-xiar",
    "asfíxica": "as-fí-xi-ca",
    "asfíxico": "as-fí-xi-co",
    "asfódelo": "as-fó-de-lo",
    "así": "a-sí",
    "asiana": "a-sia-na",
    "asiano": "a-sia-no",
    "asiática": "a-siá-ti-ca",
    "asiático": "a-siá-ti-co",
    "asibilación": "a-si-bi-la-ción",
    "asibilar": "a-si-bi-lar",
    "asicar": "a-si-car",
    "asidero": "a-si-de-ro",
    "asidonense": "a-si-do-nen-se",
    "asidua": "a-si-dua",
    "asiduamente": "a-si-dua-men-te",
    "asiduidad": "a-si-dui-dad",
    "asiduo": "a-si-duo",
    "asiento": "a-sien-to",
    "asignable": "a-sig-na-ble",
    "asignación": "a-sig-na-ción",
    "asignado": "a-sig-na-do",
    "asignar": "a-sig-nar",
    "asignataria": "a-sig-na-ta-ria",
    "asignatario": "a-sig-na-ta-rio",
    "asignatura": "a-sig-na-tu-ra",
    "asilada": "a-si-la-da",
    "asilado": "a-si-la-do",
    "asilar": "a-si-lar",
    "asilla": "a-si-lla",
    "asilo": "a-si-lo",
    "asilvestrada": "a-sil-ves-tra-da",
    "asilvestrado": "a-sil-ves-tra-do",
    "asilvestrar": "a-sil-ves-trar",
    "asimesmo": "a-si-mes-mo",
    "asimetría": "a-si-me-trí-a",
    "asimétrica": "a-si-mé-tri-ca",
    "asimétricamente": "a-si-mé-tri-ca-men-te",
    "asimétricas": "a-si-mé-tri-cas",
    "asimétrico": "a-si-mé-tri-co",
    "asimiento": "a-si-mien-to",
    "asimilable": "a-si-mi-la-ble",
    "asimilación": "a-si-mi-la-ción",
    "asimilada": "a-si-mi-la-da",
    "asimilado": "a-si-mi-la-do",
    "asimilador": "a-si-mi-la-dor",
    "asimilar": "a-si-mi-lar",
    "asimilativa": "a-si-mi-la-ti-va",
    "asimilativo": "a-si-mi-la-ti-vo",
    "asimilatorio": "a-si-mi-la-to-rio",
    "asimilismo": "a-si-mi-lis-mo",
    "asimilista": "a-si-mi-lis-ta",
    "asimismo": "a-si-mis-mo",
    "asimplada": "a-sim-pla-da",
    "asimplado": "a-sim-pla-do",
    "asín": "a-sín",
    "asina": "a-si-na",
    "asincronía": "a-sin-cro-ní-a",
    "asincrónico": "a-sin-cró-ni-co",
    "asincronismo": "a-sin-cro-nis-mo",
    "asíncrono": "a-sín-cro-no",
    "asindético": "a-sin-dé-ti-co",
    "asíndeton": "a-sín-de-ton",
    "asinergia": "a-si-ner-gia",
    "asinina": "a-si-ni-na",
    "asinino": "a-si-ni-no",
    "asintomático": "a-sin-to-má-ti-co",
    "asíntota": "a-sín-to-ta",
    "asintótico": "a-sin-tó-ti-co",
    "asir": "a-sir",
    "asiria": "a-si-ria",
    "asiriana": "a-si-ria-na",
    "asiriano": "a-si-ria-no",
    "asirio": "a-si-rio",
    "asirióloga": "a-si-rió-lo-ga",
    "asiriología": "a-si-rio-lo-gí-a",
    "asiriólogo": "a-si-rió-lo-go",
    "asísmico": "a-sís-mi-co",
    "asistemático": "a-sis-te-má-ti-co",
    "asistencia": "a-sis-ten-cia",
    "asistencial": "a-sis-ten-cial",
    "asistencialismo": "a-sis-ten-cia-lis-mo",
    "asistenta": "a-sis-ten-ta",
    "asistente": "a-sis-ten-te",
    "asistido": "a-sis-ti-do",
    "asistimiento": "a-sis-ti-mien-to",
    "asistir": "a-sis-tir",
    "asistolia": "a-sis-to-lia",
    "asistólica": "a-sis-tó-li-ca",
    "asistólico": "a-sis-tó-li-co",
    "askenazí": "as-ke-na-zí",
    "aslilla": "as-li-lla",
    "asma": "as-ma",
    "asmadamente": "as-ma-da-men-te",
    "asmadera": "as-ma-de-ra",
    "asmadero": "as-ma-de-ro",
    "asmamiento": "as-ma-mien-to",
    "asmar": "as-mar",
    "asmática": "as-má-ti-ca",
    "asmático": "as-má-ti-co",
    "asmosa": "as-mo-sa",
    "asmoso": "as-mo-so",
    "asna": "as-na",
    "asnacho": "as-na-cho",
    "asnada": "as-na-da",
    "asnado": "as-na-do",
    "asnal": "as-nal",
    "asnallo": "as-na-llo",
    "asnalmente": "as-nal-men-te",
    "asnaúcho": "as-na-ú-cho",
    "asnear": "as-ne-ar",
    "asnería": "as-ne-rí-a",
    "asnerizo": "as-ne-ri-zo",
    "asnico": "as-ni-co",
    "asnilla": "as-ni-lla",
    "asnillo": "as-ni-llo",
    "asnina": "as-ni-na",
    "asnino": "as-ni-no",
    "asno": "as-no",
    "asnuna": "as-nu-na",
    "asnuno": "as-nu-no",
    "asobarcar": "a-so-bar-car",
    "asobinar": "a-so-bi-nar",
    "asobinarse": "a-so-bi-nar-se",
    "asocairar": "a-so-cai-rar",
    "asocarronada": "a-so-ca-rro-na-da",
    "asocarronado": "a-so-ca-rro-na-do",
    "asociable": "a-so-cia-ble",
    "asociación": "a-so-cia-ción",
    "asociacionismo": "a-so-cia-cio-nis-mo",
    "asociacionista": "a-so-cia-cio-nis-ta",
    "asociada": "a-so-cia-da",
    "asociado": "a-so-cia-do",
    "asocial": "a-so-cial",
    "asociamiento": "a-so-cia-mien-to",
    "asociar": "a-so-ciar",
    "asociativo": "a-so-cia-ti-vo",
    "asocio": "a-so-cio",
    "asohora": "a-so-ho-ra",
    "asolación": "a-so-la-ción",
    "asolador": "a-so-la-dor",
    "asoladora": "a-so-la-do-ra",
    "asolamiento": "a-so-la-mien-to",
    "asolanar": "a-so-la-nar",
    "asolapar": "a-so-la-par",
    "asolar": "a-so-lar",
    "asoldadar": "a-sol-da-dar",
    "asoldar": "a-sol-dar",
    "asoleada": "a-so-le-a-da",
    "asoleado": "a-so-le-a-do",
    "asoleamiento": "a-so-le-a-mien-to",
    "asolear": "a-so-le-ar",
    "asoleo": "a-so-le-o",
    "asolvamiento": "a-sol-va-mien-to",
    "asomada": "a-so-ma-da",
    "asomadera": "a-so-ma-de-ra",
    "asomar": "a-so-mar",
    "asómate": "a-só-ma-te",
    "asombradiza": "a-som-bra-di-za",
    "asombradizo": "a-som-bra-di-zo",
    "asombrador": "a-som-bra-dor",
    "asombradora": "a-som-bra-do-ra",
    "asombramiento": "a-som-bra-mien-to",
    "asombrar": "a-som-brar",
    "asombro": "a-som-bro",
    "asombrosa": "a-som-bro-sa",
    "asombrosamente": "a-som-bro-sa-men-te",
    "asombroso": "a-som-bro-so",
    "asomo": "a-so-mo",
    "asonada": "a-so-na-da",
    "asonadía": "a-so-na-dí-a",
    "asonancia": "a-so-nan-cia",
    "asonantar": "a-so-nan-tar",
    "asonante": "a-so-nan-te",
    "asonántico": "a-so-nán-ti-co",
    "asonar": "a-so-nar",
    "asondar": "a-son-dar",
    "asordar": "a-sor-dar",
    "asorochado": "a-so-ro-cha-do",
    "asorochar": "a-so-ro-char",
    "asorocharse": "a-so-ro-char-se",
    "asosegadamente": "a-so-se-ga-da-men-te",
    "asosegar": "a-so-se-gar",
    "asosiego": "a-so-sie-go",
    "asotanar": "a-so-ta-nar",
    "asotilar": "a-so-ti-lar",
    "aspa": "as-pa",
    "aspada": "as-pa-da",
    "aspadera": "as-pa-de-ra",
    "aspado": "as-pa-do",
    "aspador": "as-pa-dor",
    "aspadora": "as-pa-do-ra",
    "aspálato": "as-pá-la-to",
    "aspalto": "as-pal-to",
    "aspar": "as-par",
    "aspaventar": "as-pa-ven-tar",
    "aspaventera": "as-pa-ven-te-ra",
    "aspaventero": "as-pa-ven-te-ro",
    "aspaventoso": "as-pa-ven-to-so",
    "aspaviento": "as-pa-vien-to",
    "aspear": "as-pe-ar",
    "aspearse": "as-pe-ar-se",
    "aspecto": "as-pec-to",
    "aspectual": "as-pec-tual",
    "áspera": "ás-pe-ra",
    "ásperamente": "ás-pe-ra-men-te",
    "asperarteria": "as-pe-rar-te-ria",
    "asperear": "as-pe-re-ar",
    "asperete": "as-pe-re-te",
    "aspereza": "as-pe-re-za",
    "aspergear": "as-per-ge-ar",
    "asperger": "as-per-ger",
    "asperges": "as-per-ges",
    "aspergilosis": "as-per-gi-lo-sis",
    "asperidad": "as-pe-ri-dad",
    "asperiega": "as-pe-rie-ga",
    "asperiego": "as-pe-rie-go",
    "asperilla": "as-pe-ri-lla",
    "asperillo": "as-pe-ri-llo",
    "asperjar": "as-per-jar",
    "áspero": "ás-pe-ro",
    "asperón": "as-pe-rón",
    "aspérrima": "as-pé-rri-ma",
    "aspérrimo": "as-pé-rri-mo",
    "aspersión": "as-per-sión",
    "aspersor": "as-per-sor",
    "aspersorio": "as-per-so-rio",
    "aspérula": "as-pé-ru-la",
    "asperura": "as-pe-ru-ra",
    "áspic": "ás-pic",
    "áspid": "ás-pid",
    "áspide": "ás-pi-de",
    "aspidistra": "as-pi-dis-tra",
    "aspilla": "as-pi-lla",
    "aspillador": "as-pi-lla-dor",
    "aspillar": "as-pi-llar",
    "aspillera": "as-pi-lle-ra",
    "aspillerar": "as-pi-lle-rar",
    "aspiración": "as-pi-ra-ción",
    "aspirada": "as-pi-ra-da",
    "aspirado": "as-pi-ra-do",
    "aspirador": "as-pi-ra-dor",
    "aspiradora": "as-pi-ra-do-ra",
    "aspirante": "as-pi-ran-te",
    "aspirar": "as-pi-rar",
    "aspirina": "as-pi-ri-na",
    "aspro": "as-pro",
    "asqueado": "as-que-a-do",
    "asqueamiento": "as-que-a-mien-to",
    "asquear": "as-que-ar",
    "asquenazí": "as-que-na-zí",
    "asquerosa": "as-que-ro-sa",
    "asquerosamente": "as-que-ro-sa-men-te",
    "asquerosidad": "as-que-ro-si-dad",
    "asqueroso": "as-que-ro-so",
    "asquiento": "as-quien-to",
    "asta": "as-ta",
    "astabandera": "as-ta-ban-de-ra",
    "astabatán": "as-ta-ba-tán",
    "astada": "as-ta-da",
    "astado": "as-ta-do",
    "astamenta": "as-ta-men-ta",
    "astática": "as-tá-ti-ca",
    "astático": "as-tá-ti-co",
    "ástato": "ás-ta-to",
    "asteísmo": "as-te-ís-mo",
    "astenia": "as-te-nia",
    "asténica": "as-té-ni-ca",
    "asténico": "as-té-ni-co",
    "astenosfera": "as-te-nos-fe-ra",
    "astenospermia": "as-te-nos-per-mia",
    "aster": "as-ter",
    "asterisco": "as-te-ris-co",
    "asterismo": "as-te-ris-mo",
    "astero": "as-te-ro",
    "asteroide": "as-te-roi-de",
    "asteroideo": "as-te-roi-de-o",
    "astifino": "as-ti-fi-no",
    "astigitana": "as-ti-gi-ta-na",
    "astigitano": "as-ti-gi-ta-no",
    "astigmática": "as-tig-má-ti-ca",
    "astigmático": "as-tig-má-ti-co",
    "astigmatismo": "as-tig-ma-tis-mo",
    "astigmómetro": "as-tig-mó-me-tro",
    "astil": "as-til",
    "astilla": "as-ti-lla",
    "astillable": "as-ti-lla-ble",
    "astillar": "as-ti-llar",
    "astillazo": "as-ti-lla-zo",
    "astillero": "as-ti-lle-ro",
    "astillosa": "as-ti-llo-sa",
    "astilloso": "as-ti-llo-so",
    "astorgana": "as-tor-ga-na",
    "astorgano": "as-tor-ga-no",
    "astracán": "as-tra-cán",
    "astracanada": "as-tra-ca-na-da",
    "astrágalo": "as-trá-ga-lo",
    "astrago": "as-tra-go",
    "astral": "as-tral",
    "astreñir": "as-tre-ñir",
    "astricción": "as-tric-ción",
    "astrictiva": "as-tric-ti-va",
    "astrictivo": "as-tric-ti-vo",
    "astricto": "as-tric-to",
    "astrífera": "as-trí-fe-ra",
    "astrífero": "as-trí-fe-ro",
    "astringencia": "as-trin-gen-cia",
    "astringente": "as-trin-gen-te",
    "astringir": "as-trin-gir",
    "astriñir": "as-tri-ñir",
    "astro": "as-tro",
    "astrobiología": "as-tro-bio-lo-gí-a",
    "astrocito": "as-tro-ci-to",
    "astrodinámica": "as-tro-di-ná-mi-ca",
    "astrofísica": "as-tro-fí-si-ca",
    "astrofísico": "as-tro-fí-si-co",
    "astrografía": "as-tro-gra-fí-a",
    "astrográfica": "as-tro-grá-fi-ca",
    "astrográfico": "as-tro-grá-fi-co",
    "astrógrafo": "as-tró-gra-fo",
    "astrolabio": "as-tro-la-bio",
    "astrolito": "as-tro-li-to",
    "astróloga": "as-tró-lo-ga",
    "astrologal": "as-tro-lo-gal",
    "astrologar": "as-tro-lo-gar",
    "astrología": "as-tro-lo-gí-a",
    "astrológica": "as-tro-ló-gi-ca",
    "astrológico": "as-tro-ló-gi-co",
    "astrólogo": "as-tró-lo-go",
    "astromelia": "as-tro-me-lia",
    "astronauta": "as-tro-nau-ta",
    "astronáutica": "as-tro-náu-ti-ca",
    "astronáutico": "as-tro-náu-ti-co",
    "astronave": "as-tro-na-ve",
    "astrónoma": "as-tró-no-ma",
    "astronomía": "as-tro-no-mí-a",
    "astronómica": "as-tro-nó-mi-ca",
    "astronómicamente": "as-tro-nó-mi-ca-men-te",
    "astronómico": "as-tro-nó-mi-co",
    "astrónomo": "as-tró-no-mo",
    "astrosa": "as-tro-sa",
    "astroso": "as-tro-so",
    "astucia": "as-tu-cia",
    "astuciosa": "as-tu-cio-sa",
    "astucioso": "as-tu-cio-so",
    "astur": "as-tur",
    "asturcón": "as-tur-cón",
    "asturcona": "as-tur-co-na",
    "asturiana": "as-tu-ria-na",
    "asturianismo": "as-tu-ria-nis-mo",
    "asturiano": "as-tu-ria-no",
    "asturias": "as-tu-rias",
    "asturicense": "as-tu-ri-cen-se",
    "asturiense": "as-tu-rien-se",
    "asturión": "as-tu-rión",
    "asturleonés": "as-tur-le-o-nés",
    "astuta": "as-tu-ta",
    "astutamente": "as-tu-ta-men-te",
    "astuto": "as-tu-to",
    "asuardada": "a-suar-da-da",
    "asuardado": "a-suar-da-do",
    "asubiadero": "a-su-bia-de-ro",
    "asubiar": "a-su-biar",
    "asueta": "a-sue-ta",
    "asueto": "a-sue-to",
    "asulcar": "a-sul-car",
    "asumible": "a-su-mi-ble",
    "asumir": "a-su-mir",
    "asuncena": "a-sun-ce-na",
    "asunceña": "a-sun-ce-ña",
    "asunceno": "a-sun-ce-no",
    "asunceño": "a-sun-ce-ño",
    "asunción": "a-sun-ción",
    "asuncionista": "a-sun-cio-nis-ta",
    "asuntar": "a-sun-tar",
    "asuntejo": "a-sun-te-jo",
    "asunteque": "a-sun-te-que",
    "asuntillo": "a-sun-ti-llo",
    "asuntina": "a-sun-ti-na",
    "asuntino": "a-sun-ti-no",
    "asunto": "a-sun-to",
    "asurar": "a-su-rar",
    "asurcada": "a-sur-ca-da",
    "asurcado": "a-sur-ca-do",
    "asurcana": "a-sur-ca-na",
    "asurcano": "a-sur-ca-no",
    "asurcar": "a-sur-car",
    "asuso": "a-su-so",
    "asustadiza": "a-sus-ta-di-za",
    "asustadizo": "a-sus-ta-di-zo",
    "asustar": "a-sus-tar",
    "asutilar": "a-su-ti-lar",
    "ata": "a-ta",
    "atabaca": "a-ta-ba-ca",
    "atabacada": "a-ta-ba-ca-da",
    "atabacado": "a-ta-ba-ca-do",
    "atabal": "a-ta-bal",
    "atabalear": "a-ta-ba-le-ar",
    "atabalera": "a-ta-ba-le-ra",
    "atabalero": "a-ta-ba-le-ro",
    "atabanada": "a-ta-ba-na-da",
    "atabanado": "a-ta-ba-na-do",
    "atabardillada": "a-ta-bar-di-lla-da",
    "atabardillado": "a-ta-bar-di-lla-do",
    "atabe": "a-ta-be",
    "atabernado": "a-ta-ber-na-do",
    "atabillar": "a-ta-bi-llar",
    "atabladera": "a-ta-bla-de-ra",
    "atablar": "a-ta-blar",
    "atacable": "a-ta-ca-ble",
    "atacada": "a-ta-ca-da",
    "atacadera": "a-ta-ca-de-ra",
    "atacado": "a-ta-ca-do",
    "atacador": "a-ta-ca-dor",
    "atacadora": "a-ta-ca-do-ra",
    "atacadura": "a-ta-ca-du-ra",
    "atacama": "a-ta-ca-ma",
    "atacameña": "a-ta-ca-me-ña",
    "atacameño": "a-ta-ca-me-ño",
    "atacamiento": "a-ta-ca-mien-to",
    "atacamita": "a-ta-ca-mi-ta",
    "atacante": "a-ta-can-te",
    "atacar": "a-ta-car",
    "atachonada": "a-ta-cho-na-da",
    "atachonado": "a-ta-cho-na-do",
    "atacir": "a-ta-cir",
    "atacola": "a-ta-co-la",
    "atada": "a-ta-da",
    "ataderas": "a-ta-de-ras",
    "atadero": "a-ta-de-ro",
    "atadijo": "a-ta-di-jo",
    "atado": "a-ta-do",
    "atador": "a-ta-dor",
    "atadora": "a-ta-do-ra",
    "atadura": "a-ta-du-ra",
    "atafagar": "a-ta-fa-gar",
    "atafago": "a-ta-fa-go",
    "atafarra": "a-ta-fa-rra",
    "atafea": "a-ta-fe-a",
    "atafetanada": "a-ta-fe-ta-na-da",
    "atafetanado": "a-ta-fe-ta-na-do",
    "atagallar": "a-ta-ga-llar",
    "ataguía": "a-ta-guí-a",
    "ataharre": "a-ta-ha-rre",
    "atahona": "a-ta-ho-na",
    "atahonero": "a-ta-ho-ne-ro",
    "atahorma": "a-ta-hor-ma",
    "atahúlla": "a-ta-hú-lla",
    "ataifor": "a-tai-for",
    "atairar": "a-tai-rar",
    "ataire": "a-tai-re",
    "atajada": "a-ta-ja-da",
    "atajadamente": "a-ta-ja-da-men-te",
    "atajadero": "a-ta-ja-de-ro",
    "atajadizo": "a-ta-ja-di-zo",
    "atajador": "a-ta-ja-dor",
    "atajadora": "a-ta-ja-do-ra",
    "atajamiento": "a-ta-ja-mien-to",
    "atajar": "a-ta-jar",
    "atajasolaces": "a-ta-ja-so-la-ces",
    "atajea": "a-ta-je-a",
    "atajía": "a-ta-jí-a",
    "atajo": "a-ta-jo",
    "atal": "a-tal",
    "atalador": "a-ta-la-dor",
    "ataladora": "a-ta-la-do-ra",
    "atalajar": "a-ta-la-jar",
    "atalaje": "a-ta-la-je",
    "atalantar": "a-ta-lan-tar",
    "atalar": "a-ta-lar",
    "atalaya": "a-ta-la-ya",
    "atalayador": "a-ta-la-ya-dor",
    "atalayadora": "a-ta-la-ya-do-ra",
    "atalayamiento": "a-ta-la-ya-mien-to",
    "atalayar": "a-ta-la-yar",
    "atalayero": "a-ta-la-ye-ro",
    "ataludar": "a-ta-lu-dar",
    "ataluzar": "a-ta-lu-zar",
    "atalvina": "a-tal-vi-na",
    "atamán": "a-ta-mán",
    "atambor": "a-tam-bor",
    "atamiento": "a-ta-mien-to",
    "atán": "a-tán",
    "atanasia": "a-ta-na-sia",
    "atancar": "a-tan-car",
    "atanco": "a-tan-co",
    "atandador": "a-tan-da-dor",
    "atañedera": "a-ta-ñe-de-ra",
    "atañedero": "a-ta-ñe-de-ro",
    "atañer": "a-ta-ñer",
    "atangayar": "a-tan-ga-yar",
    "atanor": "a-ta-nor",
    "atanquía": "a-tan-quí-a",
    "atapar": "a-ta-par",
    "atapierna": "a-ta-pier-na",
    "atapuzar": "a-ta-pu-zar",
    "ataque": "a-ta-que",
    "ataquienta": "a-ta-quien-ta",
    "ataquiento": "a-ta-quien-to",
    "ataquiza": "a-ta-qui-za",
    "ataquizar": "a-ta-qui-zar",
    "atar": "a-tar",
    "ataracea": "a-ta-ra-ce-a",
    "ataracear": "a-ta-ra-ce-ar",
    "atarailado": "a-ta-rai-la-do",
    "atarantada": "a-ta-ran-ta-da",
    "atarantado": "a-ta-ran-ta-do",
    "atarantamiento": "a-ta-ran-ta-mien-to",
    "atarantar": "a-ta-ran-tar",
    "ataraxia": "a-ta-ra-xia",
    "ataráxico": "a-ta-rá-xi-co",
    "atarazana": "a-ta-ra-za-na",
    "atarazar": "a-ta-ra-zar",
    "atarbán": "a-tar-bán",
    "atarbana": "a-tar-ba-na",
    "atardecer": "a-tar-de-cer",
    "atardecida": "a-tar-de-ci-da",
    "atarea": "a-ta-re-a",
    "atareado": "a-ta-re-a-do",
    "atarear": "a-ta-re-ar",
    "atarfe": "a-tar-fe",
    "atarjea": "a-tar-je-a",
    "atarquinar": "a-tar-qui-nar",
    "atarraga": "a-ta-rra-ga",
    "atarragar": "a-ta-rra-gar",
    "atarrajar": "a-ta-rra-jar",
    "atarraya": "a-ta-rra-ya",
    "atarrillar": "a-ta-rri-llar",
    "atarugamiento": "a-ta-ru-ga-mien-to",
    "atarugar": "a-ta-ru-gar",
    "atasajada": "a-ta-sa-ja-da",
    "atasajado": "a-ta-sa-ja-do",
    "atasajar": "a-ta-sa-jar",
    "atascaburras": "a-tas-ca-bu-rras",
    "atascada": "a-tas-ca-da",
    "atascadero": "a-tas-ca-de-ro",
    "atascado": "a-tas-ca-do",
    "atascamiento": "a-tas-ca-mien-to",
    "atascar": "a-tas-car",
    "atasco": "a-tas-co",
    "atasquería": "a-tas-que-rí-a",
    "atatay": "a-ta-tay",
    "ataucar": "a-tau-car",
    "ataúd": "a-ta-úd",
    "ataudada": "a-tau-da-da",
    "ataudado": "a-tau-da-do",
    "ataujía": "a-tau-jí-a",
    "ataujiada": "a-tau-jia-da",
    "ataujiado": "a-tau-jia-do",
    "ataurique": "a-tau-ri-que",
    "ataviar": "a-ta-viar",
    "atávica": "a-tá-vi-ca",
    "atávico": "a-tá-vi-co",
    "atavío": "a-ta-ví-o",
    "atavismo": "a-ta-vis-mo",
    "ataxia": "a-ta-xia",
    "atáxica": "a-tá-xi-ca",
    "atáxico": "a-tá-xi-co",
    "ate": "a-te",
    "atea": "a-te-a",
    "atear": "a-te-ar",
    "atediar": "a-te-diar",
    "ateísmo": "a-te-ís-mo",
    "ateísta": "a-te-ís-ta",
    "ateje": "a-te-je",
    "atelaje": "a-te-la-je",
    "atelana": "a-te-la-na",
    "atelectasia": "a-te-lec-ta-sia",
    "atembada": "a-tem-ba-da",
    "atembado": "a-tem-ba-do",
    "atembar": "a-tem-bar",
    "atemorizador": "a-te-mo-ri-za-dor",
    "atemorizar": "a-te-mo-ri-zar",
    "atemperación": "a-tem-pe-ra-ción",
    "atemperador": "a-tem-pe-ra-dor",
    "atemperante": "a-tem-pe-ran-te",
    "atemperar": "a-tem-pe-rar",
    "atempero": "a-tem-pe-ro",
    "atemporal": "a-tem-po-ral",
    "atemporalidad": "a-tem-po-ra-li-dad",
    "atemporalmente": "a-tem-po-ral-men-te",
    "atenacear": "a-te-na-ce-ar",
    "atenazada": "a-te-na-za-da",
    "atenazado": "a-te-na-za-do",
    "atenazador": "a-te-na-za-dor",
    "atenazar": "a-te-na-zar",
    "atención": "a-ten-ción",
    "atencioso": "a-ten-cio-so",
    "atendar": "a-ten-dar",
    "atendedor": "a-ten-de-dor",
    "atendedora": "a-ten-de-do-ra",
    "atendencia": "a-ten-den-cia",
    "atender": "a-ten-der",
    "atendible": "a-ten-di-ble",
    "atendimiento": "a-ten-di-mien-to",
    "atenea": "a-te-ne-a",
    "atenebrar": "a-te-ne-brar",
    "atenebrarse": "a-te-ne-brar-se",
    "atenedor": "a-te-ne-dor",
    "ateneísta": "a-te-ne-ís-ta",
    "atenencia": "a-te-nen-cia",
    "ateneo": "a-te-ne-o",
    "atener": "a-te-ner",
    "atenido": "a-te-ni-do",
    "ateniense": "a-te-nien-se",
    "ateniés": "a-te-niés",
    "ateniesa": "a-te-nie-sa",
    "atenorada": "a-te-no-ra-da",
    "atenorado": "a-te-no-ra-do",
    "atenta": "a-ten-ta",
    "atentación": "a-ten-ta-ción",
    "atentada": "a-ten-ta-da",
    "atentadamente": "a-ten-ta-da-men-te",
    "atentado": "a-ten-ta-do",
    "atentamente": "a-ten-ta-men-te",
    "atentar": "a-ten-tar",
    "atentatoria": "a-ten-ta-to-ria",
    "atentatorio": "a-ten-ta-to-rio",
    "atento": "a-ten-to",
    "atenuación": "a-te-nua-ción",
    "atenuador": "a-te-nua-dor",
    "atenuante": "a-te-nuan-te",
    "atenuar": "a-te-nuar",
    "ateo": "a-te-o",
    "ateperetado": "a-te-pe-re-ta-do",
    "atepocate": "a-te-po-ca-te",
    "atercianada": "a-ter-cia-na-da",
    "atercianado": "a-ter-cia-na-do",
    "aterciopelada": "a-ter-cio-pe-la-da",
    "aterciopelado": "a-ter-cio-pe-la-do",
    "aterecer": "a-te-re-cer",
    "aterecimiento": "a-te-re-ci-mien-to",
    "atericia": "a-te-ri-cia",
    "atericiar": "a-te-ri-ciar",
    "atericiarse": "a-te-ri-ciar-se",
    "aterido": "a-te-ri-do",
    "aterimiento": "a-te-ri-mien-to",
    "aterir": "a-te-rir",
    "atérmana": "a-tér-ma-na",
    "atérmano": "a-tér-ma-no",
    "ateroesclerosis": "a-te-ro-es-cle-ro-sis",
    "ateroma": "a-te-ro-ma",
    "ateromatoso": "a-te-ro-ma-to-so",
    "aterosclerosis": "a-te-ros-cle-ro-sis",
    "aterosclerótico": "a-te-ros-cle-ró-ti-co",
    "aterrada": "a-te-rra-da",
    "aterrador": "a-te-rra-dor",
    "aterradora": "a-te-rra-do-ra",
    "aterrajar": "a-te-rra-jar",
    "aterraje": "a-te-rra-je",
    "aterramiento": "a-te-rra-mien-to",
    "aterrar": "a-te-rrar",
    "aterrerar": "a-te-rre-rar",
    "aterrizador": "a-te-rri-za-dor",
    "aterrizaje": "a-te-rri-za-je",
    "aterrizar": "a-te-rri-zar",
    "aterro": "a-te-rro",
    "aterronar": "a-te-rro-nar",
    "aterrorizar": "a-te-rro-ri-zar",
    "atesar": "a-te-sar",
    "atesoramiento": "a-te-so-ra-mien-to",
    "atesorar": "a-te-so-rar",
    "atestación": "a-tes-ta-ción",
    "atestada": "a-tes-ta-da",
    "atestado": "a-tes-ta-do",
    "atestadura": "a-tes-ta-du-ra",
    "atestamiento": "a-tes-ta-mien-to",
    "atestar": "a-tes-tar",
    "atestiguación": "a-tes-ti-gua-ción",
    "atestiguamiento": "a-tes-ti-gua-mien-to",
    "atestiguar": "a-tes-ti-guar",
    "atetada": "a-te-ta-da",
    "atetado": "a-te-ta-do",
    "atetar": "a-te-tar",
    "atetillar": "a-te-ti-llar",
    "atetosis": "a-te-to-sis",
    "atezada": "a-te-za-da",
    "atezado": "a-te-za-do",
    "atezamiento": "a-te-za-mien-to",
    "atezar": "a-te-zar",
    "atibar": "a-ti-bar",
    "atibiar": "a-ti-biar",
    "atiborramiento": "a-ti-bo-rra-mien-to",
    "atiborrar": "a-ti-bo-rrar",
    "ática": "á-ti-ca",
    "aticismo": "a-ti-cis-mo",
    "aticista": "a-ti-cis-ta",
    "ático": "á-ti-co",
    "atiemposo": "a-tiem-po-so",
    "atierre": "a-tie-rre",
    "atiesar": "a-tie-sar",
    "atifle": "a-ti-fle",
    "atigrada": "a-ti-gra-da",
    "atigrado": "a-ti-gra-do",
    "atijara": "a-ti-ja-ra",
    "atijarero": "a-ti-ja-re-ro",
    "atila": "a-ti-la",
    "atildada": "a-til-da-da",
    "atildado": "a-til-da-do",
    "atildadura": "a-til-da-du-ra",
    "atildamiento": "a-til-da-mien-to",
    "atildar": "a-til-dar",
    "atilintar": "a-ti-lin-tar",
    "atinar": "a-ti-nar",
    "atinca": "a-tin-ca",
    "atíncar": "a-tín-car",
    "atinconar": "a-tin-co-nar",
    "atinencia": "a-ti-nen-cia",
    "atinente": "a-ti-nen-te",
    "atingencia": "a-tin-gen-cia",
    "atingente": "a-tin-gen-te",
    "atingido": "a-tin-gi-do",
    "atingir": "a-tin-gir",
    "atino": "a-ti-no",
    "atipar": "a-ti-par",
    "atipicidad": "a-ti-pi-ci-dad",
    "atípico": "a-tí-pi-co",
    "atiplada": "a-ti-pla-da",
    "atiplado": "a-ti-pla-do",
    "atiplar": "a-ti-plar",
    "atipujar": "a-ti-pu-jar",
    "atirantar": "a-ti-ran-tar",
    "atirelada": "a-ti-re-la-da",
    "atirelado": "a-ti-re-la-do",
    "atiriciar": "a-ti-ri-ciar",
    "atiriciarse": "a-ti-ri-ciar-se",
    "atisbador": "a-tis-ba-dor",
    "atisbadora": "a-tis-ba-do-ra",
    "atisbadura": "a-tis-ba-du-ra",
    "atisbar": "a-tis-bar",
    "atisbo": "a-tis-bo",
    "atisbón": "a-tis-bón",
    "atisbona": "a-tis-bo-na",
    "atisuada": "a-ti-sua-da",
    "atisuado": "a-ti-sua-do",
    "atizacandiles": "a-ti-za-can-di-les",
    "atizadero": "a-ti-za-de-ro",
    "atizador": "a-ti-za-dor",
    "atizadora": "a-ti-za-do-ra",
    "atizar": "a-ti-zar",
    "atizonar": "a-ti-zo-nar",
    "atlante": "a-tlan-te",
    "atlántica": "a-tlán-ti-ca",
    "atlanticense": "a-tlan-ti-cen-se",
    "atlántico": "a-tlán-ti-co",
    "atlantideño": "a-tlan-ti-de-ño",
    "atlantidense": "a-tlan-ti-den-se",
    "atlantiquense": "a-tlan-ti-quen-se",
    "atlantismo": "a-tlan-tis-mo",
    "atlantista": "a-tlan-tis-ta",
    "atlas": "a-tlas",
    "atleta": "a-tle-ta",
    "atlética": "a-tlé-ti-ca",
    "atléticamente": "a-tlé-ti-ca-men-te",
    "atlético": "a-tlé-ti-co",
    "atletismo": "a-tle-tis-mo",
    "atmosfera": "at-mos-fe-ra",
    "atmósfera": "at-mós-fe-ra",
    "atmosférica": "at-mos-fé-ri-ca",
    "atmosférico": "at-mos-fé-ri-co",
    "atoar": "a-to-ar",
    "atoba": "a-to-ba",
    "atobar": "a-to-bar",
    "atocha": "a-to-cha",
    "atochada": "a-to-cha-da",
    "atochado": "a-to-cha-do",
    "atochal": "a-to-chal",
    "atochar": "a-to-char",
    "atochera": "a-to-che-ra",
    "atochero": "a-to-che-ro",
    "atochón": "a-to-chón",
    "atocinada": "a-to-ci-na-da",
    "atocinado": "a-to-ci-na-do",
    "atocinar": "a-to-ci-nar",
    "atojar": "a-to-jar",
    "atol": "a-tol",
    "atolada": "a-to-la-da",
    "atole": "a-to-le",
    "atoleada": "a-to-le-a-da",
    "atolera": "a-to-le-ra",
    "atolería": "a-to-le-rí-a",
    "atolero": "a-to-le-ro",
    "atolillo": "a-to-li-llo",
    "atolladal": "a-to-lla-dal",
    "atolladar": "a-to-lla-dar",
    "atolladero": "a-to-lla-de-ro",
    "atollar": "a-to-llar",
    "atolón": "a-to-lón",
    "atolondrada": "a-to-lon-dra-da",
    "atolondradamente": "a-to-lon-dra-da-men-te",
    "atolondrado": "a-to-lon-dra-do",
    "atolondramiento": "a-to-lon-dra-mien-to",
    "atolondrar": "a-to-lon-drar",
    "atómica": "a-tó-mi-ca",
    "atómico": "a-tó-mi-co",
    "atomir": "a-to-mir",
    "atomismo": "a-to-mis-mo",
    "atomista": "a-to-mis-ta",
    "atomística": "a-to-mís-ti-ca",
    "atomístico": "a-to-mís-ti-co",
    "atomización": "a-to-mi-za-ción",
    "atomizador": "a-to-mi-za-dor",
    "atomizar": "a-to-mi-zar",
    "átomo": "á-to-mo",
    "atona": "a-to-na",
    "átona": "á-to-na",
    "atonal": "a-to-nal",
    "atonalidad": "a-to-na-li-dad",
    "atonalismo": "a-to-na-lis-mo",
    "atonar": "a-to-nar",
    "atondar": "a-ton-dar",
    "atonía": "a-to-ní-a",
    "atónica": "a-tó-ni-ca",
    "atónico": "a-tó-ni-co",
    "atónita": "a-tó-ni-ta",
    "atónitamente": "a-tó-ni-ta-men-te",
    "atónito": "a-tó-ni-to",
    "átono": "á-to-no",
    "atontado": "a-ton-ta-do",
    "atontamiento": "a-ton-ta-mien-to",
    "atontar": "a-ton-tar",
    "atontecer": "a-ton-te-cer",
    "atontolinar": "a-ton-to-li-nar",
    "atopadiza": "a-to-pa-di-za",
    "atopadizo": "a-to-pa-di-zo",
    "atópico": "a-tó-pi-co",
    "atora": "a-to-ra",
    "atoramiento": "a-to-ra-mien-to",
    "atorar": "a-to-rar",
    "atorcer": "a-tor-cer",
    "atordecer": "a-tor-de-cer",
    "atorgar": "a-tor-gar",
    "atormentador": "a-tor-men-ta-dor",
    "atormentadora": "a-tor-men-ta-do-ra",
    "atormentar": "a-tor-men-tar",
    "atornasolado": "a-tor-na-so-la-do",
    "atornillador": "a-tor-ni-lla-dor",
    "atornillar": "a-tor-ni-llar",
    "atoro": "a-to-ro",
    "atorón": "a-to-rón",
    "atorozonar": "a-to-ro-zo-nar",
    "atorozonarse": "a-to-ro-zo-nar-se",
    "atorra": "a-to-rra",
    "atorranta": "a-to-rran-ta",
    "atorrante": "a-to-rran-te",
    "atorrar": "a-to-rrar",
    "atortolar": "a-tor-to-lar",
    "atortorar": "a-tor-to-rar",
    "atortujar": "a-tor-tu-jar",
    "atosigador": "a-to-si-ga-dor",
    "atosigadora": "a-to-si-ga-do-ra",
    "atosigamiento": "a-to-si-ga-mien-to",
    "atosigar": "a-to-si-gar",
    "atoxicar": "a-to-xi-car",
    "atóxico": "a-tó-xi-co",
    "atrabajada": "a-tra-ba-ja-da",
    "atrabajado": "a-tra-ba-ja-do",
    "atrabajar": "a-tra-ba-jar",
    "atrabancar": "a-tra-ban-car",
    "atrabanco": "a-tra-ban-co",
    "atrabiliaria": "a-tra-bi-lia-ria",
    "atrabiliariamente": "a-tra-bi-lia-ria-men-te",
    "atrabiliario": "a-tra-bi-lia-rio",
    "atrabiliosa": "a-tra-bi-lio-sa",
    "atrabilioso": "a-tra-bi-lio-so",
    "atrabilis": "a-tra-bi-lis",
    "atracada": "a-tra-ca-da",
    "atracadero": "a-tra-ca-de-ro",
    "atracador": "a-tra-ca-dor",
    "atracadora": "a-tra-ca-do-ra",
    "atracar": "a-tra-car",
    "atracción": "a-trac-ción",
    "atraco": "a-tra-co",
    "atracón": "a-tra-cón",
    "atractiva": "a-trac-ti-va",
    "atractivamente": "a-trac-ti-va-men-te",
    "atractivo": "a-trac-ti-vo",
    "atractriz": "a-trac-triz",
    "atraer": "a-tra-er",
    "atrafagar": "a-tra-fa-gar",
    "atragantamiento": "a-tra-gan-ta-mien-to",
    "atragantar": "a-tra-gan-tar",
    "atraíble": "a-tra-í-ble",
    "atraicionar": "a-trai-cio-nar",
    "atraidorada": "a-trai-do-ra-da",
    "atraidorado": "a-trai-do-ra-do",
    "atraillar": "a-trai-llar",
    "atraimiento": "a-trai-mien-to",
    "atramento": "a-tra-men-to",
    "atramentosa": "a-tra-men-to-sa",
    "atramentoso": "a-tra-men-to-so",
    "atramojar": "a-tra-mo-jar",
    "atrampar": "a-tram-par",
    "atramuz": "a-tra-muz",
    "atrancar": "a-tran-car",
    "atranco": "a-tran-co",
    "atranque": "a-tran-que",
    "atrapamoscas": "a-tra-pa-mos-cas",
    "atrapar": "a-tra-par",
    "atraque": "a-tra-que",
    "atraquina": "a-tra-qui-na",
    "atrás": "a-trás",
    "atrasada": "a-tra-sa-da",
    "atrasado": "a-tra-sa-do",
    "atrasamiento": "a-tra-sa-mien-to",
    "atrasar": "a-tra-sar",
    "atraso": "a-tra-so",
    "atravesada": "a-tra-ve-sa-da",
    "atravesado": "a-tra-ve-sa-do",
    "atravesador": "a-tra-ve-sa-dor",
    "atravesadora": "a-tra-ve-sa-do-ra",
    "atravesaño": "a-tra-ve-sa-ño",
    "atravesar": "a-tra-ve-sar",
    "atravesía": "a-tra-ve-sí-a",
    "atrayente": "a-tra-yen-te",
    "atrechar": "a-tre-char",
    "atrecho": "a-tre-cho",
    "atregar": "a-tre-gar",
    "atreguada": "a-tre-gua-da",
    "atreguadamente": "a-tre-gua-da-men-te",
    "atreguado": "a-tre-gua-do",
    "atreguar": "a-tre-guar",
    "atrenzo": "a-tren-zo",
    "atrepsia": "a-trep-sia",
    "atresia": "a-tre-sia",
    "atresnalar": "a-tres-na-lar",
    "atrevencia": "a-tre-ven-cia",
    "atrever": "a-tre-ver",
    "atrevida": "a-tre-vi-da",
    "atrevidamente": "a-tre-vi-da-men-te",
    "atrevido": "a-tre-vi-do",
    "atrevimiento": "a-tre-vi-mien-to",
    "atrezo": "a-tre-zo",
    "atríaca": "a-trí-a-ca",
    "atriaca": "a-tria-ca",
    "atrial": "a-trial",
    "atriaquero": "a-tria-que-ro",
    "atribución": "a-tri-bu-ción",
    "atribuible": "a-tri-bui-ble",
    "atribuir": "a-tri-buir",
    "atribulación": "a-tri-bu-la-ción",
    "atribular": "a-tri-bu-lar",
    "atributar": "a-tri-bu-tar",
    "atributiva": "a-tri-bu-ti-va",
    "atributivo": "a-tri-bu-ti-vo",
    "atributo": "a-tri-bu-to",
    "atrición": "a-tri-ción",
    "atrida": "a-tri-da",
    "atril": "a-tril",
    "atrilera": "a-tri-le-ra",
    "atrincar": "a-trin-car",
    "atrincheramiento": "a-trin-che-ra-mien-to",
    "atrincherar": "a-trin-che-rar",
    "atrincuñar": "a-trin-cu-ñar",
    "atrio": "a-trio",
    "atrípeda": "a-trí-pe-da",
    "atrípedo": "a-trí-pe-do",
    "atrirrostra": "a-tri-rros-tra",
    "atrirrostro": "a-tri-rros-tro",
    "atristar": "a-tris-tar",
    "atrita": "a-tri-ta",
    "atrito": "a-tri-to",
    "atrochar": "a-tro-char",
    "atrocidad": "a-tro-ci-dad",
    "atrofia": "a-tro-fia",
    "atrofiar": "a-tro-fiar",
    "atrófica": "a-tró-fi-ca",
    "atrófico": "a-tró-fi-co",
    "atrojar": "a-tro-jar",
    "atrompetada": "a-trom-pe-ta-da",
    "atrompetado": "a-trom-pe-ta-do",
    "atronada": "a-tro-na-da",
    "atronado": "a-tro-na-do",
    "atronador": "a-tro-na-dor",
    "atronadora": "a-tro-na-do-ra",
    "atronadura": "a-tro-na-du-ra",
    "atronamiento": "a-tro-na-mien-to",
    "atronar": "a-tro-nar",
    "atronerar": "a-tro-ne-rar",
    "atropada": "a-tro-pa-da",
    "atropado": "a-tro-pa-do",
    "atropar": "a-tro-par",
    "atropellada": "a-tro-pe-lla-da",
    "atropelladamente": "a-tro-pe-lla-da-men-te",
    "atropellado": "a-tro-pe-lla-do",
    "atropellador": "a-tro-pe-lla-dor",
    "atropelladora": "a-tro-pe-lla-do-ra",
    "atropellamiento": "a-tro-pe-lla-mien-to",
    "atropellaplatos": "a-tro-pe-lla-pla-tos",
    "atropellar": "a-tro-pe-llar",
    "atropello": "a-tro-pe-llo",
    "atropina": "a-tro-pi-na",
    "atroz": "a-troz",
    "atrozmente": "a-troz-men-te",
    "atruchada": "a-tru-cha-da",
    "atruchado": "a-tru-cha-do",
    "atruendo": "a-truen-do",
    "atruhanada": "a-truha-na-da",
    "atruhanado": "a-truha-na-do",
    "atuendo": "a-tuen-do",
    "atufada": "a-tu-fa-da",
    "atufadamente": "a-tu-fa-da-men-te",
    "atufado": "a-tu-fa-do",
    "atufamiento": "a-tu-fa-mien-to",
    "atufar": "a-tu-far",
    "atufo": "a-tu-fo",
    "atumultuar": "a-tu-mul-tuar",
    "atún": "a-tún",
    "atuna": "a-tu-na",
    "atunara": "a-tu-na-ra",
    "atunera": "a-tu-ne-ra",
    "atunero": "a-tu-ne-ro",
    "aturada": "a-tu-ra-da",
    "aturadamente": "a-tu-ra-da-men-te",
    "aturador": "a-tu-ra-dor",
    "aturadora": "a-tu-ra-do-ra",
    "aturar": "a-tu-rar",
    "aturbonada": "a-tur-bo-na-da",
    "aturbonado": "a-tur-bo-na-do",
    "aturdida": "a-tur-di-da",
    "aturdidamente": "a-tur-di-da-men-te",
    "aturdido": "a-tur-di-do",
    "aturdidor": "a-tur-di-dor",
    "aturdidora": "a-tur-di-do-ra",
    "aturdimiento": "a-tur-di-mien-to",
    "aturdir": "a-tur-dir",
    "aturquesada": "a-tur-que-sa-da",
    "aturquesado": "a-tur-que-sa-do",
    "aturrar": "a-tu-rrar",
    "aturriar": "a-tu-rriar",
    "aturrullar": "a-tu-rru-llar",
    "aturullamiento": "a-tu-ru-lla-mien-to",
    "aturullar": "a-tu-ru-llar",
    "atusador": "a-tu-sa-dor",
    "atusadora": "a-tu-sa-do-ra",
    "atusar": "a-tu-sar",
    "atutía": "a-tu-tí-a",
    "auca": "au-ca",
    "aucción": "auc-ción",
    "aucténtica": "auc-tén-ti-ca",
    "aucténtico": "auc-tén-ti-co",
    "auctor": "auc-tor",
    "auctoridad": "auc-to-ri-dad",
    "auctorizar": "auc-to-ri-zar",
    "audacia": "au-da-cia",
    "audaz": "au-daz",
    "audazmente": "au-daz-men-te",
    "audibilidad": "au-di-bi-li-dad",
    "audible": "au-di-ble",
    "audición": "au-di-ción",
    "audiencia": "au-dien-cia",
    "audienciero": "au-dien-cie-ro",
    "audífono": "au-dí-fo-no",
    "audímetro": "au-dí-me-tro",
    "audio": "au-dio",
    "audiocasete": "au-dio-ca-se-te",
    "audiófono": "au-dió-fo-no",
    "audiofrecuencia": "au-dio-fre-cuen-cia",
    "audiograma": "au-dio-gra-ma",
    "audiometría": "au-dio-me-trí-a",
    "audiómetro": "au-dió-me-tro",
    "audioprótesis": "au-dio-pró-te-sis",
    "audioprotesista": "au-dio-pro-te-sis-ta",
    "audiotex": "au-dio-tex",
    "audiovisual": "au-dio-vi-sual",
    "auditar": "au-di-tar",
    "auditiva": "au-di-ti-va",
    "auditivo": "au-di-ti-vo",
    "audito": "au-di-to",
    "auditor": "au-di-tor",
    "auditora": "au-di-to-ra",
    "auditoría": "au-di-to-rí-a",
    "auditorio": "au-di-to-rio",
    "auditórium": "au-di-tó-rium",
    "auge": "au-ge",
    "augita": "au-gi-ta",
    "augmentación": "aug-men-ta-ción",
    "augmentar": "aug-men-tar",
    "augur": "au-gur",
    "auguración": "au-gu-ra-ción",
    "augurador": "au-gu-ra-dor",
    "auguradora": "au-gu-ra-do-ra",
    "augural": "au-gu-ral",
    "augurar": "au-gu-rar",
    "augurio": "au-gu-rio",
    "augusta": "au-gus-ta",
    "augustal": "au-gus-tal",
    "augustamente": "au-gus-ta-men-te",
    "augusto": "au-gus-to",
    "aula": "au-la",
    "aulaga": "au-la-ga",
    "aulagar": "au-la-gar",
    "aulario": "au-la-rio",
    "áulica": "áu-li-ca",
    "áulico": "áu-li-co",
    "aulladero": "au-lla-de-ro",
    "aullador": "au-lla-dor",
    "aulladora": "au-lla-do-ra",
    "aullante": "au-llan-te",
    "aullar": "au-llar",
    "aullido": "au-lli-do",
    "aúllo": "a-ú-llo",
    "aulos": "au-los",
    "aumentable": "au-men-ta-ble",
    "aumentación": "au-men-ta-ción",
    "aumentada": "au-men-ta-da",
    "aumentado": "au-men-ta-do",
    "aumentador": "au-men-ta-dor",
    "aumentadora": "au-men-ta-do-ra",
    "aumentar": "au-men-tar",
    "aumentativa": "au-men-ta-ti-va",
    "aumentativo": "au-men-ta-ti-vo",
    "aumento": "au-men-to",
    "aún": "a-ún",
    "aunable": "au-na-ble",
    "aunamiento": "au-na-mien-to",
    "aunar": "au-nar",
    "auniga": "au-ni-ga",
    "aunque": "aun-que",
    "aúpa": "a-ú-pa",
    "aupar": "au-par",
    "auquénido": "au-qué-ni-do",
    "aura": "au-ra",
    "auranciácea": "au-ran-ciá-ce-a",
    "auranciáceo": "au-ran-ciá-ce-o",
    "áurea": "áu-re-a",
    "aurelianense": "au-re-lia-nen-se",
    "áureo": "áu-re-o",
    "aureola": "au-re-o-la",
    "aureolar": "au-re-o-lar",
    "aureomicina": "au-re-o-mi-ci-na",
    "aurero": "au-re-ro",
    "aurgitana": "aur-gi-ta-na",
    "aurgitano": "aur-gi-ta-no",
    "áurica": "áu-ri-ca",
    "auricalco": "au-ri-cal-co",
    "áurico": "áu-ri-co",
    "aurícula": "au-rí-cu-la",
    "auriculada": "au-ri-cu-la-da",
    "auriculado": "au-ri-cu-la-do",
    "auricular": "au-ri-cu-lar",
    "auriense": "au-rien-se",
    "aurífera": "au-rí-fe-ra",
    "aurífero": "au-rí-fe-ro",
    "auriga": "au-ri-ga",
    "aurígero": "au-rí-ge-ro",
    "auriñaciense": "au-ri-ña-cien-se",
    "aurívora": "au-rí-vo-ra",
    "aurívoro": "au-rí-vo-ro",
    "aurora": "au-ro-ra",
    "auroral": "au-ro-ral",
    "aurragada": "au-rra-ga-da",
    "aurragado": "au-rra-ga-do",
    "aurresku": "au-rres-ku",
    "aurúspice": "au-rús-pi-ce",
    "auscultación": "aus-cul-ta-ción",
    "auscultar": "aus-cul-tar",
    "ausencia": "au-sen-cia",
    "ausentada": "au-sen-ta-da",
    "ausentado": "au-sen-ta-do",
    "ausentar": "au-sen-tar",
    "ausente": "au-sen-te",
    "ausentismo": "au-sen-tis-mo",
    "ausetana": "au-se-ta-na",
    "ausetano": "au-se-ta-no",
    "ausol": "au-sol",
    "ausonense": "au-so-nen-se",
    "ausonia": "au-so-nia",
    "ausonio": "au-so-nio",
    "auspiciador": "aus-pi-cia-dor",
    "auspiciar": "aus-pi-ciar",
    "auspicio": "aus-pi-cio",
    "auspicioso": "aus-pi-cio-so",
    "austera": "aus-te-ra",
    "austeramente": "aus-te-ra-men-te",
    "austeridad": "aus-te-ri-dad",
    "austero": "aus-te-ro",
    "austral": "aus-tral",
    "australiana": "aus-tra-lia-na",
    "australiano": "aus-tra-lia-no",
    "australopiteco": "aus-tra-lo-pi-te-co",
    "austríaca": "aus-trí-a-ca",
    "austriaca": "aus-tria-ca",
    "austriaco": "aus-tria-co",
    "austrida": "aus-tri-da",
    "austrina": "aus-tri-na",
    "austrino": "aus-tri-no",
    "austro": "aus-tro",
    "austrohúngara": "aus-tro-hún-ga-ra",
    "austrohúngaro": "aus-tro-hún-ga-ro",
    "aután": "au-tán",
    "autarcía": "au-tar-cí-a",
    "autarquía": "au-tar-quí-a",
    "autárquica": "au-tár-qui-ca",
    "autárquicamente": "au-tár-qui-ca-men-te",
    "autárquico": "au-tár-qui-co",
    "auténtica": "au-tén-ti-ca",
    "autenticación": "au-ten-ti-ca-ción",
    "auténticamente": "au-tén-ti-ca-men-te",
    "autenticar": "au-ten-ti-car",
    "autenticidad": "au-ten-ti-ci-dad",
    "auténtico": "au-tén-ti-co",
    "autentificar": "au-ten-ti-fi-car",
    "autillo": "au-ti-llo",
    "autismo": "au-tis-mo",
    "autista": "au-tis-ta",
    "autístico": "au-tís-ti-co",
    "auto": "au-to",
    "autoabastecer": "au-to-a-bas-te-cer",
    "autoabastecimiento": "au-to-a-bas-te-ci-mien-to",
    "autoacusación": "au-to-a-cu-sa-ción",
    "autoadhesivo": "au-to-a-dhe-si-vo",
    "autoafirmación": "au-to-a-fir-ma-ción",
    "autoafirmar": "au-to-a-fir-mar",
    "autoagresión": "au-to-a-gre-sión",
    "autoaprendizaje": "au-to-a-pren-di-za-je",
    "autoayuda": "au-to-a-yu-da",
    "autobaño": "au-to-ba-ño",
    "autobiógrafa": "au-to-bió-gra-fa",
    "autobiografía": "au-to-bio-gra-fí-a",
    "autobiográfica": "au-to-bio-grá-fi-ca",
    "autobiográfico": "au-to-bio-grá-fi-co",
    "autobiógrafo": "au-to-bió-gra-fo",
    "autobomba": "au-to-bom-ba",
    "autobombo": "au-to-bom-bo",
    "autobronceador": "au-to-bron-ce-a-dor",
    "autobús": "au-to-bús",
    "autobusera": "au-to-bu-se-ra",
    "autobusero": "au-to-bu-se-ro",
    "autobusete": "au-to-bu-se-te",
    "autocabeza": "au-to-ca-be-za",
    "autocamión": "au-to-ca-mión",
    "autocar": "au-to-car",
    "autocaravana": "au-to-ca-ra-va-na",
    "autocarril": "au-to-ca-rril",
    "autocartera": "au-to-car-te-ra",
    "autocensura": "au-to-cen-su-ra",
    "autocensurar": "au-to-cen-su-rar",
    "autocine": "au-to-ci-ne",
    "autoclave": "au-to-cla-ve",
    "autocompasión": "au-to-com-pa-sión",
    "autocomplacencia": "au-to-com-pla-cen-cia",
    "autocomplaciente": "au-to-com-pla-cien-te",
    "autoconfianza": "au-to-con-fian-za",
    "autoconsciencia": "au-to-cons-cien-cia",
    "autoconsumo": "au-to-con-su-mo",
    "autocontención": "au-to-con-ten-ción",
    "autocontrol": "au-to-con-trol",
    "autocontrolar": "au-to-con-tro-lar",
    "autocopista": "au-to-co-pis-ta",
    "autocracia": "au-to-cra-cia",
    "autócrata": "au-tó-cra-ta",
    "autocrática": "au-to-crá-ti-ca",
    "autocráticamente": "au-to-crá-ti-ca-men-te",
    "autocrático": "au-to-crá-ti-co",
    "autocrítica": "au-to-crí-ti-ca",
    "autocrítico": "au-to-crí-ti-co",
    "autóctona": "au-tóc-to-na",
    "autóctonamente": "au-tóc-to-na-men-te",
    "autoctonía": "au-toc-to-ní-a",
    "autóctono": "au-tóc-to-no",
    "autocuración": "au-to-cu-ra-ción",
    "autodefensa": "au-to-de-fen-sa",
    "autodefinición": "au-to-de-fi-ni-ción",
    "autodefinido": "au-to-de-fi-ni-do",
    "autodefinir": "au-to-de-fi-nir",
    "autodenominar": "au-to-de-no-mi-nar",
    "autodestrucción": "au-to-des-truc-ción",
    "autodestructivo": "au-to-des-truc-ti-vo",
    "autodeterminación": "au-to-de-ter-mi-na-ción",
    "autodidacta": "au-to-di-dac-ta",
    "autodidactismo": "au-to-di-dac-tis-mo",
    "autodidacto": "au-to-di-dac-to",
    "autodirección": "au-to-di-rec-ción",
    "autodirigido": "au-to-di-ri-gi-do",
    "autodisciplina": "au-to-dis-ci-pli-na",
    "autodisolución": "au-to-di-so-lu-ción",
    "autodominio": "au-to-do-mi-nio",
    "autódromo": "au-tó-dro-mo",
    "autoedición": "au-to-e-di-ción",
    "autoeditar": "au-to-e-di-tar",
    "autoempleo": "au-to-em-ple-o",
    "autoencendido": "au-to-en-cen-di-do",
    "autoenfoque": "au-to-en-fo-que",
    "autoescuela": "au-to-es-cue-la",
    "autoestéreo": "au-to-es-té-re-o",
    "autoestima": "au-to-es-ti-ma",
    "autoestop": "au-to-es-top",
    "autoestopista": "au-to-es-to-pis-ta",
    "autoevaluación": "au-to-e-va-lua-ción",
    "autoexcluir": "au-to-ex-cluir",
    "autoexclusión": "au-to-ex-clu-sión",
    "autoexploración": "au-to-ex-plo-ra-ción",
    "autofagia": "au-to-fa-gia",
    "autofecundación": "au-to-fe-cun-da-ción",
    "autoferro": "au-to-fe-rro",
    "autofinanciación": "au-to-fi-nan-cia-ción",
    "autofoco": "au-to-fo-co",
    "autofocus": "au-to-fo-cus",
    "autógena": "au-tó-ge-na",
    "autógeno": "au-tó-ge-no",
    "autogestión": "au-to-ges-tión",
    "autogiro": "au-to-gi-ro",
    "autognosis": "au-tog-no-sis",
    "autogobierno": "au-to-go-bier-no",
    "autogol": "au-to-gol",
    "autogolpe": "au-to-gol-pe",
    "autógrafa": "au-tó-gra-fa",
    "autografía": "au-to-gra-fí-a",
    "autografiar": "au-to-gra-fiar",
    "autográfica": "au-to-grá-fi-ca",
    "autográfico": "au-to-grá-fi-co",
    "autógrafo": "au-tó-gra-fo",
    "autoguiado": "au-to-guia-do",
    "autoinculpación": "au-toin-cul-pa-ción",
    "autoinculpar": "au-toin-cul-par",
    "autoinducción": "au-toin-duc-ción",
    "autoinducido": "au-toin-du-ci-do",
    "autoinducir": "au-toin-du-cir",
    "autoinmolar": "au-toin-mo-lar",
    "autoinmunidad": "au-toin-mu-ni-dad",
    "autointoxicación": "au-toin-to-xi-ca-ción",
    "autoinyectable": "au-toin-yec-ta-ble",
    "autolatría": "au-to-la-trí-a",
    "autolesión": "au-to-le-sión",
    "autolesionar": "au-to-le-sio-nar",
    "autolesivo": "au-to-le-si-vo",
    "autolimitar": "au-to-li-mi-tar",
    "autoliquidación": "au-to-li-qui-da-ción",
    "autolisis": "au-to-li-sis",
    "autolote": "au-to-lo-te",
    "autómata": "au-tó-ma-ta",
    "automática": "au-to-má-ti-ca",
    "automáticamente": "au-to-má-ti-ca-men-te",
    "automaticidad": "au-to-ma-ti-ci-dad",
    "automático": "au-to-má-ti-co",
    "automatismo": "au-to-ma-tis-mo",
    "automatización": "au-to-ma-ti-za-ción",
    "automatizar": "au-to-ma-ti-zar",
    "automedicación": "au-to-me-di-ca-ción",
    "automedicar": "au-to-me-di-car",
    "automedonte": "au-to-me-don-te",
    "automercado": "au-to-mer-ca-do",
    "automoción": "au-to-mo-ción",
    "automotor": "au-to-mo-tor",
    "automotora": "au-to-mo-to-ra",
    "automotriz": "au-to-mo-triz",
    "automóvil": "au-to-mó-vil",
    "automovilismo": "au-to-mo-vi-lis-mo",
    "automovilista": "au-to-mo-vi-lis-ta",
    "automovilística": "au-to-mo-vi-lís-ti-ca",
    "automovilístico": "au-to-mo-vi-lís-ti-co",
    "automutilación": "au-to-mu-ti-la-ción",
    "autónoma": "au-tó-no-ma",
    "autónomamente": "au-tó-no-ma-men-te",
    "autonomía": "au-to-no-mí-a",
    "autonómica": "au-to-nó-mi-ca",
    "autonómico": "au-to-nó-mi-co",
    "autonomismo": "au-to-no-mis-mo",
    "autonomista": "au-to-no-mis-ta",
    "autónomo": "au-tó-no-mo",
    "autoparte": "au-to-par-te",
    "autopartista": "au-to-par-tis-ta",
    "autopase": "au-to-pa-se",
    "autopiloto": "au-to-pi-lo-to",
    "autopista": "au-to-pis-ta",
    "autoplastia": "au-to-plas-tia",
    "autoproclamar": "au-to-pro-cla-mar",
    "autopromoción": "au-to-pro-mo-ción",
    "autopropulsado": "au-to-pro-pul-sa-do",
    "autopropulsión": "au-to-pro-pul-sión",
    "autoprotección": "au-to-pro-tec-ción",
    "autopsia": "au-top-sia",
    "autópsida": "au-tóp-si-da",
    "autópsido": "au-tóp-si-do",
    "autor": "au-tor",
    "autora": "au-to-ra",
    "autoría": "au-to-rí-a",
    "autoridad": "au-to-ri-dad",
    "autoritaria": "au-to-ri-ta-ria",
    "autoritariamente": "au-to-ri-ta-ria-men-te",
    "autoritario": "au-to-ri-ta-rio",
    "autoritarismo": "au-to-ri-ta-ris-mo",
    "autoritativa": "au-to-ri-ta-ti-va",
    "autoritativo": "au-to-ri-ta-ti-vo",
    "autorizable": "au-to-ri-za-ble",
    "autorización": "au-to-ri-za-ción",
    "autorizada": "au-to-ri-za-da",
    "autorizadamente": "au-to-ri-za-da-men-te",
    "autorizado": "au-to-ri-za-do",
    "autorizador": "au-to-ri-za-dor",
    "autorizadora": "au-to-ri-za-do-ra",
    "autorizamiento": "au-to-ri-za-mien-to",
    "autorizante": "au-to-ri-zan-te",
    "autorizar": "au-to-ri-zar",
    "autorrealización": "au-to-rre-a-li-za-ción",
    "autorreflexión": "au-to-rre-fle-xión",
    "autorregulable": "au-to-rre-gu-la-ble",
    "autorregulación": "au-to-rre-gu-la-ción",
    "autorregulador": "au-to-rre-gu-la-dor",
    "autorregular": "au-to-rre-gu-lar",
    "autorrelajación": "au-to-rre-la-ja-ción",
    "autorretrato": "au-to-rre-tra-to",
    "autorreverse": "au-to-rre-ver-se",
    "autosatisfacción": "au-to-sa-tis-fac-ción",
    "autoservicio": "au-to-ser-vi-cio",
    "autostop": "au-tos-top",
    "autostopista": "au-tos-to-pis-ta",
    "autosuficiencia": "au-to-su-fi-cien-cia",
    "autosuficiente": "au-to-su-fi-cien-te",
    "autosugestión": "au-to-su-ges-tión",
    "autosugestionar": "au-to-su-ges-tio-nar",
    "autotransformador": "au-to-trans-for-ma-dor",
    "autotransfusión": "au-to-trans-fu-sión",
    "autotrófico": "au-to-tró-fi-co",
    "autótrofo": "au-tó-tro-fo",
    "autovacuna": "au-to-va-cu-na",
    "autovía": "au-to-ví-a",
    "autrigón": "au-tri-gón",
    "autrigona": "au-tri-go-na",
    "autumnal": "au-tum-nal",
    "auxiliador": "au-xi-lia-dor",
    "auxiliadora": "au-xi-lia-do-ra",
    "auxiliar": "au-xi-liar",
    "auxiliaría": "au-xi-lia-rí-a",
    "auxilio": "au-xi-lio",
    "auxina": "au-xi-na",
    "auyama": "au-ya-ma",
    "ava": "a-va",
    "avacada": "a-va-ca-da",
    "avacado": "a-va-ca-do",
    "avadar": "a-va-dar",
    "avahada": "a-va-ha-da",
    "avahado": "a-va-ha-do",
    "avahar": "a-va-har",
    "aval": "a-val",
    "avalador": "a-va-la-dor",
    "avaladora": "a-va-la-do-ra",
    "avalancha": "a-va-lan-cha",
    "avalar": "a-va-lar",
    "avalentada": "a-va-len-ta-da",
    "avalentado": "a-va-len-ta-do",
    "avalentamiento": "a-va-len-ta-mien-to",
    "avalentar": "a-va-len-tar",
    "avalentonada": "a-va-len-to-na-da",
    "avalentonado": "a-va-len-to-na-do",
    "avaliar": "a-va-liar",
    "avalista": "a-va-lis-ta",
    "avallar": "a-va-llar",
    "avalorar": "a-va-lo-rar",
    "avaluación": "a-va-lua-ción",
    "avaluar": "a-va-luar",
    "avalúo": "a-va-lú-o",
    "avambrazo": "a-vam-bra-zo",
    "avampiés": "a-vam-piés",
    "avancarga": "a-van-car-ga",
    "avance": "a-van-ce",
    "avandicha": "a-van-di-cha",
    "avandicho": "a-van-di-cho",
    "avanecer": "a-va-ne-cer",
    "avanecerse": "a-va-ne-cer-se",
    "avantal": "a-van-tal",
    "avante": "a-van-te",
    "avantrén": "a-van-trén",
    "avanzada": "a-van-za-da",
    "avanzadilla": "a-van-za-di-lla",
    "avanzado": "a-van-za-do",
    "avanzar": "a-van-zar",
    "avanzo": "a-van-zo",
    "avara": "a-va-ra",
    "avaramente": "a-va-ra-men-te",
    "avaricia": "a-va-ri-cia",
    "avariciar": "a-va-ri-ciar",
    "avariciosa": "a-va-ri-cio-sa",
    "avariciosamente": "a-va-ri-cio-sa-men-te",
    "avaricioso": "a-va-ri-cio-so",
    "avarienta": "a-va-rien-ta",
    "avariento": "a-va-rien-to",
    "avariosis": "a-va-rio-sis",
    "avaro": "a-va-ro",
    "avasallador": "a-va-sa-lla-dor",
    "avasalladora": "a-va-sa-lla-do-ra",
    "avasallamiento": "a-va-sa-lla-mien-to",
    "avasallante": "a-va-sa-llan-te",
    "avasallar": "a-va-sa-llar",
    "avatar": "a-va-tar",
    "avatí": "a-va-tí",
    "ave": "a-ve",
    "ave": "a-ve",
    "avechucho": "a-ve-chu-cho",
    "avecilla": "a-ve-ci-lla",
    "avecinar": "a-ve-ci-nar",
    "avecindamiento": "a-ve-cin-da-mien-to",
    "avecindar": "a-ve-cin-dar",
    "avefría": "a-ve-frí-a",
    "avejentar": "a-ve-jen-tar",
    "avejigar": "a-ve-ji-gar",
    "avelar": "a-ve-lar",
    "avellana": "a-ve-lla-na",
    "avellanado": "a-ve-lla-na-do",
    "avellanador": "a-ve-lla-na-dor",
    "avellanal": "a-ve-lla-nal",
    "avellanar": "a-ve-lla-nar",
    "avellanate": "a-ve-lla-na-te",
    "avellaneda": "a-ve-lla-ne-da",
    "avellanedo": "a-ve-lla-ne-do",
    "avellanera": "a-ve-lla-ne-ra",
    "avellanero": "a-ve-lla-ne-ro",
    "avellano": "a-ve-lla-no",
    "aveloriado": "a-ve-lo-ria-do",
    "avemaría": "a-ve-ma-rí-a",
    "avena": "a-ve-na",
    "avenada": "a-ve-na-da",
    "avenado": "a-ve-na-do",
    "avenamiento": "a-ve-na-mien-to",
    "avenar": "a-ve-nar",
    "avenate": "a-ve-na-te",
    "avenediza": "a-ve-ne-di-za",
    "avenedizo": "a-ve-ne-di-zo",
    "avenenar": "a-ve-ne-nar",
    "avenencia": "a-ve-nen-cia",
    "avenenteza": "a-ve-nen-te-za",
    "avenerado": "a-ve-ne-ra-do",
    "avenible": "a-ve-ni-ble",
    "avenícea": "a-ve-ní-ce-a",
    "aveníceo": "a-ve-ní-ce-o",
    "avenida": "a-ve-ni-da",
    "avenidera": "a-ve-ni-de-ra",
    "avenidero": "a-ve-ni-de-ro",
    "avenido": "a-ve-ni-do",
    "avenidor": "a-ve-ni-dor",
    "avenidora": "a-ve-ni-do-ra",
    "avenimiento": "a-ve-ni-mien-to",
    "avenir": "a-ve-nir",
    "aventada": "a-ven-ta-da",
    "aventadero": "a-ven-ta-de-ro",
    "aventado": "a-ven-ta-do",
    "aventador": "a-ven-ta-dor",
    "aventadora": "a-ven-ta-do-ra",
    "aventadura": "a-ven-ta-du-ra",
    "aventaja": "a-ven-ta-ja",
    "aventajada": "a-ven-ta-ja-da",
    "aventajado": "a-ven-ta-ja-do",
    "aventajamiento": "a-ven-ta-ja-mien-to",
    "aventajar": "a-ven-ta-jar",
    "aventamiento": "a-ven-ta-mien-to",
    "aventar": "a-ven-tar",
    "aventón": "a-ven-tón",
    "aventura": "a-ven-tu-ra",
    "aventurada": "a-ven-tu-ra-da",
    "aventuradamente": "a-ven-tu-ra-da-men-te",
    "aventurado": "a-ven-tu-ra-do",
    "aventurar": "a-ven-tu-rar",
    "aventurera": "a-ven-tu-re-ra",
    "aventureramente": "a-ven-tu-re-ra-men-te",
    "aventurero": "a-ven-tu-re-ro",
    "aventurismo": "a-ven-tu-ris-mo",
    "averar": "a-ve-rar",
    "averdugar": "a-ver-du-gar",
    "avergonzada": "a-ver-gon-za-da",
    "avergonzadamente": "a-ver-gon-za-da-men-te",
    "avergonzado": "a-ver-gon-za-do",
    "avergonzamiento": "a-ver-gon-za-mien-to",
    "avergonzar": "a-ver-gon-zar",
    "avería": "a-ve-rí-a",
    "averiar": "a-ve-riar",
    "averiguable": "a-ve-ri-gua-ble",
    "averiguación": "a-ve-ri-gua-ción",
    "averiguadamente": "a-ve-ri-gua-da-men-te",
    "averiguador": "a-ve-ri-gua-dor",
    "averiguadora": "a-ve-ri-gua-do-ra",
    "averiguamiento": "a-ve-ri-gua-mien-to",
    "averiguar": "a-ve-ri-guar",
    "averiguata": "a-ve-ri-gua-ta",
    "averigüetas": "a-ve-ri-güe-tas",
    "averío": "a-ve-rí-o",
    "averna": "a-ver-na",
    "averno": "a-ver-no",
    "averroísmo": "a-ve-rro-ís-mo",
    "averroísta": "a-ve-rro-ís-ta",
    "averrugada": "a-ve-rru-ga-da",
    "averrugado": "a-ve-rru-ga-do",
    "aversa": "a-ver-sa",
    "aversar": "a-ver-sar",
    "aversaria": "a-ver-sa-ria",
    "aversario": "a-ver-sa-rio",
    "aversión": "a-ver-sión",
    "averso": "a-ver-so",
    "avesta": "a-ves-ta",
    "avéstico": "a-vés-ti-co",
    "avestruz": "a-ves-truz",
    "avetada": "a-ve-ta-da",
    "avetado": "a-ve-ta-do",
    "avetarda": "a-ve-tar-da",
    "avetorillo": "a-ve-to-ri-llo",
    "avetoro": "a-ve-to-ro",
    "aveza": "a-ve-za",
    "avezado": "a-ve-za-do",
    "avezadura": "a-ve-za-du-ra",
    "avezar": "a-ve-zar",
    "avezón": "a-ve-zón",
    "aviación": "a-via-ción",
    "aviado": "a-via-do",
    "aviador": "a-via-dor",
    "aviadora": "a-via-do-ra",
    "aviajado": "a-via-ja-do",
    "aviamiento": "a-via-mien-to",
    "aviar": "a-viar",
    "aviaria": "a-via-ria",
    "aviario": "a-via-rio",
    "avica": "a-vi-ca",
    "aviciar": "a-vi-ciar",
    "avícola": "a-ví-co-la",
    "avicultor": "a-vi-cul-tor",
    "avicultora": "a-vi-cul-to-ra",
    "avicultura": "a-vi-cul-tu-ra",
    "ávida": "á-vi-da",
    "ávidamente": "á-vi-da-men-te",
    "avidez": "a-vi-dez",
    "ávido": "á-vi-do",
    "aviejar": "a-vie-jar",
    "avienta": "a-vien-ta",
    "aviento": "a-vien-to",
    "aviesa": "a-vie-sa",
    "aviesamente": "a-vie-sa-men-te",
    "aviesas": "a-vie-sas",
    "avieso": "a-vie-so",
    "aviespa": "a-vies-pa",
    "avifauna": "a-vi-fau-na",
    "avifáunico": "a-vi-fáu-ni-co",
    "avigorar": "a-vi-go-rar",
    "avilantar": "a-vi-lan-tar",
    "avilantarse": "a-vi-lan-tar-se",
    "avilantez": "a-vi-lan-tez",
    "avilanteza": "a-vi-lan-te-za",
    "avilar": "a-vi-lar",
    "avileña": "a-vi-le-ña",
    "avileño": "a-vi-le-ño",
    "avilés": "a-vi-lés",
    "avilesa": "a-vi-le-sa",
    "avilesina": "a-vi-le-si-na",
    "avilesino": "a-vi-le-si-no",
    "avillanada": "a-vi-lla-na-da",
    "avillanado": "a-vi-lla-na-do",
    "avillanamiento": "a-vi-lla-na-mien-to",
    "avillanar": "a-vi-lla-nar",
    "aviltamiento": "a-vil-ta-mien-to",
    "aviltar": "a-vil-tar",
    "avinagrada": "a-vi-na-gra-da",
    "avinagrado": "a-vi-na-gra-do",
    "avinagrar": "a-vi-na-grar",
    "aviñonense": "a-vi-ño-nen-se",
    "aviñonés": "a-vi-ño-nés",
    "aviñonesa": "a-vi-ño-ne-sa",
    "avío": "a-ví-o",
    "avión": "a-vión",
    "avionazo": "a-vio-na-zo",
    "avioneta": "a-vio-ne-ta",
    "aviónica": "a-vió-ni-ca",
    "avisacoches": "a-vi-sa-co-ches",
    "avisada": "a-vi-sa-da",
    "avisadamente": "a-vi-sa-da-men-te",
    "avisado": "a-vi-sa-do",
    "avisador": "a-vi-sa-dor",
    "avisadora": "a-vi-sa-do-ra",
    "avisaje": "a-vi-sa-je",
    "avisamiento": "a-vi-sa-mien-to",
    "avisar": "a-vi-sar",
    "avisero": "a-vi-se-ro",
    "aviso": "a-vi-so",
    "avisón": "a-vi-són",
    "avispa": "a-vis-pa",
    "avispada": "a-vis-pa-da",
    "avispado": "a-vis-pa-do",
    "avispar": "a-vis-par",
    "avispero": "a-vis-pe-ro",
    "avispón": "a-vis-pón",
    "avistamiento": "a-vis-ta-mien-to",
    "avistar": "a-vis-tar",
    "avitaminosis": "a-vi-ta-mi-no-sis",
    "avitelada": "a-vi-te-la-da",
    "avitelado": "a-vi-te-la-do",
    "avituallamiento": "a-vi-tua-lla-mien-to",
    "avituallar": "a-vi-tua-llar",
    "avivada": "a-vi-va-da",
    "avivadamente": "a-vi-va-da-men-te",
    "avivado": "a-vi-va-do",
    "avivador": "a-vi-va-dor",
    "avivadora": "a-vi-va-do-ra",
    "avivamiento": "a-vi-va-mien-to",
    "avivar": "a-vi-var",
    "avivata": "a-vi-va-ta",
    "avivato": "a-vi-va-to",
    "avizor": "a-vi-zor",
    "avizorador": "a-vi-zo-ra-dor",
    "avizoradora": "a-vi-zo-ra-do-ra",
    "avizorar": "a-vi-zo-rar",
    "avo": "a-vo",
    "avocación": "a-vo-ca-ción",
    "avocado": "a-vo-ca-do",
    "avocamiento": "a-vo-ca-mien-to",
    "avocar": "a-vo-car",
    "avocastro": "a-vo-cas-tro",
    "avoceta": "a-vo-ce-ta",
    "avol": "a-vol",
    "avolcanada": "a-vol-ca-na-da",
    "avolcanado": "a-vol-ca-na-do",
    "avoleza": "a-vo-le-za",
    "avolvimiento": "a-vol-vi-mien-to",
    "avorazado": "a-vo-ra-za-do",
    "avorazamiento": "a-vo-ra-za-mien-to",
    "avorazar": "a-vo-ra-zar",
    "avucasta": "a-vu-cas-ta",
    "avucastro": "a-vu-cas-tro",
    "avugo": "a-vu-go",
    "avuguero": "a-vu-gue-ro",
    "avulsión": "a-vul-sión",
    "avutarda": "a-vu-tar-da",
    "avutardada": "a-vu-tar-da-da",
    "avutardado": "a-vu-tar-da-do",
    "áxcale": "áx-ca-le",
    "axénico": "a-xé-ni-co",
    "axial": "a-xial",
    "axil": "a-xil",
    "axila": "a-xi-la",
    "axilar": "a-xi-lar",
    "axinita": "a-xi-ni-ta",
    "axiología": "a-xio-lo-gí-a",
    "axiológicamente": "a-xio-ló-gi-ca-men-te",
    "axiológico": "a-xio-ló-gi-co",
    "axioma": "a-xio-ma",
    "axiomática": "a-xio-má-ti-ca",
    "axiomáticamente": "a-xio-má-ti-ca-men-te",
    "axiomático": "a-xio-má-ti-co",
    "axiomatización": "a-xio-ma-ti-za-ción",
    "axiomatizar": "a-xio-ma-ti-zar",
    "axiómetro": "a-xió-me-tro",
    "axiote": "a-xio-te",
    "axis": "a-xis",
    "axoidea": "a-xoi-de-a",
    "axoideo": "a-xoi-de-o",
    "axón": "a-xón",
    "axonometría": "a-xo-no-me-trí-a",
    "axonomorfo": "a-xo-no-mor-fo",
    "aya": "a-ya",
    "ayacahuite": "a-ya-ca-hui-te",
    "ayacaste": "a-ya-cas-te",
    "ayaco": "a-ya-co",
    "ayacote": "a-ya-co-te",
    "ayacuá": "a-ya-cuá",
    "ayacuchana": "a-ya-cu-cha-na",
    "ayacuchano": "a-ya-cu-cha-no",
    "ayacuchense": "a-ya-cu-chen-se",
    "ayahuasca": "a-ya-huas-ca",
    "ayalés": "a-ya-lés",
    "ayalesa": "a-ya-le-sa",
    "ayate": "a-ya-te",
    "ayatolá": "a-ya-to-lá",
    "ayayáu": "a-ya-yáu",
    "ayayay": "a-ya-yay",
    "ayayera": "a-ya-ye-ra",
    "ayayero": "a-ya-ye-ro",
    "ayear": "a-ye-ar",
    "ayeaye": "a-ye-a-ye",
    "ayer": "a-yer",
    "ayermar": "a-yer-mar",
    "aymara": "ay-ma-ra",
    "aymé": "ay-mé",
    "ayo": "a-yo",
    "ayocote": "a-yo-co-te",
    "ayopayeña": "a-yo-pa-ye-ña",
    "ayopayeño": "a-yo-pa-ye-ño",
    "ayora": "a-yo-ra",
    "ayorea": "a-yo-re-a",
    "ayoreo": "a-yo-re-o",
    "ayote": "a-yo-te",
    "ayotera": "a-yo-te-ra",
    "ayúa": "a-yú-a",
    "ayuda": "a-yu-da",
    "ayudada": "a-yu-da-da",
    "ayudado": "a-yu-da-do",
    "ayudador": "a-yu-da-dor",
    "ayudadora": "a-yu-da-do-ra",
    "ayudamemoria": "a-yu-da-me-mo-ria",
    "ayudamiento": "a-yu-da-mien-to",
    "ayudanta": "a-yu-dan-ta",
    "ayudante": "a-yu-dan-te",
    "ayudantía": "a-yu-dan-tí-a",
    "ayudar": "a-yu-dar",
    "ayudista": "a-yu-dis-ta",
    "ayuga": "a-yu-ga",
    "ayuna": "a-yu-na",
    "ayunador": "a-yu-na-dor",
    "ayunadora": "a-yu-na-do-ra",
    "ayunar": "a-yu-nar",
    "ayuno": "a-yu-no",
    "ayunque": "a-yun-que",
    "ayuntable": "a-yun-ta-ble",
    "ayuntadamente": "a-yun-ta-da-men-te",
    "ayuntador": "a-yun-ta-dor",
    "ayuntadora": "a-yun-ta-do-ra",
    "ayuntamiento": "a-yun-ta-mien-to",
    "ayuntar": "a-yun-tar",
    "ayuso": "a-yu-so",
    "ayustar": "a-yus-tar",
    "ayuste": "a-yus-te",
    "azabachada": "a-za-ba-cha-da",
    "azabachado": "a-za-ba-cha-do",
    "azabache": "a-za-ba-che",
    "azabachero": "a-za-ba-che-ro",
    "azabara": "a-za-ba-ra",
    "azacán": "a-za-cán",
    "azacana": "a-za-ca-na",
    "azacanar": "a-za-ca-nar",
    "azacanarse": "a-za-ca-nar-se",
    "azacanear": "a-za-ca-ne-ar",
    "azacaneo": "a-za-ca-ne-o",
    "azacaya": "a-za-ca-ya",
    "azache": "a-za-che",
    "azacuán": "a-za-cuán",
    "azada": "a-za-da",
    "azadada": "a-za-da-da",
    "azadazo": "a-za-da-zo",
    "azadilla": "a-za-di-lla",
    "azadón": "a-za-dón",
    "azadonada": "a-za-do-na-da",
    "azadonazo": "a-za-do-na-zo",
    "azadonero": "a-za-do-ne-ro",
    "azafata": "a-za-fa-ta",
    "azafate": "a-za-fa-te",
    "azafato": "a-za-fa-to",
    "azafrán": "a-za-frán",
    "azafranada": "a-za-fra-na-da",
    "azafranado": "a-za-fra-na-do",
    "azafranal": "a-za-fra-nal",
    "azafranar": "a-za-fra-nar",
    "azafranera": "a-za-fra-ne-ra",
    "azafranero": "a-za-fra-ne-ro",
    "azagadero": "a-za-ga-de-ro",
    "azagador": "a-za-ga-dor",
    "azagar": "a-za-gar",
    "azagaya": "a-za-ga-ya",
    "azagón": "a-za-gón",
    "azaguán": "a-za-guán",
    "azahar": "a-za-har",
    "azainadamente": "a-zai-na-da-men-te",
    "azalá": "a-za-lá",
    "azalea": "a-za-le-a",
    "azálea": "a-zá-le-a",
    "azamboa": "a-zam-bo-a",
    "azamboero": "a-zam-bo-e-ro",
    "azamboo": "a-zam-bo-o",
    "azanahoriate": "a-za-na-ho-ria-te",
    "azanca": "a-zan-ca",
    "azándar": "a-zán-dar",
    "azanefa": "a-za-ne-fa",
    "azangarina": "a-zan-ga-ri-na",
    "azangarino": "a-zan-ga-ri-no",
    "azanoria": "a-za-no-ria",
    "azanoriate": "a-za-no-ria-te",
    "azaque": "a-za-que",
    "azaquefa": "a-za-que-fa",
    "azar": "a-zar",
    "azaramiento": "a-za-ra-mien-to",
    "azarandar": "a-za-ran-dar",
    "azarar": "a-za-rar",
    "azararse": "a-za-rar-se",
    "azarbe": "a-zar-be",
    "azarbeta": "a-zar-be-ta",
    "azarcón": "a-zar-cón",
    "azarear": "a-za-re-ar",
    "azarearse": "a-za-re-ar-se",
    "azarja": "a-zar-ja",
    "azarnefe": "a-zar-ne-fe",
    "azaro": "a-za-ro",
    "azarolla": "a-za-ro-lla",
    "azarollo": "a-za-ro-llo",
    "azarosa": "a-za-ro-sa",
    "azarosamente": "a-za-ro-sa-men-te",
    "azaroso": "a-za-ro-so",
    "ázcale": "áz-ca-le",
    "azcarrio": "az-ca-rrio",
    "azcón": "az-cón",
    "azcona": "az-co-na",
    "azerbaijana": "a-zer-bai-ja-na",
    "azerbaijano": "a-zer-bai-ja-no",
    "azerbaiyana": "a-zer-bai-ya-na",
    "azerbaiyano": "a-zer-bai-ya-no",
    "azerí": "a-ze-rí",
    "azeuxis": "a-zeu-xis",
    "ázimo": "á-zi-mo",
    "azimut": "a-zi-mut",
    "azimutal": "a-zi-mu-tal",
    "aznacho": "az-na-cho",
    "aznallo": "az-na-llo",
    "azo": "a-zo",
    "azoada": "a-zo-a-da",
    "azoado": "a-zo-a-do",
    "azoar": "a-zo-ar",
    "azoato": "a-zo-a-to",
    "azocada": "a-zo-ca-da",
    "azocador": "a-zo-ca-dor",
    "azocadora": "a-zo-ca-do-ra",
    "azocar": "a-zo-car",
    "ázoe": "á-zo-e",
    "azoemia": "a-zo-e-mia",
    "azofaifa": "a-zo-fai-fa",
    "azofaifo": "a-zo-fai-fo",
    "azófar": "a-zó-far",
    "azofeifa": "a-zo-fei-fa",
    "azofra": "a-zo-fra",
    "azogada": "a-zo-ga-da",
    "azogadamente": "a-zo-ga-da-men-te",
    "azogado": "a-zo-ga-do",
    "azogamiento": "a-zo-ga-mien-to",
    "azogar": "a-zo-gar",
    "azogue": "a-zo-gue",
    "azogueña": "a-zo-gue-ña",
    "azogueño": "a-zo-gue-ño",
    "azoguería": "a-zo-gue-rí-a",
    "azoguero": "a-zo-gue-ro",
    "azoico": "a-zoi-co",
    "azolácea": "a-zo-lá-ce-a",
    "azoláceo": "a-zo-lá-ce-o",
    "azolar": "a-zo-lar",
    "azolea": "a-zo-le-a",
    "azoleo": "a-zo-le-o",
    "azolvamiento": "a-zol-va-mien-to",
    "azolvar": "a-zol-var",
    "azolve": "a-zol-ve",
    "azomamiento": "a-zo-ma-mien-to",
    "azomar": "a-zo-mar",
    "azonzar": "a-zon-zar",
    "azoospermia": "a-zo-os-per-mia",
    "azopilotado": "a-zo-pi-lo-ta-do",
    "azoque": "a-zo-que",
    "azor": "a-zor",
    "azorafa": "a-zo-ra-fa",
    "azoramiento": "a-zo-ra-mien-to",
    "azorante": "a-zo-ran-te",
    "azorar": "a-zo-rar",
    "azorero": "a-zo-re-ro",
    "azoriniano": "a-zo-ri-nia-no",
    "azoro": "a-zo-ro",
    "azorramiento": "a-zo-rra-mien-to",
    "azorrar": "a-zo-rrar",
    "azorrillar": "a-zo-rri-llar",
    "azotable": "a-zo-ta-ble",
    "azotacalles": "a-zo-ta-ca-lles",
    "azotada": "a-zo-ta-da",
    "azotado": "a-zo-ta-do",
    "azotador": "a-zo-ta-dor",
    "azotadora": "a-zo-ta-do-ra",
    "azotaina": "a-zo-tai-na",
    "azotalenguas": "a-zo-ta-len-guas",
    "azotamiento": "a-zo-ta-mien-to",
    "azotar": "a-zo-tar",
    "azotazo": "a-zo-ta-zo",
    "azote": "a-zo-te",
    "azotea": "a-zo-te-a",
    "azotehuela": "a-zo-te-hue-la",
    "azotina": "a-zo-ti-na",
    "azotón": "a-zo-tón",
    "azteca": "az-te-ca",
    "aztequismo": "az-te-quis-mo",
    "aztor": "az-tor",
    "azua": "a-zua",
    "azuana": "a-zua-na",
    "azuano": "a-zua-no",
    "azuaya": "a-zua-ya",
    "azuayo": "a-zua-yo",
    "azúcar": "a-zú-car",
    "azucarada": "a-zu-ca-ra-da",
    "azucarado": "a-zu-ca-ra-do",
    "azucarar": "a-zu-ca-rar",
    "azucarera": "a-zu-ca-re-ra",
    "azucarero": "a-zu-ca-re-ro",
    "azucarí": "a-zu-ca-rí",
    "azucarillo": "a-zu-ca-ri-llo",
    "azucena": "a-zu-ce-na",
    "azuche": "a-zu-che",
    "azud": "a-zud",
    "azuda": "a-zu-da",
    "azuela": "a-zue-la",
    "azufaifa": "a-zu-fai-fa",
    "azufaifo": "a-zu-fai-fo",
    "azufeifa": "a-zu-fei-fa",
    "azufeifo": "a-zu-fei-fo",
    "azufrada": "a-zu-fra-da",
    "azufrado": "a-zu-fra-do",
    "azufrador": "a-zu-fra-dor",
    "azufradora": "a-zu-fra-do-ra",
    "azuframiento": "a-zu-fra-mien-to",
    "azufrar": "a-zu-frar",
    "azufre": "a-zu-fre",
    "azufrera": "a-zu-fre-ra",
    "azufrero": "a-zu-fre-ro",
    "azufrón": "a-zu-frón",
    "azufrosa": "a-zu-fro-sa",
    "azufroso": "a-zu-fro-so",
    "azul": "a-zul",
    "azulada": "a-zu-la-da",
    "azulado": "a-zu-la-do",
    "azulaque": "a-zu-la-que",
    "azular": "a-zu-lar",
    "azulear": "a-zu-le-ar",
    "azuleja": "a-zu-le-ja",
    "azulejar": "a-zu-le-jar",
    "azulejera": "a-zu-le-je-ra",
    "azulejería": "a-zu-le-je-rí-a",
    "azulejero": "a-zu-le-je-ro",
    "azulejo": "a-zu-le-jo",
    "azulenca": "a-zu-len-ca",
    "azulenco": "a-zu-len-co",
    "azulete": "a-zu-le-te",
    "azulgrana": "a-zul-gra-na",
    "azulillo": "a-zu-li-llo",
    "azulina": "a-zu-li-na",
    "azulino": "a-zu-li-no",
    "azulón": "a-zu-lón",
    "azulona": "a-zu-lo-na",
    "azuloso": "a-zu-lo-so",
    "azumagar": "a-zu-ma-gar",
    "azúmbar": "a-zúm-bar",
    "azumbrada": "a-zum-bra-da",
    "azumbrado": "a-zum-bra-do",
    "azumbre": "a-zum-bre",
    "azuquita": "a-zu-qui-ta",
    "azuquítar": "a-zu-quí-tar",
    "azur": "a-zur",
    "azurita": "a-zu-ri-ta",
    "azurronar": "a-zu-rro-nar",
    "azurronarse": "a-zu-rro-nar-se",
    "azurumbar": "a-zu-rum-bar",
    "azut": "a-zut",
    "azutea": "a-zu-te-a",
    "azuzador": "a-zu-za-dor",
    "azuzadora": "a-zu-za-do-ra",
    "azuzar": "a-zu-zar",
    "baalita": "ba-a-li-ta",
    "baba": "ba-ba",
    "babaca": "ba-ba-ca",
    "babaco": "ba-ba-co",
    "babada": "ba-ba-da",
    "babadero": "ba-ba-de-ro",
    "babador": "ba-ba-dor",
    "babaero": "ba-ba-e-ro",
    "babahoyense": "ba-ba-ho-yen-se",
    "babanca": "ba-ban-ca",
    "babanco": "ba-ban-co",
    "babatel": "ba-ba-tel",
    "babaza": "ba-ba-za",
    "babazorra": "ba-ba-zo-rra",
    "babazorro": "ba-ba-zo-rro",
    "babeante": "ba-be-an-te",
    "babear": "ba-be-ar",
    "babel": "ba-bel",
    "babélica": "ba-bé-li-ca",
    "babélico": "ba-bé-li-co",
    "babeo": "ba-be-o",
    "babequía": "ba-be-quí-a",
    "babera": "ba-be-ra",
    "babero": "ba-be-ro",
    "baberol": "ba-be-rol",
    "babi": "ba-bi",
    "babia": "ba-bia",
    "babiana": "ba-bia-na",
    "babiano": "ba-bia-no",
    "babieca": "ba-bie-ca",
    "babilar": "ba-bi-lar",
    "babilla": "ba-bi-lla",
    "babilón": "ba-bi-lón",
    "babilona": "ba-bi-lo-na",
    "babilonia": "ba-bi-lo-nia",
    "babilónica": "ba-bi-ló-ni-ca",
    "babilónico": "ba-bi-ló-ni-co",
    "babilonio": "ba-bi-lo-nio",
    "babirusa": "ba-bi-ru-sa",
    "babismo": "ba-bis-mo",
    "bable": "ba-ble",
    "babonuco": "ba-bo-nu-co",
    "baboquía": "ba-bo-quí-a",
    "babor": "ba-bor",
    "babosa": "ba-bo-sa",
    "babosada": "ba-bo-sa-da",
    "babosear": "ba-bo-se-ar",
    "baboseo": "ba-bo-se-o",
    "babosería": "ba-bo-se-rí-a",
    "babosilla": "ba-bo-si-lla",
    "baboso": "ba-bo-so",
    "babucha": "ba-bu-cha",
    "babuchera": "ba-bu-che-ra",
    "babuchero": "ba-bu-che-ro",
    "babuino": "ba-bui-no",
    "baca": "ba-ca",
    "bacada": "ba-ca-da",
    "bacalada": "ba-ca-la-da",
    "bacaladera": "ba-ca-la-de-ra",
    "bacaladero": "ba-ca-la-de-ro",
    "bacaladilla": "ba-ca-la-di-lla",
    "bacalao": "ba-ca-la-o",
    "bacallao": "ba-ca-lla-o",
    "bacallar": "ba-ca-llar",
    "bacán": "ba-cán",
    "bacana": "ba-ca-na",
    "bacanal": "ba-ca-nal",
    "bacano": "ba-ca-no",
    "bacanora": "ba-ca-no-ra",
    "bacante": "ba-can-te",
    "bacará": "ba-ca-rá",
    "bácara": "bá-ca-ra",
    "bacaray": "ba-ca-ray",
    "bácaris": "bá-ca-ris",
    "bacarrá": "ba-ca-rrá",
    "bacelar": "ba-ce-lar",
    "bacenilla": "ba-ce-ni-lla",
    "bacera": "ba-ce-ra",
    "baceta": "ba-ce-ta",
    "bachaco": "ba-cha-co",
    "bachar": "ba-char",
    "bachata": "ba-cha-ta",
    "bachatear": "ba-cha-te-ar",
    "bachatera": "ba-cha-te-ra",
    "bachatero": "ba-cha-te-ro",
    "bache": "ba-che",
    "bacheado": "ba-che-a-do",
    "bachear": "ba-che-ar",
    "bacheo": "ba-che-o",
    "bachiano": "ba-chia-no",
    "bachicha": "ba-chi-cha",
    "bachiche": "ba-chi-che",
    "bachiller": "ba-chi-ller",
    "bachillera": "ba-chi-lle-ra",
    "bachilleramiento": "ba-chi-lle-ra-mien-to",
    "bachillerar": "ba-chi-lle-rar",
    "bachillerato": "ba-chi-lle-ra-to",
    "bachillerear": "ba-chi-lle-re-ar",
    "bachillería": "ba-chi-lle-rí-a",
    "bacía": "ba-cí-a",
    "báciga": "bá-ci-ga",
    "bacilar": "ba-ci-lar",
    "baciliforme": "ba-ci-li-for-me",
    "bacillar": "ba-ci-llar",
    "bacillo": "ba-ci-llo",
    "bacilo": "ba-ci-lo",
    "bacín": "ba-cín",
    "bacina": "ba-ci-na",
    "bacinada": "ba-ci-na-da",
    "bacinador": "ba-ci-na-dor",
    "bacinera": "ba-ci-ne-ra",
    "bacinero": "ba-ci-ne-ro",
    "bacineta": "ba-ci-ne-ta",
    "bacinete": "ba-ci-ne-te",
    "bacinica": "ba-ci-ni-ca",
    "bacinilla": "ba-ci-ni-lla",
    "bacisco": "ba-cis-co",
    "bacón": "ba-cón",
    "baconiana": "ba-co-nia-na",
    "baconiano": "ba-co-nia-no",
    "baconismo": "ba-co-nis-mo",
    "bacoreta": "ba-co-re-ta",
    "bacteria": "bac-te-ria",
    "bacteriana": "bac-te-ria-na",
    "bacteriano": "bac-te-ria-no",
    "bactericida": "bac-te-ri-ci-da",
    "bacteridia": "bac-te-ri-dia",
    "bacteriemia": "bac-te-rie-mia",
    "bacteriófago": "bac-te-rió-fa-go",
    "bacterióloga": "bac-te-rió-lo-ga",
    "bacteriología": "bac-te-rio-lo-gí-a",
    "bacteriológica": "bac-te-rio-ló-gi-ca",
    "bacteriológico": "bac-te-rio-ló-gi-co",
    "bacteriólogo": "bac-te-rió-lo-go",
    "bacteriostático": "bac-te-rios-tá-ti-co",
    "bactriana": "bac-tria-na",
    "bactriano": "bac-tria-no",
    "báculo": "bá-cu-lo",
    "bada": "ba-da",
    "badajada": "ba-da-ja-da",
    "badajazo": "ba-da-ja-zo",
    "badajear": "ba-da-je-ar",
    "badajo": "ba-da-jo",
    "badajoceña": "ba-da-jo-ce-ña",
    "badajoceño": "ba-da-jo-ce-ño",
    "badajocense": "ba-da-jo-cen-se",
    "badal": "ba-dal",
    "badallar": "ba-da-llar",
    "badalonés": "ba-da-lo-nés",
    "badalonesa": "ba-da-lo-ne-sa",
    "badán": "ba-dán",
    "badana": "ba-da-na",
    "badanada": "ba-da-na-da",
    "badanado": "ba-da-na-do",
    "badaza": "ba-da-za",
    "badea": "ba-de-a",
    "badelico": "ba-de-li-co",
    "baden": "ba-den",
    "badén": "ba-dén",
    "baderna": "ba-der-na",
    "badián": "ba-dián",
    "badiana": "ba-dia-na",
    "badil": "ba-dil",
    "badila": "ba-di-la",
    "badilazo": "ba-di-la-zo",
    "badilejo": "ba-di-le-jo",
    "badina": "ba-di-na",
    "bádminton": "bád-min-ton",
    "badomía": "ba-do-mí-a",
    "badulacada": "ba-du-la-ca-da",
    "badulaque": "ba-du-la-que",
    "badulaquear": "ba-du-la-que-ar",
    "badulaquería": "ba-du-la-que-rí-a",
    "baenera": "ba-e-ne-ra",
    "baenero": "ba-e-ne-ro",
    "baezana": "ba-e-za-na",
    "baezano": "ba-e-za-no",
    "bafle": "ba-fle",
    "baga": "ba-ga",
    "bagá": "ba-gá",
    "bagacera": "ba-ga-ce-ra",
    "bagaces": "ba-ga-ces",
    "bagacillo": "ba-ga-ci-llo",
    "bagaje": "ba-ga-je",
    "bagajera": "ba-ga-je-ra",
    "bagajero": "ba-ga-je-ro",
    "bagar": "ba-gar",
    "bagarino": "ba-ga-ri-no",
    "bagasa": "ba-ga-sa",
    "bagatela": "ba-ga-te-la",
    "bagauda": "ba-gau-da",
    "bagayear": "ba-ga-ye-ar",
    "bagayera": "ba-ga-ye-ra",
    "bagayero": "ba-ga-ye-ro",
    "bagayo": "ba-ga-yo",
    "bagazal": "ba-ga-zal",
    "bagazo": "ba-ga-zo",
    "bagdadí": "bag-da-dí",
    "bago": "ba-go",
    "bagre": "ba-gre",
    "bagrero": "ba-gre-ro",
    "bagual": "ba-gual",
    "baguala": "ba-gua-la",
    "bagualada": "ba-gua-la-da",
    "baguette": "ba-guet-te",
    "baguio": "ba-guio",
    "bahague": "ba-ha-gue",
    "bahaí": "ba-ha-í",
    "bahaísmo": "ba-ha-ís-mo",
    "bahameña": "ba-ha-me-ña",
    "bahameño": "ba-ha-me-ño",
    "bahareque": "ba-ha-re-que",
    "baharí": "ba-ha-rí",
    "bahía": "ba-hí-a",
    "bahiana": "ba-hia-na",
    "bahiano": "ba-hia-no",
    "bahiense": "ba-hien-se",
    "bahorrina": "ba-ho-rri-na",
    "bahreiní": "bah-rei-ní",
    "bahúna": "ba-hú-na",
    "bahúno": "ba-hú-no",
    "baída": "ba-í-da",
    "baila": "bai-la",
    "bailable": "bai-la-ble",
    "bailadera": "bai-la-de-ra",
    "bailadero": "bai-la-de-ro",
    "bailado": "bai-la-do",
    "bailador": "bai-la-dor",
    "bailadora": "bai-la-do-ra",
    "bailanta": "bai-lan-ta",
    "bailante": "bai-lan-te",
    "bailaor": "bai-la-or",
    "bailaora": "bai-la-o-ra",
    "bailar": "bai-lar",
    "bailarín": "bai-la-rín",
    "bailarina": "bai-la-ri-na",
    "baile": "bai-le",
    "bailecito": "bai-le-ci-to",
    "bailejo": "bai-le-jo",
    "bailete": "bai-le-te",
    "bailía": "bai-lí-a",
    "bailiaje": "bai-lia-je",
    "bailiazgo": "bai-liaz-go",
    "bailinista": "bai-li-nis-ta",
    "bailío": "bai-lí-o",
    "bailista": "bai-lis-ta",
    "bailón": "bai-lón",
    "bailona": "bai-lo-na",
    "bailonga": "bai-lon-ga",
    "bailongo": "bai-lon-go",
    "bailotear": "bai-lo-te-ar",
    "bailoteo": "bai-lo-te-o",
    "baipás": "bai-pás",
    "baivel": "bai-vel",
    "baja": "ba-ja",
    "bajá": "ba-já",
    "bajaca": "ba-ja-ca",
    "bajacaliforniana": "ba-ja-ca-li-for-nia-na",
    "bajacaliforniano": "ba-ja-ca-li-for-nia-no",
    "bajada": "ba-ja-da",
    "bajadero": "ba-ja-de-ro",
    "bajador": "ba-ja-dor",
    "bajalato": "ba-ja-la-to",
    "bajamanero": "ba-ja-ma-ne-ro",
    "bajamano": "ba-ja-ma-no",
    "bajamar": "ba-ja-mar",
    "bajamente": "ba-ja-men-te",
    "bajamiento": "ba-ja-mien-to",
    "bajante": "ba-jan-te",
    "bajar": "ba-jar",
    "bajareque": "ba-ja-re-que",
    "bajativo": "ba-ja-ti-vo",
    "bajear": "ba-je-ar",
    "bajedad": "ba-je-dad",
    "bajel": "ba-jel",
    "bajelero": "ba-je-le-ro",
    "bajera": "ba-je-ra",
    "bajero": "ba-je-ro",
    "bajete": "ba-je-te",
    "bajez": "ba-jez",
    "bajeza": "ba-je-za",
    "bajía": "ba-jí-a",
    "bajial": "ba-jial",
    "bajillo": "ba-ji-llo",
    "bajín": "ba-jín",
    "bajío": "ba-jí-o",
    "bajista": "ba-jis-ta",
    "bajo": "ba-jo",
    "bajoaragonés": "ba-jo-a-ra-go-nés",
    "bajoaragonesa": "ba-jo-a-ra-go-ne-sa",
    "bajoca": "ba-jo-ca",
    "bajomedieval": "ba-jo-me-die-val",
    "bajón": "ba-jón",
    "bajonado": "ba-jo-na-do",
    "bajonavarra": "ba-jo-na-va-rra",
    "bajonavarro": "ba-jo-na-va-rro",
    "bajonazo": "ba-jo-na-zo",
    "bajoncillo": "ba-jon-ci-llo",
    "bajoneado": "ba-jo-ne-a-do",
    "bajonear": "ba-jo-ne-ar",
    "bajoneo": "ba-jo-ne-o",
    "bajonista": "ba-jo-nis-ta",
    "bajorrelieve": "ba-jo-rre-lie-ve",
    "bajotraer": "ba-jo-tra-er",
    "bajuna": "ba-ju-na",
    "bajuno": "ba-ju-no",
    "bajura": "ba-ju-ra",
    "bakalao": "ba-ka-la-o",
    "bala": "ba-la",
    "balaca": "ba-la-ca",
    "balacada": "ba-la-ca-da",
    "balacear": "ba-la-ce-ar",
    "balacera": "ba-la-ce-ra",
    "balada": "ba-la-da",
    "baladí": "ba-la-dí",
    "baladista": "ba-la-dis-ta",
    "balador": "ba-la-dor",
    "baladora": "ba-la-do-ra",
    "baladrar": "ba-la-drar",
    "baladre": "ba-la-dre",
    "baladrear": "ba-la-dre-ar",
    "baladrera": "ba-la-dre-ra",
    "baladrero": "ba-la-dre-ro",
    "baladro": "ba-la-dro",
    "baladrón": "ba-la-drón",
    "baladrona": "ba-la-dro-na",
    "baladronada": "ba-la-dro-na-da",
    "baladronear": "ba-la-dro-ne-ar",
    "balagar": "ba-la-gar",
    "balagariense": "ba-la-ga-rien-se",
    "bálago": "bá-la-go",
    "balagre": "ba-la-gre",
    "balaguero": "ba-la-gue-ro",
    "balaj": "ba-laj",
    "balaje": "ba-la-je",
    "balalaica": "ba-la-lai-ca",
    "balalaika": "ba-la-lai-ka",
    "balamido": "ba-la-mi-do",
    "bálamo": "bá-la-mo",
    "balance": "ba-lan-ce",
    "balanceador": "ba-lan-ce-a-dor",
    "balanceadora": "ba-lan-ce-a-do-ra",
    "balanceante": "ba-lan-ce-an-te",
    "balancear": "ba-lan-ce-ar",
    "balanceo": "ba-lan-ce-o",
    "balancero": "ba-lan-ce-ro",
    "balancín": "ba-lan-cín",
    "balandra": "ba-lan-dra",
    "balandrán": "ba-lan-drán",
    "balandrista": "ba-lan-dris-ta",
    "balandro": "ba-lan-dro",
    "balandrón": "ba-lan-drón",
    "balandronada": "ba-lan-dro-na-da",
    "balanitis": "ba-la-ni-tis",
    "balano": "ba-la-no",
    "bálano": "bá-la-no",
    "balante": "ba-lan-te",
    "balanza": "ba-lan-za",
    "balanzario": "ba-lan-za-rio",
    "balanzón": "ba-lan-zón",
    "balar": "ba-lar",
    "balarrasa": "ba-la-rra-sa",
    "balastar": "ba-las-tar",
    "balasto": "ba-las-to",
    "balastro": "ba-las-tro",
    "balata": "ba-la-ta",
    "balate": "ba-la-te",
    "balausta": "ba-laus-ta",
    "balaustra": "ba-laus-tra",
    "balaustrada": "ba-laus-tra-da",
    "balaustrado": "ba-laus-tra-do",
    "balaustral": "ba-laus-tral",
    "balaústre": "ba-la-ús-tre",
    "balaustre": "ba-laus-tre",
    "balay": "ba-lay",
    "balayo": "ba-la-yo",
    "balazo": "ba-la-zo",
    "balboa": "bal-bo-a",
    "balbuceante": "bal-bu-ce-an-te",
    "balbucear": "bal-bu-ce-ar",
    "balbucencia": "bal-bu-cen-cia",
    "balbuceo": "bal-bu-ce-o",
    "balbuciente": "bal-bu-cien-te",
    "balbucir": "bal-bu-cir",
    "balbusardo": "bal-bu-sar-do",
    "balcánica": "bal-cá-ni-ca",
    "balcánico": "bal-cá-ni-co",
    "balcanización": "bal-ca-ni-za-ción",
    "balcanizar": "bal-ca-ni-zar",
    "balcanorromance": "bal-ca-no-rro-man-ce",
    "balcanorrománico": "bal-ca-no-rro-má-ni-co",
    "balcarrotas": "bal-ca-rro-tas",
    "balché": "bal-ché",
    "balcón": "bal-cón",
    "balconada": "bal-co-na-da",
    "balconaje": "bal-co-na-je",
    "balconcillo": "bal-con-ci-llo",
    "balconear": "bal-co-ne-ar",
    "balconera": "bal-co-ne-ra",
    "balconería": "bal-co-ne-rí-a",
    "balda": "bal-da",
    "baldada": "bal-da-da",
    "baldado": "bal-da-do",
    "baldadura": "bal-da-du-ra",
    "baldamiento": "bal-da-mien-to",
    "baldaquín": "bal-da-quín",
    "baldaquino": "bal-da-qui-no",
    "baldar": "bal-dar",
    "baldazo": "bal-da-zo",
    "balde": "bal-de",
    "baldear": "bal-de-ar",
    "baldeo": "bal-de-o",
    "baldés": "bal-dés",
    "baldía": "bal-dí-a",
    "baldíamente": "bal-dí-a-men-te",
    "baldío": "bal-dí-o",
    "baldo": "bal-do",
    "baldón": "bal-dón",
    "baldona": "bal-do-na",
    "baldonada": "bal-do-na-da",
    "baldonador": "bal-do-na-dor",
    "baldonadora": "bal-do-na-do-ra",
    "baldonamiento": "bal-do-na-mien-to",
    "baldonar": "bal-do-nar",
    "baldonear": "bal-do-ne-ar",
    "baldono": "bal-do-no",
    "baldosa": "bal-do-sa",
    "baldosador": "bal-do-sa-dor",
    "baldosar": "bal-do-sar",
    "baldosín": "bal-do-sín",
    "baldosón": "bal-do-són",
    "baldragas": "bal-dra-gas",
    "baldrés": "bal-drés",
    "baldrufa": "bal-dru-fa",
    "balduque": "bal-du-que",
    "balea": "ba-le-a",
    "baleador": "ba-le-a-dor",
    "baleadora": "ba-le-a-do-ra",
    "baleadura": "ba-le-a-du-ra",
    "balear": "ba-le-ar",
    "balearia": "ba-le-a-ria",
    "baleárica": "ba-le-á-ri-ca",
    "baleárico": "ba-le-á-ri-co",
    "baleario": "ba-le-a-rio",
    "balele": "ba-le-le",
    "balénido": "ba-lé-ni-do",
    "baleo": "ba-le-o",
    "balería": "ba-le-rí-a",
    "balerío": "ba-le-rí-o",
    "balero": "ba-le-ro",
    "balhurria": "bal-hu-rria",
    "balicero": "ba-li-ce-ro",
    "balido": "ba-li-do",
    "balilla": "ba-li-lla",
    "balimbín": "ba-lim-bín",
    "balimbing": "ba-lim-bing",
    "balín": "ba-lín",
    "balinazo": "ba-li-na-zo",
    "balinera": "ba-li-ne-ra",
    "balinero": "ba-li-ne-ro",
    "balinés": "ba-li-nés",
    "balinesa": "ba-li-ne-sa",
    "balista": "ba-lis-ta",
    "balística": "ba-lís-ti-ca",
    "balístico": "ba-lís-ti-co",
    "balita": "ba-li-ta",
    "balitadera": "ba-li-ta-de-ra",
    "balitar": "ba-li-tar",
    "balitear": "ba-li-te-ar",
    "baliza": "ba-li-za",
    "balizamiento": "ba-li-za-mien-to",
    "balizar": "ba-li-zar",
    "ballar": "ba-llar",
    "ballarte": "ba-llar-te",
    "ballena": "ba-lle-na",
    "ballenato": "ba-lle-na-to",
    "ballener": "ba-lle-ner",
    "ballenera": "ba-lle-ne-ra",
    "ballenero": "ba-lle-ne-ro",
    "ballesta": "ba-lles-ta",
    "ballestada": "ba-lles-ta-da",
    "ballestazo": "ba-lles-ta-zo",
    "ballestear": "ba-lles-te-ar",
    "ballestera": "ba-lles-te-ra",
    "ballestería": "ba-lles-te-rí-a",
    "ballestero": "ba-lles-te-ro",
    "ballestilla": "ba-lles-ti-lla",
    "ballestrinque": "ba-lles-trin-que",
    "ballet": "ba-llet",
    "ballico": "ba-lli-co",
    "ballueca": "ba-llue-ca",
    "balnearia": "bal-ne-a-ria",
    "balneario": "bal-ne-a-rio",
    "balneología": "bal-ne-o-lo-gí-a",
    "balneoterapia": "bal-ne-o-te-ra-pia",
    "balo": "ba-lo",
    "balompédico": "ba-lom-pé-di-co",
    "balompié": "ba-lom-pié",
    "balón": "ba-lón",
    "balonazo": "ba-lo-na-zo",
    "baloncestista": "ba-lon-ces-tis-ta",
    "baloncestístico": "ba-lon-ces-tís-ti-co",
    "baloncesto": "ba-lon-ces-to",
    "balonmanista": "ba-lon-ma-nis-ta",
    "balonmanístico": "ba-lon-ma-nís-ti-co",
    "balonmano": "ba-lon-ma-no",
    "balonvolea": "ba-lon-vo-le-a",
    "balota": "ba-lo-ta",
    "balotada": "ba-lo-ta-da",
    "balotage": "ba-lo-ta-ge",
    "balotaje": "ba-lo-ta-je",
    "balotar": "ba-lo-tar",
    "balsa": "bal-sa",
    "balsadera": "bal-sa-de-ra",
    "balsadero": "bal-sa-de-ro",
    "balsamera": "bal-sa-me-ra",
    "balsamerita": "bal-sa-me-ri-ta",
    "balsamía": "bal-sa-mí-a",
    "balsámica": "bal-sá-mi-ca",
    "balsámico": "bal-sá-mi-co",
    "balsamífero": "bal-sa-mí-fe-ro",
    "balsamina": "bal-sa-mi-na",
    "balsaminácea": "bal-sa-mi-ná-ce-a",
    "balsamináceo": "bal-sa-mi-ná-ce-o",
    "balsamita": "bal-sa-mi-ta",
    "bálsamo": "bál-sa-mo",
    "balsar": "bal-sar",
    "balsear": "bal-se-ar",
    "balsera": "bal-se-ra",
    "balsería": "bal-se-rí-a",
    "balsero": "bal-se-ro",
    "balsete": "bal-se-te",
    "balso": "bal-so",
    "balsón": "bal-són",
    "balsopeto": "bal-so-pe-to",
    "balta": "bal-ta",
    "bálteo": "bál-te-o",
    "báltica": "bál-ti-ca",
    "báltico": "bál-ti-co",
    "balto": "bal-to",
    "baltoeslavo": "bal-to-es-la-vo",
    "baltofinés": "bal-to-fi-nés",
    "baltra": "bal-tra",
    "baluarte": "ba-luar-te",
    "baluma": "ba-lu-ma",
    "balumba": "ba-lum-ba",
    "balumbo": "ba-lum-bo",
    "balume": "ba-lu-me",
    "balurda": "ba-lur-da",
    "balurde": "ba-lur-de",
    "balurdo": "ba-lur-do",
    "bamba": "bam-ba",
    "bambador": "bam-ba-dor",
    "bambalear": "bam-ba-le-ar",
    "bambalina": "bam-ba-li-na",
    "bambalinón": "bam-ba-li-nón",
    "bambanear": "bam-ba-ne-ar",
    "bambara": "bam-ba-ra",
    "bambarria": "bam-ba-rria",
    "bambear": "bam-be-ar",
    "bambi": "bam-bi",
    "bambochada": "bam-bo-cha-da",
    "bamboche": "bam-bo-che",
    "bamboleante": "bam-bo-le-an-te",
    "bambolear": "bam-bo-le-ar",
    "bamboleo": "bam-bo-le-o",
    "bambolla": "bam-bo-lla",
    "bambollera": "bam-bo-lle-ra",
    "bambollero": "bam-bo-lle-ro",
    "bambonear": "bam-bo-ne-ar",
    "bamboneo": "bam-bo-ne-o",
    "bambú": "bam-bú",
    "bambuc": "bam-buc",
    "bambuche": "bam-bu-che",
    "bambuco": "bam-bu-co",
    "bambudal": "bam-bu-dal",
    "bambula": "bam-bu-la",
    "bambusal": "bam-bu-sal",
    "baña": "ba-ña",
    "banaba": "ba-na-ba",
    "bañadera": "ba-ña-de-ra",
    "bañadero": "ba-ña-de-ro",
    "bañado": "ba-ña-do",
    "bañador": "ba-ña-dor",
    "bañadora": "ba-ña-do-ra",
    "banal": "ba-nal",
    "banalidad": "ba-na-li-dad",
    "banalización": "ba-na-li-za-ción",
    "banalizar": "ba-na-li-zar",
    "banana": "ba-na-na",
    "bananal": "ba-na-nal",
    "bananar": "ba-na-nar",
    "bananera": "ba-na-ne-ra",
    "bananero": "ba-na-ne-ro",
    "banano": "ba-na-no",
    "bañar": "ba-ñar",
    "banas": "ba-nas",
    "banasta": "ba-nas-ta",
    "banastera": "ba-nas-te-ra",
    "banastero": "ba-nas-te-ro",
    "banasto": "ba-nas-to",
    "banca": "ban-ca",
    "bancada": "ban-ca-da",
    "bancadita": "ban-ca-di-ta",
    "bancal": "ban-cal",
    "bancalero": "ban-ca-le-ro",
    "bancar": "ban-car",
    "bancaria": "ban-ca-ria",
    "bancario": "ban-ca-rio",
    "bancarización": "ban-ca-ri-za-ción",
    "bancarizar": "ban-ca-ri-zar",
    "bancarrota": "ban-ca-rro-ta",
    "bance": "ban-ce",
    "banco": "ban-co",
    "bancocracia": "ban-co-cra-cia",
    "bancomático": "ban-co-má-ti-co",
    "banda": "ban-da",
    "bandada": "ban-da-da",
    "bandar": "ban-dar",
    "bandarra": "ban-da-rra",
    "bandarria": "ban-da-rria",
    "bandazo": "ban-da-zo",
    "bandeada": "ban-de-a-da",
    "bandeado": "ban-de-a-do",
    "bandear": "ban-de-ar",
    "bandeja": "ban-de-ja",
    "bandejar": "ban-de-jar",
    "bandeo": "ban-de-o",
    "bandera": "ban-de-ra",
    "banderazo": "ban-de-ra-zo",
    "banderear": "ban-de-re-ar",
    "bandería": "ban-de-rí-a",
    "banderilla": "ban-de-ri-lla",
    "banderillazo": "ban-de-ri-lla-zo",
    "banderillear": "ban-de-ri-lle-ar",
    "banderillera": "ban-de-ri-lle-ra",
    "banderillero": "ban-de-ri-lle-ro",
    "banderín": "ban-de-rín",
    "banderita": "ban-de-ri-ta",
    "banderiza": "ban-de-ri-za",
    "banderizamente": "ban-de-ri-za-men-te",
    "banderizar": "ban-de-ri-zar",
    "banderizo": "ban-de-ri-zo",
    "bandero": "ban-de-ro",
    "banderola": "ban-de-ro-la",
    "bandida": "ban-di-da",
    "bandidaje": "ban-di-da-je",
    "bandidencia": "ban-di-den-cia",
    "bandido": "ban-di-do",
    "bandín": "ban-dín",
    "bandir": "ban-dir",
    "bando": "ban-do",
    "bandola": "ban-do-la",
    "bandolera": "ban-do-le-ra",
    "bandolerismo": "ban-do-le-ris-mo",
    "bandolero": "ban-do-le-ro",
    "bandolín": "ban-do-lín",
    "bandolina": "ban-do-li-na",
    "bandolinista": "ban-do-li-nis-ta",
    "bandolón": "ban-do-lón",
    "bandolonista": "ban-do-lo-nis-ta",
    "bandoneón": "ban-do-ne-ón",
    "bandoneonista": "ban-do-ne-o-nis-ta",
    "bandrullo": "ban-dru-llo",
    "bandujo": "ban-du-jo",
    "bandul": "ban-dul",
    "bandullo": "ban-du-llo",
    "bandurria": "ban-du-rria",
    "bandurrista": "ban-du-rris-ta",
    "bañera": "ba-ñe-ra",
    "bañero": "ba-ñe-ro",
    "bañezana": "ba-ñe-za-na",
    "bañezano": "ba-ñe-za-no",
    "bangaña": "ban-ga-ña",
    "bangaño": "ban-ga-ño",
    "bangiofícea": "ban-gio-fí-ce-a",
    "bangiofíceas": "ban-gio-fí-ce-as",
    "bangiofíceo": "ban-gio-fí-ce-o",
    "baniano": "ba-nia-no",
    "bañil": "ba-ñil",
    "banileja": "ba-ni-le-ja",
    "banilejo": "ba-ni-le-jo",
    "banir": "ba-nir",
    "bañista": "ba-ñis-ta",
    "banjo": "ban-jo",
    "baño": "ba-ño",
    "bañón": "ba-ñón",
    "banquear": "ban-que-ar",
    "banqueo": "ban-que-o",
    "banquera": "ban-que-ra",
    "banquero": "ban-que-ro",
    "banqueta": "ban-que-ta",
    "banquete": "ban-que-te",
    "banquetear": "ban-que-te-ar",
    "banquetera": "ban-que-te-ra",
    "banquetero": "ban-que-te-ro",
    "banquillo": "ban-qui-llo",
    "banquina": "ban-qui-na",
    "banquisa": "ban-qui-sa",
    "bantú": "ban-tú",
    "bantustán": "ban-tus-tán",
    "banyo": "ban-yo",
    "banzada": "ban-za-da",
    "banzado": "ban-za-do",
    "banzo": "ban-zo",
    "banzón": "ban-zón",
    "bao": "ba-o",
    "baobab": "ba-o-bab",
    "baptismal": "bap-tis-mal",
    "baptismo": "bap-tis-mo",
    "baptista": "bap-tis-ta",
    "baptisterio": "bap-tis-te-rio",
    "baptizador": "bap-ti-za-dor",
    "baptizar": "bap-ti-zar",
    "baque": "ba-que",
    "baqueana": "ba-que-a-na",
    "baqueano": "ba-que-a-no",
    "baquear": "ba-que-ar",
    "baquelita": "ba-que-li-ta",
    "baquero": "ba-que-ro",
    "baqueta": "ba-que-ta",
    "baquetazo": "ba-que-ta-zo",
    "baqueteada": "ba-que-te-a-da",
    "baqueteado": "ba-que-te-a-do",
    "baquetear": "ba-que-te-ar",
    "baqueteo": "ba-que-te-o",
    "baquetón": "ba-que-tón",
    "baquía": "ba-quí-a",
    "baquiana": "ba-quia-na",
    "baquiano": "ba-quia-no",
    "báquica": "bá-qui-ca",
    "báquico": "bá-qui-co",
    "baquio": "ba-quio",
    "báquira": "bá-qui-ra",
    "báquiro": "bá-qui-ro",
    "baraca": "ba-ra-ca",
    "baracaldés": "ba-ra-cal-dés",
    "baracaldesa": "ba-ra-cal-de-sa",
    "barahá": "ba-ra-há",
    "barahonera": "ba-ra-ho-ne-ra",
    "barahonero": "ba-ra-ho-ne-ro",
    "barahúnda": "ba-ra-hún-da",
    "barahustar": "ba-rahus-tar",
    "baraja": "ba-ra-ja",
    "barajada": "ba-ra-ja-da",
    "barajador": "ba-ra-ja-dor",
    "barajadora": "ba-ra-ja-do-ra",
    "barajadura": "ba-ra-ja-du-ra",
    "barajar": "ba-ra-jar",
    "baraje": "ba-ra-je",
    "barajear": "ba-ra-je-ar",
    "barajo": "ba-ra-jo",
    "barajón": "ba-ra-jón",
    "barajustada": "ba-ra-jus-ta-da",
    "barajustar": "ba-ra-jus-tar",
    "barajuste": "ba-ra-jus-te",
    "baraka": "ba-ra-ka",
    "baraña": "ba-ra-ña",
    "baranda": "ba-ran-da",
    "barandado": "ba-ran-da-do",
    "barandaje": "ba-ran-da-je",
    "barandal": "ba-ran-dal",
    "barandilla": "ba-ran-di-lla",
    "barangay": "ba-ran-gay",
    "barangayán": "ba-ran-ga-yán",
    "baraño": "ba-ra-ño",
    "barata": "ba-ra-ta",
    "baratador": "ba-ra-ta-dor",
    "baratadora": "ba-ra-ta-do-ra",
    "baratamente": "ba-ra-ta-men-te",
    "baratar": "ba-ra-tar",
    "baratear": "ba-ra-te-ar",
    "baratera": "ba-ra-te-ra",
    "baratería": "ba-ra-te-rí-a",
    "baratero": "ba-ra-te-ro",
    "baratía": "ba-ra-tí-a",
    "baratija": "ba-ra-ti-ja",
    "baratillera": "ba-ra-ti-lle-ra",
    "baratillero": "ba-ra-ti-lle-ro",
    "baratillo": "ba-ra-ti-llo",
    "baratista": "ba-ra-tis-ta",
    "barato": "ba-ra-to",
    "baratón": "ba-ra-tón",
    "baratona": "ba-ra-to-na",
    "báratro": "bá-ra-tro",
    "baratura": "ba-ra-tu-ra",
    "baraúnda": "ba-ra-ún-da",
    "baraustar": "ba-raus-tar",
    "barauste": "ba-raus-te",
    "barba": "bar-ba",
    "barbacana": "bar-ba-ca-na",
    "barbacoa": "bar-ba-co-a",
    "barbacuá": "bar-ba-cuá",
    "barbada": "bar-ba-da",
    "barbadamente": "bar-ba-da-men-te",
    "barbadense": "bar-ba-den-se",
    "barbado": "bar-ba-do",
    "barbaja": "bar-ba-ja",
    "barbaján": "bar-ba-ján",
    "barbajuelas": "bar-ba-jue-las",
    "barbar": "bar-bar",
    "bárbara": "bár-ba-ra",
    "bárbaramente": "bár-ba-ra-men-te",
    "barbarería": "bar-ba-re-rí-a",
    "barbaresca": "bar-ba-res-ca",
    "barbaresco": "bar-ba-res-co",
    "barbaria": "bar-ba-ria",
    "barbárica": "bar-bá-ri-ca",
    "barbáricamente": "bar-bá-ri-ca-men-te",
    "barbárico": "bar-bá-ri-co",
    "barbaridad": "bar-ba-ri-dad",
    "barbarie": "bar-ba-rie",
    "barbarismo": "bar-ba-ris-mo",
    "barbarización": "bar-ba-ri-za-ción",
    "barbarizar": "bar-ba-ri-zar",
    "bárbaro": "bár-ba-ro",
    "barbarote": "bar-ba-ro-te",
    "barbasco": "bar-bas-co",
    "barbastrense": "bar-bas-tren-se",
    "barbastrina": "bar-bas-tri-na",
    "barbastrino": "bar-bas-tri-no",
    "barbato": "bar-ba-to",
    "barbear": "bar-be-ar",
    "barbechada": "bar-be-cha-da",
    "barbechar": "bar-be-char",
    "barbechera": "bar-be-che-ra",
    "barbecho": "bar-be-cho",
    "barbera": "bar-be-ra",
    "barbería": "bar-be-rí-a",
    "barberil": "bar-be-ril",
    "barbero": "bar-be-ro",
    "barberol": "bar-be-rol",
    "barbeta": "bar-be-ta",
    "barbián": "bar-bián",
    "barbiana": "bar-bia-na",
    "barbiblanca": "bar-bi-blan-ca",
    "barbiblanco": "bar-bi-blan-co",
    "barbicacho": "bar-bi-ca-cho",
    "barbicana": "bar-bi-ca-na",
    "barbicano": "bar-bi-ca-no",
    "barbicastaña": "bar-bi-cas-ta-ña",
    "barbicastaño": "bar-bi-cas-ta-ño",
    "barbiespesa": "bar-bies-pe-sa",
    "barbiespeso": "bar-bies-pe-so",
    "barbihecho": "bar-bihe-cho",
    "barbijo": "bar-bi-jo",
    "barbilampiño": "bar-bi-lam-pi-ño",
    "barbilindo": "bar-bi-lin-do",
    "barbilla": "bar-bi-lla",
    "barbillera": "bar-bi-lle-ra",
    "barbillón": "bar-bi-llón",
    "barbilucio": "bar-bi-lu-cio",
    "barbiluenga": "bar-bi-luen-ga",
    "barbiluengo": "bar-bi-luen-go",
    "barbimorena": "bar-bi-mo-re-na",
    "barbimoreno": "bar-bi-mo-re-no",
    "barbinegra": "bar-bi-ne-gra",
    "barbinegro": "bar-bi-ne-gro",
    "barbiponiente": "bar-bi-po-nien-te",
    "barbipungente": "bar-bi-pun-gen-te",
    "barbipuniente": "bar-bi-pu-nien-te",
    "barbiquejo": "bar-bi-que-jo",
    "barbirralo": "bar-bi-rra-lo",
    "barbirrapada": "bar-bi-rra-pa-da",
    "barbirrapado": "bar-bi-rra-pa-do",
    "barbirroja": "bar-bi-rro-ja",
    "barbirrojo": "bar-bi-rro-jo",
    "barbirrubia": "bar-bi-rru-bia",
    "barbirrubio": "bar-bi-rru-bio",
    "barbirrucia": "bar-bi-rru-cia",
    "barbirrucio": "bar-bi-rru-cio",
    "barbitaheña": "bar-bi-ta-he-ña",
    "barbitaheño": "bar-bi-ta-he-ño",
    "barbiteñida": "bar-bi-te-ñi-da",
    "barbiteñido": "bar-bi-te-ñi-do",
    "barbitonta": "bar-bi-ton-ta",
    "barbitonto": "bar-bi-ton-to",
    "barbitúrico": "bar-bi-tú-ri-co",
    "barbiturismo": "bar-bi-tu-ris-mo",
    "barbo": "bar-bo",
    "barbón": "bar-bón",
    "barboquejo": "bar-bo-que-jo",
    "barbotar": "bar-bo-tar",
    "barbote": "bar-bo-te",
    "barboteadura": "bar-bo-te-a-du-ra",
    "barbotear": "bar-bo-te-ar",
    "barboteo": "bar-bo-te-o",
    "barbotina": "bar-bo-ti-na",
    "barbuda": "bar-bu-da",
    "barbudo": "bar-bu-do",
    "bárbula": "bár-bu-la",
    "bárbulas": "bár-bu-las",
    "barbulla": "bar-bu-lla",
    "barbullar": "bar-bu-llar",
    "barbullido": "bar-bu-lli-do",
    "barbullón": "bar-bu-llón",
    "barbullona": "bar-bu-llo-na",
    "barbuquejo": "bar-bu-que-jo",
    "barbusano": "bar-bu-sa-no",
    "barca": "bar-ca",
    "barcada": "bar-ca-da",
    "barcaje": "bar-ca-je",
    "barcal": "bar-cal",
    "barcarola": "bar-ca-ro-la",
    "barcaza": "bar-ca-za",
    "barcella": "bar-ce-lla",
    "barcelona": "bar-ce-lo-na",
    "barcelonense": "bar-ce-lo-nen-se",
    "barcelonés": "bar-ce-lo-nés",
    "barcelonesa": "bar-ce-lo-ne-sa",
    "barcelonista": "bar-ce-lo-nis-ta",
    "barcena": "bar-ce-na",
    "bárcena": "bár-ce-na",
    "barceno": "bar-ce-no",
    "barceo": "bar-ce-o",
    "barchilla": "bar-chi-lla",
    "barchilón": "bar-chi-lón",
    "barchilona": "bar-chi-lo-na",
    "barcia": "bar-cia",
    "barcina": "bar-ci-na",
    "barcinador": "bar-ci-na-dor",
    "barcinar": "bar-ci-nar",
    "barcino": "bar-ci-no",
    "barcinonense": "bar-ci-no-nen-se",
    "barco": "bar-co",
    "barcolongo": "bar-co-lon-go",
    "barcoluengo": "bar-co-luen-go",
    "barcón": "bar-cón",
    "barda": "bar-da",
    "bardada": "bar-da-da",
    "bardado": "bar-da-do",
    "bardaguera": "bar-da-gue-ra",
    "bardaja": "bar-da-ja",
    "bardaje": "bar-da-je",
    "bardal": "bar-dal",
    "bardana": "bar-da-na",
    "bardanza": "bar-dan-za",
    "bardar": "bar-dar",
    "bardeo": "bar-de-o",
    "bardera": "bar-de-ra",
    "bardero": "bar-de-ro",
    "bardiota": "bar-dio-ta",
    "bardiza": "bar-di-za",
    "bardo": "bar-do",
    "bardoma": "bar-do-ma",
    "bardomera": "bar-do-me-ra",
    "bárdulo": "bár-du-lo",
    "baremación": "ba-re-ma-ción",
    "baremar": "ba-re-mar",
    "baremo": "ba-re-mo",
    "bareque": "ba-re-que",
    "bareta": "ba-re-ta",
    "bareto": "ba-re-to",
    "bargueña": "bar-gue-ña",
    "bargueño": "bar-gue-ño",
    "barhidrómetro": "ba-rhi-dró-me-tro",
    "barí": "ba-rí",
    "baría": "ba-rí-a",
    "baria": "ba-ria",
    "baricéntrico": "ba-ri-cén-tri-co",
    "baricentro": "ba-ri-cen-tro",
    "bárico": "bá-ri-co",
    "baril": "ba-ril",
    "barillero": "ba-ri-lle-ro",
    "barín": "ba-rín",
    "barina": "ba-ri-na",
    "barinés": "ba-ri-nés",
    "barinesa": "ba-ri-ne-sa",
    "bario": "ba-rio",
    "barisfera": "ba-ris-fe-ra",
    "barísfera": "ba-rís-fe-ra",
    "barita": "ba-ri-ta",
    "baritel": "ba-ri-tel",
    "baritina": "ba-ri-ti-na",
    "baritonal": "ba-ri-to-nal",
    "barítono": "ba-rí-to-no",
    "barján": "bar-ján",
    "barjoleta": "bar-jo-le-ta",
    "barjuleta": "bar-ju-le-ta",
    "barloa": "bar-lo-a",
    "barloar": "bar-lo-ar",
    "barloventear": "bar-lo-ven-te-ar",
    "barloventeo": "bar-lo-ven-te-o",
    "barlovento": "bar-lo-ven-to",
    "barman": "bar-man",
    "barnabita": "bar-na-bi-ta",
    "barnacla": "bar-na-cla",
    "barniz": "bar-niz",
    "barnizado": "bar-ni-za-do",
    "barnizador": "bar-ni-za-dor",
    "barnizadora": "bar-ni-za-do-ra",
    "barnizadura": "bar-ni-za-du-ra",
    "barnizar": "bar-ni-zar",
    "baro": "ba-ro",
    "barógrafo": "ba-ró-gra-fo",
    "barojiano": "ba-ro-jia-no",
    "barométrica": "ba-ro-mé-tri-ca",
    "barométrico": "ba-ro-mé-tri-co",
    "barómetro": "ba-ró-me-tro",
    "barón": "ba-rón",
    "baronesa": "ba-ro-ne-sa",
    "baronía": "ba-ro-ní-a",
    "baroscopio": "ba-ros-co-pio",
    "baroto": "ba-ro-to",
    "barotraumatismo": "ba-ro-trau-ma-tis-mo",
    "barquear": "bar-que-ar",
    "barqueo": "bar-que-o",
    "barquera": "bar-que-ra",
    "barquero": "bar-que-ro",
    "barquía": "bar-quí-a",
    "barquilla": "bar-qui-lla",
    "barquillera": "bar-qui-lle-ra",
    "barquillero": "bar-qui-lle-ro",
    "barquillo": "bar-qui-llo",
    "barquín": "bar-quín",
    "barquinazo": "bar-qui-na-zo",
    "barquinera": "bar-qui-ne-ra",
    "barquino": "bar-qui-no",
    "barquisimetana": "bar-qui-si-me-ta-na",
    "barquisimetano": "bar-qui-si-me-ta-no",
    "barra": "ba-rra",
    "barrabás": "ba-rra-bás",
    "barrabasada": "ba-rra-ba-sa-da",
    "barrabrava": "ba-rra-bra-va",
    "barraca": "ba-rra-ca",
    "barrachel": "ba-rra-chel",
    "barracón": "ba-rra-cón",
    "barracuda": "ba-rra-cu-da",
    "barrada": "ba-rra-da",
    "barrado": "ba-rra-do",
    "barragán": "ba-rra-gán",
    "barragana": "ba-rra-ga-na",
    "barraganada": "ba-rra-ga-na-da",
    "barraganería": "ba-rra-ga-ne-rí-a",
    "barraganete": "ba-rra-ga-ne-te",
    "barraganía": "ba-rra-ga-ní-a",
    "barrajar": "ba-rra-jar",
    "barral": "ba-rral",
    "barranca": "ba-rran-ca",
    "barrancada": "ba-rran-ca-da",
    "barrancal": "ba-rran-cal",
    "barranco": "ba-rran-co",
    "barrancosa": "ba-rran-co-sa",
    "barrancoso": "ba-rran-co-so",
    "barranquera": "ba-rran-que-ra",
    "barranquillera": "ba-rran-qui-lle-ra",
    "barranquillero": "ba-rran-qui-lle-ro",
    "barranquismo": "ba-rran-quis-mo",
    "barraquera": "ba-rra-que-ra",
    "barraquero": "ba-rra-que-ro",
    "barraquillo": "ba-rra-qui-llo",
    "barraquismo": "ba-rra-quis-mo",
    "barraquista": "ba-rra-quis-ta",
    "barrar": "ba-rrar",
    "barrasco": "ba-rras-co",
    "barreaero": "ba-rre-a-e-ro",
    "barreal": "ba-rre-al",
    "barrealoso": "ba-rre-a-lo-so",
    "barrear": "ba-rre-ar",
    "barrearse": "ba-rre-ar-se",
    "barreda": "ba-rre-da",
    "barredera": "ba-rre-de-ra",
    "barredero": "ba-rre-de-ro",
    "barredor": "ba-rre-dor",
    "barredora": "ba-rre-do-ra",
    "barreduela": "ba-rre-due-la",
    "barredura": "ba-rre-du-ra",
    "barreminas": "ba-rre-mi-nas",
    "barrena": "ba-rre-na",
    "barreña": "ba-rre-ña",
    "barrenado": "ba-rre-na-do",
    "barrenador": "ba-rre-na-dor",
    "barrenar": "ba-rre-nar",
    "barrendera": "ba-rren-de-ra",
    "barrendero": "ba-rren-de-ro",
    "barrenera": "ba-rre-ne-ra",
    "barrenero": "ba-rre-ne-ro",
    "barrenillo": "ba-rre-ni-llo",
    "barrenista": "ba-rre-nis-ta",
    "barreno": "ba-rre-no",
    "barreño": "ba-rre-ño",
    "barrer": "ba-rrer",
    "barrera": "ba-rre-ra",
    "barrero": "ba-rre-ro",
    "barreta": "ba-rre-ta",
    "barrete": "ba-rre-te",
    "barretear": "ba-rre-te-ar",
    "barretero": "ba-rre-te-ro",
    "barretina": "ba-rre-ti-na",
    "barretón": "ba-rre-tón",
    "barriada": "ba-rria-da",
    "barrial": "ba-rrial",
    "barrica": "ba-rri-ca",
    "barricada": "ba-rri-ca-da",
    "barrida": "ba-rri-da",
    "barrido": "ba-rri-do",
    "barriga": "ba-rri-ga",
    "barrigón": "ba-rri-gón",
    "barrigona": "ba-rri-go-na",
    "barriguda": "ba-rri-gu-da",
    "barrigudo": "ba-rri-gu-do",
    "barriguera": "ba-rri-gue-ra",
    "barril": "ba-rril",
    "barrila": "ba-rri-la",
    "barrilaje": "ba-rri-la-je",
    "barrilamen": "ba-rri-la-men",
    "barrilera": "ba-rri-le-ra",
    "barrilería": "ba-rri-le-rí-a",
    "barrilero": "ba-rri-le-ro",
    "barrilete": "ba-rri-le-te",
    "barrilla": "ba-rri-lla",
    "barrillar": "ba-rri-llar",
    "barrillera": "ba-rri-lle-ra",
    "barrillero": "ba-rri-lle-ro",
    "barrillo": "ba-rri-llo",
    "barrio": "ba-rrio",
    "barriobajera": "ba-rrio-ba-je-ra",
    "barriobajero": "ba-rrio-ba-je-ro",
    "barriosa": "ba-rrio-sa",
    "barrioso": "ba-rrio-so",
    "barriotera": "ba-rrio-te-ra",
    "barriotero": "ba-rrio-te-ro",
    "barriquería": "ba-rri-que-rí-a",
    "barrisco": "ba-rris-co",
    "barrista": "ba-rris-ta",
    "barrita": "ba-rri-ta",
    "barritar": "ba-rri-tar",
    "barrito": "ba-rri-to",
    "barrizal": "ba-rri-zal",
    "barro": "ba-rro",
    "barroca": "ba-rro-ca",
    "barrocamente": "ba-rro-ca-men-te",
    "barrocho": "ba-rro-cho",
    "barroco": "ba-rro-co",
    "barrón": "ba-rrón",
    "barroquismo": "ba-rro-quis-mo",
    "barroquización": "ba-rro-qui-za-ción",
    "barroquizante": "ba-rro-qui-zan-te",
    "barroquizar": "ba-rro-qui-zar",
    "barrosa": "ba-rro-sa",
    "barroso": "ba-rro-so",
    "barrote": "ba-rro-te",
    "barrueco": "ba-rrue-co",
    "barrujo": "ba-rru-jo",
    "barrumbada": "ba-rrum-ba-da",
    "barrunta": "ba-rrun-ta",
    "barruntador": "ba-rrun-ta-dor",
    "barruntadora": "ba-rrun-ta-do-ra",
    "barruntamiento": "ba-rrun-ta-mien-to",
    "barruntar": "ba-rrun-tar",
    "barrunte": "ba-rrun-te",
    "barrunto": "ba-rrun-to",
    "bartola": "bar-to-la",
    "bartolear": "bar-to-le-ar",
    "bartolillo": "bar-to-li-llo",
    "bartolina": "bar-to-li-na",
    "bártulos": "bár-tu-los",
    "baruca": "ba-ru-ca",
    "barullera": "ba-ru-lle-ra",
    "barullero": "ba-ru-lle-ro",
    "barullo": "ba-ru-llo",
    "barza": "bar-za",
    "barzal": "bar-zal",
    "barzola": "bar-zo-la",
    "barzón": "bar-zón",
    "barzona": "bar-zo-na",
    "barzoneada": "bar-zo-ne-a-da",
    "barzonear": "bar-zo-ne-ar",
    "basa": "ba-sa",
    "basada": "ba-sa-da",
    "basal": "ba-sal",
    "basáltica": "ba-sál-ti-ca",
    "basáltico": "ba-sál-ti-co",
    "basalto": "ba-sal-to",
    "basamento": "ba-sa-men-to",
    "basanita": "ba-sa-ni-ta",
    "basar": "ba-sar",
    "basáride": "ba-sá-ri-de",
    "basca": "bas-ca",
    "bascar": "bas-car",
    "bascosa": "bas-co-sa",
    "bascosidad": "bas-co-si-dad",
    "bascoso": "bas-co-so",
    "báscula": "bás-cu-la",
    "basculación": "bas-cu-la-ción",
    "basculador": "bas-cu-la-dor",
    "basculamiento": "bas-cu-la-mien-to",
    "basculante": "bas-cu-lan-te",
    "bascular": "bas-cu-lar",
    "basculera": "bas-cu-le-ra",
    "basculero": "bas-cu-le-ro",
    "bascuñana": "bas-cu-ña-na",
    "base": "ba-se",
    "baselácea": "ba-se-lá-ce-a",
    "baseláceo": "ba-se-lá-ce-o",
    "basic": "ba-sic",
    "básica": "bá-si-ca",
    "básicamente": "bá-si-ca-men-te",
    "basicidad": "ba-si-ci-dad",
    "básico": "bá-si-co",
    "basidio": "ba-si-dio",
    "basidiomicete": "ba-si-dio-mi-ce-te",
    "basilar": "ba-si-lar",
    "basilense": "ba-si-len-se",
    "basilia": "ba-si-lia",
    "basílica": "ba-sí-li-ca",
    "basilical": "ba-si-li-cal",
    "basílicas": "ba-sí-li-cas",
    "basilicón": "ba-si-li-cón",
    "basiliense": "ba-si-lien-se",
    "basilio": "ba-si-lio",
    "basilisco": "ba-si-lis-co",
    "basis": "ba-sis",
    "básket": "bás-ket",
    "basna": "bas-na",
    "basquear": "bas-que-ar",
    "básquet": "bás-quet",
    "basquetbol": "bas-quet-bol",
    "basquilla": "bas-qui-lla",
    "basquiña": "bas-qui-ña",
    "basset": "bas-set",
    "basta": "bas-ta",
    "bastaje": "bas-ta-je",
    "bastante": "bas-tan-te",
    "bastantear": "bas-tan-te-ar",
    "bastantemente": "bas-tan-te-men-te",
    "bastanteo": "bas-tan-te-o",
    "bastar": "bas-tar",
    "bastarda": "bas-tar-da",
    "bastardar": "bas-tar-dar",
    "bastardear": "bas-tar-de-ar",
    "bastardelo": "bas-tar-de-lo",
    "bastardía": "bas-tar-dí-a",
    "bastardilla": "bas-tar-di-lla",
    "bastardillo": "bas-tar-di-llo",
    "bastardo": "bas-tar-do",
    "baste": "bas-te",
    "bastear": "bas-te-ar",
    "bastecedor": "bas-te-ce-dor",
    "bastecedora": "bas-te-ce-do-ra",
    "bastecer": "bas-te-cer",
    "bastecimiento": "bas-te-ci-mien-to",
    "bastedad": "bas-te-dad",
    "bastera": "bas-te-ra",
    "basterna": "bas-ter-na",
    "bastero": "bas-te-ro",
    "bastetana": "bas-te-ta-na",
    "bastetano": "bas-te-ta-no",
    "basteza": "bas-te-za",
    "bastida": "bas-ti-da",
    "bastidor": "bas-ti-dor",
    "bastilla": "bas-ti-lla",
    "bastillear": "bas-ti-lle-ar",
    "bastimentar": "bas-ti-men-tar",
    "bastimentero": "bas-ti-men-te-ro",
    "bastimento": "bas-ti-men-to",
    "bastión": "bas-tión",
    "bastionar": "bas-tio-nar",
    "bastir": "bas-tir",
    "bastitana": "bas-ti-ta-na",
    "bastitano": "bas-ti-ta-no",
    "basto": "bas-to",
    "bastón": "bas-tón",
    "bastonada": "bas-to-na-da",
    "bastonazo": "bas-to-na-zo",
    "bastoncillo": "bas-ton-ci-llo",
    "bastonear": "bas-to-ne-ar",
    "bastonera": "bas-to-ne-ra",
    "bastonero": "bas-to-ne-ro",
    "bástula": "bás-tu-la",
    "bástulo": "bás-tu-lo",
    "basuco": "ba-su-co",
    "basura": "ba-su-ra",
    "basural": "ba-su-ral",
    "basurear": "ba-su-re-ar",
    "basurera": "ba-su-re-ra",
    "basurero": "ba-su-re-ro",
    "bata": "ba-ta",
    "batacazo": "ba-ta-ca-zo",
    "bataclana": "ba-ta-cla-na",
    "batahola": "ba-ta-ho-la",
    "batalán": "ba-ta-lán",
    "batalla": "ba-ta-lla",
    "batallador": "ba-ta-lla-dor",
    "batalladora": "ba-ta-lla-do-ra",
    "batallar": "ba-ta-llar",
    "batallarosa": "ba-ta-lla-ro-sa",
    "batallaroso": "ba-ta-lla-ro-so",
    "batallita": "ba-ta-lli-ta",
    "batallola": "ba-ta-llo-la",
    "batallón": "ba-ta-llón",
    "batallona": "ba-ta-llo-na",
    "batallosa": "ba-ta-llo-sa",
    "batalloso": "ba-ta-llo-so",
    "batán": "ba-tán",
    "batanar": "ba-ta-nar",
    "batanear": "ba-ta-ne-ar",
    "batanera": "ba-ta-ne-ra",
    "batanero": "ba-ta-ne-ro",
    "batanga": "ba-tan-ga",
    "bataola": "ba-ta-o-la",
    "batasuna": "ba-ta-su-na",
    "batasuno": "ba-ta-su-no",
    "batata": "ba-ta-ta",
    "batatazo": "ba-ta-ta-zo",
    "batato": "ba-ta-to",
    "bátava": "bá-ta-va",
    "batavia": "ba-ta-via",
    "bátavo": "bá-ta-vo",
    "batayola": "ba-ta-yo-la",
    "batazo": "ba-ta-zo",
    "bate": "ba-te",
    "batea": "ba-te-a",
    "bateador": "ba-te-a-dor",
    "bateadora": "ba-te-a-do-ra",
    "bateaguas": "ba-te-a-guas",
    "batear": "ba-te-ar",
    "batel": "ba-tel",
    "batelera": "ba-te-le-ra",
    "batelero": "ba-te-le-ro",
    "bateo": "ba-te-o",
    "batera": "ba-te-ra",
    "batería": "ba-te-rí-a",
    "baterista": "ba-te-ris-ta",
    "batero": "ba-te-ro",
    "batey": "ba-tey",
    "batial": "ba-tial",
    "batiboleo": "ba-ti-bo-le-o",
    "batiborrillo": "ba-ti-bo-rri-llo",
    "batiburrillo": "ba-ti-bu-rri-llo",
    "baticabeza": "ba-ti-ca-be-za",
    "baticola": "ba-ti-co-la",
    "baticor": "ba-ti-cor",
    "baticulo": "ba-ti-cu-lo",
    "batida": "ba-ti-da",
    "batidera": "ba-ti-de-ra",
    "batidero": "ba-ti-de-ro",
    "batido": "ba-ti-do",
    "batidor": "ba-ti-dor",
    "batidora": "ba-ti-do-ra",
    "batiente": "ba-tien-te",
    "batifondo": "ba-ti-fon-do",
    "batifotómetro": "ba-ti-fo-tó-me-tro",
    "batihoja": "ba-tiho-ja",
    "batik": "ba-tik",
    "batilana": "ba-ti-la-na",
    "batimán": "ba-ti-mán",
    "batimento": "ba-ti-men-to",
    "batimetría": "ba-ti-me-trí-a",
    "batimétrica": "ba-ti-mé-tri-ca",
    "batimétrico": "ba-ti-mé-tri-co",
    "batímetro": "ba-tí-me-tro",
    "batimiento": "ba-ti-mien-to",
    "batín": "ba-tín",
    "batintín": "ba-tin-tín",
    "batipelágico": "ba-ti-pe-lá-gi-co",
    "batiportar": "ba-ti-por-tar",
    "batiporte": "ba-ti-por-te",
    "batir": "ba-tir",
    "batiscafo": "ba-tis-ca-fo",
    "batisfera": "ba-tis-fe-ra",
    "batista": "ba-tis-ta",
    "batitermógrafo": "ba-ti-ter-mó-gra-fo",
    "batllismo": "bat-llis-mo",
    "batllista": "bat-llis-ta",
    "bato": "ba-to",
    "batoideo": "ba-toi-de-o",
    "batojar": "ba-to-jar",
    "batola": "ba-to-la",
    "batolito": "ba-to-li-to",
    "batología": "ba-to-lo-gí-a",
    "batómetro": "ba-tó-me-tro",
    "batón": "ba-tón",
    "batracio": "ba-tra-cio",
    "batúa": "ba-tú-a",
    "batucada": "ba-tu-ca-da",
    "batucar": "ba-tu-car",
    "batuda": "ba-tu-da",
    "batueca": "ba-tue-ca",
    "batuecas": "ba-tue-cas",
    "batueco": "ba-tue-co",
    "batuque": "ba-tu-que",
    "batuquear": "ba-tu-que-ar",
    "batuqueo": "ba-tu-que-o",
    "baturra": "ba-tu-rra",
    "baturrada": "ba-tu-rra-da",
    "baturrillo": "ba-tu-rri-llo",
    "baturro": "ba-tu-rro",
    "batuta": "ba-tu-ta",
    "batzoki": "bat-zo-ki",
    "baudio": "bau-dio",
    "baúl": "ba-úl",
    "baula": "bau-la",
    "baulera": "bau-le-ra",
    "baulero": "bau-le-ro",
    "bauprés": "bau-prés",
    "baurac": "bau-rac",
    "baure": "bau-re",
    "bausa": "bau-sa",
    "bausán": "bau-sán",
    "bausana": "bau-sa-na",
    "bausera": "bau-se-ra",
    "bausero": "bau-se-ro",
    "bautismal": "bau-tis-mal",
    "bautismo": "bau-tis-mo",
    "bautista": "bau-tis-ta",
    "bautisterio": "bau-tis-te-rio",
    "bautizar": "bau-ti-zar",
    "bautizo": "bau-ti-zo",
    "bauxita": "bau-xi-ta",
    "bauyúa": "bau-yú-a",
    "bauza": "bau-za",
    "bauzador": "bau-za-dor",
    "bauzadora": "bau-za-do-ra",
    "bávara": "bá-va-ra",
    "bávaro": "bá-va-ro",
    "baya": "ba-ya",
    "bayadera": "ba-ya-de-ra",
    "bayal": "ba-yal",
    "bayamés": "ba-ya-més",
    "bayamesa": "ba-ya-me-sa",
    "bayamonés": "ba-ya-mo-nés",
    "bayamonesa": "ba-ya-mo-ne-sa",
    "bayana": "ba-ya-na",
    "bayanismo": "ba-ya-nis-mo",
    "bayano": "ba-ya-no",
    "bayarte": "ba-yar-te",
    "bayeta": "ba-ye-ta",
    "bayetilla": "ba-ye-ti-lla",
    "bayetón": "ba-ye-tón",
    "bayo": "ba-yo",
    "bayoco": "ba-yo-co",
    "bayón": "ba-yón",
    "bayona": "ba-yo-na",
    "bayonense": "ba-yo-nen-se",
    "bayonés": "ba-yo-nés",
    "bayonesa": "ba-yo-ne-sa",
    "bayoneta": "ba-yo-ne-ta",
    "bayonetazo": "ba-yo-ne-ta-zo",
    "bayoque": "ba-yo-que",
    "bayosa": "ba-yo-sa",
    "bayoya": "ba-yo-ya",
    "bayú": "ba-yú",
    "bayúa": "ba-yú-a",
    "bayuca": "ba-yu-ca",
    "bayunca": "ba-yun-ca",
    "bayuncada": "ba-yun-ca-da",
    "bayunco": "ba-yun-co",
    "baza": "ba-za",
    "bazar": "ba-zar",
    "bazo": "ba-zo",
    "bazofia": "ba-zo-fia",
    "bazooka": "ba-zo-o-ka",
    "bazuca": "ba-zu-ca",
    "bazucar": "ba-zu-car",
    "bazuco": "ba-zu-co",
    "bazuquear": "ba-zu-que-ar",
    "bazuqueo": "ba-zu-que-o",
    "bazuquera": "ba-zu-que-ra",
    "bazuquero": "ba-zu-que-ro",
    "beaciense": "be-a-cien-se",
    "beamontés": "be-a-mon-tés",
    "beamontesa": "be-a-mon-te-sa",
    "bearnés": "be-ar-nés",
    "bearnesa": "be-ar-ne-sa",
    "beata": "be-a-ta",
    "beatamente": "be-a-ta-men-te",
    "beatería": "be-a-te-rí-a",
    "beaterio": "be-a-te-rio",
    "beatífica": "be-a-tí-fi-ca",
    "beatificación": "be-a-ti-fi-ca-ción",
    "beatíficamente": "be-a-tí-fi-ca-men-te",
    "beatificar": "be-a-ti-fi-car",
    "beatífico": "be-a-tí-fi-co",
    "beatilla": "be-a-ti-lla",
    "beatísimo": "be-a-tí-si-mo",
    "beatitud": "be-a-ti-tud",
    "beatnik": "be-at-nik",
    "beato": "be-a-to",
    "beatón": "be-a-tón",
    "beba": "be-ba",
    "bebe": "be-be",
    "bebé": "be-bé",
    "bebedera": "be-be-de-ra",
    "bebedero": "be-be-de-ro",
    "bebediza": "be-be-di-za",
    "bebedizo": "be-be-di-zo",
    "bebedor": "be-be-dor",
    "bebedora": "be-be-do-ra",
    "bebendurria": "be-ben-du-rria",
    "bebentina": "be-ben-ti-na",
    "beber": "be-ber",
    "bebercio": "be-ber-cio",
    "bebería": "be-be-rí-a",
    "beberrón": "be-be-rrón",
    "beberrona": "be-be-rro-na",
    "bebestible": "be-bes-ti-ble",
    "bebetina": "be-be-ti-na",
    "bebezón": "be-be-zón",
    "bebiata": "be-bia-ta",
    "bebible": "be-bi-ble",
    "bebida": "be-bi-da",
    "bebido": "be-bi-do",
    "bebienda": "be-bien-da",
    "bebistrajo": "be-bis-tra-jo",
    "beborrotear": "be-bo-rro-te-ar",
    "beca": "be-ca",
    "becacina": "be-ca-ci-na",
    "becada": "be-ca-da",
    "becado": "be-ca-do",
    "becafigo": "be-ca-fi-go",
    "becante": "be-can-te",
    "becar": "be-car",
    "becardón": "be-car-dón",
    "becaria": "be-ca-ria",
    "becario": "be-ca-rio",
    "becerra": "be-ce-rra",
    "becerrada": "be-ce-rra-da",
    "becerrero": "be-ce-rre-ro",
    "becerril": "be-ce-rril",
    "becerrillo": "be-ce-rri-llo",
    "becerrista": "be-ce-rris-ta",
    "becerro": "be-ce-rro",
    "bechamel": "be-cha-mel",
    "becoquín": "be-co-quín",
    "becoquino": "be-co-qui-no",
    "becqueriana": "bec-que-ria-na",
    "becqueriano": "bec-que-ria-no",
    "becuadrado": "be-cua-dra-do",
    "becuadro": "be-cua-dro",
    "bedano": "be-da-no",
    "bedel": "be-del",
    "bedela": "be-de-la",
    "bedelía": "be-de-lí-a",
    "bedelio": "be-de-lio",
    "bederre": "be-de-rre",
    "beduina": "be-dui-na",
    "beduino": "be-dui-no",
    "beduro": "be-du-ro",
    "befa": "be-fa",
    "befabemí": "be-fa-be-mí",
    "befar": "be-far",
    "befedad": "be-fe-dad",
    "befo": "be-fo",
    "befre": "be-fre",
    "begarda": "be-gar-da",
    "begardo": "be-gar-do",
    "begastrense": "be-gas-tren-se",
    "begonia": "be-go-nia",
    "begoniácea": "be-go-niá-ce-a",
    "begoniáceas": "be-go-niá-ce-as",
    "begoniáceo": "be-go-niá-ce-o",
    "beguina": "be-gui-na",
    "beguino": "be-gui-no",
    "begum": "be-gum",
    "behaísmo": "be-ha-ís-mo",
    "behaviorismo": "be-ha-vio-ris-mo",
    "behaviorista": "be-ha-vio-ris-ta",
    "behetría": "be-he-trí-a",
    "behique": "behi-que",
    "beicon": "bei-con",
    "beige": "bei-ge",
    "beirutí": "bei-ru-tí",
    "béisbol": "béis-bol",
    "beisbolista": "beis-bo-lis-ta",
    "bejarana": "be-ja-ra-na",
    "bejarano": "be-ja-ra-no",
    "bejerana": "be-je-ra-na",
    "bejerano": "be-je-ra-no",
    "bejín": "be-jín",
    "bejuca": "be-ju-ca",
    "bejucal": "be-ju-cal",
    "bejuco": "be-ju-co",
    "bejuquear": "be-ju-que-ar",
    "bejuqueda": "be-ju-que-da",
    "bejuquero": "be-ju-que-ro",
    "bejuquilla": "be-ju-qui-lla",
    "bejuquillo": "be-ju-qui-llo",
    "bela": "be-la",
    "belcantismo": "bel-can-tis-mo",
    "belcantista": "bel-can-tis-ta",
    "belcho": "bel-cho",
    "beldad": "bel-dad",
    "beldar": "bel-dar",
    "belduque": "bel-du-que",
    "belemnita": "be-lem-ni-ta",
    "belemnites": "be-lem-ni-tes",
    "belén": "be-lén",
    "belenista": "be-le-nis-ta",
    "beleño": "be-le-ño",
    "belérico": "be-lé-ri-co",
    "belesa": "be-le-sa",
    "belez": "be-lez",
    "belezo": "be-le-zo",
    "belfa": "bel-fa",
    "belfo": "bel-fo",
    "belga": "bel-ga",
    "bélgica": "bél-gi-ca",
    "bélgico": "bél-gi-co",
    "bélica": "bé-li-ca",
    "bélicamente": "bé-li-ca-men-te",
    "beliceña": "be-li-ce-ña",
    "beliceño": "be-li-ce-ño",
    "belicense": "be-li-cen-se",
    "belicismo": "be-li-cis-mo",
    "belicista": "be-li-cis-ta",
    "bélico": "bé-li-co",
    "belicosa": "be-li-co-sa",
    "belicosamente": "be-li-co-sa-men-te",
    "belicosidad": "be-li-co-si-dad",
    "belicoso": "be-li-co-so",
    "belida": "be-li-da",
    "belígera": "be-lí-ge-ra",
    "beligerancia": "be-li-ge-ran-cia",
    "beligerante": "be-li-ge-ran-te",
    "beligerantemente": "be-li-ge-ran-te-men-te",
    "belígero": "be-lí-ge-ro",
    "belio": "be-lio",
    "belísona": "be-lí-so-na",
    "belísono": "be-lí-so-no",
    "belitre": "be-li-tre",
    "bella": "be-lla",
    "bellaca": "be-lla-ca",
    "bellacada": "be-lla-ca-da",
    "bellaco": "be-lla-co",
    "belladona": "be-lla-do-na",
    "bellamente": "be-lla-men-te",
    "bellaquear": "be-lla-que-ar",
    "bellaquería": "be-lla-que-rí-a",
    "bellardina": "be-llar-di-na",
    "bellasombra": "be-lla-som-bra",
    "bellavista": "be-lla-vis-ta",
    "bellegas": "be-lle-gas",
    "belleguín": "be-lle-guín",
    "belleza": "be-lle-za",
    "bellida": "be-lli-da",
    "bellido": "be-lli-do",
    "bellísima": "be-llí-si-ma",
    "bellista": "be-llis-ta",
    "bello": "be-llo",
    "bellota": "be-llo-ta",
    "bellote": "be-llo-te",
    "bellotear": "be-llo-te-ar",
    "bellotera": "be-llo-te-ra",
    "bellotero": "be-llo-te-ro",
    "bellotillo": "be-llo-ti-llo",
    "belloto": "be-llo-to",
    "belorta": "be-lor-ta",
    "belua": "be-lua",
    "beluga": "be-lu-ga",
    "belvedere": "bel-ve-de-re",
    "bemba": "bem-ba",
    "bembe": "bem-be",
    "bembé": "bem-bé",
    "bembetear": "bem-be-te-ar",
    "bembeteo": "bem-be-te-o",
    "bembo": "bem-bo",
    "bembón": "bem-bón",
    "bembona": "bem-bo-na",
    "bembudo": "bem-bu-do",
    "bemol": "be-mol",
    "bemolada": "be-mo-la-da",
    "bemolado": "be-mo-la-do",
    "benalmadense": "be-nal-ma-den-se",
    "benasqués": "be-nas-qués",
    "benaventino": "be-na-ven-ti-no",
    "bencénico": "ben-cé-ni-co",
    "benceno": "ben-ce-no",
    "bencina": "ben-ci-na",
    "bencinera": "ben-ci-ne-ra",
    "bencinero": "ben-ci-ne-ro",
    "bendecidor": "ben-de-ci-dor",
    "bendecidora": "ben-de-ci-do-ra",
    "bendecir": "ben-de-cir",
    "bendicera": "ben-di-ce-ra",
    "bendición": "ben-di-ción",
    "bendita": "ben-di-ta",
    "benditera": "ben-di-te-ra",
    "bendito": "ben-di-to",
    "benedícite": "be-ne-dí-ci-te",
    "benedicta": "be-ne-dic-ta",
    "benedictina": "be-ne-dic-ti-na",
    "benedictine": "be-ne-dic-ti-ne",
    "benedictino": "be-ne-dic-ti-no",
    "benefactor": "be-ne-fac-tor",
    "benefactora": "be-ne-fac-to-ra",
    "benefactría": "be-ne-fac-trí-a",
    "benéfica": "be-né-fi-ca",
    "benéficamente": "be-né-fi-ca-men-te",
    "beneficencia": "be-ne-fi-cen-cia",
    "beneficentísimo": "be-ne-fi-cen-tí-si-mo",
    "beneficiación": "be-ne-fi-cia-ción",
    "beneficiado": "be-ne-fi-cia-do",
    "beneficiador": "be-ne-fi-cia-dor",
    "beneficiadora": "be-ne-fi-cia-do-ra",
    "beneficial": "be-ne-fi-cial",
    "beneficiar": "be-ne-fi-ciar",
    "beneficiaria": "be-ne-fi-cia-ria",
    "beneficiario": "be-ne-fi-cia-rio",
    "beneficio": "be-ne-fi-cio",
    "beneficiosa": "be-ne-fi-cio-sa",
    "beneficiosamente": "be-ne-fi-cio-sa-men-te",
    "beneficioso": "be-ne-fi-cio-so",
    "benéfico": "be-né-fi-co",
    "benemerencia": "be-ne-me-ren-cia",
    "benemérita": "be-ne-mé-ri-ta",
    "benemérito": "be-ne-mé-ri-to",
    "beneplácito": "be-ne-plá-ci-to",
    "benévola": "be-né-vo-la",
    "benévolamente": "be-né-vo-la-men-te",
    "benevolencia": "be-ne-vo-len-cia",
    "benevolente": "be-ne-vo-len-te",
    "benevolentemente": "be-ne-vo-len-te-men-te",
    "benevolentísimo": "be-ne-vo-len-tí-si-mo",
    "benévolo": "be-né-vo-lo",
    "bengala": "ben-ga-la",
    "bengalí": "ben-ga-lí",
    "beniana": "be-nia-na",
    "beniano": "be-nia-no",
    "benigna": "be-nig-na",
    "benignamente": "be-nig-na-men-te",
    "benignidad": "be-nig-ni-dad",
    "benigno": "be-nig-no",
    "benimerín": "be-ni-me-rín",
    "benina": "be-ni-na",
    "beninés": "be-ni-nés",
    "beninesa": "be-ni-ne-sa",
    "benino": "be-ni-no",
    "benita": "be-ni-ta",
    "benito": "be-ni-to",
    "benjamín": "ben-ja-mín",
    "benjamina": "ben-ja-mi-na",
    "benjamita": "ben-ja-mi-ta",
    "benjuí": "ben-juí",
    "benteveo": "ben-te-ve-o",
    "bentónica": "ben-tó-ni-ca",
    "bentónico": "ben-tó-ni-co",
    "bentonita": "ben-to-ni-ta",
    "bentos": "ben-tos",
    "benzina": "ben-zi-na",
    "benzoato": "ben-zo-a-to",
    "benzodiacepina": "ben-zo-dia-ce-pi-na",
    "benzodiazepina": "ben-zo-dia-ze-pi-na",
    "benzoe": "ben-zo-e",
    "benzoica": "ben-zoi-ca",
    "benzoico": "ben-zoi-co",
    "benzol": "ben-zol",
    "benzolismo": "ben-zo-lis-mo",
    "beocia": "be-o-cia",
    "beocio": "be-o-cio",
    "beoda": "be-o-da",
    "beodera": "be-o-de-ra",
    "beodez": "be-o-dez",
    "beodo": "be-o-do",
    "beorí": "be-o-rí",
    "beque": "be-que",
    "béquico": "bé-qui-co",
    "berbajo": "ber-ba-jo",
    "berberecho": "ber-be-re-cho",
    "berberí": "ber-be-rí",
    "berberidácea": "ber-be-ri-dá-ce-a",
    "berberidáceo": "ber-be-ri-dá-ce-o",
    "berberídea": "ber-be-rí-de-a",
    "berberídeo": "ber-be-rí-de-o",
    "berberís": "ber-be-rís",
    "berberisca": "ber-be-ris-ca",
    "berberisco": "ber-be-ris-co",
    "bérbero": "bér-be-ro",
    "bérberos": "bér-be-ros",
    "berbí": "ber-bí",
    "berbiquí": "ber-bi-quí",
    "berceo": "ber-ce-o",
    "bercera": "ber-ce-ra",
    "bercería": "ber-ce-rí-a",
    "bercero": "ber-ce-ro",
    "berceuse": "ber-ceu-se",
    "bercial": "ber-cial",
    "berciana": "ber-cia-na",
    "berciano": "ber-cia-no",
    "bereber": "be-re-ber",
    "beréber": "be-ré-ber",
    "berebere": "be-re-be-re",
    "bereco": "be-re-co",
    "berengaria": "be-ren-ga-ria",
    "berengario": "be-ren-ga-rio",
    "berengo": "be-ren-go",
    "berenguela": "be-ren-gue-la",
    "berenjena": "be-ren-je-na",
    "berenjenada": "be-ren-je-na-da",
    "berenjenado": "be-ren-je-na-do",
    "berenjenal": "be-ren-je-nal",
    "berenjenín": "be-ren-je-nín",
    "bergadán": "ber-ga-dán",
    "bergadana": "ber-ga-da-na",
    "bergadano": "ber-ga-da-no",
    "bergamasca": "ber-ga-mas-ca",
    "bergamasco": "ber-ga-mas-co",
    "bergamota": "ber-ga-mo-ta",
    "bergamote": "ber-ga-mo-te",
    "bergamoto": "ber-ga-mo-to",
    "bergante": "ber-gan-te",
    "bergantín": "ber-gan-tín",
    "bergere": "ber-ge-re",
    "beriberi": "be-ri-be-ri",
    "berilia": "be-ri-lia",
    "berilio": "be-ri-lio",
    "berilo": "be-ri-lo",
    "beritense": "be-ri-ten-se",
    "berkelio": "ber-ke-lio",
    "berlandina": "ber-lan-di-na",
    "berlanga": "ber-lan-ga",
    "berlín": "ber-lín",
    "berlina": "ber-li-na",
    "berlinés": "ber-li-nés",
    "berlinesa": "ber-li-ne-sa",
    "berlinga": "ber-lin-ga",
    "berlingar": "ber-lin-gar",
    "berma": "ber-ma",
    "bermeja": "ber-me-ja",
    "bermejal": "ber-me-jal",
    "bermejear": "ber-me-je-ar",
    "bermejecer": "ber-me-je-cer",
    "bermejeña": "ber-me-je-ña",
    "bermejeño": "ber-me-je-ño",
    "bermejez": "ber-me-jez",
    "bermejía": "ber-me-jí-a",
    "bermejiza": "ber-me-ji-za",
    "bermejizo": "ber-me-ji-zo",
    "bermejo": "ber-me-jo",
    "bermejón": "ber-me-jón",
    "bermejona": "ber-me-jo-na",
    "bermejor": "ber-me-jor",
    "bermejuela": "ber-me-jue-la",
    "bermejura": "ber-me-ju-ra",
    "bermellón": "ber-me-llón",
    "bermudas": "ber-mu-das",
    "bermudeña": "ber-mu-de-ña",
    "bermudeño": "ber-mu-de-ño",
    "bermudina": "ber-mu-di-na",
    "bernarda": "ber-nar-da",
    "bernardina": "ber-nar-di-na",
    "bernardo": "ber-nar-do",
    "bernegal": "ber-ne-gal",
    "bernés": "ber-nés",
    "bernesa": "ber-ne-sa",
    "bernia": "ber-nia",
    "berón": "be-rón",
    "berona": "be-ro-na",
    "berozo": "be-ro-zo",
    "berquelio": "ber-que-lio",
    "berra": "be-rra",
    "berraña": "be-rra-ña",
    "berrar": "be-rrar",
    "berraza": "be-rra-za",
    "berrea": "be-rre-a",
    "berrear": "be-rre-ar",
    "berrejo": "be-rre-jo",
    "berrenchín": "be-rren-chín",
    "berrenda": "be-rren-da",
    "berrendear": "be-rren-de-ar",
    "berrendearse": "be-rren-de-ar-se",
    "berrendo": "be-rren-do",
    "berreo": "be-rre-o",
    "berreón": "be-rre-ón",
    "berreona": "be-rre-o-na",
    "berrera": "be-rre-ra",
    "berreta": "be-rre-ta",
    "berrete": "be-rre-te",
    "berretes": "be-rre-tes",
    "berretín": "be-rre-tín",
    "berrido": "be-rri-do",
    "berrín": "be-rrín",
    "berrinche": "be-rrin-che",
    "berrinchudo": "be-rrin-chu-do",
    "berro": "be-rro",
    "berrocal": "be-rro-cal",
    "berrodo": "be-rro-do",
    "berroqueña": "be-rro-que-ña",
    "berroqueño": "be-rro-que-ño",
    "berrueco": "be-rrue-co",
    "berta": "ber-ta",
    "bertsolari": "bert-so-la-ri",
    "bervete": "ber-ve-te",
    "berza": "ber-za",
    "berzal": "ber-zal",
    "berzas": "ber-zas",
    "berzotas": "ber-zo-tas",
    "besalamano": "be-sa-la-ma-no",
    "besamanos": "be-sa-ma-nos",
    "besamel": "be-sa-mel",
    "besamela": "be-sa-me-la",
    "besana": "be-sa-na",
    "besante": "be-san-te",
    "besar": "be-sar",
    "besico": "be-si-co",
    "beso": "be-so",
    "bestezuela": "bes-te-zue-la",
    "bestia": "bes-tia",
    "bestiada": "bes-tia-da",
    "bestiaje": "bes-tia-je",
    "bestial": "bes-tial",
    "bestialidad": "bes-tia-li-dad",
    "bestialismo": "bes-tia-lis-mo",
    "bestializar": "bes-tia-li-zar",
    "bestializarse": "bes-tia-li-zar-se",
    "bestialmente": "bes-tial-men-te",
    "bestiario": "bes-tia-rio",
    "bestión": "bes-tión",
    "bestiún": "bes-tiún",
    "bestoba": "bes-to-ba",
    "bestoga": "bes-to-ga",
    "béstola": "bés-to-la",
    "besucador": "be-su-ca-dor",
    "besucadora": "be-su-ca-do-ra",
    "besucar": "be-su-car",
    "besucón": "be-su-cón",
    "besucona": "be-su-co-na",
    "besugada": "be-su-ga-da",
    "besugo": "be-su-go",
    "besuguera": "be-su-gue-ra",
    "besuguero": "be-su-gue-ro",
    "besuguete": "be-su-gue-te",
    "besuqueador": "be-su-que-a-dor",
    "besuqueadora": "be-su-que-a-do-ra",
    "besuquear": "be-su-que-ar",
    "besuqueo": "be-su-que-o",
    "beta": "be-ta",
    "betabel": "be-ta-bel",
    "betabloqueador": "be-ta-blo-que-a-dor",
    "betabloqueante": "be-ta-blo-que-an-te",
    "betarraga": "be-ta-rra-ga",
    "betarrata": "be-ta-rra-ta",
    "betatrón": "be-ta-trón",
    "betel": "be-tel",
    "beterava": "be-te-ra-va",
    "bética": "bé-ti-ca",
    "bético": "bé-ti-co",
    "betijo": "be-ti-jo",
    "betlehemita": "be-tle-he-mi-ta",
    "betlehemítica": "be-tle-he-mí-ti-ca",
    "betlehemítico": "be-tle-he-mí-ti-co",
    "betlemita": "be-tle-mi-ta",
    "betlemítica": "be-tle-mí-ti-ca",
    "betlemítico": "be-tle-mí-ti-co",
    "betonera": "be-to-ne-ra",
    "betónica": "be-tó-ni-ca",
    "betulácea": "be-tu-lá-ce-a",
    "betuláceas": "be-tu-lá-ce-as",
    "betuláceo": "be-tu-lá-ce-o",
    "betume": "be-tu-me",
    "betumen": "be-tu-men",
    "betuminosa": "be-tu-mi-no-sa",
    "betuminoso": "be-tu-mi-no-so",
    "betún": "be-tún",
    "betunar": "be-tu-nar",
    "betunería": "be-tu-ne-rí-a",
    "betunero": "be-tu-ne-ro",
    "beuda": "beu-da",
    "beudez": "beu-dez",
    "beudo": "beu-do",
    "bezaar": "be-za-ar",
    "bezante": "be-zan-te",
    "bezar": "be-zar",
    "bezo": "be-zo",
    "bezoar": "be-zo-ar",
    "bezoárdica": "be-zo-ár-di-ca",
    "bezoárdico": "be-zo-ár-di-co",
    "bezoárica": "be-zo-á-ri-ca",
    "bezoárico": "be-zo-á-ri-co",
    "bezón": "be-zón",
    "bezote": "be-zo-te",
    "bezuda": "be-zu-da",
    "bezudo": "be-zu-do",
    "bhutanés": "bhu-ta-nés",
    "bhutanesa": "bhu-ta-ne-sa",
    "biaba": "bia-ba",
    "biajaca": "bia-ja-ca",
    "biajaiba": "bia-jai-ba",
    "biangular": "bian-gu-lar",
    "bianual": "bia-nual",
    "biarca": "biar-ca",
    "biarrota": "bia-rro-ta",
    "biatlón": "bia-tlón",
    "biaural": "biau-ral",
    "biauricular": "biau-ri-cu-lar",
    "biaxial": "bia-xial",
    "biáxico": "biá-xi-co",
    "biaza": "bia-za",
    "bíbaro": "bí-ba-ro",
    "bibe": "bi-be",
    "bibelot": "bi-be-lot",
    "biberón": "bi-be-rón",
    "bibí": "bi-bí",
    "bibicho": "bi-bi-cho",
    "bibijagua": "bi-bi-ja-gua",
    "biblia": "bi-blia",
    "bíblica": "bí-bli-ca",
    "bíblico": "bí-bli-co",
    "bibliobús": "bi-blio-bús",
    "bibliófila": "bi-blió-fi-la",
    "bibliofilia": "bi-blio-fi-lia",
    "bibliófilo": "bi-blió-fi-lo",
    "bibliógrafa": "bi-blió-gra-fa",
    "bibliografía": "bi-blio-gra-fí-a",
    "bibliográfica": "bi-blio-grá-fi-ca",
    "bibliográfico": "bi-blio-grá-fi-co",
    "bibliógrafo": "bi-blió-gra-fo",
    "bibliología": "bi-blio-lo-gí-a",
    "bibliómana": "bi-blió-ma-na",
    "bibliomancía": "bi-blio-man-cí-a",
    "bibliomancia": "bi-blio-man-cia",
    "bibliomanía": "bi-blio-ma-ní-a",
    "bibliómano": "bi-blió-ma-no",
    "bibliopola": "bi-blio-po-la",
    "bibliorato": "bi-blio-ra-to",
    "biblioteca": "bi-blio-te-ca",
    "bibliotecaria": "bi-blio-te-ca-ria",
    "bibliotecario": "bi-blio-te-ca-rio",
    "bibliotecóloga": "bi-blio-te-có-lo-ga",
    "bibliotecología": "bi-blio-te-co-lo-gí-a",
    "bibliotecológico": "bi-blio-te-co-ló-gi-co",
    "bibliotecólogo": "bi-blio-te-có-lo-go",
    "biblioteconomía": "bi-blio-te-co-no-mí-a",
    "biblista": "bi-blis-ta",
    "bical": "bi-cal",
    "bicameral": "bi-ca-me-ral",
    "bicameralismo": "bi-ca-me-ra-lis-mo",
    "bicampeón": "bi-cam-pe-ón",
    "bicapsular": "bi-cap-su-lar",
    "bicarbonatado": "bi-car-bo-na-ta-do",
    "bicarbonato": "bi-car-bo-na-to",
    "bicarpelado": "bi-car-pe-la-do",
    "bicéfala": "bi-cé-fa-la",
    "bicefalia": "bi-ce-fa-lia",
    "bicéfalo": "bi-cé-fa-lo",
    "bicentenario": "bi-cen-te-na-rio",
    "bíceps": "bí-ceps",
    "bicerra": "bi-ce-rra",
    "bicha": "bi-cha",
    "bichar": "bi-char",
    "bicharraco": "bi-cha-rra-co",
    "biche": "bi-che",
    "bicheadero": "bi-che-a-de-ro",
    "bichear": "bi-che-ar",
    "bichera": "bi-che-ra",
    "bichero": "bi-che-ro",
    "bichicome": "bi-chi-co-me",
    "bichín": "bi-chín",
    "bichino": "bi-chi-no",
    "bicho": "bi-cho",
    "bichoca": "bi-cho-ca",
    "bichoco": "bi-cho-co",
    "bichorno": "bi-chor-no",
    "bichozno": "bi-choz-no",
    "bici": "bi-ci",
    "bicicleta": "bi-ci-cle-ta",
    "bicicleteada": "bi-ci-cle-te-a-da",
    "bicicletear": "bi-ci-cle-te-ar",
    "biciclo": "bi-ci-clo",
    "bicípite": "bi-cí-pi-te",
    "bicoca": "bi-co-ca",
    "bicolor": "bi-co-lor",
    "bicóncava": "bi-cón-ca-va",
    "bicóncavo": "bi-cón-ca-vo",
    "biconvexa": "bi-con-ve-xa",
    "biconvexo": "bi-con-ve-xo",
    "bicoque": "bi-co-que",
    "bicoquete": "bi-co-que-te",
    "bicoquín": "bi-co-quín",
    "bicorne": "bi-cor-ne",
    "bicornio": "bi-cor-nio",
    "bicos": "bi-cos",
    "bicromato": "bi-cro-ma-to",
    "bicromía": "bi-cro-mí-a",
    "bicuento": "bi-cuen-to",
    "bicúspide": "bi-cús-pi-de",
    "bidé": "bi-dé",
    "bidentado": "bi-den-ta-do",
    "bidente": "bi-den-te",
    "bidimensional": "bi-di-men-sio-nal",
    "bidón": "bi-dón",
    "bidonville": "bi-don-vi-lle",
    "biela": "bie-la",
    "bielda": "biel-da",
    "bieldar": "biel-dar",
    "bieldo": "biel-do",
    "bieldro": "biel-dro",
    "bielga": "biel-ga",
    "bielgo": "biel-go",
    "bielorrusa": "bie-lo-rru-sa",
    "bielorruso": "bie-lo-rru-so",
    "biempensante": "biem-pen-san-te",
    "bienal": "bie-nal",
    "bienalmente": "bie-nal-men-te",
    "bienandante": "bie-nan-dan-te",
    "bienandanza": "bie-nan-dan-za",
    "bienaventurada": "bie-na-ven-tu-ra-da",
    "bienaventurado": "bie-na-ven-tu-ra-do",
    "bienaventuranza": "bie-na-ven-tu-ran-za",
    "bienaventurar": "bie-na-ven-tu-rar",
    "biendra": "bien-dra",
    "biendro": "bien-dro",
    "bienestar": "bie-nes-tar",
    "bienfacer": "bien-fa-cer",
    "bienfamada": "bien-fa-ma-da",
    "bienfamado": "bien-fa-ma-do",
    "bienfecho": "bien-fe-cho",
    "bienfechor": "bien-fe-chor",
    "bienfechora": "bien-fe-cho-ra",
    "bienfortunada": "bien-for-tu-na-da",
    "bienfortunado": "bien-for-tu-na-do",
    "biengranada": "bien-gra-na-da",
    "bienhablada": "bien-ha-bla-da",
    "bienhablado": "bien-ha-bla-do",
    "bienhaciente": "bien-ha-cien-te",
    "bienhadada": "bien-ha-da-da",
    "bienhadado": "bien-ha-da-do",
    "bienhallado": "bien-ha-lla-do",
    "bienhechor": "bien-he-chor",
    "bienhechora": "bien-he-cho-ra",
    "bienhechuría": "bien-he-chu-rí-a",
    "bienhumorado": "bien-hu-mo-ra-do",
    "bienintencionada": "bie-nin-ten-cio-na-da",
    "bienintencionado": "bie-nin-ten-cio-na-do",
    "bienio": "bie-nio",
    "bienllegada": "bien-lle-ga-da",
    "bienmandada": "bien-man-da-da",
    "bienmandado": "bien-man-da-do",
    "bienmesabe": "bien-me-sa-be",
    "bienoliente": "bie-no-lien-te",
    "bienplaciente": "bien-pla-cien-te",
    "bienquerencia": "bien-que-ren-cia",
    "bienquerer": "bien-que-rer",
    "bienquista": "bien-quis-ta",
    "bienquistar": "bien-quis-tar",
    "bienquisto": "bien-quis-to",
    "bienteveo": "bien-te-ve-o",
    "bienvenida": "bien-ve-ni-da",
    "bienvenido": "bien-ve-ni-do",
    "bienvista": "bien-vis-ta",
    "bienvivir": "bien-vi-vir",
    "bienza": "bien-za",
    "bierga": "bier-ga",
    "biergo": "bier-go",
    "biérgol": "biér-gol",
    "bierno": "bier-no",
    "bierzo": "bier-zo",
    "bifásica": "bi-fá-si-ca",
    "bifásico": "bi-fá-si-co",
    "bifaz": "bi-faz",
    "bife": "bi-fe",
    "bífera": "bí-fe-ra",
    "bífero": "bí-fe-ro",
    "bífida": "bí-fi-da",
    "bífido": "bí-fi-do",
    "bífidus": "bí-fi-dus",
    "biflora": "bi-flo-ra",
    "bifloro": "bi-flo-ro",
    "bifocal": "bi-fo-cal",
    "bífora": "bí-fo-ra",
    "biforme": "bi-for-me",
    "bifronte": "bi-fron-te",
    "biftec": "bif-tec",
    "bifurcación": "bi-fur-ca-ción",
    "bifurcada": "bi-fur-ca-da",
    "bifurcado": "bi-fur-ca-do",
    "bifurcar": "bi-fur-car",
    "bifurcarse": "bi-fur-car-se",
    "biga": "bi-ga",
    "bígama": "bí-ga-ma",
    "bigamia": "bi-ga-mia",
    "bígamo": "bí-ga-mo",
    "bigarda": "bi-gar-da",
    "bigardear": "bi-gar-de-ar",
    "bigardía": "bi-gar-dí-a",
    "bigardo": "bi-gar-do",
    "bígaro": "bí-ga-ro",
    "bigarrada": "bi-ga-rra-da",
    "bigarrado": "bi-ga-rra-do",
    "bigarro": "bi-ga-rro",
    "bigato": "bi-ga-to",
    "bignonia": "big-no-nia",
    "bignoniácea": "big-no-niá-ce-a",
    "bignoniáceo": "big-no-niá-ce-o",
    "bigorneta": "bi-gor-ne-ta",
    "bigornia": "bi-gor-nia",
    "bigornio": "bi-gor-nio",
    "bigorrella": "bi-go-rre-lla",
    "bigote": "bi-go-te",
    "bigotera": "bi-go-te-ra",
    "bigotuda": "bi-go-tu-da",
    "bigotudo": "bi-go-tu-do",
    "bigudí": "bi-gu-dí",
    "bija": "bi-ja",
    "bijagua": "bi-ja-gua",
    "bijao": "bi-ja-o",
    "bijol": "bi-jol",
    "bikini": "bi-ki-ni",
    "bilabiado": "bi-la-bia-do",
    "bilabial": "bi-la-bial",
    "bilao": "bi-la-o",
    "bilateral": "bi-la-te-ral",
    "bilateralmente": "bi-la-te-ral-men-te",
    "bilbaína": "bil-ba-í-na",
    "bilbaíno": "bil-ba-í-no",
    "bilbilitana": "bil-bi-li-ta-na",
    "bilbilitano": "bil-bi-li-ta-no",
    "bilé": "bi-lé",
    "bilet": "bi-let",
    "biliar": "bi-liar",
    "biliaria": "bi-lia-ria",
    "biliario": "bi-lia-rio",
    "bilimbique": "bi-lim-bi-que",
    "bilingüe": "bi-lin-güe",
    "bilingüismo": "bi-lin-güis-mo",
    "biliosa": "bi-lio-sa",
    "bilioso": "bi-lio-so",
    "bilirrubina": "bi-li-rru-bi-na",
    "bilis": "bi-lis",
    "bilítera": "bi-lí-te-ra",
    "bilítero": "bi-lí-te-ro",
    "billa": "bi-lla",
    "billalda": "bi-llal-da",
    "billamarquín": "bi-lla-mar-quín",
    "billar": "bi-llar",
    "billarda": "bi-llar-da",
    "billarista": "bi-lla-ris-ta",
    "billarístico": "bi-lla-rís-ti-co",
    "billetada": "bi-lle-ta-da",
    "billetado": "bi-lle-ta-do",
    "billetaje": "bi-lle-ta-je",
    "billete": "bi-lle-te",
    "billetear": "bi-lle-te-ar",
    "billetera": "bi-lle-te-ra",
    "billetero": "bi-lle-te-ro",
    "billón": "bi-llón",
    "billonario": "bi-llo-na-rio",
    "billonésima": "bi-llo-né-si-ma",
    "billonésimo": "bi-llo-né-si-mo",
    "billullo": "bi-llu-llo",
    "bilma": "bil-ma",
    "bilmar": "bil-mar",
    "bilobulada": "bi-lo-bu-la-da",
    "bilobulado": "bi-lo-bu-la-do",
    "bilocación": "bi-lo-ca-ción",
    "bilocar": "bi-lo-car",
    "bilocarse": "bi-lo-car-se",
    "biloculado": "bi-lo-cu-la-do",
    "bilocular": "bi-lo-cu-lar",
    "bilogía": "bi-lo-gí-a",
    "bilongo": "bi-lon-go",
    "bimana": "bi-ma-na",
    "bimano": "bi-ma-no",
    "bimba": "bim-ba",
    "bimbollo": "bim-bo-llo",
    "bimbral": "bim-bral",
    "bimbre": "bim-bre",
    "bimembre": "bi-mem-bre",
    "bimensual": "bi-men-sual",
    "bimensualmente": "bi-men-sual-men-te",
    "bimestral": "bi-mes-tral",
    "bimestralmente": "bi-mes-tral-men-te",
    "bimestre": "bi-mes-tre",
    "bimetal": "bi-me-tal",
    "bimetalismo": "bi-me-ta-lis-mo",
    "bimetalista": "bi-me-ta-lis-ta",
    "bimotor": "bi-mo-tor",
    "bina": "bi-na",
    "binación": "bi-na-ción",
    "binador": "bi-na-dor",
    "binadura": "bi-na-du-ra",
    "binar": "bi-nar",
    "binaria": "bi-na-ria",
    "binario": "bi-na-rio",
    "binazo": "bi-na-zo",
    "binazón": "bi-na-zón",
    "binear": "bi-ne-ar",
    "bingarrote": "bin-ga-rro-te",
    "bingo": "bin-go",
    "binguí": "bin-guí",
    "binocular": "bi-no-cu-lar",
    "binóculo": "bi-nó-cu-lo",
    "binodo": "bi-no-do",
    "binomio": "bi-no-mio",
    "bínuba": "bí-nu-ba",
    "bínubo": "bí-nu-bo",
    "binza": "bin-za",
    "bioacústica": "bio-a-cús-ti-ca",
    "bioagricultura": "bio-a-gri-cul-tu-ra",
    "biobasura": "bio-ba-su-ra",
    "biobibliografía": "bio-bi-blio-gra-fí-a",
    "biocatalizador": "bio-ca-ta-li-za-dor",
    "biocenosis": "bio-ce-no-sis",
    "biochip": "bio-chip",
    "biocida": "bio-ci-da",
    "biocinética": "bio-ci-né-ti-ca",
    "bioclimático": "bio-cli-má-ti-co",
    "bioclimatización": "bio-cli-ma-ti-za-ción",
    "bioclimatología": "bio-cli-ma-to-lo-gí-a",
    "biocombustible": "bio-com-bus-ti-ble",
    "biocompatibilidad": "bio-com-pa-ti-bi-li-dad",
    "biocompatible": "bio-com-pa-ti-ble",
    "biodegradable": "bio-de-gra-da-ble",
    "biodegradación": "bio-de-gra-da-ción",
    "biodegradar": "bio-de-gra-dar",
    "biodeterminismo": "bio-de-ter-mi-nis-mo",
    "biodinámica": "bio-di-ná-mi-ca",
    "biodiversidad": "bio-di-ver-si-dad",
    "bioelectricidad": "bio-e-lec-tri-ci-dad",
    "bioeléctrico": "bio-e-léc-tri-co",
    "bioelectromagnetismo": "bio-e-lec-tro-mag-ne-tis-mo",
    "bioelemento": "bio-e-le-men-to",
    "bioensayo": "bio-en-sa-yo",
    "bioequivalente": "bio-e-qui-va-len-te",
    "bioestadística": "bio-es-ta-dís-ti-ca",
    "bioestratigrafía": "bio-es-tra-ti-gra-fí-a",
    "bioética": "bio-é-ti-ca",
    "biofacies": "bio-fa-cies",
    "biofísica": "bio-fí-si-ca",
    "biofísico": "bio-fí-si-co",
    "biogás": "bio-gás",
    "biogénesis": "bio-gé-ne-sis",
    "biogeografía": "bio-ge-o-gra-fí-a",
    "biógrafa": "bió-gra-fa",
    "biografía": "bio-gra-fí-a",
    "biografiada": "bio-gra-fia-da",
    "biografiado": "bio-gra-fia-do",
    "biografiar": "bio-gra-fiar",
    "biográfica": "bio-grá-fi-ca",
    "biográfico": "bio-grá-fi-co",
    "biógrafo": "bió-gra-fo",
    "bioindicador": "bioin-di-ca-dor",
    "bioindustria": "bioin-dus-tria",
    "bioinformática": "bioin-for-má-ti-ca",
    "bioingeniería": "bioin-ge-nie-rí-a",
    "bióloga": "bió-lo-ga",
    "biología": "bio-lo-gí-a",
    "biológica": "bio-ló-gi-ca",
    "biológicamente": "bio-ló-gi-ca-men-te",
    "biológico": "bio-ló-gi-co",
    "biologismo": "bio-lo-gis-mo",
    "biólogo": "bió-lo-go",
    "bioluminiscencia": "bio-lu-mi-nis-cen-cia",
    "bioluminiscente": "bio-lu-mi-nis-cen-te",
    "bioma": "bio-ma",
    "biomasa": "bio-ma-sa",
    "biomaterial": "bio-ma-te-rial",
    "biombo": "biom-bo",
    "biomecánica": "bio-me-cá-ni-ca",
    "biomecánico": "bio-me-cá-ni-co",
    "biomedicina": "bio-me-di-ci-na",
    "biomédico": "bio-mé-di-co",
    "biometría": "bio-me-trí-a",
    "biométrico": "bio-mé-tri-co",
    "biomonitor": "bio-mo-ni-tor",
    "biónica": "bió-ni-ca",
    "biónico": "bió-ni-co",
    "biopolímero": "bio-po-lí-me-ro",
    "bioprótesis": "bio-pró-te-sis",
    "biopsia": "biop-sia",
    "bioquímica": "bio-quí-mi-ca",
    "bioquímico": "bio-quí-mi-co",
    "biorritmo": "bio-rrit-mo",
    "biosensor": "bio-sen-sor",
    "biosfera": "bios-fe-ra",
    "biósfera": "biós-fe-ra",
    "biota": "bio-ta",
    "biotecnología": "bio-tec-no-lo-gí-a",
    "biotecnológico": "bio-tec-no-ló-gi-co",
    "bioterapia": "bio-te-ra-pia",
    "biótico": "bió-ti-co",
    "biotipo": "bio-ti-po",
    "biotipología": "bio-ti-po-lo-gí-a",
    "biotipológico": "bio-ti-po-ló-gi-co",
    "biotita": "bio-ti-ta",
    "biotopo": "bio-to-po",
    "bióxido": "bió-xi-do",
    "bíparo": "bí-pa-ro",
    "bipartición": "bi-par-ti-ción",
    "bipartida": "bi-par-ti-da",
    "bipartidismo": "bi-par-ti-dis-mo",
    "bipartidista": "bi-par-ti-dis-ta",
    "bipartido": "bi-par-ti-do",
    "bipartito": "bi-par-ti-to",
    "bípeda": "bí-pe-da",
    "bipedación": "bi-pe-da-ción",
    "bipedalismo": "bi-pe-da-lis-mo",
    "bípede": "bí-pe-de",
    "bipedestación": "bi-pe-des-ta-ción",
    "bípedo": "bí-pe-do",
    "biplano": "bi-pla-no",
    "biplaza": "bi-pla-za",
    "bípode": "bí-po-de",
    "bipolar": "bi-po-lar",
    "bipolaridad": "bi-po-la-ri-dad",
    "bipolarización": "bi-po-la-ri-za-ción",
    "bipontina": "bi-pon-ti-na",
    "bipontino": "bi-pon-ti-no",
    "biquini": "bi-qui-ni",
    "biraró": "bi-ra-ró",
    "birdie": "bir-die",
    "biribís": "bi-ri-bís",
    "biricú": "bi-ri-cú",
    "birimbao": "bi-rim-ba-o",
    "birla": "bir-la",
    "birlador": "bir-la-dor",
    "birladora": "bir-la-do-ra",
    "birlar": "bir-lar",
    "birlesco": "bir-les-co",
    "birlí": "bir-lí",
    "birlo": "bir-lo",
    "birlocha": "bir-lo-cha",
    "birlocho": "bir-lo-cho",
    "birlón": "bir-lón",
    "birlonga": "bir-lon-ga",
    "birmana": "bir-ma-na",
    "birmano": "bir-ma-no",
    "biro": "bi-ro",
    "birome": "bi-ro-me",
    "birra": "bi-rra",
    "birreactor": "bi-rre-ac-tor",
    "birrectángulo": "bi-rrec-tán-gu-lo",
    "birrefringencia": "bi-rre-frin-gen-cia",
    "birrefringente": "bi-rre-frin-gen-te",
    "birreme": "bi-rre-me",
    "birreta": "bi-rre-ta",
    "birrete": "bi-rre-te",
    "birretina": "bi-rre-ti-na",
    "birria": "bi-rria",
    "birrión": "bi-rrión",
    "birrioso": "bi-rrio-so",
    "biruégano": "bi-rué-ga-no",
    "biruje": "bi-ru-je",
    "biruji": "bi-ru-ji",
    "bisabuela": "bi-sa-bue-la",
    "bisabuelo": "bi-sa-bue-lo",
    "bisagra": "bi-sa-gra",
    "bisalta": "bi-sal-ta",
    "bisalto": "bi-sal-to",
    "bisar": "bi-sar",
    "bisarma": "bi-sar-ma",
    "bisaya": "bi-sa-ya",
    "bisayo": "bi-sa-yo",
    "bisbirindo": "bis-bi-rin-do",
    "bisbís": "bis-bís",
    "bisbisar": "bis-bi-sar",
    "bisbisear": "bis-bi-se-ar",
    "bisbiseo": "bis-bi-se-o",
    "bisbita": "bis-bi-ta",
    "biscambra": "bis-cam-bra",
    "biscocho": "bis-co-cho",
    "biscote": "bis-co-te",
    "biscuit": "bis-cuit",
    "bisecar": "bi-se-car",
    "bisección": "bi-sec-ción",
    "bisector": "bi-sec-tor",
    "bisectriz": "bi-sec-triz",
    "bisel": "bi-sel",
    "biselador": "bi-se-la-dor",
    "biselar": "bi-se-lar",
    "bisemanal": "bi-se-ma-nal",
    "bisemanario": "bi-se-ma-na-rio",
    "bisextil": "bi-sex-til",
    "bisexual": "bi-se-xual",
    "bisexualidad": "bi-se-xua-li-dad",
    "bisiesto": "bi-sies-to",
    "bisílaba": "bi-sí-la-ba",
    "bisilábica": "bi-si-lá-bi-ca",
    "bisilábico": "bi-si-lá-bi-co",
    "bisílabo": "bi-sí-la-bo",
    "bismutina": "bis-mu-ti-na",
    "bismutita": "bis-mu-ti-ta",
    "bismuto": "bis-mu-to",
    "bisnear": "bis-ne-ar",
    "bisnes": "bis-nes",
    "bisnieta": "bis-nie-ta",
    "bisnieto": "bis-nie-to",
    "biso": "bi-so",
    "bisoja": "bi-so-ja",
    "bisojo": "bi-so-jo",
    "bisoña": "bi-so-ña",
    "bisoñada": "bi-so-ña-da",
    "bisoñé": "bi-so-ñé",
    "bisoñería": "bi-so-ñe-rí-a",
    "bisoñez": "bi-so-ñez",
    "bisoño": "bi-so-ño",
    "bisonte": "bi-son-te",
    "bispón": "bis-pón",
    "bisté": "bis-té",
    "bistec": "bis-tec",
    "bístola": "bís-to-la",
    "bistorta": "bis-tor-ta",
    "bistrecha": "bis-tre-cha",
    "bistró": "bis-tró",
    "bisturí": "bis-tu-rí",
    "bisulca": "bi-sul-ca",
    "bisulco": "bi-sul-co",
    "bisulfito": "bi-sul-fi-to",
    "bisulfuro": "bi-sul-fu-ro",
    "bisunta": "bi-sun-ta",
    "bisunto": "bi-sun-to",
    "bisurco": "bi-sur-co",
    "bisutera": "bi-su-te-ra",
    "bisutería": "bi-su-te-rí-a",
    "bisutero": "bi-su-te-ro",
    "bita": "bi-ta",
    "bitácora": "bi-tá-co-ra",
    "bitadura": "bi-ta-du-ra",
    "bítamo": "bí-ta-mo",
    "bitango": "bi-tan-go",
    "bitar": "bi-tar",
    "bíter": "bí-ter",
    "bitinia": "bi-ti-nia",
    "bitínica": "bi-tí-ni-ca",
    "bitínico": "bi-tí-ni-co",
    "bitinio": "bi-ti-nio",
    "bitneriácea": "bit-ne-riá-ce-a",
    "bitneriáceo": "bit-ne-riá-ce-o",
    "bitonal": "bi-to-nal",
    "bitonalidad": "bi-to-na-li-dad",
    "bitongo": "bi-ton-go",
    "bitoque": "bi-to-que",
    "bitor": "bi-tor",
    "bitumen": "bi-tu-men",
    "bituminada": "bi-tu-mi-na-da",
    "bituminado": "bi-tu-mi-na-do",
    "bituminosa": "bi-tu-mi-no-sa",
    "bituminoso": "bi-tu-mi-no-so",
    "biunívoco": "biu-ní-vo-co",
    "bivalente": "bi-va-len-te",
    "bivalva": "bi-val-va",
    "bivalvo": "bi-val-vo",
    "bivalvos": "bi-val-vos",
    "bivirí": "bi-vi-rí",
    "bivitelino": "bi-vi-te-li-no",
    "bixácea": "bi-xá-ce-a",
    "bixáceo": "bi-xá-ce-o",
    "bixínea": "bi-xí-ne-a",
    "bixíneo": "bi-xí-ne-o",
    "biyección": "bi-yec-ción",
    "biyectivo": "bi-yec-ti-vo",
    "biza": "bi-za",
    "bizantina": "bi-zan-ti-na",
    "bizantinamente": "bi-zan-ti-na-men-te",
    "bizantinismo": "bi-zan-ti-nis-mo",
    "bizantino": "bi-zan-ti-no",
    "bizarra": "bi-za-rra",
    "bizarramente": "bi-za-rra-men-te",
    "bizarrear": "bi-za-rre-ar",
    "bizarría": "bi-za-rrí-a",
    "bizarro": "bi-za-rro",
    "bizarrón": "bi-za-rrón",
    "bizaza": "bi-za-za",
    "bizbirindo": "biz-bi-rin-do",
    "bizca": "biz-ca",
    "bizcar": "biz-car",
    "bizco": "biz-co",
    "bizcochada": "biz-co-cha-da",
    "bizcochar": "biz-co-char",
    "bizcochera": "biz-co-che-ra",
    "bizcochería": "biz-co-che-rí-a",
    "bizcochero": "biz-co-che-ro",
    "bizcocho": "biz-co-cho",
    "bizcochuelo": "biz-co-chue-lo",
    "bizcoreto": "biz-co-re-to",
    "bizcorneada": "biz-cor-ne-a-da",
    "bizcorneado": "biz-cor-ne-a-do",
    "bizcornear": "biz-cor-ne-ar",
    "bizcorneta": "biz-cor-ne-ta",
    "bizcorneto": "biz-cor-ne-to",
    "bizcotela": "biz-co-te-la",
    "bizcuerna": "biz-cuer-na",
    "bizcuerno": "biz-cuer-no",
    "bizma": "biz-ma",
    "bizmar": "biz-mar",
    "bizna": "biz-na",
    "biznaga": "biz-na-ga",
    "biznagal": "biz-na-gal",
    "biznieta": "biz-nie-ta",
    "biznieto": "biz-nie-to",
    "bizquear": "biz-que-ar",
    "bizquera": "biz-que-ra",
    "blablá": "bla-blá",
    "blablablá": "bla-bla-blá",
    "blanca": "blan-ca",
    "blancal": "blan-cal",
    "blancarte": "blan-car-te",
    "blancaza": "blan-ca-za",
    "blancazo": "blan-ca-zo",
    "blanchete": "blan-che-te",
    "blanco": "blan-co",
    "blancor": "blan-cor",
    "blancota": "blan-co-ta",
    "blancote": "blan-co-te",
    "blancura": "blan-cu-ra",
    "blancuzca": "blan-cuz-ca",
    "blancuzco": "blan-cuz-co",
    "blanda": "blan-da",
    "blandamente": "blan-da-men-te",
    "blandeador": "blan-de-a-dor",
    "blandeadora": "blan-de-a-do-ra",
    "blandear": "blan-de-ar",
    "blandengue": "blan-den-gue",
    "blandenguería": "blan-den-gue-rí-a",
    "blandense": "blan-den-se",
    "blandeza": "blan-de-za",
    "blandicia": "blan-di-cia",
    "blandiciosa": "blan-di-cio-sa",
    "blandicioso": "blan-di-cio-so",
    "blandir": "blan-dir",
    "blando": "blan-do",
    "blandón": "blan-dón",
    "blanducha": "blan-du-cha",
    "blanducho": "blan-du-cho",
    "blanduja": "blan-du-ja",
    "blandujo": "blan-du-jo",
    "blandura": "blan-du-ra",
    "blandurilla": "blan-du-ri-lla",
    "blanduzco": "blan-duz-co",
    "blanqueación": "blan-que-a-ción",
    "blanqueado": "blan-que-a-do",
    "blanqueador": "blan-que-a-dor",
    "blanqueadora": "blan-que-a-do-ra",
    "blanqueadura": "blan-que-a-du-ra",
    "blanqueamiento": "blan-que-a-mien-to",
    "blanquear": "blan-que-ar",
    "blanquecedor": "blan-que-ce-dor",
    "blanquecer": "blan-que-cer",
    "blanquecimiento": "blan-que-ci-mien-to",
    "blanquecina": "blan-que-ci-na",
    "blanquecino": "blan-que-ci-no",
    "blanqueo": "blan-que-o",
    "blanquera": "blan-que-ra",
    "blanquero": "blan-que-ro",
    "blanqueta": "blan-que-ta",
    "blanquete": "blan-que-te",
    "blanquiazul": "blan-quia-zul",
    "blanquíbolo": "blan-quí-bo-lo",
    "blanquición": "blan-qui-ción",
    "blanquilla": "blan-qui-lla",
    "blanquillo": "blan-qui-llo",
    "blanquimento": "blan-qui-men-to",
    "blanquimiento": "blan-qui-mien-to",
    "blanquinegro": "blan-qui-ne-gro",
    "blanquinosa": "blan-qui-no-sa",
    "blanquinoso": "blan-qui-no-so",
    "blanquirroja": "blan-qui-rro-ja",
    "blanquirrojo": "blan-qui-rro-jo",
    "blanquiverde": "blan-qui-ver-de",
    "blanquivioleta": "blan-qui-vio-le-ta",
    "blanquiza": "blan-qui-za",
    "blanquizal": "blan-qui-zal",
    "blanquizar": "blan-qui-zar",
    "blanquizca": "blan-quiz-ca",
    "blanquizco": "blan-quiz-co",
    "blanquizo": "blan-qui-zo",
    "blao": "bla-o",
    "blasfema": "blas-fe-ma",
    "blasfemable": "blas-fe-ma-ble",
    "blasfemador": "blas-fe-ma-dor",
    "blasfemadora": "blas-fe-ma-do-ra",
    "blasfemamente": "blas-fe-ma-men-te",
    "blasfemante": "blas-fe-man-te",
    "blasfemar": "blas-fe-mar",
    "blasfematoria": "blas-fe-ma-to-ria",
    "blasfematorio": "blas-fe-ma-to-rio",
    "blasfemia": "blas-fe-mia",
    "blasfemo": "blas-fe-mo",
    "blasmar": "blas-mar",
    "blasmo": "blas-mo",
    "blasón": "bla-són",
    "blasonada": "bla-so-na-da",
    "blasonado": "bla-so-na-do",
    "blasonador": "bla-so-na-dor",
    "blasonadora": "bla-so-na-do-ra",
    "blasonar": "bla-so-nar",
    "blasonería": "bla-so-ne-rí-a",
    "blasonista": "bla-so-nis-ta",
    "blastema": "blas-te-ma",
    "blastocele": "blas-to-ce-le",
    "blastocelo": "blas-to-ce-lo",
    "blastocisto": "blas-to-cis-to",
    "blastocito": "blas-to-ci-to",
    "blastoderma": "blas-to-der-ma",
    "blastodermo": "blas-to-der-mo",
    "blastómero": "blas-tó-me-ro",
    "blástula": "blás-tu-la",
    "blaugrana": "blau-gra-na",
    "blava": "bla-va",
    "blavo": "bla-vo",
    "blazer": "bla-zer",
    "bleda": "ble-da",
    "bledo": "ble-do",
    "blefaritis": "ble-fa-ri-tis",
    "blefaroplastia": "ble-fa-ro-plas-tia",
    "blefaróstato": "ble-fa-rós-ta-to",
    "blenda": "blen-da",
    "blenorragia": "ble-no-rra-gia",
    "blenorrágica": "ble-no-rrá-gi-ca",
    "blenorrágico": "ble-no-rrá-gi-co",
    "blenorrea": "ble-no-rre-a",
    "blincar": "blin-car",
    "blinco": "blin-co",
    "blinda": "blin-da",
    "blindado": "blin-da-do",
    "blindaje": "blin-da-je",
    "blindar": "blin-dar",
    "blinis": "bli-nis",
    "blíster": "blís-ter",
    "bloca": "blo-ca",
    "blocaje": "blo-ca-je",
    "blocao": "blo-ca-o",
    "blocar": "blo-car",
    "blofear": "blo-fe-ar",
    "bloguero": "blo-gue-ro",
    "blonda": "blon-da",
    "blondina": "blon-di-na",
    "blondo": "blon-do",
    "bloque": "blo-que",
    "bloqueador": "blo-que-a-dor",
    "bloqueadora": "blo-que-a-do-ra",
    "bloquear": "blo-que-ar",
    "bloqueo": "blo-que-o",
    "blufear": "blu-fe-ar",
    "blufileña": "blu-fi-le-ña",
    "blufileño": "blu-fi-le-ño",
    "blúmer": "blú-mer",
    "blusa": "blu-sa",
    "blusón": "blu-són",
    "bluyín": "blu-yín",
    "boa": "bo-a",
    "boalaje": "bo-a-la-je",
    "boalar": "bo-a-lar",
    "boaqueña": "bo-a-que-ña",
    "boaqueño": "bo-a-que-ño",
    "boardilla": "bo-ar-di-lla",
    "boatiné": "bo-a-ti-né",
    "boato": "bo-a-to",
    "boba": "bo-ba",
    "bobada": "bo-ba-da",
    "bobales": "bo-ba-les",
    "bobalías": "bo-ba-lí-as",
    "bobalicón": "bo-ba-li-cón",
    "bobalicona": "bo-ba-li-co-na",
    "bobaliconamente": "bo-ba-li-co-na-men-te",
    "bobamente": "bo-ba-men-te",
    "bobatel": "bo-ba-tel",
    "bobática": "bo-bá-ti-ca",
    "bobático": "bo-bá-ti-co",
    "bobear": "bo-be-ar",
    "bobedad": "bo-be-dad",
    "bobera": "bo-be-ra",
    "bobería": "bo-be-rí-a",
    "bobeta": "bo-be-ta",
    "bóbilis": "bó-bi-lis",
    "bobillo": "bo-bi-llo",
    "bobina": "bo-bi-na",
    "bobinado": "bo-bi-na-do",
    "bobinadora": "bo-bi-na-do-ra",
    "bobinar": "bo-bi-nar",
    "bobo": "bo-bo",
    "boboré": "bo-bo-ré",
    "bobtail": "bob-tail",
    "boca": "bo-ca",
    "bocabajear": "bo-ca-ba-je-ar",
    "bocabajo": "bo-ca-ba-jo",
    "bocabarra": "bo-ca-ba-rra",
    "bocabierta": "bo-ca-bier-ta",
    "bocacalle": "bo-ca-ca-lle",
    "bocacaz": "bo-ca-caz",
    "bocacha": "bo-ca-cha",
    "bocacho": "bo-ca-cho",
    "bocací": "bo-ca-cí",
    "bocada": "bo-ca-da",
    "bocadear": "bo-ca-de-ar",
    "bocadillería": "bo-ca-di-lle-rí-a",
    "bocadillo": "bo-ca-di-llo",
    "bocadito": "bo-ca-di-to",
    "bocado": "bo-ca-do",
    "bocal": "bo-cal",
    "bocallave": "bo-ca-lla-ve",
    "bocamanga": "bo-ca-man-ga",
    "bocamejora": "bo-ca-me-jo-ra",
    "bocamina": "bo-ca-mi-na",
    "bocana": "bo-ca-na",
    "bocanada": "bo-ca-na-da",
    "bocanegra": "bo-ca-ne-gra",
    "bocarada": "bo-ca-ra-da",
    "bocarda": "bo-car-da",
    "bocarte": "bo-car-te",
    "bocasucia": "bo-ca-su-cia",
    "bocata": "bo-ca-ta",
    "bocateja": "bo-ca-te-ja",
    "bocatera": "bo-ca-te-ra",
    "bocatero": "bo-ca-te-ro",
    "bocatijera": "bo-ca-ti-je-ra",
    "bocatoma": "bo-ca-to-ma",
    "bocatoreña": "bo-ca-to-re-ña",
    "bocatoreño": "bo-ca-to-re-ño",
    "bocaza": "bo-ca-za",
    "bocazas": "bo-ca-zas",
    "bocazo": "bo-ca-zo",
    "bocear": "bo-ce-ar",
    "bocel": "bo-cel",
    "bocelar": "bo-ce-lar",
    "bocelete": "bo-ce-le-te",
    "bocera": "bo-ce-ra",
    "boceras": "bo-ce-ras",
    "boceto": "bo-ce-to",
    "bocezar": "bo-ce-zar",
    "bocezo": "bo-ce-zo",
    "bocha": "bo-cha",
    "bochar": "bo-char",
    "bochazo": "bo-cha-zo",
    "boche": "bo-che",
    "bochichar": "bo-chi-char",
    "bochín": "bo-chín",
    "bochinche": "bo-chin-che",
    "bochinchera": "bo-chin-che-ra",
    "bochinchero": "bo-chin-che-ro",
    "bochista": "bo-chis-ta",
    "bocho": "bo-cho",
    "bochón": "bo-chón",
    "bochorno": "bo-chor-no",
    "bochornosa": "bo-chor-no-sa",
    "bochornoso": "bo-chor-no-so",
    "bocín": "bo-cín",
    "bocina": "bo-ci-na",
    "bocinar": "bo-ci-nar",
    "bocinazo": "bo-ci-na-zo",
    "bocinegro": "bo-ci-ne-gro",
    "bocinero": "bo-ci-ne-ro",
    "bocio": "bo-cio",
    "bocón": "bo-cón",
    "bocona": "bo-co-na",
    "boconada": "bo-co-na-da",
    "bocotá": "bo-co-tá",
    "bocoy": "bo-coy",
    "bocuda": "bo-cu-da",
    "bocudo": "bo-cu-do",
    "boda": "bo-da",
    "bode": "bo-de",
    "bodega": "bo-de-ga",
    "bodegaje": "bo-de-ga-je",
    "bodego": "bo-de-go",
    "bodegón": "bo-de-gón",
    "bodegoncillo": "bo-de-gon-ci-llo",
    "bodegonera": "bo-de-go-ne-ra",
    "bodegonero": "bo-de-go-ne-ro",
    "bodegonista": "bo-de-go-nis-ta",
    "bodeguera": "bo-de-gue-ra",
    "bodeguero": "bo-de-gue-ro",
    "bodigo": "bo-di-go",
    "bodijo": "bo-di-jo",
    "bodocal": "bo-do-cal",
    "bodocazo": "bo-do-ca-zo",
    "bodollo": "bo-do-llo",
    "bodón": "bo-dón",
    "bodonal": "bo-do-nal",
    "bodoque": "bo-do-que",
    "bodoquera": "bo-do-que-ra",
    "bodorrio": "bo-do-rrio",
    "bodrio": "bo-drio",
    "bóer": "bó-er",
    "boezuelo": "bo-e-zue-lo",
    "bofa": "bo-fa",
    "bofar": "bo-far",
    "bofe": "bo-fe",
    "bofena": "bo-fe-na",
    "bofeña": "bo-fe-ña",
    "bófeta": "bó-fe-ta",
    "bofetada": "bo-fe-ta-da",
    "bofetán": "bo-fe-tán",
    "bofetón": "bo-fe-tón",
    "bofia": "bo-fia",
    "bofo": "bo-fo",
    "boga": "bo-ga",
    "bogada": "bo-ga-da",
    "bogador": "bo-ga-dor",
    "bogadora": "bo-ga-do-ra",
    "bogar": "bo-gar",
    "bogavante": "bo-ga-van-te",
    "bogey": "bo-gey",
    "bogie": "bo-gie",
    "bogotana": "bo-go-ta-na",
    "bogotano": "bo-go-ta-no",
    "bogueta": "bo-gue-ta",
    "bohardilla": "bo-har-di-lla",
    "bohema": "bo-he-ma",
    "bohemia": "bo-he-mia",
    "bohemiana": "bo-he-mia-na",
    "bohemiano": "bo-he-mia-no",
    "bohémica": "bo-hé-mi-ca",
    "bohémico": "bo-hé-mi-co",
    "bohemio": "bo-he-mio",
    "bohemo": "bo-he-mo",
    "bohena": "bo-he-na",
    "boheña": "bo-he-ña",
    "bohío": "bo-hí-o",
    "bohíque": "bo-hí-que",
    "bohonería": "bo-ho-ne-rí-a",
    "bohonero": "bo-ho-ne-ro",
    "bohordar": "bo-hor-dar",
    "bohordo": "bo-hor-do",
    "bohrio": "boh-rio",
    "boicot": "boi-cot",
    "boicoteador": "boi-co-te-a-dor",
    "boicotear": "boi-co-te-ar",
    "boicoteo": "boi-co-te-o",
    "boido": "boi-do",
    "boíl": "bo-íl",
    "boina": "boi-na",
    "boira": "boi-ra",
    "boite": "boi-te",
    "boja": "bo-ja",
    "bojar": "bo-jar",
    "bojazo": "bo-ja-zo",
    "boje": "bo-je",
    "bojear": "bo-je-ar",
    "bojedal": "bo-je-dal",
    "bojeo": "bo-je-o",
    "bojiganga": "bo-ji-gan-ga",
    "bojo": "bo-jo",
    "bojote": "bo-jo-te",
    "bojotero": "bo-jo-te-ro",
    "bola": "bo-la",
    "bolacear": "bo-la-ce-ar",
    "bolacera": "bo-la-ce-ra",
    "bolacero": "bo-la-ce-ro",
    "bolacha": "bo-la-cha",
    "bolada": "bo-la-da",
    "bolado": "bo-la-do",
    "bolaga": "bo-la-ga",
    "bolagar": "bo-la-gar",
    "bolandista": "bo-lan-dis-ta",
    "bolañega": "bo-la-ñe-ga",
    "bolañego": "bo-la-ñe-go",
    "bolaño": "bo-la-ño",
    "bolar": "bo-lar",
    "bolardo": "bo-lar-do",
    "bolastristes": "bo-las-tris-tes",
    "bolazo": "bo-la-zo",
    "bolchaca": "bol-cha-ca",
    "bolche": "bol-che",
    "bolchevique": "bol-che-vi-que",
    "bolcheviquismo": "bol-che-vi-quis-mo",
    "bolchevismo": "bol-che-vis-mo",
    "bolchevización": "bol-che-vi-za-ción",
    "bolchevizar": "bol-che-vi-zar",
    "boldina": "bol-di-na",
    "boldo": "bol-do",
    "boleada": "bo-le-a-da",
    "boleado": "bo-le-a-do",
    "boleador": "bo-le-a-dor",
    "boleadora": "bo-le-a-do-ra",
    "boleadoras": "bo-le-a-do-ras",
    "bolear": "bo-le-ar",
    "bolencia": "bo-len-cia",
    "boleo": "bo-le-o",
    "bolera": "bo-le-ra",
    "boleras": "bo-le-ras",
    "bolerear": "bo-le-re-ar",
    "bolerista": "bo-le-ris-ta",
    "bolero": "bo-le-ro",
    "boleta": "bo-le-ta",
    "boletar": "bo-le-tar",
    "boletear": "bo-le-te-ar",
    "boleteo": "bo-le-te-o",
    "boletera": "bo-le-te-ra",
    "boletería": "bo-le-te-rí-a",
    "boletero": "bo-le-te-ro",
    "boletín": "bo-le-tín",
    "boletinar": "bo-le-ti-nar",
    "boleto": "bo-le-to",
    "boli": "bo-li",
    "boliaco": "bo-lia-co",
    "bolichada": "bo-li-cha-da",
    "boliche": "bo-li-che",
    "bolichear": "bo-li-che-ar",
    "bolicheo": "bo-li-che-o",
    "bolichera": "bo-li-che-ra",
    "bolichero": "bo-li-che-ro",
    "bolicho": "bo-li-cho",
    "bólido": "bó-li-do",
    "bolígrafo": "bo-lí-gra-fo",
    "bolihoyo": "bo-liho-yo",
    "bolilla": "bo-li-lla",
    "bolillero": "bo-li-lle-ro",
    "bolillo": "bo-li-llo",
    "bolín": "bo-lín",
    "bolina": "bo-li-na",
    "bolincha": "bo-lin-cha",
    "bolinche": "bo-lin-che",
    "bolindre": "bo-lin-dre",
    "bolineador": "bo-li-ne-a-dor",
    "bolineadora": "bo-li-ne-a-do-ra",
    "bolinear": "bo-li-ne-ar",
    "bolinera": "bo-li-ne-ra",
    "bolinero": "bo-li-ne-ro",
    "bolinga": "bo-lin-ga",
    "bolisa": "bo-li-sa",
    "bolita": "bo-li-ta",
    "bolívar": "bo-lí-var",
    "bolivarense": "bo-li-va-ren-se",
    "bolivariana": "bo-li-va-ria-na",
    "bolivariano": "bo-li-va-ria-no",
    "boliviana": "bo-li-via-na",
    "bolivianismo": "bo-li-via-nis-mo",
    "boliviano": "bo-li-via-no",
    "bolla": "bo-lla",
    "bolladura": "bo-lla-du-ra",
    "bollar": "bo-llar",
    "bollecer": "bo-lle-cer",
    "bollén": "bo-llén",
    "bollera": "bo-lle-ra",
    "bollería": "bo-lle-rí-a",
    "bollero": "bo-lle-ro",
    "bolliciar": "bo-lli-ciar",
    "bollicio": "bo-lli-cio",
    "bollir": "bo-llir",
    "bollo": "bo-llo",
    "bollón": "bo-llón",
    "bollonada": "bo-llo-na-da",
    "bollonado": "bo-llo-na-do",
    "bolo": "bo-lo",
    "bololo": "bo-lo-lo",
    "bolón": "bo-lón",
    "bolondrón": "bo-lon-drón",
    "boloñés": "bo-lo-ñés",
    "boloñesa": "bo-lo-ñe-sa",
    "bolonio": "bo-lo-nio",
    "bolsa": "bol-sa",
    "bolsada": "bol-sa-da",
    "bolseada": "bol-se-a-da",
    "bolseador": "bol-se-a-dor",
    "bolsear": "bol-se-ar",
    "bolsera": "bol-se-ra",
    "bolsería": "bol-se-rí-a",
    "bolsero": "bol-se-ro",
    "bolsico": "bol-si-co",
    "bolsicón": "bol-si-cón",
    "bolsillo": "bol-si-llo",
    "bolsilluda": "bol-si-llu-da",
    "bolsilludo": "bol-si-llu-do",
    "bolsín": "bol-sín",
    "bolsiquear": "bol-si-que-ar",
    "bolsista": "bol-sis-ta",
    "bolso": "bol-so",
    "bolsón": "bol-són",
    "bolsor": "bol-sor",
    "boluda": "bo-lu-da",
    "boludear": "bo-lu-de-ar",
    "boludencia": "bo-lu-den-cia",
    "boludez": "bo-lu-dez",
    "boludo": "bo-lu-do",
    "bomba": "bom-ba",
    "bombacácea": "bom-ba-cá-ce-a",
    "bombacáceo": "bom-ba-cá-ce-o",
    "bombácea": "bom-bá-ce-a",
    "bombáceo": "bom-bá-ce-o",
    "bombacha": "bom-ba-cha",
    "bombacho": "bom-ba-cho",
    "bombachudo": "bom-ba-chu-do",
    "bombarda": "bom-bar-da",
    "bombardear": "bom-bar-de-ar",
    "bombardeo": "bom-bar-de-o",
    "bombardera": "bom-bar-de-ra",
    "bombardero": "bom-bar-de-ro",
    "bombardino": "bom-bar-di-no",
    "bombardón": "bom-bar-dón",
    "bombasí": "bom-ba-sí",
    "bombástica": "bom-bás-ti-ca",
    "bombástico": "bom-bás-ti-co",
    "bombazo": "bom-ba-zo",
    "bombé": "bom-bé",
    "bombear": "bom-be-ar",
    "bombeo": "bom-be-o",
    "bombera": "bom-be-ra",
    "bomberito": "bom-be-ri-to",
    "bombero": "bom-be-ro",
    "bombeta": "bom-be-ta",
    "bómbice": "bóm-bi-ce",
    "bombilla": "bom-bi-lla",
    "bombillo": "bom-bi-llo",
    "bombín": "bom-bín",
    "bombo": "bom-bo",
    "bombón": "bom-bón",
    "bombona": "bom-bo-na",
    "bombonaje": "bom-bo-na-je",
    "bombonera": "bom-bo-ne-ra",
    "bombonería": "bom-bo-ne-rí-a",
    "bomborombillos": "bom-bo-rom-bi-llos",
    "bona": "bo-na",
    "bonachón": "bo-na-chón",
    "bonachona": "bo-na-cho-na",
    "bonachonería": "bo-na-cho-ne-rí-a",
    "bonaense": "bo-na-en-se",
    "bonaerense": "bo-na-e-ren-se",
    "bonal": "bo-nal",
    "bonancible": "bo-nan-ci-ble",
    "bonanza": "bo-nan-za",
    "bonanzosa": "bo-nan-zo-sa",
    "bonanzoso": "bo-nan-zo-so",
    "bonapartismo": "bo-na-par-tis-mo",
    "bonapartista": "bo-na-par-tis-ta",
    "bonasí": "bo-na-sí",
    "bonaventuriano": "bo-na-ven-tu-ria-no",
    "bonche": "bon-che",
    "bondad": "bon-dad",
    "bondadosa": "bon-da-do-sa",
    "bondadosamente": "bon-da-do-sa-men-te",
    "bondadoso": "bon-da-do-so",
    "bondiola": "bon-dio-la",
    "bondosa": "bon-do-sa",
    "bondoso": "bon-do-so",
    "boneta": "bo-ne-ta",
    "bonetada": "bo-ne-ta-da",
    "bonetazo": "bo-ne-ta-zo",
    "bonete": "bo-ne-te",
    "bonetera": "bo-ne-te-ra",
    "bonetería": "bo-ne-te-rí-a",
    "bonetero": "bo-ne-te-ro",
    "bonetillo": "bo-ne-ti-llo",
    "bonga": "bon-ga",
    "bongo": "bon-go",
    "bongó": "bon-gó",
    "bongosera": "bon-go-se-ra",
    "bongosero": "bon-go-se-ro",
    "bonguero": "bon-gue-ro",
    "bonhomía": "bon-ho-mí-a",
    "bonhotel": "bon-ho-tel",
    "boniatillo": "bo-nia-ti-llo",
    "boniato": "bo-nia-to",
    "bonico": "bo-ni-co",
    "bonificación": "bo-ni-fi-ca-ción",
    "bonificar": "bo-ni-fi-car",
    "bonificativa": "bo-ni-fi-ca-ti-va",
    "bonificativo": "bo-ni-fi-ca-ti-vo",
    "boñiga": "bo-ñi-ga",
    "boñigar": "bo-ñi-gar",
    "boñigo": "bo-ñi-go",
    "boñiguero": "bo-ñi-gue-ro",
    "bonilla": "bo-ni-lla",
    "bonillo": "bo-ni-llo",
    "bonina": "bo-ni-na",
    "bonísima": "bo-ní-si-ma",
    "bonísimo": "bo-ní-si-mo",
    "bonista": "bo-nis-ta",
    "bonita": "bo-ni-ta",
    "bonítalo": "bo-ní-ta-lo",
    "bonitamente": "bo-ni-ta-men-te",
    "bonitera": "bo-ni-te-ra",
    "bonitero": "bo-ni-te-ro",
    "bonito": "bo-ni-to",
    "bonitura": "bo-ni-tu-ra",
    "bonizal": "bo-ni-zal",
    "bonizo": "bo-ni-zo",
    "bono": "bo-no",
    "bonobús": "bo-no-bús",
    "bonoloto": "bo-no-lo-to",
    "bononiense": "bo-no-nien-se",
    "bonote": "bo-no-te",
    "bonotel": "bo-no-tel",
    "bonotrén": "bo-no-trén",
    "bonsái": "bon-sái",
    "bonzo": "bon-zo",
    "book": "bo-ok",
    "boom": "bo-om",
    "boomerang": "bo-o-me-rang",
    "boque": "bo-que",
    "boqueada": "bo-que-a-da",
    "boquear": "bo-que-ar",
    "boquera": "bo-que-ra",
    "boquerón": "bo-que-rón",
    "boquerona": "bo-que-ro-na",
    "boqueronense": "bo-que-ro-nen-se",
    "boqueta": "bo-que-ta",
    "boquete": "bo-que-te",
    "boquetero": "bo-que-te-ro",
    "boqueto": "bo-que-to",
    "boqui": "bo-qui",
    "boquiabierta": "bo-quia-bier-ta",
    "boquiabierto": "bo-quia-bier-to",
    "boquiancha": "bo-quian-cha",
    "boquiancho": "bo-quian-cho",
    "boquiangosta": "bo-quian-gos-ta",
    "boquiangosto": "bo-quian-gos-to",
    "boquiblanda": "bo-qui-blan-da",
    "boquiblando": "bo-qui-blan-do",
    "boquiconejuna": "bo-qui-co-ne-ju-na",
    "boquiconejuno": "bo-qui-co-ne-ju-no",
    "boquidulce": "bo-qui-dul-ce",
    "boquidura": "bo-qui-du-ra",
    "boquiduro": "bo-qui-du-ro",
    "boquifloja": "bo-qui-flo-ja",
    "boquiflojo": "bo-qui-flo-jo",
    "boquifresca": "bo-qui-fres-ca",
    "boquifresco": "bo-qui-fres-co",
    "boquifruncida": "bo-qui-frun-ci-da",
    "boquifruncido": "bo-qui-frun-ci-do",
    "boquihendida": "bo-quihen-di-da",
    "boquihendido": "bo-quihen-di-do",
    "boquihundida": "bo-quihun-di-da",
    "boquihundido": "bo-quihun-di-do",
    "boquilla": "bo-qui-lla",
    "boquillera": "bo-qui-lle-ra",
    "boquillero": "bo-qui-lle-ro",
    "boquimuelle": "bo-qui-mue-lle",
    "boquín": "bo-quín",
    "boquina": "bo-qui-na",
    "boquinatural": "bo-qui-na-tu-ral",
    "boquinche": "bo-quin-che",
    "boquinegra": "bo-qui-ne-gra",
    "boquinegro": "bo-qui-ne-gro",
    "boquineto": "bo-qui-ne-to",
    "boquino": "bo-qui-no",
    "boquique": "bo-qui-que",
    "boquirrasgada": "bo-qui-rras-ga-da",
    "boquirrasgado": "bo-qui-rras-ga-do",
    "boquirrota": "bo-qui-rro-ta",
    "boquirroto": "bo-qui-rro-to",
    "boquirrubia": "bo-qui-rru-bia",
    "boquirrubio": "bo-qui-rru-bio",
    "boquiseca": "bo-qui-se-ca",
    "boquiseco": "bo-qui-se-co",
    "boquisucia": "bo-qui-su-cia",
    "boquisucio": "bo-qui-su-cio",
    "boquisumida": "bo-qui-su-mi-da",
    "boquisumido": "bo-qui-su-mi-do",
    "boquitorcida": "bo-qui-tor-ci-da",
    "boquitorcido": "bo-qui-tor-ci-do",
    "boquituerta": "bo-qui-tuer-ta",
    "boquituerto": "bo-qui-tuer-to",
    "boratera": "bo-ra-te-ra",
    "boratero": "bo-ra-te-ro",
    "borato": "bo-ra-to",
    "bórax": "bó-rax",
    "borbolla": "bor-bo-lla",
    "borbollar": "bor-bo-llar",
    "borbollear": "bor-bo-lle-ar",
    "borbolleo": "bor-bo-lle-o",
    "borbollón": "bor-bo-llón",
    "borbollonear": "bor-bo-llo-ne-ar",
    "borbónica": "bor-bó-ni-ca",
    "borbónico": "bor-bó-ni-co",
    "borbor": "bor-bor",
    "borborigmo": "bor-bo-rig-mo",
    "borboritar": "bor-bo-ri-tar",
    "borborito": "bor-bo-ri-to",
    "borbotar": "bor-bo-tar",
    "borbotear": "bor-bo-te-ar",
    "borboteo": "bor-bo-te-o",
    "borbotón": "bor-bo-tón",
    "borceguí": "bor-ce-guí",
    "borceguinera": "bor-ce-gui-ne-ra",
    "borceguinería": "bor-ce-gui-ne-rí-a",
    "borceguinero": "bor-ce-gui-ne-ro",
    "borcelana": "bor-ce-la-na",
    "borcelano": "bor-ce-la-no",
    "borcellar": "bor-ce-llar",
    "borda": "bor-da",
    "bordada": "bor-da-da",
    "bordadillo": "bor-da-di-llo",
    "bordado": "bor-da-do",
    "bordador": "bor-da-dor",
    "bordadora": "bor-da-do-ra",
    "bordadura": "bor-da-du-ra",
    "bordalesa": "bor-da-le-sa",
    "bordar": "bor-dar",
    "borde": "bor-de",
    "bordear": "bor-de-ar",
    "bordelés": "bor-de-lés",
    "bordelesa": "bor-de-le-sa",
    "bordillo": "bor-di-llo",
    "bordiona": "bor-dio-na",
    "bordo": "bor-do",
    "bordón": "bor-dón",
    "bordona": "bor-do-na",
    "bordoncillo": "bor-don-ci-llo",
    "bordonear": "bor-do-ne-ar",
    "bordoneo": "bor-do-ne-o",
    "bordonera": "bor-do-ne-ra",
    "bordonería": "bor-do-ne-rí-a",
    "bordonero": "bor-do-ne-ro",
    "bordura": "bor-du-ra",
    "boreal": "bo-re-al",
    "bóreas": "bó-re-as",
    "bóreo": "bó-re-o",
    "borgeano": "bor-ge-a-no",
    "borgiano": "bor-gia-no",
    "borgoña": "bor-go-ña",
    "borgoñés": "bor-go-ñés",
    "borgoñón": "bor-go-ñón",
    "borgoñona": "bor-go-ño-na",
    "borgoñota": "bor-go-ño-ta",
    "borguil": "bor-guil",
    "boria": "bo-ria",
    "boricada": "bo-ri-ca-da",
    "boricado": "bo-ri-ca-do",
    "bórico": "bó-ri-co",
    "boricua": "bo-ri-cua",
    "borincano": "bo-rin-ca-no",
    "borinqueña": "bo-rin-que-ña",
    "borinqueño": "bo-rin-que-ño",
    "borla": "bor-la",
    "borlar": "bor-lar",
    "borlilla": "bor-li-lla",
    "borlón": "bor-lón",
    "borlote": "bor-lo-te",
    "borlotera": "bor-lo-te-ra",
    "borlotero": "bor-lo-te-ro",
    "borna": "bor-na",
    "borne": "bor-ne",
    "borneadiza": "bor-ne-a-di-za",
    "borneadizo": "bor-ne-a-di-zo",
    "borneadura": "bor-ne-a-du-ra",
    "bornear": "bor-ne-ar",
    "borneo": "bor-ne-o",
    "bornera": "bor-ne-ra",
    "bornero": "bor-ne-ro",
    "borní": "bor-ní",
    "bornizo": "bor-ni-zo",
    "boro": "bo-ro",
    "borona": "bo-ro-na",
    "borondanga": "bo-ron-dan-ga",
    "boronero": "bo-ro-ne-ro",
    "boronía": "bo-ro-ní-a",
    "borra": "bo-rra",
    "borracha": "bo-rra-cha",
    "borrachada": "bo-rra-cha-da",
    "borrachales": "bo-rra-cha-les",
    "borrachear": "bo-rra-che-ar",
    "borrachera": "bo-rra-che-ra",
    "borrachería": "bo-rra-che-rí-a",
    "borrachero": "bo-rra-che-ro",
    "borrachez": "bo-rra-chez",
    "borrachín": "bo-rra-chín",
    "borrachina": "bo-rra-chi-na",
    "borracho": "bo-rra-cho",
    "borrachómetro": "bo-rra-chó-me-tro",
    "borrachuela": "bo-rra-chue-la",
    "borrachuza": "bo-rra-chu-za",
    "borrachuzo": "bo-rra-chu-zo",
    "borrada": "bo-rra-da",
    "borrado": "bo-rra-do",
    "borrador": "bo-rra-dor",
    "borradora": "bo-rra-do-ra",
    "borradura": "bo-rra-du-ra",
    "borraginácea": "bo-rra-gi-ná-ce-a",
    "borragináceo": "bo-rra-gi-ná-ce-o",
    "borragínea": "bo-rra-gí-ne-a",
    "borragíneo": "bo-rra-gí-ne-o",
    "borraj": "bo-rraj",
    "borraja": "bo-rra-ja",
    "borrajear": "bo-rra-je-ar",
    "borrajo": "bo-rra-jo",
    "borrar": "bo-rrar",
    "borrasca": "bo-rras-ca",
    "borrascosa": "bo-rras-co-sa",
    "borrascosamente": "bo-rras-co-sa-men-te",
    "borrascoso": "bo-rras-co-so",
    "borrasquera": "bo-rras-que-ra",
    "borrasquero": "bo-rras-que-ro",
    "borrega": "bo-rre-ga",
    "borregada": "bo-rre-ga-da",
    "borrego": "bo-rre-go",
    "borreguera": "bo-rre-gue-ra",
    "borreguero": "bo-rre-gue-ro",
    "borreguil": "bo-rre-guil",
    "borreguismo": "bo-rre-guis-mo",
    "borrén": "bo-rrén",
    "borrero": "bo-rre-ro",
    "borrica": "bo-rri-ca",
    "borricada": "bo-rri-ca-da",
    "borrical": "bo-rri-cal",
    "borrico": "bo-rri-co",
    "borricón": "bo-rri-cón",
    "borricote": "bo-rri-co-te",
    "borrina": "bo-rri-na",
    "borriqueña": "bo-rri-que-ña",
    "borriqueño": "bo-rri-que-ño",
    "borriquero": "bo-rri-que-ro",
    "borriqueta": "bo-rri-que-ta",
    "borriquete": "bo-rri-que-te",
    "borro": "bo-rro",
    "borrominesco": "bo-rro-mi-nes-co",
    "borrón": "bo-rrón",
    "borroncillo": "bo-rron-ci-llo",
    "borronear": "bo-rro-ne-ar",
    "borroñoso": "bo-rro-ño-so",
    "borrosa": "bo-rro-sa",
    "borrosamente": "bo-rro-sa-men-te",
    "borrosidad": "bo-rro-si-dad",
    "borroso": "bo-rro-so",
    "borrufalla": "bo-rru-fa-lla",
    "borrumbada": "bo-rrum-ba-da",
    "borsalino": "bor-sa-li-no",
    "bortal": "bor-tal",
    "borto": "bor-to",
    "boruca": "bo-ru-ca",
    "boruga": "bo-ru-ga",
    "borujo": "bo-ru-jo",
    "borujón": "bo-ru-jón",
    "borundés": "bo-run-dés",
    "borundesa": "bo-run-de-sa",
    "boruquienta": "bo-ru-quien-ta",
    "boruquiento": "bo-ru-quien-to",
    "boruro": "bo-ru-ro",
    "borusca": "bo-rus-ca",
    "bosadilla": "bo-sa-di-lla",
    "bosar": "bo-sar",
    "boscaje": "bos-ca-je",
    "boscosa": "bos-co-sa",
    "boscoso": "bos-co-so",
    "bósforo": "bós-fo-ro",
    "boshito": "bos-hi-to",
    "bosnia": "bos-nia",
    "bosníaca": "bos-ní-a-ca",
    "bosniaca": "bos-nia-ca",
    "bosníaco": "bos-ní-a-co",
    "bosniaco": "bos-nia-co",
    "bosnio": "bos-nio",
    "bosón": "bo-són",
    "bosque": "bos-que",
    "bosquejar": "bos-que-jar",
    "bosquejo": "bos-que-jo",
    "bosquete": "bos-que-te",
    "bosquimán": "bos-qui-mán",
    "bosquimana": "bos-qui-ma-na",
    "bosquimano": "bos-qui-ma-no",
    "bossa": "bos-sa",
    "bosta": "bos-ta",
    "bostar": "bos-tar",
    "bostear": "bos-te-ar",
    "bostezador": "bos-te-za-dor",
    "bostezadora": "bos-te-za-do-ra",
    "bostezar": "bos-te-zar",
    "bostezo": "bos-te-zo",
    "bosticar": "bos-ti-car",
    "bostoniana": "bos-to-nia-na",
    "bostoniano": "bos-to-nia-no",
    "bota": "bo-ta",
    "botada": "bo-ta-da",
    "botadero": "bo-ta-de-ro",
    "botado": "bo-ta-do",
    "botador": "bo-ta-dor",
    "botadora": "bo-ta-do-ra",
    "botadura": "bo-ta-du-ra",
    "botafuego": "bo-ta-fue-go",
    "botafumeiro": "bo-ta-fu-mei-ro",
    "botagua": "bo-ta-gua",
    "botagueña": "bo-ta-gue-ña",
    "botaina": "bo-tai-na",
    "botalomo": "bo-ta-lo-mo",
    "botalón": "bo-ta-lón",
    "botamanga": "bo-ta-man-ga",
    "botamay": "bo-ta-may",
    "botamen": "bo-ta-men",
    "botana": "bo-ta-na",
    "botanear": "bo-ta-ne-ar",
    "botánica": "bo-tá-ni-ca",
    "botánico": "bo-tá-ni-co",
    "botanista": "bo-ta-nis-ta",
    "botar": "bo-tar",
    "botarata": "bo-ta-ra-ta",
    "botaratada": "bo-ta-ra-ta-da",
    "botaratas": "bo-ta-ra-tas",
    "botarate": "bo-ta-ra-te",
    "botarel": "bo-ta-rel",
    "botarete": "bo-ta-re-te",
    "botarga": "bo-tar-ga",
    "botasilla": "bo-ta-si-lla",
    "botavante": "bo-ta-van-te",
    "botavara": "bo-ta-va-ra",
    "bote": "bo-te",
    "boteal": "bo-te-al",
    "botear": "bo-te-ar",
    "botecario": "bo-te-ca-rio",
    "boteja": "bo-te-ja",
    "botella": "bo-te-lla",
    "botellazo": "bo-te-lla-zo",
    "botellera": "bo-te-lle-ra",
    "botellero": "bo-te-lle-ro",
    "botellín": "bo-te-llín",
    "botellita": "bo-te-lli-ta",
    "botellón": "bo-te-llón",
    "botepronto": "bo-te-pron-to",
    "botería": "bo-te-rí-a",
    "botero": "bo-te-ro",
    "botica": "bo-ti-ca",
    "boticaje": "bo-ti-ca-je",
    "boticaria": "bo-ti-ca-ria",
    "boticario": "bo-ti-ca-rio",
    "botifarra": "bo-ti-fa-rra",
    "botiga": "bo-ti-ga",
    "botiguera": "bo-ti-gue-ra",
    "botiguero": "bo-ti-gue-ro",
    "botija": "bo-ti-ja",
    "botijera": "bo-ti-je-ra",
    "botijero": "bo-ti-je-ro",
    "botijo": "bo-ti-jo",
    "botijón": "bo-ti-jón",
    "botijona": "bo-ti-jo-na",
    "botijuela": "bo-ti-jue-la",
    "botilla": "bo-ti-lla",
    "botiller": "bo-ti-ller",
    "botillería": "bo-ti-lle-rí-a",
    "botillero": "bo-ti-lle-ro",
    "botillo": "bo-ti-llo",
    "botín": "bo-tín",
    "botina": "bo-ti-na",
    "botinera": "bo-ti-ne-ra",
    "botinería": "bo-ti-ne-rí-a",
    "botinero": "bo-ti-ne-ro",
    "botionda": "bo-tion-da",
    "botiondo": "bo-tion-do",
    "botiquería": "bo-ti-que-rí-a",
    "botiquín": "bo-ti-quín",
    "botito": "bo-ti-to",
    "botivoleo": "bo-ti-vo-le-o",
    "boto": "bo-to",
    "botocuda": "bo-to-cu-da",
    "botocudo": "bo-to-cu-do",
    "botón": "bo-tón",
    "botonadura": "bo-to-na-du-ra",
    "botonaza": "bo-to-na-za",
    "botonazo": "bo-to-na-zo",
    "botonear": "bo-to-ne-ar",
    "botonera": "bo-to-ne-ra",
    "botonería": "bo-to-ne-rí-a",
    "botonero": "bo-to-ne-ro",
    "botones": "bo-to-nes",
    "botor": "bo-tor",
    "botoral": "bo-to-ral",
    "botosa": "bo-to-sa",
    "botoso": "bo-to-so",
    "bototo": "bo-to-to",
    "botrino": "bo-tri-no",
    "botsuana": "bot-sua-na",
    "botsuano": "bot-sua-no",
    "botulismo": "bo-tu-lis-mo",
    "botuto": "bo-tu-to",
    "boutade": "bou-ta-de",
    "boutique": "bou-ti-que",
    "bovaje": "bo-va-je",
    "bovático": "bo-vá-ti-co",
    "bóveda": "bó-ve-da",
    "bovedilla": "bo-ve-di-lla",
    "bóvido": "bó-vi-do",
    "bovina": "bo-vi-na",
    "bovino": "bo-vi-no",
    "boxeador": "bo-xe-a-dor",
    "boxeadora": "bo-xe-a-do-ra",
    "boxear": "bo-xe-ar",
    "boxeo": "bo-xe-o",
    "bóxer": "bó-xer",
    "boxístico": "bo-xís-ti-co",
    "boxita": "bo-xi-ta",
    "boxito": "bo-xi-to",
    "boya": "bo-ya",
    "boyacense": "bo-ya-cen-se",
    "boyada": "bo-ya-da",
    "boyal": "bo-yal",
    "boyante": "bo-yan-te",
    "boyar": "bo-yar",
    "boyarda": "bo-yar-da",
    "boyardo": "bo-yar-do",
    "boyarín": "bo-ya-rín",
    "boyera": "bo-ye-ra",
    "boyeriza": "bo-ye-ri-za",
    "boyerizo": "bo-ye-ri-zo",
    "boyero": "bo-ye-ro",
    "boyuna": "bo-yu-na",
    "boyuno": "bo-yu-no",
    "boza": "bo-za",
    "bozal": "bo-zal",
    "bozalear": "bo-za-le-ar",
    "bozalejo": "bo-za-le-jo",
    "bozalillo": "bo-za-li-llo",
    "bozo": "bo-zo",
    "bozón": "bo-zón",
    "bozorola": "bo-zo-ro-la",
    "brabante": "bra-ban-te",
    "brabántico": "bra-bán-ti-co",
    "brabanzón": "bra-ban-zón",
    "brabanzona": "bra-ban-zo-na",
    "braca": "bra-ca",
    "bracamarte": "bra-ca-mar-te",
    "bracarense": "bra-ca-ren-se",
    "braceada": "bra-ce-a-da",
    "braceador": "bra-ce-a-dor",
    "braceadora": "bra-ce-a-do-ra",
    "braceaje": "bra-ce-a-je",
    "bracear": "bra-ce-ar",
    "braceo": "bra-ce-o",
    "bracera": "bra-ce-ra",
    "braceral": "bra-ce-ral",
    "bracero": "bra-ce-ro",
    "bracete": "bra-ce-te",
    "bracil": "bra-cil",
    "bracillo": "bra-ci-llo",
    "bracista": "bra-cis-ta",
    "bracmán": "brac-mán",
    "braco": "bra-co",
    "bráctea": "brác-te-a",
    "bractéola": "brac-té-o-la",
    "bradicardia": "bra-di-car-dia",
    "bradilalia": "bra-di-la-lia",
    "bradipepsia": "bra-di-pep-sia",
    "bradita": "bra-di-ta",
    "brafonera": "bra-fo-ne-ra",
    "braga": "bra-ga",
    "bragada": "bra-ga-da",
    "bragado": "bra-ga-do",
    "bragadura": "bra-ga-du-ra",
    "bragapañal": "bra-ga-pa-ñal",
    "bragazas": "bra-ga-zas",
    "braguero": "bra-gue-ro",
    "bragueta": "bra-gue-ta",
    "braguetazo": "bra-gue-ta-zo",
    "braguetero": "bra-gue-te-ro",
    "braguillas": "bra-gui-llas",
    "brahmán": "brah-mán",
    "brahmánico": "brah-má-ni-co",
    "brahmanismo": "brah-ma-nis-mo",
    "brahmín": "brah-mín",
    "brahón": "bra-hón",
    "brahonera": "bra-ho-ne-ra",
    "braille": "brai-lle",
    "brama": "bra-ma",
    "bramadera": "bra-ma-de-ra",
    "bramadero": "bra-ma-de-ro",
    "bramador": "bra-ma-dor",
    "bramadora": "bra-ma-do-ra",
    "bramante": "bra-man-te",
    "bramar": "bra-mar",
    "bramido": "bra-mi-do",
    "bramona": "bra-mo-na",
    "bramuras": "bra-mu-ras",
    "braña": "bra-ña",
    "branca": "bran-ca",
    "brancada": "bran-ca-da",
    "brancal": "bran-cal",
    "brandada": "bran-da-da",
    "brandal": "bran-dal",
    "brandi": "bran-di",
    "brandís": "bran-dís",
    "branque": "bran-que",
    "branquia": "bran-quia",
    "branquial": "bran-quial",
    "branquífera": "bran-quí-fe-ra",
    "branquífero": "bran-quí-fe-ro",
    "branquiópodo": "bran-quió-po-do",
    "branquiuro": "bran-quiu-ro",
    "branza": "bran-za",
    "braquiación": "bra-quia-ción",
    "braquiador": "bra-quia-dor",
    "braquiadora": "bra-quia-do-ra",
    "braquial": "bra-quial",
    "braquiar": "bra-quiar",
    "braquicéfala": "bra-qui-cé-fa-la",
    "braquicefalia": "bra-qui-ce-fa-lia",
    "braquicéfalo": "bra-qui-cé-fa-lo",
    "braquícero": "bra-quí-ce-ro",
    "braquigrafía": "bra-qui-gra-fí-a",
    "braquilogía": "bra-qui-lo-gí-a",
    "braquiocefálica": "bra-quio-ce-fá-li-ca",
    "braquiocefálico": "bra-quio-ce-fá-li-co",
    "braquiópodo": "bra-quió-po-do",
    "braquiosaurio": "bra-quio-sau-rio",
    "braquiuro": "bra-quiu-ro",
    "brasa": "bra-sa",
    "brasca": "bras-ca",
    "brasear": "bra-se-ar",
    "braserillo": "bra-se-ri-llo",
    "brasero": "bra-se-ro",
    "brasil": "bra-sil",
    "brasilada": "bra-si-la-da",
    "brasilado": "bra-si-la-do",
    "brasileña": "bra-si-le-ña",
    "brasileño": "bra-si-le-ño",
    "brasilero": "bra-si-le-ro",
    "brasilete": "bra-si-le-te",
    "brasmología": "bras-mo-lo-gí-a",
    "brassavola": "bras-sa-vo-la",
    "brasserie": "bras-se-rie",
    "brava": "bra-va",
    "bravamente": "bra-va-men-te",
    "bravata": "bra-va-ta",
    "bravato": "bra-va-to",
    "braveador": "bra-ve-a-dor",
    "braveadora": "bra-ve-a-do-ra",
    "bravear": "bra-ve-ar",
    "bravera": "bra-ve-ra",
    "bravería": "bra-ve-rí-a",
    "braveza": "bra-ve-za",
    "bravía": "bra-ví-a",
    "bravío": "bra-ví-o",
    "bravo": "bra-vo",
    "bravocear": "bra-vo-ce-ar",
    "bravonel": "bra-vo-nel",
    "bravosa": "bra-vo-sa",
    "bravosía": "bra-vo-sí-a",
    "bravosidad": "bra-vo-si-dad",
    "bravoso": "bra-vo-so",
    "bravote": "bra-vo-te",
    "bravucón": "bra-vu-cón",
    "bravucona": "bra-vu-co-na",
    "bravuconada": "bra-vu-co-na-da",
    "bravuconamente": "bra-vu-co-na-men-te",
    "bravuconear": "bra-vu-co-ne-ar",
    "bravuconería": "bra-vu-co-ne-rí-a",
    "bravura": "bra-vu-ra",
    "braza": "bra-za",
    "brazada": "bra-za-da",
    "brazado": "bra-za-do",
    "brazaje": "bra-za-je",
    "brazal": "bra-zal",
    "brazalete": "bra-za-le-te",
    "braznar": "braz-nar",
    "brazo": "bra-zo",
    "brazola": "bra-zo-la",
    "brazolargo": "bra-zo-lar-go",
    "brazuelo": "bra-zue-lo",
    "brea": "bre-a",
    "break": "bre-ak",
    "brear": "bre-ar",
    "brebaje": "bre-ba-je",
    "brebajo": "bre-ba-jo",
    "breca": "bre-ca",
    "brecha": "bre-cha",
    "brechero": "bre-che-ro",
    "brechtiano": "brech-tia-no",
    "breco": "bre-co",
    "brécol": "bré-col",
    "brecolera": "bre-co-le-ra",
    "brega": "bre-ga",
    "bregadura": "bre-ga-du-ra",
    "bregar": "bre-gar",
    "breguera": "bre-gue-ra",
    "breguero": "bre-gue-ro",
    "brejeta": "bre-je-ta",
    "brejetera": "bre-je-te-ra",
    "brejetero": "bre-je-te-ro",
    "brema": "bre-ma",
    "breña": "bre-ña",
    "breñal": "bre-ñal",
    "breñar": "bre-ñar",
    "brenca": "bren-ca",
    "breñosa": "bre-ño-sa",
    "breñoso": "bre-ño-so",
    "breque": "bre-que",
    "bresca": "bres-ca",
    "brescar": "bres-car",
    "bretador": "bre-ta-dor",
    "bretaña": "bre-ta-ña",
    "brete": "bre-te",
    "breteador": "bre-te-a-dor",
    "bretear": "bre-te-ar",
    "bretel": "bre-tel",
    "bretón": "bre-tón",
    "bretona": "bre-to-na",
    "bretoniana": "bre-to-nia-na",
    "bretoniano": "bre-to-nia-no",
    "bretónica": "bre-tó-ni-ca",
    "breva": "bre-va",
    "breval": "bre-val",
    "breve": "bre-ve",
    "brevedad": "bre-ve-dad",
    "brevemente": "bre-ve-men-te",
    "brevera": "bre-ve-ra",
    "brevete": "bre-ve-te",
    "breviario": "bre-via-rio",
    "brevipenne": "bre-vi-pen-ne",
    "brezal": "bre-zal",
    "brezar": "bre-zar",
    "brezo": "bre-zo",
    "briaga": "bria-ga",
    "briago": "bria-go",
    "briba": "bri-ba",
    "bribar": "bri-bar",
    "bribia": "bri-bia",
    "bribiática": "bri-biá-ti-ca",
    "bribiático": "bri-biá-ti-co",
    "bribión": "bri-bión",
    "bribón": "bri-bón",
    "bribona": "bri-bo-na",
    "bribonada": "bri-bo-na-da",
    "bribonear": "bri-bo-ne-ar",
    "bribonería": "bri-bo-ne-rí-a",
    "bribonesca": "bri-bo-nes-ca",
    "bribonesco": "bri-bo-nes-co",
    "bribri": "bri-bri",
    "bribrí": "bri-brí",
    "bricbarca": "bric-bar-ca",
    "bricho": "bri-cho",
    "bricolaje": "bri-co-la-je",
    "brida": "bri-da",
    "bridecú": "bri-de-cú",
    "bridge": "brid-ge",
    "bridón": "bri-dón",
    "briega": "brie-ga",
    "brigada": "bri-ga-da",
    "brigadero": "bri-ga-de-ro",
    "brigadier": "bri-ga-dier",
    "brigadiera": "bri-ga-die-ra",
    "brigadista": "bri-ga-dis-ta",
    "brigantina": "bri-gan-ti-na",
    "brigantino": "bri-gan-ti-no",
    "brigola": "bri-go-la",
    "briján": "bri-ján",
    "brillador": "bri-lla-dor",
    "brilladora": "bri-lla-do-ra",
    "brillante": "bri-llan-te",
    "brillantemente": "bri-llan-te-men-te",
    "brillantez": "bri-llan-tez",
    "brillantina": "bri-llan-ti-na",
    "brillar": "bri-llar",
    "brillazón": "bri-lla-zón",
    "brillo": "bri-llo",
    "brilloso": "bri-llo-so",
    "brincadero": "brin-ca-de-ro",
    "brincador": "brin-ca-dor",
    "brincadora": "brin-ca-do-ra",
    "brincar": "brin-car",
    "brincho": "brin-cho",
    "brincia": "brin-cia",
    "brinco": "brin-co",
    "brindador": "brin-da-dor",
    "brindadora": "brin-da-do-ra",
    "brindar": "brin-dar",
    "brindis": "brin-dis",
    "briñón": "bri-ñón",
    "brinquillo": "brin-qui-llo",
    "brinquiño": "brin-qui-ño",
    "brinza": "brin-za",
    "brío": "brí-o",
    "briocense": "brio-cen-se",
    "brioche": "brio-che",
    "briofita": "brio-fi-ta",
    "briofito": "brio-fi-to",
    "briofitos": "brio-fi-tos",
    "brionia": "brio-nia",
    "briosa": "brio-sa",
    "briosamente": "brio-sa-men-te",
    "brioso": "brio-so",
    "briozoo": "brio-zo-o",
    "briqueta": "bri-que-ta",
    "brisa": "bri-sa",
    "brisar": "bri-sar",
    "brisca": "bris-ca",
    "briscada": "bris-ca-da",
    "briscado": "bris-ca-do",
    "briscar": "bris-car",
    "brisco": "bris-co",
    "brisera": "bri-se-ra",
    "brisote": "bri-so-te",
    "brístol": "brís-tol",
    "brisura": "bri-su-ra",
    "britana": "bri-ta-na",
    "británica": "bri-tá-ni-ca",
    "británico": "bri-tá-ni-co",
    "britano": "bri-ta-no",
    "briza": "bri-za",
    "brizar": "bri-zar",
    "brizna": "briz-na",
    "briznosa": "briz-no-sa",
    "briznoso": "briz-no-so",
    "broa": "bro-a",
    "broca": "bro-ca",
    "brocada": "bro-ca-da",
    "brocadillo": "bro-ca-di-llo",
    "brocado": "bro-ca-do",
    "brocadura": "bro-ca-du-ra",
    "brocal": "bro-cal",
    "brocalada": "bro-ca-la-da",
    "brocalado": "bro-ca-la-do",
    "brocamantón": "bro-ca-man-tón",
    "brocárdico": "bro-cár-di-co",
    "brocatel": "bro-ca-tel",
    "brocear": "bro-ce-ar",
    "brocearse": "bro-ce-ar-se",
    "brocense": "bro-cen-se",
    "broceo": "bro-ce-o",
    "brocha": "bro-cha",
    "brochada": "bro-cha-da",
    "brochado": "bro-cha-do",
    "brochadura": "bro-cha-du-ra",
    "brochal": "bro-chal",
    "brochazo": "bro-cha-zo",
    "broche": "bro-che",
    "brocheta": "bro-che-ta",
    "brocho": "bro-cho",
    "brochón": "bro-chón",
    "brocino": "bro-ci-no",
    "brócol": "bró-col",
    "brócoli": "bró-co-li",
    "brócul": "bró-cul",
    "bróculi": "bró-cu-li",
    "brodio": "bro-dio",
    "brodista": "bro-dis-ta",
    "broker": "bro-ker",
    "brollador": "bro-lla-dor",
    "brolladora": "bro-lla-do-ra",
    "brollar": "bro-llar",
    "brollo": "bro-llo",
    "broma": "bro-ma",
    "bromación": "bro-ma-ción",
    "bromar": "bro-mar",
    "bromato": "bro-ma-to",
    "bromatóloga": "bro-ma-tó-lo-ga",
    "bromatología": "bro-ma-to-lo-gí-a",
    "bromatológico": "bro-ma-to-ló-gi-co",
    "bromatólogo": "bro-ma-tó-lo-go",
    "bromazo": "bro-ma-zo",
    "bromear": "bro-me-ar",
    "bromeliácea": "bro-me-liá-ce-a",
    "bromeliáceas": "bro-me-liá-ce-as",
    "bromeliáceo": "bro-me-liá-ce-o",
    "bromhídrico": "brom-hí-dri-co",
    "brómico": "bró-mi-co",
    "bromista": "bro-mis-ta",
    "bromo": "bro-mo",
    "bromoso": "bro-mo-so",
    "bromuro": "bro-mu-ro",
    "bronca": "bron-ca",
    "broncamente": "bron-ca-men-te",
    "bronce": "bron-ce",
    "bronceada": "bron-ce-a-da",
    "bronceado": "bron-ce-a-do",
    "bronceador": "bron-ce-a-dor",
    "bronceadura": "bron-ce-a-du-ra",
    "broncear": "bron-ce-ar",
    "broncería": "bron-ce-rí-a",
    "broncha": "bron-cha",
    "broncínea": "bron-cí-ne-a",
    "broncíneo": "bron-cí-ne-o",
    "broncista": "bron-cis-ta",
    "bronco": "bron-co",
    "broncodilatador": "bron-co-di-la-ta-dor",
    "broncografía": "bron-co-gra-fí-a",
    "bronconeumonía": "bron-co-neu-mo-ní-a",
    "broncopatía": "bron-co-pa-tí-a",
    "broncorragia": "bron-co-rra-gia",
    "broncorrea": "bron-co-rre-a",
    "broncoscopia": "bron-cos-co-pia",
    "broncoscopio": "bron-cos-co-pio",
    "bronquedad": "bron-que-dad",
    "bronquial": "bron-quial",
    "bronquiectasia": "bron-quiec-ta-sia",
    "bronquina": "bron-qui-na",
    "bronquio": "bron-quio",
    "bronquíolo": "bron-quí-o-lo",
    "bronquiolo": "bron-quio-lo",
    "bronquítica": "bron-quí-ti-ca",
    "bronquítico": "bron-quí-ti-co",
    "bronquitis": "bron-qui-tis",
    "brontología": "bron-to-lo-gí-a",
    "brontosaurio": "bron-to-sau-rio",
    "bronzo": "bron-zo",
    "broquel": "bro-quel",
    "broquelar": "bro-que-lar",
    "broquelarse": "bro-que-lar-se",
    "broquelazo": "bro-que-la-zo",
    "broquelero": "bro-que-le-ro",
    "broquelillo": "bro-que-li-llo",
    "broqueta": "bro-que-ta",
    "bróquil": "bró-quil",
    "brosla": "bros-la",
    "broslador": "bros-la-dor",
    "brosladura": "bros-la-du-ra",
    "broslar": "bros-lar",
    "brosquil": "bros-quil",
    "brota": "bro-ta",
    "brotación": "bro-ta-ción",
    "brotadura": "bro-ta-du-ra",
    "brótano": "bró-ta-no",
    "brotar": "bro-tar",
    "brote": "bro-te",
    "broto": "bro-to",
    "brótola": "bró-to-la",
    "brotón": "bro-tón",
    "browniano": "brow-nia-no",
    "broza": "bro-za",
    "brozador": "bro-za-dor",
    "brozar": "bro-zar",
    "brozna": "broz-na",
    "broznamente": "broz-na-men-te",
    "broznedad": "broz-ne-dad",
    "brozno": "broz-no",
    "brozosa": "bro-zo-sa",
    "brozoso": "bro-zo-so",
    "brucelosis": "bru-ce-lo-sis",
    "brucero": "bru-ce-ro",
    "bruces": "bru-ces",
    "brucita": "bru-ci-ta",
    "brugo": "bru-go",
    "bruja": "bru-ja",
    "brujeador": "bru-je-a-dor",
    "brujear": "bru-je-ar",
    "brujera": "bru-je-ra",
    "brujería": "bru-je-rí-a",
    "brujeril": "bru-je-ril",
    "brujero": "bru-je-ro",
    "brujesca": "bru-jes-ca",
    "brujesco": "bru-jes-co",
    "brujez": "bru-jez",
    "brujidor": "bru-ji-dor",
    "brujilla": "bru-ji-lla",
    "brujir": "bru-jir",
    "brujo": "bru-jo",
    "brujón": "bru-jón",
    "brujul": "bru-jul",
    "brújula": "brú-ju-la",
    "brujulear": "bru-ju-le-ar",
    "brujuleo": "bru-ju-le-o",
    "brulote": "bru-lo-te",
    "bruma": "bru-ma",
    "brumador": "bru-ma-dor",
    "brumadora": "bru-ma-do-ra",
    "brumal": "bru-mal",
    "brumamiento": "bru-ma-mien-to",
    "brumar": "bru-mar",
    "brumario": "bru-ma-rio",
    "brumazón": "bru-ma-zón",
    "brumo": "bru-mo",
    "brumosa": "bru-mo-sa",
    "brumoso": "bru-mo-so",
    "bruna": "bru-na",
    "brunca": "brun-ca",
    "bruneana": "bru-ne-a-na",
    "bruneano": "bru-ne-a-no",
    "brunela": "bru-ne-la",
    "bruneta": "bru-ne-ta",
    "brunete": "bru-ne-te",
    "bruñido": "bru-ñi-do",
    "bruñidor": "bru-ñi-dor",
    "bruñidora": "bru-ñi-do-ra",
    "bruñidura": "bru-ñi-du-ra",
    "bruñimiento": "bru-ñi-mien-to",
    "bruñir": "bru-ñir",
    "bruno": "bru-no",
    "bruño": "bru-ño",
    "brusca": "brus-ca",
    "bruscadera": "brus-ca-de-ra",
    "bruscamente": "brus-ca-men-te",
    "bruscate": "brus-ca-te",
    "brusco": "brus-co",
    "brusela": "bru-se-la",
    "bruselas": "bru-se-las",
    "bruselense": "bru-se-len-se",
    "brushing": "brus-hing",
    "brusquedad": "brus-que-dad",
    "brusquero": "brus-que-ro",
    "bruta": "bru-ta",
    "brutada": "bru-ta-da",
    "brutal": "bru-tal",
    "brutalidad": "bru-ta-li-dad",
    "brutalismo": "bru-ta-lis-mo",
    "brutalizar": "bru-ta-li-zar",
    "brutalizarse": "bru-ta-li-zar-se",
    "brutalmente": "bru-tal-men-te",
    "brutesca": "bru-tes-ca",
    "brutesco": "bru-tes-co",
    "brutez": "bru-tez",
    "bruteza": "bru-te-za",
    "bruto": "bru-to",
    "bruxismo": "bru-xis-mo",
    "bruza": "bru-za",
    "bruzador": "bru-za-dor",
    "bruzar": "bru-zar",
    "bruzas": "bru-zas",
    "bruzos": "bru-zos",
    "búa": "bú-a",
    "buaro": "bua-ro",
    "buba": "bu-ba",
    "búbala": "bú-ba-la",
    "búbalo": "bú-ba-lo",
    "bubática": "bu-bá-ti-ca",
    "bubático": "bu-bá-ti-co",
    "bubi": "bu-bi",
    "bubón": "bu-bón",
    "bubónica": "bu-bó-ni-ca",
    "bubónico": "bu-bó-ni-co",
    "bubosa": "bu-bo-sa",
    "buboso": "bu-bo-so",
    "bubucha": "bu-bu-cha",
    "bucal": "bu-cal",
    "bucanero": "bu-ca-ne-ro",
    "bucaral": "bu-ca-ral",
    "bucardo": "bu-car-do",
    "bucare": "bu-ca-re",
    "búcare": "bú-ca-re",
    "búcaro": "bú-ca-ro",
    "buccinador": "buc-ci-na-dor",
    "buccino": "buc-ci-no",
    "buceador": "bu-ce-a-dor",
    "buceadora": "bu-ce-a-do-ra",
    "bucear": "bu-ce-ar",
    "bucéfalo": "bu-cé-fa-lo",
    "bucelario": "bu-ce-la-rio",
    "buceo": "bu-ce-o",
    "bucero": "bu-ce-ro",
    "buces": "bu-ces",
    "bucha": "bu-cha",
    "buchaca": "bu-cha-ca",
    "buchada": "bu-cha-da",
    "buche": "bu-che",
    "bucheta": "bu-che-ta",
    "buchete": "bu-che-te",
    "buchín": "bu-chín",
    "buchinche": "bu-chin-che",
    "buchipluma": "bu-chi-plu-ma",
    "buchón": "bu-chón",
    "buchona": "bu-cho-na",
    "bucinador": "bu-ci-na-dor",
    "bucio": "bu-cio",
    "bucle": "bu-cle",
    "buclosa": "bu-clo-sa",
    "bucloso": "bu-clo-so",
    "buco": "bu-co",
    "bucodental": "bu-co-den-tal",
    "bucofaríngeo": "bu-co-fa-rín-ge-o",
    "bucólica": "bu-có-li-ca",
    "bucólicamente": "bu-có-li-ca-men-te",
    "bucólico": "bu-có-li-co",
    "bucolismo": "bu-co-lis-mo",
    "bucráneo": "bu-crá-ne-o",
    "buda": "bu-da",
    "budare": "bu-da-re",
    "búdica": "bú-di-ca",
    "búdico": "bú-di-co",
    "budín": "bu-dín",
    "budinera": "bu-di-ne-ra",
    "budión": "bu-dión",
    "budismo": "bu-dis-mo",
    "budista": "bu-dis-ta",
    "búe": "bú-e",
    "buega": "bue-ga",
    "bueitre": "buei-tre",
    "buena": "bue-na",
    "buenaboya": "bue-na-bo-ya",
    "buenamente": "bue-na-men-te",
    "buenamoza": "bue-na-mo-za",
    "buenandanza": "bue-nan-dan-za",
    "buenaventura": "bue-na-ven-tu-ra",
    "buenaventuriano": "bue-na-ven-tu-ria-no",
    "buenaza": "bue-na-za",
    "buenazo": "bue-na-zo",
    "buenmozo": "buen-mo-zo",
    "bueno": "bue-no",
    "buera": "bue-ra",
    "buétago": "bué-ta-go",
    "buetre": "bue-tre",
    "bueyuna": "bue-yu-na",
    "bueyuno": "bue-yu-no",
    "bufa": "bu-fa",
    "bufado": "bu-fa-do",
    "bufador": "bu-fa-dor",
    "búfala": "bú-fa-la",
    "bufalina": "bu-fa-li-na",
    "bufalino": "bu-fa-li-no",
    "búfalo": "bú-fa-lo",
    "búfana": "bú-fa-na",
    "bufanda": "bu-fan-da",
    "búfano": "bú-fa-no",
    "bufar": "bu-far",
    "bufarda": "bu-far-da",
    "bufarrón": "bu-fa-rrón",
    "bufé": "bu-fé",
    "bufeo": "bu-fe-o",
    "bufet": "bu-fet",
    "bufete": "bu-fe-te",
    "buffer": "buf-fer",
    "buffet": "buf-fet",
    "bufia": "bu-fia",
    "bufido": "bu-fi-do",
    "bufo": "bu-fo",
    "bufón": "bu-fón",
    "bufona": "bu-fo-na",
    "bufonada": "bu-fo-na-da",
    "bufonear": "bu-fo-ne-ar",
    "bufonería": "bu-fo-ne-rí-a",
    "bufonesca": "bu-fo-nes-ca",
    "bufonesco": "bu-fo-nes-co",
    "bufonizar": "bu-fo-ni-zar",
    "bufos": "bu-fos",
    "bufosa": "bu-fo-sa",
    "bufoso": "bu-fo-so",
    "buga": "bu-ga",
    "bugalla": "bu-ga-lla",
    "bugambilia": "bu-gam-bi-lia",
    "buganvilia": "bu-gan-vi-lia",
    "buganvilla": "bu-gan-vi-lla",
    "bugarrón": "bu-ga-rrón",
    "bugata": "bu-ga-ta",
    "bugle": "bu-gle",
    "buglosa": "bu-glo-sa",
    "buharda": "buhar-da",
    "buhardilla": "buhar-di-lla",
    "buharro": "buha-rro",
    "buhedal": "buhe-dal",
    "buhedera": "buhe-de-ra",
    "buhedo": "buhe-do",
    "buhero": "buhe-ro",
    "buhío": "bu-hí-o",
    "buhitiho": "buhi-tiho",
    "búho": "bú-ho",
    "buhonera": "buho-ne-ra",
    "buhonería": "buho-ne-rí-a",
    "buhonero": "buho-ne-ro",
    "buida": "bui-da",
    "buido": "bui-do",
    "buitre": "bui-tre",
    "buitreada": "bui-tre-a-da",
    "buitrear": "bui-tre-ar",
    "buitrera": "bui-tre-ra",
    "buitrero": "bui-tre-ro",
    "buitrino": "bui-tri-no",
    "buitrón": "bui-trón",
    "buja": "bu-ja",
    "bujaja": "bu-ja-ja",
    "bujalazor": "bu-ja-la-zor",
    "bujarasol": "bu-ja-ra-sol",
    "bujarda": "bu-jar-da",
    "bujarrón": "bu-ja-rrón",
    "buje": "bu-je",
    "bujeda": "bu-je-da",
    "bujedal": "bu-je-dal",
    "bujedo": "bu-je-do",
    "bujelada": "bu-je-la-da",
    "bujeo": "bu-je-o",
    "bujería": "bu-je-rí-a",
    "bujero": "bu-je-ro",
    "bujeta": "bu-je-ta",
    "bujía": "bu-jí-a",
    "bujier": "bu-jier",
    "bujiería": "bu-jie-rí-a",
    "bujo": "bu-jo",
    "bula": "bu-la",
    "bular": "bu-lar",
    "bulárcama": "bu-lár-ca-ma",
    "bulario": "bu-la-rio",
    "bulbar": "bul-bar",
    "bulbo": "bul-bo",
    "bulbosa": "bul-bo-sa",
    "bulbosas": "bul-bo-sas",
    "bulboso": "bul-bo-so",
    "bulbul": "bul-bul",
    "bulda": "bul-da",
    "buldería": "bul-de-rí-a",
    "buldero": "bul-de-ro",
    "buldog": "bul-dog",
    "bule": "bu-le",
    "buleco": "bu-le-co",
    "bulería": "bu-le-rí-a",
    "bulerías": "bu-le-rí-as",
    "bulero": "bu-le-ro",
    "buleto": "bu-le-to",
    "bulevar": "bu-le-var",
    "búlgara": "búl-ga-ra",
    "búlgaro": "búl-ga-ro",
    "bulí": "bu-lí",
    "búlico": "bú-li-co",
    "bulimia": "bu-li-mia",
    "bulímica": "bu-lí-mi-ca",
    "bulímico": "bu-lí-mi-co",
    "bulín": "bu-lín",
    "bulla": "bu-lla",
    "bullabesa": "bu-lla-be-sa",
    "bullaje": "bu-lla-je",
    "bullanga": "bu-llan-ga",
    "bullanguera": "bu-llan-gue-ra",
    "bullanguero": "bu-llan-gue-ro",
    "bullaranga": "bu-lla-ran-ga",
    "bullarengue": "bu-lla-ren-gue",
    "bulldog": "bull-dog",
    "bullebulle": "bu-lle-bu-lle",
    "bullente": "bu-llen-te",
    "bullicio": "bu-lli-cio",
    "bulliciosa": "bu-lli-cio-sa",
    "bulliciosamente": "bu-lli-cio-sa-men-te",
    "bullicioso": "bu-lli-cio-so",
    "bullidor": "bu-lli-dor",
    "bullidora": "bu-lli-do-ra",
    "bullir": "bu-llir",
    "bullón": "bu-llón",
    "bullterrier": "bull-te-rrier",
    "bulo": "bu-lo",
    "bulón": "bu-lón",
    "bulterrier": "bul-te-rrier",
    "bulto": "bul-to",
    "bululú": "bu-lu-lú",
    "bumangués": "bu-man-gués",
    "bumanguesa": "bu-man-gue-sa",
    "bumbulón": "bum-bu-lón",
    "bumerán": "bu-me-rán",
    "búmeran": "bú-me-ran",
    "bumper": "bum-per",
    "buna": "bu-na",
    "bunde": "bun-de",
    "bungaló": "bun-ga-ló",
    "bungalow": "bun-ga-low",
    "buniatal": "bu-nia-tal",
    "buniato": "bu-nia-to",
    "bunio": "bu-nio",
    "búnker": "bún-ker",
    "buñolera": "bu-ño-le-ra",
    "buñolería": "bu-ño-le-rí-a",
    "buñolero": "bu-ño-le-ro",
    "buñuelera": "bu-ñue-le-ra",
    "buñuelero": "bu-ñue-le-ro",
    "buñuelo": "bu-ñue-lo",
    "buque": "bu-que",
    "buqué": "bu-qué",
    "bura": "bu-ra",
    "buraco": "bu-ra-co",
    "burato": "bu-ra-to",
    "burbuja": "bur-bu-ja",
    "burbujeante": "bur-bu-je-an-te",
    "burbujear": "bur-bu-je-ar",
    "burbujeo": "bur-bu-je-o",
    "burca": "bur-ca",
    "burchaca": "bur-cha-ca",
    "burche": "bur-che",
    "burda": "bur-da",
    "burdamente": "bur-da-men-te",
    "burdégano": "bur-dé-ga-no",
    "burdel": "bur-del",
    "burdelera": "bur-de-le-ra",
    "burdelero": "bur-de-le-ro",
    "burdelesco": "bur-de-les-co",
    "burdeos": "bur-de-os",
    "burdo": "bur-do",
    "burear": "bu-re-ar",
    "burebana": "bu-re-ba-na",
    "burebano": "bu-re-ba-no",
    "burel": "bu-rel",
    "burelado": "bu-re-la-do",
    "burén": "bu-rén",
    "bureo": "bu-re-o",
    "bureta": "bu-re-ta",
    "burga": "bur-ga",
    "burgado": "bur-ga-do",
    "burgalés": "bur-ga-lés",
    "burgalesa": "bur-ga-le-sa",
    "burger": "bur-ger",
    "burgés": "bur-gés",
    "burgesa": "bur-ge-sa",
    "burgo": "bur-go",
    "burgomaestre": "bur-go-ma-es-tre",
    "burgos": "bur-gos",
    "burgrave": "bur-gra-ve",
    "burgraviato": "bur-gra-via-to",
    "burgueña": "bur-gue-ña",
    "burgueño": "bur-gue-ño",
    "burgués": "bur-gués",
    "burguesa": "bur-gue-sa",
    "burguesamente": "bur-gue-sa-men-te",
    "burguesía": "bur-gue-sí-a",
    "burguesismo": "bur-gue-sis-mo",
    "burgundia": "bur-gun-dia",
    "burgundio": "bur-gun-dio",
    "buri": "bu-ri",
    "burí": "bu-rí",
    "buriel": "bu-riel",
    "burielada": "bu-rie-la-da",
    "burielado": "bu-rie-la-do",
    "buril": "bu-ril",
    "burilada": "bu-ri-la-da",
    "burilador": "bu-ri-la-dor",
    "buriladora": "bu-ri-la-do-ra",
    "buriladura": "bu-ri-la-du-ra",
    "burilar": "bu-ri-lar",
    "burillo": "bu-ri-llo",
    "burío": "bu-rí-o",
    "burio": "bu-rio",
    "burjaca": "bur-ja-ca",
    "burka": "bur-ka",
    "burla": "bur-la",
    "burladera": "bur-la-de-ra",
    "burladero": "bur-la-de-ro",
    "burlador": "bur-la-dor",
    "burladora": "bur-la-do-ra",
    "burlar": "bur-lar",
    "burlería": "bur-le-rí-a",
    "burlesca": "bur-les-ca",
    "burlescamente": "bur-les-ca-men-te",
    "burlesco": "bur-les-co",
    "burlete": "bur-le-te",
    "burlón": "bur-lón",
    "burlona": "bur-lo-na",
    "burlonamente": "bur-lo-na-men-te",
    "burlote": "bur-lo-te",
    "burmés": "bur-més",
    "burmesa": "bur-me-sa",
    "buro": "bu-ro",
    "buró": "bu-ró",
    "burocracia": "bu-ro-cra-cia",
    "burócrata": "bu-ró-cra-ta",
    "burocrática": "bu-ro-crá-ti-ca",
    "burocrático": "bu-ro-crá-ti-co",
    "burocratismo": "bu-ro-cra-tis-mo",
    "burocratización": "bu-ro-cra-ti-za-ción",
    "burocratizar": "bu-ro-cra-ti-zar",
    "burofax": "bu-ro-fax",
    "burótica": "bu-ró-ti-ca",
    "burra": "bu-rra",
    "burrada": "bu-rra-da",
    "burrajear": "bu-rra-je-ar",
    "burrajo": "bu-rra-jo",
    "burral": "bu-rral",
    "burreño": "bu-rre-ño",
    "burrera": "bu-rre-ra",
    "burrero": "bu-rre-ro",
    "burrez": "bu-rrez",
    "burricie": "bu-rri-cie",
    "burriciega": "bu-rri-cie-ga",
    "burriciego": "bu-rri-cie-go",
    "burriel": "bu-rriel",
    "burril": "bu-rril",
    "burrillo": "bu-rri-llo",
    "burrita": "bu-rri-ta",
    "burrito": "bu-rri-to",
    "burro": "bu-rro",
    "burrotaxi": "bu-rro-ta-xi",
    "burrucha": "bu-rru-cha",
    "burrumbada": "bu-rrum-ba-da",
    "bursátil": "bur-sá-til",
    "burserácea": "bur-se-rá-ce-a",
    "burseráceo": "bur-se-rá-ce-o",
    "bursitis": "bur-si-tis",
    "buruca": "bu-ru-ca",
    "burucuyá": "bu-ru-cu-yá",
    "burujo": "bu-ru-jo",
    "burujón": "bu-ru-jón",
    "burundanga": "bu-run-dan-ga",
    "burundés": "bu-run-dés",
    "burundesa": "bu-run-de-sa",
    "burundiana": "bu-run-dia-na",
    "burundiano": "bu-run-dia-no",
    "buruquiento": "bu-ru-quien-to",
    "burusca": "bu-rus-ca",
    "burusco": "bu-rus-co",
    "busa": "bu-sa",
    "busaca": "bu-sa-ca",
    "busarda": "bu-sar-da",
    "busca": "bus-ca",
    "buscabulla": "bus-ca-bu-lla",
    "buscabullas": "bus-ca-bu-llas",
    "buscada": "bus-ca-da",
    "buscador": "bus-ca-dor",
    "buscadora": "bus-ca-do-ra",
    "buscamiento": "bus-ca-mien-to",
    "buscaniguas": "bus-ca-ni-guas",
    "buscapersonas": "bus-ca-per-so-nas",
    "buscapié": "bus-ca-pié",
    "buscapiés": "bus-ca-piés",
    "buscapique": "bus-ca-pi-que",
    "buscapleitos": "bus-ca-plei-tos",
    "buscar": "bus-car",
    "buscarla": "bus-car-la",
    "buscarruidos": "bus-ca-rrui-dos",
    "buscavida": "bus-ca-vi-da",
    "buscavidas": "bus-ca-vi-das",
    "buscaviento": "bus-ca-vien-to",
    "busco": "bus-co",
    "buscón": "bus-cón",
    "buscona": "bus-co-na",
    "buseca": "bu-se-ca",
    "busera": "bu-se-ra",
    "busero": "bu-se-ro",
    "buseta": "bu-se-ta",
    "busier": "bu-sier",
    "busiete": "bu-sie-te",
    "busilis": "bu-si-lis",
    "busito": "bu-si-to",
    "buso": "bu-so",
    "búsqueda": "bús-que-da",
    "busquilla": "bus-qui-lla",
    "busquillo": "bus-qui-llo",
    "búster": "bús-ter",
    "busto": "bus-to",
    "bustrofedon": "bus-tro-fe-don",
    "bustrófedon": "bus-tró-fe-don",
    "butaca": "bu-ta-ca",
    "butaco": "bu-ta-co",
    "butacón": "bu-ta-cón",
    "butadieno": "bu-ta-die-no",
    "butanera": "bu-ta-ne-ra",
    "butanero": "bu-ta-ne-ro",
    "butanés": "bu-ta-nés",
    "butanesa": "bu-ta-ne-sa",
    "butano": "bu-ta-no",
    "butanoico": "bu-ta-noi-co",
    "butaque": "bu-ta-que",
    "buten": "bu-ten",
    "buteno": "bu-te-no",
    "butiá": "bu-tiá",
    "butifarra": "bu-ti-fa-rra",
    "butifarrera": "bu-ti-fa-rre-ra",
    "butifarrero": "bu-ti-fa-rre-ro",
    "butionda": "bu-tion-da",
    "butiondo": "bu-tion-do",
    "butírico": "bu-tí-ri-co",
    "butiro": "bu-ti-ro",
    "butirosa": "bu-ti-ro-sa",
    "butiroso": "bu-ti-ro-so",
    "butomácea": "bu-to-má-ce-a",
    "butomáceo": "bu-to-má-ce-o",
    "butomea": "bu-to-me-a",
    "butomeo": "bu-to-me-o",
    "butrino": "bu-tri-no",
    "butrón": "bu-trón",
    "butronera": "bu-tro-ne-ra",
    "butronero": "bu-tro-ne-ro",
    "butuco": "bu-tu-co",
    "buxácea": "bu-xá-ce-a",
    "buxáceas": "bu-xá-ce-as",
    "buxáceo": "bu-xá-ce-o",
    "buyo": "bu-yo",
    "buzamiento": "bu-za-mien-to",
    "búzano": "bú-za-no",
    "buzaque": "bu-za-que",
    "buzar": "bu-zar",
    "buzarda": "bu-zar-da",
    "buzcorona": "buz-co-ro-na",
    "buzo": "bu-zo",
    "buzón": "bu-zón",
    "buzonear": "bu-zo-ne-ar",
    "buzoneo": "bu-zo-ne-o",
    "buzonera": "bu-zo-ne-ra",
    "buzonero": "bu-zo-ne-ro",
    "buzos": "bu-zos",
    "bwana": "bwa-na",
    "caaminí": "ca-a-mi-ní",
    "cabadelante": "ca-ba-de-lan-te",
    "cabadura": "ca-ba-du-ra",
    "cabal": "ca-bal",
    "cábala": "cá-ba-la",
    "cabalar": "ca-ba-lar",
    "cabalero": "ca-ba-le-ro",
    "cabalgada": "ca-bal-ga-da",
    "cabalgador": "ca-bal-ga-dor",
    "cabalgadora": "ca-bal-ga-do-ra",
    "cabalgadura": "ca-bal-ga-du-ra",
    "cabalgamiento": "ca-bal-ga-mien-to",
    "cabalgar": "ca-bal-gar",
    "cabalgata": "ca-bal-ga-ta",
    "cabalgazón": "ca-bal-ga-zón",
    "cabalhuste": "ca-bal-hus-te",
    "cabalina": "ca-ba-li-na",
    "cabalino": "ca-ba-li-no",
    "cabalista": "ca-ba-lis-ta",
    "cabalística": "ca-ba-lís-ti-ca",
    "cabalístico": "ca-ba-lís-ti-co",
    "caballa": "ca-ba-lla",
    "caballada": "ca-ba-lla-da",
    "caballaje": "ca-ba-lla-je",
    "caballar": "ca-ba-llar",
    "caballazo": "ca-ba-lla-zo",
    "caballear": "ca-ba-lle-ar",
    "caballejo": "ca-ba-lle-jo",
    "caballera": "ca-ba-lle-ra",
    "caballerango": "ca-ba-lle-ran-go",
    "caballerato": "ca-ba-lle-ra-to",
    "caballerazo": "ca-ba-lle-ra-zo",
    "caballerear": "ca-ba-lle-re-ar",
    "caballeresca": "ca-ba-lle-res-ca",
    "caballerescamente": "ca-ba-lle-res-ca-men-te",
    "caballeresco": "ca-ba-lle-res-co",
    "caballerete": "ca-ba-lle-re-te",
    "caballería": "ca-ba-lle-rí-a",
    "caballericero": "ca-ba-lle-ri-ce-ro",
    "caballeril": "ca-ba-lle-ril",
    "caballerito": "ca-ba-lle-ri-to",
    "caballeriza": "ca-ba-lle-ri-za",
    "caballerizo": "ca-ba-lle-ri-zo",
    "caballero": "ca-ba-lle-ro",
    "caballerosa": "ca-ba-lle-ro-sa",
    "caballerosamente": "ca-ba-lle-ro-sa-men-te",
    "caballerosidad": "ca-ba-lle-ro-si-dad",
    "caballeroso": "ca-ba-lle-ro-so",
    "caballerote": "ca-ba-lle-ro-te",
    "caballeta": "ca-ba-lle-ta",
    "caballete": "ca-ba-lle-te",
    "caballillo": "ca-ba-lli-llo",
    "caballista": "ca-ba-llis-ta",
    "caballito": "ca-ba-lli-to",
    "caballo": "ca-ba-llo",
    "caballochupa": "ca-ba-llo-chu-pa",
    "caballón": "ca-ba-llón",
    "caballuna": "ca-ba-llu-na",
    "caballuno": "ca-ba-llu-no",
    "cabalmente": "ca-bal-men-te",
    "cabalonga": "ca-ba-lon-ga",
    "cabaña": "ca-ba-ña",
    "cabañal": "ca-ba-ñal",
    "cabañense": "ca-ba-ñen-se",
    "cabañera": "ca-ba-ñe-ra",
    "cabañería": "ca-ba-ñe-rí-a",
    "cabañero": "ca-ba-ñe-ro",
    "cabanga": "ca-ban-ga",
    "cabañil": "ca-ba-ñil",
    "cabanista": "ca-ba-nis-ta",
    "cabañuelas": "ca-ba-ñue-las",
    "cabaré": "ca-ba-ré",
    "cabaret": "ca-ba-ret",
    "cabaretera": "ca-ba-re-te-ra",
    "cabaretero": "ca-ba-re-te-ro",
    "cabarga": "ca-bar-ga",
    "cabarra": "ca-ba-rra",
    "cabarrón": "ca-ba-rrón",
    "cabás": "ca-bás",
    "cabaza": "ca-ba-za",
    "cabdal": "cab-dal",
    "cabdillazgo": "cab-di-llaz-go",
    "cabdillo": "cab-di-llo",
    "cabe": "ca-be",
    "cabear": "ca-be-ar",
    "cabécar": "ca-bé-car",
    "cabeceado": "ca-be-ce-a-do",
    "cabeceador": "ca-be-ce-a-dor",
    "cabeceamiento": "ca-be-ce-a-mien-to",
    "cabecear": "ca-be-ce-ar",
    "cabeceo": "ca-be-ce-o",
    "cabecera": "ca-be-ce-ra",
    "cabecero": "ca-be-ce-ro",
    "cabeciancha": "ca-be-cian-cha",
    "cabeciancho": "ca-be-cian-cho",
    "cabeciblanco": "ca-be-ci-blan-co",
    "cabecidura": "ca-be-ci-du-ra",
    "cabeciduro": "ca-be-ci-du-ro",
    "cabecilla": "ca-be-ci-lla",
    "cabecirrojo": "ca-be-ci-rro-jo",
    "cabedera": "ca-be-de-ra",
    "cabedero": "ca-be-de-ro",
    "cabellada": "ca-be-lla-da",
    "cabellado": "ca-be-lla-do",
    "cabellar": "ca-be-llar",
    "cabellera": "ca-be-lle-ra",
    "cabello": "ca-be-llo",
    "cabelluda": "ca-be-llu-da",
    "cabelludo": "ca-be-llu-do",
    "caber": "ca-ber",
    "cabera": "ca-be-ra",
    "cabero": "ca-be-ro",
    "cabestraje": "ca-bes-tra-je",
    "cabestrante": "ca-bes-tran-te",
    "cabestrar": "ca-bes-trar",
    "cabestrear": "ca-bes-tre-ar",
    "cabestrería": "ca-bes-tre-rí-a",
    "cabestrero": "ca-bes-tre-ro",
    "cabestrillo": "ca-bes-tri-llo",
    "cabestro": "ca-bes-tro",
    "cabete": "ca-be-te",
    "cabeza": "ca-be-za",
    "cabezada": "ca-be-za-da",
    "cabezaje": "ca-be-za-je",
    "cabezal": "ca-be-zal",
    "cabezalera": "ca-be-za-le-ra",
    "cabezalería": "ca-be-za-le-rí-a",
    "cabezalero": "ca-be-za-le-ro",
    "cabezazo": "ca-be-za-zo",
    "cabezcaída": "ca-bez-ca-í-da",
    "cabezcaído": "ca-bez-ca-í-do",
    "cabezo": "ca-be-zo",
    "cabezón": "ca-be-zón",
    "cabezona": "ca-be-zo-na",
    "cabezonada": "ca-be-zo-na-da",
    "cabezonería": "ca-be-zo-ne-rí-a",
    "cabezorro": "ca-be-zo-rro",
    "cabezota": "ca-be-zo-ta",
    "cabezote": "ca-be-zo-te",
    "cabezuda": "ca-be-zu-da",
    "cabezudamente": "ca-be-zu-da-men-te",
    "cabezudo": "ca-be-zu-do",
    "cabezuela": "ca-be-zue-la",
    "cabiblanco": "ca-bi-blan-co",
    "cabida": "ca-bi-da",
    "cabido": "ca-bi-do",
    "cabila": "ca-bi-la",
    "cabildada": "ca-bil-da-da",
    "cabildante": "ca-bil-dan-te",
    "cabildear": "ca-bil-de-ar",
    "cabildeo": "ca-bil-de-o",
    "cabildera": "ca-bil-de-ra",
    "cabildero": "ca-bil-de-ro",
    "cabildo": "ca-bil-do",
    "cabileña": "ca-bi-le-ña",
    "cabileño": "ca-bi-le-ño",
    "cabilla": "ca-bi-lla",
    "cabillero": "ca-bi-lle-ro",
    "cabillo": "ca-bi-llo",
    "cabimiento": "ca-bi-mien-to",
    "cabina": "ca-bi-na",
    "cabinera": "ca-bi-ne-ra",
    "cabio": "ca-bio",
    "cabizbaja": "ca-biz-ba-ja",
    "cabizbajo": "ca-biz-ba-jo",
    "cabizcaída": "ca-biz-ca-í-da",
    "cabizcaído": "ca-biz-ca-í-do",
    "cabizmordida": "ca-biz-mor-di-da",
    "cabizmordido": "ca-biz-mor-di-do",
    "cable": "ca-ble",
    "cableado": "ca-ble-a-do",
    "cablear": "ca-ble-ar",
    "cablecarril": "ca-ble-ca-rril",
    "cablegrafiar": "ca-ble-gra-fiar",
    "cablegráfica": "ca-ble-grá-fi-ca",
    "cablegráficamente": "ca-ble-grá-fi-ca-men-te",
    "cablegráfico": "ca-ble-grá-fi-co",
    "cablegrama": "ca-ble-gra-ma",
    "cablera": "ca-ble-ra",
    "cablero": "ca-ble-ro",
    "cablevisión": "ca-ble-vi-sión",
    "cablieva": "ca-blie-va",
    "cablista": "ca-blis-ta",
    "cablote": "ca-blo-te",
    "cabo": "ca-bo",
    "caboral": "ca-bo-ral",
    "cabotaje": "ca-bo-ta-je",
    "caboverdiana": "ca-bo-ver-dia-na",
    "caboverdiano": "ca-bo-ver-dia-no",
    "cabra": "ca-bra",
    "cabracho": "ca-bra-cho",
    "cabrada": "ca-bra-da",
    "cabrahigadura": "ca-brahi-ga-du-ra",
    "cabrahigal": "ca-brahi-gal",
    "cabrahigar": "ca-brahi-gar",
    "cabrahígo": "ca-bra-hí-go",
    "cabrales": "ca-bra-les",
    "cabrear": "ca-bre-ar",
    "cabreo": "ca-bre-o",
    "cabrera": "ca-bre-ra",
    "cabrería": "ca-bre-rí-a",
    "cabreriza": "ca-bre-ri-za",
    "cabrerizo": "ca-bre-ri-zo",
    "cabrero": "ca-bre-ro",
    "cabrestante": "ca-bres-tan-te",
    "cabrestear": "ca-bres-te-ar",
    "cabresto": "ca-bres-to",
    "cabría": "ca-brí-a",
    "cabria": "ca-bria",
    "cabrilla": "ca-bri-lla",
    "cabrillear": "ca-bri-lle-ar",
    "cabrilleo": "ca-bri-lle-o",
    "cabrina": "ca-bri-na",
    "cabrío": "ca-brí-o",
    "cabrio": "ca-brio",
    "cabriola": "ca-brio-la",
    "cabriolar": "ca-brio-lar",
    "cabriolé": "ca-brio-lé",
    "cabriolear": "ca-brio-le-ar",
    "cabrita": "ca-bri-ta",
    "cabritada": "ca-bri-ta-da",
    "cabritera": "ca-bri-te-ra",
    "cabritero": "ca-bri-te-ro",
    "cabritilla": "ca-bri-ti-lla",
    "cabrito": "ca-bri-to",
    "cabrituna": "ca-bri-tu-na",
    "cabrituno": "ca-bri-tu-no",
    "cabro": "ca-bro",
    "cabrón": "ca-brón",
    "cabrona": "ca-bro-na",
    "cabronada": "ca-bro-na-da",
    "cabronazo": "ca-bro-na-zo",
    "cabruna": "ca-bru-na",
    "cabruñar": "ca-bru-ñar",
    "cabruno": "ca-bru-no",
    "cabruño": "ca-bru-ño",
    "cabuda": "ca-bu-da",
    "cabujón": "ca-bu-jón",
    "cábula": "cá-bu-la",
    "caburé": "ca-bu-ré",
    "cabuya": "ca-bu-ya",
    "cabuyera": "ca-bu-ye-ra",
    "cabuyería": "ca-bu-ye-rí-a",
    "cabuyo": "ca-bu-yo",
    "caca": "ca-ca",
    "cácabo": "cá-ca-bo",
    "cacahuacentli": "ca-ca-hua-cen-tli",
    "cacahuacintle": "ca-ca-hua-cin-tle",
    "cacahual": "ca-ca-hual",
    "cacahuatal": "ca-ca-hua-tal",
    "cacahuate": "ca-ca-hua-te",
    "cacahuatera": "ca-ca-hua-te-ra",
    "cacahuatero": "ca-ca-hua-te-ro",
    "cacahué": "ca-ca-hué",
    "cacahuera": "ca-ca-hue-ra",
    "cacahuero": "ca-ca-hue-ro",
    "cacahuete": "ca-ca-hue-te",
    "cacalichuche": "ca-ca-li-chu-che",
    "cacalosúchil": "ca-ca-lo-sú-chil",
    "cacalota": "ca-ca-lo-ta",
    "cacalotazo": "ca-ca-lo-ta-zo",
    "cacalote": "ca-ca-lo-te",
    "cacán": "ca-cán",
    "cacana": "ca-ca-na",
    "cacao": "ca-ca-o",
    "cacaonance": "ca-ca-o-nan-ce",
    "cacaopera": "ca-ca-o-pe-ra",
    "cacaotal": "ca-ca-o-tal",
    "cacaotera": "ca-ca-o-te-ra",
    "cacaotero": "ca-ca-o-te-ro",
    "cacaraña": "ca-ca-ra-ña",
    "cacarañada": "ca-ca-ra-ña-da",
    "cacarañado": "ca-ca-ra-ña-do",
    "cacaraquear": "ca-ca-ra-que-ar",
    "cacareado": "ca-ca-re-a-do",
    "cacareador": "ca-ca-re-a-dor",
    "cacareadora": "ca-ca-re-a-do-ra",
    "cacarear": "ca-ca-re-ar",
    "cacareo": "ca-ca-re-o",
    "cacarico": "ca-ca-ri-co",
    "cacariza": "ca-ca-ri-za",
    "cacarizo": "ca-ca-ri-zo",
    "cácaro": "cá-ca-ro",
    "cacarro": "ca-ca-rro",
    "cacasena": "ca-ca-se-na",
    "cacaseno": "ca-ca-se-no",
    "cacaste": "ca-cas-te",
    "cacastle": "ca-cas-tle",
    "cacatúa": "ca-ca-tú-a",
    "cacaxtle": "ca-cax-tle",
    "cacaztle": "ca-caz-tle",
    "cacea": "ca-ce-a",
    "cacear": "ca-ce-ar",
    "caceo": "ca-ce-o",
    "cacera": "ca-ce-ra",
    "cacereña": "ca-ce-re-ña",
    "cacereño": "ca-ce-re-ño",
    "cacería": "ca-ce-rí-a",
    "cacerina": "ca-ce-ri-na",
    "cacerola": "ca-ce-ro-la",
    "cacerolada": "ca-ce-ro-la-da",
    "cacerolazo": "ca-ce-ro-la-zo",
    "caceroleo": "ca-ce-ro-le-o",
    "caceta": "ca-ce-ta",
    "cacha": "ca-cha",
    "cachaca": "ca-cha-ca",
    "cachacienta": "ca-cha-cien-ta",
    "cachaciento": "ca-cha-cien-to",
    "cachaco": "ca-cha-co",
    "cachada": "ca-cha-da",
    "cachador": "ca-cha-dor",
    "cachadora": "ca-cha-do-ra",
    "cachadura": "ca-cha-du-ra",
    "cachafaz": "ca-cha-faz",
    "cachafaza": "ca-cha-fa-za",
    "cachalote": "ca-cha-lo-te",
    "cachamarín": "ca-cha-ma-rín",
    "cachaña": "ca-cha-ña",
    "cachanchán": "ca-chan-chán",
    "cachanchana": "ca-chan-cha-na",
    "cachañear": "ca-cha-ñe-ar",
    "cachanlagua": "ca-chan-la-gua",
    "cachano": "ca-cha-no",
    "cachapa": "ca-cha-pa",
    "cachapear": "ca-cha-pe-ar",
    "cachapera": "ca-cha-pe-ra",
    "cachapoalina": "ca-cha-po-a-li-na",
    "cachapoalino": "ca-cha-po-a-li-no",
    "cachar": "ca-char",
    "cacharpa": "ca-char-pa",
    "cacharpari": "ca-char-pa-ri",
    "cacharpas": "ca-char-pas",
    "cacharpaya": "ca-char-pa-ya",
    "cacharpear": "ca-char-pe-ar",
    "cacharra": "ca-cha-rra",
    "cacharrazo": "ca-cha-rra-zo",
    "cacharrear": "ca-cha-rre-ar",
    "cacharrera": "ca-cha-rre-ra",
    "cacharrería": "ca-cha-rre-rí-a",
    "cacharrero": "ca-cha-rre-ro",
    "cacharriento": "ca-cha-rrien-to",
    "cacharro": "ca-cha-rro",
    "cachas": "ca-chas",
    "cachativa": "ca-cha-ti-va",
    "cachava": "ca-cha-va",
    "cachavazo": "ca-cha-va-zo",
    "cachavo": "ca-cha-vo",
    "cachaza": "ca-cha-za",
    "cachazo": "ca-cha-zo",
    "cachazuda": "ca-cha-zu-da",
    "cachazudamente": "ca-cha-zu-da-men-te",
    "cachazudo": "ca-cha-zu-do",
    "caché": "ca-ché",
    "cachear": "ca-che-ar",
    "cachelos": "ca-che-los",
    "cachemarín": "ca-che-ma-rín",
    "cachemir": "ca-che-mir",
    "cachemira": "ca-che-mi-ra",
    "cacheo": "ca-che-o",
    "cachera": "ca-che-ra",
    "cachero": "ca-che-ro",
    "cachet": "ca-chet",
    "cacheta": "ca-che-ta",
    "cachetada": "ca-che-ta-da",
    "cachete": "ca-che-te",
    "cachetear": "ca-che-te-ar",
    "cacheteo": "ca-che-te-o",
    "cachetera": "ca-che-te-ra",
    "cachetero": "ca-che-te-ro",
    "cachetina": "ca-che-ti-na",
    "cachetiza": "ca-che-ti-za",
    "cachetón": "ca-che-tón",
    "cachetona": "ca-che-to-na",
    "cachetonear": "ca-che-to-ne-ar",
    "cachetuda": "ca-che-tu-da",
    "cachetudo": "ca-che-tu-do",
    "cachicamo": "ca-chi-ca-mo",
    "cachicán": "ca-chi-cán",
    "cachicana": "ca-chi-ca-na",
    "cachicha": "ca-chi-cha",
    "cachicuerna": "ca-chi-cuer-na",
    "cachicuerno": "ca-chi-cuer-no",
    "cachidiablo": "ca-chi-dia-blo",
    "cachifa": "ca-chi-fa",
    "cachiflín": "ca-chi-flín",
    "cachifo": "ca-chi-fo",
    "cachifollar": "ca-chi-fo-llar",
    "cachigorda": "ca-chi-gor-da",
    "cachigordo": "ca-chi-gor-do",
    "cachila": "ca-chi-la",
    "cachillada": "ca-chi-lla-da",
    "cachilo": "ca-chi-lo",
    "cachimán": "ca-chi-mán",
    "cachimba": "ca-chim-ba",
    "cachimbazo": "ca-chim-ba-zo",
    "cachimbeada": "ca-chim-be-a-da",
    "cachimbeado": "ca-chim-be-a-do",
    "cachimbear": "ca-chim-be-ar",
    "cachimbeo": "ca-chim-be-o",
    "cachimbera": "ca-chim-be-ra",
    "cachimbero": "ca-chim-be-ro",
    "cachimbo": "ca-chim-bo",
    "cachimbón": "ca-chim-bón",
    "cachimbona": "ca-chim-bo-na",
    "cachina": "ca-chi-na",
    "cachinera": "ca-chi-ne-ra",
    "cachinería": "ca-chi-ne-rí-a",
    "cachinero": "ca-chi-ne-ro",
    "cachinflín": "ca-chin-flín",
    "cachipodar": "ca-chi-po-dar",
    "cachipolla": "ca-chi-po-lla",
    "cachiporra": "ca-chi-po-rra",
    "cachiporrazo": "ca-chi-po-rra-zo",
    "cachiporrear": "ca-chi-po-rre-ar",
    "cachiporrera": "ca-chi-po-rre-ra",
    "cachiporrero": "ca-chi-po-rre-ro",
    "cachipuco": "ca-chi-pu-co",
    "cachiquel": "ca-chi-quel",
    "cachiri": "ca-chi-ri",
    "cachirla": "ca-chir-la",
    "cachirolada": "ca-chi-ro-la-da",
    "cachirul": "ca-chi-rul",
    "cachirula": "ca-chi-ru-la",
    "cachirulear": "ca-chi-ru-le-ar",
    "cachirulo": "ca-chi-ru-lo",
    "cachista": "ca-chis-ta",
    "cachita": "ca-chi-ta",
    "cachito": "ca-chi-to",
    "cachivache": "ca-chi-va-che",
    "cachivachero": "ca-chi-va-che-ro",
    "cachiza": "ca-chi-za",
    "cachizo": "ca-chi-zo",
    "cacho": "ca-cho",
    "cachola": "ca-cho-la",
    "cachón": "ca-chón",
    "cachonda": "ca-chon-da",
    "cachondas": "ca-chon-das",
    "cachondear": "ca-chon-de-ar",
    "cachondeo": "ca-chon-de-o",
    "cachondez": "ca-chon-dez",
    "cachondiez": "ca-chon-diez",
    "cachondo": "ca-chon-do",
    "cachopín": "ca-cho-pín",
    "cachopo": "ca-cho-po",
    "cachorra": "ca-cho-rra",
    "cachorreñas": "ca-cho-rre-ñas",
    "cachorrillo": "ca-cho-rri-llo",
    "cachorro": "ca-cho-rro",
    "cachú": "ca-chú",
    "cachua": "ca-chua",
    "cachucha": "ca-chu-cha",
    "cachuchazo": "ca-chu-cha-zo",
    "cachuchero": "ca-chu-che-ro",
    "cachucho": "ca-chu-cho",
    "cachuchudo": "ca-chu-chu-do",
    "cachuda": "ca-chu-da",
    "cachudo": "ca-chu-do",
    "cachuela": "ca-chue-la",
    "cachuelo": "ca-chue-lo",
    "cachulera": "ca-chu-le-ra",
    "cachulero": "ca-chu-le-ro",
    "cachumbambé": "ca-chum-bam-bé",
    "cachumbo": "ca-chum-bo",
    "cachunde": "ca-chun-de",
    "cachupín": "ca-chu-pín",
    "cachupina": "ca-chu-pi-na",
    "cachupinada": "ca-chu-pi-na-da",
    "cachurear": "ca-chu-re-ar",
    "cachureca": "ca-chu-re-ca",
    "cachureco": "ca-chu-re-co",
    "cachureo": "ca-chu-re-o",
    "cachurera": "ca-chu-re-ra",
    "cachurero": "ca-chu-re-ro",
    "cacica": "ca-ci-ca",
    "cacicada": "ca-ci-ca-da",
    "cacicato": "ca-ci-ca-to",
    "cacicatura": "ca-ci-ca-tu-ra",
    "cacicazgo": "ca-ci-caz-go",
    "cacillo": "ca-ci-llo",
    "cacimba": "ca-cim-ba",
    "cacique": "ca-ci-que",
    "caciquear": "ca-ci-que-ar",
    "caciquil": "ca-ci-quil",
    "caciquismo": "ca-ci-quis-mo",
    "cacle": "ca-cle",
    "caco": "ca-co",
    "cacodilato": "ca-co-di-la-to",
    "cacodílico": "ca-co-dí-li-co",
    "cacodilo": "ca-co-di-lo",
    "cacofonía": "ca-co-fo-ní-a",
    "cacofónica": "ca-co-fó-ni-ca",
    "cacofónico": "ca-co-fó-ni-co",
    "cacografía": "ca-co-gra-fí-a",
    "cacología": "ca-co-lo-gí-a",
    "cacomite": "ca-co-mi-te",
    "cacomixtle": "ca-co-mix-tle",
    "cacomiztle": "ca-co-miz-tle",
    "cacoquimia": "ca-co-qui-mia",
    "cacoquímica": "ca-co-quí-mi-ca",
    "cacoquímico": "ca-co-quí-mi-co",
    "cacoquimio": "ca-co-qui-mio",
    "cacorro": "ca-co-rro",
    "cacosmia": "ca-cos-mia",
    "cacota": "ca-co-ta",
    "cacreca": "ca-cre-ca",
    "cacreco": "ca-cre-co",
    "cactácea": "cac-tá-ce-a",
    "cactáceas": "cac-tá-ce-as",
    "cactáceo": "cac-tá-ce-o",
    "cáctea": "các-te-a",
    "cácteas": "các-te-as",
    "cácteo": "các-te-o",
    "cacto": "cac-to",
    "cactus": "cac-tus",
    "caculear": "ca-cu-le-ar",
    "caculo": "ca-cu-lo",
    "cacumen": "ca-cu-men",
    "cacuminal": "ca-cu-mi-nal",
    "cacuy": "ca-cuy",
    "cada": "ca-da",
    "cadahalso": "ca-da-hal-so",
    "cadaldía": "ca-dal-dí-a",
    "cadalecho": "ca-da-le-cho",
    "cadalso": "ca-dal-so",
    "cadañal": "ca-da-ñal",
    "cadañega": "ca-da-ñe-ga",
    "cadañego": "ca-da-ñe-go",
    "cadañera": "ca-da-ñe-ra",
    "cadañero": "ca-da-ñe-ro",
    "cadarzo": "ca-dar-zo",
    "cádava": "cá-da-va",
    "cadaval": "ca-da-val",
    "cadáver": "ca-dá-ver",
    "cadavera": "ca-da-ve-ra",
    "cadavérica": "ca-da-vé-ri-ca",
    "cadavérico": "ca-da-vé-ri-co",
    "cadaverina": "ca-da-ve-ri-na",
    "cadaverosa": "ca-da-ve-ro-sa",
    "cadaveroso": "ca-da-ve-ro-so",
    "caddie": "cad-die",
    "cadejo": "ca-de-jo",
    "cadena": "ca-de-na",
    "cadenado": "ca-de-na-do",
    "cadenazo": "ca-de-na-zo",
    "cadencia": "ca-den-cia",
    "cadencial": "ca-den-cial",
    "cadenciosa": "ca-den-cio-sa",
    "cadenciosamente": "ca-den-cio-sa-men-te",
    "cadencioso": "ca-den-cio-so",
    "cadenera": "ca-de-ne-ra",
    "cadenero": "ca-de-ne-ro",
    "cadeneta": "ca-de-ne-ta",
    "cadenilla": "ca-de-ni-lla",
    "cadente": "ca-den-te",
    "cadera": "ca-de-ra",
    "caderamen": "ca-de-ra-men",
    "caderillas": "ca-de-ri-llas",
    "cadetada": "ca-de-ta-da",
    "cadete": "ca-de-te",
    "cadi": "ca-di",
    "cadí": "ca-dí",
    "cadiazgo": "ca-diaz-go",
    "cadillar": "ca-di-llar",
    "cadillo": "ca-di-llo",
    "cadira": "ca-di-ra",
    "cadireta": "ca-di-re-ta",
    "cadmía": "cad-mí-a",
    "cádmico": "cád-mi-co",
    "cadmio": "cad-mio",
    "cado": "ca-do",
    "cadoce": "ca-do-ce",
    "cadozo": "ca-do-zo",
    "caduca": "ca-du-ca",
    "caducamente": "ca-du-ca-men-te",
    "caducar": "ca-du-car",
    "caduceador": "ca-du-ce-a-dor",
    "caduceo": "ca-du-ce-o",
    "caducidad": "ca-du-ci-dad",
    "caducifolio": "ca-du-ci-fo-lio",
    "caduco": "ca-du-co",
    "caduquez": "ca-du-quez",
    "caediza": "ca-e-di-za",
    "caedizo": "ca-e-di-zo",
    "caedura": "ca-e-du-ra",
    "caena": "ca-e-na",
    "caer": "ca-er",
    "café": "ca-fé",
    "cafeína": "ca-fe-í-na",
    "cafelito": "ca-fe-li-to",
    "cafesero": "ca-fe-se-ro",
    "cafesoso": "ca-fe-so-so",
    "cafetal": "ca-fe-tal",
    "cafetalera": "ca-fe-ta-le-ra",
    "cafetalero": "ca-fe-ta-le-ro",
    "cafetear": "ca-fe-te-ar",
    "cafetera": "ca-fe-te-ra",
    "cafetería": "ca-fe-te-rí-a",
    "cafetero": "ca-fe-te-ro",
    "cafetín": "ca-fe-tín",
    "cafeto": "ca-fe-to",
    "cafetucho": "ca-fe-tu-cho",
    "cafiche": "ca-fi-che",
    "cafichear": "ca-fi-che-ar",
    "caficho": "ca-fi-cho",
    "caficultor": "ca-fi-cul-tor",
    "caficultora": "ca-fi-cul-to-ra",
    "caficultura": "ca-fi-cul-tu-ra",
    "cáfila": "cá-fi-la",
    "cafiroleta": "ca-fi-ro-le-ta",
    "cafishiar": "ca-fis-hiar",
    "cafishio": "ca-fis-hio",
    "cafisho": "ca-fis-ho",
    "cafisio": "ca-fi-sio",
    "cafiz": "ca-fiz",
    "cafizamiento": "ca-fi-za-mien-to",
    "cafre": "ca-fre",
    "caftán": "caf-tán",
    "cafúa": "ca-fú-a",
    "cafuinga": "ca-fuin-ga",
    "cagaaceite": "ca-ga-a-cei-te",
    "cagachín": "ca-ga-chín",
    "cagada": "ca-ga-da",
    "cagadal": "ca-ga-dal",
    "cagadero": "ca-ga-de-ro",
    "cagado": "ca-ga-do",
    "cagafierro": "ca-ga-fie-rro",
    "cagafuego": "ca-ga-fue-go",
    "cagajón": "ca-ga-jón",
    "cagalaolla": "ca-ga-la-o-lla",
    "cagalar": "ca-ga-lar",
    "cagaleche": "ca-ga-le-che",
    "cagalera": "ca-ga-le-ra",
    "cagaluta": "ca-ga-lu-ta",
    "caganido": "ca-ga-ni-do",
    "caganidos": "ca-ga-ni-dos",
    "cagantina": "ca-gan-ti-na",
    "cagar": "ca-gar",
    "cagarrache": "ca-ga-rra-che",
    "cagarria": "ca-ga-rria",
    "cagarrina": "ca-ga-rri-na",
    "cagarropa": "ca-ga-rro-pa",
    "cagarruta": "ca-ga-rru-ta",
    "cagatinta": "ca-ga-tin-ta",
    "cagatintas": "ca-ga-tin-tas",
    "cagatorio": "ca-ga-to-rio",
    "cagón": "ca-gón",
    "cagona": "ca-go-na",
    "caguairán": "ca-guai-rán",
    "caguama": "ca-gua-ma",
    "caguaso": "ca-gua-so",
    "caguayo": "ca-gua-yo",
    "cague": "ca-gue",
    "cagüeña": "ca-güe-ña",
    "cagüeño": "ca-güe-ño",
    "cagueta": "ca-gue-ta",
    "cahíta": "ca-hí-ta",
    "cahíz": "ca-híz",
    "cahizada": "cahi-za-da",
    "cahuama": "ca-hua-ma",
    "cahuerco": "ca-huer-co",
    "cahuín": "ca-huín",
    "caí": "ca-í",
    "caíble": "ca-í-ble",
    "caico": "cai-co",
    "caicobé": "cai-co-bé",
    "caícos": "ca-í-cos",
    "caíd": "ca-íd",
    "caída": "ca-í-da",
    "caído": "ca-í-do",
    "caifán": "cai-fán",
    "caigua": "cai-gua",
    "caiguá": "cai-guá",
    "caigüe": "cai-güe",
    "caima": "cai-ma",
    "caimacán": "cai-ma-cán",
    "caimán": "cai-mán",
    "caimanera": "cai-ma-ne-ra",
    "caimiento": "cai-mien-to",
    "caimital": "cai-mi-tal",
    "caimito": "cai-mi-to",
    "caín": "ca-ín",
    "cainar": "cai-nar",
    "cainismo": "cai-nis-mo",
    "cainita": "cai-ni-ta",
    "caipiriña": "cai-pi-ri-ña",
    "caique": "cai-que",
    "caire": "cai-re",
    "cairel": "cai-rel",
    "cairelar": "cai-re-lar",
    "cairina": "cai-ri-na",
    "cairino": "cai-ri-no",
    "cairoa": "cai-ro-a",
    "cairota": "cai-ro-ta",
    "caite": "cai-te",
    "caitear": "cai-te-ar",
    "caituda": "cai-tu-da",
    "caitudo": "cai-tu-do",
    "caja": "ca-ja",
    "cajabambina": "ca-ja-bam-bi-na",
    "cajabambino": "ca-ja-bam-bi-no",
    "cajamarquina": "ca-ja-mar-qui-na",
    "cajamarquino": "ca-ja-mar-qui-no",
    "cajatambina": "ca-ja-tam-bi-na",
    "cajatambino": "ca-ja-tam-bi-no",
    "cajear": "ca-je-ar",
    "cajel": "ca-jel",
    "cajera": "ca-je-ra",
    "cajería": "ca-je-rí-a",
    "cajero": "ca-je-ro",
    "cajeta": "ca-je-ta",
    "cajete": "ca-je-te",
    "cajetear": "ca-je-te-ar",
    "cajetilla": "ca-je-ti-lla",
    "cajetín": "ca-je-tín",
    "cají": "ca-jí",
    "cajiga": "ca-ji-ga",
    "cajigal": "ca-ji-gal",
    "cajigo": "ca-ji-go",
    "cajilla": "ca-ji-lla",
    "cajín": "ca-jín",
    "cajista": "ca-jis-ta",
    "cajo": "ca-jo",
    "cajón": "ca-jón",
    "cajonada": "ca-jo-na-da",
    "cajonera": "ca-jo-ne-ra",
    "cajonería": "ca-jo-ne-rí-a",
    "cajonero": "ca-jo-ne-ro",
    "cajonga": "ca-jon-ga",
    "cajuela": "ca-jue-la",
    "cajuil": "ca-juil",
    "cakchiquel": "cak-chi-quel",
    "cake": "ca-ke",
    "cala": "ca-la",
    "calaba": "ca-la-ba",
    "calabacear": "ca-la-ba-ce-ar",
    "calabacera": "ca-la-ba-ce-ra",
    "calabacero": "ca-la-ba-ce-ro",
    "calabacil": "ca-la-ba-cil",
    "calabacilla": "ca-la-ba-ci-lla",
    "calabacín": "ca-la-ba-cín",
    "calabacinate": "ca-la-ba-ci-na-te",
    "calabacino": "ca-la-ba-ci-no",
    "calabacita": "ca-la-ba-ci-ta",
    "calabaza": "ca-la-ba-za",
    "calabazada": "ca-la-ba-za-da",
    "calabazar": "ca-la-ba-zar",
    "calabazate": "ca-la-ba-za-te",
    "calabazazo": "ca-la-ba-za-zo",
    "calabazo": "ca-la-ba-zo",
    "calabazón": "ca-la-ba-zón",
    "calabazona": "ca-la-ba-zo-na",
    "calabazuela": "ca-la-ba-zue-la",
    "calabobos": "ca-la-bo-bos",
    "calabocero": "ca-la-bo-ce-ro",
    "calabozaje": "ca-la-bo-za-je",
    "calabozo": "ca-la-bo-zo",
    "calabrés": "ca-la-brés",
    "calabresa": "ca-la-bre-sa",
    "calabriada": "ca-la-bria-da",
    "calabriar": "ca-la-briar",
    "calabrotar": "ca-la-bro-tar",
    "calabrote": "ca-la-bro-te",
    "calaca": "ca-la-ca",
    "calacear": "ca-la-ce-ar",
    "calache": "ca-la-che",
    "calacuerda": "ca-la-cuer-da",
    "calada": "ca-la-da",
    "caladera": "ca-la-de-ra",
    "caladero": "ca-la-de-ro",
    "calado": "ca-la-do",
    "calador": "ca-la-dor",
    "caladora": "ca-la-do-ra",
    "caladre": "ca-la-dre",
    "caladura": "ca-la-du-ra",
    "calafate": "ca-la-fa-te",
    "calafateado": "ca-la-fa-te-a-do",
    "calafateador": "ca-la-fa-te-a-dor",
    "calafateadora": "ca-la-fa-te-a-do-ra",
    "calafateadura": "ca-la-fa-te-a-du-ra",
    "calafatear": "ca-la-fa-te-ar",
    "calafateo": "ca-la-fa-te-o",
    "calafatería": "ca-la-fa-te-rí-a",
    "calafatín": "ca-la-fa-tín",
    "calafetear": "ca-la-fe-te-ar",
    "calagozo": "ca-la-go-zo",
    "calagraña": "ca-la-gra-ña",
    "calaguala": "ca-la-gua-la",
    "calaguasca": "ca-la-guas-ca",
    "calaguastazo": "ca-la-guas-ta-zo",
    "calagurritana": "ca-la-gu-rri-ta-na",
    "calagurritano": "ca-la-gu-rri-ta-no",
    "calahorra": "ca-la-ho-rra",
    "calahorrana": "ca-la-ho-rra-na",
    "calahorrano": "ca-la-ho-rra-no",
    "calahorreña": "ca-la-ho-rre-ña",
    "calahorreño": "ca-la-ho-rre-ño",
    "calaica": "ca-lai-ca",
    "calaínos": "ca-la-í-nos",
    "calaíta": "ca-la-í-ta",
    "calaje": "ca-la-je",
    "calaluz": "ca-la-luz",
    "calamaco": "ca-la-ma-co",
    "calamar": "ca-la-mar",
    "calamarqueña": "ca-la-mar-que-ña",
    "calamarqueño": "ca-la-mar-que-ño",
    "calambac": "ca-lam-bac",
    "calambre": "ca-lam-bre",
    "calambreña": "ca-lam-bre-ña",
    "calambrina": "ca-lam-bri-na",
    "calambuca": "ca-lam-bu-ca",
    "calambuco": "ca-lam-bu-co",
    "calambur": "ca-lam-bur",
    "calameña": "ca-la-me-ña",
    "calameño": "ca-la-me-ño",
    "calamento": "ca-la-men-to",
    "calamidad": "ca-la-mi-dad",
    "calamiforme": "ca-la-mi-for-me",
    "calamillera": "ca-la-mi-lle-ra",
    "calamina": "ca-la-mi-na",
    "calaminar": "ca-la-mi-nar",
    "calaminta": "ca-la-min-ta",
    "calamistro": "ca-la-mis-tro",
    "calamita": "ca-la-mi-ta",
    "calamite": "ca-la-mi-te",
    "calamitosa": "ca-la-mi-to-sa",
    "calamitosamente": "ca-la-mi-to-sa-men-te",
    "calamitoso": "ca-la-mi-to-so",
    "cálamo": "cá-la-mo",
    "calamocana": "ca-la-mo-ca-na",
    "calamocano": "ca-la-mo-ca-no",
    "calamocha": "ca-la-mo-cha",
    "calamoco": "ca-la-mo-co",
    "calamón": "ca-la-món",
    "calamonar": "ca-la-mo-nar",
    "calamonarse": "ca-la-mo-nar-se",
    "calamorra": "ca-la-mo-rra",
    "calamorrada": "ca-la-mo-rra-da",
    "calamorrar": "ca-la-mo-rrar",
    "calamorrazo": "ca-la-mo-rra-zo",
    "calamorro": "ca-la-mo-rro",
    "calán": "ca-lán",
    "calaña": "ca-la-ña",
    "calañas": "ca-la-ñas",
    "calancanear": "ca-lan-ca-ne-ar",
    "calancas": "ca-lan-cas",
    "calancho": "ca-lan-cho",
    "calandina": "ca-lan-di-na",
    "calandino": "ca-lan-di-no",
    "calandra": "ca-lan-dra",
    "calandraca": "ca-lan-dra-ca",
    "calandraco": "ca-lan-dra-co",
    "calandrado": "ca-lan-dra-do",
    "calandrajo": "ca-lan-dra-jo",
    "calandrar": "ca-lan-drar",
    "calandria": "ca-lan-dria",
    "calañés": "ca-la-ñés",
    "calañesa": "ca-la-ñe-sa",
    "cálanis": "cá-la-nis",
    "calaño": "ca-la-ño",
    "calántica": "ca-lán-ti-ca",
    "cálao": "cá-la-o",
    "calapé": "ca-la-pé",
    "calapié": "ca-la-pié",
    "calar": "ca-lar",
    "calasancia": "ca-la-san-cia",
    "calasancio": "ca-la-san-cio",
    "calata": "ca-la-ta",
    "calate": "ca-la-te",
    "calato": "ca-la-to",
    "cálato": "cá-la-to",
    "calatoso": "ca-la-to-so",
    "calatrava": "ca-la-tra-va",
    "calatraveña": "ca-la-tra-ve-ña",
    "calatraveño": "ca-la-tra-ve-ño",
    "calatravo": "ca-la-tra-vo",
    "calavera": "ca-la-ve-ra",
    "calaverada": "ca-la-ve-ra-da",
    "calaverear": "ca-la-ve-re-ar",
    "calaverna": "ca-la-ver-na",
    "calavernario": "ca-la-ver-na-rio",
    "calavero": "ca-la-ve-ro",
    "calaverón": "ca-la-ve-rón",
    "calazo": "ca-la-zo",
    "calboche": "cal-bo-che",
    "calbote": "cal-bo-te",
    "calbotes": "cal-bo-tes",
    "calca": "cal-ca",
    "calcado": "cal-ca-do",
    "calcador": "cal-ca-dor",
    "calcadora": "cal-ca-do-ra",
    "calcañal": "cal-ca-ñal",
    "calcañar": "cal-ca-ñar",
    "calcáneo": "cal-cá-ne-o",
    "calcaño": "cal-ca-ño",
    "calcañuelo": "cal-ca-ñue-lo",
    "calcar": "cal-car",
    "calcárea": "cal-cá-re-a",
    "calcáreo": "cal-cá-re-o",
    "calce": "cal-ce",
    "calceatense": "cal-ce-a-ten-se",
    "calcedonense": "cal-ce-do-nen-se",
    "calcedonia": "cal-ce-do-nia",
    "calcedonio": "cal-ce-do-nio",
    "calcemia": "cal-ce-mia",
    "cálceo": "cál-ce-o",
    "calceolaria": "cal-ce-o-la-ria",
    "calcés": "cal-cés",
    "calceta": "cal-ce-ta",
    "calcetar": "cal-ce-tar",
    "calcetas": "cal-ce-tas",
    "calcetera": "cal-ce-te-ra",
    "calcetería": "cal-ce-te-rí-a",
    "calcetero": "cal-ce-te-ro",
    "calcetín": "cal-ce-tín",
    "calceto": "cal-ce-to",
    "calcetón": "cal-ce-tón",
    "calcha": "cal-cha",
    "calchacura": "cal-cha-cu-ra",
    "calchaquí": "cal-cha-quí",
    "calchín": "cal-chín",
    "calchón": "cal-chón",
    "calchona": "cal-cho-na",
    "calchuda": "cal-chu-da",
    "calchudo": "cal-chu-do",
    "cálcica": "cál-ci-ca",
    "cálcico": "cál-ci-co",
    "calcicosis": "cal-ci-co-sis",
    "calcídico": "cal-cí-di-co",
    "calciferol": "cal-ci-fe-rol",
    "calcificación": "cal-ci-fi-ca-ción",
    "calcificar": "cal-ci-fi-car",
    "calcillas": "cal-ci-llas",
    "calcímetro": "cal-cí-me-tro",
    "calcina": "cal-ci-na",
    "calcinable": "cal-ci-na-ble",
    "calcinación": "cal-ci-na-ción",
    "calcinado": "cal-ci-na-do",
    "calcinador": "cal-ci-na-dor",
    "calcinadora": "cal-ci-na-do-ra",
    "calcinamiento": "cal-ci-na-mien-to",
    "calcinar": "cal-ci-nar",
    "calcinatorio": "cal-ci-na-to-rio",
    "calcinero": "cal-ci-ne-ro",
    "calcio": "cal-cio",
    "calciotermia": "cal-cio-ter-mia",
    "calcita": "cal-ci-ta",
    "calcitonina": "cal-ci-to-ni-na",
    "calcitrapa": "cal-ci-tra-pa",
    "calco": "cal-co",
    "calcógrafa": "cal-có-gra-fa",
    "calcografía": "cal-co-gra-fí-a",
    "calcografiar": "cal-co-gra-fiar",
    "calcográfica": "cal-co-grá-fi-ca",
    "calcográfico": "cal-co-grá-fi-co",
    "calcógrafo": "cal-có-gra-fo",
    "calcolítica": "cal-co-lí-ti-ca",
    "calcolítico": "cal-co-lí-ti-co",
    "calcomanía": "cal-co-ma-ní-a",
    "calcopirita": "cal-co-pi-ri-ta",
    "calcorrear": "cal-co-rre-ar",
    "calcorro": "cal-co-rro",
    "calcotipia": "cal-co-ti-pia",
    "calculable": "cal-cu-la-ble",
    "calculación": "cal-cu-la-ción",
    "calculadamente": "cal-cu-la-da-men-te",
    "calculador": "cal-cu-la-dor",
    "calculadora": "cal-cu-la-do-ra",
    "calcular": "cal-cu-lar",
    "calculatoria": "cal-cu-la-to-ria",
    "calculatorio": "cal-cu-la-to-rio",
    "calculista": "cal-cu-lis-ta",
    "cálculo": "cál-cu-lo",
    "calculosa": "cal-cu-lo-sa",
    "calculoso": "cal-cu-lo-so",
    "calcutense": "cal-cu-ten-se",
    "calda": "cal-da",
    "caldaica": "cal-dai-ca",
    "caldaico": "cal-dai-co",
    "caldaria": "cal-da-ria",
    "caldario": "cal-da-rio",
    "caldea": "cal-de-a",
    "caldeamiento": "cal-de-a-mien-to",
    "caldear": "cal-de-ar",
    "caldeísmo": "cal-de-ís-mo",
    "caldén": "cal-dén",
    "caldense": "cal-den-se",
    "caldeo": "cal-de-o",
    "caldera": "cal-de-ra",
    "calderada": "cal-de-ra-da",
    "calderera": "cal-de-re-ra",
    "calderería": "cal-de-re-rí-a",
    "calderero": "cal-de-re-ro",
    "caldereta": "cal-de-re-ta",
    "calderetera": "cal-de-re-te-ra",
    "calderetero": "cal-de-re-te-ro",
    "calderil": "cal-de-ril",
    "calderilla": "cal-de-ri-lla",
    "calderín": "cal-de-rín",
    "caldero": "cal-de-ro",
    "calderón": "cal-de-rón",
    "calderoniana": "cal-de-ro-nia-na",
    "calderoniano": "cal-de-ro-nia-no",
    "calderuela": "cal-de-rue-la",
    "caldibache": "cal-di-ba-che",
    "caldibaldo": "cal-di-bal-do",
    "caldillo": "cal-di-llo",
    "caldo": "cal-do",
    "caldosa": "cal-do-sa",
    "caldoso": "cal-do-so",
    "caldúa": "cal-dú-a",
    "calducho": "cal-du-cho",
    "calduda": "cal-du-da",
    "caldudo": "cal-du-do",
    "cale": "ca-le",
    "calé": "ca-lé",
    "caledonia": "ca-le-do-nia",
    "caledoniano": "ca-le-do-nia-no",
    "caledonio": "ca-le-do-nio",
    "calefacción": "ca-le-fac-ción",
    "calefaccionar": "ca-le-fac-cio-nar",
    "calefactable": "ca-le-fac-ta-ble",
    "calefactor": "ca-le-fac-tor",
    "calefactora": "ca-le-fac-to-ra",
    "calefactorio": "ca-le-fac-to-rio",
    "calefón": "ca-le-fón",
    "caleidoscópico": "ca-lei-dos-có-pi-co",
    "caleidoscopio": "ca-lei-dos-co-pio",
    "calejo": "ca-le-jo",
    "caleña": "ca-le-ña",
    "calenda": "ca-len-da",
    "calendar": "ca-len-dar",
    "calendario": "ca-len-da-rio",
    "calendarista": "ca-len-da-ris-ta",
    "calendarización": "ca-len-da-ri-za-ción",
    "calendarizar": "ca-len-da-ri-zar",
    "calendas": "ca-len-das",
    "caléndula": "ca-lén-du-la",
    "caleño": "ca-le-ño",
    "calentado": "ca-len-ta-do",
    "calentador": "ca-len-ta-dor",
    "calentadora": "ca-len-ta-do-ra",
    "calentamiento": "ca-len-ta-mien-to",
    "calentana": "ca-len-ta-na",
    "calentano": "ca-len-ta-no",
    "calentar": "ca-len-tar",
    "calentera": "ca-len-te-ra",
    "calentita": "ca-len-ti-ta",
    "calentito": "ca-len-ti-to",
    "calentón": "ca-len-tón",
    "calentona": "ca-len-to-na",
    "calentorro": "ca-len-to-rro",
    "calentura": "ca-len-tu-ra",
    "calenturienta": "ca-len-tu-rien-ta",
    "calenturiento": "ca-len-tu-rien-to",
    "calenturón": "ca-len-tu-rón",
    "calenturosa": "ca-len-tu-ro-sa",
    "calenturoso": "ca-len-tu-ro-so",
    "calepino": "ca-le-pi-no",
    "caler": "ca-ler",
    "calera": "ca-le-ra",
    "calería": "ca-le-rí-a",
    "calero": "ca-le-ro",
    "calés": "ca-lés",
    "calesa": "ca-le-sa",
    "calesera": "ca-le-se-ra",
    "calesero": "ca-le-se-ro",
    "calesín": "ca-le-sín",
    "calesinero": "ca-le-si-ne-ro",
    "calesita": "ca-le-si-ta",
    "caleta": "ca-le-ta",
    "caletear": "ca-le-te-ar",
    "caletero": "ca-le-te-ro",
    "caleto": "ca-le-to",
    "caletre": "ca-le-tre",
    "caletrero": "ca-le-tre-ro",
    "caleza": "ca-le-za",
    "cali": "ca-li",
    "cálibe": "cá-li-be",
    "cálibo": "cá-li-bo",
    "calibración": "ca-li-bra-ción",
    "calibrado": "ca-li-bra-do",
    "calibrador": "ca-li-bra-dor",
    "calibrar": "ca-li-brar",
    "calibre": "ca-li-bre",
    "calicanto": "ca-li-can-to",
    "calicata": "ca-li-ca-ta",
    "cálice": "cá-li-ce",
    "caliche": "ca-li-che",
    "calichera": "ca-li-che-ra",
    "caliciflora": "ca-li-ci-flo-ra",
    "caliciforme": "ca-li-ci-for-me",
    "calicillo": "ca-li-ci-llo",
    "calicinal": "ca-li-ci-nal",
    "calicó": "ca-li-có",
    "calicud": "ca-li-cud",
    "caliculada": "ca-li-cu-la-da",
    "caliculado": "ca-li-cu-la-do",
    "calicular": "ca-li-cu-lar",
    "calículo": "ca-lí-cu-lo",
    "calicut": "ca-li-cut",
    "cálida": "cá-li-da",
    "calidad": "ca-li-dad",
    "cálidamente": "cá-li-da-men-te",
    "calidez": "ca-li-dez",
    "cálido": "cá-li-do",
    "calidonia": "ca-li-do-nia",
    "calidonio": "ca-li-do-nio",
    "calidoscópica": "ca-li-dos-có-pi-ca",
    "calidoscópico": "ca-li-dos-có-pi-co",
    "calidoscopio": "ca-li-dos-co-pio",
    "calientabraguetas": "ca-lien-ta-bra-gue-tas",
    "calientacamas": "ca-lien-ta-ca-mas",
    "calientapiés": "ca-lien-ta-piés",
    "calientaplatos": "ca-lien-ta-pla-tos",
    "calientapollas": "ca-lien-ta-po-llas",
    "caliente": "ca-lien-te",
    "calientemente": "ca-lien-te-men-te",
    "califa": "ca-li-fa",
    "califal": "ca-li-fal",
    "califato": "ca-li-fa-to",
    "calífero": "ca-lí-fe-ro",
    "calificable": "ca-li-fi-ca-ble",
    "calificación": "ca-li-fi-ca-ción",
    "calificada": "ca-li-fi-ca-da",
    "calificadamente": "ca-li-fi-ca-da-men-te",
    "calificado": "ca-li-fi-ca-do",
    "calificador": "ca-li-fi-ca-dor",
    "calificadora": "ca-li-fi-ca-do-ra",
    "calificar": "ca-li-fi-car",
    "calificativa": "ca-li-fi-ca-ti-va",
    "calificativo": "ca-li-fi-ca-ti-vo",
    "california": "ca-li-for-nia",
    "californiana": "ca-li-for-nia-na",
    "californiano": "ca-li-for-nia-no",
    "califórnica": "ca-li-fór-ni-ca",
    "califórnico": "ca-li-fór-ni-co",
    "californio": "ca-li-for-nio",
    "cáliga": "cá-li-ga",
    "calígine": "ca-lí-gi-ne",
    "caliginosa": "ca-li-gi-no-sa",
    "caliginoso": "ca-li-gi-no-so",
    "calígrafa": "ca-lí-gra-fa",
    "caligrafía": "ca-li-gra-fí-a",
    "caligrafiar": "ca-li-gra-fiar",
    "caligráfica": "ca-li-grá-fi-ca",
    "caligráficamente": "ca-li-grá-fi-ca-men-te",
    "caligráfico": "ca-li-grá-fi-co",
    "calígrafo": "ca-lí-gra-fo",
    "caligrama": "ca-li-gra-ma",
    "calilla": "ca-li-lla",
    "calima": "ca-li-ma",
    "calimaco": "ca-li-ma-co",
    "calimba": "ca-lim-ba",
    "calimbar": "ca-lim-bar",
    "calimbo": "ca-lim-bo",
    "calimocho": "ca-li-mo-cho",
    "calimosa": "ca-li-mo-sa",
    "calimoso": "ca-li-mo-so",
    "calimote": "ca-li-mo-te",
    "calina": "ca-li-na",
    "calinguero": "ca-lin-gue-ro",
    "calinosa": "ca-li-no-sa",
    "calinoso": "ca-li-no-so",
    "calípedes": "ca-lí-pe-des",
    "calipedia": "ca-li-pe-dia",
    "calipédica": "ca-li-pé-di-ca",
    "calipédico": "ca-li-pé-di-co",
    "calípico": "ca-lí-pi-co",
    "calipso": "ca-lip-so",
    "caliptra": "ca-lip-tra",
    "caliqueño": "ca-li-que-ño",
    "calisaya": "ca-li-sa-ya",
    "calistenia": "ca-lis-te-nia",
    "calitipia": "ca-li-ti-pia",
    "calivo": "ca-li-vo",
    "cáliz": "cá-liz",
    "caliza": "ca-li-za",
    "calizo": "ca-li-zo",
    "calla": "ca-lla",
    "callabuaya": "ca-lla-bua-ya",
    "callacuece": "ca-lla-cue-ce",
    "callada": "ca-lla-da",
    "calladamente": "ca-lla-da-men-te",
    "callado": "ca-lla-do",
    "callador": "ca-lla-dor",
    "calladora": "ca-lla-do-ra",
    "callamiento": "ca-lla-mien-to",
    "callampa": "ca-llam-pa",
    "callana": "ca-lla-na",
    "callandico": "ca-llan-di-co",
    "callandito": "ca-llan-di-to",
    "callando": "ca-llan-do",
    "callantar": "ca-llan-tar",
    "callanuda": "ca-lla-nu-da",
    "callanudo": "ca-lla-nu-do",
    "callao": "ca-lla-o",
    "callapo": "ca-lla-po",
    "callar": "ca-llar",
    "calle": "ca-lle",
    "callear": "ca-lle-ar",
    "callecalle": "ca-lle-ca-lle",
    "calleja": "ca-lle-ja",
    "callejear": "ca-lle-je-ar",
    "callejeo": "ca-lle-je-o",
    "callejera": "ca-lle-je-ra",
    "callejero": "ca-lle-je-ro",
    "callejo": "ca-lle-jo",
    "callejón": "ca-lle-jón",
    "callejuela": "ca-lle-jue-la",
    "callentar": "ca-llen-tar",
    "callera": "ca-lle-ra",
    "calletre": "ca-lle-tre",
    "callialta": "ca-llial-ta",
    "callialto": "ca-llial-to",
    "callicida": "ca-lli-ci-da",
    "callista": "ca-llis-ta",
    "callizo": "ca-lli-zo",
    "callo": "ca-llo",
    "callón": "ca-llón",
    "callonca": "ca-llon-ca",
    "callosa": "ca-llo-sa",
    "callosar": "ca-llo-sar",
    "callosidad": "ca-llo-si-dad",
    "calloso": "ca-llo-so",
    "callosotomía": "ca-llo-so-to-mí-a",
    "callueso": "ca-llue-so",
    "calma": "cal-ma",
    "calmante": "cal-man-te",
    "calmar": "cal-mar",
    "calmaría": "cal-ma-rí-a",
    "calmatol": "cal-ma-tol",
    "calmazo": "cal-ma-zo",
    "calmería": "cal-me-rí-a",
    "calmo": "cal-mo",
    "calmosa": "cal-mo-sa",
    "calmosamente": "cal-mo-sa-men-te",
    "calmoso": "cal-mo-so",
    "calmuca": "cal-mu-ca",
    "calmuco": "cal-mu-co",
    "calmuda": "cal-mu-da",
    "calmudo": "cal-mu-do",
    "calnado": "cal-na-do",
    "calo": "ca-lo",
    "caló": "ca-ló",
    "calobiótica": "ca-lo-bió-ti-ca",
    "calocéfala": "ca-lo-cé-fa-la",
    "calocéfalo": "ca-lo-cé-fa-lo",
    "calofila": "ca-lo-fi-la",
    "calofilo": "ca-lo-fi-lo",
    "calofriar": "ca-lo-friar",
    "calofriarse": "ca-lo-friar-se",
    "calofrío": "ca-lo-frí-o",
    "calografía": "ca-lo-gra-fí-a",
    "calología": "ca-lo-lo-gí-a",
    "caloma": "ca-lo-ma",
    "calomel": "ca-lo-mel",
    "calomelanos": "ca-lo-me-la-nos",
    "calón": "ca-lón",
    "caloña": "ca-lo-ña",
    "caloñar": "ca-lo-ñar",
    "calonche": "ca-lon-che",
    "calonge": "ca-lon-ge",
    "calongía": "ca-lon-gí-a",
    "caloniar": "ca-lo-niar",
    "calóptera": "ca-lóp-te-ra",
    "calóptero": "ca-lóp-te-ro",
    "calor": "ca-lor",
    "caloría": "ca-lo-rí-a",
    "caloriamperímetro": "ca-lo-riam-pe-rí-me-tro",
    "caloricidad": "ca-lo-ri-ci-dad",
    "calórico": "ca-ló-ri-co",
    "calorídoro": "ca-lo-rí-do-ro",
    "calorífera": "ca-lo-rí-fe-ra",
    "calorífero": "ca-lo-rí-fe-ro",
    "calorífica": "ca-lo-rí-fi-ca",
    "calorificación": "ca-lo-ri-fi-ca-ción",
    "calorífico": "ca-lo-rí-fi-co",
    "calorífugo": "ca-lo-rí-fu-go",
    "calorimetría": "ca-lo-ri-me-trí-a",
    "calorimétrica": "ca-lo-ri-mé-tri-ca",
    "calorimétrico": "ca-lo-ri-mé-tri-co",
    "calorímetro": "ca-lo-rí-me-tro",
    "calorina": "ca-lo-ri-na",
    "calorón": "ca-lo-rón",
    "calorosa": "ca-lo-ro-sa",
    "calorosamente": "ca-lo-ro-sa-men-te",
    "caloroso": "ca-lo-ro-so",
    "calosa": "ca-lo-sa",
    "calosfriar": "ca-los-friar",
    "calosfriarse": "ca-los-friar-se",
    "calosfrío": "ca-los-frí-o",
    "caloso": "ca-lo-so",
    "calostro": "ca-los-tro",
    "calote": "ca-lo-te",
    "calotear": "ca-lo-te-ar",
    "calotipia": "ca-lo-ti-pia",
    "caloyo": "ca-lo-yo",
    "calpamula": "cal-pa-mu-la",
    "calpamulo": "cal-pa-mu-lo",
    "calpense": "cal-pen-se",
    "calpián": "cal-pián",
    "calpixque": "cal-pix-que",
    "calpul": "cal-pul",
    "calpulli": "cal-pu-lli",
    "calqueña": "cal-que-ña",
    "calqueño": "cal-que-ño",
    "calquín": "cal-quín",
    "calseca": "cal-se-ca",
    "calseco": "cal-se-co",
    "calta": "cal-ta",
    "calucha": "ca-lu-cha",
    "caluga": "ca-lu-ga",
    "caluguiento": "ca-lu-guien-to",
    "caluma": "ca-lu-ma",
    "calumbo": "ca-lum-bo",
    "calumbre": "ca-lum-bre",
    "calumbrecer": "ca-lum-bre-cer",
    "calumbrecerse": "ca-lum-bre-cer-se",
    "calumbrienta": "ca-lum-brien-ta",
    "calumbriento": "ca-lum-brien-to",
    "calumet": "ca-lu-met",
    "calumnia": "ca-lum-nia",
    "calumniador": "ca-lum-nia-dor",
    "calumniadora": "ca-lum-nia-do-ra",
    "calumniar": "ca-lum-niar",
    "calumniosa": "ca-lum-nio-sa",
    "calumniosamente": "ca-lum-nio-sa-men-te",
    "calumnioso": "ca-lum-nio-so",
    "calungo": "ca-lun-go",
    "calura": "ca-lu-ra",
    "caluro": "ca-lu-ro",
    "calurosa": "ca-lu-ro-sa",
    "calurosamente": "ca-lu-ro-sa-men-te",
    "caluroso": "ca-lu-ro-so",
    "caluyo": "ca-lu-yo",
    "calva": "cal-va",
    "calvados": "cal-va-dos",
    "calvar": "cal-var",
    "calvario": "cal-va-rio",
    "calvatrueno": "cal-va-true-no",
    "calveriza": "cal-ve-ri-za",
    "calverizo": "cal-ve-ri-zo",
    "calvero": "cal-ve-ro",
    "calvete": "cal-ve-te",
    "calvez": "cal-vez",
    "calvicie": "cal-vi-cie",
    "calvijar": "cal-vi-jar",
    "calvinismo": "cal-vi-nis-mo",
    "calvinista": "cal-vi-nis-ta",
    "calvitar": "cal-vi-tar",
    "calvo": "cal-vo",
    "calvorota": "cal-vo-ro-ta",
    "calypso": "calyp-so",
    "calza": "cal-za",
    "calzacalzón": "cal-za-cal-zón",
    "calzada": "cal-za-da",
    "calzadera": "cal-za-de-ra",
    "calzado": "cal-za-do",
    "calzador": "cal-za-dor",
    "calzadura": "cal-za-du-ra",
    "calzar": "cal-zar",
    "calzatrepas": "cal-za-tre-pas",
    "calzo": "cal-zo",
    "calzón": "cal-zón",
    "calzona": "cal-zo-na",
    "calzonarias": "cal-zo-na-rias",
    "calzonario": "cal-zo-na-rio",
    "calzonazos": "cal-zo-na-zos",
    "calzoncillo": "cal-zon-ci-llo",
    "calzoneras": "cal-zo-ne-ras",
    "calzoneta": "cal-zo-ne-ta",
    "calzonudo": "cal-zo-nu-do",
    "calzorras": "cal-zo-rras",
    "cama": "ca-ma",
    "camacero": "ca-ma-ce-ro",
    "camachile": "ca-ma-chi-le",
    "camachuelo": "ca-ma-chue-lo",
    "camada": "ca-ma-da",
    "camafeo": "ca-ma-fe-o",
    "camagón": "ca-ma-gón",
    "camagua": "ca-ma-gua",
    "camagüe": "ca-ma-güe",
    "camagüeyana": "ca-ma-güe-ya-na",
    "camagüeyano": "ca-ma-güe-ya-no",
    "camagüira": "ca-ma-güi-ra",
    "camahuas": "ca-ma-huas",
    "camaján": "ca-ma-ján",
    "camajana": "ca-ma-ja-na",
    "camal": "ca-mal",
    "camaldulense": "ca-mal-du-len-se",
    "camaleón": "ca-ma-le-ón",
    "camaleónica": "ca-ma-le-ó-ni-ca",
    "camaleónicamente": "ca-ma-le-ó-ni-ca-men-te",
    "camaleónico": "ca-ma-le-ó-ni-co",
    "camalero": "ca-ma-le-ro",
    "camalotal": "ca-ma-lo-tal",
    "camalote": "ca-ma-lo-te",
    "camama": "ca-ma-ma",
    "camambú": "ca-mam-bú",
    "camamila": "ca-ma-mi-la",
    "camanance": "ca-ma-nan-ce",
    "camanchaca": "ca-man-cha-ca",
    "camándula": "ca-mán-du-la",
    "camandulear": "ca-man-du-le-ar",
    "camandulense": "ca-man-du-len-se",
    "camandulera": "ca-man-du-le-ra",
    "camandulería": "ca-man-du-le-rí-a",
    "camandulero": "ca-man-du-le-ro",
    "camaneja": "ca-ma-ne-ja",
    "camanejo": "ca-ma-ne-jo",
    "camanonca": "ca-ma-non-ca",
    "camao": "ca-ma-o",
    "cámara": "cá-ma-ra",
    "camarada": "ca-ma-ra-da",
    "camaradería": "ca-ma-ra-de-rí-a",
    "camaraje": "ca-ma-ra-je",
    "camaranchón": "ca-ma-ran-chón",
    "camarera": "ca-ma-re-ra",
    "camarería": "ca-ma-re-rí-a",
    "camarero": "ca-ma-re-ro",
    "camareta": "ca-ma-re-ta",
    "camargueña": "ca-mar-gue-ña",
    "camargueño": "ca-mar-gue-ño",
    "camarico": "ca-ma-ri-co",
    "camarienta": "ca-ma-rien-ta",
    "camariento": "ca-ma-rien-to",
    "camarilla": "ca-ma-ri-lla",
    "camarillera": "ca-ma-ri-lle-ra",
    "camarillesca": "ca-ma-ri-lles-ca",
    "camarillesco": "ca-ma-ri-lles-co",
    "camarín": "ca-ma-rín",
    "camarina": "ca-ma-ri-na",
    "camariña": "ca-ma-ri-ña",
    "camarista": "ca-ma-ris-ta",
    "camarlengo": "ca-mar-len-go",
    "cámaro": "cá-ma-ro",
    "camarógrafa": "ca-ma-ró-gra-fa",
    "camarógrafo": "ca-ma-ró-gra-fo",
    "camarón": "ca-ma-rón",
    "camarona": "ca-ma-ro-na",
    "camaronada": "ca-ma-ro-na-da",
    "camaronear": "ca-ma-ro-ne-ar",
    "camaronera": "ca-ma-ro-ne-ra",
    "camaronero": "ca-ma-ro-ne-ro",
    "camarote": "ca-ma-ro-te",
    "camarotera": "ca-ma-ro-te-ra",
    "camarotero": "ca-ma-ro-te-ro",
    "camarroya": "ca-ma-rro-ya",
    "camarú": "ca-ma-rú",
    "camastro": "ca-mas-tro",
    "camastrón": "ca-mas-trón",
    "camastrona": "ca-mas-tro-na",
    "camastronería": "ca-mas-tro-ne-rí-a",
    "camatón": "ca-ma-tón",
    "camaza": "ca-ma-za",
    "camba": "cam-ba",
    "cambada": "cam-ba-da",
    "cambado": "cam-ba-do",
    "cambalachar": "cam-ba-la-char",
    "cambalache": "cam-ba-la-che",
    "cambalachear": "cam-ba-la-che-ar",
    "cambalachera": "cam-ba-la-che-ra",
    "cambalachero": "cam-ba-la-che-ro",
    "cambalada": "cam-ba-la-da",
    "cambaleo": "cam-ba-le-o",
    "camballada": "cam-ba-lla-da",
    "cambalud": "cam-ba-lud",
    "cambar": "cam-bar",
    "cambará": "cam-ba-rá",
    "cámbara": "cám-ba-ra",
    "cambarín": "cam-ba-rín",
    "cámbaro": "cám-ba-ro",
    "cambera": "cam-be-ra",
    "cambero": "cam-be-ro",
    "cambeta": "cam-be-ta",
    "cambeto": "cam-be-to",
    "cambiable": "cam-bia-ble",
    "cambiacasaca": "cam-bia-ca-sa-ca",
    "cambiada": "cam-bia-da",
    "cambiadiza": "cam-bia-di-za",
    "cambiadizo": "cam-bia-di-zo",
    "cambiador": "cam-bia-dor",
    "cambiadora": "cam-bia-do-ra",
    "cambiamiento": "cam-bia-mien-to",
    "cambiante": "cam-bian-te",
    "cambiar": "cam-biar",
    "cambiario": "cam-bia-rio",
    "cambiavía": "cam-bia-ví-a",
    "cambiazo": "cam-bia-zo",
    "cambija": "cam-bi-ja",
    "cambímbora": "cam-bím-bo-ra",
    "cambín": "cam-bín",
    "cambio": "cam-bio",
    "cambista": "cam-bis-ta",
    "cámbium": "cám-bium",
    "cambiza": "cam-bi-za",
    "cambizar": "cam-bi-zar",
    "cambizo": "cam-bi-zo",
    "cambo": "cam-bo",
    "cambocho": "cam-bo-cho",
    "cambón": "cam-bón",
    "cambote": "cam-bo-te",
    "camboyana": "cam-bo-ya-na",
    "camboyano": "cam-bo-ya-no",
    "camboyense": "cam-bo-yen-se",
    "camboyés": "cam-bo-yés",
    "camboyesa": "cam-bo-ye-sa",
    "cambra": "cam-bra",
    "cambray": "cam-bray",
    "cambrayada": "cam-bra-ya-da",
    "cambrayado": "cam-bra-ya-do",
    "cambrayón": "cam-bra-yón",
    "cambriana": "cam-bria-na",
    "cambriano": "cam-bria-no",
    "cámbrica": "cám-bri-ca",
    "cámbrico": "cám-bri-co",
    "cambrillón": "cam-bri-llón",
    "cambrón": "cam-brón",
    "cambronal": "cam-bro-nal",
    "cambronera": "cam-bro-ne-ra",
    "cambroño": "cam-bro-ño",
    "cambrún": "cam-brún",
    "cambucha": "cam-bu-cha",
    "cambucho": "cam-bu-cho",
    "cambuj": "cam-buj",
    "cambuja": "cam-bu-ja",
    "cambujo": "cam-bu-jo",
    "cambullo": "cam-bu-llo",
    "cambullón": "cam-bu-llón",
    "cambullonera": "cam-bu-llo-ne-ra",
    "cambullonero": "cam-bu-llo-ne-ro",
    "cambur": "cam-bur",
    "cambural": "cam-bu-ral",
    "cambustera": "cam-bus-te-ra",
    "cambuta": "cam-bu-ta",
    "cambute": "cam-bu-te",
    "cambutera": "cam-bu-te-ra",
    "cambuto": "cam-bu-to",
    "camedrio": "ca-me-drio",
    "camedris": "ca-me-dris",
    "camedrita": "ca-me-dri-ta",
    "camelador": "ca-me-la-dor",
    "cameladora": "ca-me-la-do-ra",
    "camelar": "ca-me-lar",
    "camelete": "ca-me-le-te",
    "camelia": "ca-me-lia",
    "camélido": "ca-mé-li-do",
    "cameliea": "ca-me-lie-a",
    "camelieo": "ca-me-lie-o",
    "camelina": "ca-me-li-na",
    "camelio": "ca-me-lio",
    "camelista": "ca-me-lis-ta",
    "camelístico": "ca-me-lís-ti-co",
    "camella": "ca-me-lla",
    "camellada": "ca-me-lla-da",
    "camellar": "ca-me-llar",
    "camellera": "ca-me-lle-ra",
    "camellería": "ca-me-lle-rí-a",
    "camellero": "ca-me-lle-ro",
    "camello": "ca-me-llo",
    "camellón": "ca-me-llón",
    "camelo": "ca-me-lo",
    "camelotada": "ca-me-lo-ta-da",
    "camelotado": "ca-me-lo-ta-do",
    "camelote": "ca-me-lo-te",
    "camelotina": "ca-me-lo-ti-na",
    "camelotón": "ca-me-lo-tón",
    "camember": "ca-mem-ber",
    "camembert": "ca-mem-bert",
    "camena": "ca-me-na",
    "camenal": "ca-me-nal",
    "camera": "ca-me-ra",
    "camerá": "ca-me-rá",
    "cameral": "ca-me-ral",
    "camerana": "ca-me-ra-na",
    "camerano": "ca-me-ra-no",
    "camerino": "ca-me-ri-no",
    "camerístico": "ca-me-rís-ti-co",
    "camero": "ca-me-ro",
    "camerunés": "ca-me-ru-nés",
    "camerunesa": "ca-me-ru-ne-sa",
    "camiar": "ca-miar",
    "camias": "ca-mias",
    "camíbar": "ca-mí-bar",
    "cámica": "cá-mi-ca",
    "camicace": "ca-mi-ca-ce",
    "camilita": "ca-mi-li-ta",
    "camilito": "ca-mi-li-to",
    "camilla": "ca-mi-lla",
    "camillera": "ca-mi-lle-ra",
    "camillero": "ca-mi-lle-ro",
    "camilo": "ca-mi-lo",
    "camilucha": "ca-mi-lu-cha",
    "camilucho": "ca-mi-lu-cho",
    "caminada": "ca-mi-na-da",
    "caminador": "ca-mi-na-dor",
    "caminadora": "ca-mi-na-do-ra",
    "caminante": "ca-mi-nan-te",
    "caminar": "ca-mi-nar",
    "caminata": "ca-mi-na-ta",
    "caminera": "ca-mi-ne-ra",
    "caminero": "ca-mi-ne-ro",
    "caminí": "ca-mi-ní",
    "camino": "ca-mi-no",
    "cámino": "cá-mi-no",
    "camio": "ca-mio",
    "camión": "ca-mión",
    "camionada": "ca-mio-na-da",
    "camionado": "ca-mio-na-do",
    "camionaje": "ca-mio-na-je",
    "camionera": "ca-mio-ne-ra",
    "camionero": "ca-mio-ne-ro",
    "camioneta": "ca-mio-ne-ta",
    "camionetilla": "ca-mio-ne-ti-lla",
    "camireña": "ca-mi-re-ña",
    "camireño": "ca-mi-re-ño",
    "camisa": "ca-mi-sa",
    "camiseado": "ca-mi-se-a-do",
    "camisera": "ca-mi-se-ra",
    "camisería": "ca-mi-se-rí-a",
    "camisero": "ca-mi-se-ro",
    "camiseta": "ca-mi-se-ta",
    "camisilla": "ca-mi-si-lla",
    "camisola": "ca-mi-so-la",
    "camisolín": "ca-mi-so-lín",
    "camisón": "ca-mi-són",
    "camisote": "ca-mi-so-te",
    "camita": "ca-mi-ta",
    "camítica": "ca-mí-ti-ca",
    "camítico": "ca-mí-ti-co",
    "camitosemítico": "ca-mi-to-se-mí-ti-co",
    "camoatí": "ca-mo-a-tí",
    "camocán": "ca-mo-cán",
    "camochar": "ca-mo-char",
    "camomila": "ca-mo-mi-la",
    "camón": "ca-món",
    "camonadura": "ca-mo-na-du-ra",
    "camoncillo": "ca-mon-ci-llo",
    "camorra": "ca-mo-rra",
    "camorrear": "ca-mo-rre-ar",
    "camorrera": "ca-mo-rre-ra",
    "camorrero": "ca-mo-rre-ro",
    "camorrista": "ca-mo-rris-ta",
    "camota": "ca-mo-ta",
    "camotal": "ca-mo-tal",
    "camote": "ca-mo-te",
    "camotear": "ca-mo-te-ar",
    "camotera": "ca-mo-te-ra",
    "camotero": "ca-mo-te-ro",
    "camotillo": "ca-mo-ti-llo",
    "camotudo": "ca-mo-tu-do",
    "campa": "cam-pa",
    "campago": "cam-pa-go",
    "cámpago": "cám-pa-go",
    "campal": "cam-pal",
    "campamental": "cam-pa-men-tal",
    "campamento": "cam-pa-men-to",
    "campamiento": "cam-pa-mien-to",
    "campamocha": "cam-pa-mo-cha",
    "campana": "cam-pa-na",
    "campaña": "cam-pa-ña",
    "campanada": "cam-pa-na-da",
    "campanario": "cam-pa-na-rio",
    "campanazo": "cam-pa-na-zo",
    "campanear": "cam-pa-ne-ar",
    "campanela": "cam-pa-ne-la",
    "campaneo": "cam-pa-ne-o",
    "campanero": "cam-pa-ne-ro",
    "campaniforme": "cam-pa-ni-for-me",
    "campanil": "cam-pa-nil",
    "campanilla": "cam-pa-ni-lla",
    "campanillazo": "cam-pa-ni-lla-zo",
    "campanillear": "cam-pa-ni-lle-ar",
    "campanilleo": "cam-pa-ni-lle-o",
    "campanillera": "cam-pa-ni-lle-ra",
    "campanillero": "cam-pa-ni-lle-ro",
    "campanillo": "cam-pa-ni-llo",
    "campañista": "cam-pa-ñis-ta",
    "campañisto": "cam-pa-ñis-to",
    "campanita": "cam-pa-ni-ta",
    "campano": "cam-pa-no",
    "campañol": "cam-pa-ñol",
    "campanóloga": "cam-pa-nó-lo-ga",
    "campanología": "cam-pa-no-lo-gí-a",
    "campanólogo": "cam-pa-nó-lo-go",
    "campante": "cam-pan-te",
    "campanuda": "cam-pa-nu-da",
    "campanudamente": "cam-pa-nu-da-men-te",
    "campanudo": "cam-pa-nu-do",
    "campánula": "cam-pá-nu-la",
    "campanulácea": "cam-pa-nu-lá-ce-a",
    "campanuláceas": "cam-pa-nu-lá-ce-as",
    "campanuláceo": "cam-pa-nu-lá-ce-o",
    "campar": "cam-par",
    "camparín": "cam-pa-rín",
    "campeada": "cam-pe-a-da",
    "campeador": "cam-pe-a-dor",
    "campear": "cam-pe-ar",
    "campechana": "cam-pe-cha-na",
    "campechanamente": "cam-pe-cha-na-men-te",
    "campechanería": "cam-pe-cha-ne-rí-a",
    "campechanía": "cam-pe-cha-ní-a",
    "campechano": "cam-pe-cha-no",
    "campeche": "cam-pe-che",
    "campeña": "cam-pe-ña",
    "campeño": "cam-pe-ño",
    "campeo": "cam-pe-o",
    "campeón": "cam-pe-ón",
    "campeona": "cam-pe-o-na",
    "campeonar": "cam-pe-o-nar",
    "campeonato": "cam-pe-o-na-to",
    "campera": "cam-pe-ra",
    "camperear": "cam-pe-re-ar",
    "camperera": "cam-pe-re-ra",
    "camperero": "cam-pe-re-ro",
    "campería": "cam-pe-rí-a",
    "campero": "cam-pe-ro",
    "campés": "cam-pés",
    "campesa": "cam-pe-sa",
    "campesina": "cam-pe-si-na",
    "campesinado": "cam-pe-si-na-do",
    "campesino": "cam-pe-si-no",
    "campestre": "cam-pes-tre",
    "campiar": "cam-piar",
    "campilán": "cam-pi-lán",
    "campillo": "cam-pi-llo",
    "campimetría": "cam-pi-me-trí-a",
    "campiña": "cam-pi-ña",
    "campiñés": "cam-pi-ñés",
    "campiñesa": "cam-pi-ñe-sa",
    "camping": "cam-ping",
    "campión": "cam-pión",
    "campirana": "cam-pi-ra-na",
    "campirano": "cam-pi-ra-no",
    "campismo": "cam-pis-mo",
    "campista": "cam-pis-ta",
    "campisto": "cam-pis-to",
    "campizal": "cam-pi-zal",
    "campo": "cam-po",
    "camporruteña": "cam-po-rru-te-ña",
    "camporruteño": "cam-po-rru-te-ño",
    "camposantero": "cam-po-san-te-ro",
    "camposanto": "cam-po-san-to",
    "camposina": "cam-po-si-na",
    "camposino": "cam-po-si-no",
    "campurosa": "cam-pu-ro-sa",
    "campuroso": "cam-pu-ro-so",
    "campurriana": "cam-pu-rria-na",
    "campurriano": "cam-pu-rria-no",
    "campurusa": "cam-pu-ru-sa",
    "campuruso": "cam-pu-ru-so",
    "campus": "cam-pus",
    "camuatí": "ca-mua-tí",
    "camucha": "ca-mu-cha",
    "camuesa": "ca-mue-sa",
    "camueso": "ca-mue-so",
    "camuflaje": "ca-mu-fla-je",
    "camuflar": "ca-mu-flar",
    "camulián": "ca-mu-lián",
    "camuliana": "ca-mu-lia-na",
    "camuña": "ca-mu-ña",
    "camuza": "ca-mu-za",
    "cana": "ca-na",
    "caña": "ca-ña",
    "canaballa": "ca-na-ba-lla",
    "canabínea": "ca-na-bí-ne-a",
    "canabíneo": "ca-na-bí-ne-o",
    "cañabota": "ca-ña-bo-ta",
    "cañabrava": "ca-ña-bra-va",
    "canaca": "ca-na-ca",
    "canácea": "ca-ná-ce-a",
    "canáceo": "ca-ná-ce-o",
    "canaco": "ca-na-co",
    "cañacoro": "ca-ña-co-ro",
    "cañada": "ca-ña-da",
    "canadiella": "ca-na-die-lla",
    "canadiense": "ca-na-dien-se",
    "cañadilla": "ca-ña-di-lla",
    "canadillo": "ca-na-di-llo",
    "cañado": "ca-ña-do",
    "cañadón": "ca-ña-dón",
    "cañaduz": "ca-ña-duz",
    "cañaduzal": "ca-ña-du-zal",
    "cañafístola": "ca-ña-fís-to-la",
    "cañafístula": "ca-ña-fís-tu-la",
    "cañaheja": "ca-ña-he-ja",
    "cañaherla": "ca-ña-her-la",
    "cañahuatal": "ca-ña-hua-tal",
    "cañahuate": "ca-ña-hua-te",
    "cañahueca": "ca-ña-hue-ca",
    "cañaílla": "ca-ña-í-lla",
    "cañajelga": "ca-ña-jel-ga",
    "canal": "ca-nal",
    "cañal": "ca-ñal",
    "canalada": "ca-na-la-da",
    "canalado": "ca-na-la-do",
    "canaladura": "ca-na-la-du-ra",
    "canalé": "ca-na-lé",
    "canaleja": "ca-na-le-ja",
    "canalera": "ca-na-le-ra",
    "canalero": "ca-na-le-ro",
    "canaleta": "ca-na-le-ta",
    "canalete": "ca-na-le-te",
    "canaleto": "ca-na-le-to",
    "cañaliega": "ca-ña-lie-ga",
    "canalizable": "ca-na-li-za-ble",
    "canalización": "ca-na-li-za-ción",
    "canalizar": "ca-na-li-zar",
    "canalizo": "ca-na-li-zo",
    "canalla": "ca-na-lla",
    "canallada": "ca-na-lla-da",
    "canallesca": "ca-na-lles-ca",
    "canallescamente": "ca-na-lles-ca-men-te",
    "canallesco": "ca-na-lles-co",
    "canalón": "ca-na-lón",
    "cáñama": "cá-ña-ma",
    "cañamar": "ca-ña-mar",
    "cañamazo": "ca-ña-ma-zo",
    "cañamelar": "ca-ña-me-lar",
    "cañameña": "ca-ña-me-ña",
    "cañameño": "ca-ña-me-ño",
    "cañamera": "ca-ña-me-ra",
    "cañamero": "ca-ña-me-ro",
    "cañamiel": "ca-ña-miel",
    "cañamiza": "ca-ña-mi-za",
    "cáñamo": "cá-ña-mo",
    "cañamón": "ca-ña-món",
    "cañamonada": "ca-ña-mo-na-da",
    "cañamonado": "ca-ña-mo-na-do",
    "cañamoncillo": "ca-ña-mon-ci-llo",
    "cañamonera": "ca-ña-mo-ne-ra",
    "cañamonero": "ca-ña-mo-ne-ro",
    "canana": "ca-na-na",
    "cañandonga": "ca-ñan-don-ga",
    "cananea": "ca-na-ne-a",
    "cananeo": "ca-na-ne-o",
    "cananga": "ca-nan-ga",
    "cañangazo": "ca-ñan-ga-zo",
    "canapé": "ca-na-pé",
    "cañar": "ca-ñar",
    "cañardo": "ca-ñar-do",
    "cañareja": "ca-ña-re-ja",
    "cañarejo": "ca-ña-re-jo",
    "cañarense": "ca-ña-ren-se",
    "cañari": "ca-ña-ri",
    "cañarí": "ca-ña-rí",
    "canaria": "ca-na-ria",
    "canaricultura": "ca-na-ri-cul-tu-ra",
    "cañariega": "ca-ña-rie-ga",
    "cañariego": "ca-ña-rie-go",
    "canariense": "ca-na-rien-se",
    "canariera": "ca-na-rie-ra",
    "canario": "ca-na-rio",
    "canarión": "ca-na-rión",
    "canariona": "ca-na-rio-na",
    "canarismo": "ca-na-ris-mo",
    "cañaro": "ca-ña-ro",
    "canarreo": "ca-na-rre-o",
    "cañarroya": "ca-ña-rro-ya",
    "canasta": "ca-nas-ta",
    "canastada": "ca-nas-ta-da",
    "canastera": "ca-nas-te-ra",
    "canastero": "ca-nas-te-ro",
    "canastilla": "ca-nas-ti-lla",
    "canastillera": "ca-nas-ti-lle-ra",
    "canastillero": "ca-nas-ti-lle-ro",
    "canastillo": "ca-nas-ti-llo",
    "canastita": "ca-nas-ti-ta",
    "canasto": "ca-nas-to",
    "canastro": "ca-nas-tro",
    "canaula": "ca-nau-la",
    "cañavera": "ca-ña-ve-ra",
    "cañaveral": "ca-ña-ve-ral",
    "cañaverear": "ca-ña-ve-re-ar",
    "cañaverería": "ca-ña-ve-re-rí-a",
    "cañaverero": "ca-ña-ve-re-ro",
    "cañaza": "ca-ña-za",
    "cañazo": "ca-ña-zo",
    "cáncamo": "cán-ca-mo",
    "cancamurria": "can-ca-mu-rria",
    "cancamusa": "can-ca-mu-sa",
    "cancán": "can-cán",
    "cancana": "can-ca-na",
    "cáncana": "cán-ca-na",
    "cancaneada": "can-ca-ne-a-da",
    "cancaneado": "can-ca-ne-a-do",
    "cancanear": "can-ca-ne-ar",
    "cancaneo": "can-ca-ne-o",
    "cancanilla": "can-ca-ni-lla",
    "cancano": "can-ca-no",
    "cáncano": "cán-ca-no",
    "cancanosa": "can-ca-no-sa",
    "cancanoso": "can-ca-no-so",
    "cancato": "can-ca-to",
    "cancel": "can-cel",
    "cancela": "can-ce-la",
    "cancelación": "can-ce-la-ción",
    "canceladura": "can-ce-la-du-ra",
    "cancelar": "can-ce-lar",
    "cancelaría": "can-ce-la-rí-a",
    "cancelariato": "can-ce-la-ria-to",
    "cancelario": "can-ce-la-rio",
    "cancelería": "can-ce-le-rí-a",
    "canceller": "can-ce-ller",
    "cancellería": "can-ce-lle-rí-a",
    "cáncer": "cán-cer",
    "cancerada": "can-ce-ra-da",
    "cancerado": "can-ce-ra-do",
    "cancerar": "can-ce-rar",
    "cancerbera": "can-cer-be-ra",
    "cancerbero": "can-cer-be-ro",
    "canceriana": "can-ce-ria-na",
    "canceriano": "can-ce-ria-no",
    "canceriforme": "can-ce-ri-for-me",
    "cancerígeno": "can-ce-rí-ge-no",
    "canceróloga": "can-ce-ró-lo-ga",
    "cancerología": "can-ce-ro-lo-gí-a",
    "cancerológico": "can-ce-ro-ló-gi-co",
    "cancerólogo": "can-ce-ró-lo-go",
    "cancerosa": "can-ce-ro-sa",
    "canceroso": "can-ce-ro-so",
    "cancha": "can-cha",
    "canchal": "can-chal",
    "canchalagua": "can-cha-la-gua",
    "canchamina": "can-cha-mi-na",
    "canchaminero": "can-cha-mi-ne-ro",
    "canchear": "can-che-ar",
    "canchelagua": "can-che-la-gua",
    "cancheo": "can-che-o",
    "canchera": "can-che-ra",
    "canchero": "can-che-ro",
    "cancho": "can-cho",
    "canchón": "can-chón",
    "cancilla": "can-ci-lla",
    "canciller": "can-ci-ller",
    "cancillera": "can-ci-lle-ra",
    "cancilleresca": "can-ci-lle-res-ca",
    "cancilleresco": "can-ci-lle-res-co",
    "cancillería": "can-ci-lle-rí-a",
    "cancín": "can-cín",
    "cancina": "can-ci-na",
    "canción": "can-ción",
    "cancioneril": "can-cio-ne-ril",
    "cancionero": "can-cio-ne-ro",
    "cancioneta": "can-cio-ne-ta",
    "cancionista": "can-cio-nis-ta",
    "canclón": "can-clón",
    "canco": "can-co",
    "cancón": "can-cón",
    "cancona": "can-co-na",
    "cancos": "can-cos",
    "cancro": "can-cro",
    "cancroide": "can-croi-de",
    "cancroidea": "can-croi-de-a",
    "cancroideo": "can-croi-de-o",
    "cancunense": "can-cu-nen-se",
    "candado": "can-da-do",
    "candajón": "can-da-jón",
    "candajona": "can-da-jo-na",
    "candalera": "can-da-le-ra",
    "candaliza": "can-da-li-za",
    "cándalo": "cán-da-lo",
    "candamo": "can-da-mo",
    "candanga": "can-dan-ga",
    "candangas": "can-dan-gas",
    "cándano": "cán-da-no",
    "candar": "can-dar",
    "cándara": "cán-da-ra",
    "cande": "can-de",
    "candeal": "can-de-al",
    "candeda": "can-de-da",
    "candela": "can-de-la",
    "candelabro": "can-de-la-bro",
    "candelada": "can-de-la-da",
    "candelaria": "can-de-la-ria",
    "candelariera": "can-de-la-rie-ra",
    "candelariero": "can-de-la-rie-ro",
    "candelario": "can-de-la-rio",
    "candelazo": "can-de-la-zo",
    "candelecho": "can-de-le-cho",
    "candeledana": "can-de-le-da-na",
    "candeledano": "can-de-le-da-no",
    "candelejón": "can-de-le-jón",
    "candelera": "can-de-le-ra",
    "candelerazo": "can-de-le-ra-zo",
    "candelería": "can-de-le-rí-a",
    "candelero": "can-de-le-ro",
    "candeleta": "can-de-le-ta",
    "candelilla": "can-de-li-lla",
    "candelizo": "can-de-li-zo",
    "candelón": "can-de-lón",
    "candencia": "can-den-cia",
    "candente": "can-den-te",
    "candi": "can-di",
    "candial": "can-dial",
    "cándida": "cán-di-da",
    "candidación": "can-di-da-ción",
    "candidado": "can-di-da-do",
    "cándidamente": "cán-di-da-men-te",
    "candidata": "can-di-da-ta",
    "candidatear": "can-di-da-te-ar",
    "candidato": "can-di-da-to",
    "candidatura": "can-di-da-tu-ra",
    "candidez": "can-di-dez",
    "candidiasis": "can-di-dia-sis",
    "cándido": "cán-di-do",
    "candiel": "can-diel",
    "candil": "can-dil",
    "candilada": "can-di-la-da",
    "candilazo": "can-di-la-zo",
    "candileja": "can-di-le-ja",
    "candilejo": "can-di-le-jo",
    "candilera": "can-di-le-ra",
    "candilero": "can-di-le-ro",
    "candilillo": "can-di-li-llo",
    "candilón": "can-di-lón",
    "candinga": "can-din-ga",
    "candiota": "can-dio-ta",
    "candiote": "can-dio-te",
    "candiotera": "can-dio-te-ra",
    "candiotero": "can-dio-te-ro",
    "candombe": "can-dom-be",
    "candombear": "can-dom-be-ar",
    "candomblé": "can-dom-blé",
    "candonga": "can-don-ga",
    "candongo": "can-don-go",
    "candonguear": "can-don-gue-ar",
    "candonguera": "can-don-gue-ra",
    "candonguero": "can-don-gue-ro",
    "candor": "can-dor",
    "candorga": "can-dor-ga",
    "candorosa": "can-do-ro-sa",
    "candorosamente": "can-do-ro-sa-men-te",
    "candoroso": "can-do-ro-so",
    "candray": "can-dray",
    "canducha": "can-du-cha",
    "canducho": "can-du-cho",
    "cané": "ca-né",
    "canear": "ca-ne-ar",
    "cañear": "ca-ñe-ar",
    "caneca": "ca-ne-ca",
    "canecer": "ca-ne-cer",
    "canecho": "ca-ne-cho",
    "canecillo": "ca-ne-ci-llo",
    "caneco": "ca-ne-co",
    "cañedo": "ca-ñe-do",
    "canéfora": "ca-né-fo-ra",
    "caneforias": "ca-ne-fo-rias",
    "canela": "ca-ne-la",
    "canelácea": "ca-ne-lá-ce-a",
    "caneláceo": "ca-ne-lá-ce-o",
    "canelada": "ca-ne-la-da",
    "canelado": "ca-ne-la-do",
    "canelar": "ca-ne-lar",
    "canelazo": "ca-ne-la-zo",
    "canelero": "ca-ne-le-ro",
    "canelilla": "ca-ne-li-lla",
    "canelillo": "ca-ne-li-llo",
    "canelina": "ca-ne-li-na",
    "canelita": "ca-ne-li-ta",
    "canelo": "ca-ne-lo",
    "canelón": "ca-ne-lón",
    "cañengo": "ca-ñen-go",
    "cañeo": "ca-ñe-o",
    "canequí": "ca-ne-quí",
    "cañera": "ca-ñe-ra",
    "cañería": "ca-ñe-rí-a",
    "cañerla": "ca-ñer-la",
    "canero": "ca-ne-ro",
    "cañero": "ca-ñe-ro",
    "canesú": "ca-ne-sú",
    "cañeta": "ca-ñe-ta",
    "cañetana": "ca-ñe-ta-na",
    "cañetano": "ca-ñe-ta-no",
    "cañete": "ca-ñe-te",
    "canetón": "ca-ne-tón",
    "caney": "ca-ney",
    "canez": "ca-nez",
    "canfín": "can-fín",
    "canfinflero": "can-fin-fle-ro",
    "canfínfora": "can-fín-fo-ra",
    "canfor": "can-for",
    "canfora": "can-fo-ra",
    "canforar": "can-fo-rar",
    "canga": "can-ga",
    "cangador": "can-ga-dor",
    "cangagua": "can-ga-gua",
    "cangahua": "can-ga-hua",
    "cangalla": "can-ga-lla",
    "cangallar": "can-ga-llar",
    "cangallero": "can-ga-lle-ro",
    "cangallo": "can-ga-llo",
    "cangar": "can-gar",
    "cangilón": "can-gi-lón",
    "cangre": "can-gre",
    "cangreja": "can-gre-ja",
    "cangrejal": "can-gre-jal",
    "cangrejera": "can-gre-je-ra",
    "cangrejero": "can-gre-je-ro",
    "cangrejito": "can-gre-ji-to",
    "cangrejo": "can-gre-jo",
    "cangrena": "can-gre-na",
    "cangrenar": "can-gre-nar",
    "cangrenarse": "can-gre-nar-se",
    "cangro": "can-gro",
    "cangrosa": "can-gro-sa",
    "cangroso": "can-gro-so",
    "canguelo": "can-gue-lo",
    "cangüeso": "can-güe-so",
    "canguil": "can-guil",
    "canguis": "can-guis",
    "canguro": "can-gu-ro",
    "cañí": "ca-ñí",
    "cania": "ca-nia",
    "caníbal": "ca-ní-bal",
    "canibalesco": "ca-ni-ba-les-co",
    "canibalismo": "ca-ni-ba-lis-mo",
    "canibalizar": "ca-ni-ba-li-zar",
    "canica": "ca-ni-ca",
    "cañiceras": "ca-ñi-ce-ras",
    "caniche": "ca-ni-che",
    "canicie": "ca-ni-cie",
    "canícula": "ca-ní-cu-la",
    "canicular": "ca-ni-cu-lar",
    "caniculario": "ca-ni-cu-la-rio",
    "cañicultor": "ca-ñi-cul-tor",
    "cañicultora": "ca-ñi-cul-to-ra",
    "canido": "ca-ni-do",
    "cánido": "cá-ni-do",
    "cañifla": "ca-ñi-fla",
    "cañiherla": "ca-ñiher-la",
    "cañihua": "ca-ñi-hua",
    "cañihueco": "ca-ñi-hue-co",
    "canija": "ca-ni-ja",
    "canijo": "ca-ni-jo",
    "canil": "ca-nil",
    "cañilavada": "ca-ñi-la-va-da",
    "cañilavado": "ca-ñi-la-va-do",
    "cañilero": "ca-ñi-le-ro",
    "canilla": "ca-ni-lla",
    "canillada": "ca-ni-lla-da",
    "canillado": "ca-ni-lla-do",
    "canillera": "ca-ni-lle-ra",
    "cañillera": "ca-ñi-lle-ra",
    "canillero": "ca-ni-lle-ro",
    "canillita": "ca-ni-lli-ta",
    "canilluda": "ca-ni-llu-da",
    "canilludo": "ca-ni-llu-do",
    "canime": "ca-ni-me",
    "canina": "ca-ni-na",
    "caninamente": "ca-ni-na-men-te",
    "caninero": "ca-ni-ne-ro",
    "caninez": "ca-ni-nez",
    "canino": "ca-ni-no",
    "cañinque": "ca-ñin-que",
    "caniquí": "ca-ni-quí",
    "cañirla": "ca-ñir-la",
    "cañista": "ca-ñis-ta",
    "canistel": "ca-nis-tel",
    "canistro": "ca-nis-tro",
    "cañita": "ca-ñi-ta",
    "cañivano": "ca-ñi-va-no",
    "canivete": "ca-ni-ve-te",
    "cañivete": "ca-ñi-ve-te",
    "cañiza": "ca-ñi-za",
    "cañizal": "ca-ñi-zal",
    "cañizar": "ca-ñi-zar",
    "cañizo": "ca-ñi-zo",
    "canje": "can-je",
    "canjeable": "can-je-a-ble",
    "canjear": "can-je-ar",
    "canjilón": "can-ji-lón",
    "canjilona": "can-ji-lo-na",
    "canjura": "can-ju-ra",
    "canjuro": "can-ju-ro",
    "canmiar": "can-miar",
    "cannabácea": "can-na-bá-ce-a",
    "cannabáceas": "can-na-bá-ce-as",
    "cannabáceo": "can-na-bá-ce-o",
    "cannabis": "can-na-bis",
    "cannácea": "can-ná-ce-a",
    "cannáceo": "can-ná-ce-o",
    "cano": "ca-no",
    "caño": "ca-ño",
    "canoa": "ca-no-a",
    "canoada": "ca-no-a-da",
    "cañocal": "ca-ño-cal",
    "cañocazo": "ca-ño-ca-zo",
    "canódromo": "ca-nó-dro-mo",
    "canoera": "ca-no-e-ra",
    "canoero": "ca-no-e-ro",
    "canon": "ca-non",
    "cañón": "ca-ñón",
    "cañona": "ca-ño-na",
    "cañonazo": "ca-ño-na-zo",
    "cañonear": "ca-ño-ne-ar",
    "cañoneo": "ca-ño-ne-o",
    "cañonera": "ca-ño-ne-ra",
    "cañonería": "ca-ño-ne-rí-a",
    "cañonero": "ca-ño-ne-ro",
    "canonesa": "ca-no-ne-sa",
    "canónica": "ca-nó-ni-ca",
    "canonical": "ca-no-ni-cal",
    "canónicamente": "ca-nó-ni-ca-men-te",
    "canonicato": "ca-no-ni-ca-to",
    "canónico": "ca-nó-ni-co",
    "canóniga": "ca-nó-ni-ga",
    "canonigado": "ca-no-ni-ga-do",
    "canónigo": "ca-nó-ni-go",
    "canonista": "ca-no-nis-ta",
    "canonizable": "ca-no-ni-za-ble",
    "canonización": "ca-no-ni-za-ción",
    "canonizar": "ca-no-ni-zar",
    "canonjía": "ca-non-jí-a",
    "canonjible": "ca-non-ji-ble",
    "canope": "ca-no-pe",
    "canora": "ca-no-ra",
    "canoro": "ca-no-ro",
    "canosa": "ca-no-sa",
    "canoso": "ca-no-so",
    "cañota": "ca-ño-ta",
    "canotaje": "ca-no-ta-je",
    "canotier": "ca-no-tier",
    "canquén": "can-quén",
    "cansa": "can-sa",
    "cansada": "can-sa-da",
    "cansadamente": "can-sa-da-men-te",
    "cansado": "can-sa-do",
    "cansadón": "can-sa-dón",
    "cansador": "can-sa-dor",
    "cansamiento": "can-sa-mien-to",
    "cansancio": "can-san-cio",
    "cansar": "can-sar",
    "cansera": "can-se-ra",
    "cansía": "can-sí-a",
    "cansina": "can-si-na",
    "cansinamente": "can-si-na-men-te",
    "cansino": "can-si-no",
    "cansío": "can-sí-o",
    "canso": "can-so",
    "cansón": "can-són",
    "canstadiense": "cans-ta-dien-se",
    "canta": "can-ta",
    "cantábile": "can-tá-bi-le",
    "cantable": "can-ta-ble",
    "cántabra": "cán-ta-bra",
    "cantábrica": "can-tá-bri-ca",
    "cantábrico": "can-tá-bri-co",
    "cántabro": "cán-ta-bro",
    "cantaclaro": "can-ta-cla-ro",
    "cantada": "can-ta-da",
    "cantadera": "can-ta-de-ra",
    "cantado": "can-ta-do",
    "cantador": "can-ta-dor",
    "cantadora": "can-ta-do-ra",
    "cantal": "can-tal",
    "cantalear": "can-ta-le-ar",
    "cantaleta": "can-ta-le-ta",
    "cantaletear": "can-ta-le-te-ar",
    "cantalinosa": "can-ta-li-no-sa",
    "cantalinoso": "can-ta-li-no-so",
    "cantalupo": "can-ta-lu-po",
    "cantamañanas": "can-ta-ma-ña-nas",
    "cantamisa": "can-ta-mi-sa",
    "cantante": "can-tan-te",
    "cantaor": "can-ta-or",
    "cantaora": "can-ta-o-ra",
    "cantar": "can-tar",
    "cántara": "cán-ta-ra",
    "cantarada": "can-ta-ra-da",
    "cantaral": "can-ta-ral",
    "cantarano": "can-ta-ra-no",
    "cantarela": "can-ta-re-la",
    "cantarera": "can-ta-re-ra",
    "cantarería": "can-ta-re-rí-a",
    "cantarero": "can-ta-re-ro",
    "cantárida": "can-tá-ri-da",
    "cantarilla": "can-ta-ri-lla",
    "cantarillos": "can-ta-ri-llos",
    "cantarín": "can-ta-rín",
    "cantarina": "can-ta-ri-na",
    "cántaro": "cán-ta-ro",
    "cantarola": "can-ta-ro-la",
    "cantarrana": "can-ta-rra-na",
    "cantata": "can-ta-ta",
    "cantatriz": "can-ta-triz",
    "cantautor": "can-tau-tor",
    "cantautora": "can-tau-to-ra",
    "cantazo": "can-ta-zo",
    "cante": "can-te",
    "cantear": "can-te-ar",
    "cantegril": "can-te-gril",
    "cantel": "can-tel",
    "canteña": "can-te-ña",
    "canteño": "can-te-ño",
    "cantera": "can-te-ra",
    "canterana": "can-te-ra-na",
    "canterano": "can-te-ra-no",
    "cantería": "can-te-rí-a",
    "canterios": "can-te-rios",
    "canterito": "can-te-ri-to",
    "cantero": "can-te-ro",
    "cantesa": "can-te-sa",
    "cantía": "can-tí-a",
    "cántica": "cán-ti-ca",
    "canticio": "can-ti-cio",
    "cántico": "cán-ti-co",
    "cantidad": "can-ti-dad",
    "cantiga": "can-ti-ga",
    "cántiga": "cán-ti-ga",
    "cantil": "can-til",
    "cantilena": "can-ti-le-na",
    "cantillo": "can-ti-llo",
    "cantimpla": "can-tim-pla",
    "cantimplora": "can-tim-plo-ra",
    "cantina": "can-ti-na",
    "cantiña": "can-ti-ña",
    "cantinela": "can-ti-ne-la",
    "cantinera": "can-ti-ne-ra",
    "cantinero": "can-ti-ne-ro",
    "cantinflada": "can-tin-fla-da",
    "cantinflas": "can-tin-flas",
    "cantinflear": "can-tin-fle-ar",
    "cantinfleo": "can-tin-fle-o",
    "cantinflérico": "can-tin-flé-ri-co",
    "cantinflero": "can-tin-fle-ro",
    "cantinflesco": "can-tin-fles-co",
    "cantista": "can-tis-ta",
    "cantitativa": "can-ti-ta-ti-va",
    "cantitativo": "can-ti-ta-ti-vo",
    "cantizal": "can-ti-zal",
    "canto": "can-to",
    "cantollanista": "can-to-lla-nis-ta",
    "cantón": "can-tón",
    "cantonada": "can-to-na-da",
    "cantonado": "can-to-na-do",
    "cantonal": "can-to-nal",
    "cantonalismo": "can-to-na-lis-mo",
    "cantonalista": "can-to-na-lis-ta",
    "cantonalización": "can-to-na-li-za-ción",
    "cantonar": "can-to-nar",
    "cantonear": "can-to-ne-ar",
    "cantonearse": "can-to-ne-ar-se",
    "cantoneo": "can-to-ne-o",
    "cantonera": "can-to-ne-ra",
    "cantonero": "can-to-ne-ro",
    "cantonés": "can-to-nés",
    "cantonesa": "can-to-ne-sa",
    "cantor": "can-tor",
    "cantora": "can-to-ra",
    "cantoral": "can-to-ral",
    "cantoría": "can-to-rí-a",
    "cantorral": "can-to-rral",
    "cantosa": "can-to-sa",
    "cantoso": "can-to-so",
    "cantú": "can-tú",
    "cantúa": "can-tú-a",
    "cantuariense": "can-tua-rien-se",
    "cantueso": "can-tue-so",
    "canturía": "can-tu-rí-a",
    "canturrear": "can-tu-rre-ar",
    "canturreo": "can-tu-rre-o",
    "canturria": "can-tu-rria",
    "canturriar": "can-tu-rriar",
    "cantusar": "can-tu-sar",
    "cantusear": "can-tu-se-ar",
    "cantuta": "can-tu-ta",
    "cañucela": "ca-ñu-ce-la",
    "canuda": "ca-nu-da",
    "canudo": "ca-nu-do",
    "cañuela": "ca-ñue-la",
    "cánula": "cá-nu-la",
    "canular": "ca-nu-lar",
    "canuta": "ca-nu-ta",
    "canutazo": "ca-nu-ta-zo",
    "cañutazo": "ca-ñu-ta-zo",
    "canute": "ca-nu-te",
    "cañutería": "ca-ñu-te-rí-a",
    "canutero": "ca-nu-te-ro",
    "cañutero": "ca-ñu-te-ro",
    "canutillo": "ca-nu-ti-llo",
    "cañutillo": "ca-ñu-ti-llo",
    "canuto": "ca-nu-to",
    "cañuto": "ca-ñu-to",
    "canyengue": "can-yen-gue",
    "cao": "ca-o",
    "caoba": "ca-o-ba",
    "caobana": "ca-o-ba-na",
    "caobilla": "ca-o-bi-lla",
    "caobo": "ca-o-bo",
    "caolín": "ca-o-lín",
    "caolinización": "ca-o-li-ni-za-ción",
    "caos": "ca-os",
    "caótica": "ca-ó-ti-ca",
    "caóticamente": "ca-ó-ti-ca-men-te",
    "caótico": "ca-ó-ti-co",
    "capa": "ca-pa",
    "capá": "ca-pá",
    "capacear": "ca-pa-ce-ar",
    "capaceta": "ca-pa-ce-ta",
    "capacete": "ca-pa-ce-te",
    "capacha": "ca-pa-cha",
    "capachada": "ca-pa-cha-da",
    "capachera": "ca-pa-che-ra",
    "capachero": "ca-pa-che-ro",
    "capacho": "ca-pa-cho",
    "capacidad": "ca-pa-ci-dad",
    "capacitación": "ca-pa-ci-ta-ción",
    "capacitancia": "ca-pa-ci-tan-cia",
    "capacitar": "ca-pa-ci-tar",
    "capadillo": "ca-pa-di-llo",
    "capadocia": "ca-pa-do-cia",
    "capadocio": "ca-pa-do-cio",
    "capador": "ca-pa-dor",
    "capadura": "ca-pa-du-ra",
    "capanga": "ca-pan-ga",
    "capar": "ca-par",
    "caparacho": "ca-pa-ra-cho",
    "capararoch": "ca-pa-ra-roch",
    "caparazón": "ca-pa-ra-zón",
    "caparidácea": "ca-pa-ri-dá-ce-a",
    "caparidáceo": "ca-pa-ri-dá-ce-o",
    "caparídea": "ca-pa-rí-de-a",
    "caparídeo": "ca-pa-rí-de-o",
    "caparra": "ca-pa-rra",
    "caparro": "ca-pa-rro",
    "caparrón": "ca-pa-rrón",
    "caparrosa": "ca-pa-rro-sa",
    "capataz": "ca-pa-taz",
    "capataza": "ca-pa-ta-za",
    "capaz": "ca-paz",
    "capaza": "ca-pa-za",
    "capazmente": "ca-paz-men-te",
    "capazo": "ca-pa-zo",
    "capazón": "ca-pa-zón",
    "capción": "cap-ción",
    "capciosa": "cap-cio-sa",
    "capciosidad": "cap-cio-si-dad",
    "capcioso": "cap-cio-so",
    "capdal": "cap-dal",
    "capea": "ca-pe-a",
    "capeada": "ca-pe-a-da",
    "capeadera": "ca-pe-a-de-ra",
    "capeador": "ca-pe-a-dor",
    "capeadora": "ca-pe-a-do-ra",
    "capear": "ca-pe-ar",
    "capeja": "ca-pe-ja",
    "capel": "ca-pel",
    "capelán": "ca-pe-lán",
    "capelardente": "ca-pe-lar-den-te",
    "capelete": "ca-pe-le-te",
    "capelina": "ca-pe-li-na",
    "capellada": "ca-pe-lla-da",
    "capellán": "ca-pe-llán",
    "capellanía": "ca-pe-lla-ní-a",
    "capellar": "ca-pe-llar",
    "capellina": "ca-pe-lli-na",
    "capelo": "ca-pe-lo",
    "capeo": "ca-pe-o",
    "capeón": "ca-pe-ón",
    "capero": "ca-pe-ro",
    "caperol": "ca-pe-rol",
    "caperucear": "ca-pe-ru-ce-ar",
    "caperuza": "ca-pe-ru-za",
    "caperuzada": "ca-pe-ru-za-da",
    "caperuzado": "ca-pe-ru-za-do",
    "caperuzo": "ca-pe-ru-zo",
    "caperuzón": "ca-pe-ru-zón",
    "capeta": "ca-pe-ta",
    "capetonada": "ca-pe-to-na-da",
    "capi": "ca-pi",
    "capia": "ca-pia",
    "capialzado": "ca-pial-za-do",
    "capialzar": "ca-pial-zar",
    "capialzo": "ca-pial-zo",
    "capibara": "ca-pi-ba-ra",
    "capicatí": "ca-pi-ca-tí",
    "capichola": "ca-pi-cho-la",
    "capicholada": "ca-pi-cho-la-da",
    "capicholado": "ca-pi-cho-la-do",
    "capicúa": "ca-pi-cú-a",
    "capidengue": "ca-pi-den-gue",
    "capigorra": "ca-pi-go-rra",
    "capigorrista": "ca-pi-go-rris-ta",
    "capigorrón": "ca-pi-go-rrón",
    "capiguara": "ca-pi-gua-ra",
    "capilar": "ca-pi-lar",
    "capilaridad": "ca-pi-la-ri-dad",
    "capilarímetro": "ca-pi-la-rí-me-tro",
    "capilla": "ca-pi-lla",
    "capillada": "ca-pi-lla-da",
    "capilleja": "ca-pi-lle-ja",
    "capillejo": "ca-pi-lle-jo",
    "capiller": "ca-pi-ller",
    "capillero": "ca-pi-lle-ro",
    "capilleta": "ca-pi-lle-ta",
    "capillo": "ca-pi-llo",
    "capilluda": "ca-pi-llu-da",
    "capilludo": "ca-pi-llu-do",
    "capín": "ca-pín",
    "capincho": "ca-pin-cho",
    "capingo": "ca-pin-go",
    "capinoteña": "ca-pi-no-te-ña",
    "capinoteño": "ca-pi-no-te-ño",
    "capio": "ca-pio",
    "capipardo": "ca-pi-par-do",
    "capirón": "ca-pi-rón",
    "capirotada": "ca-pi-ro-ta-da",
    "capirotado": "ca-pi-ro-ta-do",
    "capirotazo": "ca-pi-ro-ta-zo",
    "capirote": "ca-pi-ro-te",
    "capirotero": "ca-pi-ro-te-ro",
    "capirra": "ca-pi-rra",
    "capirro": "ca-pi-rro",
    "capirucho": "ca-pi-ru-cho",
    "capisayo": "ca-pi-sa-yo",
    "capiscar": "ca-pis-car",
    "capiscol": "ca-pis-col",
    "capiscolía": "ca-pis-co-lí-a",
    "capista": "ca-pis-ta",
    "capistro": "ca-pis-tro",
    "capitá": "ca-pi-tá",
    "capitación": "ca-pi-ta-ción",
    "capital": "ca-pi-tal",
    "capitaleña": "ca-pi-ta-le-ña",
    "capitaleño": "ca-pi-ta-le-ño",
    "capitalidad": "ca-pi-ta-li-dad",
    "capitalina": "ca-pi-ta-li-na",
    "capitalino": "ca-pi-ta-li-no",
    "capitalismo": "ca-pi-ta-lis-mo",
    "capitalista": "ca-pi-ta-lis-ta",
    "capitalizable": "ca-pi-ta-li-za-ble",
    "capitalización": "ca-pi-ta-li-za-ción",
    "capitalizar": "ca-pi-ta-li-zar",
    "capitalmente": "ca-pi-tal-men-te",
    "capitán": "ca-pi-tán",
    "capitana": "ca-pi-ta-na",
    "capitanear": "ca-pi-ta-ne-ar",
    "capitaneja": "ca-pi-ta-ne-ja",
    "capitanejo": "ca-pi-ta-ne-jo",
    "capitanía": "ca-pi-ta-ní-a",
    "capitel": "ca-pi-tel",
    "capitidisminución": "ca-pi-ti-dis-mi-nu-ción",
    "capitidisminuido": "ca-pi-ti-dis-mi-nui-do",
    "capitidisminuir": "ca-pi-ti-dis-mi-nuir",
    "capítol": "ca-pí-tol",
    "capitolina": "ca-pi-to-li-na",
    "capitolino": "ca-pi-to-li-no",
    "capitolio": "ca-pi-to-lio",
    "capitón": "ca-pi-tón",
    "capitoné": "ca-pi-to-né",
    "capitonear": "ca-pi-to-ne-ar",
    "capitosa": "ca-pi-to-sa",
    "capitoso": "ca-pi-to-so",
    "capitoste": "ca-pi-tos-te",
    "capítula": "ca-pí-tu-la",
    "capitulación": "ca-pi-tu-la-ción",
    "capitulada": "ca-pi-tu-la-da",
    "capitulado": "ca-pi-tu-la-do",
    "capitulante": "ca-pi-tu-lan-te",
    "capitular": "ca-pi-tu-lar",
    "capitulario": "ca-pi-tu-la-rio",
    "capitularmente": "ca-pi-tu-lar-men-te",
    "capitulear": "ca-pi-tu-le-ar",
    "capítulo": "ca-pí-tu-lo",
    "capizana": "ca-pi-za-na",
    "capnomancía": "cap-no-man-cí-a",
    "capnomancia": "cap-no-man-cia",
    "capo": "ca-po",
    "capó": "ca-pó",
    "capocho": "ca-po-cho",
    "capoeira": "ca-po-ei-ra",
    "capolado": "ca-po-la-do",
    "capolar": "ca-po-lar",
    "capón": "ca-pón",
    "capona": "ca-po-na",
    "caponada": "ca-po-na-da",
    "caponar": "ca-po-nar",
    "caponera": "ca-po-ne-ra",
    "caporal": "ca-po-ral",
    "caporalista": "ca-po-ra-lis-ta",
    "capororoca": "ca-po-ro-ro-ca",
    "caporos": "ca-po-ros",
    "capota": "ca-po-ta",
    "capotar": "ca-po-tar",
    "capotazo": "ca-po-ta-zo",
    "capote": "ca-po-te",
    "capotear": "ca-po-te-ar",
    "capoteo": "ca-po-te-o",
    "capotera": "ca-po-te-ra",
    "capotero": "ca-po-te-ro",
    "capotillo": "ca-po-ti-llo",
    "capotuda": "ca-po-tu-da",
    "capotudo": "ca-po-tu-do",
    "cappa": "cap-pa",
    "capraria": "ca-pra-ria",
    "caprario": "ca-pra-rio",
    "capricho": "ca-pri-cho",
    "caprichosa": "ca-pri-cho-sa",
    "caprichosamente": "ca-pri-cho-sa-men-te",
    "caprichoso": "ca-pri-cho-so",
    "caprichuda": "ca-pri-chu-da",
    "caprichudo": "ca-pri-chu-do",
    "capricorniana": "ca-pri-cor-nia-na",
    "capricorniano": "ca-pri-cor-nia-no",
    "capricornio": "ca-pri-cor-nio",
    "caprierense": "ca-prie-ren-se",
    "caprifoliácea": "ca-pri-fo-liá-ce-a",
    "caprifoliáceo": "ca-pri-fo-liá-ce-o",
    "caprina": "ca-pri-na",
    "caprino": "ca-pri-no",
    "caprípeda": "ca-prí-pe-da",
    "caprípede": "ca-prí-pe-de",
    "caprípedo": "ca-prí-pe-do",
    "cápsida": "cáp-si-da",
    "cápsula": "cáp-su-la",
    "capsular": "cap-su-lar",
    "captación": "cap-ta-ción",
    "captador": "cap-ta-dor",
    "captadora": "cap-ta-do-ra",
    "captar": "cap-tar",
    "captatoria": "cap-ta-to-ria",
    "captatorio": "cap-ta-to-rio",
    "captenencia": "cap-te-nen-cia",
    "captener": "cap-te-ner",
    "captiva": "cap-ti-va",
    "captivar": "cap-ti-var",
    "captiverio": "cap-ti-ve-rio",
    "captividad": "cap-ti-vi-dad",
    "captivo": "cap-ti-vo",
    "captor": "cap-tor",
    "captora": "cap-to-ra",
    "captura": "cap-tu-ra",
    "capturar": "cap-tu-rar",
    "capturista": "cap-tu-ris-ta",
    "capuana": "ca-pua-na",
    "capuano": "ca-pua-no",
    "capuca": "ca-pu-ca",
    "capuceta": "ca-pu-ce-ta",
    "capucete": "ca-pu-ce-te",
    "capucha": "ca-pu-cha",
    "capuchar": "ca-pu-char",
    "capuchina": "ca-pu-chi-na",
    "capuchino": "ca-pu-chi-no",
    "capucho": "ca-pu-cho",
    "capuchón": "ca-pu-chón",
    "capuera": "ca-pue-ra",
    "capujar": "ca-pu-jar",
    "capuleto": "ca-pu-le-to",
    "capulí": "ca-pu-lí",
    "capúlido": "ca-pú-li-do",
    "capulín": "ca-pu-lín",
    "capulina": "ca-pu-li-na",
    "capulla": "ca-pu-lla",
    "capullada": "ca-pu-lla-da",
    "capullina": "ca-pu-lli-na",
    "capullo": "ca-pu-llo",
    "cápulo": "cá-pu-lo",
    "capuz": "ca-puz",
    "capuzar": "ca-pu-zar",
    "capuzón": "ca-pu-zón",
    "caquéctica": "ca-quéc-ti-ca",
    "caquéctico": "ca-quéc-ti-co",
    "caquetense": "ca-que-ten-se",
    "caquetío": "ca-que-tí-o",
    "caquexia": "ca-que-xia",
    "caqui": "ca-qui",
    "cara": "ca-ra",
    "caraba": "ca-ra-ba",
    "carabalí": "ca-ra-ba-lí",
    "carabaña": "ca-ra-ba-ña",
    "carabao": "ca-ra-ba-o",
    "cárabe": "cá-ra-be",
    "carabear": "ca-ra-be-ar",
    "carabela": "ca-ra-be-la",
    "carabelón": "ca-ra-be-lón",
    "carabera": "ca-ra-be-ra",
    "carabero": "ca-ra-be-ro",
    "carábido": "ca-rá-bi-do",
    "carabina": "ca-ra-bi-na",
    "carabinazo": "ca-ra-bi-na-zo",
    "carabinera": "ca-ra-bi-ne-ra",
    "carabinero": "ca-ra-bi-ne-ro",
    "carablanca": "ca-ra-blan-ca",
    "cárabo": "cá-ra-bo",
    "carabobeña": "ca-ra-bo-be-ña",
    "carabobeño": "ca-ra-bo-be-ño",
    "carabritear": "ca-ra-bri-te-ar",
    "caraca": "ca-ra-ca",
    "caracal": "ca-ra-cal",
    "caracalla": "ca-ra-ca-lla",
    "caracará": "ca-ra-ca-rá",
    "caracas": "ca-ra-cas",
    "caracatey": "ca-ra-ca-tey",
    "caracense": "ca-ra-cen-se",
    "caracha": "ca-ra-cha",
    "carache": "ca-ra-che",
    "carachenta": "ca-ra-chen-ta",
    "carachento": "ca-ra-chen-to",
    "caracho": "ca-ra-cho",
    "carachosa": "ca-ra-cho-sa",
    "carachoso": "ca-ra-cho-so",
    "carachupa": "ca-ra-chu-pa",
    "caracoa": "ca-ra-co-a",
    "caracol": "ca-ra-col",
    "caracola": "ca-ra-co-la",
    "caracolada": "ca-ra-co-la-da",
    "caracolear": "ca-ra-co-le-ar",
    "caracoleo": "ca-ra-co-le-o",
    "caracolera": "ca-ra-co-le-ra",
    "caracolero": "ca-ra-co-le-ro",
    "caracoleta": "ca-ra-co-le-ta",
    "caracolí": "ca-ra-co-lí",
    "caracolillo": "ca-ra-co-li-llo",
    "carácter": "ca-rác-ter",
    "caracterial": "ca-rac-te-rial",
    "caracteriológico": "ca-rac-te-rio-ló-gi-co",
    "caracterismo": "ca-rac-te-ris-mo",
    "característica": "ca-rac-te-rís-ti-ca",
    "característicamente": "ca-rac-te-rís-ti-ca-men-te",
    "característico": "ca-rac-te-rís-ti-co",
    "caracterización": "ca-rac-te-ri-za-ción",
    "caracterizada": "ca-rac-te-ri-za-da",
    "caracterizadamente": "ca-rac-te-ri-za-da-men-te",
    "caracterizado": "ca-rac-te-ri-za-do",
    "caracterizador": "ca-rac-te-ri-za-dor",
    "caracterizadora": "ca-rac-te-ri-za-do-ra",
    "caracterizar": "ca-rac-te-ri-zar",
    "caracterología": "ca-rac-te-ro-lo-gí-a",
    "caracterológico": "ca-rac-te-ro-ló-gi-co",
    "caracú": "ca-ra-cú",
    "caracul": "ca-ra-cul",
    "carada": "ca-ra-da",
    "caradelante": "ca-ra-de-lan-te",
    "carado": "ca-ra-do",
    "caradriforme": "ca-ra-dri-for-me",
    "caradura": "ca-ra-du-ra",
    "caradurismo": "ca-ra-du-ris-mo",
    "carago": "ca-ra-go",
    "caraguatá": "ca-ra-gua-tá",
    "caragüilla": "ca-ra-güi-lla",
    "caraipo": "ca-rai-po",
    "caraira": "ca-rai-ra",
    "caraísmo": "ca-ra-ís-mo",
    "caraíta": "ca-ra-í-ta",
    "caraja": "ca-ra-ja",
    "carajada": "ca-ra-ja-da",
    "carajal": "ca-ra-jal",
    "carajás": "ca-ra-jás",
    "carajazo": "ca-ra-ja-zo",
    "carajear": "ca-ra-je-ar",
    "carajete": "ca-ra-je-te",
    "carajillo": "ca-ra-ji-llo",
    "carajita": "ca-ra-ji-ta",
    "carajito": "ca-ra-ji-to",
    "carajo": "ca-ra-jo",
    "carajón": "ca-ra-jón",
    "caralla": "ca-ra-lla",
    "carama": "ca-ra-ma",
    "caramanchel": "ca-ra-man-chel",
    "caramanchelera": "ca-ra-man-che-le-ra",
    "caramanchelero": "ca-ra-man-che-le-ro",
    "caramanchón": "ca-ra-man-chón",
    "caramañola": "ca-ra-ma-ño-la",
    "caramayola": "ca-ra-ma-yo-la",
    "caramba": "ca-ram-ba",
    "carambada": "ca-ram-ba-da",
    "carambanada": "ca-ram-ba-na-da",
    "carambanado": "ca-ram-ba-na-do",
    "carámbano": "ca-rám-ba-no",
    "carambillo": "ca-ram-bi-llo",
    "carambola": "ca-ram-bo-la",
    "carambolear": "ca-ram-bo-le-ar",
    "carambolera": "ca-ram-bo-le-ra",
    "carambolero": "ca-ram-bo-le-ro",
    "carambolista": "ca-ram-bo-lis-ta",
    "carambolo": "ca-ram-bo-lo",
    "caramel": "ca-ra-mel",
    "caramelear": "ca-ra-me-le-ar",
    "carameleo": "ca-ra-me-le-o",
    "caramelizar": "ca-ra-me-li-zar",
    "caramelo": "ca-ra-me-lo",
    "caramente": "ca-ra-men-te",
    "caramera": "ca-ra-me-ra",
    "caramida": "ca-ra-mi-da",
    "caramilla": "ca-ra-mi-lla",
    "caramillar": "ca-ra-mi-llar",
    "caramilleras": "ca-ra-mi-lle-ras",
    "caramillo": "ca-ra-mi-llo",
    "caramillosa": "ca-ra-mi-llo-sa",
    "caramilloso": "ca-ra-mi-llo-so",
    "caramo": "ca-ra-mo",
    "caramora": "ca-ra-mo-ra",
    "caramujo": "ca-ra-mu-jo",
    "caramullar": "ca-ra-mu-llar",
    "caramullo": "ca-ra-mu-llo",
    "caramuzal": "ca-ra-mu-zal",
    "caraña": "ca-ra-ña",
    "caranaveña": "ca-ra-na-ve-ña",
    "caranaveño": "ca-ra-na-ve-ño",
    "carancho": "ca-ran-cho",
    "carandero": "ca-ran-de-ro",
    "caranegra": "ca-ra-ne-gra",
    "caranga": "ca-ran-ga",
    "carángano": "ca-rán-ga-no",
    "caranqui": "ca-ran-qui",
    "carantamaula": "ca-ran-ta-mau-la",
    "carantón": "ca-ran-tón",
    "carantoña": "ca-ran-to-ña",
    "carantoñera": "ca-ran-to-ñe-ra",
    "carantoñero": "ca-ran-to-ñe-ro",
    "carao": "ca-ra-o",
    "caraos": "ca-ra-os",
    "caraota": "ca-ra-o-ta",
    "carapa": "ca-ra-pa",
    "carapachay": "ca-ra-pa-chay",
    "carapacho": "ca-ra-pa-cho",
    "carapato": "ca-ra-pa-to",
    "carape": "ca-ra-pe",
    "carapico": "ca-ra-pi-co",
    "carapopela": "ca-ra-po-pe-la",
    "carapucho": "ca-ra-pu-cho",
    "carapulca": "ca-ra-pul-ca",
    "caraqueña": "ca-ra-que-ña",
    "caraqueño": "ca-ra-que-ño",
    "caraquense": "ca-ra-quen-se",
    "caraquilla": "ca-ra-qui-lla",
    "carare": "ca-ra-re",
    "cararoso": "ca-ra-ro-so",
    "carasol": "ca-ra-sol",
    "carate": "ca-ra-te",
    "caratejo": "ca-ra-te-jo",
    "carato": "ca-ra-to",
    "caratoso": "ca-ra-to-so",
    "carátula": "ca-rá-tu-la",
    "caratulada": "ca-ra-tu-la-da",
    "caratulado": "ca-ra-tu-la-do",
    "caratular": "ca-ra-tu-lar",
    "caratulera": "ca-ra-tu-le-ra",
    "caratulero": "ca-ra-tu-le-ro",
    "caraú": "ca-ra-ú",
    "carauz": "ca-rauz",
    "caravaca": "ca-ra-va-ca",
    "caravana": "ca-ra-va-na",
    "caravanera": "ca-ra-va-ne-ra",
    "caravanero": "ca-ra-va-ne-ro",
    "caravaning": "ca-ra-va-ning",
    "caravasar": "ca-ra-va-sar",
    "caravelina": "ca-ra-ve-li-na",
    "caravelino": "ca-ra-ve-li-no",
    "caray": "ca-ray",
    "carayá": "ca-ra-yá",
    "carba": "car-ba",
    "carbalí": "car-ba-lí",
    "cárbaso": "cár-ba-so",
    "carbinol": "car-bi-nol",
    "carbizal": "car-bi-zal",
    "carbizo": "car-bi-zo",
    "carbodinamita": "car-bo-di-na-mi-ta",
    "carbógeno": "car-bó-ge-no",
    "carbólico": "car-bó-li-co",
    "carbolíneo": "car-bo-lí-ne-o",
    "carbón": "car-bón",
    "carbonada": "car-bo-na-da",
    "carbonado": "car-bo-na-do",
    "carbonalla": "car-bo-na-lla",
    "carbonar": "car-bo-nar",
    "carbonara": "car-bo-na-ra",
    "carbonaria": "car-bo-na-ria",
    "carbonario": "car-bo-na-rio",
    "carbonarismo": "car-bo-na-ris-mo",
    "carbonatada": "car-bo-na-ta-da",
    "carbonatado": "car-bo-na-ta-do",
    "carbonatar": "car-bo-na-tar",
    "carbonato": "car-bo-na-to",
    "carboncillo": "car-bon-ci-llo",
    "carbonear": "car-bo-ne-ar",
    "carboneo": "car-bo-ne-o",
    "carbonera": "car-bo-ne-ra",
    "carbonería": "car-bo-ne-rí-a",
    "carbonerica": "car-bo-ne-ri-ca",
    "carbonero": "car-bo-ne-ro",
    "carbónica": "car-bó-ni-ca",
    "carbónico": "car-bó-ni-co",
    "carbonífera": "car-bo-ní-fe-ra",
    "carbonífero": "car-bo-ní-fe-ro",
    "carbonilla": "car-bo-ni-lla",
    "carbonilo": "car-bo-ni-lo",
    "carbonita": "car-bo-ni-ta",
    "carbonización": "car-bo-ni-za-ción",
    "carbonizar": "car-bo-ni-zar",
    "carbono": "car-bo-no",
    "carbonosa": "car-bo-no-sa",
    "carbonoso": "car-bo-no-so",
    "carborundo": "car-bo-run-do",
    "carboxílico": "car-bo-xí-li-co",
    "carboxilo": "car-bo-xi-lo",
    "carbuncal": "car-bun-cal",
    "carbunclo": "car-bun-clo",
    "carbunco": "car-bun-co",
    "carbuncosa": "car-bun-co-sa",
    "carbuncosis": "car-bun-co-sis",
    "carbuncoso": "car-bun-co-so",
    "carbúnculo": "car-bún-cu-lo",
    "carburación": "car-bu-ra-ción",
    "carburador": "car-bu-ra-dor",
    "carburante": "car-bu-ran-te",
    "carburar": "car-bu-rar",
    "carburina": "car-bu-ri-na",
    "carburo": "car-bu-ro",
    "carca": "car-ca",
    "carcacha": "car-ca-cha",
    "carcachento": "car-ca-chen-to",
    "carcaj": "car-caj",
    "carcajada": "car-ca-ja-da",
    "carcajear": "car-ca-je-ar",
    "carcajeo": "car-ca-je-o",
    "carcamal": "car-ca-mal",
    "carcamán": "car-ca-mán",
    "carcamana": "car-ca-ma-na",
    "cárcamo": "cár-ca-mo",
    "carcañal": "car-ca-ñal",
    "carcaño": "car-ca-ño",
    "carcasa": "car-ca-sa",
    "cárcava": "cár-ca-va",
    "carcavear": "car-ca-ve-ar",
    "carcavera": "car-ca-ve-ra",
    "carcavina": "car-ca-vi-na",
    "carcavinar": "car-ca-vi-nar",
    "cárcavo": "cár-ca-vo",
    "carcavón": "car-ca-vón",
    "carcavonera": "car-ca-vo-ne-ra",
    "carcavuezo": "car-ca-vue-zo",
    "carcax": "car-cax",
    "carcaza": "car-ca-za",
    "cárcel": "cár-cel",
    "carcelaje": "car-ce-la-je",
    "carcelaria": "car-ce-la-ria",
    "carcelario": "car-ce-la-rio",
    "carcelazo": "car-ce-la-zo",
    "carcelera": "car-ce-le-ra",
    "carcelería": "car-ce-le-rí-a",
    "carcelero": "car-ce-le-ro",
    "carchense": "car-chen-se",
    "carchi": "car-chi",
    "carcinogénico": "car-ci-no-gé-ni-co",
    "carcinógeno": "car-ci-nó-ge-no",
    "carcinología": "car-ci-no-lo-gí-a",
    "carcinológica": "car-ci-no-ló-gi-ca",
    "carcinológico": "car-ci-no-ló-gi-co",
    "carcinoma": "car-ci-no-ma",
    "carcocha": "car-co-cha",
    "cárcola": "cár-co-la",
    "carcoma": "car-co-ma",
    "carcomer": "car-co-mer",
    "carcomienta": "car-co-mien-ta",
    "carcomiento": "car-co-mien-to",
    "carcón": "car-cón",
    "carcoso": "car-co-so",
    "carcunda": "car-cun-da",
    "carcundia": "car-cun-dia",
    "carda": "car-da",
    "cardada": "car-da-da",
    "cardado": "car-da-do",
    "cardador": "car-da-dor",
    "cardadora": "car-da-do-ra",
    "cardadura": "car-da-du-ra",
    "cardaestambre": "car-da-es-tam-bre",
    "cardal": "car-dal",
    "cardamina": "car-da-mi-na",
    "cardamomo": "car-da-mo-mo",
    "cardán": "car-dán",
    "cardancho": "car-dan-cho",
    "cardar": "car-dar",
    "cardario": "car-da-rio",
    "cardelina": "car-de-li-na",
    "cardeña": "car-de-ña",
    "cárdena": "cár-de-na",
    "cardenal": "car-de-nal",
    "cardenalato": "car-de-na-la-to",
    "cardenalicia": "car-de-na-li-cia",
    "cardenalicio": "car-de-na-li-cio",
    "cardencha": "car-den-cha",
    "cardenchal": "car-den-chal",
    "cardenilla": "car-de-ni-lla",
    "cardenillo": "car-de-ni-llo",
    "cárdeno": "cár-de-no",
    "cardería": "car-de-rí-a",
    "cardero": "car-de-ro",
    "cardíaca": "car-dí-a-ca",
    "cardiaca": "car-dia-ca",
    "cardiácea": "car-diá-ce-a",
    "cardiáceo": "car-diá-ce-o",
    "cardíaco": "car-dí-a-co",
    "cardiaco": "car-dia-co",
    "cardial": "car-dial",
    "cardialgia": "car-dial-gia",
    "cardiálgica": "car-diál-gi-ca",
    "cardiálgico": "car-diál-gi-co",
    "cardias": "car-dias",
    "cárdigan": "cár-di-gan",
    "cardillar": "car-di-llar",
    "cardillo": "car-di-llo",
    "cardimuelle": "car-di-mue-lle",
    "cardina": "car-di-na",
    "cardinal": "car-di-nal",
    "cardinas": "car-di-nas",
    "cardinche": "car-din-che",
    "cardiocirculatorio": "car-dio-cir-cu-la-to-rio",
    "cardiocirugía": "car-dio-ci-ru-gí-a",
    "cardiocirujana": "car-dio-ci-ru-ja-na",
    "cardiocirujano": "car-dio-ci-ru-ja-no",
    "cardiografía": "car-dio-gra-fí-a",
    "cardiógrafo": "car-dió-gra-fo",
    "cardiograma": "car-dio-gra-ma",
    "cardióloga": "car-dió-lo-ga",
    "cardiología": "car-dio-lo-gí-a",
    "cardiológico": "car-dio-ló-gi-co",
    "cardiólogo": "car-dió-lo-go",
    "cardiópata": "car-dió-pa-ta",
    "cardiopatía": "car-dio-pa-tí-a",
    "cardiopulmonar": "car-dio-pul-mo-nar",
    "cardiorrespiratorio": "car-dio-rres-pi-ra-to-rio",
    "cardiotónico": "car-dio-tó-ni-co",
    "cardiovascular": "car-dio-vas-cu-lar",
    "cardítico": "car-dí-ti-co",
    "carditis": "car-di-tis",
    "cardizal": "car-di-zal",
    "cardo": "car-do",
    "cardón": "car-dón",
    "cardona": "car-do-na",
    "cardonal": "car-do-nal",
    "cardoncillo": "car-don-ci-llo",
    "carducha": "car-du-cha",
    "cardume": "car-du-me",
    "cardumen": "car-du-men",
    "carduza": "car-du-za",
    "carduzador": "car-du-za-dor",
    "carduzadora": "car-du-za-do-ra",
    "carduzal": "car-du-zal",
    "carduzar": "car-du-zar",
    "carea": "ca-re-a",
    "careador": "ca-re-a-dor",
    "carear": "ca-re-ar",
    "carecer": "ca-re-cer",
    "carecimiento": "ca-re-ci-mien-to",
    "careicillo": "ca-rei-ci-llo",
    "carel": "ca-rel",
    "carena": "ca-re-na",
    "carenado": "ca-re-na-do",
    "carenadura": "ca-re-na-du-ra",
    "carenar": "ca-re-nar",
    "carencia": "ca-ren-cia",
    "carencial": "ca-ren-cial",
    "carenero": "ca-re-ne-ro",
    "carenóstilo": "ca-re-nós-ti-lo",
    "carenote": "ca-re-no-te",
    "carente": "ca-ren-te",
    "careo": "ca-re-o",
    "carepalo": "ca-re-pa-lo",
    "carera": "ca-re-ra",
    "carero": "ca-re-ro",
    "caresa": "ca-re-sa",
    "carestía": "ca-res-tí-a",
    "careta": "ca-re-ta",
    "careto": "ca-re-to",
    "caretón": "ca-re-tón",
    "carey": "ca-rey",
    "careza": "ca-re-za",
    "carga": "car-ga",
    "cargada": "car-ga-da",
    "cargadal": "car-ga-dal",
    "cargadera": "car-ga-de-ra",
    "cargadero": "car-ga-de-ro",
    "cargadilla": "car-ga-di-lla",
    "cargado": "car-ga-do",
    "cargador": "car-ga-dor",
    "cargadora": "car-ga-do-ra",
    "cargamento": "car-ga-men-to",
    "cargamontón": "car-ga-mon-tón",
    "cargancia": "car-gan-cia",
    "cargante": "car-gan-te",
    "cargar": "car-gar",
    "cargareme": "car-ga-re-me",
    "cargazón": "car-ga-zón",
    "cargo": "car-go",
    "cargosa": "car-go-sa",
    "cargosear": "car-go-se-ar",
    "cargoso": "car-go-so",
    "cargue": "car-gue",
    "carguera": "car-gue-ra",
    "carguerío": "car-gue-rí-o",
    "carguero": "car-gue-ro",
    "carguillera": "car-gui-lle-ra",
    "carguillero": "car-gui-lle-ro",
    "carguío": "car-guí-o",
    "carhuacina": "car-hua-ci-na",
    "carhuacino": "car-hua-ci-no",
    "cari": "ca-ri",
    "caria": "ca-ria",
    "cariaceda": "ca-ria-ce-da",
    "cariacedo": "ca-ria-ce-do",
    "cariaco": "ca-ria-co",
    "cariacontecida": "ca-ria-con-te-ci-da",
    "cariacontecido": "ca-ria-con-te-ci-do",
    "cariacos": "ca-ria-cos",
    "cariacuchillada": "ca-ria-cu-chi-lla-da",
    "cariacuchillado": "ca-ria-cu-chi-lla-do",
    "cariada": "ca-ria-da",
    "cariado": "ca-ria-do",
    "cariadura": "ca-ria-du-ra",
    "cariaguileña": "ca-ria-gui-le-ña",
    "cariaguileño": "ca-ria-gui-le-ño",
    "carialegre": "ca-ria-le-gre",
    "carialzada": "ca-rial-za-da",
    "carialzado": "ca-rial-za-do",
    "cariampollada": "ca-riam-po-lla-da",
    "cariampollado": "ca-riam-po-lla-do",
    "cariampollar": "ca-riam-po-llar",
    "cariancha": "ca-rian-cha",
    "cariancho": "ca-rian-cho",
    "cariaquito": "ca-ria-qui-to",
    "cariar": "ca-riar",
    "cariátide": "ca-riá-ti-de",
    "caríbal": "ca-rí-bal",
    "caribe": "ca-ri-be",
    "caribear": "ca-ri-be-ar",
    "caribello": "ca-ri-be-llo",
    "caribeña": "ca-ri-be-ña",
    "caribeño": "ca-ri-be-ño",
    "cariblanco": "ca-ri-blan-co",
    "caribú": "ca-ri-bú",
    "caricácea": "ca-ri-cá-ce-a",
    "caricáceo": "ca-ri-cá-ce-o",
    "caricari": "ca-ri-ca-ri",
    "caricato": "ca-ri-ca-to",
    "caricatura": "ca-ri-ca-tu-ra",
    "caricatural": "ca-ri-ca-tu-ral",
    "caricaturalmente": "ca-ri-ca-tu-ral-men-te",
    "caricaturar": "ca-ri-ca-tu-rar",
    "caricaturesca": "ca-ri-ca-tu-res-ca",
    "caricaturescamente": "ca-ri-ca-tu-res-ca-men-te",
    "caricaturesco": "ca-ri-ca-tu-res-co",
    "caricaturista": "ca-ri-ca-tu-ris-ta",
    "caricaturización": "ca-ri-ca-tu-ri-za-ción",
    "caricaturizar": "ca-ri-ca-tu-ri-zar",
    "carichata": "ca-ri-cha-ta",
    "carichato": "ca-ri-cha-to",
    "caricia": "ca-ri-cia",
    "cariciosa": "ca-ri-cio-sa",
    "cariciosamente": "ca-ri-cio-sa-men-te",
    "caricioso": "ca-ri-cio-so",
    "caridad": "ca-ri-dad",
    "caridelantera": "ca-ri-de-lan-te-ra",
    "caridelantero": "ca-ri-de-lan-te-ro",
    "caridoliente": "ca-ri-do-lien-te",
    "cariduro": "ca-ri-du-ro",
    "cariedón": "ca-rie-dón",
    "carientismo": "ca-rien-tis-mo",
    "caries": "ca-ries",
    "carifruncida": "ca-ri-frun-ci-da",
    "carifruncido": "ca-ri-frun-ci-do",
    "carigorda": "ca-ri-gor-da",
    "carigordo": "ca-ri-gor-do",
    "cariharta": "ca-rihar-ta",
    "cariharto": "ca-rihar-to",
    "carilampiña": "ca-ri-lam-pi-ña",
    "carilampiño": "ca-ri-lam-pi-ño",
    "carilarga": "ca-ri-lar-ga",
    "carilargo": "ca-ri-lar-go",
    "carilimpia": "ca-ri-lim-pia",
    "carilimpio": "ca-ri-lim-pio",
    "carilinda": "ca-ri-lin-da",
    "carilindo": "ca-ri-lin-do",
    "carilla": "ca-ri-lla",
    "carillena": "ca-ri-lle-na",
    "carilleno": "ca-ri-lle-no",
    "carillo": "ca-ri-llo",
    "carillón": "ca-ri-llón",
    "carilucia": "ca-ri-lu-cia",
    "carilucio": "ca-ri-lu-cio",
    "carimañola": "ca-ri-ma-ño-la",
    "carimba": "ca-rim-ba",
    "carimbo": "ca-rim-bo",
    "cariña": "ca-ri-ña",
    "cariñana": "ca-ri-ña-na",
    "cariñar": "ca-ri-ñar",
    "carincho": "ca-rin-cho",
    "carinegra": "ca-ri-ne-gra",
    "carinegro": "ca-ri-ne-gro",
    "cariñena": "ca-ri-ñe-na",
    "carininfa": "ca-ri-nin-fa",
    "carininfo": "ca-ri-nin-fo",
    "cariño": "ca-ri-ño",
    "cariñosa": "ca-ri-ño-sa",
    "cariñosamente": "ca-ri-ño-sa-men-te",
    "cariñoso": "ca-ri-ño-so",
    "cario": "ca-rio",
    "carioca": "ca-rio-ca",
    "cariocar": "ca-rio-car",
    "cariocariácea": "ca-rio-ca-riá-ce-a",
    "cariocariáceo": "ca-rio-ca-riá-ce-o",
    "cariocinesis": "ca-rio-ci-ne-sis",
    "cariocinética": "ca-rio-ci-né-ti-ca",
    "cariocinético": "ca-rio-ci-né-ti-co",
    "cariofilácea": "ca-rio-fi-lá-ce-a",
    "cariofiláceo": "ca-rio-fi-lá-ce-o",
    "cariofilea": "ca-rio-fi-le-a",
    "cariofileo": "ca-rio-fi-le-o",
    "cariofilina": "ca-rio-fi-li-na",
    "cariola": "ca-rio-la",
    "cariópside": "ca-rióp-si-de",
    "carioquinesis": "ca-rio-qui-ne-sis",
    "cariosa": "ca-rio-sa",
    "carioso": "ca-rio-so",
    "cariotipo": "ca-rio-ti-po",
    "caripareja": "ca-ri-pa-re-ja",
    "cariparejo": "ca-ri-pa-re-jo",
    "caripelado": "ca-ri-pe-la-do",
    "carirraída": "ca-ri-rra-í-da",
    "carirraído": "ca-ri-rra-í-do",
    "carirredonda": "ca-ri-rre-don-da",
    "carirredondo": "ca-ri-rre-don-do",
    "carisea": "ca-ri-se-a",
    "cariseto": "ca-ri-se-to",
    "carisias": "ca-ri-sias",
    "carisma": "ca-ris-ma",
    "carismática": "ca-ris-má-ti-ca",
    "carismáticamente": "ca-ris-má-ti-ca-men-te",
    "carismático": "ca-ris-má-ti-co",
    "carisquio": "ca-ris-quio",
    "caristia": "ca-ris-tia",
    "caristias": "ca-ris-tias",
    "caristio": "ca-ris-tio",
    "caritate": "ca-ri-ta-te",
    "caritatero": "ca-ri-ta-te-ro",
    "caritativa": "ca-ri-ta-ti-va",
    "caritativamente": "ca-ri-ta-ti-va-men-te",
    "caritativo": "ca-ri-ta-ti-vo",
    "carite": "ca-ri-te",
    "cariucho": "ca-riu-cho",
    "cariz": "ca-riz",
    "carla": "car-la",
    "carlanca": "car-lan-ca",
    "carlanco": "car-lan-co",
    "carlancón": "car-lan-cón",
    "carlancona": "car-lan-co-na",
    "carlear": "car-le-ar",
    "carleta": "car-le-ta",
    "carlín": "car-lín",
    "carlina": "car-li-na",
    "carlincho": "car-lin-cho",
    "carlinga": "car-lin-ga",
    "carlismo": "car-lis-mo",
    "carlista": "car-lis-ta",
    "carlita": "car-li-ta",
    "carló": "car-ló",
    "carlón": "car-lón",
    "carlota": "car-lo-ta",
    "carlovingia": "car-lo-vin-gia",
    "carlovingio": "car-lo-vin-gio",
    "carmañola": "car-ma-ño-la",
    "carme": "car-me",
    "carmel": "car-mel",
    "carmela": "car-me-la",
    "carmelina": "car-me-li-na",
    "carmelita": "car-me-li-ta",
    "carmelitana": "car-me-li-ta-na",
    "carmelitano": "car-me-li-ta-no",
    "carmen": "car-men",
    "carmenador": "car-me-na-dor",
    "carmenadura": "car-me-na-du-ra",
    "carmenar": "car-me-nar",
    "carmentina": "car-men-ti-na",
    "carmes": "car-mes",
    "carmesí": "car-me-sí",
    "carmesita": "car-me-si-ta",
    "cármica": "cár-mi-ca",
    "carmín": "car-mín",
    "carminar": "car-mi-nar",
    "carminativa": "car-mi-na-ti-va",
    "carminativo": "car-mi-na-ti-vo",
    "carmínea": "car-mí-ne-a",
    "carmíneo": "car-mí-ne-o",
    "carminita": "car-mi-ni-ta",
    "carminosa": "car-mi-no-sa",
    "carminoso": "car-mi-no-so",
    "carnación": "car-na-ción",
    "carnada": "car-na-da",
    "carnadura": "car-na-du-ra",
    "carnaje": "car-na-je",
    "carnal": "car-nal",
    "carnalidad": "car-na-li-dad",
    "carnalmente": "car-nal-men-te",
    "carnauba": "car-nau-ba",
    "carnaval": "car-na-val",
    "carnavalada": "car-na-va-la-da",
    "carnavalear": "car-na-va-le-ar",
    "carnavalero": "car-na-va-le-ro",
    "carnavalesca": "car-na-va-les-ca",
    "carnavalesco": "car-na-va-les-co",
    "carnaválica": "car-na-vá-li-ca",
    "carnaválico": "car-na-vá-li-co",
    "carnavalito": "car-na-va-li-to",
    "carnaza": "car-na-za",
    "carnazón": "car-na-zón",
    "carne": "car-ne",
    "carné": "car-né",
    "cárnea": "cár-ne-a",
    "carneada": "car-ne-a-da",
    "carnear": "car-ne-ar",
    "carnecería": "car-ne-ce-rí-a",
    "carnecilla": "car-ne-ci-lla",
    "cárneo": "cár-ne-o",
    "carnera": "car-ne-ra",
    "carnerada": "car-ne-ra-da",
    "carneraje": "car-ne-ra-je",
    "carnereamiento": "car-ne-re-a-mien-to",
    "carnerear": "car-ne-re-ar",
    "carnerero": "car-ne-re-ro",
    "carneril": "car-ne-ril",
    "carnero": "car-ne-ro",
    "carneruna": "car-ne-ru-na",
    "carneruno": "car-ne-ru-no",
    "carnestolendas": "car-nes-to-len-das",
    "carnet": "car-net",
    "carnicera": "car-ni-ce-ra",
    "carnicería": "car-ni-ce-rí-a",
    "carnicero": "car-ni-ce-ro",
    "cárnico": "cár-ni-co",
    "carnicol": "car-ni-col",
    "carnícoles": "car-ní-co-les",
    "carnificación": "car-ni-fi-ca-ción",
    "carnificar": "car-ni-fi-car",
    "carnificarse": "car-ni-fi-car-se",
    "carnífice": "car-ní-fi-ce",
    "carniforme": "car-ni-for-me",
    "carniola": "car-nio-la",
    "carnios": "car-nios",
    "carniseca": "car-ni-se-ca",
    "carniseco": "car-ni-se-co",
    "carnitas": "car-ni-tas",
    "carnívora": "car-ní-vo-ra",
    "carnívoro": "car-ní-vo-ro",
    "carniza": "car-ni-za",
    "carnosa": "car-no-sa",
    "carnosidad": "car-no-si-dad",
    "carnoso": "car-no-so",
    "carnuda": "car-nu-da",
    "carnudo": "car-nu-do",
    "carnuz": "car-nuz",
    "carnuza": "car-nu-za",
    "caro": "ca-ro",
    "caroba": "ca-ro-ba",
    "caroca": "ca-ro-ca",
    "carocha": "ca-ro-cha",
    "carochar": "ca-ro-char",
    "carola": "ca-ro-la",
    "carolina": "ca-ro-li-na",
    "carolinensa": "ca-ro-li-nen-sa",
    "carolinense": "ca-ro-li-nen-se",
    "carolingia": "ca-ro-lin-gia",
    "carolingio": "ca-ro-lin-gio",
    "carolino": "ca-ro-li-no",
    "carolo": "ca-ro-lo",
    "cárolus": "cá-ro-lus",
    "caromomia": "ca-ro-mo-mia",
    "carón": "ca-rón",
    "carona": "ca-ro-na",
    "caronchar": "ca-ron-char",
    "caroncharse": "ca-ron-char-se",
    "caroncho": "ca-ron-cho",
    "caronchosa": "ca-ron-cho-sa",
    "caronchoso": "ca-ron-cho-so",
    "caronjo": "ca-ron-jo",
    "caroñosa": "ca-ro-ño-sa",
    "caroñoso": "ca-ro-ño-so",
    "caroquera": "ca-ro-que-ra",
    "caroquero": "ca-ro-que-ro",
    "caroreña": "ca-ro-re-ña",
    "caroreño": "ca-ro-re-ño",
    "carosiera": "ca-ro-sie-ra",
    "carosiero": "ca-ro-sie-ro",
    "carosis": "ca-ro-sis",
    "carota": "ca-ro-ta",
    "caroteno": "ca-ro-te-no",
    "carotenoide": "ca-ro-te-noi-de",
    "carótida": "ca-ró-ti-da",
    "carotídeo": "ca-ro-tí-de-o",
    "carotina": "ca-ro-ti-na",
    "caroto": "ca-ro-to",
    "carozo": "ca-ro-zo",
    "carpa": "car-pa",
    "carpancho": "car-pan-cho",
    "carpanel": "car-pa-nel",
    "carpanta": "car-pan-ta",
    "carpe": "car-pe",
    "carpedal": "car-pe-dal",
    "carpelar": "car-pe-lar",
    "carpelo": "car-pe-lo",
    "carpeña": "car-pe-ña",
    "carpeño": "car-pe-ño",
    "carpentear": "car-pen-te-ar",
    "carpeta": "car-pe-ta",
    "carpetana": "car-pe-ta-na",
    "carpetano": "car-pe-ta-no",
    "carpetazo": "car-pe-ta-zo",
    "carpetera": "car-pe-te-ra",
    "carpetero": "car-pe-te-ro",
    "carpetovetónico": "car-pe-to-ve-tó-ni-co",
    "carpiana": "car-pia-na",
    "carpiano": "car-pia-no",
    "carpidor": "car-pi-dor",
    "carpín": "car-pín",
    "carpincho": "car-pin-cho",
    "carpintear": "car-pin-te-ar",
    "carpintera": "car-pin-te-ra",
    "carpinterear": "car-pin-te-re-ar",
    "carpintereo": "car-pin-te-re-o",
    "carpintería": "car-pin-te-rí-a",
    "carpinteril": "car-pin-te-ril",
    "carpintero": "car-pin-te-ro",
    "carpintesa": "car-pin-te-sa",
    "carpir": "car-pir",
    "carpo": "car-po",
    "carpobálsamo": "car-po-bál-sa-mo",
    "carpófaga": "car-pó-fa-ga",
    "carpófago": "car-pó-fa-go",
    "carpología": "car-po-lo-gí-a",
    "carqueja": "car-que-ja",
    "carquerol": "car-que-rol",
    "carquesa": "car-que-sa",
    "carquesia": "car-que-sia",
    "carquiñol": "car-qui-ñol",
    "carra": "ca-rra",
    "carraca": "ca-rra-ca",
    "carracacao": "ca-rra-ca-ca-o",
    "carracera": "ca-rra-ce-ra",
    "carracero": "ca-rra-ce-ro",
    "carraco": "ca-rra-co",
    "carracón": "ca-rra-cón",
    "carracuca": "ca-rra-cu-ca",
    "carrada": "ca-rra-da",
    "carrafa": "ca-rra-fa",
    "carral": "ca-rral",
    "carraleja": "ca-rra-le-ja",
    "carralero": "ca-rra-le-ro",
    "carramarro": "ca-rra-ma-rro",
    "carramplón": "ca-rram-plón",
    "carraña": "ca-rra-ña",
    "carrañaca": "ca-rra-ña-ca",
    "carranca": "ca-rran-ca",
    "carrancla": "ca-rran-cla",
    "carranclo": "ca-rran-clo",
    "carranclón": "ca-rran-clón",
    "carrancudo": "ca-rran-cu-do",
    "carrañón": "ca-rra-ñón",
    "carrañona": "ca-rra-ño-na",
    "carrañosa": "ca-rra-ño-sa",
    "carrañoso": "ca-rra-ño-so",
    "carranza": "ca-rran-za",
    "carrao": "ca-rra-o",
    "carraón": "ca-rra-ón",
    "carraplana": "ca-rra-pla-na",
    "carraquear": "ca-rra-que-ar",
    "carrara": "ca-rra-ra",
    "carrasca": "ca-rras-ca",
    "carrascal": "ca-rras-cal",
    "carrascaloso": "ca-rras-ca-lo-so",
    "carrasco": "ca-rras-co",
    "carrascosa": "ca-rras-co-sa",
    "carrascoso": "ca-rras-co-so",
    "carraspada": "ca-rras-pa-da",
    "carraspear": "ca-rras-pe-ar",
    "carraspeña": "ca-rras-pe-ña",
    "carraspeño": "ca-rras-pe-ño",
    "carraspeo": "ca-rras-pe-o",
    "carraspera": "ca-rras-pe-ra",
    "carraspiento": "ca-rras-pien-to",
    "carraspina": "ca-rras-pi-na",
    "carraspique": "ca-rras-pi-que",
    "carrasposa": "ca-rras-po-sa",
    "carrasposo": "ca-rras-po-so",
    "carrasquear": "ca-rras-que-ar",
    "carrasqueña": "ca-rras-que-ña",
    "carrasqueño": "ca-rras-que-ño",
    "carrasquera": "ca-rras-que-ra",
    "carrasquilla": "ca-rras-qui-lla",
    "carrasquizo": "ca-rras-qui-zo",
    "carraza": "ca-rra-za",
    "carrazo": "ca-rra-zo",
    "carrear": "ca-rre-ar",
    "carredana": "ca-rre-da-na",
    "carredano": "ca-rre-da-no",
    "carrejo": "ca-rre-jo",
    "carreña": "ca-rre-ña",
    "carrendera": "ca-rren-de-ra",
    "carrendilla": "ca-rren-di-lla",
    "carrera": "ca-rre-ra",
    "carrerear": "ca-rre-re-ar",
    "carrerilla": "ca-rre-ri-lla",
    "carrerista": "ca-rre-ris-ta",
    "carrero": "ca-rre-ro",
    "carreta": "ca-rre-ta",
    "carretada": "ca-rre-ta-da",
    "carretaje": "ca-rre-ta-je",
    "carretal": "ca-rre-tal",
    "carretanagua": "ca-rre-ta-na-gua",
    "carrete": "ca-rre-te",
    "carretear": "ca-rre-te-ar",
    "carretel": "ca-rre-tel",
    "carretela": "ca-rre-te-la",
    "carreteo": "ca-rre-te-o",
    "carretera": "ca-rre-te-ra",
    "carretería": "ca-rre-te-rí-a",
    "carreteril": "ca-rre-te-ril",
    "carretero": "ca-rre-te-ro",
    "carretil": "ca-rre-til",
    "carretilla": "ca-rre-ti-lla",
    "carretillada": "ca-rre-ti-lla-da",
    "carretillera": "ca-rre-ti-lle-ra",
    "carretillero": "ca-rre-ti-lle-ro",
    "carretillo": "ca-rre-ti-llo",
    "carretina": "ca-rre-ti-na",
    "carreto": "ca-rre-to",
    "carretón": "ca-rre-tón",
    "carretonada": "ca-rre-to-na-da",
    "carretonaje": "ca-rre-to-na-je",
    "carretoncillo": "ca-rre-ton-ci-llo",
    "carretonero": "ca-rre-to-ne-ro",
    "carric": "ca-rric",
    "carricar": "ca-rri-car",
    "carricera": "ca-rri-ce-ra",
    "carricerín": "ca-rri-ce-rín",
    "carricero": "ca-rri-ce-ro",
    "carricillo": "ca-rri-ci-llo",
    "carricoche": "ca-rri-co-che",
    "carricuba": "ca-rri-cu-ba",
    "carriego": "ca-rrie-go",
    "carriel": "ca-rriel",
    "carril": "ca-rril",
    "carrilada": "ca-rri-la-da",
    "carrilano": "ca-rri-la-no",
    "carrilar": "ca-rri-lar",
    "carrilear": "ca-rri-le-ar",
    "carrilera": "ca-rri-le-ra",
    "carrilero": "ca-rri-le-ro",
    "carrilete": "ca-rri-le-te",
    "carrillada": "ca-rri-lla-da",
    "carrillera": "ca-rri-lle-ra",
    "carrillo": "ca-rri-llo",
    "carrillón": "ca-rri-llón",
    "carrilluda": "ca-rri-llu-da",
    "carrilludo": "ca-rri-llu-do",
    "carrindanga": "ca-rrin-dan-ga",
    "carriño": "ca-rri-ño",
    "carriola": "ca-rrio-la",
    "carriona": "ca-rrio-na",
    "carrique": "ca-rri-que",
    "carriquí": "ca-rri-quí",
    "carrito": "ca-rri-to",
    "carriza": "ca-rri-za",
    "carrizada": "ca-rri-za-da",
    "carrizal": "ca-rri-zal",
    "carrizo": "ca-rri-zo",
    "carro": "ca-rro",
    "carrocera": "ca-rro-ce-ra",
    "carrocería": "ca-rro-ce-rí-a",
    "carrocero": "ca-rro-ce-ro",
    "carrocha": "ca-rro-cha",
    "carrochar": "ca-rro-char",
    "carrocín": "ca-rro-cín",
    "carromatero": "ca-rro-ma-te-ro",
    "carromato": "ca-rro-ma-to",
    "carrón": "ca-rrón",
    "carroña": "ca-rro-ña",
    "carronada": "ca-rro-na-da",
    "carroñar": "ca-rro-ñar",
    "carroñera": "ca-rro-ñe-ra",
    "carroñero": "ca-rro-ñe-ro",
    "carroño": "ca-rro-ño",
    "carroñoso": "ca-rro-ño-so",
    "carroza": "ca-rro-za",
    "carrozable": "ca-rro-za-ble",
    "carrozar": "ca-rro-zar",
    "carruaje": "ca-rrua-je",
    "carruajero": "ca-rrua-je-ro",
    "carruata": "ca-rrua-ta",
    "carrubia": "ca-rru-bia",
    "carrubio": "ca-rru-bio",
    "carruca": "ca-rru-ca",
    "carrucar": "ca-rru-car",
    "carrucha": "ca-rru-cha",
    "carruchera": "ca-rru-che-ra",
    "carruco": "ca-rru-co",
    "carrujada": "ca-rru-ja-da",
    "carrujado": "ca-rru-ja-do",
    "carrujo": "ca-rru-jo",
    "carruna": "ca-rru-na",
    "carrusel": "ca-rru-sel",
    "cárstico": "cárs-ti-co",
    "carta": "car-ta",
    "cartabón": "car-ta-bón",
    "cartagenera": "car-ta-ge-ne-ra",
    "cartagenero": "car-ta-ge-ne-ro",
    "cartaginense": "car-ta-gi-nen-se",
    "cartaginés": "car-ta-gi-nés",
    "cartaginesa": "car-ta-gi-ne-sa",
    "cartaginiense": "car-ta-gi-nien-se",
    "cártama": "cár-ta-ma",
    "cártamo": "cár-ta-mo",
    "cartapacio": "car-ta-pa-cio",
    "cartapel": "car-ta-pel",
    "cartazo": "car-ta-zo",
    "carteado": "car-te-a-do",
    "cartear": "car-te-ar",
    "cartel": "car-tel",
    "cártel": "cár-tel",
    "cartela": "car-te-la",
    "cartelado": "car-te-la-do",
    "cartelear": "car-te-le-ar",
    "cartelera": "car-te-le-ra",
    "cartelero": "car-te-le-ro",
    "cartelismo": "car-te-lis-mo",
    "cartelista": "car-te-lis-ta",
    "carteo": "car-te-o",
    "cárter": "cár-ter",
    "cartera": "car-te-ra",
    "carterear": "car-te-re-ar",
    "cartería": "car-te-rí-a",
    "carterista": "car-te-ris-ta",
    "carterita": "car-te-ri-ta",
    "cartero": "car-te-ro",
    "cartesiana": "car-te-sia-na",
    "cartesianamente": "car-te-sia-na-men-te",
    "cartesianismo": "car-te-sia-nis-mo",
    "cartesiano": "car-te-sia-no",
    "carteta": "car-te-ta",
    "cartiero": "car-tie-ro",
    "cartilágine": "car-ti-lá-gi-ne",
    "cartilagíneo": "car-ti-la-gí-ne-o",
    "cartilaginosa": "car-ti-la-gi-no-sa",
    "cartilaginoso": "car-ti-la-gi-no-so",
    "cartílago": "car-tí-la-go",
    "cartilla": "car-ti-lla",
    "cartivana": "car-ti-va-na",
    "cartógrafa": "car-tó-gra-fa",
    "cartografía": "car-to-gra-fí-a",
    "cartografiar": "car-to-gra-fiar",
    "cartográfica": "car-to-grá-fi-ca",
    "cartográfico": "car-to-grá-fi-co",
    "cartógrafo": "car-tó-gra-fo",
    "cartolas": "car-to-las",
    "cartomancía": "car-to-man-cí-a",
    "cartomancia": "car-to-man-cia",
    "cartomántica": "car-to-mán-ti-ca",
    "cartomántico": "car-to-mán-ti-co",
    "cartometría": "car-to-me-trí-a",
    "cartométrica": "car-to-mé-tri-ca",
    "cartométrico": "car-to-mé-tri-co",
    "cartómetro": "car-tó-me-tro",
    "cartón": "car-tón",
    "cartona": "car-to-na",
    "cartonaje": "car-to-na-je",
    "cartoné": "car-to-né",
    "cartonera": "car-to-ne-ra",
    "cartonería": "car-to-ne-rí-a",
    "cartonero": "car-to-ne-ro",
    "cartonista": "car-to-nis-ta",
    "cartuchera": "car-tu-che-ra",
    "cartucho": "car-tu-cho",
    "cartuchón": "car-tu-chón",
    "cartuja": "car-tu-ja",
    "cartujana": "car-tu-ja-na",
    "cartujano": "car-tu-ja-no",
    "cartujo": "car-tu-jo",
    "cartulario": "car-tu-la-rio",
    "cartulina": "car-tu-li-na",
    "cartusana": "car-tu-sa-na",
    "caruata": "ca-rua-ta",
    "caruja": "ca-ru-ja",
    "carúncula": "ca-rún-cu-la",
    "carunculada": "ca-run-cu-la-da",
    "carunculado": "ca-run-cu-la-do",
    "caruncular": "ca-run-cu-lar",
    "carupanera": "ca-ru-pa-ne-ra",
    "carupanero": "ca-ru-pa-ne-ro",
    "carurú": "ca-ru-rú",
    "caruto": "ca-ru-to",
    "carvajal": "car-va-jal",
    "carvajo": "car-va-jo",
    "carvallar": "car-va-llar",
    "carvalleda": "car-va-lle-da",
    "carvalledo": "car-va-lle-do",
    "carvallo": "car-va-llo",
    "carvayo": "car-va-yo",
    "carvi": "car-vi",
    "casa": "ca-sa",
    "casabe": "ca-sa-be",
    "casaca": "ca-sa-ca",
    "casación": "ca-sa-ción",
    "casada": "ca-sa-da",
    "casadera": "ca-sa-de-ra",
    "casadero": "ca-sa-de-ro",
    "casado": "ca-sa-do",
    "casal": "ca-sal",
    "casalera": "ca-sa-le-ra",
    "casalero": "ca-sa-le-ro",
    "casalicio": "ca-sa-li-cio",
    "casamata": "ca-sa-ma-ta",
    "casamentera": "ca-sa-men-te-ra",
    "casamentero": "ca-sa-men-te-ro",
    "casamiento": "ca-sa-mien-to",
    "casampulga": "ca-sam-pul-ga",
    "casamuro": "ca-sa-mu-ro",
    "casanareña": "ca-sa-na-re-ña",
    "casanareño": "ca-sa-na-re-ño",
    "casanarense": "ca-sa-na-ren-se",
    "casanova": "ca-sa-no-va",
    "casapuerta": "ca-sa-puer-ta",
    "casaquilla": "ca-sa-qui-lla",
    "casaquín": "ca-sa-quín",
    "casar": "ca-sar",
    "casariega": "ca-sa-rie-ga",
    "casariego": "ca-sa-rie-go",
    "casarón": "ca-sa-rón",
    "casateniente": "ca-sa-te-nien-te",
    "casatienda": "ca-sa-tien-da",
    "casba": "cas-ba",
    "casca": "cas-ca",
    "cascabel": "cas-ca-bel",
    "cascabela": "cas-ca-be-la",
    "cascabelada": "cas-ca-be-la-da",
    "cascabelear": "cas-ca-be-le-ar",
    "cascabeleo": "cas-ca-be-le-o",
    "cascabelera": "cas-ca-be-le-ra",
    "cascabelero": "cas-ca-be-le-ro",
    "cascabelillo": "cas-ca-be-li-llo",
    "cascabillo": "cas-ca-bi-llo",
    "cascabullo": "cas-ca-bu-llo",
    "cascaciruelas": "cas-ca-ci-rue-las",
    "cascada": "cas-ca-da",
    "cascado": "cas-ca-do",
    "cascadura": "cas-ca-du-ra",
    "cascajal": "cas-ca-jal",
    "cascajar": "cas-ca-jar",
    "cascajera": "cas-ca-je-ra",
    "cascajo": "cas-ca-jo",
    "cascajosa": "cas-ca-jo-sa",
    "cascajoso": "cas-ca-jo-so",
    "cascajuela": "cas-ca-jue-la",
    "cascajuelo": "cas-ca-jue-lo",
    "cascalbo": "cas-cal-bo",
    "cascalleja": "cas-ca-lle-ja",
    "cascalote": "cas-ca-lo-te",
    "cascamajar": "cas-ca-ma-jar",
    "cascamiento": "cas-ca-mien-to",
    "cascanueces": "cas-ca-nue-ces",
    "cascapiñones": "cas-ca-pi-ño-nes",
    "cascar": "cas-car",
    "cáscara": "cás-ca-ra",
    "cascarela": "cas-ca-re-la",
    "cascarilla": "cas-ca-ri-lla",
    "cascarillal": "cas-ca-ri-llal",
    "cascarillera": "cas-ca-ri-lle-ra",
    "cascarillero": "cas-ca-ri-lle-ro",
    "cascarillina": "cas-ca-ri-lli-na",
    "cascarillo": "cas-ca-ri-llo",
    "cascarita": "cas-ca-ri-ta",
    "cascarón": "cas-ca-rón",
    "cascarrabias": "cas-ca-rra-bias",
    "cascarria": "cas-ca-rria",
    "cascarrina": "cas-ca-rri-na",
    "cascarrinada": "cas-ca-rri-na-da",
    "cascarrinar": "cas-ca-rri-nar",
    "cascarrioso": "cas-ca-rrio-so",
    "cascarrojas": "cas-ca-rro-jas",
    "cascarrón": "cas-ca-rrón",
    "cascarrona": "cas-ca-rro-na",
    "cascaruda": "cas-ca-ru-da",
    "cascarudo": "cas-ca-ru-do",
    "cascaruja": "cas-ca-ru-ja",
    "cascaruleta": "cas-ca-ru-le-ta",
    "cascás": "cas-cás",
    "cascatreguas": "cas-ca-tre-guas",
    "casco": "cas-co",
    "cascol": "cas-col",
    "cascolitro": "cas-co-li-tro",
    "cascorvo": "cas-cor-vo",
    "cascote": "cas-co-te",
    "cascuda": "cas-cu-da",
    "cascudo": "cas-cu-do",
    "cascué": "cas-cué",
    "cásea": "cá-se-a",
    "caseación": "ca-se-a-ción",
    "caseica": "ca-sei-ca",
    "caseico": "ca-sei-co",
    "caseificación": "ca-sei-fi-ca-ción",
    "caseificar": "ca-sei-fi-car",
    "caseína": "ca-se-í-na",
    "cáseo": "cá-se-o",
    "caseosa": "ca-se-o-sa",
    "caseoso": "ca-se-o-so",
    "casera": "ca-se-ra",
    "caseramente": "ca-se-ra-men-te",
    "casería": "ca-se-rí-a",
    "caserillo": "ca-se-ri-llo",
    "caserío": "ca-se-rí-o",
    "caserna": "ca-ser-na",
    "casero": "ca-se-ro",
    "caserón": "ca-se-rón",
    "caseta": "ca-se-ta",
    "casete": "ca-se-te",
    "casetera": "ca-se-te-ra",
    "casetero": "ca-se-te-ro",
    "caseto": "ca-se-to",
    "casetón": "ca-se-tón",
    "casi": "ca-si",
    "casia": "ca-sia",
    "casida": "ca-si-da",
    "casidulina": "ca-si-du-li-na",
    "casilla": "ca-si-lla",
    "casiller": "ca-si-ller",
    "casillero": "ca-si-lle-ro",
    "casimba": "ca-sim-ba",
    "casimir": "ca-si-mir",
    "casimira": "ca-si-mi-ra",
    "casimpulga": "ca-sim-pul-ga",
    "casina": "ca-si-na",
    "casineta": "ca-si-ne-ta",
    "casinete": "ca-si-ne-te",
    "casinita": "ca-si-ni-ta",
    "casino": "ca-si-no",
    "casio": "ca-sio",
    "casiopiri": "ca-sio-pi-ri",
    "casis": "ca-sis",
    "casiterita": "ca-si-te-ri-ta",
    "casmeña": "cas-me-ña",
    "casmeño": "cas-me-ño",
    "casmodia": "cas-mo-dia",
    "caso": "ca-so",
    "casón": "ca-són",
    "casona": "ca-so-na",
    "casorio": "ca-so-rio",
    "caspa": "cas-pa",
    "caspera": "cas-pe-ra",
    "caspia": "cas-pia",
    "caspicias": "cas-pi-cias",
    "caspiento": "cas-pien-to",
    "caspio": "cas-pio",
    "caspiroleta": "cas-pi-ro-le-ta",
    "cáspita": "cás-pi-ta",
    "caspolina": "cas-po-li-na",
    "caspolino": "cas-po-li-no",
    "casposa": "cas-po-sa",
    "casposo": "cas-po-so",
    "casquera": "cas-que-ra",
    "casquería": "cas-que-rí-a",
    "casquero": "cas-que-ro",
    "casquetada": "cas-que-ta-da",
    "casquetazo": "cas-que-ta-zo",
    "casquete": "cas-que-te",
    "casquiacopada": "cas-quia-co-pa-da",
    "casquiacopado": "cas-quia-co-pa-do",
    "casquiblanda": "cas-qui-blan-da",
    "casquiblando": "cas-qui-blan-do",
    "casquiderramada": "cas-qui-de-rra-ma-da",
    "casquiderramado": "cas-qui-de-rra-ma-do",
    "casquijo": "cas-qui-jo",
    "casquilla": "cas-qui-lla",
    "casquillo": "cas-qui-llo",
    "casquilucia": "cas-qui-lu-cia",
    "casquilucio": "cas-qui-lu-cio",
    "casquimuleña": "cas-qui-mu-le-ña",
    "casquimuleño": "cas-qui-mu-le-ño",
    "casquite": "cas-qui-te",
    "casquivana": "cas-qui-va-na",
    "casquivano": "cas-qui-va-no",
    "cassette": "cas-set-te",
    "casta": "cas-ta",
    "castalia": "cas-ta-lia",
    "castálidas": "cas-tá-li-das",
    "castalio": "cas-ta-lio",
    "castamente": "cas-ta-men-te",
    "castaña": "cas-ta-ña",
    "castañal": "cas-ta-ñal",
    "castañar": "cas-ta-ñar",
    "castañazo": "cas-ta-ña-zo",
    "castañear": "cas-ta-ñe-ar",
    "castañeda": "cas-ta-ñe-da",
    "castañedo": "cas-ta-ñe-do",
    "castañera": "cas-ta-ñe-ra",
    "castañero": "cas-ta-ñe-ro",
    "castañeta": "cas-ta-ñe-ta",
    "castañetada": "cas-ta-ñe-ta-da",
    "castañetazo": "cas-ta-ñe-ta-zo",
    "castañete": "cas-ta-ñe-te",
    "castañeteado": "cas-ta-ñe-te-a-do",
    "castañetear": "cas-ta-ñe-te-ar",
    "castañeteo": "cas-ta-ñe-te-o",
    "castaño": "cas-ta-ño",
    "castañola": "cas-ta-ño-la",
    "castañuela": "cas-ta-ñue-la",
    "castañuelo": "cas-ta-ñue-lo",
    "castel": "cas-tel",
    "castellana": "cas-te-lla-na",
    "castellanamente": "cas-te-lla-na-men-te",
    "castellanía": "cas-te-lla-ní-a",
    "castellanidad": "cas-te-lla-ni-dad",
    "castellanismo": "cas-te-lla-nis-mo",
    "castellanista": "cas-te-lla-nis-ta",
    "castellanización": "cas-te-lla-ni-za-ción",
    "castellanizar": "cas-te-lla-ni-zar",
    "castellano": "cas-te-lla-no",
    "castellanohablante": "cas-te-lla-no-ha-blan-te",
    "castellanoparlante": "cas-te-lla-no-par-lan-te",
    "castellar": "cas-te-llar",
    "castellero": "cas-te-lle-ro",
    "castellonense": "cas-te-llo-nen-se",
    "casticidad": "cas-ti-ci-dad",
    "casticismo": "cas-ti-cis-mo",
    "casticista": "cas-ti-cis-ta",
    "castidad": "cas-ti-dad",
    "castigación": "cas-ti-ga-ción",
    "castigadamente": "cas-ti-ga-da-men-te",
    "castigadera": "cas-ti-ga-de-ra",
    "castigador": "cas-ti-ga-dor",
    "castigadora": "cas-ti-ga-do-ra",
    "castigar": "cas-ti-gar",
    "castigo": "cas-ti-go",
    "castilla": "cas-ti-lla",
    "castillada": "cas-ti-lla-da",
    "castillado": "cas-ti-lla-do",
    "castillaje": "cas-ti-lla-je",
    "castillejo": "cas-ti-lle-jo",
    "castillería": "cas-ti-lle-rí-a",
    "castillero": "cas-ti-lle-ro",
    "castillete": "cas-ti-lle-te",
    "castillo": "cas-ti-llo",
    "castimonia": "cas-ti-mo-nia",
    "castina": "cas-ti-na",
    "cásting": "cás-ting",
    "castiza": "cas-ti-za",
    "castizamente": "cas-ti-za-men-te",
    "castizo": "cas-ti-zo",
    "casto": "cas-to",
    "castor": "cas-tor",
    "castora": "cas-to-ra",
    "castorcillo": "cas-tor-ci-llo",
    "castoreño": "cas-to-re-ño",
    "castóreo": "cas-tó-re-o",
    "castorina": "cas-to-ri-na",
    "castorio": "cas-to-rio",
    "castra": "cas-tra",
    "castración": "cas-tra-ción",
    "castrada": "cas-tra-da",
    "castradera": "cas-tra-de-ra",
    "castrado": "cas-tra-do",
    "castrador": "cas-tra-dor",
    "castradora": "cas-tra-do-ra",
    "castradura": "cas-tra-du-ra",
    "castrametación": "cas-tra-me-ta-ción",
    "castrante": "cas-tran-te",
    "castrapuercas": "cas-tra-puer-cas",
    "castrapuercos": "cas-tra-puer-cos",
    "castrar": "cas-trar",
    "castrato": "cas-tra-to",
    "castrazón": "cas-tra-zón",
    "castreña": "cas-tre-ña",
    "castreño": "cas-tre-ño",
    "castrense": "cas-tren-se",
    "castrina": "cas-tri-na",
    "castrino": "cas-tri-no",
    "castrismo": "cas-tris-mo",
    "castrista": "cas-tris-ta",
    "castro": "cas-tro",
    "castrón": "cas-trón",
    "castúa": "cas-tú-a",
    "castuga": "cas-tu-ga",
    "cástula": "cás-tu-la",
    "castúo": "cas-tú-o",
    "casual": "ca-sual",
    "casualidad": "ca-sua-li-dad",
    "casualismo": "ca-sua-lis-mo",
    "casualista": "ca-sua-lis-ta",
    "casualmente": "ca-sual-men-te",
    "casuar": "ca-suar",
    "casuárida": "ca-suá-ri-da",
    "casuárido": "ca-suá-ri-do",
    "casuariforme": "ca-sua-ri-for-me",
    "casuarina": "ca-sua-ri-na",
    "casuarinácea": "ca-sua-ri-ná-ce-a",
    "casuarináceo": "ca-sua-ri-ná-ce-o",
    "casuario": "ca-sua-rio",
    "casuca": "ca-su-ca",
    "casucha": "ca-su-cha",
    "casucho": "ca-su-cho",
    "casuismo": "ca-suis-mo",
    "casuista": "ca-suis-ta",
    "casuística": "ca-suís-ti-ca",
    "casuístico": "ca-suís-ti-co",
    "casulla": "ca-su-lla",
    "casullero": "ca-su-lle-ro",
    "cata": "ca-ta",
    "catabejas": "ca-ta-be-jas",
    "catabólica": "ca-ta-bó-li-ca",
    "catabólico": "ca-ta-bó-li-co",
    "catabolismo": "ca-ta-bo-lis-mo",
    "catabra": "ca-ta-bra",
    "catabre": "ca-ta-bre",
    "catabro": "ca-ta-bro",
    "catacaldos": "ca-ta-cal-dos",
    "catachín": "ca-ta-chín",
    "cataclismo": "ca-ta-clis-mo",
    "catacresis": "ca-ta-cre-sis",
    "catacumbas": "ca-ta-cum-bas",
    "catadióptrica": "ca-ta-dióp-tri-ca",
    "catadióptrico": "ca-ta-dióp-tri-co",
    "catador": "ca-ta-dor",
    "catadora": "ca-ta-do-ra",
    "catádroma": "ca-tá-dro-ma",
    "catádromo": "ca-tá-dro-mo",
    "catadura": "ca-ta-du-ra",
    "catafalco": "ca-ta-fal-co",
    "catáfora": "ca-tá-fo-ra",
    "catafórico": "ca-ta-fó-ri-co",
    "catalán": "ca-ta-lán",
    "catalana": "ca-ta-la-na",
    "catalanidad": "ca-ta-la-ni-dad",
    "catalanismo": "ca-ta-la-nis-mo",
    "catalanista": "ca-ta-la-nis-ta",
    "catalanización": "ca-ta-la-ni-za-ción",
    "catalanizar": "ca-ta-la-ni-zar",
    "catalanohablante": "ca-ta-la-no-ha-blan-te",
    "catalanoparlante": "ca-ta-la-no-par-lan-te",
    "cataláunica": "ca-ta-láu-ni-ca",
    "cataláunico": "ca-ta-láu-ni-co",
    "cataldo": "ca-tal-do",
    "cataléctico": "ca-ta-léc-ti-co",
    "catalejo": "ca-ta-le-jo",
    "catalepsia": "ca-ta-lep-sia",
    "cataléptica": "ca-ta-lép-ti-ca",
    "cataléptico": "ca-ta-lép-ti-co",
    "catalicón": "ca-ta-li-cón",
    "catalicores": "ca-ta-li-co-res",
    "catalina": "ca-ta-li-na",
    "catalineta": "ca-ta-li-ne-ta",
    "catálisis": "ca-tá-li-sis",
    "catalítica": "ca-ta-lí-ti-ca",
    "catalítico": "ca-ta-lí-ti-co",
    "catalizador": "ca-ta-li-za-dor",
    "catalizadora": "ca-ta-li-za-do-ra",
    "catalizar": "ca-ta-li-zar",
    "catalnica": "ca-tal-ni-ca",
    "catalogación": "ca-ta-lo-ga-ción",
    "catalogador": "ca-ta-lo-ga-dor",
    "catalogadora": "ca-ta-lo-ga-do-ra",
    "catalogar": "ca-ta-lo-gar",
    "catálogo": "ca-tá-lo-go",
    "catalpa": "ca-tal-pa",
    "catalufa": "ca-ta-lu-fa",
    "cataluja": "ca-ta-lu-ja",
    "catamarán": "ca-ta-ma-rán",
    "catamarqueña": "ca-ta-mar-que-ña",
    "catamarqueño": "ca-ta-mar-que-ño",
    "catamenial": "ca-ta-me-nial",
    "catamiento": "ca-ta-mien-to",
    "catán": "ca-tán",
    "catana": "ca-ta-na",
    "catanga": "ca-tan-ga",
    "cataplasma": "ca-ta-plas-ma",
    "cataplexia": "ca-ta-ple-xia",
    "cataplín": "ca-ta-plín",
    "cataplum": "ca-ta-plum",
    "catapulta": "ca-ta-pul-ta",
    "catapultar": "ca-ta-pul-tar",
    "catapum": "ca-ta-pum",
    "catapún": "ca-ta-pún",
    "catar": "ca-tar",
    "cataraña": "ca-ta-ra-ña",
    "catarata": "ca-ta-ra-ta",
    "catarí": "ca-ta-rí",
    "catarinita": "ca-ta-ri-ni-ta",
    "cátaro": "cá-ta-ro",
    "catarral": "ca-ta-rral",
    "catarribera": "ca-ta-rri-be-ra",
    "catarriento": "ca-ta-rrien-to",
    "catarrino": "ca-ta-rri-no",
    "catarro": "ca-ta-rro",
    "catarrosa": "ca-ta-rro-sa",
    "catarroso": "ca-ta-rro-so",
    "catarrufín": "ca-ta-rru-fín",
    "catarsis": "ca-tar-sis",
    "catártica": "ca-tár-ti-ca",
    "catártico": "ca-tár-ti-co",
    "catartiforme": "ca-tar-ti-for-me",
    "catasalsas": "ca-ta-sal-sas",
    "catascán": "ca-tas-cán",
    "catascana": "ca-tas-ca-na",
    "catascopio": "ca-tas-co-pio",
    "catasta": "ca-tas-ta",
    "catástasis": "ca-tás-ta-sis",
    "catastral": "ca-tas-tral",
    "catastro": "ca-tas-tro",
    "catástrofe": "ca-tás-tro-fe",
    "catastróficamente": "ca-tas-tró-fi-ca-men-te",
    "catastrófico": "ca-tas-tró-fi-co",
    "catastrofismo": "ca-tas-tro-fis-mo",
    "catastrofista": "ca-tas-tro-fis-ta",
    "catatar": "ca-ta-tar",
    "catatipia": "ca-ta-ti-pia",
    "catatonia": "ca-ta-to-nia",
    "catatónica": "ca-ta-tó-ni-ca",
    "catatónico": "ca-ta-tó-ni-co",
    "catatumba": "ca-ta-tum-ba",
    "cataubas": "ca-tau-bas",
    "catauro": "ca-tau-ro",
    "cataviento": "ca-ta-vien-to",
    "catavino": "ca-ta-vi-no",
    "catavinos": "ca-ta-vi-nos",
    "catcher": "cat-cher",
    "cate": "ca-te",
    "cateada": "ca-te-a-da",
    "cateador": "ca-te-a-dor",
    "cateadora": "ca-te-a-do-ra",
    "catear": "ca-te-ar",
    "catecismo": "ca-te-cis-mo",
    "catecolamina": "ca-te-co-la-mi-na",
    "catecú": "ca-te-cú",
    "catecúmena": "ca-te-cú-me-na",
    "catecumenado": "ca-te-cu-me-na-do",
    "catecumenia": "ca-te-cu-me-nia",
    "catecúmeno": "ca-te-cú-me-no",
    "cátedra": "cá-te-dra",
    "catedral": "ca-te-dral",
    "catedralicia": "ca-te-dra-li-cia",
    "catedralicio": "ca-te-dra-li-cio",
    "catedralidad": "ca-te-dra-li-dad",
    "catedrar": "ca-te-drar",
    "catedrática": "ca-te-drá-ti-ca",
    "catedrático": "ca-te-drá-ti-co",
    "catedrilla": "ca-te-dri-lla",
    "cátedro": "cá-te-dro",
    "categorema": "ca-te-go-re-ma",
    "categoremático": "ca-te-go-re-má-ti-co",
    "categoría": "ca-te-go-rí-a",
    "categorial": "ca-te-go-rial",
    "categórica": "ca-te-gó-ri-ca",
    "categóricamente": "ca-te-gó-ri-ca-men-te",
    "categórico": "ca-te-gó-ri-co",
    "categorismo": "ca-te-go-ris-mo",
    "categorización": "ca-te-go-ri-za-ción",
    "categorizador": "ca-te-go-ri-za-dor",
    "categorizar": "ca-te-go-ri-zar",
    "catela": "ca-te-la",
    "catenaria": "ca-te-na-ria",
    "catenario": "ca-te-na-rio",
    "catenular": "ca-te-nu-lar",
    "cateo": "ca-te-o",
    "catequesis": "ca-te-que-sis",
    "catequética": "ca-te-qué-ti-ca",
    "catequético": "ca-te-qué-ti-co",
    "catequismo": "ca-te-quis-mo",
    "catequista": "ca-te-quis-ta",
    "catequística": "ca-te-quís-ti-ca",
    "catequístico": "ca-te-quís-ti-co",
    "catequización": "ca-te-qui-za-ción",
    "catequizador": "ca-te-qui-za-dor",
    "catequizadora": "ca-te-qui-za-do-ra",
    "catequizar": "ca-te-qui-zar",
    "catera": "ca-te-ra",
    "cateramba": "ca-te-ram-ba",
    "catéresis": "ca-té-re-sis",
    "caterética": "ca-te-ré-ti-ca",
    "caterético": "ca-te-ré-ti-co",
    "caterva": "ca-ter-va",
    "catervarios": "ca-ter-va-rios",
    "cateta": "ca-te-ta",
    "catete": "ca-te-te",
    "catetear": "ca-te-te-ar",
    "cateteo": "ca-te-te-o",
    "catéter": "ca-té-ter",
    "cateterismo": "ca-te-te-ris-mo",
    "cateto": "ca-te-to",
    "catetómetro": "ca-te-tó-me-tro",
    "catey": "ca-tey",
    "cateya": "ca-te-ya",
    "catibía": "ca-ti-bí-a",
    "catibo": "ca-ti-bo",
    "catifa": "ca-ti-fa",
    "catiguá": "ca-ti-guá",
    "catilinaria": "ca-ti-li-na-ria",
    "catimbao": "ca-tim-ba-o",
    "catimía": "ca-ti-mí-a",
    "catín": "ca-tín",
    "catinga": "ca-tin-ga",
    "catingosa": "ca-tin-go-sa",
    "catingoso": "ca-tin-go-so",
    "catinguda": "ca-tin-gu-da",
    "catingudo": "ca-tin-gu-do",
    "catino": "ca-ti-no",
    "catión": "ca-tión",
    "catira": "ca-ti-ra",
    "catire": "ca-ti-re",
    "catiro": "ca-ti-ro",
    "catirrino": "ca-ti-rri-no",
    "catita": "ca-ti-ta",
    "catite": "ca-ti-te",
    "catitear": "ca-ti-te-ar",
    "catiusca": "ca-tius-ca",
    "cativa": "ca-ti-va",
    "cativar": "ca-ti-var",
    "cativí": "ca-ti-ví",
    "cativo": "ca-ti-vo",
    "catizumba": "ca-ti-zum-ba",
    "catizumbada": "ca-ti-zum-ba-da",
    "catizumbazo": "ca-ti-zum-ba-zo",
    "catleya": "ca-tle-ya",
    "cato": "ca-to",
    "catoche": "ca-to-che",
    "catódica": "ca-tó-di-ca",
    "catódico": "ca-tó-di-co",
    "cátodo": "cá-to-do",
    "catodonte": "ca-to-don-te",
    "católica": "ca-tó-li-ca",
    "católicamente": "ca-tó-li-ca-men-te",
    "catolicidad": "ca-to-li-ci-dad",
    "catolicismo": "ca-to-li-cis-mo",
    "católico": "ca-tó-li-co",
    "catolicón": "ca-to-li-cón",
    "catolizar": "ca-to-li-zar",
    "catón": "ca-tón",
    "catoniana": "ca-to-nia-na",
    "catoniano": "ca-to-nia-no",
    "catonismo": "ca-to-nis-mo",
    "catonizar": "ca-to-ni-zar",
    "catóptrica": "ca-tóp-tri-ca",
    "catóptrico": "ca-tóp-tri-co",
    "catoptromancía": "ca-top-tro-man-cí-a",
    "catoptromancia": "ca-top-tro-man-cia",
    "catoptroscopia": "ca-top-tros-co-pia",
    "catoquita": "ca-to-qui-ta",
    "catorce": "ca-tor-ce",
    "catorceavo": "ca-tor-ce-a-vo",
    "catorcena": "ca-tor-ce-na",
    "catorceno": "ca-tor-ce-no",
    "catorrazo": "ca-to-rra-zo",
    "catorzal": "ca-tor-zal",
    "catorzava": "ca-tor-za-va",
    "catorzavo": "ca-tor-za-vo",
    "catos": "ca-tos",
    "catracha": "ca-tra-cha",
    "catracho": "ca-tra-cho",
    "catramina": "ca-tra-mi-na",
    "catre": "ca-tre",
    "catrecillo": "ca-tre-ci-llo",
    "catrera": "ca-tre-ra",
    "catricofre": "ca-tri-co-fre",
    "catrín": "ca-trín",
    "catrina": "ca-tri-na",
    "caturra": "ca-tu-rra",
    "catuto": "ca-tu-to",
    "cauba": "cau-ba",
    "cauca": "cau-ca",
    "caucana": "cau-ca-na",
    "caucano": "cau-ca-no",
    "caucásea": "cau-cá-se-a",
    "caucáseo": "cau-cá-se-o",
    "caucasiana": "cau-ca-sia-na",
    "caucasiano": "cau-ca-sia-no",
    "caucásica": "cau-cá-si-ca",
    "caucásico": "cau-cá-si-co",
    "caucáu": "cau-cáu",
    "cauce": "cau-ce",
    "caucel": "cau-cel",
    "caucense": "cau-cen-se",
    "caucha": "cau-cha",
    "cauchal": "cau-chal",
    "cauchar": "cau-char",
    "caucháu": "cau-cháu",
    "cauchera": "cau-che-ra",
    "cauchero": "cau-che-ro",
    "cauchicultor": "cau-chi-cul-tor",
    "cauchicultora": "cau-chi-cul-to-ra",
    "cauchil": "cau-chil",
    "caucho": "cau-cho",
    "cauchotina": "cau-cho-ti-na",
    "caución": "cau-ción",
    "caucionado": "cau-cio-na-do",
    "caucionar": "cau-cio-nar",
    "caucionero": "cau-cio-ne-ro",
    "caucos": "cau-cos",
    "cauda": "cau-da",
    "caudada": "cau-da-da",
    "caudado": "cau-da-do",
    "caudal": "cau-dal",
    "caudalosa": "cau-da-lo-sa",
    "caudalosamente": "cau-da-lo-sa-men-te",
    "caudaloso": "cau-da-lo-so",
    "caudata": "cau-da-ta",
    "caudatario": "cau-da-ta-rio",
    "caudato": "cau-da-to",
    "caudatrémula": "cau-da-tré-mu-la",
    "caudillaje": "cau-di-lla-je",
    "caudillismo": "cau-di-llis-mo",
    "caudillista": "cau-di-llis-ta",
    "caudillo": "cau-di-llo",
    "caudimano": "cau-di-ma-no",
    "caudímano": "cau-dí-ma-no",
    "caudina": "cau-di-na",
    "caudino": "cau-di-no",
    "caudón": "cau-dón",
    "caujazo": "cau-ja-zo",
    "cauje": "cau-je",
    "caula": "cau-la",
    "caulescente": "cau-les-cen-te",
    "caulícolo": "cau-lí-co-lo",
    "caulículo": "cau-lí-cu-lo",
    "caulífera": "cau-lí-fe-ra",
    "caulífero": "cau-lí-fe-ro",
    "cauliforme": "cau-li-for-me",
    "caulinar": "cau-li-nar",
    "caulote": "cau-lo-te",
    "cauno": "cau-no",
    "cauque": "cau-que",
    "cauquén": "cau-quén",
    "cauquenina": "cau-que-ni-na",
    "cauquenino": "cau-que-ni-no",
    "cauri": "cau-ri",
    "cauriense": "cau-rien-se",
    "cauro": "cau-ro",
    "causa": "cau-sa",
    "causador": "cau-sa-dor",
    "causadora": "cau-sa-do-ra",
    "causahabiente": "cau-sa-ha-bien-te",
    "causal": "cau-sal",
    "causalidad": "cau-sa-li-dad",
    "causante": "cau-san-te",
    "causar": "cau-sar",
    "causativa": "cau-sa-ti-va",
    "causativo": "cau-sa-ti-vo",
    "causear": "cau-se-ar",
    "causeo": "cau-se-o",
    "causeta": "cau-se-ta",
    "causídica": "cau-sí-di-ca",
    "causídico": "cau-sí-di-co",
    "causón": "cau-són",
    "cáustica": "cáus-ti-ca",
    "cáusticamente": "cáus-ti-ca-men-te",
    "causticar": "caus-ti-car",
    "causticidad": "caus-ti-ci-dad",
    "cáustico": "cáus-ti-co",
    "cauta": "cau-ta",
    "cautamente": "cau-ta-men-te",
    "cautela": "cau-te-la",
    "cautelar": "cau-te-lar",
    "cautelarmente": "cau-te-lar-men-te",
    "cautelosa": "cau-te-lo-sa",
    "cautelosamente": "cau-te-lo-sa-men-te",
    "cauteloso": "cau-te-lo-so",
    "cauterio": "cau-te-rio",
    "cauterización": "cau-te-ri-za-ción",
    "cauterizador": "cau-te-ri-za-dor",
    "cauterizadora": "cau-te-ri-za-do-ra",
    "cauterizar": "cau-te-ri-zar",
    "cautín": "cau-tín",
    "cautiva": "cau-ti-va",
    "cautivador": "cau-ti-va-dor",
    "cautivadora": "cau-ti-va-do-ra",
    "cautivar": "cau-ti-var",
    "cautiverio": "cau-ti-ve-rio",
    "cautividad": "cau-ti-vi-dad",
    "cautivo": "cau-ti-vo",
    "cauto": "cau-to",
    "cauza": "cau-za",
    "cava": "ca-va",
    "cavacote": "ca-va-co-te",
    "cavada": "ca-va-da",
    "cavadiza": "ca-va-di-za",
    "cavadizo": "ca-va-di-zo",
    "cavado": "ca-va-do",
    "cavador": "ca-va-dor",
    "cavadura": "ca-va-du-ra",
    "cavalillo": "ca-va-li-llo",
    "caván": "ca-ván",
    "cavanillera": "ca-va-ni-lle-ra",
    "cavanillero": "ca-va-ni-lle-ro",
    "cavar": "ca-var",
    "cavaria": "ca-va-ria",
    "cavaril": "ca-va-ril",
    "cavaros": "ca-va-ros",
    "cavatina": "ca-va-ti-na",
    "cavazón": "ca-va-zón",
    "cave": "ca-ve",
    "cávea": "cá-ve-a",
    "cavedio": "ca-ve-dio",
    "caverna": "ca-ver-na",
    "cavernaria": "ca-ver-na-ria",
    "cavernario": "ca-ver-na-rio",
    "cavernícola": "ca-ver-ní-co-la",
    "cavernidad": "ca-ver-ni-dad",
    "cavernosa": "ca-ver-no-sa",
    "cavernosidad": "ca-ver-no-si-dad",
    "cavernoso": "ca-ver-no-so",
    "cavero": "ca-ve-ro",
    "caveto": "ca-ve-to",
    "caví": "ca-ví",
    "cavia": "ca-via",
    "cavial": "ca-vial",
    "caviar": "ca-viar",
    "cavicornio": "ca-vi-cor-nio",
    "cavidad": "ca-vi-dad",
    "cavilación": "ca-vi-la-ción",
    "cavilar": "ca-vi-lar",
    "cavilo": "ca-vi-lo",
    "cavilosa": "ca-vi-lo-sa",
    "cavilosamente": "ca-vi-lo-sa-men-te",
    "cavilosidad": "ca-vi-lo-si-dad",
    "caviloso": "ca-vi-lo-so",
    "cavío": "ca-ví-o",
    "cavitación": "ca-vi-ta-ción",
    "cavo": "ca-vo",
    "cavón": "ca-vón",
    "cayá": "ca-yá",
    "cayada": "ca-ya-da",
    "cayadilla": "ca-ya-di-lla",
    "cayado": "ca-ya-do",
    "cayagual": "ca-ya-gual",
    "cayahual": "ca-ya-hual",
    "cayajabo": "ca-ya-ja-bo",
    "cayama": "ca-ya-ma",
    "cayán": "ca-yán",
    "cayana": "ca-ya-na",
    "cayanco": "ca-yan-co",
    "cayapa": "ca-ya-pa",
    "cayapear": "ca-ya-pe-ar",
    "cayapona": "ca-ya-po-na",
    "cayapós": "ca-ya-pós",
    "cayarí": "ca-ya-rí",
    "cayaya": "ca-ya-ya",
    "cayena": "ca-ye-na",
    "cayente": "ca-yen-te",
    "cayeputi": "ca-ye-pu-ti",
    "cayería": "ca-ye-rí-a",
    "cayetés": "ca-ye-tés",
    "cayeyana": "ca-ye-ya-na",
    "cayeyano": "ca-ye-ya-no",
    "cayo": "ca-yo",
    "cayota": "ca-yo-ta",
    "cayote": "ca-yo-te",
    "cayto": "cay-to",
    "cayuca": "ca-yu-ca",
    "cayuco": "ca-yu-co",
    "cayuela": "ca-yue-la",
    "caza": "ca-za",
    "cazabe": "ca-za-be",
    "cazabombardero": "ca-za-bom-bar-de-ro",
    "cazaclavos": "ca-za-cla-vos",
    "cazadero": "ca-za-de-ro",
    "cazado": "ca-za-do",
    "cazador": "ca-za-dor",
    "cazadora": "ca-za-do-ra",
    "cazadotes": "ca-za-do-tes",
    "cazafortunas": "ca-za-for-tu-nas",
    "cazalla": "ca-za-lla",
    "cazallera": "ca-za-lle-ra",
    "cazallero": "ca-za-lle-ro",
    "cazaminas": "ca-za-mi-nas",
    "cazar": "ca-zar",
    "cazarete": "ca-za-re-te",
    "cazarra": "ca-za-rra",
    "cazarrecompensas": "ca-za-rre-com-pen-sas",
    "cazarrica": "ca-za-rri-ca",
    "cazarro": "ca-za-rro",
    "cazata": "ca-za-ta",
    "cazatalentos": "ca-za-ta-len-tos",
    "cazatorpedero": "ca-za-tor-pe-de-ro",
    "cazavirus": "ca-za-vi-rus",
    "cazcalear": "caz-ca-le-ar",
    "cazcarria": "caz-ca-rria",
    "cazcarrienta": "caz-ca-rrien-ta",
    "cazcarriento": "caz-ca-rrien-to",
    "cazcarrioso": "caz-ca-rrio-so",
    "cazcorva": "caz-cor-va",
    "cazcorvo": "caz-cor-vo",
    "cazo": "ca-zo",
    "cazolada": "ca-zo-la-da",
    "cazoleja": "ca-zo-le-ja",
    "cazolero": "ca-zo-le-ro",
    "cazoleta": "ca-zo-le-ta",
    "cazoletear": "ca-zo-le-te-ar",
    "cazoletero": "ca-zo-le-te-ro",
    "cazón": "ca-zón",
    "cazonal": "ca-zo-nal",
    "cazonete": "ca-zo-ne-te",
    "cazorría": "ca-zo-rrí-a",
    "cazuda": "ca-zu-da",
    "cazudo": "ca-zu-do",
    "cazuela": "ca-zue-la",
    "cazumbrar": "ca-zum-brar",
    "cazumbre": "ca-zum-bre",
    "cazumbrón": "ca-zum-brón",
    "cazurra": "ca-zu-rra",
    "cazurramente": "ca-zu-rra-men-te",
    "cazurrear": "ca-zu-rre-ar",
    "cazurrería": "ca-zu-rre-rí-a",
    "cazurría": "ca-zu-rrí-a",
    "cazurro": "ca-zu-rro",
    "cazuz": "ca-zuz",
    "cazuzo": "ca-zu-zo",
    "cea": "ce-a",
    "ceaja": "ce-a-ja",
    "ceajo": "ce-a-jo",
    "ceanoto": "ce-a-no-to",
    "cearina": "ce-a-ri-na",
    "ceática": "ce-á-ti-ca",
    "ceba": "ce-ba",
    "cebada": "ce-ba-da",
    "cebadal": "ce-ba-dal",
    "cebadar": "ce-ba-dar",
    "cebadaza": "ce-ba-da-za",
    "cebadazo": "ce-ba-da-zo",
    "cebadera": "ce-ba-de-ra",
    "cebadería": "ce-ba-de-rí-a",
    "cebadero": "ce-ba-de-ro",
    "cebadilla": "ce-ba-di-lla",
    "cebado": "ce-ba-do",
    "cebador": "ce-ba-dor",
    "cebadora": "ce-ba-do-ra",
    "cebadura": "ce-ba-du-ra",
    "cebar": "ce-bar",
    "cebellina": "ce-be-lli-na",
    "cebera": "ce-be-ra",
    "cebero": "ce-be-ro",
    "cebiche": "ce-bi-che",
    "cebil": "ce-bil",
    "cebipero": "ce-bi-pe-ro",
    "cebique": "ce-bi-que",
    "cebo": "ce-bo",
    "cebolla": "ce-bo-lla",
    "cebollada": "ce-bo-lla-da",
    "cebollana": "ce-bo-lla-na",
    "cebollar": "ce-bo-llar",
    "cebollento": "ce-bo-llen-to",
    "cebollera": "ce-bo-lle-ra",
    "cebollero": "ce-bo-lle-ro",
    "cebolleta": "ce-bo-lle-ta",
    "cebollín": "ce-bo-llín",
    "cebollino": "ce-bo-lli-no",
    "cebollón": "ce-bo-llón",
    "cebolluda": "ce-bo-llu-da",
    "cebolludo": "ce-bo-llu-do",
    "cebón": "ce-bón",
    "cebona": "ce-bo-na",
    "ceborrincha": "ce-bo-rrin-cha",
    "cebra": "ce-bra",
    "cebrada": "ce-bra-da",
    "cebrado": "ce-bra-do",
    "cebratana": "ce-bra-ta-na",
    "cebrión": "ce-brión",
    "cebro": "ce-bro",
    "cebruna": "ce-bru-na",
    "cebruno": "ce-bru-no",
    "cebtí": "ceb-tí",
    "cebú": "ce-bú",
    "cebuana": "ce-bua-na",
    "cebuano": "ce-bua-no",
    "cebucán": "ce-bu-cán",
    "ceburro": "ce-bu-rro",
    "ceca": "ce-ca",
    "cecal": "ce-cal",
    "ceceante": "ce-ce-an-te",
    "cecear": "ce-ce-ar",
    "ceceo": "ce-ce-o",
    "ceceosa": "ce-ce-o-sa",
    "ceceoso": "ce-ce-o-so",
    "cechero": "ce-che-ro",
    "cecial": "ce-cial",
    "cecias": "ce-cias",
    "cecidia": "ce-ci-dia",
    "cecilia": "ce-ci-lia",
    "cecina": "ce-ci-na",
    "cecinar": "ce-ci-nar",
    "ceción": "ce-ción",
    "cecografía": "ce-co-gra-fí-a",
    "cecógrafo": "ce-có-gra-fo",
    "cécubo": "cé-cu-bo",
    "cecuciente": "ce-cu-cien-te",
    "ceda": "ce-da",
    "cedacear": "ce-da-ce-ar",
    "cedacera": "ce-da-ce-ra",
    "cedacería": "ce-da-ce-rí-a",
    "cedacero": "ce-da-ce-ro",
    "cedacillo": "ce-da-ci-llo",
    "cedazo": "ce-da-zo",
    "cedé": "ce-dé",
    "cedente": "ce-den-te",
    "ceder": "ce-der",
    "cederrón": "ce-de-rrón",
    "cedible": "ce-di-ble",
    "cedicia": "ce-di-cia",
    "cedicio": "ce-di-cio",
    "cedilla": "ce-di-lla",
    "cediza": "ce-di-za",
    "cedizo": "ce-di-zo",
    "cedo": "ce-do",
    "cedoaria": "ce-do-a-ria",
    "cedras": "ce-dras",
    "cedreleón": "ce-dre-le-ón",
    "cedreno": "ce-dre-no",
    "cedria": "ce-dria",
    "cédride": "cé-dri-de",
    "cedrina": "ce-dri-na",
    "cedrino": "ce-dri-no",
    "cedrito": "ce-dri-to",
    "cedro": "ce-dro",
    "cedróleo": "ce-dró-le-o",
    "cedrón": "ce-drón",
    "cédula": "cé-du-la",
    "cedulaje": "ce-du-la-je",
    "cedular": "ce-du-lar",
    "cedulario": "ce-du-la-rio",
    "cedulón": "ce-du-lón",
    "cefalalgia": "ce-fa-lal-gia",
    "cefalálgica": "ce-fa-lál-gi-ca",
    "cefalálgico": "ce-fa-lál-gi-co",
    "cefalea": "ce-fa-le-a",
    "cefálica": "ce-fá-li-ca",
    "cefálico": "ce-fá-li-co",
    "cefalitis": "ce-fa-li-tis",
    "céfalo": "cé-fa-lo",
    "cefalocordado": "ce-fa-lo-cor-da-do",
    "cefalópodo": "ce-fa-ló-po-do",
    "cefalorraquídeo": "ce-fa-lo-rra-quí-de-o",
    "cefalosporina": "ce-fa-los-po-ri-na",
    "cefalotórax": "ce-fa-lo-tó-rax",
    "cefea": "ce-fe-a",
    "cefear": "ce-fe-ar",
    "céfiro": "cé-fi-ro",
    "cefo": "ce-fo",
    "cefrada": "ce-fra-da",
    "cefrado": "ce-fra-do",
    "cegado": "ce-ga-do",
    "cegador": "ce-ga-dor",
    "cegadora": "ce-ga-do-ra",
    "cegaja": "ce-ga-ja",
    "cegajear": "ce-ga-je-ar",
    "cegajez": "ce-ga-jez",
    "cegajo": "ce-ga-jo",
    "cegajosa": "ce-ga-jo-sa",
    "cegajoso": "ce-ga-jo-so",
    "cegama": "ce-ga-ma",
    "cegamiento": "ce-ga-mien-to",
    "cegar": "ce-gar",
    "cegarra": "ce-ga-rra",
    "cegarrita": "ce-ga-rri-ta",
    "cegata": "ce-ga-ta",
    "cegatera": "ce-ga-te-ra",
    "cegatero": "ce-ga-te-ro",
    "cegato": "ce-ga-to",
    "cegatón": "ce-ga-tón",
    "cegatosa": "ce-ga-to-sa",
    "cegatoso": "ce-ga-to-so",
    "cegesimal": "ce-ge-si-mal",
    "cegrí": "ce-grí",
    "cegua": "ce-gua",
    "ceguedad": "ce-gue-dad",
    "ceguera": "ce-gue-ra",
    "ceiba": "cei-ba",
    "ceibal": "cei-bal",
    "ceibeña": "cei-be-ña",
    "ceibeño": "cei-be-ño",
    "ceibo": "cei-bo",
    "ceibón": "cei-bón",
    "ceilán": "cei-lán",
    "ceilandés": "cei-lan-dés",
    "ceilandesa": "cei-lan-de-sa",
    "ceisatita": "cei-sa-ti-ta",
    "ceja": "ce-ja",
    "cejadero": "ce-ja-de-ro",
    "cejador": "ce-ja-dor",
    "cejar": "ce-jar",
    "ceje": "ce-je",
    "cejijunta": "ce-ji-jun-ta",
    "cejijunto": "ce-ji-jun-to",
    "cejilla": "ce-ji-lla",
    "cejo": "ce-jo",
    "cejuda": "ce-ju-da",
    "cejudo": "ce-ju-do",
    "cejuela": "ce-jue-la",
    "cejunta": "ce-jun-ta",
    "cejunto": "ce-jun-to",
    "cela": "ce-la",
    "celacanto": "ce-la-can-to",
    "celada": "ce-la-da",
    "celadamente": "ce-la-da-men-te",
    "celado": "ce-la-do",
    "celadón": "ce-la-dón",
    "celador": "ce-la-dor",
    "celadora": "ce-la-do-ra",
    "celaduría": "ce-la-du-rí-a",
    "celaje": "ce-la-je",
    "celajería": "ce-la-je-rí-a",
    "celambre": "ce-lam-bre",
    "celán": "ce-lán",
    "celante": "ce-lan-te",
    "celar": "ce-lar",
    "celastrácea": "ce-las-trá-ce-a",
    "celastráceo": "ce-las-trá-ce-o",
    "celastrínea": "ce-las-trí-ne-a",
    "celastríneo": "ce-las-trí-ne-o",
    "celastro": "ce-las-tro",
    "celda": "cel-da",
    "celdilla": "cel-di-lla",
    "celdrana": "cel-dra-na",
    "cele": "ce-le",
    "celebérrima": "ce-le-bé-rri-ma",
    "celebérrimo": "ce-le-bé-rri-mo",
    "celebración": "ce-le-bra-ción",
    "celebrado": "ce-le-bra-do",
    "celebrador": "ce-le-bra-dor",
    "celebradora": "ce-le-bra-do-ra",
    "celebrante": "ce-le-bran-te",
    "celebrar": "ce-le-brar",
    "célebre": "cé-le-bre",
    "celebrero": "ce-le-bre-ro",
    "celebridad": "ce-le-bri-dad",
    "celebro": "ce-le-bro",
    "celedón": "ce-le-dón",
    "celemín": "ce-le-mín",
    "celeminada": "ce-le-mi-na-da",
    "celeminear": "ce-le-mi-ne-ar",
    "celeminero": "ce-le-mi-ne-ro",
    "celendina": "ce-len-di-na",
    "celendino": "ce-len-di-no",
    "celentéreo": "ce-len-té-re-o",
    "celeque": "ce-le-que",
    "celera": "ce-le-ra",
    "celerada": "ce-le-ra-da",
    "celerado": "ce-le-ra-do",
    "célere": "cé-le-re",
    "celeridad": "ce-le-ri-dad",
    "celescopio": "ce-les-co-pio",
    "celesta": "ce-les-ta",
    "celeste": "ce-les-te",
    "celestial": "ce-les-tial",
    "celestialmente": "ce-les-tial-men-te",
    "celestina": "ce-les-ti-na",
    "celestinaje": "ce-les-ti-na-je",
    "celestinazgo": "ce-les-ti-naz-go",
    "celestinear": "ce-les-ti-ne-ar",
    "celestineo": "ce-les-ti-ne-o",
    "celestinesca": "ce-les-ti-nes-ca",
    "celestinesco": "ce-les-ti-nes-co",
    "celestino": "ce-les-ti-no",
    "celestre": "ce-les-tre",
    "celfo": "cel-fo",
    "celia": "ce-lia",
    "celíaca": "ce-lí-a-ca",
    "celiaca": "ce-lia-ca",
    "celíaco": "ce-lí-a-co",
    "celiaco": "ce-lia-co",
    "celibato": "ce-li-ba-to",
    "célibe": "cé-li-be",
    "célica": "cé-li-ca",
    "célico": "cé-li-co",
    "celícola": "ce-lí-co-la",
    "celidonia": "ce-li-do-nia",
    "celidueña": "ce-li-due-ña",
    "celinda": "ce-lin-da",
    "celindrate": "ce-lin-dra-te",
    "celista": "ce-lis-ta",
    "cella": "ce-lla",
    "cellar": "ce-llar",
    "cellenca": "ce-llen-ca",
    "cellenco": "ce-llen-co",
    "cellerizo": "ce-lle-ri-zo",
    "cellisca": "ce-llis-ca",
    "cellisquear": "ce-llis-que-ar",
    "cello": "ce-llo",
    "celo": "ce-lo",
    "celofán": "ce-lo-fán",
    "celoidina": "ce-loi-di-na",
    "celoma": "ce-lo-ma",
    "celomado": "ce-lo-ma-do",
    "celomático": "ce-lo-má-ti-co",
    "celosa": "ce-lo-sa",
    "celosamente": "ce-lo-sa-men-te",
    "celosía": "ce-lo-sí-a",
    "celoso": "ce-lo-so",
    "celota": "ce-lo-ta",
    "celotipia": "ce-lo-ti-pia",
    "celsitud": "cel-si-tud",
    "celta": "cel-ta",
    "celtíbera": "cel-tí-be-ra",
    "celtiberia": "cel-ti-be-ria",
    "celtibérica": "cel-ti-bé-ri-ca",
    "celtibérico": "cel-ti-bé-ri-co",
    "celtiberio": "cel-ti-be-rio",
    "celtíbero": "cel-tí-be-ro",
    "céltica": "cél-ti-ca",
    "céltico": "cél-ti-co",
    "celtídea": "cel-tí-de-a",
    "celtídeo": "cel-tí-de-o",
    "celtismo": "cel-tis-mo",
    "celtista": "cel-tis-ta",
    "celtohispana": "cel-tohis-pa-na",
    "celtohispánica": "cel-tohis-pá-ni-ca",
    "celtohispánico": "cel-tohis-pá-ni-co",
    "celtohispano": "cel-tohis-pa-no",
    "celtolatina": "cel-to-la-ti-na",
    "celtolatino": "cel-to-la-ti-no",
    "célula": "cé-lu-la",
    "celulada": "ce-lu-la-da",
    "celulado": "ce-lu-la-do",
    "celular": "ce-lu-lar",
    "celularia": "ce-lu-la-ria",
    "celulario": "ce-lu-la-rio",
    "celulasa": "ce-lu-la-sa",
    "celulita": "ce-lu-li-ta",
    "celulítico": "ce-lu-lí-ti-co",
    "celulitis": "ce-lu-li-tis",
    "celuloide": "ce-lu-loi-de",
    "celulosa": "ce-lu-lo-sa",
    "celulósico": "ce-lu-ló-si-co",
    "cema": "ce-ma",
    "cémbalo": "cém-ba-lo",
    "cembo": "cem-bo",
    "cembrio": "cem-brio",
    "cementación": "ce-men-ta-ción",
    "cementante": "ce-men-tan-te",
    "cementar": "ce-men-tar",
    "cementera": "ce-men-te-ra",
    "cementerial": "ce-men-te-rial",
    "cementerio": "ce-men-te-rio",
    "cementero": "ce-men-te-ro",
    "cemento": "ce-men-to",
    "cementosa": "ce-men-to-sa",
    "cementoso": "ce-men-to-so",
    "cemita": "ce-mi-ta",
    "cempasúchil": "cem-pa-sú-chil",
    "cena": "ce-na",
    "ceña": "ce-ña",
    "cenacho": "ce-na-cho",
    "cenáculo": "ce-ná-cu-lo",
    "cenada": "ce-na-da",
    "cenadero": "ce-na-de-ro",
    "cenado": "ce-na-do",
    "cenador": "ce-na-dor",
    "cenadora": "ce-na-do-ra",
    "cenaduría": "ce-na-du-rí-a",
    "cenaga": "ce-na-ga",
    "cenagal": "ce-na-gal",
    "cenagar": "ce-na-gar",
    "cenagosa": "ce-na-go-sa",
    "cenagoso": "ce-na-go-so",
    "cenal": "ce-nal",
    "cenaoscuras": "ce-na-os-cu-ras",
    "cenar": "ce-nar",
    "ceñar": "ce-ñar",
    "cenata": "ce-na-ta",
    "cenca": "cen-ca",
    "cencapa": "cen-ca-pa",
    "cencellada": "cen-ce-lla-da",
    "cenceña": "cen-ce-ña",
    "cenceñada": "cen-ce-ña-da",
    "cenceño": "cen-ce-ño",
    "cencero": "cen-ce-ro",
    "cencerra": "cen-ce-rra",
    "cencerrada": "cen-ce-rra-da",
    "cencerrado": "cen-ce-rra-do",
    "cencerrear": "cen-ce-rre-ar",
    "cencerreo": "cen-ce-rre-o",
    "cencerril": "cen-ce-rril",
    "cencerrillas": "cen-ce-rri-llas",
    "cencerro": "cen-ce-rro",
    "cencerrón": "cen-ce-rrón",
    "cencha": "cen-cha",
    "cencida": "cen-ci-da",
    "cencido": "cen-ci-do",
    "cencío": "cen-cí-o",
    "cencio": "cen-cio",
    "cencivera": "cen-ci-ve-ra",
    "cenco": "cen-co",
    "cencuate": "cen-cua-te",
    "cendal": "cen-dal",
    "cendalí": "cen-da-lí",
    "céndea": "cén-de-a",
    "cendolilla": "cen-do-li-lla",
    "cendra": "cen-dra",
    "cendrada": "cen-dra-da",
    "cendradilla": "cen-dra-di-lla",
    "cendrado": "cen-dra-do",
    "cendrar": "cen-drar",
    "cendrazo": "cen-dra-zo",
    "cenefa": "ce-ne-fa",
    "cenegar": "ce-ne-gar",
    "ceneque": "ce-ne-que",
    "cenero": "ce-ne-ro",
    "cenestesia": "ce-nes-te-sia",
    "cenestésica": "ce-nes-té-si-ca",
    "cenestésico": "ce-nes-té-si-co",
    "cenete": "ce-ne-te",
    "cenetista": "ce-ne-tis-ta",
    "cenhegí": "cen-he-gí",
    "cení": "ce-ní",
    "cenia": "ce-nia",
    "cenicense": "ce-ni-cen-se",
    "cenicerense": "ce-ni-ce-ren-se",
    "cenicero": "ce-ni-ce-ro",
    "cenícero": "ce-ní-ce-ro",
    "cenicienta": "ce-ni-cien-ta",
    "ceniciento": "ce-ni-cien-to",
    "cenicilla": "ce-ni-ci-lla",
    "ceñida": "ce-ñi-da",
    "ceñidamente": "ce-ñi-da-men-te",
    "ceñideras": "ce-ñi-de-ras",
    "ceñidero": "ce-ñi-de-ro",
    "ceñido": "ce-ñi-do",
    "ceñidor": "ce-ñi-dor",
    "ceñidura": "ce-ñi-du-ra",
    "ceñiglo": "ce-ñi-glo",
    "ceñimiento": "ce-ñi-mien-to",
    "ceñir": "ce-ñir",
    "cenit": "ce-nit",
    "cénit": "cé-nit",
    "cenital": "ce-ni-tal",
    "ceniza": "ce-ni-za",
    "cenizal": "ce-ni-zal",
    "cenízaro": "ce-ní-za-ro",
    "cenizo": "ce-ni-zo",
    "cenizosa": "ce-ni-zo-sa",
    "cenizoso": "ce-ni-zo-so",
    "ceño": "ce-ño",
    "cenobial": "ce-no-bial",
    "cenobio": "ce-no-bio",
    "cenobita": "ce-no-bi-ta",
    "cenobítica": "ce-no-bí-ti-ca",
    "cenobítico": "ce-no-bí-ti-co",
    "cenobitismo": "ce-no-bi-tis-mo",
    "cenojil": "ce-no-jil",
    "cenopegias": "ce-no-pe-gias",
    "ceñosa": "ce-ño-sa",
    "cenoso": "ce-no-so",
    "ceñoso": "ce-ño-so",
    "cenotafio": "ce-no-ta-fio",
    "cenote": "ce-no-te",
    "cenozoico": "ce-no-zoi-co",
    "censador": "cen-sa-dor",
    "censadora": "cen-sa-do-ra",
    "censal": "cen-sal",
    "censalista": "cen-sa-lis-ta",
    "censar": "cen-sar",
    "censataria": "cen-sa-ta-ria",
    "censatario": "cen-sa-ta-rio",
    "censista": "cen-sis-ta",
    "censitario": "cen-si-ta-rio",
    "censo": "cen-so",
    "censor": "cen-sor",
    "censora": "cen-so-ra",
    "censoria": "cen-so-ria",
    "censorina": "cen-so-ri-na",
    "censorino": "cen-so-ri-no",
    "censorio": "cen-so-rio",
    "censual": "cen-sual",
    "censualista": "cen-sua-lis-ta",
    "censuario": "cen-sua-rio",
    "censura": "cen-su-ra",
    "censurable": "cen-su-ra-ble",
    "censurador": "cen-su-ra-dor",
    "censuradora": "cen-su-ra-do-ra",
    "censurar": "cen-su-rar",
    "censurista": "cen-su-ris-ta",
    "centalla": "cen-ta-lla",
    "centaura": "cen-tau-ra",
    "centaurea": "cen-tau-re-a",
    "centauro": "cen-tau-ro",
    "centava": "cen-ta-va",
    "centavo": "cen-ta-vo",
    "centella": "cen-te-lla",
    "centellador": "cen-te-lla-dor",
    "centelladora": "cen-te-lla-do-ra",
    "centellar": "cen-te-llar",
    "centelleante": "cen-te-lle-an-te",
    "centellear": "cen-te-lle-ar",
    "centelleo": "cen-te-lle-o",
    "centellón": "cen-te-llón",
    "centén": "cen-tén",
    "centena": "cen-te-na",
    "centenada": "cen-te-na-da",
    "centenal": "cen-te-nal",
    "centenar": "cen-te-nar",
    "centenaria": "cen-te-na-ria",
    "centenario": "cen-te-na-rio",
    "centenaza": "cen-te-na-za",
    "centenera": "cen-te-ne-ra",
    "centenero": "cen-te-ne-ro",
    "centenilla": "cen-te-ni-lla",
    "centeno": "cen-te-no",
    "centenosa": "cen-te-no-sa",
    "centenoso": "cen-te-no-so",
    "centésima": "cen-té-si-ma",
    "centesimal": "cen-te-si-mal",
    "centésimo": "cen-té-si-mo",
    "centi": "cen-ti",
    "centiárea": "cen-tiá-re-a",
    "centígrada": "cen-tí-gra-da",
    "centígrado": "cen-tí-gra-do",
    "centigramo": "cen-ti-gra-mo",
    "centilitro": "cen-ti-li-tro",
    "centillero": "cen-ti-lle-ro",
    "centiloquio": "cen-ti-lo-quio",
    "céntima": "cén-ti-ma",
    "centimano": "cen-ti-ma-no",
    "centímano": "cen-tí-ma-no",
    "centímetro": "cen-tí-me-tro",
    "céntimo": "cén-ti-mo",
    "centinela": "cen-ti-ne-la",
    "centinodia": "cen-ti-no-dia",
    "centiplicada": "cen-ti-pli-ca-da",
    "centiplicado": "cen-ti-pli-ca-do",
    "centipondio": "cen-ti-pon-dio",
    "centola": "cen-to-la",
    "centolla": "cen-to-lla",
    "centollo": "cen-to-llo",
    "centón": "cen-tón",
    "centonar": "cen-to-nar",
    "centrada": "cen-tra-da",
    "centrado": "cen-tra-do",
    "central": "cen-tral",
    "centralense": "cen-tra-len-se",
    "centralidad": "cen-tra-li-dad",
    "centralilla": "cen-tra-li-lla",
    "centralismo": "cen-tra-lis-mo",
    "centralista": "cen-tra-lis-ta",
    "centralita": "cen-tra-li-ta",
    "centralización": "cen-tra-li-za-ción",
    "centralizado": "cen-tra-li-za-do",
    "centralizador": "cen-tra-li-za-dor",
    "centralizadora": "cen-tra-li-za-do-ra",
    "centralizar": "cen-tra-li-zar",
    "centrar": "cen-trar",
    "centrarco": "cen-trar-co",
    "céntrica": "cén-tri-ca",
    "céntrico": "cén-tri-co",
    "centrífuga": "cen-trí-fu-ga",
    "centrifugación": "cen-tri-fu-ga-ción",
    "centrifugado": "cen-tri-fu-ga-do",
    "centrifugador": "cen-tri-fu-ga-dor",
    "centrifugadora": "cen-tri-fu-ga-do-ra",
    "centrifugar": "cen-tri-fu-gar",
    "centrífugo": "cen-trí-fu-go",
    "centrina": "cen-tri-na",
    "centrípeta": "cen-trí-pe-ta",
    "centrípeto": "cen-trí-pe-to",
    "centris": "cen-tris",
    "centrisco": "cen-tris-co",
    "centrismo": "cen-tris-mo",
    "centrista": "cen-tris-ta",
    "centro": "cen-tro",
    "centroafricana": "cen-tro-a-fri-ca-na",
    "centroafricano": "cen-tro-a-fri-ca-no",
    "centroamericana": "cen-tro-a-me-ri-ca-na",
    "centroamericano": "cen-tro-a-me-ri-ca-no",
    "centrobárica": "cen-tro-bá-ri-ca",
    "centrobárico": "cen-tro-bá-ri-co",
    "centrocampista": "cen-tro-cam-pis-ta",
    "centroeuropea": "cen-tro-eu-ro-pe-a",
    "centroeuropeo": "cen-tro-eu-ro-pe-o",
    "centrosoma": "cen-tro-so-ma",
    "centunviral": "cen-tun-vi-ral",
    "centunvirato": "cen-tun-vi-ra-to",
    "centunviro": "cen-tun-vi-ro",
    "céntupla": "cén-tu-pla",
    "centuplicar": "cen-tu-pli-car",
    "céntuplo": "cén-tu-plo",
    "centuria": "cen-tu-ria",
    "centurión": "cen-tu-rión",
    "centurionazgo": "cen-tu-rio-naz-go",
    "ceñuda": "ce-ñu-da",
    "ceñudo": "ce-ñu-do",
    "cenuro": "ce-nu-ro",
    "cenutria": "ce-nu-tria",
    "cenutrio": "ce-nu-trio",
    "cenzalina": "cen-za-li-na",
    "cenzalino": "cen-za-li-no",
    "cénzalo": "cén-za-lo",
    "cenzaya": "cen-za-ya",
    "cenzayo": "cen-za-yo",
    "cenzonte": "cen-zon-te",
    "cenzontle": "cen-zon-tle",
    "ceo": "ce-o",
    "ceolita": "ce-o-li-ta",
    "cepa": "ce-pa",
    "cepadgo": "ce-pad-go",
    "cepazo": "ce-pa-zo",
    "cepeda": "ce-pe-da",
    "cepejón": "ce-pe-jón",
    "cepellón": "ce-pe-llón",
    "cepera": "ce-pe-ra",
    "cepero": "ce-pe-ro",
    "cepillada": "ce-pi-lla-da",
    "cepillado": "ce-pi-lla-do",
    "cepilladura": "ce-pi-lla-du-ra",
    "cepillar": "ce-pi-llar",
    "cepillo": "ce-pi-llo",
    "cepillón": "ce-pi-llón",
    "cepita": "ce-pi-ta",
    "cepo": "ce-po",
    "cepola": "ce-po-la",
    "ceporrez": "ce-po-rrez",
    "ceporro": "ce-po-rro",
    "cepote": "ce-po-te",
    "ceprén": "ce-prén",
    "ceptí": "cep-tí",
    "cequeta": "ce-que-ta",
    "cequí": "ce-quí",
    "cequia": "ce-quia",
    "cequiaje": "ce-quia-je",
    "cequión": "ce-quión",
    "cera": "ce-ra",
    "ceracate": "ce-ra-ca-te",
    "cerafolio": "ce-ra-fo-lio",
    "ceragallo": "ce-ra-ga-llo",
    "cerámica": "ce-rá-mi-ca",
    "cerámico": "ce-rá-mi-co",
    "ceramida": "ce-ra-mi-da",
    "ceramista": "ce-ra-mis-ta",
    "ceramita": "ce-ra-mi-ta",
    "ceranda": "ce-ran-da",
    "cerapez": "ce-ra-pez",
    "cerasiote": "ce-ra-sio-te",
    "cerasita": "ce-ra-si-ta",
    "cerasta": "ce-ras-ta",
    "cerastas": "ce-ras-tas",
    "ceraste": "ce-ras-te",
    "cerastes": "ce-ras-tes",
    "cerástide": "ce-rás-ti-de",
    "cerate": "ce-ra-te",
    "ceratias": "ce-ra-tias",
    "cerato": "ce-ra-to",
    "ceraunia": "ce-rau-nia",
    "ceraunomancía": "ce-rau-no-man-cí-a",
    "ceraunomancia": "ce-rau-no-man-cia",
    "ceraunómetro": "ce-rau-nó-me-tro",
    "ceraza": "ce-ra-za",
    "cerbas": "cer-bas",
    "cerbatana": "cer-ba-ta-na",
    "cerbelo": "cer-be-lo",
    "cerbero": "cer-be-ro",
    "cerbillera": "cer-bi-lle-ra",
    "cerca": "cer-ca",
    "cercado": "cer-ca-do",
    "cercador": "cer-ca-dor",
    "cercadora": "cer-ca-do-ra",
    "cercadura": "cer-ca-du-ra",
    "cercamiento": "cer-ca-mien-to",
    "cercana": "cer-ca-na",
    "cercanamente": "cer-ca-na-men-te",
    "cercandanza": "cer-can-dan-za",
    "cercanía": "cer-ca-ní-a",
    "cercano": "cer-ca-no",
    "cercar": "cer-car",
    "cercaria": "cer-ca-ria",
    "cercear": "cer-ce-ar",
    "cercen": "cer-cen",
    "cercén": "cer-cén",
    "cércena": "cér-ce-na",
    "cercenadamente": "cer-ce-na-da-men-te",
    "cercenador": "cer-ce-na-dor",
    "cercenadora": "cer-ce-na-do-ra",
    "cercenadura": "cer-ce-na-du-ra",
    "cercenamiento": "cer-ce-na-mien-to",
    "cercenar": "cer-ce-nar",
    "cércene": "cér-ce-ne",
    "cérceno": "cér-ce-no",
    "cercera": "cer-ce-ra",
    "cerceta": "cer-ce-ta",
    "cercha": "cer-cha",
    "cerchar": "cer-char",
    "cerchear": "cer-che-ar",
    "cerchearse": "cer-che-ar-se",
    "cerchón": "cer-chón",
    "cercillo": "cer-ci-llo",
    "cerciorar": "cer-cio-rar",
    "cerco": "cer-co",
    "cercópido": "cer-có-pi-do",
    "cercopiteco": "cer-co-pi-te-co",
    "cércopo": "cér-co-po",
    "cercote": "cer-co-te",
    "cerda": "cer-da",
    "cerdada": "cer-da-da",
    "cerdamen": "cer-da-men",
    "cerdear": "cer-de-ar",
    "cerdo": "cer-do",
    "cerdón": "cer-dón",
    "cerdosa": "cer-do-sa",
    "cerdoso": "cer-do-so",
    "cerduda": "cer-du-da",
    "cerdudo": "cer-du-do",
    "cérea": "cé-re-a",
    "cereal": "ce-re-al",
    "cerealera": "ce-re-a-le-ra",
    "cerealero": "ce-re-a-le-ro",
    "cerealista": "ce-re-a-lis-ta",
    "cerebelo": "ce-re-be-lo",
    "cerebeloso": "ce-re-be-lo-so",
    "cerebración": "ce-re-bra-ción",
    "cerebral": "ce-re-bral",
    "cerebralismo": "ce-re-bra-lis-mo",
    "cerebrina": "ce-re-bri-na",
    "cerebro": "ce-re-bro",
    "cerebroespinal": "ce-re-bro-es-pi-nal",
    "cereceda": "ce-re-ce-da",
    "cerecere": "ce-re-ce-re",
    "cerecilla": "ce-re-ci-lla",
    "cereguete": "ce-re-gue-te",
    "ceremonia": "ce-re-mo-nia",
    "ceremonial": "ce-re-mo-nial",
    "ceremonialmente": "ce-re-mo-nial-men-te",
    "ceremoniática": "ce-re-mo-niá-ti-ca",
    "ceremoniático": "ce-re-mo-niá-ti-co",
    "ceremoniero": "ce-re-mo-nie-ro",
    "ceremoniosa": "ce-re-mo-nio-sa",
    "ceremoniosamente": "ce-re-mo-nio-sa-men-te",
    "ceremonioso": "ce-re-mo-nio-so",
    "cereña": "ce-re-ña",
    "cereño": "ce-re-ño",
    "céreo": "cé-re-o",
    "cerequeque": "ce-re-que-que",
    "cerera": "ce-re-ra",
    "cerería": "ce-re-rí-a",
    "cerero": "ce-re-ro",
    "ceresina": "ce-re-si-na",
    "ceretana": "ce-re-ta-na",
    "ceretano": "ce-re-ta-no",
    "cerete": "ce-re-te",
    "cerevisina": "ce-re-vi-si-na",
    "cereza": "ce-re-za",
    "cerezal": "ce-re-zal",
    "cerezo": "ce-re-zo",
    "ceriballo": "ce-ri-ba-llo",
    "ceribón": "ce-ri-bón",
    "cerífera": "ce-rí-fe-ra",
    "cerífero": "ce-rí-fe-ro",
    "cerífica": "ce-rí-fi-ca",
    "ceriflor": "ce-ri-flor",
    "cerilla": "ce-ri-lla",
    "cerillera": "ce-ri-lle-ra",
    "cerillero": "ce-ri-lle-ro",
    "cerillo": "ce-ri-llo",
    "cerina": "ce-ri-na",
    "cerio": "ce-rio",
    "ceriolario": "ce-rio-la-rio",
    "cerionda": "ce-rion-da",
    "ceriondo": "ce-rion-do",
    "cerita": "ce-ri-ta",
    "cerito": "ce-ri-to",
    "cermeña": "cer-me-ña",
    "cermeño": "cer-me-ño",
    "cerna": "cer-na",
    "cernada": "cer-na-da",
    "cernadero": "cer-na-de-ro",
    "cernaja": "cer-na-ja",
    "cerne": "cer-ne",
    "cernear": "cer-ne-ar",
    "cernedera": "cer-ne-de-ra",
    "cernedero": "cer-ne-de-ro",
    "cernedor": "cer-ne-dor",
    "cernedora": "cer-ne-do-ra",
    "cerneja": "cer-ne-ja",
    "cernejuda": "cer-ne-ju-da",
    "cernejudo": "cer-ne-ju-do",
    "cerner": "cer-ner",
    "cernera": "cer-ne-ra",
    "cernícalo": "cer-ní-ca-lo",
    "cernidera": "cer-ni-de-ra",
    "cernidero": "cer-ni-de-ro",
    "cernidillo": "cer-ni-di-llo",
    "cernido": "cer-ni-do",
    "cernidora": "cer-ni-do-ra",
    "cernidura": "cer-ni-du-ra",
    "cernir": "cer-nir",
    "cerno": "cer-no",
    "cero": "ce-ro",
    "ceroferario": "ce-ro-fe-ra-rio",
    "cerógrafo": "ce-ró-gra-fo",
    "ceroleína": "ce-ro-le-í-na",
    "cerolla": "ce-ro-lla",
    "cerollo": "ce-ro-llo",
    "ceroma": "ce-ro-ma",
    "ceromancía": "ce-ro-man-cí-a",
    "ceromancia": "ce-ro-man-cia",
    "ceromática": "ce-ro-má-ti-ca",
    "ceromático": "ce-ro-má-ti-co",
    "ceromiel": "ce-ro-miel",
    "cerón": "ce-rón",
    "ceronera": "ce-ro-ne-ra",
    "ceronero": "ce-ro-ne-ro",
    "ceroplástica": "ce-ro-plás-ti-ca",
    "cerorrinco": "ce-ro-rrin-co",
    "cerosa": "ce-ro-sa",
    "ceroso": "ce-ro-so",
    "cerote": "ce-ro-te",
    "cerotear": "ce-ro-te-ar",
    "cerotero": "ce-ro-te-ro",
    "ceroto": "ce-ro-to",
    "cerpa": "cer-pa",
    "cerquillo": "cer-qui-llo",
    "cerquita": "cer-qui-ta",
    "cerra": "ce-rra",
    "cerracatín": "ce-rra-ca-tín",
    "cerracatina": "ce-rra-ca-ti-na",
    "cerrada": "ce-rra-da",
    "cerradamente": "ce-rra-da-men-te",
    "cerradera": "ce-rra-de-ra",
    "cerradero": "ce-rra-de-ro",
    "cerradiza": "ce-rra-di-za",
    "cerradizo": "ce-rra-di-zo",
    "cerrado": "ce-rra-do",
    "cerrador": "ce-rra-dor",
    "cerradora": "ce-rra-do-ra",
    "cerradura": "ce-rra-du-ra",
    "cerraja": "ce-rra-ja",
    "cerrajear": "ce-rra-je-ar",
    "cerrajera": "ce-rra-je-ra",
    "cerrajería": "ce-rra-je-rí-a",
    "cerrajerillo": "ce-rra-je-ri-llo",
    "cerrajero": "ce-rra-je-ro",
    "cerrajón": "ce-rra-jón",
    "cerralle": "ce-rra-lle",
    "cerramiento": "ce-rra-mien-to",
    "cerrar": "ce-rrar",
    "cerras": "ce-rras",
    "cerrateña": "ce-rra-te-ña",
    "cerrateño": "ce-rra-te-ño",
    "cerrazón": "ce-rra-zón",
    "cerrebojar": "ce-rre-bo-jar",
    "cerrejón": "ce-rre-jón",
    "cerreña": "ce-rre-ña",
    "cerreño": "ce-rre-ño",
    "cerrera": "ce-rre-ra",
    "cerrería": "ce-rre-rí-a",
    "cerrero": "ce-rre-ro",
    "cerreta": "ce-rre-ta",
    "cerretana": "ce-rre-ta-na",
    "cerretano": "ce-rre-ta-no",
    "cerrevedijón": "ce-rre-ve-di-jón",
    "cerrica": "ce-rri-ca",
    "cerril": "ce-rril",
    "cerrilidad": "ce-rri-li-dad",
    "cerrilismo": "ce-rri-lis-mo",
    "cerrilla": "ce-rri-lla",
    "cerrillada": "ce-rri-lla-da",
    "cerrillar": "ce-rri-llar",
    "cerrillo": "ce-rri-llo",
    "cerrilmente": "ce-rril-men-te",
    "cerrión": "ce-rrión",
    "cerristopa": "ce-rris-to-pa",
    "cerro": "ce-rro",
    "cerrojazo": "ce-rro-ja-zo",
    "cerrojillo": "ce-rro-ji-llo",
    "cerrojito": "ce-rro-ji-to",
    "cerrojo": "ce-rro-jo",
    "cerrón": "ce-rrón",
    "cerrotino": "ce-rro-ti-no",
    "cerruma": "ce-rru-ma",
    "certamen": "cer-ta-men",
    "certeneja": "cer-te-ne-ja",
    "certera": "cer-te-ra",
    "certeramente": "cer-te-ra-men-te",
    "certería": "cer-te-rí-a",
    "certero": "cer-te-ro",
    "certeza": "cer-te-za",
    "certidumbre": "cer-ti-dum-bre",
    "certificable": "cer-ti-fi-ca-ble",
    "certificación": "cer-ti-fi-ca-ción",
    "certificada": "cer-ti-fi-ca-da",
    "certificadamente": "cer-ti-fi-ca-da-men-te",
    "certificado": "cer-ti-fi-ca-do",
    "certificador": "cer-ti-fi-ca-dor",
    "certificadora": "cer-ti-fi-ca-do-ra",
    "certificar": "cer-ti-fi-car",
    "certificatoria": "cer-ti-fi-ca-to-ria",
    "certificatorio": "cer-ti-fi-ca-to-rio",
    "certinidad": "cer-ti-ni-dad",
    "certísima": "cer-tí-si-ma",
    "certísimo": "cer-tí-si-mo",
    "certitud": "cer-ti-tud",
    "ceruca": "ce-ru-ca",
    "cerúlea": "ce-rú-le-a",
    "cerúleo": "ce-rú-le-o",
    "cerulina": "ce-ru-li-na",
    "ceruma": "ce-ru-ma",
    "cerumen": "ce-ru-men",
    "ceruminoso": "ce-ru-mi-no-so",
    "cerusa": "ce-ru-sa",
    "cerusita": "ce-ru-si-ta",
    "cerval": "cer-val",
    "cervantesca": "cer-van-tes-ca",
    "cervantesco": "cer-van-tes-co",
    "cervántica": "cer-ván-ti-ca",
    "cervántico": "cer-ván-ti-co",
    "cervantina": "cer-van-ti-na",
    "cervantino": "cer-van-ti-no",
    "cervantismo": "cer-van-tis-mo",
    "cervantista": "cer-van-tis-ta",
    "cervantófila": "cer-van-tó-fi-la",
    "cervantófilo": "cer-van-tó-fi-lo",
    "cervaria": "cer-va-ria",
    "cervariense": "cer-va-rien-se",
    "cervario": "cer-va-rio",
    "cervatica": "cer-va-ti-ca",
    "cervatillo": "cer-va-ti-llo",
    "cervato": "cer-va-to",
    "cerveceada": "cer-ve-ce-a-da",
    "cervecear": "cer-ve-ce-ar",
    "cerveceo": "cer-ve-ce-o",
    "cervecera": "cer-ve-ce-ra",
    "cervecería": "cer-ve-ce-rí-a",
    "cervecero": "cer-ve-ce-ro",
    "cerverana": "cer-ve-ra-na",
    "cerverano": "cer-ve-ra-no",
    "cerveza": "cer-ve-za",
    "cervicabra": "cer-vi-ca-bra",
    "cervical": "cer-vi-cal",
    "cervicular": "cer-vi-cu-lar",
    "cérvido": "cér-vi-do",
    "cervigón": "cer-vi-gón",
    "cerviguda": "cer-vi-gu-da",
    "cervigudo": "cer-vi-gu-do",
    "cerviguillo": "cer-vi-gui-llo",
    "cervina": "cer-vi-na",
    "cervino": "cer-vi-no",
    "cerviz": "cer-viz",
    "cervuna": "cer-vu-na",
    "cervuno": "cer-vu-no",
    "cesación": "ce-sa-ción",
    "cesamiento": "ce-sa-mien-to",
    "cesante": "ce-san-te",
    "cesanteada": "ce-san-te-a-da",
    "cesanteado": "ce-san-te-a-do",
    "cesantear": "ce-san-te-ar",
    "cesantía": "ce-san-tí-a",
    "cesar": "ce-sar",
    "césar": "cé-sar",
    "cesaraugustana": "ce-sa-rau-gus-ta-na",
    "cesaraugustano": "ce-sa-rau-gus-ta-no",
    "cesárea": "ce-sá-re-a",
    "cesarense": "ce-sa-ren-se",
    "cesáreo": "ce-sá-re-o",
    "cesariana": "ce-sa-ria-na",
    "cesariano": "ce-sa-ria-no",
    "cesariense": "ce-sa-rien-se",
    "cesarina": "ce-sa-ri-na",
    "cesarino": "ce-sa-ri-no",
    "cesarismo": "ce-sa-ris-mo",
    "cesarista": "ce-sa-ris-ta",
    "cese": "ce-se",
    "cesenés": "ce-se-nés",
    "cesenesa": "ce-se-ne-sa",
    "cesible": "ce-si-ble",
    "cesio": "ce-sio",
    "cesión": "ce-sión",
    "cesionaria": "ce-sio-na-ria",
    "cesionario": "ce-sio-na-rio",
    "cesionista": "ce-sio-nis-ta",
    "cesolfaút": "ce-sol-fa-út",
    "cesonaria": "ce-so-na-ria",
    "cesonario": "ce-so-na-rio",
    "césped": "cés-ped",
    "céspede": "cés-pe-de",
    "cespedera": "ces-pe-de-ra",
    "cespitar": "ces-pi-tar",
    "cespitosa": "ces-pi-to-sa",
    "cespitoso": "ces-pi-to-so",
    "cesta": "ces-ta",
    "cestada": "ces-ta-da",
    "cestaño": "ces-ta-ño",
    "cestera": "ces-te-ra",
    "cestería": "ces-te-rí-a",
    "cesteril": "ces-te-ril",
    "cestero": "ces-te-ro",
    "cestiario": "ces-tia-rio",
    "cesto": "ces-to",
    "cestodo": "ces-to-do",
    "cestón": "ces-tón",
    "cestonada": "ces-to-na-da",
    "cesura": "ce-su-ra",
    "ceta": "ce-ta",
    "cetáceo": "ce-tá-ce-o",
    "cetano": "ce-ta-no",
    "cetárea": "ce-tá-re-a",
    "cetaria": "ce-ta-ria",
    "cetario": "ce-ta-rio",
    "cética": "cé-ti-ca",
    "cético": "cé-ti-co",
    "cetil": "ce-til",
    "cetilo": "ce-ti-lo",
    "cetina": "ce-ti-na",
    "cetís": "ce-tís",
    "cetme": "cet-me",
    "cetona": "ce-to-na",
    "cetonemia": "ce-to-ne-mia",
    "cetonia": "ce-to-nia",
    "cetónico": "ce-tó-ni-co",
    "cetonuria": "ce-to-nu-ria",
    "cetosis": "ce-to-sis",
    "cetra": "ce-tra",
    "cetrarina": "ce-tra-ri-na",
    "cetre": "ce-tre",
    "cetrería": "ce-tre-rí-a",
    "cetrero": "ce-tre-ro",
    "cetrina": "ce-tri-na",
    "cetrino": "ce-tri-no",
    "cetro": "ce-tro",
    "ceugma": "ceug-ma",
    "ceutí": "ceu-tí",
    "ceviche": "ce-vi-che",
    "cevichera": "ce-vi-che-ra",
    "cevichería": "ce-vi-che-rí-a",
    "cevichero": "ce-vi-che-ro",
    "chabacana": "cha-ba-ca-na",
    "chabacanada": "cha-ba-ca-na-da",
    "chabacanamente": "cha-ba-ca-na-men-te",
    "chabacanería": "cha-ba-ca-ne-rí-a",
    "chabacano": "cha-ba-ca-no",
    "chabela": "cha-be-la",
    "chabelo": "cha-be-lo",
    "chabelón": "cha-be-lón",
    "chabisque": "cha-bis-que",
    "chabola": "cha-bo-la",
    "chabolismo": "cha-bo-lis-mo",
    "chabolista": "cha-bo-lis-ta",
    "chabón": "cha-bón",
    "chabona": "cha-bo-na",
    "chaca": "cha-ca",
    "chacabucana": "cha-ca-bu-ca-na",
    "chacabucano": "cha-ca-bu-ca-no",
    "chacal": "cha-cal",
    "chacalele": "cha-ca-le-le",
    "chacalín": "cha-ca-lín",
    "chacana": "cha-ca-na",
    "chacanear": "cha-ca-ne-ar",
    "chacaneo": "cha-ca-ne-o",
    "chacar": "cha-car",
    "chácara": "chá-ca-ra",
    "chacarera": "cha-ca-re-ra",
    "chacarería": "cha-ca-re-rí-a",
    "chacarero": "cha-ca-re-ro",
    "chacarona": "cha-ca-ro-na",
    "chacarrachaca": "cha-ca-rra-cha-ca",
    "chácena": "chá-ce-na",
    "chacha": "cha-cha",
    "chachá": "cha-chá",
    "chachachá": "cha-cha-chá",
    "chachacoma": "cha-cha-co-ma",
    "chachafruto": "cha-cha-fru-to",
    "chachaguata": "cha-cha-gua-ta",
    "chachaguato": "cha-cha-gua-to",
    "chachajo": "cha-cha-jo",
    "chachal": "cha-chal",
    "chachalaca": "cha-cha-la-ca",
    "chachalaquear": "cha-cha-la-que-ar",
    "chachapoyana": "cha-cha-po-ya-na",
    "chachapoyano": "cha-cha-po-ya-no",
    "chachar": "cha-char",
    "cháchara": "chá-cha-ra",
    "chacharear": "cha-cha-re-ar",
    "chacharera": "cha-cha-re-ra",
    "chacharero": "cha-cha-re-ro",
    "chacharón": "cha-cha-rón",
    "chacharona": "cha-cha-ro-na",
    "chachas": "cha-chas",
    "chachi": "cha-chi",
    "chacho": "cha-cho",
    "chachón": "cha-chón",
    "chacina": "cha-ci-na",
    "chacinado": "cha-ci-na-do",
    "chacinera": "cha-ci-ne-ra",
    "chacinería": "cha-ci-ne-rí-a",
    "chacinero": "cha-ci-ne-ro",
    "chacla": "cha-cla",
    "chacmol": "chac-mol",
    "chaco": "cha-co",
    "chacó": "cha-có",
    "chacolí": "cha-co-lí",
    "chacolotear": "cha-co-lo-te-ar",
    "chacoloteo": "cha-co-lo-te-o",
    "chacón": "cha-cón",
    "chacona": "cha-co-na",
    "chaconada": "cha-co-na-da",
    "chaconera": "cha-co-ne-ra",
    "chaconero": "cha-co-ne-ro",
    "chacota": "cha-co-ta",
    "chacotear": "cha-co-te-ar",
    "chacoteo": "cha-co-te-o",
    "chacotera": "cha-co-te-ra",
    "chacotero": "cha-co-te-ro",
    "chacra": "cha-cra",
    "chacrear": "cha-cre-ar",
    "chacuaco": "cha-cua-co",
    "chacualear": "cha-cua-le-ar",
    "chacuatol": "cha-cua-tol",
    "chadiana": "cha-dia-na",
    "chadiano": "cha-dia-no",
    "chádico": "chá-di-co",
    "chador": "cha-dor",
    "chafa": "cha-fa",
    "chafaldete": "cha-fal-de-te",
    "chafaldita": "cha-fal-di-ta",
    "chafalditera": "cha-fal-di-te-ra",
    "chafalditero": "cha-fal-di-te-ro",
    "chafallada": "cha-fa-lla-da",
    "chafallar": "cha-fa-llar",
    "chafallo": "cha-fa-llo",
    "chafallón": "cha-fa-llón",
    "chafallona": "cha-fa-llo-na",
    "chafalmejas": "cha-fal-me-jas",
    "chafalonía": "cha-fa-lo-ní-a",
    "chafandín": "cha-fan-dín",
    "chafar": "cha-far",
    "chafardear": "cha-far-de-ar",
    "chafardeo": "cha-far-de-o",
    "chafardera": "cha-far-de-ra",
    "chafardería": "cha-far-de-rí-a",
    "chafardero": "cha-far-de-ro",
    "chafariz": "cha-fa-riz",
    "chafarota": "cha-fa-ro-ta",
    "chafarotada": "cha-fa-ro-ta-da",
    "chafarotazo": "cha-fa-ro-ta-zo",
    "chafarote": "cha-fa-ro-te",
    "chafarraño": "cha-fa-rra-ño",
    "chafarrinada": "cha-fa-rri-na-da",
    "chafarrinar": "cha-fa-rri-nar",
    "chafarrinón": "cha-fa-rri-nón",
    "chafarrocas": "cha-fa-rro-cas",
    "chafirete": "cha-fi-re-te",
    "chaflán": "cha-flán",
    "chaflanar": "cha-fla-nar",
    "chaflar": "cha-flar",
    "chagolla": "cha-go-lla",
    "chagra": "cha-gra",
    "chagrillo": "cha-gri-llo",
    "chagual": "cha-gual",
    "chaguala": "cha-gua-la",
    "chagualo": "cha-gua-lo",
    "chagualón": "cha-gua-lón",
    "cháguar": "chá-guar",
    "chaguaral": "cha-gua-ral",
    "chaguarama": "cha-gua-ra-ma",
    "chaguaramo": "cha-gua-ra-mo",
    "chaguí": "cha-guí",
    "chagüís": "cha-güís",
    "chagüital": "cha-güi-tal",
    "chagüite": "cha-güi-te",
    "chahuador": "cha-hua-dor",
    "chahuadora": "cha-hua-do-ra",
    "chahuar": "cha-huar",
    "chahuiscle": "cha-huis-cle",
    "chahuistle": "cha-huis-tle",
    "chaima": "chai-ma",
    "chaira": "chai-ra",
    "chairo": "chai-ro",
    "chaitenina": "chai-te-ni-na",
    "chaitenino": "chai-te-ni-no",
    "chajá": "cha-já",
    "chajazo": "cha-ja-zo",
    "chajuán": "cha-juán",
    "chajuanado": "cha-jua-na-do",
    "chala": "cha-la",
    "chalaca": "cha-la-ca",
    "chalaco": "cha-la-co",
    "chalada": "cha-la-da",
    "chalado": "cha-la-do",
    "chaladura": "cha-la-du-ra",
    "chalala": "cha-la-la",
    "chalán": "cha-lán",
    "chalana": "cha-la-na",
    "chalanear": "cha-la-ne-ar",
    "chalaneo": "cha-la-ne-o",
    "chalanería": "cha-la-ne-rí-a",
    "chalanesca": "cha-la-nes-ca",
    "chalanesco": "cha-la-nes-co",
    "chalar": "cha-lar",
    "chalate": "cha-la-te",
    "chalateca": "cha-la-te-ca",
    "chalateco": "cha-la-te-co",
    "chalaza": "cha-la-za",
    "chalazión": "cha-la-zión",
    "chalcha": "chal-cha",
    "chalchal": "chal-chal",
    "chalchalero": "chal-cha-le-ro",
    "chalchigua": "chal-chi-gua",
    "chalchihuite": "chal-chi-hui-te",
    "chale": "cha-le",
    "chalé": "cha-lé",
    "chaleco": "cha-le-co",
    "chalequera": "cha-le-que-ra",
    "chalequero": "cha-le-que-ro",
    "chalet": "cha-let",
    "chalina": "cha-li-na",
    "challa": "cha-lla",
    "challapateña": "cha-lla-pa-te-ña",
    "challapateño": "cha-lla-pa-te-ño",
    "challar": "cha-llar",
    "challulla": "cha-llu-lla",
    "chalmate": "chal-ma-te",
    "chalón": "cha-lón",
    "chalona": "cha-lo-na",
    "chalota": "cha-lo-ta",
    "chalote": "cha-lo-te",
    "chalupa": "cha-lu-pa",
    "chama": "cha-ma",
    "chamaca": "cha-ma-ca",
    "chamacazo": "cha-ma-ca-zo",
    "chamaco": "cha-ma-co",
    "chamada": "cha-ma-da",
    "chamagosa": "cha-ma-go-sa",
    "chamagoso": "cha-ma-go-so",
    "chamagua": "cha-ma-gua",
    "chamal": "cha-mal",
    "chamamé": "cha-ma-mé",
    "chamán": "cha-mán",
    "chamánico": "cha-má-ni-co",
    "chamanismo": "cha-ma-nis-mo",
    "chamanístico": "cha-ma-nís-ti-co",
    "chamanto": "cha-man-to",
    "chamar": "cha-mar",
    "chámara": "chá-ma-ra",
    "chamarasca": "cha-ma-ras-ca",
    "chamarilear": "cha-ma-ri-le-ar",
    "chamarileo": "cha-ma-ri-le-o",
    "chamarilera": "cha-ma-ri-le-ra",
    "chamarilería": "cha-ma-ri-le-rí-a",
    "chamarilero": "cha-ma-ri-le-ro",
    "chamarillera": "cha-ma-ri-lle-ra",
    "chamarillero": "cha-ma-ri-lle-ro",
    "chamarillón": "cha-ma-ri-llón",
    "chamarillona": "cha-ma-ri-llo-na",
    "chamariz": "cha-ma-riz",
    "chamarón": "cha-ma-rón",
    "chamarra": "cha-ma-rra",
    "chamarreta": "cha-ma-rre-ta",
    "chamarrita": "cha-ma-rri-ta",
    "chamarro": "cha-ma-rro",
    "chamba": "cham-ba",
    "chambado": "cham-ba-do",
    "chambaril": "cham-ba-ril",
    "chambeador": "cham-be-a-dor",
    "chambeadora": "cham-be-a-do-ra",
    "chambear": "cham-be-ar",
    "chambel": "cham-bel",
    "chambelán": "cham-be-lán",
    "chambelona": "cham-be-lo-na",
    "chamberga": "cham-ber-ga",
    "chambergo": "cham-ber-go",
    "chamberguilla": "cham-ber-gui-lla",
    "chamberí": "cham-be-rí",
    "chambilla": "cham-bi-lla",
    "chambira": "cham-bi-ra",
    "chambismo": "cham-bis-mo",
    "chambista": "cham-bis-ta",
    "chambón": "cham-bón",
    "chambona": "cham-bo-na",
    "chambonada": "cham-bo-na-da",
    "chambonear": "cham-bo-ne-ar",
    "chamborote": "cham-bo-ro-te",
    "chambra": "cham-bra",
    "chambrana": "cham-bra-na",
    "chambre": "cham-bre",
    "chambrita": "cham-bri-ta",
    "chambroso": "cham-bro-so",
    "chambuque": "cham-bu-que",
    "chamburgo": "cham-bur-go",
    "chamburo": "cham-bu-ro",
    "chamelador": "cha-me-la-dor",
    "chamelar": "cha-me-lar",
    "chamelo": "cha-me-lo",
    "chamelote": "cha-me-lo-te",
    "chamelotón": "cha-me-lo-tón",
    "chamerluco": "cha-mer-lu-co",
    "chamicada": "cha-mi-ca-da",
    "chamicado": "cha-mi-ca-do",
    "chamicera": "cha-mi-ce-ra",
    "chamicero": "cha-mi-ce-ro",
    "chamico": "cha-mi-co",
    "chamillo": "cha-mi-llo",
    "chamiza": "cha-mi-za",
    "chamizo": "cha-mi-zo",
    "chamo": "cha-mo",
    "chamorra": "cha-mo-rra",
    "chamorrar": "cha-mo-rrar",
    "chamorrera": "cha-mo-rre-ra",
    "chamorrero": "cha-mo-rre-ro",
    "chamorro": "cha-mo-rro",
    "champa": "cham-pa",
    "champán": "cham-pán",
    "champaña": "cham-pa-ña",
    "champañazo": "cham-pa-ña-zo",
    "champar": "cham-par",
    "champear": "cham-pe-ar",
    "champiñón": "cham-pi-ñón",
    "champión": "cham-pión",
    "champola": "cham-po-la",
    "champú": "cham-pú",
    "champuda": "cham-pu-da",
    "champudo": "cham-pu-do",
    "champurrada": "cham-pu-rra-da",
    "champurrado": "cham-pu-rra-do",
    "champurrar": "cham-pu-rrar",
    "champurreado": "cham-pu-rre-a-do",
    "champurrear": "cham-pu-rre-ar",
    "champús": "cham-pús",
    "champuz": "cham-puz",
    "chamuchina": "cha-mu-chi-na",
    "chamuco": "cha-mu-co",
    "chamula": "cha-mu-la",
    "chamullar": "cha-mu-llar",
    "chamullento": "cha-mu-llen-to",
    "chamullero": "cha-mu-lle-ro",
    "chamullo": "cha-mu-llo",
    "chamurrar": "cha-mu-rrar",
    "chamusca": "cha-mus-ca",
    "chamuscada": "cha-mus-ca-da",
    "chamuscado": "cha-mus-ca-do",
    "chamuscar": "cha-mus-car",
    "chamusco": "cha-mus-co",
    "chamusquina": "cha-mus-qui-na",
    "chamuyar": "cha-mu-yar",
    "chamuyo": "cha-mu-yo",
    "chaná": "cha-ná",
    "chanada": "cha-na-da",
    "chañar": "cha-ñar",
    "chañaralina": "cha-ña-ra-li-na",
    "chañaralino": "cha-ña-ra-li-no",
    "chanca": "chan-ca",
    "chancaca": "chan-ca-ca",
    "chancacazo": "chan-ca-ca-zo",
    "chancadora": "chan-ca-do-ra",
    "chancaquita": "chan-ca-qui-ta",
    "chancar": "chan-car",
    "chancay": "chan-cay",
    "chance": "chan-ce",
    "chancear": "chan-ce-ar",
    "chancelar": "chan-ce-lar",
    "chancera": "chan-ce-ra",
    "chancero": "chan-ce-ro",
    "chancha": "chan-cha",
    "chanchada": "chan-cha-da",
    "chanchamayina": "chan-cha-ma-yi-na",
    "chanchamayino": "chan-cha-ma-yi-no",
    "cháncharras": "chán-cha-rras",
    "chanchera": "chan-che-ra",
    "chanchería": "chan-che-rí-a",
    "chanchero": "chan-che-ro",
    "chanchi": "chan-chi",
    "chanchiro": "chan-chi-ro",
    "chanchita": "chan-chi-ta",
    "chancho": "chan-cho",
    "chanchullar": "chan-chu-llar",
    "chanchullera": "chan-chu-lle-ra",
    "chanchullero": "chan-chu-lle-ro",
    "chanchullo": "chan-chu-llo",
    "chanciller": "chan-ci-ller",
    "chancillería": "chan-ci-lle-rí-a",
    "chancla": "chan-cla",
    "chancleta": "chan-cle-ta",
    "chancletear": "chan-cle-te-ar",
    "chancleteo": "chan-cle-te-o",
    "chancletera": "chan-cle-te-ra",
    "chancletero": "chan-cle-te-ro",
    "chancletudo": "chan-cle-tu-do",
    "chanclo": "chan-clo",
    "chancluda": "chan-clu-da",
    "chancludo": "chan-clu-do",
    "chanco": "chan-co",
    "chancomer": "chan-co-mer",
    "chancón": "chan-cón",
    "chancro": "chan-cro",
    "chancuco": "chan-cu-co",
    "chanda": "chan-da",
    "chándal": "chán-dal",
    "chandosa": "chan-do-sa",
    "chandoso": "chan-do-so",
    "chane": "cha-ne",
    "chané": "cha-né",
    "chaneco": "cha-ne-co",
    "chanelar": "cha-ne-lar",
    "chanfa": "chan-fa",
    "chanfaina": "chan-fai-na",
    "chanfla": "chan-fla",
    "chanfle": "chan-fle",
    "chanflear": "chan-fle-ar",
    "chanflón": "chan-flón",
    "chanflona": "chan-flo-na",
    "changa": "chan-ga",
    "changador": "chan-ga-dor",
    "changalla": "chan-ga-lla",
    "changallo": "chan-ga-llo",
    "changar": "chan-gar",
    "changarín": "chan-ga-rín",
    "changarra": "chan-ga-rra",
    "changarro": "chan-ga-rro",
    "changle": "chan-gle",
    "chango": "chan-go",
    "changoneta": "chan-go-ne-ta",
    "changonetero": "chan-go-ne-te-ro",
    "changua": "chan-gua",
    "changuear": "chan-gue-ar",
    "changuería": "chan-gue-rí-a",
    "changüí": "chan-güí",
    "changurro": "chan-gu-rro",
    "chanquear": "chan-que-ar",
    "chanquete": "chan-que-te",
    "chanta": "chan-ta",
    "chantado": "chan-ta-do",
    "chantaje": "chan-ta-je",
    "chantajear": "chan-ta-je-ar",
    "chantajista": "chan-ta-jis-ta",
    "chantar": "chan-tar",
    "chantillí": "chan-ti-llí",
    "chantillón": "chan-ti-llón",
    "chantilly": "chan-tilly",
    "chanto": "chan-to",
    "chantre": "chan-tre",
    "chantría": "chan-trí-a",
    "chanza": "chan-za",
    "chanzoneta": "chan-zo-ne-ta",
    "chanzonetero": "chan-zo-ne-te-ro",
    "chao": "cha-o",
    "chaola": "cha-o-la",
    "chapa": "cha-pa",
    "chapaca": "cha-pa-ca",
    "chapaco": "cha-pa-co",
    "chapada": "cha-pa-da",
    "chapadamente": "cha-pa-da-men-te",
    "chapado": "cha-pa-do",
    "chapalear": "cha-pa-le-ar",
    "chapalele": "cha-pa-le-le",
    "chapaleo": "cha-pa-le-o",
    "chapaleta": "cha-pa-le-ta",
    "chapaletear": "cha-pa-le-te-ar",
    "chapaleteo": "cha-pa-le-te-o",
    "chapandongo": "cha-pan-don-go",
    "chapapote": "cha-pa-po-te",
    "chapar": "cha-par",
    "chapareña": "cha-pa-re-ña",
    "chapareño": "cha-pa-re-ño",
    "chaparra": "cha-pa-rra",
    "chaparrada": "cha-pa-rra-da",
    "chaparral": "cha-pa-rral",
    "chaparrastroso": "cha-pa-rras-tro-so",
    "chaparrazo": "cha-pa-rra-zo",
    "chaparrear": "cha-pa-rre-ar",
    "chaparreras": "cha-pa-rre-ras",
    "chaparrete": "cha-pa-rre-te",
    "chaparro": "cha-pa-rro",
    "chaparrón": "cha-pa-rrón",
    "chaparruda": "cha-pa-rru-da",
    "chaparrudo": "cha-pa-rru-do",
    "chapata": "cha-pa-ta",
    "chapatal": "cha-pa-tal",
    "chape": "cha-pe",
    "chapeada": "cha-pe-a-da",
    "chapeado": "cha-pe-a-do",
    "chapeador": "cha-pe-a-dor",
    "chapeadora": "cha-pe-a-do-ra",
    "chapear": "cha-pe-ar",
    "chapeca": "cha-pe-ca",
    "chapecar": "cha-pe-car",
    "chapel": "cha-pel",
    "chapela": "cha-pe-la",
    "chapelo": "cha-pe-lo",
    "chapeo": "cha-pe-o",
    "chapera": "cha-pe-ra",
    "chapería": "cha-pe-rí-a",
    "chapero": "cha-pe-ro",
    "chaperón": "cha-pe-rón",
    "chaperona": "cha-pe-ro-na",
    "chaperonada": "cha-pe-ro-na-da",
    "chaperonado": "cha-pe-ro-na-do",
    "chaperonear": "cha-pe-ro-ne-ar",
    "chapeta": "cha-pe-ta",
    "chapeteado": "cha-pe-te-a-do",
    "chapetón": "cha-pe-tón",
    "chapetona": "cha-pe-to-na",
    "chapetonada": "cha-pe-to-na-da",
    "chapia": "cha-pia",
    "chapico": "cha-pi-co",
    "chapín": "cha-pín",
    "chapina": "cha-pi-na",
    "chapinada": "cha-pi-na-da",
    "chapinazo": "cha-pi-na-zo",
    "chapinería": "cha-pi-ne-rí-a",
    "chapinero": "cha-pi-ne-ro",
    "chapinete": "cha-pi-ne-te",
    "chapingorro": "cha-pin-go-rro",
    "chapinismo": "cha-pi-nis-mo",
    "chapinizar": "cha-pi-ni-zar",
    "chapinuda": "cha-pi-nu-da",
    "chapinudo": "cha-pi-nu-do",
    "chápiro": "chá-pi-ro",
    "chapirón": "cha-pi-rón",
    "chapisca": "cha-pis-ca",
    "chapista": "cha-pis-ta",
    "chapistear": "cha-pis-te-ar",
    "chapistería": "cha-pis-te-rí-a",
    "chapita": "cha-pi-ta",
    "chapitel": "cha-pi-tel",
    "chaple": "cha-ple",
    "chapo": "cha-po",
    "chapó": "cha-pó",
    "chapodar": "cha-po-dar",
    "chapodo": "cha-po-do",
    "chapola": "cha-po-la",
    "chapón": "cha-pón",
    "chapona": "cha-po-na",
    "chapopote": "cha-po-po-te",
    "chapoteadero": "cha-po-te-a-de-ro",
    "chapotear": "cha-po-te-ar",
    "chapoteo": "cha-po-te-o",
    "chapucear": "cha-pu-ce-ar",
    "chapucera": "cha-pu-ce-ra",
    "chapuceramente": "cha-pu-ce-ra-men-te",
    "chapucería": "cha-pu-ce-rí-a",
    "chapucero": "cha-pu-ce-ro",
    "chapul": "cha-pul",
    "chapulín": "cha-pu-lín",
    "chapullar": "cha-pu-llar",
    "chapupa": "cha-pu-pa",
    "chapurrado": "cha-pu-rra-do",
    "chapurrar": "cha-pu-rrar",
    "chapurrear": "cha-pu-rre-ar",
    "chapurreo": "cha-pu-rre-o",
    "chapuz": "cha-puz",
    "chapuza": "cha-pu-za",
    "chapuzar": "cha-pu-zar",
    "chapuzas": "cha-pu-zas",
    "chapuzón": "cha-pu-zón",
    "chaqué": "cha-qué",
    "chaqueña": "cha-que-ña",
    "chaqueño": "cha-que-ño",
    "chaquense": "cha-quen-se",
    "chaqueta": "cha-que-ta",
    "chaquete": "cha-que-te",
    "chaquetear": "cha-que-te-ar",
    "chaqueteo": "cha-que-te-o",
    "chaquetera": "cha-que-te-ra",
    "chaquetero": "cha-que-te-ro",
    "chaquetilla": "cha-que-ti-lla",
    "chaquetón": "cha-que-tón",
    "chaqui": "cha-qui",
    "chaquiñán": "cha-qui-ñán",
    "chaquira": "cha-qui-ra",
    "charabán": "cha-ra-bán",
    "charabasca": "cha-ra-bas-ca",
    "charabón": "cha-ra-bón",
    "charada": "cha-ra-da",
    "charal": "cha-ral",
    "charamada": "cha-ra-ma-da",
    "charamasca": "cha-ra-mas-ca",
    "charambita": "cha-ram-bi-ta",
    "charamita": "cha-ra-mi-ta",
    "charamusca": "cha-ra-mus-ca",
    "charancaco": "cha-ran-ca-co",
    "charanda": "cha-ran-da",
    "charañeña": "cha-ra-ñe-ña",
    "charañeño": "cha-ra-ñe-ño",
    "charanga": "cha-ran-ga",
    "charango": "cha-ran-go",
    "charanguera": "cha-ran-gue-ra",
    "charanguero": "cha-ran-gue-ro",
    "charapa": "cha-ra-pa",
    "charape": "cha-ra-pe",
    "charata": "cha-ra-ta",
    "charca": "char-ca",
    "charcal": "char-cal",
    "charcas": "char-cas",
    "charcha": "char-cha",
    "charchazo": "char-cha-zo",
    "charchina": "char-chi-na",
    "charco": "char-co",
    "charcón": "char-cón",
    "charcona": "char-co-na",
    "charcutera": "char-cu-te-ra",
    "charcutería": "char-cu-te-rí-a",
    "charcutero": "char-cu-te-ro",
    "charla": "char-la",
    "charlador": "char-la-dor",
    "charladora": "char-la-do-ra",
    "charladuría": "char-la-du-rí-a",
    "charlar": "char-lar",
    "charlatán": "char-la-tán",
    "charlatana": "char-la-ta-na",
    "charlatanear": "char-la-ta-ne-ar",
    "charlatanería": "char-la-ta-ne-rí-a",
    "charlatanismo": "char-la-ta-nis-mo",
    "charlear": "char-le-ar",
    "charlestón": "char-les-tón",
    "charleta": "char-le-ta",
    "charlista": "char-lis-ta",
    "charlo": "char-lo",
    "charlón": "char-lón",
    "charlona": "char-lo-na",
    "charlotada": "char-lo-ta-da",
    "charlotear": "char-lo-te-ar",
    "charloteo": "char-lo-te-o",
    "charneca": "char-ne-ca",
    "charnecal": "char-ne-cal",
    "charnega": "char-ne-ga",
    "charnego": "char-ne-go",
    "charnela": "char-ne-la",
    "charneta": "char-ne-ta",
    "charol": "cha-rol",
    "charola": "cha-ro-la",
    "charolada": "cha-ro-la-da",
    "charolado": "cha-ro-la-do",
    "charolar": "cha-ro-lar",
    "charolista": "cha-ro-lis-ta",
    "charpa": "char-pa",
    "charpe": "char-pe",
    "charque": "char-que",
    "charquear": "char-que-ar",
    "charquecillo": "char-que-ci-llo",
    "charquense": "char-quen-se",
    "charquero": "char-que-ro",
    "charquetal": "char-que-tal",
    "charqui": "char-qui",
    "charquicán": "char-qui-cán",
    "charquino": "char-qui-no",
    "charra": "cha-rra",
    "charrada": "cha-rra-da",
    "charral": "cha-rral",
    "charraludo": "cha-rra-lu-do",
    "charrán": "cha-rrán",
    "charrana": "cha-rra-na",
    "charranada": "cha-rra-na-da",
    "charrancito": "cha-rran-ci-to",
    "charranear": "cha-rra-ne-ar",
    "charranería": "cha-rra-ne-rí-a",
    "charrar": "cha-rrar",
    "charrasca": "cha-rras-ca",
    "charrasco": "cha-rras-co",
    "charrasqueado": "cha-rras-que-a-do",
    "charrasquear": "cha-rras-que-ar",
    "charreada": "cha-rre-a-da",
    "charrera": "cha-rre-ra",
    "charrería": "cha-rre-rí-a",
    "charrete": "cha-rre-te",
    "charretera": "cha-rre-te-ra",
    "charriote": "cha-rrio-te",
    "charro": "cha-rro",
    "charrúa": "cha-rrú-a",
    "charrulo": "cha-rru-lo",
    "chárter": "chár-ter",
    "chartista": "char-tis-ta",
    "chartreuse": "char-treu-se",
    "chasca": "chas-ca",
    "chascada": "chas-ca-da",
    "chascar": "chas-car",
    "chascarrillo": "chas-ca-rri-llo",
    "chascarro": "chas-ca-rro",
    "chascás": "chas-cás",
    "chasco": "chas-co",
    "chascón": "chas-cón",
    "chascona": "chas-co-na",
    "chasconear": "chas-co-ne-ar",
    "chascoso": "chas-co-so",
    "chascudo": "chas-cu-do",
    "chasis": "cha-sis",
    "chaspar": "chas-par",
    "chasparría": "chas-pa-rrí-a",
    "chaspe": "chas-pe",
    "chaspear": "chas-pe-ar",
    "chasponazo": "chas-po-na-zo",
    "chasque": "chas-que",
    "chasqueador": "chas-que-a-dor",
    "chasqueadora": "chas-que-a-do-ra",
    "chasquear": "chas-que-ar",
    "chasquero": "chas-que-ro",
    "chasqui": "chas-qui",
    "chasquido": "chas-qui-do",
    "chasquilla": "chas-qui-lla",
    "chata": "cha-ta",
    "chatarra": "cha-ta-rra",
    "chatarrear": "cha-ta-rre-ar",
    "chatarrera": "cha-ta-rre-ra",
    "chatarrería": "cha-ta-rre-rí-a",
    "chatarrero": "cha-ta-rre-ro",
    "chatear": "cha-te-ar",
    "chatedad": "cha-te-dad",
    "chatel": "cha-tel",
    "chateo": "cha-te-o",
    "chatero": "cha-te-ro",
    "chatino": "cha-ti-no",
    "chato": "cha-to",
    "chatón": "cha-tón",
    "chatre": "cha-tre",
    "chatria": "cha-tria",
    "chatungo": "cha-tun-go",
    "chatura": "cha-tu-ra",
    "chaucha": "chau-cha",
    "chauche": "chau-che",
    "chauchear": "chau-che-ar",
    "chauchera": "chau-che-ra",
    "chauchón": "chau-chón",
    "chauchona": "chau-cho-na",
    "chaúl": "cha-úl",
    "chauvinismo": "chau-vi-nis-mo",
    "chauvinista": "chau-vi-nis-ta",
    "chava": "cha-va",
    "chaval": "cha-val",
    "chavala": "cha-va-la",
    "chavalería": "cha-va-le-rí-a",
    "chavalo": "cha-va-lo",
    "chavar": "cha-var",
    "chavarí": "cha-va-rí",
    "chavasca": "cha-vas-ca",
    "chavea": "cha-ve-a",
    "chavería": "cha-ve-rí-a",
    "chaveta": "cha-ve-ta",
    "chavetear": "cha-ve-te-ar",
    "chavetero": "cha-ve-te-ro",
    "chaviza": "cha-vi-za",
    "chavo": "cha-vo",
    "chavó": "cha-vó",
    "chavola": "cha-vo-la",
    "chavón": "cha-vón",
    "chaya": "cha-ya",
    "chayar": "cha-yar",
    "chayo": "cha-yo",
    "chayota": "cha-yo-ta",
    "chayotal": "cha-yo-tal",
    "chayote": "cha-yo-te",
    "chayotera": "cha-yo-te-ra",
    "chaza": "cha-za",
    "chazador": "cha-za-dor",
    "chazar": "cha-zar",
    "chazo": "cha-zo",
    "cheada": "che-a-da",
    "checa": "che-ca",
    "checar": "che-car",
    "checata": "che-ca-ta",
    "checato": "che-ca-to",
    "cheche": "che-che",
    "chechén": "che-chén",
    "chechena": "che-che-na",
    "checheno": "che-che-no",
    "chéchere": "ché-che-re",
    "chécheres": "ché-che-res",
    "checo": "che-co",
    "checoeslovaca": "che-co-es-lo-va-ca",
    "checoeslovaco": "che-co-es-lo-va-co",
    "checoslovaca": "che-cos-lo-va-ca",
    "checoslovaco": "che-cos-lo-va-co",
    "cheira": "chei-ra",
    "cheje": "che-je",
    "chela": "che-la",
    "chele": "che-le",
    "cheli": "che-li",
    "chelín": "che-lín",
    "chelista": "che-lis-ta",
    "chelo": "che-lo",
    "cheloso": "che-lo-so",
    "chenca": "chen-ca",
    "chenilla": "che-ni-lla",
    "chentino": "chen-ti-no",
    "chepa": "che-pa",
    "chepe": "che-pe",
    "chepear": "che-pe-ar",
    "chepenana": "che-pe-na-na",
    "chepenano": "che-pe-na-no",
    "chepia": "che-pia",
    "chépica": "ché-pi-ca",
    "chepo": "che-po",
    "cheposo": "che-po-so",
    "chepudo": "che-pu-do",
    "cheque": "che-que",
    "chequear": "che-que-ar",
    "chequén": "che-quén",
    "chequeo": "che-que-o",
    "chequera": "che-que-ra",
    "chera": "che-ra",
    "cheral": "che-ral",
    "chercán": "cher-cán",
    "chercha": "cher-cha",
    "cherchar": "cher-char",
    "cherenga": "che-ren-ga",
    "cherkesa": "cher-ke-sa",
    "cherlicrés": "cher-li-crés",
    "cherna": "cher-na",
    "cherne": "cher-ne",
    "chero": "che-ro",
    "cherriar": "che-rriar",
    "cherrión": "che-rrión",
    "cherva": "cher-va",
    "chesa": "che-sa",
    "cheso": "che-so",
    "chéster": "chés-ter",
    "cheto": "che-to",
    "chetumaleño": "che-tu-ma-le-ño",
    "chetumalense": "che-tu-ma-len-se",
    "cheurón": "cheu-rón",
    "cheuta": "cheu-ta",
    "cheuto": "cheu-to",
    "chévere": "ché-ve-re",
    "chevió": "che-vió",
    "cheviot": "che-viot",
    "cheyene": "che-ye-ne",
    "chía": "chí-a",
    "chianti": "chian-ti",
    "chiapa": "chia-pa",
    "chiapaneca": "chia-pa-ne-ca",
    "chiapaneco": "chia-pa-ne-co",
    "chibalete": "chi-ba-le-te",
    "chibcha": "chib-cha",
    "chibola": "chi-bo-la",
    "chibolo": "chi-bo-lo",
    "chiborra": "chi-bo-rra",
    "chibuquí": "chi-bu-quí",
    "chica": "chi-ca",
    "chicada": "chi-ca-da",
    "chicalé": "chi-ca-lé",
    "chicalote": "chi-ca-lo-te",
    "chicana": "chi-ca-na",
    "chicane": "chi-ca-ne",
    "chicanear": "chi-ca-ne-ar",
    "chicanero": "chi-ca-ne-ro",
    "chicano": "chi-ca-no",
    "chicarrera": "chi-ca-rre-ra",
    "chicarrero": "chi-ca-rre-ro",
    "chicarro": "chi-ca-rro",
    "chicarrón": "chi-ca-rrón",
    "chicarrona": "chi-ca-rro-na",
    "chicata": "chi-ca-ta",
    "chicato": "chi-ca-to",
    "chicha": "chi-cha",
    "chícharo": "chí-cha-ro",
    "chicharra": "chi-cha-rra",
    "chicharrar": "chi-cha-rrar",
    "chicharrear": "chi-cha-rre-ar",
    "chicharrera": "chi-cha-rre-ra",
    "chicharrero": "chi-cha-rre-ro",
    "chicharrina": "chi-cha-rri-na",
    "chicharrita": "chi-cha-rri-ta",
    "chicharro": "chi-cha-rro",
    "chicharrón": "chi-cha-rrón",
    "chicharrona": "chi-cha-rro-na",
    "chicharronear": "chi-cha-rro-ne-ar",
    "chicharronería": "chi-cha-rro-ne-rí-a",
    "chiche": "chi-che",
    "chichear": "chi-che-ar",
    "chicheme": "chi-che-me",
    "chicheo": "chi-che-o",
    "chichera": "chi-che-ra",
    "chichería": "chi-che-rí-a",
    "chichero": "chi-che-ro",
    "chichi": "chi-chi",
    "chichí": "chi-chí",
    "chichicaste": "chi-chi-cas-te",
    "chichicastle": "chi-chi-cas-tle",
    "chichicuilote": "chi-chi-cui-lo-te",
    "chichigua": "chi-chi-gua",
    "chichiguaste": "chi-chi-guas-te",
    "chichilasa": "chi-chi-la-sa",
    "chichilo": "chi-chi-lo",
    "chichiltote": "chi-chil-to-te",
    "chichimeca": "chi-chi-me-ca",
    "chichimeco": "chi-chi-me-co",
    "chichimora": "chi-chi-mo-ra",
    "chichina": "chi-chi-na",
    "chichinabo": "chi-chi-na-bo",
    "chichinar": "chi-chi-nar",
    "chichinflor": "chi-chin-flor",
    "chichinguaste": "chi-chin-guas-te",
    "chichintora": "chi-chin-to-ra",
    "chichipata": "chi-chi-pa-ta",
    "chichipate": "chi-chi-pa-te",
    "chichipato": "chi-chi-pa-to",
    "chichisbeo": "chi-chis-be-o",
    "chichito": "chi-chi-to",
    "chichitote": "chi-chi-to-te",
    "chicho": "chi-cho",
    "chicholo": "chi-cho-lo",
    "chichón": "chi-chón",
    "chichona": "chi-cho-na",
    "chichonera": "chi-cho-ne-ra",
    "chichota": "chi-cho-ta",
    "chichote": "chi-cho-te",
    "chichunte": "chi-chun-te",
    "chichurro": "chi-chu-rro",
    "chiclán": "chi-clán",
    "chiclanera": "chi-cla-ne-ra",
    "chiclanero": "chi-cla-ne-ro",
    "chiclano": "chi-cla-no",
    "chiclayana": "chi-cla-ya-na",
    "chiclayano": "chi-cla-ya-no",
    "chiclazo": "chi-cla-zo",
    "chicle": "chi-cle",
    "chiclé": "chi-clé",
    "chiclear": "chi-cle-ar",
    "chiclero": "chi-cle-ro",
    "chicloso": "chi-clo-so",
    "chico": "chi-co",
    "chicoca": "chi-co-ca",
    "chicoco": "chi-co-co",
    "chicolear": "chi-co-le-ar",
    "chicoleo": "chi-co-le-o",
    "chícora": "chí-co-ra",
    "chicoria": "chi-co-ria",
    "chicoriácea": "chi-co-riá-ce-a",
    "chicoriáceo": "chi-co-riá-ce-o",
    "chicorro": "chi-co-rro",
    "chicorrotín": "chi-co-rro-tín",
    "chicorrotina": "chi-co-rro-ti-na",
    "chicota": "chi-co-ta",
    "chicotazo": "chi-co-ta-zo",
    "chicote": "chi-co-te",
    "chicoteada": "chi-co-te-a-da",
    "chicotear": "chi-co-te-ar",
    "chicozapote": "chi-co-za-po-te",
    "chicuelina": "chi-cue-li-na",
    "chicuije": "chi-cui-je",
    "chícura": "chí-cu-ra",
    "chido": "chi-do",
    "chifa": "chi-fa",
    "chifla": "chi-fla",
    "chiflada": "chi-fla-da",
    "chifladera": "chi-fla-de-ra",
    "chiflado": "chi-fla-do",
    "chifladura": "chi-fla-du-ra",
    "chiflar": "chi-flar",
    "chiflato": "chi-fla-to",
    "chifle": "chi-fle",
    "chiflera": "chi-fle-ra",
    "chifleta": "chi-fle-ta",
    "chiflete": "chi-fle-te",
    "chiflido": "chi-fli-do",
    "chiflo": "chi-flo",
    "chiflón": "chi-flón",
    "chifonier": "chi-fo-nier",
    "chigre": "chi-gre",
    "chigrero": "chi-gre-ro",
    "chigua": "chi-gua",
    "chigüí": "chi-güí",
    "chigüil": "chi-güil",
    "chigüín": "chi-güín",
    "chigüina": "chi-güi-na",
    "chigüire": "chi-güi-re",
    "chihuaco": "chi-hua-co",
    "chihuahua": "chi-hua-hua",
    "chihuahueño": "chi-hua-hue-ño",
    "chihuahuense": "chi-hua-huen-se",
    "chijetazo": "chi-je-ta-zo",
    "chijete": "chi-je-te",
    "chilaba": "chi-la-ba",
    "chilacayote": "chi-la-ca-yo-te",
    "chilacoa": "chi-la-co-a",
    "chilamate": "chi-la-ma-te",
    "chilanco": "chi-lan-co",
    "chilanga": "chi-lan-ga",
    "chilango": "chi-lan-go",
    "chilaquila": "chi-la-qui-la",
    "chilaquiles": "chi-la-qui-les",
    "chilar": "chi-lar",
    "chilate": "chi-la-te",
    "chilatole": "chi-la-to-le",
    "chilca": "chil-ca",
    "chilcano": "chil-ca-no",
    "chilchote": "chil-cho-te",
    "chilco": "chil-co",
    "chile": "chi-le",
    "chilena": "chi-le-na",
    "chilenismo": "chi-le-nis-mo",
    "chileno": "chi-le-no",
    "chilera": "chi-le-ra",
    "chilero": "chi-le-ro",
    "chili": "chi-li",
    "chilillo": "chi-li-llo",
    "chilindrina": "chi-lin-dri-na",
    "chilindrinera": "chi-lin-dri-ne-ra",
    "chilindrinero": "chi-lin-dri-ne-ro",
    "chilindrón": "chi-lin-drón",
    "chilinguear": "chi-lin-gue-ar",
    "chilipuca": "chi-li-pu-ca",
    "chilipuco": "chi-li-pu-co",
    "chilla": "chi-lla",
    "chillado": "chi-lla-do",
    "chillador": "chi-lla-dor",
    "chilladora": "chi-lla-do-ra",
    "chillanense": "chi-lla-nen-se",
    "chillante": "chi-llan-te",
    "chillar": "chi-llar",
    "chillera": "chi-lle-ra",
    "chillería": "chi-lle-rí-a",
    "chillido": "chi-lli-do",
    "chillo": "chi-llo",
    "chillón": "chi-llón",
    "chillona": "chi-llo-na",
    "chillonamente": "chi-llo-na-men-te",
    "chilmole": "chil-mo-le",
    "chilmolera": "chil-mo-le-ra",
    "chilmolero": "chil-mo-le-ro",
    "chilmotate": "chil-mo-ta-te",
    "chiloense": "chi-lo-en-se",
    "chiloso": "chi-lo-so",
    "chilostra": "chi-los-tra",
    "chilota": "chi-lo-ta",
    "chilote": "chi-lo-te",
    "chilpancingueña": "chil-pan-cin-gue-ña",
    "chilpancingueño": "chil-pan-cin-gue-ño",
    "chilpayata": "chil-pa-ya-ta",
    "chilpayate": "chil-pa-ya-te",
    "chilpe": "chil-pe",
    "chilposo": "chil-po-so",
    "chiltepe": "chil-te-pe",
    "chiltipiquín": "chil-ti-pi-quín",
    "chiltomate": "chil-to-ma-te",
    "chiltota": "chil-to-ta",
    "chiltote": "chil-to-te",
    "chiltuca": "chil-tu-ca",
    "chimalteca": "chi-mal-te-ca",
    "chimalteco": "chi-mal-te-co",
    "chimango": "chi-man-go",
    "chimar": "chi-mar",
    "chimba": "chim-ba",
    "chimbador": "chim-ba-dor",
    "chimbadora": "chim-ba-do-ra",
    "chimbaguele": "chim-ba-gue-le",
    "chimbar": "chim-bar",
    "chimbo": "chim-bo",
    "chimbolero": "chim-bo-le-ro",
    "chimbomba": "chim-bom-ba",
    "chimboracense": "chim-bo-ra-cen-se",
    "chimenea": "chi-me-ne-a",
    "chimento": "chi-men-to",
    "chimichaca": "chi-mi-cha-ca",
    "chimichurri": "chi-mi-chu-rri",
    "chiminango": "chi-mi-nan-go",
    "chimirringo": "chi-mi-rrin-go",
    "chimiscolazo": "chi-mis-co-la-zo",
    "chimiscolear": "chi-mis-co-le-ar",
    "chimiscolera": "chi-mis-co-le-ra",
    "chimiscolero": "chi-mis-co-le-ro",
    "chimisturria": "chi-mis-tu-rria",
    "chimó": "chi-mó",
    "chimojo": "chi-mo-jo",
    "chimón": "chi-món",
    "chimpancé": "chim-pan-cé",
    "chimpilinear": "chim-pi-li-ne-ar",
    "chimpinilla": "chim-pi-ni-lla",
    "chimpinillera": "chim-pi-ni-lle-ra",
    "chimpunes": "chim-pu-nes",
    "chimú": "chi-mú",
    "chimuchina": "chi-mu-chi-na",
    "chimuela": "chi-mue-la",
    "chimuelo": "chi-mue-lo",
    "china": "chi-na",
    "chinaca": "chi-na-ca",
    "chinacate": "chi-na-ca-te",
    "chinaco": "chi-na-co",
    "chinama": "chi-na-ma",
    "chinamo": "chi-na-mo",
    "chinampa": "chi-nam-pa",
    "chinampera": "chi-nam-pe-ra",
    "chinampero": "chi-nam-pe-ro",
    "chinandegana": "chi-nan-de-ga-na",
    "chinandegano": "chi-nan-de-ga-no",
    "chinapo": "chi-na-po",
    "chinapopo": "chi-na-po-po",
    "chinar": "chi-nar",
    "chinarral": "chi-na-rral",
    "chinarro": "chi-na-rro",
    "chinaste": "chi-nas-te",
    "chinastear": "chi-nas-te-ar",
    "chinata": "chi-na-ta",
    "chinateado": "chi-na-te-a-do",
    "chinazo": "chi-na-zo",
    "chinazte": "chi-naz-te",
    "chincalé": "chin-ca-lé",
    "chincha": "chin-cha",
    "chinchal": "chin-chal",
    "chinchalero": "chin-cha-le-ro",
    "chinchana": "chin-cha-na",
    "chinchano": "chin-cha-no",
    "chinchar": "chin-char",
    "chincharrazo": "chin-cha-rra-zo",
    "chincharrero": "chin-cha-rre-ro",
    "chinchayote": "chin-cha-yo-te",
    "chinche": "chin-che",
    "chinchel": "chin-chel",
    "chinchemolle": "chin-che-mo-lle",
    "chinchero": "chin-che-ro",
    "chincheta": "chin-che-ta",
    "chinchibí": "chin-chi-bí",
    "chinchilla": "chin-chi-lla",
    "chinchimén": "chin-chi-mén",
    "chinchín": "chin-chín",
    "chinchinear": "chin-chi-ne-ar",
    "chinchinga": "chin-chin-ga",
    "chinchintor": "chin-chin-tor",
    "chinchón": "chin-chón",
    "chinchona": "chin-cho-na",
    "chinchorrear": "chin-cho-rre-ar",
    "chinchorrera": "chin-cho-rre-ra",
    "chinchorrería": "chin-cho-rre-rí-a",
    "chinchorrero": "chin-cho-rre-ro",
    "chinchorro": "chin-cho-rro",
    "chinchosa": "chin-cho-sa",
    "chinchoso": "chin-cho-so",
    "chinchudo": "chin-chu-do",
    "chinchulín": "chin-chu-lín",
    "chinchunte": "chin-chun-te",
    "chinchurria": "chin-chu-rria",
    "chincol": "chin-col",
    "chinda": "chin-da",
    "chindondo": "chin-don-do",
    "chiné": "chi-né",
    "chineada": "chi-ne-a-da",
    "chinear": "chi-ne-ar",
    "chinela": "chi-ne-la",
    "chinelazo": "chi-ne-la-zo",
    "chineo": "chi-ne-o",
    "chinerío": "chi-ne-rí-o",
    "chinero": "chi-ne-ro",
    "chinesca": "chi-nes-ca",
    "chinesco": "chi-nes-co",
    "chinga": "chin-ga",
    "chingada": "chin-ga-da",
    "chingadazo": "chin-ga-da-zo",
    "chingadera": "chin-ga-de-ra",
    "chingado": "chin-ga-do",
    "chingana": "chin-ga-na",
    "chingaquedita": "chin-ga-que-di-ta",
    "chingaquedito": "chin-ga-que-di-to",
    "chingar": "chin-gar",
    "chingaste": "chin-gas-te",
    "chinglar": "chin-glar",
    "chingo": "chin-go",
    "chingolear": "chin-go-le-ar",
    "chingolingo": "chin-go-lin-go",
    "chingolo": "chin-go-lo",
    "chingón": "chin-gón",
    "chingona": "chin-go-na",
    "chingua": "chin-gua",
    "chingue": "chin-gue",
    "chinguear": "chin-gue-ar",
    "chínguere": "chín-gue-re",
    "chinguero": "chin-gue-ro",
    "chinguirito": "chin-gui-ri-to",
    "chinín": "chi-nín",
    "chinita": "chi-ni-ta",
    "chino": "chi-no",
    "chinola": "chi-no-la",
    "chinología": "chi-no-lo-gí-a",
    "chinotibetano": "chi-no-ti-be-ta-no",
    "chintano": "chin-ta-no",
    "chinto": "chin-to",
    "chinvarona": "chin-va-ro-na",
    "chionodoxa": "chio-no-do-xa",
    "chipa": "chi-pa",
    "chipá": "chi-pá",
    "chipaca": "chi-pa-ca",
    "chipe": "chi-pe",
    "chipé": "chi-pé",
    "chipeado": "chi-pe-a-do",
    "chipear": "chi-pe-ar",
    "chipén": "chi-pén",
    "chipiar": "chi-piar",
    "chipichape": "chi-pi-cha-pe",
    "chipichipi": "chi-pi-chi-pi",
    "chipil": "chi-pil",
    "chipile": "chi-pi-le",
    "chipilear": "chi-pi-le-ar",
    "chipilín": "chi-pi-lín",
    "chipilina": "chi-pi-li-na",
    "chipilo": "chi-pi-lo",
    "chipirón": "chi-pi-rón",
    "chipojear": "chi-po-je-ar",
    "chipojo": "chi-po-jo",
    "chipolo": "chi-po-lo",
    "chiporro": "chi-po-rro",
    "chipote": "chi-po-te",
    "chipotle": "chi-po-tle",
    "chipriota": "chi-prio-ta",
    "chipriote": "chi-prio-te",
    "chipuste": "chi-pus-te",
    "chiqueador": "chi-que-a-dor",
    "chiqueadores": "chi-que-a-do-res",
    "chiquear": "chi-que-ar",
    "chiqueo": "chi-que-o",
    "chiquero": "chi-que-ro",
    "chiquichanca": "chi-qui-chan-ca",
    "chiquichaque": "chi-qui-cha-que",
    "chiquigüite": "chi-qui-güi-te",
    "chiquihuite": "chi-qui-hui-te",
    "chiquilicuatre": "chi-qui-li-cua-tre",
    "chiquilicuatro": "chi-qui-li-cua-tro",
    "chiquilín": "chi-qui-lín",
    "chiquilina": "chi-qui-li-na",
    "chiquilla": "chi-qui-lla",
    "chiquillada": "chi-qui-lla-da",
    "chiquillería": "chi-qui-lle-rí-a",
    "chiquillo": "chi-qui-llo",
    "chiquimulteca": "chi-qui-mul-te-ca",
    "chiquimulteco": "chi-qui-mul-te-co",
    "chiquirín": "chi-qui-rín",
    "chiquirritica": "chi-qui-rri-ti-ca",
    "chiquirritico": "chi-qui-rri-ti-co",
    "chiquirritín": "chi-qui-rri-tín",
    "chiquirritina": "chi-qui-rri-ti-na",
    "chiquita": "chi-qui-ta",
    "chiquitana": "chi-qui-ta-na",
    "chiquitano": "chi-qui-ta-no",
    "chiquitear": "chi-qui-te-ar",
    "chiquitín": "chi-qui-tín",
    "chiquitina": "chi-qui-ti-na",
    "chiquito": "chi-qui-to",
    "chiquizuela": "chi-qui-zue-la",
    "chira": "chi-ra",
    "chirajo": "chi-ra-jo",
    "chirapa": "chi-ra-pa",
    "chirca": "chir-ca",
    "chircal": "chir-cal",
    "chircate": "chir-ca-te",
    "chiri": "chi-ri",
    "chiribico": "chi-ri-bi-co",
    "chiribiqui": "chi-ri-bi-qui",
    "chiribita": "chi-ri-bi-ta",
    "chiribital": "chi-ri-bi-tal",
    "chiribitil": "chi-ri-bi-til",
    "chiribito": "chi-ri-bi-to",
    "chiricana": "chi-ri-ca-na",
    "chiricano": "chi-ri-ca-no",
    "chiricatana": "chi-ri-ca-ta-na",
    "chiricaya": "chi-ri-ca-ya",
    "chiricote": "chi-ri-co-te",
    "chirigota": "chi-ri-go-ta",
    "chirigotear": "chi-ri-go-te-ar",
    "chirigotera": "chi-ri-go-te-ra",
    "chirigotero": "chi-ri-go-te-ro",
    "chiriguano": "chi-ri-gua-no",
    "chiriguare": "chi-ri-gua-re",
    "chirigüe": "chi-ri-güe",
    "chirimacha": "chi-ri-ma-cha",
    "chirimbolo": "chi-rim-bo-lo",
    "chirimía": "chi-ri-mí-a",
    "chirimiri": "chi-ri-mi-ri",
    "chirimoya": "chi-ri-mo-ya",
    "chirimoyo": "chi-ri-mo-yo",
    "chirinada": "chi-ri-na-da",
    "chiringa": "chi-rin-ga",
    "chiringo": "chi-rin-go",
    "chiringuito": "chi-rin-gui-to",
    "chirinoco": "chi-ri-no-co",
    "chirinola": "chi-ri-no-la",
    "chiripa": "chi-ri-pa",
    "chiripá": "chi-ri-pá",
    "chiripada": "chi-ri-pa-da",
    "chiripazo": "chi-ri-pa-zo",
    "chiripear": "chi-ri-pe-ar",
    "chiripera": "chi-ri-pe-ra",
    "chiripero": "chi-ri-pe-ro",
    "chirís": "chi-rís",
    "chiriveje": "chi-ri-ve-je",
    "chirivía": "chi-ri-ví-a",
    "chirivín": "chi-ri-vín",
    "chiriviscal": "chi-ri-vis-cal",
    "chirivisco": "chi-ri-vis-co",
    "chiriza": "chi-ri-za",
    "chirizo": "chi-ri-zo",
    "chirla": "chir-la",
    "chirlador": "chir-la-dor",
    "chirladora": "chir-la-do-ra",
    "chirlar": "chir-lar",
    "chirlata": "chir-la-ta",
    "chirlatar": "chir-la-tar",
    "chirlazo": "chir-la-zo",
    "chirle": "chir-le",
    "chirlear": "chir-le-ar",
    "chirlera": "chir-le-ra",
    "chirlería": "chir-le-rí-a",
    "chirlero": "chir-le-ro",
    "chirlido": "chir-li-do",
    "chirlo": "chir-lo",
    "chirlomirlo": "chir-lo-mir-lo",
    "chirmol": "chir-mol",
    "chirmoloso": "chir-mo-lo-so",
    "chirola": "chi-ro-la",
    "chirona": "chi-ro-na",
    "chironda": "chi-ron-da",
    "chiroso": "chi-ro-so",
    "chirote": "chi-ro-te",
    "chirotear": "chi-ro-te-ar",
    "chirpia": "chir-pia",
    "chirpial": "chir-pial",
    "chirraca": "chi-rra-ca",
    "chirre": "chi-rre",
    "chirreador": "chi-rre-a-dor",
    "chirrear": "chi-rre-ar",
    "chirreo": "chi-rre-o",
    "chirriadera": "chi-rria-de-ra",
    "chirriadero": "chi-rria-de-ro",
    "chirriado": "chi-rria-do",
    "chirriador": "chi-rria-dor",
    "chirriante": "chi-rrian-te",
    "chirriar": "chi-rriar",
    "chirrichote": "chi-rri-cho-te",
    "chirrido": "chi-rri-do",
    "chirrión": "chi-rrión",
    "chirrionar": "chi-rrio-nar",
    "chirrionero": "chi-rrio-ne-ro",
    "chirrisco": "chi-rris-co",
    "chirrisquear": "chi-rris-que-ar",
    "chirula": "chi-ru-la",
    "chirulí": "chi-ru-lí",
    "chirumba": "chi-rum-ba",
    "chirumbela": "chi-rum-be-la",
    "chirumen": "chi-ru-men",
    "chirusa": "chi-ru-sa",
    "chiruza": "chi-ru-za",
    "chisa": "chi-sa",
    "chiscar": "chis-car",
    "chiscarra": "chis-ca-rra",
    "chischás": "chis-chás",
    "chischil": "chis-chil",
    "chischís": "chis-chís",
    "chiscón": "chis-cón",
    "chisgarabís": "chis-ga-ra-bís",
    "chisgua": "chis-gua",
    "chisguete": "chis-gue-te",
    "chislama": "chis-la-ma",
    "chisma": "chis-ma",
    "chismar": "chis-mar",
    "chisme": "chis-me",
    "chismear": "chis-me-ar",
    "chismecaliente": "chis-me-ca-lien-te",
    "chismera": "chis-me-ra",
    "chismería": "chis-me-rí-a",
    "chismero": "chis-me-ro",
    "chismiar": "chis-miar",
    "chismografía": "chis-mo-gra-fí-a",
    "chismorrear": "chis-mo-rre-ar",
    "chismorreo": "chis-mo-rre-o",
    "chismorrería": "chis-mo-rre-rí-a",
    "chismosa": "chis-mo-sa",
    "chismosear": "chis-mo-se-ar",
    "chismoso": "chis-mo-so",
    "chismotear": "chis-mo-te-ar",
    "chismoteo": "chis-mo-te-o",
    "chispa": "chis-pa",
    "chispar": "chis-par",
    "chispazo": "chis-pa-zo",
    "chispeado": "chis-pe-a-do",
    "chispeante": "chis-pe-an-te",
    "chispear": "chis-pe-ar",
    "chispero": "chis-pe-ro",
    "chispo": "chis-po",
    "chispoleta": "chis-po-le-ta",
    "chispoleto": "chis-po-le-to",
    "chisporrotear": "chis-po-rro-te-ar",
    "chisporroteo": "chis-po-rro-te-o",
    "chisposa": "chis-po-sa",
    "chisposo": "chis-po-so",
    "chisque": "chis-que",
    "chisquero": "chis-que-ro",
    "chistar": "chis-tar",
    "chistata": "chis-ta-ta",
    "chiste": "chis-te",
    "chistera": "chis-te-ra",
    "chistido": "chis-ti-do",
    "chistorra": "chis-to-rra",
    "chistosa": "chis-to-sa",
    "chistosamente": "chis-to-sa-men-te",
    "chistoso": "chis-to-so",
    "chistu": "chis-tu",
    "chistulari": "chis-tu-la-ri",
    "chita": "chi-ta",
    "chitar": "chi-tar",
    "chite": "chi-te",
    "chiticalla": "chi-ti-ca-lla",
    "chiticallando": "chi-ti-ca-llan-do",
    "chito": "chi-to",
    "chiton": "chi-ton",
    "chitón": "chi-tón",
    "chitreana": "chi-tre-a-na",
    "chitreano": "chi-tre-a-no",
    "chitrula": "chi-tru-la",
    "chitrulo": "chi-tru-lo",
    "chiva": "chi-va",
    "chivada": "chi-va-da",
    "chivado": "chi-va-do",
    "chival": "chi-val",
    "chivar": "chi-var",
    "chivarra": "chi-va-rra",
    "chivarras": "chi-va-rras",
    "chivarro": "chi-va-rro",
    "chivata": "chi-va-ta",
    "chivatada": "chi-va-ta-da",
    "chivatazo": "chi-va-ta-zo",
    "chivatear": "chi-va-te-ar",
    "chivateo": "chi-va-te-o",
    "chivato": "chi-va-to",
    "chivaza": "chi-va-za",
    "chiveada": "chi-ve-a-da",
    "chivear": "chi-ve-ar",
    "chivera": "chi-ve-ra",
    "chivero": "chi-ve-ro",
    "chiveta": "chi-ve-ta",
    "chivetero": "chi-ve-te-ro",
    "chiviar": "chi-viar",
    "chivichana": "chi-vi-cha-na",
    "chiviento": "chi-vien-to",
    "chivillo": "chi-vi-llo",
    "chivirico": "chi-vi-ri-co",
    "chivital": "chi-vi-tal",
    "chivitero": "chi-vi-te-ro",
    "chivitil": "chi-vi-til",
    "chivito": "chi-vi-to",
    "chivo": "chi-vo",
    "chivón": "chi-vón",
    "chivona": "chi-vo-na",
    "chivudo": "chi-vu-do",
    "chiza": "chi-za",
    "choapina": "cho-a-pi-na",
    "choapino": "cho-a-pi-no",
    "choba": "cho-ba",
    "choca": "cho-ca",
    "chocador": "cho-ca-dor",
    "chocadora": "cho-ca-do-ra",
    "chocallera": "cho-ca-lle-ra",
    "chocallero": "cho-ca-lle-ro",
    "chocallo": "cho-ca-llo",
    "chocante": "cho-can-te",
    "chocantería": "cho-can-te-rí-a",
    "chocar": "cho-car",
    "chocarrear": "cho-ca-rre-ar",
    "chocarrera": "cho-ca-rre-ra",
    "chocarrería": "cho-ca-rre-rí-a",
    "chocarrero": "cho-ca-rre-ro",
    "chocha": "cho-cha",
    "chochada": "cho-cha-da",
    "chochaperdiz": "cho-cha-per-diz",
    "chochar": "cho-char",
    "chochear": "cho-che-ar",
    "chochera": "cho-che-ra",
    "chochero": "cho-che-ro",
    "chochez": "cho-chez",
    "chochín": "cho-chín",
    "chocho": "cho-cho",
    "chochocol": "cho-cho-col",
    "choclar": "cho-clar",
    "choclillo": "cho-cli-llo",
    "choclo": "cho-clo",
    "choclón": "cho-clón",
    "choclona": "cho-clo-na",
    "choclonera": "cho-clo-ne-ra",
    "choclonero": "cho-clo-ne-ro",
    "choclotanda": "cho-clo-tan-da",
    "choco": "cho-co",
    "chocó": "cho-có",
    "chocoana": "cho-co-a-na",
    "chocoano": "cho-co-a-no",
    "chocoe": "cho-co-e",
    "chocolatada": "cho-co-la-ta-da",
    "chocolate": "cho-co-la-te",
    "chocolateado": "cho-co-la-te-a-do",
    "chocolatera": "cho-co-la-te-ra",
    "chocolatería": "cho-co-la-te-rí-a",
    "chocolatero": "cho-co-la-te-ro",
    "chocolatín": "cho-co-la-tín",
    "chocolatina": "cho-co-la-ti-na",
    "chocolía": "cho-co-lí-a",
    "chócolo": "chó-co-lo",
    "chocón": "cho-cón",
    "chocona": "cho-co-na",
    "choconoy": "cho-co-noy",
    "chocoso": "cho-co-so",
    "chocoya": "cho-co-ya",
    "chocoyo": "cho-co-yo",
    "chofe": "cho-fe",
    "chofer": "cho-fer",
    "chófer": "chó-fer",
    "choferear": "cho-fe-re-ar",
    "choferesa": "cho-fe-re-sa",
    "chofeta": "cho-fe-ta",
    "chófiro": "chó-fi-ro",
    "chofista": "cho-fis-ta",
    "chojín": "cho-jín",
    "chola": "cho-la",
    "cholco": "chol-co",
    "chole": "cho-le",
    "cholear": "cho-le-ar",
    "cholenco": "cho-len-co",
    "cholera": "cho-le-ra",
    "cholerío": "cho-le-rí-o",
    "cholero": "cho-le-ro",
    "cholga": "chol-ga",
    "cholgua": "chol-gua",
    "cholguán": "chol-guán",
    "cholla": "cho-lla",
    "chollar": "cho-llar",
    "chollo": "cho-llo",
    "chollón": "cho-llón",
    "cholo": "cho-lo",
    "choloque": "cho-lo-que",
    "cholotón": "cho-lo-tón",
    "cholula": "cho-lu-la",
    "cholulo": "cho-lu-lo",
    "cholulteca": "cho-lul-te-ca",
    "cholulteco": "cho-lul-te-co",
    "cholutecana": "cho-lu-te-ca-na",
    "cholutecano": "cho-lu-te-ca-no",
    "chomba": "chom-ba",
    "chombo": "chom-bo",
    "chomite": "cho-mi-te",
    "chompa": "chom-pa",
    "chompapo": "chom-pa-po",
    "chompipe": "chom-pi-pe",
    "chona": "cho-na",
    "choncholí": "chon-cho-lí",
    "chonchón": "chon-chón",
    "chonela": "cho-ne-la",
    "chonete": "cho-ne-te",
    "chonga": "chon-ga",
    "chongo": "chon-go",
    "chonguear": "chon-gue-ar",
    "chonguearse": "chon-gue-ar-se",
    "chonguenga": "chon-guen-ga",
    "chono": "cho-no",
    "chonono": "cho-no-no",
    "chonta": "chon-ta",
    "chontaduro": "chon-ta-du-ro",
    "chontal": "chon-tal",
    "chontaleña": "chon-ta-le-ña",
    "chontaleño": "chon-ta-le-ño",
    "chonte": "chon-te",
    "chopa": "cho-pa",
    "chopal": "cho-pal",
    "chopalera": "cho-pa-le-ra",
    "chopazo": "cho-pa-zo",
    "chope": "cho-pe",
    "chopeadura": "cho-pe-a-du-ra",
    "chopear": "cho-pe-ar",
    "chóped": "chó-ped",
    "chopera": "cho-pe-ra",
    "chopiniano": "cho-pi-nia-no",
    "chopito": "cho-pi-to",
    "chopo": "cho-po",
    "choque": "cho-que",
    "choquezuela": "cho-que-zue-la",
    "chora": "cho-ra",
    "chorar": "cho-rar",
    "chorato": "cho-ra-to",
    "chorba": "chor-ba",
    "chorbo": "chor-bo",
    "chorca": "chor-ca",
    "chorcha": "chor-cha",
    "chorchero": "chor-che-ro",
    "chordón": "chor-dón",
    "choreado": "cho-re-a-do",
    "chorear": "cho-re-ar",
    "choreo": "cho-re-o",
    "choreta": "cho-re-ta",
    "choreto": "cho-re-to",
    "choreza": "cho-re-za",
    "chori": "cho-ri",
    "choricear": "cho-ri-ce-ar",
    "choriceo": "cho-ri-ce-o",
    "choricera": "cho-ri-ce-ra",
    "choricería": "cho-ri-ce-rí-a",
    "choricero": "cho-ri-ce-ro",
    "choripán": "cho-ri-pán",
    "choriza": "cho-ri-za",
    "chorizada": "cho-ri-za-da",
    "chorizar": "cho-ri-zar",
    "chorizo": "cho-ri-zo",
    "chorla": "chor-la",
    "chorlitejo": "chor-li-te-jo",
    "chorlito": "chor-li-to",
    "chorlo": "chor-lo",
    "choro": "cho-ro",
    "chorompo": "cho-rom-po",
    "chorote": "cho-ro-te",
    "chorotega": "cho-ro-te-ga",
    "choroy": "cho-roy",
    "chorpa": "chor-pa",
    "chorra": "cho-rra",
    "chorrada": "cho-rra-da",
    "chorreada": "cho-rre-a-da",
    "chorreado": "cho-rre-a-do",
    "chorreadura": "cho-rre-a-du-ra",
    "chorreante": "cho-rre-an-te",
    "chorrear": "cho-rre-ar",
    "chorreo": "cho-rre-o",
    "chorreón": "cho-rre-ón",
    "chorrera": "cho-rre-ra",
    "chorretada": "cho-rre-ta-da",
    "chorretón": "cho-rre-tón",
    "chorrillo": "cho-rri-llo",
    "chorro": "cho-rro",
    "chorroborro": "cho-rro-bo-rro",
    "chorrocientos": "cho-rro-cien-tos",
    "chorrón": "cho-rrón",
    "chortal": "chor-tal",
    "chortí": "chor-tí",
    "chorva": "chor-va",
    "chorvo": "chor-vo",
    "chospar": "chos-par",
    "chota": "cho-ta",
    "chotacabras": "cho-ta-ca-bras",
    "chotana": "cho-ta-na",
    "chotano": "cho-ta-no",
    "chotar": "cho-tar",
    "chote": "cho-te",
    "choteado": "cho-te-a-do",
    "chotear": "cho-te-ar",
    "choteo": "cho-te-o",
    "chotería": "cho-te-rí-a",
    "chotis": "cho-tis",
    "choto": "cho-to",
    "chotudo": "cho-tu-do",
    "chotuna": "cho-tu-na",
    "chotuno": "cho-tu-no",
    "choucroute": "chou-crou-te",
    "chova": "cho-va",
    "chovinismo": "cho-vi-nis-mo",
    "chovinista": "cho-vi-nis-ta",
    "choya": "cho-ya",
    "choyar": "cho-yar",
    "choyudo": "cho-yu-do",
    "choza": "cho-za",
    "chozna": "choz-na",
    "chozno": "choz-no",
    "chozo": "cho-zo",
    "chozpar": "choz-par",
    "chozpo": "choz-po",
    "chozpón": "choz-pón",
    "chozpona": "choz-po-na",
    "chúa": "chú-a",
    "chuascle": "chuas-cle",
    "chubascada": "chu-bas-ca-da",
    "chubasco": "chu-bas-co",
    "chubasquería": "chu-bas-que-rí-a",
    "chubasquero": "chu-bas-que-ro",
    "chubesqui": "chu-bes-qui",
    "chubutense": "chu-bu-ten-se",
    "chuca": "chu-ca",
    "chucán": "chu-cán",
    "chucana": "chu-ca-na",
    "chucanear": "chu-ca-ne-ar",
    "chucano": "chu-ca-no",
    "chucao": "chu-ca-o",
    "chúcara": "chú-ca-ra",
    "chúcaro": "chú-ca-ro",
    "chucero": "chu-ce-ro",
    "chucha": "chu-cha",
    "chuchanga": "chu-chan-ga",
    "chuchango": "chu-chan-go",
    "chuchar": "chu-char",
    "chuchazo": "chu-cha-zo",
    "chuche": "chu-che",
    "chuchear": "chu-che-ar",
    "chuchera": "chu-che-ra",
    "chuchería": "chu-che-rí-a",
    "chuchero": "chu-che-ro",
    "chuchito": "chu-chi-to",
    "chucho": "chu-cho",
    "chuchoca": "chu-cho-ca",
    "chuchoquear": "chu-cho-que-ar",
    "chuchoqueo": "chu-cho-que-o",
    "chuchoquera": "chu-cho-que-ra",
    "chuchoquero": "chu-cho-que-ro",
    "chuchulmeca": "chu-chul-me-ca",
    "chuchuluco": "chu-chu-lu-co",
    "chuchumeco": "chu-chu-me-co",
    "chuchurrido": "chu-chu-rri-do",
    "chuchurrío": "chu-chu-rrí-o",
    "chucrut": "chu-crut",
    "chucua": "chu-cua",
    "chucuiteña": "chu-cui-te-ña",
    "chucuiteño": "chu-cui-te-ño",
    "chucuri": "chu-cu-ri",
    "chucuta": "chu-cu-ta",
    "chucuto": "chu-cu-to",
    "chueca": "chue-ca",
    "chueco": "chue-co",
    "chuecura": "chue-cu-ra",
    "chuelita": "chue-li-ta",
    "chueta": "chue-ta",
    "chufa": "chu-fa",
    "chufar": "chu-far",
    "chufera": "chu-fe-ra",
    "chufería": "chu-fe-rí-a",
    "chufero": "chu-fe-ro",
    "chufeta": "chu-fe-ta",
    "chufla": "chu-fla",
    "chuflar": "chu-flar",
    "chuflay": "chu-flay",
    "chufleta": "chu-fle-ta",
    "chufletear": "chu-fle-te-ar",
    "chufletera": "chu-fle-te-ra",
    "chufletero": "chu-fle-te-ro",
    "chuflido": "chu-fli-do",
    "chuica": "chui-ca",
    "chuico": "chui-co",
    "chula": "chu-la",
    "chulada": "chu-la-da",
    "chulampín": "chu-lam-pín",
    "chulángano": "chu-lán-ga-no",
    "chulapa": "chu-la-pa",
    "chulapo": "chu-la-po",
    "chulapón": "chu-la-pón",
    "chulapona": "chu-la-po-na",
    "chulé": "chu-lé",
    "chulear": "chu-le-ar",
    "chuleo": "chu-le-o",
    "chulería": "chu-le-rí-a",
    "chulesca": "chu-les-ca",
    "chulescamente": "chu-les-ca-men-te",
    "chulesco": "chu-les-co",
    "chuleta": "chu-le-ta",
    "chuletada": "chu-le-ta-da",
    "chuletón": "chu-le-tón",
    "chuletona": "chu-le-to-na",
    "chulillo": "chu-li-llo",
    "chulla": "chu-lla",
    "chullo": "chu-llo",
    "chullpi": "chull-pi",
    "chullu": "chu-llu",
    "chulo": "chu-lo",
    "chulón": "chu-lón",
    "chulumaneña": "chu-lu-ma-ne-ña",
    "chulumaneño": "chu-lu-ma-ne-ño",
    "chuma": "chu-ma",
    "chumacera": "chu-ma-ce-ra",
    "chumado": "chu-ma-do",
    "chumar": "chu-mar",
    "chumba": "chum-ba",
    "chumbar": "chum-bar",
    "chumbe": "chum-be",
    "chumbera": "chum-be-ra",
    "chumbimba": "chum-bim-ba",
    "chumbimbo": "chum-bim-bo",
    "chumbivilcana": "chum-bi-vil-ca-na",
    "chumbivilcano": "chum-bi-vil-ca-no",
    "chumbo": "chum-bo",
    "chumbón": "chum-bón",
    "chuminada": "chu-mi-na-da",
    "chumino": "chu-mi-no",
    "chumpa": "chum-pa",
    "chumpe": "chum-pe",
    "chumpipe": "chum-pi-pe",
    "chuna": "chu-na",
    "chuña": "chu-ña",
    "chuncha": "chun-cha",
    "chuncho": "chun-cho",
    "chunchoso": "chun-cho-so",
    "chunchucuyo": "chun-chu-cu-yo",
    "chunchules": "chun-chu-les",
    "chunchullo": "chun-chu-llo",
    "chunga": "chun-ga",
    "chungo": "chun-go",
    "chungón": "chun-gón",
    "chungona": "chun-go-na",
    "chunguear": "chun-gue-ar",
    "chungueo": "chun-gue-o",
    "chuño": "chu-ño",
    "chuñusco": "chu-ñus-co",
    "chupa": "chu-pa",
    "chupaca": "chu-pa-ca",
    "chupachús": "chu-pa-chús",
    "chupacirios": "chu-pa-ci-rios",
    "chupaco": "chu-pa-co",
    "chupacobre": "chu-pa-co-bre",
    "chupada": "chu-pa-da",
    "chupadera": "chu-pa-de-ra",
    "chupadero": "chu-pa-de-ro",
    "chupado": "chu-pa-do",
    "chupador": "chu-pa-dor",
    "chupadora": "chu-pa-do-ra",
    "chupadura": "chu-pa-du-ra",
    "chupaflor": "chu-pa-flor",
    "chupalámparas": "chu-pa-lám-pa-ras",
    "chupalandero": "chu-pa-lan-de-ro",
    "chupalla": "chu-pa-lla",
    "chupamedia": "chu-pa-me-dia",
    "chupamedias": "chu-pa-me-dias",
    "chupamirto": "chu-pa-mir-to",
    "chupapiedras": "chu-pa-pie-dras",
    "chupaquina": "chu-pa-qui-na",
    "chupaquino": "chu-pa-qui-no",
    "chupar": "chu-par",
    "chuparrosa": "chu-pa-rro-sa",
    "chupatintas": "chu-pa-tin-tas",
    "chupativa": "chu-pa-ti-va",
    "chupativo": "chu-pa-ti-vo",
    "chupe": "chu-pe",
    "chupé": "chu-pé",
    "chuperretear": "chu-pe-rre-te-ar",
    "chuperreteo": "chu-pe-rre-te-o",
    "chupeta": "chu-pe-ta",
    "chupete": "chu-pe-te",
    "chupetear": "chu-pe-te-ar",
    "chupeteo": "chu-pe-te-o",
    "chupetilla": "chu-pe-ti-lla",
    "chupetín": "chu-pe-tín",
    "chupetón": "chu-pe-tón",
    "chupi": "chu-pi",
    "chupilca": "chu-pil-ca",
    "chupín": "chu-pín",
    "chupinazo": "chu-pi-na-zo",
    "chupinear": "chu-pi-ne-ar",
    "chupino": "chu-pi-no",
    "chupito": "chu-pi-to",
    "chuplús": "chu-plús",
    "chupo": "chu-po",
    "chupón": "chu-pón",
    "chupona": "chu-po-na",
    "chupóptero": "chu-póp-te-ro",
    "chupulún": "chu-pu-lún",
    "chupuste": "chu-pus-te",
    "chuquiragua": "chu-qui-ra-gua",
    "chuquisa": "chu-qui-sa",
    "chuquisaqueña": "chu-qui-sa-que-ña",
    "chuquisaqueño": "chu-qui-sa-que-ño",
    "chura": "chu-ra",
    "churana": "chu-ra-na",
    "churcha": "chur-cha",
    "churco": "chur-co",
    "churdón": "chur-dón",
    "churepo": "chu-re-po",
    "churera": "chu-re-ra",
    "churero": "chu-re-ro",
    "churla": "chur-la",
    "churlenga": "chur-len-ga",
    "churlengo": "chur-len-go",
    "churlo": "chur-lo",
    "churo": "chu-ro",
    "churra": "chu-rra",
    "churrar": "chu-rrar",
    "churrascar": "chu-rras-car",
    "churrasco": "chu-rras-co",
    "churrasquear": "chu-rras-que-ar",
    "churre": "chu-rre",
    "churrera": "chu-rre-ra",
    "churrería": "chu-rre-rí-a",
    "churrero": "chu-rre-ro",
    "churretada": "chu-rre-ta-da",
    "churrete": "chu-rre-te",
    "churretear": "chu-rre-te-ar",
    "churretón": "chu-rre-tón",
    "churretosa": "chu-rre-to-sa",
    "churretoso": "chu-rre-to-so",
    "churri": "chu-rri",
    "churria": "chu-rria",
    "churriana": "chu-rria-na",
    "churriburri": "chu-rri-bu-rri",
    "churrienta": "chu-rrien-ta",
    "churriento": "chu-rrien-to",
    "churrigueresca": "chu-rri-gue-res-ca",
    "churrigueresco": "chu-rri-gue-res-co",
    "churriguerismo": "chu-rri-gue-ris-mo",
    "churriguerista": "chu-rri-gue-ris-ta",
    "churrín": "chu-rrín",
    "churrinche": "chu-rrin-che",
    "churriosa": "chu-rrio-sa",
    "churrioso": "chu-rrio-so",
    "churritar": "chu-rri-tar",
    "churrito": "chu-rri-to",
    "churro": "chu-rro",
    "churrosa": "chu-rro-sa",
    "churroso": "chu-rro-so",
    "churrullera": "chu-rru-lle-ra",
    "churrullero": "chu-rru-lle-ro",
    "churrupear": "chu-rru-pe-ar",
    "churruscar": "chu-rrus-car",
    "churrusco": "chu-rrus-co",
    "churú": "chu-rú",
    "churuata": "chu-rua-ta",
    "churuco": "chu-ru-co",
    "churumba": "chu-rum-ba",
    "churumbel": "chu-rum-bel",
    "churumbela": "chu-rum-be-la",
    "churumen": "chu-ru-men",
    "churumo": "chu-ru-mo",
    "churuncullo": "chu-run-cu-llo",
    "churupo": "chu-ru-po",
    "churute": "chu-ru-te",
    "chusbarba": "chus-bar-ba",
    "chusca": "chus-ca",
    "chuscada": "chus-ca-da",
    "chuscamente": "chus-ca-men-te",
    "chusco": "chus-co",
    "chusema": "chu-se-ma",
    "chusma": "chus-ma",
    "chusmaje": "chus-ma-je",
    "chusmear": "chus-me-ar",
    "chusmerío": "chus-me-rí-o",
    "chuspa": "chus-pa",
    "chusque": "chus-que",
    "chusquel": "chus-quel",
    "chusquera": "chus-que-ra",
    "chusquero": "chus-que-ro",
    "chuta": "chu-ta",
    "chutar": "chu-tar",
    "chute": "chu-te",
    "chuto": "chu-to",
    "chuva": "chu-va",
    "chuyo": "chu-yo",
    "chuza": "chu-za",
    "chuzar": "chu-zar",
    "chuzazo": "chu-za-zo",
    "chuznieta": "chuz-nie-ta",
    "chuznieto": "chuz-nie-to",
    "chuzo": "chu-zo",
    "chuzón": "chu-zón",
    "chuzona": "chu-zo-na",
    "chuzonada": "chu-zo-na-da",
    "chuzonería": "chu-zo-ne-rí-a",
    "cía": "cí-a",
    "ciaboga": "cia-bo-ga",
    "ciabogar": "cia-bo-gar",
    "cianato": "cia-na-to",
    "cianea": "cia-ne-a",
    "cianhídrico": "cian-hí-dri-co",
    "cianí": "cia-ní",
    "ciánica": "ciá-ni-ca",
    "ciánico": "ciá-ni-co",
    "cianita": "cia-ni-ta",
    "cianobacterias": "cia-no-bac-te-rias",
    "cianógeno": "cia-nó-ge-no",
    "cianosis": "cia-no-sis",
    "cianótica": "cia-nó-ti-ca",
    "cianótico": "cia-nó-ti-co",
    "cianuro": "cia-nu-ro",
    "ciática": "ciá-ti-ca",
    "ciático": "ciá-ti-co",
    "ciato": "cia-to",
    "cibaeña": "ci-ba-e-ña",
    "cibaeño": "ci-ba-e-ño",
    "cibaje": "ci-ba-je",
    "cibal": "ci-bal",
    "cibarcos": "ci-bar-cos",
    "cibaria": "ci-ba-ria",
    "cibario": "ci-ba-rio",
    "cibdad": "cib-dad",
    "cibdadano": "cib-da-da-no",
    "cibelea": "ci-be-le-a",
    "cibeleo": "ci-be-le-o",
    "cibelina": "ci-be-li-na",
    "cibera": "ci-be-ra",
    "cibercultura": "ci-ber-cul-tu-ra",
    "ciberespacio": "ci-be-res-pa-cio",
    "cibernauta": "ci-ber-nau-ta",
    "cibernética": "ci-ber-né-ti-ca",
    "cibernético": "ci-ber-né-ti-co",
    "ciberusuaria": "ci-be-ru-sua-ria",
    "ciberusuario": "ci-be-ru-sua-rio",
    "cibi": "ci-bi",
    "cibiaca": "ci-bia-ca",
    "cibica": "ci-bi-ca",
    "cibicón": "ci-bi-cón",
    "cibo": "ci-bo",
    "cíbola": "cí-bo-la",
    "cíbolo": "cí-bo-lo",
    "ciborg": "ci-borg",
    "ciborio": "ci-bo-rio",
    "cibucán": "ci-bu-cán",
    "cica": "ci-ca",
    "cicadácea": "ci-ca-dá-ce-a",
    "cicadáceas": "ci-ca-dá-ce-as",
    "cicadáceo": "ci-ca-dá-ce-o",
    "cicádea": "ci-cá-de-a",
    "cicádeo": "ci-cá-de-o",
    "cicádido": "ci-cá-di-do",
    "cicahuite": "ci-ca-hui-te",
    "cicalar": "ci-ca-lar",
    "cicatear": "ci-ca-te-ar",
    "cicatera": "ci-ca-te-ra",
    "cicateramente": "ci-ca-te-ra-men-te",
    "cicatería": "ci-ca-te-rí-a",
    "cicatero": "ci-ca-te-ro",
    "cicatricial": "ci-ca-tri-cial",
    "cicatriz": "ci-ca-triz",
    "cicatrización": "ci-ca-tri-za-ción",
    "cicatrizal": "ci-ca-tri-zal",
    "cicatrizante": "ci-ca-tri-zan-te",
    "cicatrizar": "ci-ca-tri-zar",
    "cicatrizativa": "ci-ca-tri-za-ti-va",
    "cicatrizativo": "ci-ca-tri-za-ti-vo",
    "cicca": "cic-ca",
    "cícera": "cí-ce-ra",
    "cicercha": "ci-cer-cha",
    "cicércula": "ci-cér-cu-la",
    "cícero": "cí-ce-ro",
    "cicerón": "ci-ce-rón",
    "cicerona": "ci-ce-ro-na",
    "cicerone": "ci-ce-ro-ne",
    "ciceroniana": "ci-ce-ro-nia-na",
    "ciceroniano": "ci-ce-ro-nia-no",
    "cicimite": "ci-ci-mi-te",
    "cicindela": "ci-cin-de-la",
    "cicindélido": "ci-cin-dé-li-do",
    "cición": "ci-ción",
    "ciclada": "ci-cla-da",
    "ciclamen": "ci-cla-men",
    "ciclamino": "ci-cla-mi-no",
    "ciclamor": "ci-cla-mor",
    "ciclán": "ci-clán",
    "ciclar": "ci-clar",
    "ciclatón": "ci-cla-tón",
    "cíclica": "cí-cli-ca",
    "cíclicamente": "cí-cli-ca-men-te",
    "cíclico": "cí-cli-co",
    "cíclido": "cí-cli-do",
    "ciclismo": "ci-clis-mo",
    "ciclista": "ci-clis-ta",
    "ciclístico": "ci-clís-ti-co",
    "ciclo": "ci-clo",
    "ciclohexano": "ci-clo-he-xa-no",
    "cicloidal": "ci-cloi-dal",
    "cicloide": "ci-cloi-de",
    "cicloidea": "ci-cloi-de-a",
    "cicloideo": "ci-cloi-de-o",
    "ciclomotor": "ci-clo-mo-tor",
    "ciclón": "ci-clón",
    "ciclonal": "ci-clo-nal",
    "ciclónica": "ci-cló-ni-ca",
    "ciclónico": "ci-cló-ni-co",
    "cíclope": "cí-clo-pe",
    "ciclópeo": "ci-cló-pe-o",
    "ciclópica": "ci-cló-pi-ca",
    "ciclópico": "ci-cló-pi-co",
    "ciclóptero": "ci-clóp-te-ro",
    "ciclorama": "ci-clo-ra-ma",
    "ciclostil": "ci-clos-til",
    "ciclostilo": "ci-clos-ti-lo",
    "ciclóstoma": "ci-clós-to-ma",
    "ciclóstomo": "ci-clós-to-mo",
    "ciclotimia": "ci-clo-ti-mia",
    "ciclotímica": "ci-clo-tí-mi-ca",
    "ciclotímico": "ci-clo-tí-mi-co",
    "ciclotrón": "ci-clo-trón",
    "cicloturismo": "ci-clo-tu-ris-mo",
    "cicloturista": "ci-clo-tu-ris-ta",
    "cicloturístico": "ci-clo-tu-rís-ti-co",
    "ciconiforme": "ci-co-ni-for-me",
    "cicoria": "ci-co-ria",
    "cicunscripto": "ci-cuns-crip-to",
    "cicuta": "ci-cu-ta",
    "cicutina": "ci-cu-ti-na",
    "cidiana": "ci-dia-na",
    "cidiano": "ci-dia-no",
    "cidra": "ci-dra",
    "cidrada": "ci-dra-da",
    "cidral": "ci-dral",
    "cidrayota": "ci-dra-yo-ta",
    "cidrera": "ci-dre-ra",
    "cidria": "ci-dria",
    "cidro": "ci-dro",
    "cidronela": "ci-dro-ne-la",
    "cieca": "cie-ca",
    "ciega": "cie-ga",
    "ciegamente": "cie-ga-men-te",
    "ciegayernos": "cie-ga-yer-nos",
    "ciego": "cie-go",
    "cielito": "cie-li-to",
    "cielo": "cie-lo",
    "cielorraso": "cie-lo-rra-so",
    "ciemo": "cie-mo",
    "ciempiés": "ciem-piés",
    "ciénaga": "cié-na-ga",
    "ciénago": "cié-na-go",
    "ciencia": "cien-cia",
    "cienciología": "cien-cio-lo-gí-a",
    "ciénega": "cié-ne-ga",
    "ciénego": "cié-ne-go",
    "cienfueguera": "cien-fue-gue-ra",
    "cienfueguero": "cien-fue-gue-ro",
    "cienmilésima": "cien-mi-lé-si-ma",
    "cienmilésimo": "cien-mi-lé-si-mo",
    "cienmilímetro": "cien-mi-lí-me-tro",
    "cienmillonésima": "cien-mi-llo-né-si-ma",
    "cienmillonésimo": "cien-mi-llo-né-si-mo",
    "cienmilmillonésima": "cien-mil-mi-llo-né-si-ma",
    "cienmilmillonésimo": "cien-mil-mi-llo-né-si-mo",
    "cieno": "cie-no",
    "cienosa": "cie-no-sa",
    "cienoso": "cie-no-so",
    "ciensayos": "cien-sa-yos",
    "cientanal": "cien-ta-nal",
    "ciente": "cien-te",
    "científica": "cien-tí-fi-ca",
    "científicamente": "cien-tí-fi-ca-men-te",
    "cientificidad": "cien-ti-fi-ci-dad",
    "cientificismo": "cien-ti-fi-cis-mo",
    "cientificista": "cien-ti-fi-cis-ta",
    "científico": "cien-tí-fi-co",
    "cientifismo": "cien-ti-fis-mo",
    "ciento": "cien-to",
    "cientopiés": "cien-to-piés",
    "cierna": "cier-na",
    "cierne": "cier-ne",
    "cierrapuertas": "cie-rra-puer-tas",
    "cierre": "cie-rre",
    "cierro": "cie-rro",
    "cierta": "cier-ta",
    "ciertamente": "cier-ta-men-te",
    "cierto": "cier-to",
    "cierva": "cier-va",
    "ciervo": "cier-vo",
    "cierzas": "cier-zas",
    "cierzo": "cier-zo",
    "cifaque": "ci-fa-que",
    "cifela": "ci-fe-la",
    "cifosis": "ci-fo-sis",
    "cifra": "ci-fra",
    "cifrada": "ci-fra-da",
    "cifradamente": "ci-fra-da-men-te",
    "cifrado": "ci-fra-do",
    "cifrar": "ci-frar",
    "cigala": "ci-ga-la",
    "cigallo": "ci-ga-llo",
    "cigarra": "ci-ga-rra",
    "cigarral": "ci-ga-rral",
    "cigarralera": "ci-ga-rra-le-ra",
    "cigarralero": "ci-ga-rra-le-ro",
    "cigarrera": "ci-ga-rre-ra",
    "cigarrería": "ci-ga-rre-rí-a",
    "cigarrero": "ci-ga-rre-ro",
    "cigarrillo": "ci-ga-rri-llo",
    "cigarro": "ci-ga-rro",
    "cigarrón": "ci-ga-rrón",
    "cigofilácea": "ci-go-fi-lá-ce-a",
    "cigofiláceo": "ci-go-fi-lá-ce-o",
    "cigofílea": "ci-go-fí-le-a",
    "cigofíleo": "ci-go-fí-le-o",
    "cigomática": "ci-go-má-ti-ca",
    "cigomático": "ci-go-má-ti-co",
    "cigomorfo": "ci-go-mor-fo",
    "cigoñal": "ci-go-ñal",
    "cigoñino": "ci-go-ñi-no",
    "cigoñuela": "ci-go-ñue-la",
    "cigoto": "ci-go-to",
    "cigua": "ci-gua",
    "ciguanaba": "ci-gua-na-ba",
    "ciguapa": "ci-gua-pa",
    "ciguapate": "ci-gua-pa-te",
    "ciguaraya": "ci-gua-ra-ya",
    "ciguata": "ci-gua-ta",
    "ciguatar": "ci-gua-tar",
    "ciguatarse": "ci-gua-tar-se",
    "ciguatera": "ci-gua-te-ra",
    "ciguato": "ci-gua-to",
    "cigüeña": "ci-güe-ña",
    "cigüeñal": "ci-güe-ñal",
    "cigüeñato": "ci-güe-ña-to",
    "cigüeño": "ci-güe-ño",
    "cigüeñuela": "ci-güe-ñue-la",
    "cigüete": "ci-güe-te",
    "cija": "ci-ja",
    "cilampa": "ci-lam-pa",
    "cilanco": "ci-lan-co",
    "cilantro": "ci-lan-tro",
    "cilbiceno": "cil-bi-ce-no",
    "ciliada": "ci-lia-da",
    "ciliado": "ci-lia-do",
    "ciliar": "ci-liar",
    "cilicio": "ci-li-cio",
    "cilindrada": "ci-lin-dra-da",
    "cilindrado": "ci-lin-dra-do",
    "cilindradora": "ci-lin-dra-do-ra",
    "cilindrar": "ci-lin-drar",
    "cilíndrica": "ci-lín-dri-ca",
    "cilíndrico": "ci-lín-dri-co",
    "cilindro": "ci-lin-dro",
    "cilindroeje": "ci-lin-dro-e-je",
    "cilio": "ci-lio",
    "cilla": "ci-lla",
    "cillazgo": "ci-llaz-go",
    "cillerero": "ci-lle-re-ro",
    "cillería": "ci-lle-rí-a",
    "cilleriza": "ci-lle-ri-za",
    "cillerizo": "ci-lle-ri-zo",
    "cillero": "ci-lle-ro",
    "cima": "ci-ma",
    "cimacio": "ci-ma-cio",
    "cimar": "ci-mar",
    "cimarra": "ci-ma-rra",
    "cimarrero": "ci-ma-rre-ro",
    "cimarrón": "ci-ma-rrón",
    "cimarrona": "ci-ma-rro-na",
    "cimarronada": "ci-ma-rro-na-da",
    "cimate": "ci-ma-te",
    "cimba": "cim-ba",
    "cimbado": "cim-ba-do",
    "cimbalaria": "cim-ba-la-ria",
    "cimbalera": "cim-ba-le-ra",
    "cimbalero": "cim-ba-le-ro",
    "cimbalillo": "cim-ba-li-llo",
    "cimbalista": "cim-ba-lis-ta",
    "címbalo": "cím-ba-lo",
    "cimbanillo": "cim-ba-ni-llo",
    "címbara": "cím-ba-ra",
    "cimbel": "cim-bel",
    "cimblar": "cim-blar",
    "cimboga": "cim-bo-ga",
    "cimborio": "cim-bo-rio",
    "cimborrio": "cim-bo-rrio",
    "cimbra": "cim-bra",
    "cimbrado": "cim-bra-do",
    "cimbrador": "cim-bra-dor",
    "cimbrar": "cim-brar",
    "cimbre": "cim-bre",
    "cimbreante": "cim-bre-an-te",
    "cimbrear": "cim-bre-ar",
    "cimbreña": "cim-bre-ña",
    "cimbreño": "cim-bre-ño",
    "cimbreo": "cim-bre-o",
    "cimbria": "cim-bria",
    "címbrica": "cím-bri-ca",
    "címbrico": "cím-bri-co",
    "cimbrio": "cim-brio",
    "cimbro": "cim-bro",
    "cimbrón": "cim-brón",
    "cimbronazo": "cim-bro-na-zo",
    "cimentación": "ci-men-ta-ción",
    "cimentado": "ci-men-ta-do",
    "cimentador": "ci-men-ta-dor",
    "cimentadora": "ci-men-ta-do-ra",
    "cimental": "ci-men-tal",
    "cimentar": "ci-men-tar",
    "cimentera": "ci-men-te-ra",
    "cimenterio": "ci-men-te-rio",
    "cimento": "ci-men-to",
    "cimera": "ci-me-ra",
    "cimeria": "ci-me-ria",
    "cimerio": "ci-me-rio",
    "cimero": "ci-me-ro",
    "cimia": "ci-mia",
    "cimicaria": "ci-mi-ca-ria",
    "cimiento": "ci-mien-to",
    "cimillo": "ci-mi-llo",
    "cimitarra": "ci-mi-ta-rra",
    "cimofana": "ci-mo-fa-na",
    "cimorro": "ci-mo-rro",
    "cimpa": "cim-pa",
    "cina": "ci-na",
    "cinabrio": "ci-na-brio",
    "cinacina": "ci-na-ci-na",
    "cinámica": "ci-ná-mi-ca",
    "cinámico": "ci-ná-mi-co",
    "cinamomo": "ci-na-mo-mo",
    "cinarra": "ci-na-rra",
    "cinca": "cin-ca",
    "cincado": "cin-ca-do",
    "cincel": "cin-cel",
    "cincelado": "cin-ce-la-do",
    "cincelador": "cin-ce-la-dor",
    "cinceladora": "cin-ce-la-do-ra",
    "cinceladura": "cin-ce-la-du-ra",
    "cincelar": "cin-ce-lar",
    "cincha": "cin-cha",
    "cinchacear": "cin-cha-ce-ar",
    "cinchado": "cin-cha-do",
    "cinchadura": "cin-cha-du-ra",
    "cinchar": "cin-char",
    "cinchazo": "cin-cha-zo",
    "cinchera": "cin-che-ra",
    "cincho": "cin-cho",
    "cinchón": "cin-chón",
    "cinchonazo": "cin-cho-na-zo",
    "cinchonear": "cin-cho-ne-ar",
    "cinchuela": "cin-chue-la",
    "cinchuelo": "cin-chue-lo",
    "cinco": "cin-co",
    "cincoañal": "cin-co-a-ñal",
    "cincoenrama": "cin-co-en-ra-ma",
    "cincograbado": "cin-co-gra-ba-do",
    "cincografía": "cin-co-gra-fí-a",
    "cincomesina": "cin-co-me-si-na",
    "cincomesino": "cin-co-me-si-no",
    "cinconegritos": "cin-co-ne-gri-tos",
    "cincuenta": "cin-cuen-ta",
    "cincuentaina": "cin-cuen-tai-na",
    "cincuentañal": "cin-cuen-ta-ñal",
    "cincuentava": "cin-cuen-ta-va",
    "cincuentavo": "cin-cuen-ta-vo",
    "cincuentén": "cin-cuen-tén",
    "cincuentena": "cin-cuen-te-na",
    "cincuentenaria": "cin-cuen-te-na-ria",
    "cincuentenario": "cin-cuen-te-na-rio",
    "cincuenteno": "cin-cuen-te-no",
    "cincuentín": "cin-cuen-tín",
    "cincuentón": "cin-cuen-tón",
    "cincuentona": "cin-cuen-to-na",
    "cincuesma": "cin-cues-ma",
    "cine": "ci-ne",
    "cineasta": "ci-ne-as-ta",
    "cineclub": "ci-ne-club",
    "cinéfila": "ci-né-fi-la",
    "cinefilia": "ci-ne-fi-lia",
    "cinéfilo": "ci-né-fi-lo",
    "cinefórum": "ci-ne-fó-rum",
    "cinegética": "ci-ne-gé-ti-ca",
    "cinegético": "ci-ne-gé-ti-co",
    "cinema": "ci-ne-ma",
    "cinemascope": "ci-ne-mas-co-pe",
    "cinemateca": "ci-ne-ma-te-ca",
    "cinemática": "ci-ne-má-ti-ca",
    "cinemático": "ci-ne-má-ti-co",
    "cinematografía": "ci-ne-ma-to-gra-fí-a",
    "cinematografiar": "ci-ne-ma-to-gra-fiar",
    "cinematográfica": "ci-ne-ma-to-grá-fi-ca",
    "cinematográficamente": "ci-ne-ma-to-grá-fi-ca-men-te",
    "cinematográfico": "ci-ne-ma-to-grá-fi-co",
    "cinematografista": "ci-ne-ma-to-gra-fis-ta",
    "cinematógrafo": "ci-ne-ma-tó-gra-fo",
    "cinemómetro": "ci-ne-mó-me-tro",
    "cineración": "ci-ne-ra-ción",
    "cinerama": "ci-ne-ra-ma",
    "cineraria": "ci-ne-ra-ria",
    "cinerario": "ci-ne-ra-rio",
    "cinérea": "ci-né-re-a",
    "cinéreo": "ci-né-re-o",
    "cinericia": "ci-ne-ri-cia",
    "cinericio": "ci-ne-ri-cio",
    "cinésica": "ci-né-si-ca",
    "cinésico": "ci-né-si-co",
    "cinesiología": "ci-ne-sio-lo-gí-a",
    "cinesiterapia": "ci-ne-si-te-ra-pia",
    "cinestesia": "ci-nes-te-sia",
    "cineteca": "ci-ne-te-ca",
    "cinética": "ci-né-ti-ca",
    "cinético": "ci-né-ti-co",
    "cingalés": "cin-ga-lés",
    "cingalesa": "cin-ga-le-sa",
    "cíngara": "cín-ga-ra",
    "cíngaro": "cín-ga-ro",
    "cingiberácea": "cin-gi-be-rá-ce-a",
    "cingiberáceas": "cin-gi-be-rá-ce-as",
    "cingiberáceo": "cin-gi-be-rá-ce-o",
    "cinglado": "cin-gla-do",
    "cinglar": "cin-glar",
    "cingleta": "cin-gle-ta",
    "cíngulo": "cín-gu-lo",
    "cinia": "ci-nia",
    "cínica": "cí-ni-ca",
    "cínicamente": "cí-ni-ca-men-te",
    "cínico": "cí-ni-co",
    "cínife": "cí-ni-fe",
    "cinípedo": "ci-ní-pe-do",
    "cinismo": "ci-nis-mo",
    "cinocéfalo": "ci-no-cé-fa-lo",
    "cinoglosa": "ci-no-glo-sa",
    "cinquecento": "cin-que-cen-to",
    "cinquén": "cin-quén",
    "cinquena": "cin-que-na",
    "cinqueña": "cin-que-ña",
    "cinqueno": "cin-que-no",
    "cinqueño": "cin-que-ño",
    "cinquero": "cin-que-ro",
    "cinquillo": "cin-qui-llo",
    "cinquina": "cin-qui-na",
    "cinquino": "cin-qui-no",
    "cinta": "cin-ta",
    "cintadero": "cin-ta-de-ro",
    "cintagorda": "cin-ta-gor-da",
    "cintajo": "cin-ta-jo",
    "cintar": "cin-tar",
    "cintarazo": "cin-ta-ra-zo",
    "cintarear": "cin-ta-re-ar",
    "cinteada": "cin-te-a-da",
    "cinteado": "cin-te-a-do",
    "cintera": "cin-te-ra",
    "cintería": "cin-te-rí-a",
    "cintero": "cin-te-ro",
    "cinteta": "cin-te-ta",
    "cintilar": "cin-ti-lar",
    "cintillo": "cin-ti-llo",
    "cinto": "cin-to",
    "cintra": "cin-tra",
    "cintrada": "cin-tra-da",
    "cintrado": "cin-tra-do",
    "cintrel": "cin-trel",
    "cintroniguera": "cin-tro-ni-gue-ra",
    "cintroniguero": "cin-tro-ni-gue-ro",
    "cintura": "cin-tu-ra",
    "cinturica": "cin-tu-ri-ca",
    "cinturilla": "cin-tu-ri-lla",
    "cinturita": "cin-tu-ri-ta",
    "cinturón": "cin-tu-rón",
    "ciñuela": "ci-ñue-la",
    "cinzaya": "cin-za-ya",
    "cinzolín": "cin-zo-lín",
    "cío": "cí-o",
    "cipariso": "ci-pa-ri-so",
    "cipayo": "ci-pa-yo",
    "cipe": "ci-pe",
    "cipera": "ci-pe-ra",
    "ciperácea": "ci-pe-rá-ce-a",
    "ciperáceo": "ci-pe-rá-ce-o",
    "cipión": "ci-pión",
    "cipo": "ci-po",
    "cipolina": "ci-po-li-na",
    "cipolino": "ci-po-li-no",
    "cipota": "ci-po-ta",
    "cipotada": "ci-po-ta-da",
    "cipotazo": "ci-po-ta-zo",
    "cipote": "ci-po-te",
    "cipotero": "ci-po-te-ro",
    "cipotón": "ci-po-tón",
    "cipotona": "ci-po-to-na",
    "ciprés": "ci-prés",
    "cipresal": "ci-pre-sal",
    "cipresillo": "ci-pre-si-llo",
    "cipresina": "ci-pre-si-na",
    "cipresino": "ci-pre-si-no",
    "cipria": "ci-pria",
    "cíprico": "cí-pri-co",
    "ciprina": "ci-pri-na",
    "ciprínido": "ci-prí-ni-do",
    "ciprino": "ci-pri-no",
    "ciprinodóntido": "ci-pri-no-dón-ti-do",
    "ciprio": "ci-prio",
    "cipriota": "ci-prio-ta",
    "ciquibaile": "ci-qui-bai-le",
    "ciquiricata": "ci-qui-ri-ca-ta",
    "ciquitraque": "ci-qui-tra-que",
    "ciquitroque": "ci-qui-tro-que",
    "cirate": "ci-ra-te",
    "circa": "cir-ca",
    "circadiano": "cir-ca-dia-no",
    "circasiana": "cir-ca-sia-na",
    "circasiano": "cir-ca-sia-no",
    "circe": "cir-ce",
    "circense": "cir-cen-se",
    "circo": "cir-co",
    "circón": "cir-cón",
    "circona": "cir-co-na",
    "circonio": "cir-co-nio",
    "circonita": "cir-co-ni-ta",
    "circuición": "cir-cui-ción",
    "circuir": "cir-cuir",
    "circuito": "cir-cui-to",
    "circulación": "cir-cu-la-ción",
    "circulante": "cir-cu-lan-te",
    "circular": "cir-cu-lar",
    "circularidad": "cir-cu-la-ri-dad",
    "circularmente": "cir-cu-lar-men-te",
    "circulatoria": "cir-cu-la-to-ria",
    "circulatorio": "cir-cu-la-to-rio",
    "círculo": "cír-cu-lo",
    "circumcirca": "cir-cum-cir-ca",
    "circumincesión": "cir-cu-min-ce-sión",
    "circumpolar": "cir-cum-po-lar",
    "circun": "cir-cun",
    "circuncidar": "cir-cun-ci-dar",
    "circuncisa": "cir-cun-ci-sa",
    "circuncisión": "cir-cun-ci-sión",
    "circunciso": "cir-cun-ci-so",
    "circundante": "cir-cun-dan-te",
    "circundar": "cir-cun-dar",
    "circunferencia": "cir-cun-fe-ren-cia",
    "circunferencial": "cir-cun-fe-ren-cial",
    "circunferencialmente": "cir-cun-fe-ren-cial-men-te",
    "circunferente": "cir-cun-fe-ren-te",
    "circunferir": "cir-cun-fe-rir",
    "circunflejo": "cir-cun-fle-jo",
    "circunfusa": "cir-cun-fu-sa",
    "circunfuso": "cir-cun-fu-so",
    "circunlocución": "cir-cun-lo-cu-ción",
    "circunloquio": "cir-cun-lo-quio",
    "circunnavegación": "cir-cun-na-ve-ga-ción",
    "circunnavegar": "cir-cun-na-ve-gar",
    "circunscribir": "cir-cuns-cri-bir",
    "circunscripción": "cir-cuns-crip-ción",
    "circunscripta": "cir-cuns-crip-ta",
    "circunscripto": "cir-cuns-crip-to",
    "circunscrita": "cir-cuns-cri-ta",
    "circunscrito": "cir-cuns-cri-to",
    "circunsolar": "cir-cun-so-lar",
    "circunspección": "cir-cuns-pec-ción",
    "circunspecta": "cir-cuns-pec-ta",
    "circunspectamente": "cir-cuns-pec-ta-men-te",
    "circunspecto": "cir-cuns-pec-to",
    "circunstancia": "cir-cuns-tan-cia",
    "circunstanciada": "cir-cuns-tan-cia-da",
    "circunstanciadamente": "cir-cuns-tan-cia-da-men-te",
    "circunstanciado": "cir-cuns-tan-cia-do",
    "circunstancial": "cir-cuns-tan-cial",
    "circunstancialmente": "cir-cuns-tan-cial-men-te",
    "circunstanciar": "cir-cuns-tan-ciar",
    "circunstante": "cir-cuns-tan-te",
    "circunvalación": "cir-cun-va-la-ción",
    "circunvalar": "cir-cun-va-lar",
    "circunvecina": "cir-cun-ve-ci-na",
    "circunvecino": "cir-cun-ve-ci-no",
    "circunvenir": "cir-cun-ve-nir",
    "circunvolar": "cir-cun-vo-lar",
    "circunvolución": "cir-cun-vo-lu-ción",
    "circunyacente": "cir-cun-ya-cen-te",
    "cirenaica": "ci-re-nai-ca",
    "cirenaico": "ci-re-nai-co",
    "cirenea": "ci-re-ne-a",
    "cireneo": "ci-re-ne-o",
    "cirial": "ci-rial",
    "cirigalla": "ci-ri-ga-lla",
    "cirigallo": "ci-ri-ga-llo",
    "cirigaña": "ci-ri-ga-ña",
    "cirílico": "ci-rí-li-co",
    "cirinea": "ci-ri-ne-a",
    "cirineo": "ci-ri-ne-o",
    "cirio": "ci-rio",
    "cirolero": "ci-ro-le-ro",
    "cirquera": "cir-que-ra",
    "cirquero": "cir-que-ro",
    "cirrípedo": "ci-rrí-pe-do",
    "cirro": "ci-rro",
    "cirrocúmulo": "ci-rro-cú-mu-lo",
    "cirrópodo": "ci-rró-po-do",
    "cirrosa": "ci-rro-sa",
    "cirrosis": "ci-rro-sis",
    "cirroso": "ci-rro-so",
    "cirrostrato": "ci-rros-tra-to",
    "cirrótica": "ci-rró-ti-ca",
    "cirrótico": "ci-rró-ti-co",
    "ciruela": "ci-rue-la",
    "ciruelillo": "ci-rue-li-llo",
    "ciruelo": "ci-rue-lo",
    "cirugía": "ci-ru-gí-a",
    "ciruja": "ci-ru-ja",
    "cirujana": "ci-ru-ja-na",
    "cirujano": "ci-ru-ja-no",
    "cirujear": "ci-ru-je-ar",
    "cisalpina": "ci-sal-pi-na",
    "cisalpino": "ci-sal-pi-no",
    "cisandina": "ci-san-di-na",
    "cisandino": "ci-san-di-no",
    "cisca": "cis-ca",
    "ciscar": "cis-car",
    "cisco": "cis-co",
    "ciscón": "cis-cón",
    "cisión": "ci-sión",
    "cisípedo": "ci-sí-pe-do",
    "cisma": "cis-ma",
    "cismar": "cis-mar",
    "cismática": "cis-má-ti-ca",
    "cismáticamente": "cis-má-ti-ca-men-te",
    "cismático": "cis-má-ti-co",
    "cismontana": "cis-mon-ta-na",
    "cismontano": "cis-mon-ta-no",
    "cisne": "cis-ne",
    "cisneriense": "cis-ne-rien-se",
    "cisoria": "ci-so-ria",
    "cispadana": "cis-pa-da-na",
    "cispadano": "cis-pa-da-no",
    "cisquera": "cis-que-ra",
    "cisquero": "cis-que-ro",
    "cista": "cis-ta",
    "cistácea": "cis-tá-ce-a",
    "cistáceo": "cis-tá-ce-o",
    "cisterciense": "cis-ter-cien-se",
    "cisterna": "cis-ter-na",
    "cisticerco": "cis-ti-cer-co",
    "cisticercosis": "cis-ti-cer-co-sis",
    "cístico": "cís-ti-co",
    "cistina": "cis-ti-na",
    "cistínea": "cis-tí-ne-a",
    "cistíneo": "cis-tí-ne-o",
    "cistitis": "cis-ti-tis",
    "cistoscopia": "cis-tos-co-pia",
    "cistoscopio": "cis-tos-co-pio",
    "cistotomía": "cis-to-to-mí-a",
    "cisura": "ci-su-ra",
    "cita": "ci-ta",
    "citación": "ci-ta-ción",
    "citadina": "ci-ta-di-na",
    "citadino": "ci-ta-di-no",
    "citador": "ci-ta-dor",
    "citadora": "ci-ta-do-ra",
    "citana": "ci-ta-na",
    "citania": "ci-ta-nia",
    "citano": "ci-ta-no",
    "citar": "ci-tar",
    "citara": "ci-ta-ra",
    "cítara": "cí-ta-ra",
    "citaredo": "ci-ta-re-do",
    "citarilla": "ci-ta-ri-lla",
    "citarista": "ci-ta-ris-ta",
    "citarizar": "ci-ta-ri-zar",
    "citarón": "ci-ta-rón",
    "citatoria": "ci-ta-to-ria",
    "citatorio": "ci-ta-to-rio",
    "citerea": "ci-te-re-a",
    "citereo": "ci-te-re-o",
    "citerior": "ci-te-rior",
    "cítiso": "cí-ti-so",
    "cito": "ci-to",
    "citocinesis": "ci-to-ci-ne-sis",
    "citocromo": "ci-to-cro-mo",
    "citodiagnosis": "ci-to-diag-no-sis",
    "citodiagnóstico": "ci-to-diag-nós-ti-co",
    "citófono": "ci-tó-fo-no",
    "citogenética": "ci-to-ge-né-ti-ca",
    "cítola": "cí-to-la",
    "citóloga": "ci-tó-lo-ga",
    "citología": "ci-to-lo-gí-a",
    "citólogo": "ci-tó-lo-go",
    "citoplasma": "ci-to-plas-ma",
    "citoplasmático": "ci-to-plas-má-ti-co",
    "citoplásmico": "ci-to-plás-mi-co",
    "citoquina": "ci-to-qui-na",
    "cítora": "cí-to-ra",
    "citosina": "ci-to-si-na",
    "citostático": "ci-tos-tá-ti-co",
    "citostoma": "ci-tos-to-ma",
    "citote": "ci-to-te",
    "citotóxico": "ci-to-tó-xi-co",
    "citra": "ci-tra",
    "citramontana": "ci-tra-mon-ta-na",
    "citramontano": "ci-tra-mon-ta-no",
    "citrato": "ci-tra-to",
    "cítrica": "cí-tri-ca",
    "cítrico": "cí-tri-co",
    "citrícola": "ci-trí-co-la",
    "citricultura": "ci-tri-cul-tu-ra",
    "citrina": "ci-tri-na",
    "citrino": "ci-tri-no",
    "citrón": "ci-trón",
    "citrus": "ci-trus",
    "ciudad": "ciu-dad",
    "ciudadana": "ciu-da-da-na",
    "ciudadanía": "ciu-da-da-ní-a",
    "ciudadano": "ciu-da-da-no",
    "ciudadela": "ciu-da-de-la",
    "ciudadrealeña": "ciu-da-dre-a-le-ña",
    "ciudadrealeño": "ciu-da-dre-a-le-ño",
    "civeta": "ci-ve-ta",
    "civeto": "ci-ve-to",
    "cívica": "cí-vi-ca",
    "cívicamente": "cí-vi-ca-men-te",
    "cívico": "cí-vi-co",
    "civil": "ci-vil",
    "civilidad": "ci-vi-li-dad",
    "civilista": "ci-vi-lis-ta",
    "civilización": "ci-vi-li-za-ción",
    "civilizador": "ci-vi-li-za-dor",
    "civilizadora": "ci-vi-li-za-do-ra",
    "civilizar": "ci-vi-li-zar",
    "civilmente": "ci-vil-men-te",
    "civismo": "ci-vis-mo",
    "cizalla": "ci-za-lla",
    "cizalladura": "ci-za-lla-du-ra",
    "cizallar": "ci-za-llar",
    "cizaña": "ci-za-ña",
    "cizañador": "ci-za-ña-dor",
    "cizañadora": "ci-za-ña-do-ra",
    "cizañar": "ci-za-ñar",
    "cizañear": "ci-za-ñe-ar",
    "cizañera": "ci-za-ñe-ra",
    "cizañero": "ci-za-ñe-ro",
    "clachique": "cla-chi-que",
    "claco": "cla-co",
    "clacote": "cla-co-te",
    "cladócero": "cla-dó-ce-ro",
    "cladodio": "cla-do-dio",
    "clamar": "cla-mar",
    "clámide": "clá-mi-de",
    "clamidosauro": "cla-mi-do-sau-ro",
    "clamor": "cla-mor",
    "clamoreada": "cla-mo-re-a-da",
    "clamorear": "cla-mo-re-ar",
    "clamoreo": "cla-mo-re-o",
    "clamorosa": "cla-mo-ro-sa",
    "clamorosamente": "cla-mo-ro-sa-men-te",
    "clamoroso": "cla-mo-ro-so",
    "clamosa": "cla-mo-sa",
    "clamosidad": "cla-mo-si-dad",
    "clamoso": "cla-mo-so",
    "clandestina": "clan-des-ti-na",
    "clandestinamente": "clan-des-ti-na-men-te",
    "clandestinidad": "clan-des-ti-ni-dad",
    "clandestino": "clan-des-ti-no",
    "clanga": "clan-ga",
    "clangor": "clan-gor",
    "clapa": "cla-pa",
    "clapo": "cla-po",
    "claque": "cla-que",
    "claqué": "cla-qué",
    "claqueta": "cla-que-ta",
    "claquetista": "cla-que-tis-ta",
    "clara": "cla-ra",
    "claraboya": "cla-ra-bo-ya",
    "claramente": "cla-ra-men-te",
    "clarar": "cla-rar",
    "clarea": "cla-re-a",
    "clarear": "cla-re-ar",
    "clarecer": "cla-re-cer",
    "clárens": "clá-rens",
    "clareo": "cla-re-o",
    "clarete": "cla-re-te",
    "claretiana": "cla-re-tia-na",
    "claretiano": "cla-re-tia-no",
    "clareza": "cla-re-za",
    "claridad": "cla-ri-dad",
    "claridoso": "cla-ri-do-so",
    "clarífica": "cla-rí-fi-ca",
    "clarificación": "cla-ri-fi-ca-ción",
    "clarificador": "cla-ri-fi-ca-dor",
    "clarificadora": "cla-ri-fi-ca-do-ra",
    "clarificar": "cla-ri-fi-car",
    "clarificativa": "cla-ri-fi-ca-ti-va",
    "clarificativo": "cla-ri-fi-ca-ti-vo",
    "clarífico": "cla-rí-fi-co",
    "clarilla": "cla-ri-lla",
    "clarimente": "cla-ri-men-te",
    "clarimento": "cla-ri-men-to",
    "clarín": "cla-rín",
    "clarinada": "cla-ri-na-da",
    "clarinado": "cla-ri-na-do",
    "clarinazo": "cla-ri-na-zo",
    "clarinero": "cla-ri-ne-ro",
    "clarinete": "cla-ri-ne-te",
    "clarinetista": "cla-ri-ne-tis-ta",
    "clariniano": "cla-ri-nia-no",
    "clarión": "cla-rión",
    "clarioncillo": "cla-rion-ci-llo",
    "clariosa": "cla-rio-sa",
    "clarisa": "cla-ri-sa",
    "claristorio": "cla-ris-to-rio",
    "clarividencia": "cla-ri-vi-den-cia",
    "clarividente": "cla-ri-vi-den-te",
    "clarividentemente": "cla-ri-vi-den-te-men-te",
    "claro": "cla-ro",
    "clarona": "cla-ro-na",
    "claror": "cla-ror",
    "claroscuro": "cla-ros-cu-ro",
    "clarucha": "cla-ru-cha",
    "clarucho": "cla-ru-cho",
    "clase": "cla-se",
    "clasema": "cla-se-ma",
    "clásica": "clá-si-ca",
    "clásicamente": "clá-si-ca-men-te",
    "clasicismo": "cla-si-cis-mo",
    "clasicista": "cla-si-cis-ta",
    "clásico": "clá-si-co",
    "clasificable": "cla-si-fi-ca-ble",
    "clasificación": "cla-si-fi-ca-ción",
    "clasificada": "cla-si-fi-ca-da",
    "clasificado": "cla-si-fi-ca-do",
    "clasificador": "cla-si-fi-ca-dor",
    "clasificadora": "cla-si-fi-ca-do-ra",
    "clasificar": "cla-si-fi-car",
    "clasificatorio": "cla-si-fi-ca-to-rio",
    "clasismo": "cla-sis-mo",
    "clasista": "cla-sis-ta",
    "clástico": "clás-ti-co",
    "claudia": "clau-dia",
    "claudicación": "clau-di-ca-ción",
    "claudicante": "clau-di-can-te",
    "claudicar": "clau-di-car",
    "claustra": "claus-tra",
    "claustral": "claus-tral",
    "claustrar": "claus-trar",
    "claustrero": "claus-tre-ro",
    "claustrillo": "claus-tri-llo",
    "claustro": "claus-tro",
    "claustrofobia": "claus-tro-fo-bia",
    "claustrofóbico": "claus-tro-fó-bi-co",
    "cláusula": "cláu-su-la",
    "clausulada": "clau-su-la-da",
    "clausulado": "clau-su-la-do",
    "clausular": "clau-su-lar",
    "clausura": "clau-su-ra",
    "clausurar": "clau-su-rar",
    "clava": "cla-va",
    "clavada": "cla-va-da",
    "clavadismo": "cla-va-dis-mo",
    "clavadista": "cla-va-dis-ta",
    "clavadiza": "cla-va-di-za",
    "clavadizo": "cla-va-di-zo",
    "clavado": "cla-va-do",
    "clavadora": "cla-va-do-ra",
    "clavadura": "cla-va-du-ra",
    "claval": "cla-val",
    "clavar": "cla-var",
    "clavaria": "cla-va-ria",
    "clavario": "cla-va-rio",
    "clavazón": "cla-va-zón",
    "clave": "cla-ve",
    "clavear": "cla-ve-ar",
    "clavecín": "cla-ve-cín",
    "clavecinista": "cla-ve-ci-nis-ta",
    "clavel": "cla-vel",
    "clavelina": "cla-ve-li-na",
    "clavelito": "cla-ve-li-to",
    "clavellina": "cla-ve-lli-na",
    "clavelón": "cla-ve-lón",
    "claveque": "cla-ve-que",
    "clavera": "cla-ve-ra",
    "clavería": "cla-ve-rí-a",
    "clavero": "cla-ve-ro",
    "claveta": "cla-ve-ta",
    "clavete": "cla-ve-te",
    "clavetear": "cla-ve-te-ar",
    "claveteo": "cla-ve-te-o",
    "clavicembalista": "cla-vi-cem-ba-lis-ta",
    "clavicémbalo": "cla-vi-cém-ba-lo",
    "clavicímbalo": "cla-vi-cím-ba-lo",
    "clavicímbano": "cla-vi-cím-ba-no",
    "clavicordio": "cla-vi-cor-dio",
    "clavícula": "cla-ví-cu-la",
    "claviculada": "cla-vi-cu-la-da",
    "claviculado": "cla-vi-cu-la-do",
    "clavicular": "cla-vi-cu-lar",
    "claviforme": "cla-vi-for-me",
    "clavija": "cla-vi-ja",
    "clavijera": "cla-vi-je-ra",
    "clavijero": "cla-vi-je-ro",
    "clavillo": "cla-vi-llo",
    "claviórgano": "cla-viór-ga-no",
    "clavito": "cla-vi-to",
    "clavo": "cla-vo",
    "claxon": "cla-xon",
    "clazol": "cla-zol",
    "clema": "cle-ma",
    "clemátide": "cle-má-ti-de",
    "clembuterol": "clem-bu-te-rol",
    "clemencia": "cle-men-cia",
    "clemente": "cle-men-te",
    "clementina": "cle-men-ti-na",
    "clementina": "cle-men-ti-na",
    "clepsidra": "clep-si-dra",
    "cleptofobia": "clep-to-fo-bia",
    "cleptómana": "clep-tó-ma-na",
    "cleptomanía": "clep-to-ma-ní-a",
    "cleptomaníaca": "clep-to-ma-ní-a-ca",
    "cleptomaniaca": "clep-to-ma-nia-ca",
    "cleptomaníaco": "clep-to-ma-ní-a-co",
    "cleptomaniaco": "clep-to-ma-nia-co",
    "cleptómano": "clep-tó-ma-no",
    "clerecía": "cle-re-cí-a",
    "clerical": "cle-ri-cal",
    "clericalismo": "cle-ri-ca-lis-mo",
    "clericalmente": "cle-ri-cal-men-te",
    "clericato": "cle-ri-ca-to",
    "clericatura": "cle-ri-ca-tu-ra",
    "clericó": "cle-ri-có",
    "clerigalla": "cle-ri-ga-lla",
    "clérigo": "clé-ri-go",
    "cleriguicia": "cle-ri-gui-cia",
    "clerizón": "cle-ri-zón",
    "clerizonte": "cle-ri-zon-te",
    "clero": "cle-ro",
    "clerófoba": "cle-ró-fo-ba",
    "clerofobia": "cle-ro-fo-bia",
    "clerófobo": "cle-ró-fo-bo",
    "cleuasmo": "cleuas-mo",
    "clíbano": "clí-ba-no",
    "clica": "cli-ca",
    "clicar": "cli-car",
    "cliceña": "cli-ce-ña",
    "cliceño": "cli-ce-ño",
    "cliché": "cli-ché",
    "clienta": "clien-ta",
    "cliente": "clien-te",
    "clientela": "clien-te-la",
    "clientelismo": "clien-te-lis-mo",
    "clima": "cli-ma",
    "climatérica": "cli-ma-té-ri-ca",
    "climatérico": "cli-ma-té-ri-co",
    "climaterio": "cli-ma-te-rio",
    "climática": "cli-má-ti-ca",
    "climático": "cli-má-ti-co",
    "climatización": "cli-ma-ti-za-ción",
    "climatizado": "cli-ma-ti-za-do",
    "climatizador": "cli-ma-ti-za-dor",
    "climatizar": "cli-ma-ti-zar",
    "climatóloga": "cli-ma-tó-lo-ga",
    "climatología": "cli-ma-to-lo-gí-a",
    "climatológica": "cli-ma-to-ló-gi-ca",
    "climatológicamente": "cli-ma-to-ló-gi-ca-men-te",
    "climatológico": "cli-ma-to-ló-gi-co",
    "climatólogo": "cli-ma-tó-lo-go",
    "clímax": "clí-max",
    "climograma": "cli-mo-gra-ma",
    "clineja": "cli-ne-ja",
    "clinera": "cli-ne-ra",
    "clinero": "cli-ne-ro",
    "clínex": "clí-nex",
    "clínica": "clí-ni-ca",
    "clínicamente": "clí-ni-ca-men-te",
    "clínico": "clí-ni-co",
    "clinómetro": "cli-nó-me-tro",
    "clinopodio": "cli-no-po-dio",
    "clipe": "cli-pe",
    "clípeo": "clí-pe-o",
    "clíper": "clí-per",
    "clipiador": "cli-pia-dor",
    "cliqueo": "cli-que-o",
    "clisado": "cli-sa-do",
    "clisar": "cli-sar",
    "clisé": "cli-sé",
    "clisos": "cli-sos",
    "clistel": "clis-tel",
    "clistelera": "clis-te-le-ra",
    "clister": "clis-ter",
    "clisterizar": "clis-te-ri-zar",
    "clitelo": "cli-te-lo",
    "clítico": "clí-ti-co",
    "clitómetro": "cli-tó-me-tro",
    "clitoriano": "cli-to-ria-no",
    "clítoris": "clí-to-ris",
    "clivaje": "cli-va-je",
    "clivosa": "cli-vo-sa",
    "clivoso": "cli-vo-so",
    "cloaca": "clo-a-ca",
    "cloacal": "clo-a-cal",
    "cloasma": "clo-as-ma",
    "clocar": "clo-car",
    "cloche": "clo-che",
    "clochel": "clo-chel",
    "clonación": "clo-na-ción",
    "clonar": "clo-nar",
    "clónica": "cló-ni-ca",
    "clónico": "cló-ni-co",
    "clonqui": "clon-qui",
    "cloque": "clo-que",
    "cloquear": "clo-que-ar",
    "cloqueo": "clo-que-o",
    "cloquera": "clo-que-ra",
    "cloquero": "clo-que-ro",
    "cloración": "clo-ra-ción",
    "cloral": "clo-ral",
    "cloramfenicol": "clo-ram-fe-ni-col",
    "cloranfenicol": "clo-ran-fe-ni-col",
    "clorar": "clo-rar",
    "cloratado": "clo-ra-ta-do",
    "cloratita": "clo-ra-ti-ta",
    "clorato": "clo-ra-to",
    "clorhidrato": "clo-rhi-dra-to",
    "clorhídrica": "clo-rhí-dri-ca",
    "clorhídrico": "clo-rhí-dri-co",
    "clórica": "cló-ri-ca",
    "clórico": "cló-ri-co",
    "clorita": "clo-ri-ta",
    "clorítica": "clo-rí-ti-ca",
    "clorítico": "clo-rí-ti-co",
    "clorito": "clo-ri-to",
    "cloro": "clo-ro",
    "cloroacético": "clo-ro-a-cé-ti-co",
    "clorofila": "clo-ro-fi-la",
    "clorofílica": "clo-ro-fí-li-ca",
    "clorofílico": "clo-ro-fí-li-co",
    "clorofilo": "clo-ro-fi-lo",
    "clorofluorocarbonado": "clo-ro-fluo-ro-car-bo-na-do",
    "clorofluorocarbono": "clo-ro-fluo-ro-car-bo-no",
    "cloroformar": "clo-ro-for-mar",
    "clorofórmica": "clo-ro-fór-mi-ca",
    "clorofórmico": "clo-ro-fór-mi-co",
    "cloroformización": "clo-ro-for-mi-za-ción",
    "cloroformizar": "clo-ro-for-mi-zar",
    "cloroformo": "clo-ro-for-mo",
    "cloromicetina": "clo-ro-mi-ce-ti-na",
    "cloroplasto": "clo-ro-plas-to",
    "clorosis": "clo-ro-sis",
    "cloroso": "clo-ro-so",
    "clorótica": "clo-ró-ti-ca",
    "clorótico": "clo-ró-ti-co",
    "clorurar": "clo-ru-rar",
    "cloruro": "clo-ru-ro",
    "clóset": "cló-set",
    "clota": "clo-ta",
    "clotear": "clo-te-ar",
    "clube": "clu-be",
    "clubista": "clu-bis-ta",
    "clueca": "clue-ca",
    "clueco": "clue-co",
    "cluequera": "clue-que-ra",
    "cluniacense": "clu-nia-cen-se",
    "cluniense": "clu-nien-se",
    "cneorácea": "cne-o-rá-ce-a",
    "cneoráceo": "cne-o-rá-ce-o",
    "cnidario": "cni-da-rio",
    "coa": "co-a",
    "coacción": "co-ac-ción",
    "coaccionar": "co-ac-cio-nar",
    "coacervación": "co-a-cer-va-ción",
    "coacervar": "co-a-cer-var",
    "coachear": "co-a-che-ar",
    "coacreedor": "co-a-cre-e-dor",
    "coacreedora": "co-a-cre-e-do-ra",
    "coactiva": "co-ac-ti-va",
    "coactivamente": "co-ac-ti-va-men-te",
    "coactividad": "co-ac-ti-vi-dad",
    "coactivo": "co-ac-ti-vo",
    "coacusada": "co-a-cu-sa-da",
    "coacusado": "co-a-cu-sa-do",
    "coadjutor": "co-ad-ju-tor",
    "coadjutora": "co-ad-ju-to-ra",
    "coadjutoría": "co-ad-ju-to-rí-a",
    "coadministrador": "co-ad-mi-nis-tra-dor",
    "coadquisición": "co-ad-qui-si-ción",
    "coadunación": "co-a-du-na-ción",
    "coadunamiento": "co-a-du-na-mien-to",
    "coadunar": "co-a-du-nar",
    "coadyutor": "co-ad-yu-tor",
    "coadyutoria": "co-ad-yu-to-ria",
    "coadyutorio": "co-ad-yu-to-rio",
    "coadyuvador": "co-ad-yu-va-dor",
    "coadyuvadora": "co-ad-yu-va-do-ra",
    "coadyuvante": "co-ad-yu-van-te",
    "coadyuvar": "co-ad-yu-var",
    "coagente": "co-a-gen-te",
    "coagulable": "co-a-gu-la-ble",
    "coagulación": "co-a-gu-la-ción",
    "coagulador": "co-a-gu-la-dor",
    "coaguladora": "co-a-gu-la-do-ra",
    "coagulante": "co-a-gu-lan-te",
    "coagular": "co-a-gu-lar",
    "coágulo": "co-á-gu-lo",
    "coagulosa": "co-a-gu-lo-sa",
    "coaguloso": "co-a-gu-lo-so",
    "coahuilense": "co-a-hui-len-se",
    "coaita": "co-ai-ta",
    "coala": "co-a-la",
    "coalescencia": "co-a-les-cen-cia",
    "coalescente": "co-a-les-cen-te",
    "coalición": "co-a-li-ción",
    "coalicionista": "co-a-li-cio-nis-ta",
    "coaligada": "co-a-li-ga-da",
    "coaligado": "co-a-li-ga-do",
    "coaligar": "co-a-li-gar",
    "coalla": "co-a-lla",
    "coamante": "co-a-man-te",
    "coana": "co-a-na",
    "coapóstol": "co-a-pós-tol",
    "coaptación": "co-ap-ta-ción",
    "coaptar": "co-ap-tar",
    "coarcho": "co-ar-cho",
    "coarrendador": "co-a-rren-da-dor",
    "coarrendadora": "co-a-rren-da-do-ra",
    "coartación": "co-ar-ta-ción",
    "coartada": "co-ar-ta-da",
    "coartado": "co-ar-ta-do",
    "coartador": "co-ar-ta-dor",
    "coartadora": "co-ar-ta-do-ra",
    "coartar": "co-ar-tar",
    "coatí": "co-a-tí",
    "coautor": "co-au-tor",
    "coautora": "co-au-to-ra",
    "coaxial": "co-a-xial",
    "coba": "co-ba",
    "cobáltica": "co-bál-ti-ca",
    "cobáltico": "co-bál-ti-co",
    "cobaltina": "co-bal-ti-na",
    "cobalto": "co-bal-to",
    "cobaltoterapia": "co-bal-to-te-ra-pia",
    "cobanera": "co-ba-ne-ra",
    "cobanero": "co-ba-ne-ro",
    "cobarcho": "co-bar-cho",
    "cobarde": "co-bar-de",
    "cobardear": "co-bar-de-ar",
    "cobardemente": "co-bar-de-men-te",
    "cobardía": "co-bar-dí-a",
    "cobardica": "co-bar-di-ca",
    "cobardón": "co-bar-dón",
    "cobaya": "co-ba-ya",
    "cobayo": "co-ba-yo",
    "cobea": "co-be-a",
    "cobertera": "co-ber-te-ra",
    "cobertero": "co-ber-te-ro",
    "cobertizo": "co-ber-ti-zo",
    "cobertor": "co-ber-tor",
    "cobertura": "co-ber-tu-ra",
    "cobez": "co-bez",
    "cobija": "co-bi-ja",
    "cobijador": "co-bi-ja-dor",
    "cobijadora": "co-bi-ja-do-ra",
    "cobijadura": "co-bi-ja-du-ra",
    "cobijamiento": "co-bi-ja-mien-to",
    "cobijar": "co-bi-jar",
    "cobijeña": "co-bi-je-ña",
    "cobijeño": "co-bi-je-ño",
    "cobijera": "co-bi-je-ra",
    "cobijo": "co-bi-jo",
    "cobijón": "co-bi-jón",
    "cobil": "co-bil",
    "cobista": "co-bis-ta",
    "cobla": "co-bla",
    "cobo": "co-bo",
    "cobol": "co-bol",
    "cobra": "co-bra",
    "cobrable": "co-bra-ble",
    "cobrada": "co-bra-da",
    "cobradera": "co-bra-de-ra",
    "cobradero": "co-bra-de-ro",
    "cobrado": "co-bra-do",
    "cobrador": "co-bra-dor",
    "cobradora": "co-bra-do-ra",
    "cobramiento": "co-bra-mien-to",
    "cobranza": "co-bran-za",
    "cobrar": "co-brar",
    "cobratoria": "co-bra-to-ria",
    "cobratorio": "co-bra-to-rio",
    "cobre": "co-bre",
    "cobreado": "co-bre-a-do",
    "cobrear": "co-bre-ar",
    "cobreña": "co-bre-ña",
    "cobreño": "co-bre-ño",
    "cobriza": "co-bri-za",
    "cobrizo": "co-bri-zo",
    "cobro": "co-bro",
    "coca": "co-ca",
    "cocacho": "co-ca-cho",
    "cocada": "co-ca-da",
    "cocador": "co-ca-dor",
    "cocadora": "co-ca-do-ra",
    "cocaína": "co-ca-í-na",
    "cocainómana": "co-cai-nó-ma-na",
    "cocainomanía": "co-cai-no-ma-ní-a",
    "cocainómano": "co-cai-nó-ma-no",
    "cocal": "co-cal",
    "cocalera": "co-ca-le-ra",
    "cocalero": "co-ca-le-ro",
    "cocama": "co-ca-ma",
    "cocán": "co-cán",
    "cocar": "co-car",
    "cocarar": "co-ca-rar",
    "cocaví": "co-ca-ví",
    "cocazo": "co-ca-zo",
    "coccidio": "coc-ci-dio",
    "cóccido": "cóc-ci-do",
    "coccígea": "coc-cí-ge-a",
    "coccígeo": "coc-cí-ge-o",
    "coccínea": "coc-cí-ne-a",
    "coccinela": "coc-ci-ne-la",
    "coccinélido": "coc-ci-né-li-do",
    "coccíneo": "coc-cí-ne-o",
    "cocción": "coc-ción",
    "cóccix": "cóc-cix",
    "coceador": "co-ce-a-dor",
    "coceadora": "co-ce-a-do-ra",
    "coceadura": "co-ce-a-du-ra",
    "coceamiento": "co-ce-a-mien-to",
    "cocear": "co-ce-ar",
    "cocedera": "co-ce-de-ra",
    "cocedero": "co-ce-de-ro",
    "cocediza": "co-ce-di-za",
    "cocedizo": "co-ce-di-zo",
    "cocedor": "co-ce-dor",
    "cócedra": "có-ce-dra",
    "cocedura": "co-ce-du-ra",
    "cocer": "co-cer",
    "cocha": "co-cha",
    "cochabambina": "co-cha-bam-bi-na",
    "cochabambino": "co-cha-bam-bi-no",
    "cochada": "co-cha-da",
    "cochama": "co-cha-ma",
    "cochambre": "co-cham-bre",
    "cochambrera": "co-cham-bre-ra",
    "cochambrería": "co-cham-bre-rí-a",
    "cochambrero": "co-cham-bre-ro",
    "cochambrosa": "co-cham-bro-sa",
    "cochambroso": "co-cham-bro-so",
    "cochano": "co-cha-no",
    "cochar": "co-char",
    "cocharro": "co-cha-rro",
    "cochastro": "co-chas-tro",
    "cochayuyo": "co-cha-yu-yo",
    "coche": "co-che",
    "cochear": "co-che-ar",
    "cochecito": "co-che-ci-to",
    "cochera": "co-che-ra",
    "cochería": "co-che-rí-a",
    "cocheril": "co-che-ril",
    "cochero": "co-che-ro",
    "cocherón": "co-che-rón",
    "cochevira": "co-che-vi-ra",
    "cochevís": "co-che-vís",
    "cochi": "co-chi",
    "cochía": "co-chí-a",
    "cochichear": "co-chi-che-ar",
    "cochifrito": "co-chi-fri-to",
    "cochigato": "co-chi-ga-to",
    "cochillo": "co-chi-llo",
    "cochina": "co-chi-na",
    "cochinada": "co-chi-na-da",
    "cochinamente": "co-chi-na-men-te",
    "cochinata": "co-chi-na-ta",
    "cochinera": "co-chi-ne-ra",
    "cochinería": "co-chi-ne-rí-a",
    "cochinero": "co-chi-ne-ro",
    "cochinilla": "co-chi-ni-lla",
    "cochinillo": "co-chi-ni-llo",
    "cochinito": "co-chi-ni-to",
    "cochino": "co-chi-no",
    "cochío": "co-chí-o",
    "cochiquera": "co-chi-que-ra",
    "cochite": "co-chi-te",
    "cochitril": "co-chi-tril",
    "cochizo": "co-chi-zo",
    "cocho": "co-cho",
    "cochorro": "co-cho-rro",
    "cochura": "co-chu-ra",
    "cochurero": "co-chu-re-ro",
    "cochusa": "co-chu-sa",
    "cochuso": "co-chu-so",
    "cochuza": "co-chu-za",
    "cochuzo": "co-chu-zo",
    "cocida": "co-ci-da",
    "cocido": "co-ci-do",
    "cociente": "co-cien-te",
    "cocimiento": "co-ci-mien-to",
    "cocina": "co-ci-na",
    "cocinado": "co-ci-na-do",
    "cocinar": "co-ci-nar",
    "cocinera": "co-ci-ne-ra",
    "cocinería": "co-ci-ne-rí-a",
    "cocinero": "co-ci-ne-ro",
    "cocinilla": "co-ci-ni-lla",
    "cocinita": "co-ci-ni-ta",
    "cocker": "coc-ker",
    "cocktail": "cock-tail",
    "cóclea": "có-cle-a",
    "coclear": "co-cle-ar",
    "coclearia": "co-cle-a-ria",
    "coclesana": "co-cle-sa-na",
    "coclesano": "co-cle-sa-no",
    "coclí": "co-clí",
    "coco": "co-co",
    "cocó": "co-có",
    "cocoa": "co-co-a",
    "cocobálsamo": "co-co-bál-sa-mo",
    "cocobola": "co-co-bo-la",
    "cocobolo": "co-co-bo-lo",
    "cococha": "co-co-cha",
    "cocodrilo": "co-co-dri-lo",
    "cocol": "co-col",
    "cocolazo": "co-co-la-zo",
    "cocolea": "co-co-le-a",
    "cocolero": "co-co-le-ro",
    "cocolía": "co-co-lí-a",
    "cocoliche": "co-co-li-che",
    "cocoliso": "co-co-li-so",
    "cocoliste": "co-co-lis-te",
    "cocolón": "co-co-lón",
    "cócono": "có-co-no",
    "cocora": "co-co-ra",
    "cócora": "có-co-ra",
    "cocorita": "co-co-ri-ta",
    "cocorito": "co-co-ri-to",
    "cocoroca": "co-co-ro-ca",
    "cocoroco": "co-co-ro-co",
    "cocorota": "co-co-ro-ta",
    "cocorronazo": "co-co-rro-na-zo",
    "cocosa": "co-co-sa",
    "cocoso": "co-co-so",
    "cocota": "co-co-ta",
    "cocotal": "co-co-tal",
    "cocote": "co-co-te",
    "cocotero": "co-co-te-ro",
    "cocotología": "co-co-to-lo-gí-a",
    "cocotte": "co-cot-te",
    "coctel": "coc-tel",
    "cóctel": "cóc-tel",
    "coctelera": "coc-te-le-ra",
    "coctelería": "coc-te-le-rí-a",
    "cocui": "co-cui",
    "cocuisa": "co-cui-sa",
    "cocuiza": "co-cui-za",
    "cocuma": "co-cu-ma",
    "cocuy": "co-cuy",
    "cocuyo": "co-cu-yo",
    "coda": "co-da",
    "codadura": "co-da-du-ra",
    "codal": "co-dal",
    "codaste": "co-das-te",
    "codastre": "co-das-tre",
    "codazo": "co-da-zo",
    "codeador": "co-de-a-dor",
    "codeadora": "co-de-a-do-ra",
    "codear": "co-de-ar",
    "codecillo": "co-de-ci-llo",
    "codecisión": "co-de-ci-sión",
    "codeína": "co-de-í-na",
    "codelincuencia": "co-de-lin-cuen-cia",
    "codelincuente": "co-de-lin-cuen-te",
    "codena": "co-de-na",
    "codeo": "co-de-o",
    "codera": "co-de-ra",
    "codero": "co-de-ro",
    "codesera": "co-de-se-ra",
    "codeso": "co-de-so",
    "codeudor": "co-deu-dor",
    "codeudora": "co-deu-do-ra",
    "códex": "có-dex",
    "codez": "co-dez",
    "codezmero": "co-dez-me-ro",
    "códice": "có-di-ce",
    "codicia": "co-di-cia",
    "codiciable": "co-di-cia-ble",
    "codiciador": "co-di-cia-dor",
    "codiciadora": "co-di-cia-do-ra",
    "codiciar": "co-di-ciar",
    "codicilar": "co-di-ci-lar",
    "codicilio": "co-di-ci-lio",
    "codicillo": "co-di-ci-llo",
    "codicilo": "co-di-ci-lo",
    "codiciosa": "co-di-cio-sa",
    "codiciosamente": "co-di-cio-sa-men-te",
    "codicioso": "co-di-cio-so",
    "codicología": "co-di-co-lo-gí-a",
    "codicológico": "co-di-co-ló-gi-co",
    "codificable": "co-di-fi-ca-ble",
    "codificación": "co-di-fi-ca-ción",
    "codificador": "co-di-fi-ca-dor",
    "codificadora": "co-di-fi-ca-do-ra",
    "codificar": "co-di-fi-car",
    "código": "có-di-go",
    "codillera": "co-di-lle-ra",
    "codillo": "co-di-llo",
    "codín": "co-dín",
    "codina": "co-di-na",
    "codirección": "co-di-rec-ción",
    "codirector": "co-di-rec-tor",
    "codirectora": "co-di-rec-to-ra",
    "codirigir": "co-di-ri-gir",
    "codo": "co-do",
    "codón": "co-dón",
    "codoñate": "co-do-ña-te",
    "codorniz": "co-dor-niz",
    "codorno": "co-dor-no",
    "codorra": "co-do-rra",
    "codorro": "co-do-rro",
    "codujo": "co-du-jo",
    "codujón": "co-du-jón",
    "coechar": "co-e-char",
    "coedición": "co-e-di-ción",
    "coeducación": "co-e-du-ca-ción",
    "coeficiencia": "co-e-fi-cien-cia",
    "coeficiente": "co-e-fi-cien-te",
    "coendú": "co-en-dú",
    "coenzima": "co-en-zi-ma",
    "coepíscopo": "co-e-pís-co-po",
    "coercer": "co-er-cer",
    "coercible": "co-er-ci-ble",
    "coerción": "co-er-ción",
    "coercitiva": "co-er-ci-ti-va",
    "coercitivo": "co-er-ci-ti-vo",
    "coesposa": "co-es-po-sa",
    "coetánea": "co-e-tá-ne-a",
    "coetáneamente": "co-e-tá-ne-a-men-te",
    "coetáneo": "co-e-tá-ne-o",
    "coeterna": "co-e-ter-na",
    "coeternidad": "co-e-ter-ni-dad",
    "coeterno": "co-e-ter-no",
    "coeva": "co-e-va",
    "coevo": "co-e-vo",
    "coexistencia": "co-e-xis-ten-cia",
    "coexistente": "co-e-xis-ten-te",
    "coexistir": "co-e-xis-tir",
    "coextender": "co-ex-ten-der",
    "coextenderse": "co-ex-ten-der-se",
    "cofa": "co-fa",
    "cofactor": "co-fac-tor",
    "cofán": "co-fán",
    "cofia": "co-fia",
    "cofiador": "co-fia-dor",
    "cofín": "co-fín",
    "cofinanciación": "co-fi-nan-cia-ción",
    "cofinanciar": "co-fi-nan-ciar",
    "cofrada": "co-fra-da",
    "cofrade": "co-fra-de",
    "cofradero": "co-fra-de-ro",
    "cofradía": "co-fra-dí-a",
    "cofre": "co-fre",
    "cofrear": "co-fre-ar",
    "cofrera": "co-fre-ra",
    "cofrero": "co-fre-ro",
    "cofundador": "co-fun-da-dor",
    "cofundadora": "co-fun-da-do-ra",
    "cogecha": "co-ge-cha",
    "cogechar": "co-ge-char",
    "cogecho": "co-ge-cho",
    "cogedera": "co-ge-de-ra",
    "cogedero": "co-ge-de-ro",
    "cogediza": "co-ge-di-za",
    "cogedizo": "co-ge-di-zo",
    "cogedor": "co-ge-dor",
    "cogedora": "co-ge-do-ra",
    "cogedura": "co-ge-du-ra",
    "cogeneración": "co-ge-ne-ra-ción",
    "coger": "co-ger",
    "cogermana": "co-ger-ma-na",
    "cogermano": "co-ger-ma-no",
    "cogestión": "co-ges-tión",
    "cogida": "co-gi-da",
    "cogido": "co-gi-do",
    "cogienda": "co-gien-da",
    "cogimiento": "co-gi-mien-to",
    "cogioca": "co-gio-ca",
    "cogitabunda": "co-gi-ta-bun-da",
    "cogitabundo": "co-gi-ta-bun-do",
    "cogitación": "co-gi-ta-ción",
    "cogitar": "co-gi-tar",
    "cogitativa": "co-gi-ta-ti-va",
    "cogitativo": "co-gi-ta-ti-vo",
    "cognación": "cog-na-ción",
    "cognada": "cog-na-da",
    "cognado": "cog-na-do",
    "cognaticia": "cog-na-ti-cia",
    "cognaticio": "cog-na-ti-cio",
    "cognición": "cog-ni-ción",
    "cognitivismo": "cog-ni-ti-vis-mo",
    "cognitivo": "cog-ni-ti-vo",
    "cognocer": "cog-no-cer",
    "cognombre": "cog-nom-bre",
    "cognomen": "cog-no-men",
    "cognomento": "cog-no-men-to",
    "cognominar": "cog-no-mi-nar",
    "cognoscente": "cog-nos-cen-te",
    "cognoscibilidad": "cog-nos-ci-bi-li-dad",
    "cognoscible": "cog-nos-ci-ble",
    "cognoscitiva": "cog-nos-ci-ti-va",
    "cognoscitivamente": "cog-nos-ci-ti-va-men-te",
    "cognoscitivo": "cog-nos-ci-ti-vo",
    "cogollero": "co-go-lle-ro",
    "cogollo": "co-go-llo",
    "cogolmar": "co-gol-mar",
    "cogombrillo": "co-gom-bri-llo",
    "cogombro": "co-gom-bro",
    "cogón": "co-gón",
    "cogonal": "co-go-nal",
    "cogorza": "co-gor-za",
    "cogotazo": "co-go-ta-zo",
    "cogote": "co-go-te",
    "cogotear": "co-go-te-ar",
    "cogoteo": "co-go-te-o",
    "cogotera": "co-go-te-ra",
    "cogotillo": "co-go-ti-llo",
    "cogotuda": "co-go-tu-da",
    "cogotudo": "co-go-tu-do",
    "cogucho": "co-gu-cho",
    "cogüelmo": "co-güel-mo",
    "cóguil": "có-guil",
    "coguilera": "co-gui-le-ra",
    "coguionista": "co-guio-nis-ta",
    "coguja": "co-gu-ja",
    "cogujada": "co-gu-ja-da",
    "cogujón": "co-gu-jón",
    "cogujonera": "co-gu-jo-ne-ra",
    "cogujonero": "co-gu-jo-ne-ro",
    "cogulla": "co-gu-lla",
    "cogullada": "co-gu-lla-da",
    "cohabitación": "co-ha-bi-ta-ción",
    "cohabitar": "co-ha-bi-tar",
    "cohecha": "co-he-cha",
    "cohechador": "co-he-cha-dor",
    "cohechadora": "co-he-cha-do-ra",
    "cohechar": "co-he-char",
    "cohecho": "co-he-cho",
    "coheredar": "co-he-re-dar",
    "coheredera": "co-he-re-de-ra",
    "coheredero": "co-he-re-de-ro",
    "coherencia": "co-he-ren-cia",
    "coherente": "co-he-ren-te",
    "coherentemente": "co-he-ren-te-men-te",
    "cohermana": "co-her-ma-na",
    "cohermano": "co-her-ma-no",
    "cohesión": "co-he-sión",
    "cohesionador": "co-he-sio-na-dor",
    "cohesionar": "co-he-sio-nar",
    "cohesiva": "co-he-si-va",
    "cohesivo": "co-he-si-vo",
    "cohesor": "co-he-sor",
    "cohetazo": "co-he-ta-zo",
    "cohete": "co-he-te",
    "cohetera": "co-he-te-ra",
    "cohetería": "co-he-te-rí-a",
    "cohetero": "co-he-te-ro",
    "cohibición": "cohi-bi-ción",
    "cohibido": "cohi-bi-do",
    "cohibir": "cohi-bir",
    "cohipónimo": "cohi-pó-ni-mo",
    "cohíta": "co-hí-ta",
    "cohobación": "co-ho-ba-ción",
    "cohobar": "co-ho-bar",
    "cohobo": "co-ho-bo",
    "cohollo": "co-ho-llo",
    "cohombral": "co-hom-bral",
    "cohombrillo": "co-hom-bri-llo",
    "cohombro": "co-hom-bro",
    "cohonder": "co-hon-der",
    "cohondimiento": "co-hon-di-mien-to",
    "cohonestador": "co-ho-nes-ta-dor",
    "cohonestadora": "co-ho-nes-ta-do-ra",
    "cohonestar": "co-ho-nes-tar",
    "cohorte": "co-hor-te",
    "coición": "coi-ción",
    "coicoy": "coi-coy",
    "coigüe": "coi-güe",
    "coihaiquina": "co-ihai-qui-na",
    "coihaiquino": "co-ihai-qui-no",
    "coihue": "coi-hue",
    "coihué": "coi-hué",
    "coima": "coi-ma",
    "coimbricense": "coim-bri-cen-se",
    "coime": "coi-me",
    "coimear": "coi-me-ar",
    "coimera": "coi-me-ra",
    "coimero": "coi-me-ro",
    "coimputada": "coim-pu-ta-da",
    "coimputado": "coim-pu-ta-do",
    "coincidencia": "coin-ci-den-cia",
    "coincidente": "coin-ci-den-te",
    "coincidentemente": "coin-ci-den-te-men-te",
    "coincidir": "coin-ci-dir",
    "coiné": "coi-né",
    "coinquilina": "coin-qui-li-na",
    "coinquilino": "coin-qui-li-no",
    "coinquinar": "coin-qui-nar",
    "cointeresada": "coin-te-re-sa-da",
    "cointeresado": "coin-te-re-sa-do",
    "coipo": "coi-po",
    "coirón": "coi-rón",
    "coironal": "coi-ro-nal",
    "coital": "coi-tal",
    "coitar": "coi-tar",
    "coito": "coi-to",
    "coja": "co-ja",
    "cojal": "co-jal",
    "cojear": "co-je-ar",
    "cojedeña": "co-je-de-ña",
    "cojedeño": "co-je-de-ño",
    "cojera": "co-je-ra",
    "cojijo": "co-ji-jo",
    "cojijosa": "co-ji-jo-sa",
    "cojijoso": "co-ji-jo-so",
    "cojín": "co-jín",
    "cojinete": "co-ji-ne-te",
    "cojinillo": "co-ji-ni-llo",
    "cojinoba": "co-ji-no-ba",
    "cojinova": "co-ji-no-va",
    "cojinúa": "co-ji-nú-a",
    "cojitranca": "co-ji-tran-ca",
    "cojitranco": "co-ji-tran-co",
    "cojo": "co-jo",
    "cojobo": "co-jo-bo",
    "cojolite": "co-jo-li-te",
    "cojón": "co-jón",
    "cojonal": "co-jo-nal",
    "cojonudamente": "co-jo-nu-da-men-te",
    "cojonudo": "co-jo-nu-do",
    "cojuda": "co-ju-da",
    "cojudez": "co-ju-dez",
    "cojudo": "co-ju-do",
    "cojuelo": "co-jue-lo",
    "cojutepecana": "co-ju-te-pe-ca-na",
    "cojutepecano": "co-ju-te-pe-ca-no",
    "cojutepequense": "co-ju-te-pe-quen-se",
    "cola": "co-la",
    "colaboración": "co-la-bo-ra-ción",
    "colaboracionismo": "co-la-bo-ra-cio-nis-mo",
    "colaboracionista": "co-la-bo-ra-cio-nis-ta",
    "colaborador": "co-la-bo-ra-dor",
    "colaboradora": "co-la-bo-ra-do-ra",
    "colaborar": "co-la-bo-rar",
    "colación": "co-la-ción",
    "colacionar": "co-la-cio-nar",
    "colactánea": "co-lac-tá-ne-a",
    "colactáneo": "co-lac-tá-ne-o",
    "colada": "co-la-da",
    "coladera": "co-la-de-ra",
    "coladero": "co-la-de-ro",
    "coladiza": "co-la-di-za",
    "coladizo": "co-la-di-zo",
    "colado": "co-la-do",
    "colador": "co-la-dor",
    "coladora": "co-la-do-ra",
    "coladura": "co-la-du-ra",
    "colage": "co-la-ge",
    "colágena": "co-lá-ge-na",
    "colágeno": "co-lá-ge-no",
    "colagoga": "co-la-go-ga",
    "colagogo": "co-la-go-go",
    "colaina": "co-lai-na",
    "colaire": "co-lai-re",
    "colambre": "co-lam-bre",
    "colana": "co-la-na",
    "colaña": "co-la-ña",
    "colanilla": "co-la-ni-lla",
    "colapez": "co-la-pez",
    "colapiscis": "co-la-pis-cis",
    "colapsar": "co-lap-sar",
    "colapso": "co-lap-so",
    "colar": "co-lar",
    "colateral": "co-la-te-ral",
    "colateralmente": "co-la-te-ral-men-te",
    "colativa": "co-la-ti-va",
    "colativo": "co-la-ti-vo",
    "colaudar": "co-lau-dar",
    "colayo": "co-la-yo",
    "cólcedra": "cól-ce-dra",
    "colcha": "col-cha",
    "colchada": "col-cha-da",
    "colchado": "col-cha-do",
    "colchadura": "col-cha-du-ra",
    "colchagüina": "col-cha-güi-na",
    "colchagüino": "col-cha-güi-no",
    "colchar": "col-char",
    "colchera": "col-che-ra",
    "colchero": "col-che-ro",
    "colchón": "col-chón",
    "colchonera": "col-cho-ne-ra",
    "colchonería": "col-cho-ne-rí-a",
    "colchonero": "col-cho-ne-ro",
    "colchoneta": "col-cho-ne-ta",
    "colcótar": "col-có-tar",
    "cole": "co-le",
    "coleada": "co-le-a-da",
    "coleador": "co-le-a-dor",
    "coleadura": "co-le-a-du-ra",
    "colear": "co-le-ar",
    "colección": "co-lec-ción",
    "coleccionable": "co-lec-cio-na-ble",
    "coleccionador": "co-lec-cio-na-dor",
    "coleccionadora": "co-lec-cio-na-do-ra",
    "coleccionar": "co-lec-cio-nar",
    "coleccionismo": "co-lec-cio-nis-mo",
    "coleccionista": "co-lec-cio-nis-ta",
    "colecistectomía": "co-le-cis-tec-to-mí-a",
    "colecistitis": "co-le-cis-ti-tis",
    "colecta": "co-lec-ta",
    "colectación": "co-lec-ta-ción",
    "colectánea": "co-lec-tá-ne-a",
    "colectar": "co-lec-tar",
    "colecticia": "co-lec-ti-cia",
    "colecticio": "co-lec-ti-cio",
    "colectiva": "co-lec-ti-va",
    "colectivamente": "co-lec-ti-va-men-te",
    "colectivera": "co-lec-ti-ve-ra",
    "colectivero": "co-lec-ti-ve-ro",
    "colectividad": "co-lec-ti-vi-dad",
    "colectivismo": "co-lec-ti-vis-mo",
    "colectivista": "co-lec-ti-vis-ta",
    "colectivización": "co-lec-ti-vi-za-ción",
    "colectivizar": "co-lec-ti-vi-zar",
    "colectivo": "co-lec-ti-vo",
    "colectomía": "co-lec-to-mí-a",
    "colector": "co-lec-tor",
    "colectora": "co-lec-to-ra",
    "colecturía": "co-lec-tu-rí-a",
    "colédoco": "co-lé-do-co",
    "colega": "co-le-ga",
    "colegatario": "co-le-ga-ta-rio",
    "colegiación": "co-le-gia-ción",
    "colegiada": "co-le-gia-da",
    "colegiadamente": "co-le-gia-da-men-te",
    "colegiado": "co-le-gia-do",
    "colegial": "co-le-gial",
    "colegiala": "co-le-gia-la",
    "colegialidad": "co-le-gia-li-dad",
    "colegialmente": "co-le-gial-men-te",
    "colegiar": "co-le-giar",
    "colegiata": "co-le-gia-ta",
    "colegiatura": "co-le-gia-tu-ra",
    "colegio": "co-le-gio",
    "colegir": "co-le-gir",
    "colegislador": "co-le-gis-la-dor",
    "colegisladora": "co-le-gis-la-do-ra",
    "colémbolo": "co-lém-bo-lo",
    "colemia": "co-le-mia",
    "colemono": "co-le-mo-no",
    "colendo": "co-len-do",
    "colénquima": "co-lén-qui-ma",
    "coleo": "co-le-o",
    "coleóptero": "co-le-óp-te-ro",
    "colera": "co-le-ra",
    "cólera": "có-le-ra",
    "colérica": "co-lé-ri-ca",
    "colérico": "co-lé-ri-co",
    "coleriforme": "co-le-ri-for-me",
    "colerín": "co-le-rín",
    "colerina": "co-le-ri-na",
    "colerizar": "co-le-ri-zar",
    "colero": "co-le-ro",
    "colesterina": "co-les-te-ri-na",
    "colesterol": "co-les-te-rol",
    "colesterolemia": "co-les-te-ro-le-mia",
    "coleta": "co-le-ta",
    "coletazo": "co-le-ta-zo",
    "coletero": "co-le-te-ro",
    "coletilla": "co-le-ti-lla",
    "coletillo": "co-le-ti-llo",
    "coleto": "co-le-to",
    "coletón": "co-le-tón",
    "coletudo": "co-le-tu-do",
    "coletuy": "co-le-tuy",
    "colgada": "col-ga-da",
    "colgadera": "col-ga-de-ra",
    "colgadero": "col-ga-de-ro",
    "colgadiza": "col-ga-di-za",
    "colgadizo": "col-ga-di-zo",
    "colgado": "col-ga-do",
    "colgador": "col-ga-dor",
    "colgadura": "col-ga-du-ra",
    "colgajo": "col-ga-jo",
    "colgamiento": "col-ga-mien-to",
    "colgandera": "col-gan-de-ra",
    "colgandero": "col-gan-de-ro",
    "colgante": "col-gan-te",
    "colgar": "col-gar",
    "colibacilo": "co-li-ba-ci-lo",
    "colibacilosis": "co-li-ba-ci-lo-sis",
    "colibrí": "co-li-brí",
    "cólica": "có-li-ca",
    "colicana": "co-li-ca-na",
    "colicano": "co-li-ca-no",
    "coliche": "co-li-che",
    "cólico": "có-li-co",
    "colicoli": "co-li-co-li",
    "colicuación": "co-li-cua-ción",
    "colicuar": "co-li-cuar",
    "colicuativa": "co-li-cua-ti-va",
    "colicuativo": "co-li-cua-ti-vo",
    "colicuecer": "co-li-cue-cer",
    "colidir": "co-li-dir",
    "coliflor": "co-li-flor",
    "coligación": "co-li-ga-ción",
    "coligadura": "co-li-ga-du-ra",
    "coligamiento": "co-li-ga-mien-to",
    "coligar": "co-li-gar",
    "coligarse": "co-li-gar-se",
    "coliguacho": "co-li-gua-cho",
    "coligual": "co-li-gual",
    "coligüe": "co-li-güe",
    "colihual": "co-li-hual",
    "colihue": "co-li-hue",
    "colilarga": "co-li-lar-ga",
    "colilla": "co-li-lla",
    "colillera": "co-li-lle-ra",
    "colillero": "co-li-lle-ro",
    "colimación": "co-li-ma-ción",
    "colimador": "co-li-ma-dor",
    "colimar": "co-li-mar",
    "colimba": "co-lim-ba",
    "colimbo": "co-lim-bo",
    "colimeño": "co-li-me-ño",
    "colimense": "co-li-men-se",
    "colimote": "co-li-mo-te",
    "colín": "co-lín",
    "colina": "co-li-na",
    "colinabo": "co-li-na-bo",
    "colindancia": "co-lin-dan-cia",
    "colindante": "co-lin-dan-te",
    "colindar": "co-lin-dar",
    "colineal": "co-li-ne-al",
    "colinérgico": "co-li-nér-gi-co",
    "colineta": "co-li-ne-ta",
    "colino": "co-li-no",
    "colipato": "co-li-pa-to",
    "colipava": "co-li-pa-va",
    "colipavo": "co-li-pa-vo",
    "coliquera": "co-li-que-ra",
    "colirio": "co-li-rio",
    "colirrojo": "co-li-rro-jo",
    "colisa": "co-li-sa",
    "coliseo": "co-li-se-o",
    "colisión": "co-li-sión",
    "colisionar": "co-li-sio-nar",
    "colista": "co-lis-ta",
    "colita": "co-li-ta",
    "coliteja": "co-li-te-ja",
    "colitigante": "co-li-ti-gan-te",
    "colitis": "co-li-tis",
    "coliza": "co-li-za",
    "colla": "co-lla",
    "collación": "co-lla-ción",
    "collada": "co-lla-da",
    "colladía": "co-lla-dí-a",
    "collado": "co-lla-do",
    "collage": "co-lla-ge",
    "collalba": "co-llal-ba",
    "collar": "co-llar",
    "collareja": "co-lla-re-ja",
    "collarejo": "co-lla-re-jo",
    "collarín": "co-lla-rín",
    "collarino": "co-lla-ri-no",
    "collaza": "co-lla-za",
    "collazo": "co-lla-zo",
    "college": "co-lle-ge",
    "colleja": "co-lle-ja",
    "collera": "co-lle-ra",
    "collerón": "co-lle-rón",
    "colleta": "co-lle-ta",
    "collie": "co-llie",
    "colliguay": "co-lli-guay",
    "collón": "co-llón",
    "collona": "co-llo-na",
    "collonada": "co-llo-na-da",
    "collonería": "co-llo-ne-rí-a",
    "colmada": "col-ma-da",
    "colmadamente": "col-ma-da-men-te",
    "colmado": "col-ma-do",
    "colmadura": "col-ma-du-ra",
    "colmar": "col-mar",
    "colmatación": "col-ma-ta-ción",
    "colmatar": "col-ma-tar",
    "colme": "col-me",
    "colmena": "col-me-na",
    "colmenar": "col-me-nar",
    "colmenera": "col-me-ne-ra",
    "colmenero": "col-me-ne-ro",
    "colmenilla": "col-me-ni-lla",
    "colmillada": "col-mi-lla-da",
    "colmillar": "col-mi-llar",
    "colmillazo": "col-mi-lla-zo",
    "colmilleja": "col-mi-lle-ja",
    "colmillo": "col-mi-llo",
    "colmilluda": "col-mi-llu-da",
    "colmilludo": "col-mi-llu-do",
    "colmo": "col-mo",
    "colo": "co-lo",
    "colobo": "co-lo-bo",
    "colocación": "co-lo-ca-ción",
    "colocado": "co-lo-ca-do",
    "colocar": "co-lo-car",
    "colocasia": "co-lo-ca-sia",
    "colocha": "co-lo-cha",
    "colochera": "co-lo-che-ra",
    "colocho": "co-lo-cho",
    "colochón": "co-lo-chón",
    "colochona": "co-lo-cho-na",
    "colocolo": "co-lo-co-lo",
    "colocón": "co-lo-cón",
    "colocutor": "co-lo-cu-tor",
    "colocutora": "co-lo-cu-to-ra",
    "colodión": "co-lo-dión",
    "colodra": "co-lo-dra",
    "colodrazgo": "co-lo-draz-go",
    "colodrillo": "co-lo-dri-llo",
    "colodro": "co-lo-dro",
    "colofón": "co-lo-fón",
    "colofonia": "co-lo-fo-nia",
    "colofonita": "co-lo-fo-ni-ta",
    "cologüina": "co-lo-güi-na",
    "coloidal": "co-loi-dal",
    "coloidalmente": "co-loi-dal-men-te",
    "coloide": "co-loi-de",
    "coloidea": "co-loi-de-a",
    "coloideo": "co-loi-de-o",
    "colombiana": "co-lom-bia-na",
    "colombianismo": "co-lom-bia-nis-mo",
    "colombiano": "co-lom-bia-no",
    "colombicultura": "co-lom-bi-cul-tu-ra",
    "colombina": "co-lom-bi-na",
    "colombino": "co-lom-bi-no",
    "colombío": "co-lom-bí-o",
    "colombo": "co-lom-bo",
    "colombófila": "co-lom-bó-fi-la",
    "colombofilia": "co-lom-bo-fi-lia",
    "colombófilo": "co-lom-bó-fi-lo",
    "colombroño": "co-lom-bro-ño",
    "colomín": "co-lo-mín",
    "colomina": "co-lo-mi-na",
    "colon": "co-lon",
    "colón": "co-lón",
    "colona": "co-lo-na",
    "colonato": "co-lo-na-to",
    "colonche": "co-lon-che",
    "colonda": "co-lon-da",
    "coloneña": "co-lo-ne-ña",
    "coloneño": "co-lo-ne-ño",
    "colonense": "co-lo-nen-se",
    "colonia": "co-lo-nia",
    "coloniaje": "co-lo-nia-je",
    "colonial": "co-lo-nial",
    "colonialismo": "co-lo-nia-lis-mo",
    "colonialista": "co-lo-nia-lis-ta",
    "coloniense": "co-lo-nien-se",
    "colonización": "co-lo-ni-za-ción",
    "colonizador": "co-lo-ni-za-dor",
    "colonizadora": "co-lo-ni-za-do-ra",
    "colonizar": "co-lo-ni-zar",
    "colono": "co-lo-no",
    "coloño": "co-lo-ño",
    "colonoscopia": "co-lo-nos-co-pia",
    "colonoscopio": "co-lo-nos-co-pio",
    "coloque": "co-lo-que",
    "coloquial": "co-lo-quial",
    "coloquialismo": "co-lo-quia-lis-mo",
    "coloquialmente": "co-lo-quial-men-te",
    "coloquíntida": "co-lo-quín-ti-da",
    "coloquio": "co-lo-quio",
    "color": "co-lor",
    "coloración": "co-lo-ra-ción",
    "colorada": "co-lo-ra-da",
    "coloradamente": "co-lo-ra-da-men-te",
    "coloradilla": "co-lo-ra-di-lla",
    "coloradismo": "co-lo-ra-dis-mo",
    "colorado": "co-lo-ra-do",
    "coloramiento": "co-lo-ra-mien-to",
    "colorante": "co-lo-ran-te",
    "colorar": "co-lo-rar",
    "colorativa": "co-lo-ra-ti-va",
    "colorativo": "co-lo-ra-ti-vo",
    "coloratura": "co-lo-ra-tu-ra",
    "colorear": "co-lo-re-ar",
    "colorete": "co-lo-re-te",
    "colorido": "co-lo-ri-do",
    "coloridor": "co-lo-ri-dor",
    "coloridora": "co-lo-ri-do-ra",
    "colorimetría": "co-lo-ri-me-trí-a",
    "colorimétrico": "co-lo-ri-mé-tri-co",
    "colorímetro": "co-lo-rí-me-tro",
    "colorín": "co-lo-rín",
    "colorinche": "co-lo-rin-che",
    "colorir": "co-lo-rir",
    "colorismo": "co-lo-ris-mo",
    "colorista": "co-lo-ris-ta",
    "colosal": "co-lo-sal",
    "colosalismo": "co-lo-sa-lis-mo",
    "colosalista": "co-lo-sa-lis-ta",
    "colosalmente": "co-lo-sal-men-te",
    "colosense": "co-lo-sen-se",
    "coloso": "co-lo-so",
    "colostomía": "co-los-to-mí-a",
    "colote": "co-lo-te",
    "colpa": "col-pa",
    "colpar": "col-par",
    "colpe": "col-pe",
    "colposcopia": "col-pos-co-pia",
    "colquechaqueña": "col-que-cha-que-ña",
    "colquechaqueño": "col-que-cha-que-ño",
    "colquicácea": "col-qui-cá-ce-a",
    "colquicáceo": "col-qui-cá-ce-o",
    "cólquico": "cól-qui-co",
    "colúbrido": "co-lú-bri-do",
    "coluda": "co-lu-da",
    "coludir": "co-lu-dir",
    "coludo": "co-lu-do",
    "columbario": "co-lum-ba-rio",
    "columbeta": "co-lum-be-ta",
    "columbiforme": "co-lum-bi-for-me",
    "columbina": "co-lum-bi-na",
    "columbino": "co-lum-bi-no",
    "columbio": "co-lum-bio",
    "columbrar": "co-lum-brar",
    "columbrete": "co-lum-bre-te",
    "columbrón": "co-lum-brón",
    "columelar": "co-lu-me-lar",
    "columna": "co-lum-na",
    "columnaria": "co-lum-na-ria",
    "columnario": "co-lum-na-rio",
    "columnata": "co-lum-na-ta",
    "columnista": "co-lum-nis-ta",
    "columpiar": "co-lum-piar",
    "columpio": "co-lum-pio",
    "coluna": "co-lu-na",
    "coluro": "co-lu-ro",
    "colusión": "co-lu-sión",
    "colusor": "co-lu-sor",
    "colusoria": "co-lu-so-ria",
    "colusorio": "co-lu-so-rio",
    "colutorio": "co-lu-to-rio",
    "coluvial": "co-lu-vial",
    "coluvie": "co-lu-vie",
    "coluvión": "co-lu-vión",
    "colza": "col-za",
    "coma": "co-ma",
    "comadrazgo": "co-ma-draz-go",
    "comadre": "co-ma-dre",
    "comadrear": "co-ma-dre-ar",
    "comadreja": "co-ma-dre-ja",
    "comadreo": "co-ma-dre-o",
    "comadrera": "co-ma-dre-ra",
    "comadrería": "co-ma-dre-rí-a",
    "comadrero": "co-ma-dre-ro",
    "comadrita": "co-ma-dri-ta",
    "comadrón": "co-ma-drón",
    "comadrona": "co-ma-dro-na",
    "comal": "co-mal",
    "comalada": "co-ma-la-da",
    "comalecer": "co-ma-le-cer",
    "comalecerse": "co-ma-le-cer-se",
    "comalia": "co-ma-lia",
    "comalida": "co-ma-li-da",
    "comalido": "co-ma-li-do",
    "comanche": "co-man-che",
    "comanda": "co-man-da",
    "comandamiento": "co-man-da-mien-to",
    "comandancia": "co-man-dan-cia",
    "comandanta": "co-man-dan-ta",
    "comandante": "co-man-dan-te",
    "comandar": "co-man-dar",
    "comandita": "co-man-di-ta",
    "comanditar": "co-man-di-tar",
    "comanditaria": "co-man-di-ta-ria",
    "comanditario": "co-man-di-ta-rio",
    "comando": "co-man-do",
    "comarapeña": "co-ma-ra-pe-ña",
    "comarapeño": "co-ma-ra-pe-ño",
    "comarca": "co-mar-ca",
    "comarcal": "co-mar-cal",
    "comarcalización": "co-mar-ca-li-za-ción",
    "comarcana": "co-mar-ca-na",
    "comarcano": "co-mar-ca-no",
    "comarcar": "co-mar-car",
    "comatosa": "co-ma-to-sa",
    "comatoso": "co-ma-to-so",
    "comayagüense": "co-ma-ya-güen-se",
    "comba": "com-ba",
    "combado": "com-ba-do",
    "combadura": "com-ba-du-ra",
    "combalachar": "com-ba-la-char",
    "combar": "com-bar",
    "combarcana": "com-bar-ca-na",
    "combarcano": "com-bar-ca-no",
    "combate": "com-ba-te",
    "combatible": "com-ba-ti-ble",
    "combatidor": "com-ba-ti-dor",
    "combatiente": "com-ba-tien-te",
    "combatimiento": "com-ba-ti-mien-to",
    "combatir": "com-ba-tir",
    "combatividad": "com-ba-ti-vi-dad",
    "combativo": "com-ba-ti-vo",
    "combazo": "com-ba-zo",
    "combeneficiado": "com-be-ne-fi-cia-do",
    "combés": "com-bés",
    "combinable": "com-bi-na-ble",
    "combinación": "com-bi-na-ción",
    "combinada": "com-bi-na-da",
    "combinadamente": "com-bi-na-da-men-te",
    "combinado": "com-bi-na-do",
    "combinar": "com-bi-nar",
    "combinatoria": "com-bi-na-to-ria",
    "combinatorio": "com-bi-na-to-rio",
    "combleza": "com-ble-za",
    "comblezo": "com-ble-zo",
    "comblueza": "com-blue-za",
    "combluezo": "com-blue-zo",
    "combo": "com-bo",
    "combosa": "com-bo-sa",
    "comboso": "com-bo-so",
    "combretácea": "com-bre-tá-ce-a",
    "combretáceo": "com-bre-tá-ce-o",
    "comburente": "com-bu-ren-te",
    "combusta": "com-bus-ta",
    "combustibilidad": "com-bus-ti-bi-li-dad",
    "combustible": "com-bus-ti-ble",
    "combustión": "com-bus-tión",
    "combusto": "com-bus-to",
    "comecandela": "co-me-can-de-la",
    "comechingón": "co-me-chin-gón",
    "comechingona": "co-me-chin-go-na",
    "comecobalde": "co-me-co-bal-de",
    "comecocos": "co-me-co-cos",
    "comecome": "co-me-co-me",
    "comedera": "co-me-de-ra",
    "comedero": "co-me-de-ro",
    "comedia": "co-me-dia",
    "comedianta": "co-me-dian-ta",
    "comediante": "co-me-dian-te",
    "comediar": "co-me-diar",
    "comedición": "co-me-di-ción",
    "comedida": "co-me-di-da",
    "comedidamente": "co-me-di-da-men-te",
    "comedido": "co-me-di-do",
    "comedimiento": "co-me-di-mien-to",
    "comedio": "co-me-dio",
    "comediógrafa": "co-me-dió-gra-fa",
    "comediógrafo": "co-me-dió-gra-fo",
    "comedir": "co-me-dir",
    "comedón": "co-me-dón",
    "comedor": "co-me-dor",
    "comedora": "co-me-do-ra",
    "comehostias": "co-me-hos-tias",
    "comeibebe": "co-mei-be-be",
    "comején": "co-me-jén",
    "comejenera": "co-me-je-ne-ra",
    "comelata": "co-me-la-ta",
    "comelón": "co-me-lón",
    "comelona": "co-me-lo-na",
    "comemierda": "co-me-mier-da",
    "comendación": "co-men-da-ción",
    "comendador": "co-men-da-dor",
    "comendadora": "co-men-da-do-ra",
    "comendadoría": "co-men-da-do-rí-a",
    "comendamiento": "co-men-da-mien-to",
    "comendatario": "co-men-da-ta-rio",
    "comendaticia": "co-men-da-ti-cia",
    "comendaticio": "co-men-da-ti-cio",
    "comendatoria": "co-men-da-to-ria",
    "comendatorio": "co-men-da-to-rio",
    "comendero": "co-men-de-ro",
    "comensal": "co-men-sal",
    "comensalía": "co-men-sa-lí-a",
    "comensalismo": "co-men-sa-lis-mo",
    "comentador": "co-men-ta-dor",
    "comentadora": "co-men-ta-do-ra",
    "comentar": "co-men-tar",
    "comentario": "co-men-ta-rio",
    "comentarista": "co-men-ta-ris-ta",
    "comento": "co-men-to",
    "comenzadera": "co-men-za-de-ra",
    "comenzadero": "co-men-za-de-ro",
    "comenzador": "co-men-za-dor",
    "comenzamiento": "co-men-za-mien-to",
    "comenzante": "co-men-zan-te",
    "comenzar": "co-men-zar",
    "comer": "co-mer",
    "comerciable": "co-mer-cia-ble",
    "comercial": "co-mer-cial",
    "comercialidad": "co-mer-cia-li-dad",
    "comercialismo": "co-mer-cia-lis-mo",
    "comercialización": "co-mer-cia-li-za-ción",
    "comercializar": "co-mer-cia-li-zar",
    "comerciante": "co-mer-cian-te",
    "comerciar": "co-mer-ciar",
    "comercio": "co-mer-cio",
    "comestible": "co-mes-ti-ble",
    "cometa": "co-me-ta",
    "cometaria": "co-me-ta-ria",
    "cometario": "co-me-ta-rio",
    "cometedor": "co-me-te-dor",
    "cometedora": "co-me-te-do-ra",
    "cometer": "co-me-ter",
    "cometida": "co-me-ti-da",
    "cometido": "co-me-ti-do",
    "cometimiento": "co-me-ti-mien-to",
    "comezón": "co-me-zón",
    "comible": "co-mi-ble",
    "cómic": "có-mic",
    "cómica": "có-mi-ca",
    "cómicamente": "có-mi-ca-men-te",
    "cómicas": "có-mi-cas",
    "comicastro": "co-mi-cas-tro",
    "comichear": "co-mi-che-ar",
    "comicial": "co-mi-cial",
    "comicidad": "co-mi-ci-dad",
    "comicios": "co-mi-cios",
    "cómico": "có-mi-co",
    "comida": "co-mi-da",
    "comidera": "co-mi-de-ra",
    "comidero": "co-mi-de-ro",
    "comidilla": "co-mi-di-lla",
    "comido": "co-mi-do",
    "comienda": "co-mien-da",
    "comienzo": "co-mien-zo",
    "comigo": "co-mi-go",
    "comilitón": "co-mi-li-tón",
    "comilitona": "co-mi-li-to-na",
    "comillas": "co-mi-llas",
    "comilón": "co-mi-lón",
    "comilona": "co-mi-lo-na",
    "cominear": "co-mi-ne-ar",
    "cominería": "co-mi-ne-rí-a",
    "cominero": "co-mi-ne-ro",
    "cominillo": "co-mi-ni-llo",
    "comino": "co-mi-no",
    "comiquear": "co-mi-que-ar",
    "comiquería": "co-mi-que-rí-a",
    "comiquita": "co-mi-qui-ta",
    "comiquitas": "co-mi-qui-tas",
    "comís": "co-mís",
    "comisar": "co-mi-sar",
    "comisaría": "co-mi-sa-rí-a",
    "comisaria": "co-mi-sa-ria",
    "comisariado": "co-mi-sa-ria-do",
    "comisariar": "co-mi-sa-riar",
    "comisariato": "co-mi-sa-ria-to",
    "comisario": "co-mi-sa-rio",
    "comiscar": "co-mis-car",
    "comisión": "co-mi-sión",
    "comisionada": "co-mi-sio-na-da",
    "comisionado": "co-mi-sio-na-do",
    "comisionar": "co-mi-sio-nar",
    "comisionista": "co-mi-sio-nis-ta",
    "comiso": "co-mi-so",
    "comisorio": "co-mi-so-rio",
    "comisquear": "co-mis-que-ar",
    "comistión": "co-mis-tión",
    "comistrajo": "co-mis-tra-jo",
    "comisura": "co-mi-su-ra",
    "comital": "co-mi-tal",
    "comité": "co-mi-té",
    "cómite": "có-mi-te",
    "comitente": "co-mi-ten-te",
    "comitiva": "co-mi-ti-va",
    "cómitre": "có-mi-tre",
    "comiza": "co-mi-za",
    "commelinácea": "com-me-li-ná-ce-a",
    "commelináceo": "com-me-li-ná-ce-o",
    "como": "co-mo",
    "cómo": "có-mo",
    "cómoda": "có-mo-da",
    "comodable": "co-mo-da-ble",
    "cómodamente": "có-mo-da-men-te",
    "comodante": "co-mo-dan-te",
    "comodataria": "co-mo-da-ta-ria",
    "comodatario": "co-mo-da-ta-rio",
    "comodato": "co-mo-da-to",
    "comodidad": "co-mo-di-dad",
    "comodidoso": "co-mo-di-do-so",
    "comodín": "co-mo-dín",
    "comodino": "co-mo-di-no",
    "comodista": "co-mo-dis-ta",
    "cómodo": "có-mo-do",
    "comodón": "co-mo-dón",
    "comodona": "co-mo-do-na",
    "comodoro": "co-mo-do-ro",
    "comoquiera": "co-mo-quie-ra",
    "comorana": "co-mo-ra-na",
    "comorano": "co-mo-ra-no",
    "comorense": "co-mo-ren-se",
    "compa": "com-pa",
    "compacidad": "com-pa-ci-dad",
    "compaciente": "com-pa-cien-te",
    "compacta": "com-pac-ta",
    "compactación": "com-pac-ta-ción",
    "compactar": "com-pac-tar",
    "compactera": "com-pac-te-ra",
    "compactibilidad": "com-pac-ti-bi-li-dad",
    "compacto": "com-pac-to",
    "compadecer": "com-pa-de-cer",
    "compadrada": "com-pa-dra-da",
    "compadraje": "com-pa-dra-je",
    "compadrar": "com-pa-drar",
    "compadrazgo": "com-pa-draz-go",
    "compadre": "com-pa-dre",
    "compadrear": "com-pa-dre-ar",
    "compadreo": "com-pa-dre-o",
    "compadrería": "com-pa-dre-rí-a",
    "compadrito": "com-pa-dri-to",
    "compadrón": "com-pa-drón",
    "compaginación": "com-pa-gi-na-ción",
    "compaginada": "com-pa-gi-na-da",
    "compaginado": "com-pa-gi-na-do",
    "compaginador": "com-pa-gi-na-dor",
    "compaginadora": "com-pa-gi-na-do-ra",
    "compaginar": "com-pa-gi-nar",
    "compaisana": "com-pai-sa-na",
    "compaisano": "com-pai-sa-no",
    "compaña": "com-pa-ña",
    "companaje": "com-pa-na-je",
    "compañera": "com-pa-ñe-ra",
    "compañería": "com-pa-ñe-rí-a",
    "compañerismo": "com-pa-ñe-ris-mo",
    "compañero": "com-pa-ñe-ro",
    "compango": "com-pan-go",
    "compañía": "com-pa-ñí-a",
    "compaño": "com-pa-ño",
    "compañón": "com-pa-ñón",
    "comparable": "com-pa-ra-ble",
    "comparación": "com-pa-ra-ción",
    "comparada": "com-pa-ra-da",
    "comparado": "com-pa-ra-do",
    "comparador": "com-pa-ra-dor",
    "comparanza": "com-pa-ran-za",
    "comparar": "com-pa-rar",
    "comparatismo": "com-pa-ra-tis-mo",
    "comparatista": "com-pa-ra-tis-ta",
    "comparativa": "com-pa-ra-ti-va",
    "comparativamente": "com-pa-ra-ti-va-men-te",
    "comparativo": "com-pa-ra-ti-vo",
    "comparecencia": "com-pa-re-cen-cia",
    "comparecer": "com-pa-re-cer",
    "compareciente": "com-pa-re-cien-te",
    "comparente": "com-pa-ren-te",
    "comparsa": "com-par-sa",
    "comparsería": "com-par-se-rí-a",
    "comparte": "com-par-te",
    "compartible": "com-par-ti-ble",
    "compartido": "com-par-ti-do",
    "compartidor": "com-par-ti-dor",
    "compartidora": "com-par-ti-do-ra",
    "compartimentación": "com-par-ti-men-ta-ción",
    "compartimentar": "com-par-ti-men-tar",
    "compartimento": "com-par-ti-men-to",
    "compartimiento": "com-par-ti-mien-to",
    "compartir": "com-par-tir",
    "compás": "com-pás",
    "compasada": "com-pa-sa-da",
    "compasadamente": "com-pa-sa-da-men-te",
    "compasado": "com-pa-sa-do",
    "compasar": "com-pa-sar",
    "compasear": "com-pa-se-ar",
    "compaseo": "com-pa-se-o",
    "compasible": "com-pa-si-ble",
    "compasillo": "com-pa-si-llo",
    "compasión": "com-pa-sión",
    "compasionada": "com-pa-sio-na-da",
    "compasionado": "com-pa-sio-na-do",
    "compasiva": "com-pa-si-va",
    "compasivamente": "com-pa-si-va-men-te",
    "compasivo": "com-pa-si-vo",
    "compaternidad": "com-pa-ter-ni-dad",
    "compatibilidad": "com-pa-ti-bi-li-dad",
    "compatibilización": "com-pa-ti-bi-li-za-ción",
    "compatibilizar": "com-pa-ti-bi-li-zar",
    "compatible": "com-pa-ti-ble",
    "compatricia": "com-pa-tri-cia",
    "compatricio": "com-pa-tri-cio",
    "compatriota": "com-pa-trio-ta",
    "compatrioto": "com-pa-trio-to",
    "compatrón": "com-pa-trón",
    "compatrona": "com-pa-tro-na",
    "compatronato": "com-pa-tro-na-to",
    "compatrono": "com-pa-tro-no",
    "compeler": "com-pe-ler",
    "compelir": "com-pe-lir",
    "compendiador": "com-pen-dia-dor",
    "compendiadora": "com-pen-dia-do-ra",
    "compendiar": "com-pen-diar",
    "compendiariamente": "com-pen-dia-ria-men-te",
    "compendio": "com-pen-dio",
    "compendiosa": "com-pen-dio-sa",
    "compendiosamente": "com-pen-dio-sa-men-te",
    "compendioso": "com-pen-dio-so",
    "compendista": "com-pen-dis-ta",
    "compendizar": "com-pen-di-zar",
    "compenetración": "com-pe-ne-tra-ción",
    "compenetrar": "com-pe-ne-trar",
    "compenetrarse": "com-pe-ne-trar-se",
    "compensable": "com-pen-sa-ble",
    "compensación": "com-pen-sa-ción",
    "compensador": "com-pen-sa-dor",
    "compensadora": "com-pen-sa-do-ra",
    "compensar": "com-pen-sar",
    "compensativa": "com-pen-sa-ti-va",
    "compensativo": "com-pen-sa-ti-vo",
    "compensatoria": "com-pen-sa-to-ria",
    "compensatorio": "com-pen-sa-to-rio",
    "competencia": "com-pe-ten-cia",
    "competencial": "com-pe-ten-cial",
    "competente": "com-pe-ten-te",
    "competentemente": "com-pe-ten-te-men-te",
    "competer": "com-pe-ter",
    "competición": "com-pe-ti-ción",
    "competidor": "com-pe-ti-dor",
    "competidora": "com-pe-ti-do-ra",
    "competir": "com-pe-tir",
    "competitivamente": "com-pe-ti-ti-va-men-te",
    "competitividad": "com-pe-ti-ti-vi-dad",
    "competitivo": "com-pe-ti-ti-vo",
    "compilación": "com-pi-la-ción",
    "compilador": "com-pi-la-dor",
    "compiladora": "com-pi-la-do-ra",
    "compilar": "com-pi-lar",
    "compilatoria": "com-pi-la-to-ria",
    "compilatorio": "com-pi-la-to-rio",
    "compinchar": "com-pin-char",
    "compinche": "com-pin-che",
    "compitales": "com-pi-ta-les",
    "complacedera": "com-pla-ce-de-ra",
    "complacedero": "com-pla-ce-de-ro",
    "complacedor": "com-pla-ce-dor",
    "complacedora": "com-pla-ce-do-ra",
    "complacencia": "com-pla-cen-cia",
    "complacer": "com-pla-cer",
    "complacidamente": "com-pla-ci-da-men-te",
    "complacido": "com-pla-ci-do",
    "complaciente": "com-pla-cien-te",
    "complacientemente": "com-pla-cien-te-men-te",
    "complacimiento": "com-pla-ci-mien-to",
    "complanar": "com-pla-nar",
    "complañir": "com-pla-ñir",
    "compleción": "com-ple-ción",
    "compleja": "com-ple-ja",
    "complejidad": "com-ple-ji-dad",
    "complejista": "com-ple-jis-ta",
    "complejo": "com-ple-jo",
    "complementación": "com-ple-men-ta-ción",
    "complementar": "com-ple-men-tar",
    "complementaria": "com-ple-men-ta-ria",
    "complementariamente": "com-ple-men-ta-ria-men-te",
    "complementariedad": "com-ple-men-ta-rie-dad",
    "complementario": "com-ple-men-ta-rio",
    "complemento": "com-ple-men-to",
    "completa": "com-ple-ta",
    "completamente": "com-ple-ta-men-te",
    "completar": "com-ple-tar",
    "completas": "com-ple-tas",
    "completez": "com-ple-tez",
    "completitud": "com-ple-ti-tud",
    "completiva": "com-ple-ti-va",
    "completivamente": "com-ple-ti-va-men-te",
    "completivo": "com-ple-ti-vo",
    "completo": "com-ple-to",
    "completoria": "com-ple-to-ria",
    "completorio": "com-ple-to-rio",
    "completud": "com-ple-tud",
    "complexa": "com-ple-xa",
    "complexidad": "com-ple-xi-dad",
    "complexión": "com-ple-xión",
    "complexionada": "com-ple-xio-na-da",
    "complexionado": "com-ple-xio-na-do",
    "complexional": "com-ple-xio-nal",
    "complexo": "com-ple-xo",
    "complicación": "com-pli-ca-ción",
    "complicada": "com-pli-ca-da",
    "complicadamente": "com-pli-ca-da-men-te",
    "complicado": "com-pli-ca-do",
    "complicar": "com-pli-car",
    "cómplice": "cóm-pli-ce",
    "complicidad": "com-pli-ci-dad",
    "complida": "com-pli-da",
    "complido": "com-pli-do",
    "complidura": "com-pli-du-ra",
    "complimiento": "com-pli-mien-to",
    "complixión": "com-pli-xión",
    "complot": "com-plot",
    "complotada": "com-plo-ta-da",
    "complotado": "com-plo-ta-do",
    "complotar": "com-plo-tar",
    "complutense": "com-plu-ten-se",
    "compluvio": "com-plu-vio",
    "compón": "com-pón",
    "componada": "com-po-na-da",
    "componado": "com-po-na-do",
    "componedor": "com-po-ne-dor",
    "componedora": "com-po-ne-do-ra",
    "componenda": "com-po-nen-da",
    "componente": "com-po-nen-te",
    "componer": "com-po-ner",
    "componible": "com-po-ni-ble",
    "componimiento": "com-po-ni-mien-to",
    "comporta": "com-por-ta",
    "comportable": "com-por-ta-ble",
    "comportamiento": "com-por-ta-mien-to",
    "comportar": "com-por-tar",
    "comporte": "com-por-te",
    "comportería": "com-por-te-rí-a",
    "comportero": "com-por-te-ro",
    "composible": "com-po-si-ble",
    "composición": "com-po-si-ción",
    "composicional": "com-po-si-cio-nal",
    "composite": "com-po-si-te",
    "compositiva": "com-po-si-ti-va",
    "compositivo": "com-po-si-ti-vo",
    "compositor": "com-po-si-tor",
    "compositora": "com-po-si-to-ra",
    "compost": "com-post",
    "compostage": "com-pos-ta-ge",
    "compostaje": "com-pos-ta-je",
    "compostela": "com-pos-te-la",
    "compostelana": "com-pos-te-la-na",
    "compostelano": "com-pos-te-la-no",
    "composteo": "com-pos-te-o",
    "compostura": "com-pos-tu-ra",
    "compota": "com-po-ta",
    "compotera": "com-po-te-ra",
    "compra": "com-pra",
    "comprable": "com-pra-ble",
    "comprachilla": "com-pra-chi-lla",
    "comprada": "com-pra-da",
    "compradera": "com-pra-de-ra",
    "compradero": "com-pra-de-ro",
    "compradillo": "com-pra-di-llo",
    "compradiza": "com-pra-di-za",
    "compradizo": "com-pra-di-zo",
    "comprado": "com-pra-do",
    "comprador": "com-pra-dor",
    "compradora": "com-pra-do-ra",
    "comprante": "com-pran-te",
    "comprar": "com-prar",
    "compraventa": "com-pra-ven-ta",
    "cómpreda": "cóm-pre-da",
    "comprehender": "com-pre-hen-der",
    "comprehensible": "com-pre-hen-si-ble",
    "comprehensión": "com-pre-hen-sión",
    "comprehensiva": "com-pre-hen-si-va",
    "comprehensivo": "com-pre-hen-si-vo",
    "comprehensor": "com-pre-hen-sor",
    "comprehensora": "com-pre-hen-so-ra",
    "comprendedor": "com-pren-de-dor",
    "comprendedora": "com-pren-de-do-ra",
    "comprender": "com-pren-der",
    "comprensibilidad": "com-pren-si-bi-li-dad",
    "comprensible": "com-pren-si-ble",
    "comprensiblemente": "com-pren-si-ble-men-te",
    "comprensión": "com-pren-sión",
    "comprensiva": "com-pren-si-va",
    "comprensivamente": "com-pren-si-va-men-te",
    "comprensivo": "com-pren-si-vo",
    "comprensor": "com-pren-sor",
    "comprensora": "com-pren-so-ra",
    "comprera": "com-pre-ra",
    "comprero": "com-pre-ro",
    "compresa": "com-pre-sa",
    "compresamente": "com-pre-sa-men-te",
    "compresbítero": "com-pres-bí-te-ro",
    "compresibilidad": "com-pre-si-bi-li-dad",
    "compresible": "com-pre-si-ble",
    "compresión": "com-pre-sión",
    "compresiva": "com-pre-si-va",
    "compresivo": "com-pre-si-vo",
    "compresor": "com-pre-sor",
    "compresora": "com-pre-so-ra",
    "comprimaria": "com-pri-ma-ria",
    "comprimario": "com-pri-ma-rio",
    "comprimible": "com-pri-mi-ble",
    "comprimida": "com-pri-mi-da",
    "comprimido": "com-pri-mi-do",
    "comprimir": "com-pri-mir",
    "comprobable": "com-pro-ba-ble",
    "comprobación": "com-pro-ba-ción",
    "comprobante": "com-pro-ban-te",
    "comprobar": "com-pro-bar",
    "comprobatoria": "com-pro-ba-to-ria",
    "comprobatorio": "com-pro-ba-to-rio",
    "comprofesor": "com-pro-fe-sor",
    "comprofesora": "com-pro-fe-so-ra",
    "comprometedor": "com-pro-me-te-dor",
    "comprometedora": "com-pro-me-te-do-ra",
    "comprometer": "com-pro-me-ter",
    "comprometidamente": "com-pro-me-ti-da-men-te",
    "comprometido": "com-pro-me-ti-do",
    "comprometimiento": "com-pro-me-ti-mien-to",
    "compromisaria": "com-pro-mi-sa-ria",
    "compromisario": "com-pro-mi-sa-rio",
    "compromiso": "com-pro-mi-so",
    "compromisoria": "com-pro-mi-so-ria",
    "compromisorio": "com-pro-mi-so-rio",
    "comprovincial": "com-pro-vin-cial",
    "comprovinciana": "com-pro-vin-cia-na",
    "comprovinciano": "com-pro-vin-cia-no",
    "comprueba": "com-prue-ba",
    "compto": "comp-to",
    "compueblana": "com-pue-bla-na",
    "compueblano": "com-pue-bla-no",
    "compuerta": "com-puer-ta",
    "compuesta": "com-pues-ta",
    "compuestamente": "com-pues-ta-men-te",
    "compuestas": "com-pues-tas",
    "compuesto": "com-pues-to",
    "compulsa": "com-pul-sa",
    "compulsación": "com-pul-sa-ción",
    "compulsar": "com-pul-sar",
    "compulsión": "com-pul-sión",
    "compulsiva": "com-pul-si-va",
    "compulsivo": "com-pul-si-vo",
    "compunción": "com-pun-ción",
    "compungida": "com-pun-gi-da",
    "compungido": "com-pun-gi-do",
    "compungir": "com-pun-gir",
    "compungiva": "com-pun-gi-va",
    "compungivo": "com-pun-gi-vo",
    "compurgación": "com-pur-ga-ción",
    "computable": "com-pu-ta-ble",
    "computación": "com-pu-ta-ción",
    "computacional": "com-pu-ta-cio-nal",
    "computador": "com-pu-ta-dor",
    "computadora": "com-pu-ta-do-ra",
    "computadorizar": "com-pu-ta-do-ri-zar",
    "computar": "com-pu-tar",
    "computarizar": "com-pu-ta-ri-zar",
    "computear": "com-pu-te-ar",
    "computerización": "com-pu-te-ri-za-ción",
    "computerizado": "com-pu-te-ri-za-do",
    "computerizar": "com-pu-te-ri-zar",
    "computista": "com-pu-tis-ta",
    "cómputo": "cóm-pu-to",
    "comta": "com-ta",
    "comto": "com-to",
    "comulación": "co-mu-la-ción",
    "comulgante": "co-mul-gan-te",
    "comulgar": "co-mul-gar",
    "comulgatorio": "co-mul-ga-to-rio",
    "común": "co-mún",
    "comuna": "co-mu-na",
    "comuña": "co-mu-ña",
    "comunal": "co-mu-nal",
    "comunaleza": "co-mu-na-le-za",
    "comunalía": "co-mu-na-lí-a",
    "comunalmente": "co-mu-nal-men-te",
    "comunamente": "co-mu-na-men-te",
    "comunera": "co-mu-ne-ra",
    "comunero": "co-mu-ne-ro",
    "comunicabilidad": "co-mu-ni-ca-bi-li-dad",
    "comunicable": "co-mu-ni-ca-ble",
    "comunicación": "co-mu-ni-ca-ción",
    "comunicacional": "co-mu-ni-ca-cio-nal",
    "comunicada": "co-mu-ni-ca-da",
    "comunicado": "co-mu-ni-ca-do",
    "comunicador": "co-mu-ni-ca-dor",
    "comunicadora": "co-mu-ni-ca-do-ra",
    "comunicante": "co-mu-ni-can-te",
    "comunicar": "co-mu-ni-car",
    "comunicativa": "co-mu-ni-ca-ti-va",
    "comunicativamente": "co-mu-ni-ca-ti-va-men-te",
    "comunicatividad": "co-mu-ni-ca-ti-vi-dad",
    "comunicativo": "co-mu-ni-ca-ti-vo",
    "comunicatorias": "co-mu-ni-ca-to-rias",
    "comunicóloga": "co-mu-ni-có-lo-ga",
    "comunicología": "co-mu-ni-co-lo-gí-a",
    "comunicólogo": "co-mu-ni-có-lo-go",
    "comunidad": "co-mu-ni-dad",
    "comunión": "co-mu-nión",
    "comunismo": "co-mu-nis-mo",
    "comunista": "co-mu-nis-ta",
    "comunitariamente": "co-mu-ni-ta-ria-men-te",
    "comunitario": "co-mu-ni-ta-rio",
    "comúnmente": "co-mún-men-te",
    "coña": "co-ña",
    "coñac": "co-ñac",
    "conacaste": "co-na-cas-te",
    "coñacear": "co-ña-ce-ar",
    "conacho": "co-na-cho",
    "coñamentazón": "co-ña-men-ta-zón",
    "conana": "co-na-na",
    "conativo": "co-na-ti-vo",
    "conato": "co-na-to",
    "coñazo": "co-ña-zo",
    "conca": "con-ca",
    "concadenar": "con-ca-de-nar",
    "concambio": "con-cam-bio",
    "concanónigo": "con-ca-nó-ni-go",
    "concatedralidad": "con-ca-te-dra-li-dad",
    "concatenación": "con-ca-te-na-ción",
    "concatenamiento": "con-ca-te-na-mien-to",
    "concatenar": "con-ca-te-nar",
    "concausa": "con-cau-sa",
    "cóncava": "cón-ca-va",
    "concavidad": "con-ca-vi-dad",
    "cóncavo": "cón-ca-vo",
    "concavoconvexo": "con-ca-vo-con-ve-xo",
    "concebible": "con-ce-bi-ble",
    "concebimiento": "con-ce-bi-mien-to",
    "concebir": "con-ce-bir",
    "concedente": "con-ce-den-te",
    "conceder": "con-ce-der",
    "concejal": "con-ce-jal",
    "concejala": "con-ce-ja-la",
    "concejalía": "con-ce-ja-lí-a",
    "concejera": "con-ce-je-ra",
    "concejeramente": "con-ce-je-ra-men-te",
    "concejero": "con-ce-je-ro",
    "concejil": "con-ce-jil",
    "concejo": "con-ce-jo",
    "concelebrado": "con-ce-le-bra-do",
    "concelebrar": "con-ce-le-brar",
    "conceller": "con-ce-ller",
    "concento": "con-cen-to",
    "concentrabilidad": "con-cen-tra-bi-li-dad",
    "concentrable": "con-cen-tra-ble",
    "concentración": "con-cen-tra-ción",
    "concentrada": "con-cen-tra-da",
    "concentrado": "con-cen-tra-do",
    "concentrador": "con-cen-tra-dor",
    "concentradora": "con-cen-tra-do-ra",
    "concentrar": "con-cen-trar",
    "concéntrica": "con-cén-tri-ca",
    "concéntricamente": "con-cén-tri-ca-men-te",
    "concéntrico": "con-cén-tri-co",
    "concentuosa": "con-cen-tuo-sa",
    "concentuoso": "con-cen-tuo-so",
    "concepción": "con-cep-ción",
    "concepcionera": "con-cep-cio-ne-ra",
    "concepcionero": "con-cep-cio-ne-ro",
    "concepcionina": "con-cep-cio-ni-na",
    "concepcionino": "con-cep-cio-ni-no",
    "concepcionista": "con-cep-cio-nis-ta",
    "concepta": "con-cep-ta",
    "conceptear": "con-cep-te-ar",
    "conceptible": "con-cep-ti-ble",
    "conceptismo": "con-cep-tis-mo",
    "conceptista": "con-cep-tis-ta",
    "conceptiva": "con-cep-ti-va",
    "conceptivo": "con-cep-ti-vo",
    "concepto": "con-cep-to",
    "conceptuación": "con-cep-tua-ción",
    "conceptual": "con-cep-tual",
    "conceptualismo": "con-cep-tua-lis-mo",
    "conceptualista": "con-cep-tua-lis-ta",
    "conceptualización": "con-cep-tua-li-za-ción",
    "conceptualizar": "con-cep-tua-li-zar",
    "conceptualmente": "con-cep-tual-men-te",
    "conceptuar": "con-cep-tuar",
    "conceptuosa": "con-cep-tuo-sa",
    "conceptuosamente": "con-cep-tuo-sa-men-te",
    "conceptuosidad": "con-cep-tuo-si-dad",
    "conceptuoso": "con-cep-tuo-so",
    "concercana": "con-cer-ca-na",
    "concercano": "con-cer-ca-no",
    "concernencia": "con-cer-nen-cia",
    "concerniente": "con-cer-nien-te",
    "concernir": "con-cer-nir",
    "concertación": "con-cer-ta-ción",
    "concertada": "con-cer-ta-da",
    "concertadamente": "con-cer-ta-da-men-te",
    "concertado": "con-cer-ta-do",
    "concertador": "con-cer-ta-dor",
    "concertadora": "con-cer-ta-do-ra",
    "concertaje": "con-cer-ta-je",
    "concertante": "con-cer-tan-te",
    "concertar": "con-cer-tar",
    "concertina": "con-cer-ti-na",
    "concertino": "con-cer-ti-no",
    "concertista": "con-cer-tis-ta",
    "concerto": "con-cer-to",
    "concesible": "con-ce-si-ble",
    "concesión": "con-ce-sión",
    "concesionar": "con-ce-sio-nar",
    "concesionaria": "con-ce-sio-na-ria",
    "concesionario": "con-ce-sio-na-rio",
    "concesiva": "con-ce-si-va",
    "concesivo": "con-ce-si-vo",
    "conceto": "con-ce-to",
    "conceyo": "con-ce-yo",
    "concha": "con-cha",
    "conchabamiento": "con-cha-ba-mien-to",
    "conchabanza": "con-cha-ban-za",
    "conchabar": "con-cha-bar",
    "conchabe": "con-cha-be",
    "conchabo": "con-cha-bo",
    "conchada": "con-cha-da",
    "conchado": "con-cha-do",
    "conchal": "con-chal",
    "conchero": "con-che-ro",
    "concheros": "con-che-ros",
    "conchesta": "con-ches-ta",
    "conchichar": "con-chi-char",
    "conchífera": "con-chí-fe-ra",
    "conchífero": "con-chí-fe-ro",
    "conchil": "con-chil",
    "concho": "con-cho",
    "conchoprimismo": "con-cho-pri-mis-mo",
    "conchoprimo": "con-cho-pri-mo",
    "conchosa": "con-cho-sa",
    "conchoso": "con-cho-so",
    "conchuda": "con-chu-da",
    "conchudo": "con-chu-do",
    "conchuela": "con-chue-la",
    "conchupancia": "con-chu-pan-cia",
    "concia": "con-cia",
    "conciencia": "con-cien-cia",
    "concienciación": "con-cien-cia-ción",
    "concienciar": "con-cien-ciar",
    "concientización": "con-cien-ti-za-ción",
    "concientizar": "con-cien-ti-zar",
    "concienzuda": "con-cien-zu-da",
    "concienzudamente": "con-cien-zu-da-men-te",
    "concienzudo": "con-cien-zu-do",
    "concierto": "con-cier-to",
    "conciliable": "con-ci-lia-ble",
    "conciliábulo": "con-ci-liá-bu-lo",
    "conciliación": "con-ci-lia-ción",
    "conciliador": "con-ci-lia-dor",
    "conciliadora": "con-ci-lia-do-ra",
    "conciliar": "con-ci-liar",
    "conciliativa": "con-ci-lia-ti-va",
    "conciliativo": "con-ci-lia-ti-vo",
    "conciliatoria": "con-ci-lia-to-ria",
    "conciliatorio": "con-ci-lia-to-rio",
    "concilio": "con-ci-lio",
    "concina": "con-ci-na",
    "concinidad": "con-ci-ni-dad",
    "concino": "con-ci-no",
    "conción": "con-ción",
    "concionador": "con-cio-na-dor",
    "concionadora": "con-cio-na-do-ra",
    "concionar": "con-cio-nar",
    "concisa": "con-ci-sa",
    "concisamente": "con-ci-sa-men-te",
    "concisión": "con-ci-sión",
    "conciso": "con-ci-so",
    "concitación": "con-ci-ta-ción",
    "concitador": "con-ci-ta-dor",
    "concitadora": "con-ci-ta-do-ra",
    "concitar": "con-ci-tar",
    "concitativa": "con-ci-ta-ti-va",
    "concitativo": "con-ci-ta-ti-vo",
    "conciudadana": "con-ciu-da-da-na",
    "conciudadano": "con-ciu-da-da-no",
    "cónclave": "cón-cla-ve",
    "conclavista": "con-cla-vis-ta",
    "concluir": "con-cluir",
    "conclusa": "con-clu-sa",
    "conclusión": "con-clu-sión",
    "conclusiva": "con-clu-si-va",
    "conclusivo": "con-clu-si-vo",
    "concluso": "con-clu-so",
    "concluyente": "con-clu-yen-te",
    "concluyentemente": "con-clu-yen-te-men-te",
    "concoide": "con-coi-de",
    "concoidea": "con-coi-de-a",
    "concoideo": "con-coi-de-o",
    "concolega": "con-co-le-ga",
    "concolón": "con-co-lón",
    "concomer": "con-co-mer",
    "concomerse": "con-co-mer-se",
    "concomimiento": "con-co-mi-mien-to",
    "concomio": "con-co-mio",
    "concomitancia": "con-co-mi-tan-cia",
    "concomitante": "con-co-mi-tan-te",
    "concomitantemente": "con-co-mi-tan-te-men-te",
    "concón": "con-cón",
    "concordable": "con-cor-da-ble",
    "concordación": "con-cor-da-ción",
    "concordador": "con-cor-da-dor",
    "concordadora": "con-cor-da-do-ra",
    "concordancia": "con-cor-dan-cia",
    "concordante": "con-cor-dan-te",
    "concordanza": "con-cor-dan-za",
    "concordar": "con-cor-dar",
    "concordata": "con-cor-da-ta",
    "concordataria": "con-cor-da-ta-ria",
    "concordatariamente": "con-cor-da-ta-ria-men-te",
    "concordatario": "con-cor-da-ta-rio",
    "concordativa": "con-cor-da-ti-va",
    "concordativo": "con-cor-da-ti-vo",
    "concordato": "con-cor-da-to",
    "concorde": "con-cor-de",
    "concordemente": "con-cor-de-men-te",
    "concordia": "con-cor-dia",
    "concorpórea": "con-cor-pó-re-a",
    "concorpóreo": "con-cor-pó-re-o",
    "concorvada": "con-cor-va-da",
    "concorvado": "con-cor-va-do",
    "concreada": "con-cre-a-da",
    "concreado": "con-cre-a-do",
    "concreción": "con-cre-ción",
    "concrecionar": "con-cre-cio-nar",
    "concrescencia": "con-cres-cen-cia",
    "concreta": "con-cre-ta",
    "concretamente": "con-cre-ta-men-te",
    "concretar": "con-cre-tar",
    "concretera": "con-cre-te-ra",
    "concretización": "con-cre-ti-za-ción",
    "concretizar": "con-cre-ti-zar",
    "concreto": "con-cre-to",
    "concuasar": "con-cua-sar",
    "concubina": "con-cu-bi-na",
    "concubinario": "con-cu-bi-na-rio",
    "concubinato": "con-cu-bi-na-to",
    "concubino": "con-cu-bi-no",
    "concubio": "con-cu-bio",
    "concúbito": "con-cú-bi-to",
    "concuerda": "con-cuer-da",
    "conculcación": "con-cul-ca-ción",
    "conculcador": "con-cul-ca-dor",
    "conculcadora": "con-cul-ca-do-ra",
    "conculcar": "con-cul-car",
    "concuna": "con-cu-na",
    "concuña": "con-cu-ña",
    "concuñada": "con-cu-ña-da",
    "concuñado": "con-cu-ña-do",
    "concuño": "con-cu-ño",
    "concupiscencia": "con-cu-pis-cen-cia",
    "concupiscente": "con-cu-pis-cen-te",
    "concupiscible": "con-cu-pis-ci-ble",
    "concurrencia": "con-cu-rren-cia",
    "concurrente": "con-cu-rren-te",
    "concurrido": "con-cu-rri-do",
    "concurrir": "con-cu-rrir",
    "concursado": "con-cur-sa-do",
    "concursante": "con-cur-san-te",
    "concursar": "con-cur-sar",
    "concurso": "con-cur-so",
    "concusión": "con-cu-sión",
    "concusionaria": "con-cu-sio-na-ria",
    "concusionario": "con-cu-sio-na-rio",
    "condado": "con-da-do",
    "condal": "con-dal",
    "conde": "con-de",
    "condecabo": "con-de-ca-bo",
    "condecente": "con-de-cen-te",
    "condecir": "con-de-cir",
    "condecoración": "con-de-co-ra-ción",
    "condecorar": "con-de-co-rar",
    "condemasiado": "con-de-ma-sia-do",
    "condena": "con-de-na",
    "condenable": "con-de-na-ble",
    "condenación": "con-de-na-ción",
    "condenada": "con-de-na-da",
    "condenado": "con-de-na-do",
    "condenador": "con-de-na-dor",
    "condenadora": "con-de-na-do-ra",
    "condenar": "con-de-nar",
    "condenatoria": "con-de-na-to-ria",
    "condenatorio": "con-de-na-to-rio",
    "condensa": "con-den-sa",
    "condensabilidad": "con-den-sa-bi-li-dad",
    "condensable": "con-den-sa-ble",
    "condensación": "con-den-sa-ción",
    "condensado": "con-den-sa-do",
    "condensador": "con-den-sa-dor",
    "condensadora": "con-den-sa-do-ra",
    "condensar": "con-den-sar",
    "condensativa": "con-den-sa-ti-va",
    "condensativo": "con-den-sa-ti-vo",
    "condenso": "con-den-so",
    "condesa": "con-de-sa",
    "condesado": "con-de-sa-do",
    "condesar": "con-de-sar",
    "condescendencia": "con-des-cen-den-cia",
    "condescender": "con-des-cen-der",
    "condescendiente": "con-des-cen-dien-te",
    "condescendientemente": "con-des-cen-dien-te-men-te",
    "condesijo": "con-de-si-jo",
    "condesil": "con-de-sil",
    "condestable": "con-des-ta-ble",
    "condestablesa": "con-des-ta-ble-sa",
    "condestablía": "con-des-ta-blí-a",
    "condición": "con-di-ción",
    "condicionada": "con-di-cio-na-da",
    "condicionado": "con-di-cio-na-do",
    "condicional": "con-di-cio-nal",
    "condicionalmente": "con-di-cio-nal-men-te",
    "condicionamiento": "con-di-cio-na-mien-to",
    "condicionante": "con-di-cio-nan-te",
    "condicionar": "con-di-cio-nar",
    "condidor": "con-di-dor",
    "condigna": "con-dig-na",
    "condignamente": "con-dig-na-men-te",
    "condigno": "con-dig-no",
    "cóndilo": "cón-di-lo",
    "condimentación": "con-di-men-ta-ción",
    "condimentar": "con-di-men-tar",
    "condimento": "con-di-men-to",
    "condir": "con-dir",
    "condiscípula": "con-dis-cí-pu-la",
    "condiscípulo": "con-dis-cí-pu-lo",
    "condolecer": "con-do-le-cer",
    "condolecerse": "con-do-le-cer-se",
    "condolencia": "con-do-len-cia",
    "condoler": "con-do-ler",
    "condominio": "con-do-mi-nio",
    "condómino": "con-dó-mi-no",
    "condón": "con-dón",
    "condonación": "con-do-na-ción",
    "condonante": "con-do-nan-te",
    "condonar": "con-do-nar",
    "cóndor": "cón-dor",
    "condoro": "con-do-ro",
    "condotiero": "con-do-tie-ro",
    "condrictio": "con-dric-tio",
    "condrila": "con-dri-la",
    "condriosoma": "con-drio-so-ma",
    "condritis": "con-dri-tis",
    "condrografía": "con-dro-gra-fí-a",
    "condrográfica": "con-dro-grá-fi-ca",
    "condrográfico": "con-dro-grá-fi-co",
    "condrología": "con-dro-lo-gí-a",
    "condroma": "con-dro-ma",
    "conducción": "con-duc-ción",
    "conducencia": "con-du-cen-cia",
    "conducente": "con-du-cen-te",
    "conduchar": "con-du-char",
    "conducho": "con-du-cho",
    "conducible": "con-du-ci-ble",
    "conducidor": "con-du-ci-dor",
    "conducidora": "con-du-ci-do-ra",
    "conducir": "con-du-cir",
    "conducta": "con-duc-ta",
    "conductancia": "con-duc-tan-cia",
    "conductero": "con-duc-te-ro",
    "conductibilidad": "con-duc-ti-bi-li-dad",
    "conductible": "con-duc-ti-ble",
    "conducticio": "con-duc-ti-cio",
    "conductímetro": "con-duc-tí-me-tro",
    "conductismo": "con-duc-tis-mo",
    "conductista": "con-duc-tis-ta",
    "conductiva": "con-duc-ti-va",
    "conductividad": "con-duc-ti-vi-dad",
    "conductivo": "con-duc-ti-vo",
    "conducto": "con-duc-to",
    "conductor": "con-duc-tor",
    "conductora": "con-duc-to-ra",
    "conductual": "con-duc-tual",
    "condueña": "con-due-ña",
    "condueño": "con-due-ño",
    "conduerma": "con-duer-ma",
    "condumio": "con-du-mio",
    "conduplicación": "con-du-pli-ca-ción",
    "condurango": "con-du-ran-go",
    "condurar": "con-du-rar",
    "conduta": "con-du-ta",
    "condutal": "con-du-tal",
    "condutero": "con-du-te-ro",
    "coñear": "co-ñe-ar",
    "conectador": "co-nec-ta-dor",
    "conectar": "co-nec-tar",
    "conecte": "co-nec-te",
    "conectiva": "co-nec-ti-va",
    "conectividad": "co-nec-ti-vi-dad",
    "conectivo": "co-nec-ti-vo",
    "conector": "co-nec-tor",
    "coneja": "co-ne-ja",
    "conejal": "co-ne-jal",
    "conejar": "co-ne-jar",
    "conejera": "co-ne-je-ra",
    "conejero": "co-ne-je-ro",
    "conejil": "co-ne-jil",
    "conejillo": "co-ne-ji-llo",
    "conejito": "co-ne-ji-to",
    "conejo": "co-ne-jo",
    "conejuna": "co-ne-ju-na",
    "conejuno": "co-ne-ju-no",
    "conepatl": "co-ne-patl",
    "coñete": "co-ñe-te",
    "conexa": "co-ne-xa",
    "conexidad": "co-ne-xi-dad",
    "conexión": "co-ne-xión",
    "conexionar": "co-ne-xio-nar",
    "conexionarse": "co-ne-xio-nar-se",
    "conexiva": "co-ne-xi-va",
    "conexivo": "co-ne-xi-vo",
    "conexo": "co-ne-xo",
    "confabulación": "con-fa-bu-la-ción",
    "confabulador": "con-fa-bu-la-dor",
    "confabuladora": "con-fa-bu-la-do-ra",
    "confabular": "con-fa-bu-lar",
    "confacción": "con-fac-ción",
    "confalón": "con-fa-lón",
    "confalonier": "con-fa-lo-nier",
    "confaloniero": "con-fa-lo-nie-ro",
    "confarreación": "con-fa-rre-a-ción",
    "confección": "con-fec-ción",
    "confeccionador": "con-fec-cio-na-dor",
    "confeccionadora": "con-fec-cio-na-do-ra",
    "confeccionar": "con-fec-cio-nar",
    "confeccionista": "con-fec-cio-nis-ta",
    "confederación": "con-fe-de-ra-ción",
    "confederada": "con-fe-de-ra-da",
    "confederado": "con-fe-de-ra-do",
    "confederal": "con-fe-de-ral",
    "confederar": "con-fe-de-rar",
    "confederativa": "con-fe-de-ra-ti-va",
    "confederativo": "con-fe-de-ra-ti-vo",
    "cónfer": "cón-fer",
    "conferencia": "con-fe-ren-cia",
    "conferenciante": "con-fe-ren-cian-te",
    "conferenciar": "con-fe-ren-ciar",
    "conferencista": "con-fe-ren-cis-ta",
    "conferir": "con-fe-rir",
    "confesa": "con-fe-sa",
    "confesable": "con-fe-sa-ble",
    "confesada": "con-fe-sa-da",
    "confesado": "con-fe-sa-do",
    "confesante": "con-fe-san-te",
    "confesar": "con-fe-sar",
    "confesión": "con-fe-sión",
    "confesional": "con-fe-sio-nal",
    "confesionalidad": "con-fe-sio-na-li-dad",
    "confesionario": "con-fe-sio-na-rio",
    "confesionista": "con-fe-sio-nis-ta",
    "confeso": "con-fe-so",
    "confesonario": "con-fe-so-na-rio",
    "confesor": "con-fe-sor",
    "confesorio": "con-fe-so-rio",
    "confesuría": "con-fe-su-rí-a",
    "confeti": "con-fe-ti",
    "confiabilidad": "con-fia-bi-li-dad",
    "confiable": "con-fia-ble",
    "confiada": "con-fia-da",
    "confiadamente": "con-fia-da-men-te",
    "confiado": "con-fia-do",
    "confiador": "con-fia-dor",
    "confiadora": "con-fia-do-ra",
    "confianza": "con-fian-za",
    "confianzuda": "con-fian-zu-da",
    "confianzudamente": "con-fian-zu-da-men-te",
    "confianzudo": "con-fian-zu-do",
    "confiar": "con-fiar",
    "conficiente": "con-fi-cien-te",
    "confición": "con-fi-ción",
    "conficionar": "con-fi-cio-nar",
    "confidencia": "con-fi-den-cia",
    "confidencial": "con-fi-den-cial",
    "confidencialidad": "con-fi-den-cia-li-dad",
    "confidencialmente": "con-fi-den-cial-men-te",
    "confidenta": "con-fi-den-ta",
    "confidente": "con-fi-den-te",
    "confidentemente": "con-fi-den-te-men-te",
    "configuración": "con-fi-gu-ra-ción",
    "configurar": "con-fi-gu-rar",
    "confín": "con-fín",
    "confinación": "con-fi-na-ción",
    "confinada": "con-fi-na-da",
    "confinado": "con-fi-na-do",
    "confinamiento": "con-fi-na-mien-to",
    "confinante": "con-fi-nan-te",
    "confinar": "con-fi-nar",
    "confinidad": "con-fi-ni-dad",
    "confinio": "con-fi-nio",
    "confirmación": "con-fir-ma-ción",
    "confirmadamente": "con-fir-ma-da-men-te",
    "confirmador": "con-fir-ma-dor",
    "confirmadora": "con-fir-ma-do-ra",
    "confirmamiento": "con-fir-ma-mien-to",
    "confirmanda": "con-fir-man-da",
    "confirmando": "con-fir-man-do",
    "confirmante": "con-fir-man-te",
    "confirmar": "con-fir-mar",
    "confirmativa": "con-fir-ma-ti-va",
    "confirmativo": "con-fir-ma-ti-vo",
    "confirmatoria": "con-fir-ma-to-ria",
    "confirmatorio": "con-fir-ma-to-rio",
    "confiscable": "con-fis-ca-ble",
    "confiscación": "con-fis-ca-ción",
    "confiscada": "con-fis-ca-da",
    "confiscado": "con-fis-ca-do",
    "confiscar": "con-fis-car",
    "confiscatorio": "con-fis-ca-to-rio",
    "confit": "con-fit",
    "confitada": "con-fi-ta-da",
    "confitado": "con-fi-ta-do",
    "confitar": "con-fi-tar",
    "confite": "con-fi-te",
    "confitente": "con-fi-ten-te",
    "confíteor": "con-fí-te-or",
    "confitera": "con-fi-te-ra",
    "confitería": "con-fi-te-rí-a",
    "confitero": "con-fi-te-ro",
    "confitico": "con-fi-ti-co",
    "confitura": "con-fi-tu-ra",
    "conflación": "con-fla-ción",
    "conflagración": "con-fla-gra-ción",
    "conflagrar": "con-fla-grar",
    "conflátil": "con-flá-til",
    "conflictividad": "con-flic-ti-vi-dad",
    "conflictivo": "con-flic-ti-vo",
    "conflicto": "con-flic-to",
    "conflictual": "con-flic-tual",
    "confligir": "con-fli-gir",
    "confluencia": "con-fluen-cia",
    "confluente": "con-fluen-te",
    "confluir": "con-fluir",
    "confluyente": "con-flu-yen-te",
    "conformación": "con-for-ma-ción",
    "conformado": "con-for-ma-do",
    "conformador": "con-for-ma-dor",
    "conformar": "con-for-mar",
    "conforme": "con-for-me",
    "conformemente": "con-for-me-men-te",
    "conformidad": "con-for-mi-dad",
    "conformismo": "con-for-mis-mo",
    "conformista": "con-for-mis-ta",
    "confort": "con-fort",
    "confortabilidad": "con-for-ta-bi-li-dad",
    "confortable": "con-for-ta-ble",
    "confortablemente": "con-for-ta-ble-men-te",
    "confortación": "con-for-ta-ción",
    "confortador": "con-for-ta-dor",
    "confortadora": "con-for-ta-do-ra",
    "confortamiento": "con-for-ta-mien-to",
    "confortante": "con-for-tan-te",
    "confortar": "con-for-tar",
    "confortativa": "con-for-ta-ti-va",
    "confortativo": "con-for-ta-ti-vo",
    "conforte": "con-for-te",
    "conforto": "con-for-to",
    "confracción": "con-frac-ción",
    "confrade": "con-fra-de",
    "confradía": "con-fra-dí-a",
    "confragosa": "con-fra-go-sa",
    "confragoso": "con-fra-go-so",
    "confraternar": "con-fra-ter-nar",
    "confraternidad": "con-fra-ter-ni-dad",
    "confraternización": "con-fra-ter-ni-za-ción",
    "confraternizar": "con-fra-ter-ni-zar",
    "confricación": "con-fri-ca-ción",
    "confricar": "con-fri-car",
    "confrontación": "con-fron-ta-ción",
    "confrontar": "con-fron-tar",
    "confuciana": "con-fu-cia-na",
    "confucianismo": "con-fu-cia-nis-mo",
    "confuciano": "con-fu-cia-no",
    "confucionismo": "con-fu-cio-nis-mo",
    "confucionista": "con-fu-cio-nis-ta",
    "confuerzo": "con-fuer-zo",
    "confuir": "con-fuir",
    "confulgencia": "con-ful-gen-cia",
    "confundible": "con-fun-di-ble",
    "confundidor": "con-fun-di-dor",
    "confundidora": "con-fun-di-do-ra",
    "confundimiento": "con-fun-di-mien-to",
    "confundir": "con-fun-dir",
    "confusa": "con-fu-sa",
    "confusamente": "con-fu-sa-men-te",
    "confusión": "con-fu-sión",
    "confusionismo": "con-fu-sio-nis-mo",
    "confusionista": "con-fu-sio-nis-ta",
    "confuso": "con-fu-so",
    "confutación": "con-fu-ta-ción",
    "confutador": "con-fu-ta-dor",
    "confutadora": "con-fu-ta-do-ra",
    "confutar": "con-fu-tar",
    "confutatoria": "con-fu-ta-to-ria",
    "confutatorio": "con-fu-ta-to-rio",
    "conga": "con-ga",
    "congal": "con-gal",
    "congelable": "con-ge-la-ble",
    "congelación": "con-ge-la-ción",
    "congelado": "con-ge-la-do",
    "congelador": "con-ge-la-dor",
    "congelamiento": "con-ge-la-mien-to",
    "congelar": "con-ge-lar",
    "congelativa": "con-ge-la-ti-va",
    "congelativo": "con-ge-la-ti-vo",
    "congénere": "con-gé-ne-re",
    "congenial": "con-ge-nial",
    "congeniar": "con-ge-niar",
    "congénita": "con-gé-ni-ta",
    "congénito": "con-gé-ni-to",
    "congerie": "con-ge-rie",
    "congeries": "con-ge-ries",
    "congestión": "con-ges-tión",
    "congestionar": "con-ges-tio-nar",
    "congestiva": "con-ges-ti-va",
    "congestivo": "con-ges-ti-vo",
    "congiario": "con-gia-rio",
    "congio": "con-gio",
    "conglobación": "con-glo-ba-ción",
    "conglobar": "con-glo-bar",
    "conglomeración": "con-glo-me-ra-ción",
    "conglomerado": "con-glo-me-ra-do",
    "conglomerante": "con-glo-me-ran-te",
    "conglomerar": "con-glo-me-rar",
    "congloriar": "con-glo-riar",
    "conglutinación": "con-glu-ti-na-ción",
    "conglutinante": "con-glu-ti-nan-te",
    "conglutinar": "con-glu-ti-nar",
    "conglutinativa": "con-glu-ti-na-ti-va",
    "conglutinativo": "con-glu-ti-na-ti-vo",
    "conglutinosa": "con-glu-ti-no-sa",
    "conglutinoso": "con-glu-ti-no-so",
    "congo": "con-go",
    "congoja": "con-go-ja",
    "congojar": "con-go-jar",
    "congojo": "con-go-jo",
    "congojosa": "con-go-jo-sa",
    "congojoso": "con-go-jo-so",
    "congola": "con-go-la",
    "congoleña": "con-go-le-ña",
    "congoleño": "con-go-le-ño",
    "congolés": "con-go-lés",
    "congolesa": "con-go-le-sa",
    "congolona": "con-go-lo-na",
    "congona": "con-go-na",
    "congorocho": "con-go-ro-cho",
    "congosto": "con-gos-to",
    "congraciador": "con-gra-cia-dor",
    "congraciadora": "con-gra-cia-do-ra",
    "congraciamiento": "con-gra-cia-mien-to",
    "congraciar": "con-gra-ciar",
    "congratulación": "con-gra-tu-la-ción",
    "congratular": "con-gra-tu-lar",
    "congratulatoria": "con-gra-tu-la-to-ria",
    "congratulatorio": "con-gra-tu-la-to-rio",
    "congregación": "con-gre-ga-ción",
    "congreganta": "con-gre-gan-ta",
    "congregante": "con-gre-gan-te",
    "congregar": "con-gre-gar",
    "congresal": "con-gre-sal",
    "congresista": "con-gre-sis-ta",
    "congreso": "con-gre-so",
    "congresual": "con-gre-sual",
    "congreve": "con-gre-ve",
    "congrí": "con-grí",
    "congrio": "con-grio",
    "congrua": "con-grua",
    "congruamente": "con-grua-men-te",
    "congruencia": "con-gruen-cia",
    "congruente": "con-gruen-te",
    "congruentemente": "con-gruen-te-men-te",
    "congruidad": "con-grui-dad",
    "congruismo": "con-gruis-mo",
    "congruista": "con-gruis-ta",
    "congruo": "con-gruo",
    "conguear": "con-gue-ar",
    "conguito": "con-gui-to",
    "conhortar": "con-hor-tar",
    "conhorte": "con-hor-te",
    "cónica": "có-ni-ca",
    "conicidad": "co-ni-ci-dad",
    "cónico": "có-ni-co",
    "coniecha": "co-nie-cha",
    "conífera": "co-ní-fe-ra",
    "coníferas": "co-ní-fe-ras",
    "conífero": "co-ní-fe-ro",
    "coniforme": "co-ni-for-me",
    "conimbricense": "co-nim-bri-cen-se",
    "conirrostro": "co-ni-rros-tro",
    "conivalva": "co-ni-val-va",
    "conivalvo": "co-ni-val-vo",
    "coniza": "co-ni-za",
    "conjetura": "con-je-tu-ra",
    "conjeturable": "con-je-tu-ra-ble",
    "conjeturador": "con-je-tu-ra-dor",
    "conjeturadora": "con-je-tu-ra-do-ra",
    "conjetural": "con-je-tu-ral",
    "conjeturalmente": "con-je-tu-ral-men-te",
    "conjeturar": "con-je-tu-rar",
    "conjuez": "con-juez",
    "conjugable": "con-ju-ga-ble",
    "conjugación": "con-ju-ga-ción",
    "conjugada": "con-ju-ga-da",
    "conjugadas": "con-ju-ga-das",
    "conjugado": "con-ju-ga-do",
    "conjugador": "con-ju-ga-dor",
    "conjugal": "con-ju-gal",
    "conjugar": "con-ju-gar",
    "conjunción": "con-jun-ción",
    "conjunta": "con-jun-ta",
    "conjuntado": "con-jun-ta-do",
    "conjuntamente": "con-jun-ta-men-te",
    "conjuntar": "con-jun-tar",
    "conjuntiva": "con-jun-ti-va",
    "conjuntival": "con-jun-ti-val",
    "conjuntivitis": "con-jun-ti-vi-tis",
    "conjuntivo": "con-jun-ti-vo",
    "conjunto": "con-jun-to",
    "conjuntura": "con-jun-tu-ra",
    "conjura": "con-ju-ra",
    "conjuración": "con-ju-ra-ción",
    "conjurada": "con-ju-ra-da",
    "conjurado": "con-ju-ra-do",
    "conjurador": "con-ju-ra-dor",
    "conjuramentar": "con-ju-ra-men-tar",
    "conjurar": "con-ju-rar",
    "conjuro": "con-ju-ro",
    "conllevador": "con-lle-va-dor",
    "conllevadora": "con-lle-va-do-ra",
    "conllevar": "con-lle-var",
    "conllorar": "con-llo-rar",
    "conloar": "con-lo-ar",
    "conmemorable": "con-me-mo-ra-ble",
    "conmemoración": "con-me-mo-ra-ción",
    "conmemorar": "con-me-mo-rar",
    "conmemorativa": "con-me-mo-ra-ti-va",
    "conmemorativo": "con-me-mo-ra-ti-vo",
    "conmemoratoria": "con-me-mo-ra-to-ria",
    "conmemoratorio": "con-me-mo-ra-to-rio",
    "conmensal": "con-men-sal",
    "conmensalía": "con-men-sa-lí-a",
    "conmensurabilidad": "con-men-su-ra-bi-li-dad",
    "conmensurable": "con-men-su-ra-ble",
    "conmensuración": "con-men-su-ra-ción",
    "conmensurar": "con-men-su-rar",
    "conmensurativa": "con-men-su-ra-ti-va",
    "conmensurativo": "con-men-su-ra-ti-vo",
    "conmigo": "con-mi-go",
    "conmilitón": "con-mi-li-tón",
    "conminación": "con-mi-na-ción",
    "conminador": "con-mi-na-dor",
    "conminadora": "con-mi-na-do-ra",
    "conminar": "con-mi-nar",
    "conminativa": "con-mi-na-ti-va",
    "conminativo": "con-mi-na-ti-vo",
    "conminatoria": "con-mi-na-to-ria",
    "conminatorio": "con-mi-na-to-rio",
    "conminuta": "con-mi-nu-ta",
    "conmiseración": "con-mi-se-ra-ción",
    "conmiserativamente": "con-mi-se-ra-ti-va-men-te",
    "conmiserativo": "con-mi-se-ra-ti-vo",
    "conmista": "con-mis-ta",
    "conmistión": "con-mis-tión",
    "conmisto": "con-mis-to",
    "conmistura": "con-mis-tu-ra",
    "conmixta": "con-mix-ta",
    "conmixtión": "con-mix-tión",
    "conmixto": "con-mix-to",
    "conmoción": "con-mo-ción",
    "conmocionar": "con-mo-cio-nar",
    "conmonitorio": "con-mo-ni-to-rio",
    "conmoración": "con-mo-ra-ción",
    "conmovedor": "con-mo-ve-dor",
    "conmovedora": "con-mo-ve-do-ra",
    "conmover": "con-mo-ver",
    "conmuta": "con-mu-ta",
    "conmutabilidad": "con-mu-ta-bi-li-dad",
    "conmutable": "con-mu-ta-ble",
    "conmutación": "con-mu-ta-ción",
    "conmutador": "con-mu-ta-dor",
    "conmutadora": "con-mu-ta-do-ra",
    "conmutar": "con-mu-tar",
    "conmutativa": "con-mu-ta-ti-va",
    "conmutatividad": "con-mu-ta-ti-vi-dad",
    "conmutativo": "con-mu-ta-ti-vo",
    "conmutatriz": "con-mu-ta-triz",
    "connacional": "con-na-cio-nal",
    "connatural": "con-na-tu-ral",
    "connaturalización": "con-na-tu-ra-li-za-ción",
    "connaturalizar": "con-na-tu-ra-li-zar",
    "connaturalmente": "con-na-tu-ral-men-te",
    "connivencia": "con-ni-ven-cia",
    "connivente": "con-ni-ven-te",
    "connombre": "con-nom-bre",
    "connosco": "con-nos-co",
    "connotación": "con-no-ta-ción",
    "connotada": "con-no-ta-da",
    "connotado": "con-no-ta-do",
    "connotar": "con-no-tar",
    "connotativo": "con-no-ta-ti-vo",
    "connovicia": "con-no-vi-cia",
    "connovicio": "con-no-vi-cio",
    "connubial": "con-nu-bial",
    "connubio": "con-nu-bio",
    "connumerar": "con-nu-me-rar",
    "cono": "co-no",
    "coño": "co-ño",
    "conocedor": "co-no-ce-dor",
    "conocedora": "co-no-ce-do-ra",
    "conocencia": "co-no-cen-cia",
    "conocer": "co-no-cer",
    "conocible": "co-no-ci-ble",
    "conocida": "co-no-ci-da",
    "conocidamente": "co-no-ci-da-men-te",
    "conocido": "co-no-ci-do",
    "conocimiento": "co-no-ci-mien-to",
    "conoidal": "co-noi-dal",
    "conoide": "co-noi-de",
    "conoidea": "co-noi-de-a",
    "conoideo": "co-noi-de-o",
    "coñón": "co-ñón",
    "conopeo": "co-no-pe-o",
    "conopial": "co-no-pial",
    "conoscencia": "co-nos-cen-cia",
    "conoto": "co-no-to",
    "conque": "con-que",
    "conqué": "con-qué",
    "conquense": "con-quen-se",
    "conqueridor": "con-que-ri-dor",
    "conqueridora": "con-que-ri-do-ra",
    "conquerir": "con-que-rir",
    "cónquibus": "cón-qui-bus",
    "conquiforme": "con-qui-for-me",
    "conquilióloga": "con-qui-lió-lo-ga",
    "conquiliología": "con-qui-lio-lo-gí-a",
    "conquiliólogo": "con-qui-lió-lo-go",
    "conquiolina": "con-quio-li-na",
    "conquista": "con-quis-ta",
    "conquistable": "con-quis-ta-ble",
    "conquistador": "con-quis-ta-dor",
    "conquistadora": "con-quis-ta-do-ra",
    "conquistar": "con-quis-tar",
    "conrear": "con-re-ar",
    "conreinar": "con-rei-nar",
    "conreo": "con-re-o",
    "consabida": "con-sa-bi-da",
    "consabido": "con-sa-bi-do",
    "consabidor": "con-sa-bi-dor",
    "consabidora": "con-sa-bi-do-ra",
    "consaburense": "con-sa-bu-ren-se",
    "consagrable": "con-sa-gra-ble",
    "consagración": "con-sa-gra-ción",
    "consagramiento": "con-sa-gra-mien-to",
    "consagrar": "con-sa-grar",
    "consagratorio": "con-sa-gra-to-rio",
    "consanguínea": "con-san-guí-ne-a",
    "consanguineidad": "con-san-gui-nei-dad",
    "consanguíneo": "con-san-guí-ne-o",
    "consanguinidad": "con-san-gui-ni-dad",
    "consciencia": "cons-cien-cia",
    "consciente": "cons-cien-te",
    "conscientemente": "cons-cien-te-men-te",
    "conscripción": "cons-crip-ción",
    "conscripto": "cons-crip-to",
    "consectaria": "con-sec-ta-ria",
    "consectario": "con-sec-ta-rio",
    "consecución": "con-se-cu-ción",
    "consecuencia": "con-se-cuen-cia",
    "consecuente": "con-se-cuen-te",
    "consecuentemente": "con-se-cuen-te-men-te",
    "consecutiva": "con-se-cu-ti-va",
    "consecutivamente": "con-se-cu-ti-va-men-te",
    "consecutivo": "con-se-cu-ti-vo",
    "conseguido": "con-se-gui-do",
    "conseguimiento": "con-se-gui-mien-to",
    "conseguir": "con-se-guir",
    "conseja": "con-se-ja",
    "consejable": "con-se-ja-ble",
    "consejador": "con-se-ja-dor",
    "consejar": "con-se-jar",
    "consejera": "con-se-je-ra",
    "consejeramente": "con-se-je-ra-men-te",
    "consejería": "con-se-je-rí-a",
    "consejero": "con-se-je-ro",
    "consejo": "con-se-jo",
    "consenciente": "con-sen-cien-te",
    "consenso": "con-sen-so",
    "consensual": "con-sen-sual",
    "consensuar": "con-sen-suar",
    "consentida": "con-sen-ti-da",
    "consentido": "con-sen-ti-do",
    "consentidor": "con-sen-ti-dor",
    "consentidora": "con-sen-ti-do-ra",
    "consentimiento": "con-sen-ti-mien-to",
    "consentir": "con-sen-tir",
    "conserje": "con-ser-je",
    "conserjería": "con-ser-je-rí-a",
    "conserva": "con-ser-va",
    "conservable": "con-ser-va-ble",
    "conservación": "con-ser-va-ción",
    "conservacionismo": "con-ser-va-cio-nis-mo",
    "conservacionista": "con-ser-va-cio-nis-ta",
    "conservador": "con-ser-va-dor",
    "conservadora": "con-ser-va-do-ra",
    "conservadorismo": "con-ser-va-do-ris-mo",
    "conservaduría": "con-ser-va-du-rí-a",
    "conservadurismo": "con-ser-va-du-ris-mo",
    "conservante": "con-ser-van-te",
    "conservar": "con-ser-var",
    "conservativa": "con-ser-va-ti-va",
    "conservativo": "con-ser-va-ti-vo",
    "conservatoría": "con-ser-va-to-rí-a",
    "conservatorio": "con-ser-va-to-rio",
    "conservera": "con-ser-ve-ra",
    "conservería": "con-ser-ve-rí-a",
    "conservero": "con-ser-ve-ro",
    "conseyo": "con-se-yo",
    "considerable": "con-si-de-ra-ble",
    "considerablemente": "con-si-de-ra-ble-men-te",
    "consideración": "con-si-de-ra-ción",
    "considerada": "con-si-de-ra-da",
    "considerado": "con-si-de-ra-do",
    "considerador": "con-si-de-ra-dor",
    "consideradora": "con-si-de-ra-do-ra",
    "considerando": "con-si-de-ran-do",
    "considerar": "con-si-de-rar",
    "considerativa": "con-si-de-ra-ti-va",
    "considerativo": "con-si-de-ra-ti-vo",
    "consiervo": "con-sier-vo",
    "consigna": "con-sig-na",
    "consignación": "con-sig-na-ción",
    "consignador": "con-sig-na-dor",
    "consignar": "con-sig-nar",
    "consignatario": "con-sig-na-ta-rio",
    "consignativo": "con-sig-na-ti-vo",
    "consigo": "con-si-go",
    "consiguiente": "con-si-guien-te",
    "consiguientemente": "con-si-guien-te-men-te",
    "consiliaria": "con-si-lia-ria",
    "consiliario": "con-si-lia-rio",
    "consiliativa": "con-si-lia-ti-va",
    "consiliativo": "con-si-lia-ti-vo",
    "consintiente": "con-sin-tien-te",
    "consistencia": "con-sis-ten-cia",
    "consistente": "con-sis-ten-te",
    "consistir": "con-sis-tir",
    "consistorial": "con-sis-to-rial",
    "consistorialmente": "con-sis-to-rial-men-te",
    "consistorio": "con-sis-to-rio",
    "consocia": "con-so-cia",
    "consocio": "con-so-cio",
    "consograr": "con-so-grar",
    "consola": "con-so-la",
    "consolable": "con-so-la-ble",
    "consolación": "con-so-la-ción",
    "consolador": "con-so-la-dor",
    "consoladora": "con-so-la-do-ra",
    "consolar": "con-so-lar",
    "consolativa": "con-so-la-ti-va",
    "consolativo": "con-so-la-ti-vo",
    "consolatoria": "con-so-la-to-ria",
    "consolatorio": "con-so-la-to-rio",
    "consoldar": "con-sol-dar",
    "consólida": "con-só-li-da",
    "consolidación": "con-so-li-da-ción",
    "consolidada": "con-so-li-da-da",
    "consolidado": "con-so-li-da-do",
    "consolidar": "con-so-li-dar",
    "consolidativa": "con-so-li-da-ti-va",
    "consolidativo": "con-so-li-da-ti-vo",
    "consomé": "con-so-mé",
    "cónsona": "cón-so-na",
    "consonamiento": "con-so-na-mien-to",
    "consonancia": "con-so-nan-cia",
    "consonante": "con-so-nan-te",
    "consonantemente": "con-so-nan-te-men-te",
    "consonántica": "con-so-nán-ti-ca",
    "consonántico": "con-so-nán-ti-co",
    "consonantismo": "con-so-nan-tis-mo",
    "consonantización": "con-so-nan-ti-za-ción",
    "consonantizar": "con-so-nan-ti-zar",
    "consonar": "con-so-nar",
    "cónsone": "cón-so-ne",
    "cónsono": "cón-so-no",
    "consorcio": "con-sor-cio",
    "consorte": "con-sor-te",
    "conspicua": "cons-pi-cua",
    "conspicuamente": "cons-pi-cua-men-te",
    "conspicuo": "cons-pi-cuo",
    "conspiración": "cons-pi-ra-ción",
    "conspirado": "cons-pi-ra-do",
    "conspirador": "cons-pi-ra-dor",
    "conspiradora": "cons-pi-ra-do-ra",
    "conspirar": "cons-pi-rar",
    "conspirativo": "cons-pi-ra-ti-vo",
    "conspiratorio": "cons-pi-ra-to-rio",
    "constable": "cons-ta-ble",
    "constancia": "cons-tan-cia",
    "constanciense": "cons-tan-cien-se",
    "constante": "cons-tan-te",
    "constantemente": "cons-tan-te-men-te",
    "constantiniano": "cons-tan-ti-nia-no",
    "constantinopla": "cons-tan-ti-no-pla",
    "constantinopolitana": "cons-tan-ti-no-po-li-ta-na",
    "constantinopolitano": "cons-tan-ti-no-po-li-ta-no",
    "constar": "cons-tar",
    "constatación": "cons-ta-ta-ción",
    "constatar": "cons-ta-tar",
    "constelación": "cons-te-la-ción",
    "constelado": "cons-te-la-do",
    "constelar": "cons-te-lar",
    "consternación": "cons-ter-na-ción",
    "consternado": "cons-ter-na-do",
    "consternar": "cons-ter-nar",
    "constipación": "cons-ti-pa-ción",
    "constipado": "cons-ti-pa-do",
    "constipar": "cons-ti-par",
    "constipativa": "cons-ti-pa-ti-va",
    "constipativo": "cons-ti-pa-ti-vo",
    "constitución": "cons-ti-tu-ción",
    "constitucional": "cons-ti-tu-cio-nal",
    "constitucionalidad": "cons-ti-tu-cio-na-li-dad",
    "constitucionalismo": "cons-ti-tu-cio-na-lis-mo",
    "constitucionalista": "cons-ti-tu-cio-na-lis-ta",
    "constitucionalización": "cons-ti-tu-cio-na-li-za-ción",
    "constitucionalizar": "cons-ti-tu-cio-na-li-zar",
    "constitucionalmente": "cons-ti-tu-cio-nal-men-te",
    "constituidor": "cons-ti-tui-dor",
    "constituidora": "cons-ti-tui-do-ra",
    "constituir": "cons-ti-tuir",
    "constitutiva": "cons-ti-tu-ti-va",
    "constitutivo": "cons-ti-tu-ti-vo",
    "constituyente": "cons-ti-tu-yen-te",
    "constreñimiento": "cons-tre-ñi-mien-to",
    "constreñir": "cons-tre-ñir",
    "constricción": "cons-tric-ción",
    "constrictiva": "cons-tric-ti-va",
    "constrictivo": "cons-tric-ti-vo",
    "constrictor": "cons-tric-tor",
    "constrictora": "cons-tric-to-ra",
    "constrictura": "cons-tric-tu-ra",
    "constringente": "cons-trin-gen-te",
    "constringir": "cons-trin-gir",
    "constriñir": "cons-tri-ñir",
    "construcción": "cons-truc-ción",
    "constructiva": "cons-truc-ti-va",
    "constructivamente": "cons-truc-ti-va-men-te",
    "constructivismo": "cons-truc-ti-vis-mo",
    "constructivista": "cons-truc-ti-vis-ta",
    "constructivo": "cons-truc-ti-vo",
    "constructor": "cons-truc-tor",
    "constructora": "cons-truc-to-ra",
    "construido": "cons-trui-do",
    "construir": "cons-truir",
    "consubstanciación": "con-subs-tan-cia-ción",
    "consubstancial": "con-subs-tan-cial",
    "consubstancialidad": "con-subs-tan-cia-li-dad",
    "consubstanciar": "con-subs-tan-ciar",
    "consuegra": "con-sue-gra",
    "consuegrar": "con-sue-grar",
    "consuegro": "con-sue-gro",
    "consuelda": "con-suel-da",
    "consuelo": "con-sue-lo",
    "consueta": "con-sue-ta",
    "consueto": "con-sue-to",
    "consuetud": "con-sue-tud",
    "consuetudinaria": "con-sue-tu-di-na-ria",
    "consuetudinariamente": "con-sue-tu-di-na-ria-men-te",
    "consuetudinario": "con-sue-tu-di-na-rio",
    "cónsul": "cón-sul",
    "cónsula": "cón-su-la",
    "consulado": "con-su-la-do",
    "consular": "con-su-lar",
    "consulazgo": "con-su-laz-go",
    "consulesa": "con-su-le-sa",
    "consulta": "con-sul-ta",
    "consultable": "con-sul-ta-ble",
    "consultación": "con-sul-ta-ción",
    "consultante": "con-sul-tan-te",
    "consultar": "con-sul-tar",
    "consulting": "con-sul-ting",
    "consultiva": "con-sul-ti-va",
    "consultivo": "con-sul-ti-vo",
    "consulto": "con-sul-to",
    "consultor": "con-sul-tor",
    "consultora": "con-sul-to-ra",
    "consultoría": "con-sul-to-rí-a",
    "consultorio": "con-sul-to-rio",
    "consumación": "con-su-ma-ción",
    "consumada": "con-su-ma-da",
    "consumado": "con-su-ma-do",
    "consumador": "con-su-ma-dor",
    "consumadora": "con-su-ma-do-ra",
    "consumar": "con-su-mar",
    "consumativa": "con-su-ma-ti-va",
    "consumativo": "con-su-ma-ti-vo",
    "consumero": "con-su-me-ro",
    "consumible": "con-su-mi-ble",
    "consumición": "con-su-mi-ción",
    "consumida": "con-su-mi-da",
    "consumido": "con-su-mi-do",
    "consumidor": "con-su-mi-dor",
    "consumidora": "con-su-mi-do-ra",
    "consumimiento": "con-su-mi-mien-to",
    "consumir": "con-su-mir",
    "consumismo": "con-su-mis-mo",
    "consumista": "con-su-mis-ta",
    "consumo": "con-su-mo",
    "consuna": "con-su-na",
    "consunción": "con-sun-ción",
    "consuno": "con-su-no",
    "consunta": "con-sun-ta",
    "consuntiva": "con-sun-ti-va",
    "consuntivo": "con-sun-ti-vo",
    "consunto": "con-sun-to",
    "consustanciación": "con-sus-tan-cia-ción",
    "consustancial": "con-sus-tan-cial",
    "consustancialidad": "con-sus-tan-cia-li-dad",
    "consustancialmente": "con-sus-tan-cial-men-te",
    "consustanciar": "con-sus-tan-ciar",
    "conta": "con-ta",
    "contabilidad": "con-ta-bi-li-dad",
    "contabilizar": "con-ta-bi-li-zar",
    "contable": "con-ta-ble",
    "contactar": "con-tac-tar",
    "contacto": "con-tac-to",
    "contactóloga": "con-tac-tó-lo-ga",
    "contactología": "con-tac-to-lo-gí-a",
    "contactólogo": "con-tac-tó-lo-go",
    "contada": "con-ta-da",
    "contadera": "con-ta-de-ra",
    "contadero": "con-ta-de-ro",
    "contado": "con-ta-do",
    "contador": "con-ta-dor",
    "contadora": "con-ta-do-ra",
    "contaduría": "con-ta-du-rí-a",
    "contagiar": "con-ta-giar",
    "contagio": "con-ta-gio",
    "contagión": "con-ta-gión",
    "contagiosa": "con-ta-gio-sa",
    "contagiosidad": "con-ta-gio-si-dad",
    "contagioso": "con-ta-gio-so",
    "container": "con-tai-ner",
    "contal": "con-tal",
    "contamanina": "con-ta-ma-ni-na",
    "contamanino": "con-ta-ma-ni-no",
    "contaminación": "con-ta-mi-na-ción",
    "contaminador": "con-ta-mi-na-dor",
    "contaminadora": "con-ta-mi-na-do-ra",
    "contaminante": "con-ta-mi-nan-te",
    "contaminar": "con-ta-mi-nar",
    "contante": "con-tan-te",
    "contar": "con-tar",
    "contario": "con-ta-rio",
    "contecer": "con-te-cer",
    "contemperar": "con-tem-pe-rar",
    "contemplación": "con-tem-pla-ción",
    "contemplador": "con-tem-pla-dor",
    "contempladora": "con-tem-pla-do-ra",
    "contemplar": "con-tem-plar",
    "contemplativa": "con-tem-pla-ti-va",
    "contemplativamente": "con-tem-pla-ti-va-men-te",
    "contemplativo": "con-tem-pla-ti-vo",
    "contemplatoria": "con-tem-pla-to-ria",
    "contemplatorio": "con-tem-pla-to-rio",
    "contemporánea": "con-tem-po-rá-ne-a",
    "contemporáneamente": "con-tem-po-rá-ne-a-men-te",
    "contemporaneidad": "con-tem-po-ra-nei-dad",
    "contemporáneo": "con-tem-po-rá-ne-o",
    "contemporización": "con-tem-po-ri-za-ción",
    "contemporizador": "con-tem-po-ri-za-dor",
    "contemporizadora": "con-tem-po-ri-za-do-ra",
    "contemporizar": "con-tem-po-ri-zar",
    "contén": "con-tén",
    "contención": "con-ten-ción",
    "contenciosa": "con-ten-cio-sa",
    "contencioso": "con-ten-cio-so",
    "contendedor": "con-ten-de-dor",
    "contender": "con-ten-der",
    "contendiente": "con-ten-dien-te",
    "contendor": "con-ten-dor",
    "contenedor": "con-te-ne-dor",
    "contenedora": "con-te-ne-do-ra",
    "contenencia": "con-te-nen-cia",
    "contener": "con-te-ner",
    "contenible": "con-te-ni-ble",
    "contenida": "con-te-ni-da",
    "contenidamente": "con-te-ni-da-men-te",
    "contenido": "con-te-ni-do",
    "contenta": "con-ten-ta",
    "contentación": "con-ten-ta-ción",
    "contentadiza": "con-ten-ta-di-za",
    "contentadizo": "con-ten-ta-di-zo",
    "contentamiento": "con-ten-ta-mien-to",
    "contentar": "con-ten-tar",
    "contenteza": "con-ten-te-za",
    "contentible": "con-ten-ti-ble",
    "contentiva": "con-ten-ti-va",
    "contentivo": "con-ten-ti-vo",
    "contento": "con-ten-to",
    "contentura": "con-ten-tu-ra",
    "conteo": "con-te-o",
    "contera": "con-te-ra",
    "contérmina": "con-tér-mi-na",
    "contérmino": "con-tér-mi-no",
    "contero": "con-te-ro",
    "conterránea": "con-te-rrá-ne-a",
    "conterráneo": "con-te-rrá-ne-o",
    "contertulia": "con-ter-tu-lia",
    "contertuliana": "con-ter-tu-lia-na",
    "contertuliano": "con-ter-tu-lia-no",
    "contertulio": "con-ter-tu-lio",
    "contesta": "con-tes-ta",
    "contestable": "con-tes-ta-ble",
    "contestación": "con-tes-ta-ción",
    "contestador": "con-tes-ta-dor",
    "contestadora": "con-tes-ta-do-ra",
    "contestana": "con-tes-ta-na",
    "contestano": "con-tes-ta-no",
    "contestar": "con-tes-tar",
    "contestatario": "con-tes-ta-ta-rio",
    "conteste": "con-tes-te",
    "contestón": "con-tes-tón",
    "contestona": "con-tes-to-na",
    "contexto": "con-tex-to",
    "contextual": "con-tex-tual",
    "contextualización": "con-tex-tua-li-za-ción",
    "contextualizar": "con-tex-tua-li-zar",
    "contextuar": "con-tex-tuar",
    "contextura": "con-tex-tu-ra",
    "contía": "con-tí-a",
    "conticinio": "con-ti-ci-nio",
    "contienda": "con-tien-da",
    "contignación": "con-tig-na-ción",
    "contigo": "con-ti-go",
    "contigua": "con-ti-gua",
    "contiguamente": "con-ti-gua-men-te",
    "contigüidad": "con-ti-güi-dad",
    "contiguo": "con-ti-guo",
    "contil": "con-til",
    "contimás": "con-ti-más",
    "contina": "con-ti-na",
    "continencia": "con-ti-nen-cia",
    "continental": "con-ti-nen-tal",
    "continentalidad": "con-ti-nen-ta-li-dad",
    "continente": "con-ti-nen-te",
    "continentemente": "con-ti-nen-te-men-te",
    "contingencia": "con-tin-gen-cia",
    "contingentar": "con-tin-gen-tar",
    "contingente": "con-tin-gen-te",
    "contingentemente": "con-tin-gen-te-men-te",
    "contingible": "con-tin-gi-ble",
    "contino": "con-ti-no",
    "continua": "con-ti-nua",
    "continuación": "con-ti-nua-ción",
    "continuada": "con-ti-nua-da",
    "continuadamente": "con-ti-nua-da-men-te",
    "continuado": "con-ti-nua-do",
    "continuador": "con-ti-nua-dor",
    "continuadora": "con-ti-nua-do-ra",
    "continuamente": "con-ti-nua-men-te",
    "continuamiento": "con-ti-nua-mien-to",
    "continuar": "con-ti-nuar",
    "continuativa": "con-ti-nua-ti-va",
    "continuativo": "con-ti-nua-ti-vo",
    "continuidad": "con-ti-nui-dad",
    "continuismo": "con-ti-nuis-mo",
    "continuista": "con-ti-nuis-ta",
    "continuo": "con-ti-nuo",
    "contiosa": "con-tio-sa",
    "contioso": "con-tio-so",
    "contlapache": "con-tla-pa-che",
    "contlapachear": "con-tla-pa-che-ar",
    "contonear": "con-to-ne-ar",
    "contonearse": "con-to-ne-ar-se",
    "contoneo": "con-to-ne-o",
    "contorcer": "con-tor-cer",
    "contorcerse": "con-tor-cer-se",
    "contorción": "con-tor-ción",
    "contornada": "con-tor-na-da",
    "contornado": "con-tor-na-do",
    "contornar": "con-tor-nar",
    "contornear": "con-tor-ne-ar",
    "contorneo": "con-tor-ne-o",
    "contorno": "con-tor-no",
    "contorsión": "con-tor-sión",
    "contorsionar": "con-tor-sio-nar",
    "contorsionista": "con-tor-sio-nis-ta",
    "contra": "con-tra",
    "contraalisio": "con-tra-a-li-sio",
    "contraalmirante": "con-tra-al-mi-ran-te",
    "contraamura": "con-tra-a-mu-ra",
    "contraanálisis": "con-tra-a-ná-li-sis",
    "contraaproches": "con-tra-a-pro-ches",
    "contraargumentación": "con-tra-ar-gu-men-ta-ción",
    "contraargumentar": "con-tra-ar-gu-men-tar",
    "contraargumento": "con-tra-ar-gu-men-to",
    "contraarmadura": "con-tra-ar-ma-du-ra",
    "contraarmiños": "con-tra-ar-mi-ños",
    "contraatacar": "con-tra-a-ta-car",
    "contraataguía": "con-tra-a-ta-guí-a",
    "contraataque": "con-tra-a-ta-que",
    "contraaviso": "con-tra-a-vi-so",
    "contrabajete": "con-tra-ba-je-te",
    "contrabajista": "con-tra-ba-jis-ta",
    "contrabajo": "con-tra-ba-jo",
    "contrabajón": "con-tra-ba-jón",
    "contrabajonista": "con-tra-ba-jo-nis-ta",
    "contrabalancear": "con-tra-ba-lan-ce-ar",
    "contrabalanza": "con-tra-ba-lan-za",
    "contrabandado": "con-tra-ban-da-do",
    "contrabandear": "con-tra-ban-de-ar",
    "contrabandeo": "con-tra-ban-de-o",
    "contrabandismo": "con-tra-ban-dis-mo",
    "contrabandista": "con-tra-ban-dis-ta",
    "contrabando": "con-tra-ban-do",
    "contrabarrera": "con-tra-ba-rre-ra",
    "contrabasa": "con-tra-ba-sa",
    "contrabatería": "con-tra-ba-te-rí-a",
    "contrabatir": "con-tra-ba-tir",
    "contrabloqueo": "con-tra-blo-que-o",
    "contrabolina": "con-tra-bo-li-na",
    "contrabranque": "con-tra-bran-que",
    "contrabraza": "con-tra-bra-za",
    "contracaja": "con-tra-ca-ja",
    "contracambio": "con-tra-cam-bio",
    "contracampo": "con-tra-cam-po",
    "contracanal": "con-tra-ca-nal",
    "contracancha": "con-tra-can-cha",
    "contracandela": "con-tra-can-de-la",
    "contracanto": "con-tra-can-to",
    "contracara": "con-tra-ca-ra",
    "contracarril": "con-tra-ca-rril",
    "contracarta": "con-tra-car-ta",
    "contracción": "con-trac-ción",
    "contracebadera": "con-tra-ce-ba-de-ra",
    "contracédula": "con-tra-cé-du-la",
    "contracepción": "con-tra-cep-ción",
    "contraceptivo": "con-tra-cep-ti-vo",
    "contrachapado": "con-tra-cha-pa-do",
    "contrachapeado": "con-tra-cha-pe-a-do",
    "contracifra": "con-tra-ci-fra",
    "contraclave": "con-tra-cla-ve",
    "contracodaste": "con-tra-co-das-te",
    "contraconcepción": "con-tra-con-cep-ción",
    "contraconceptivo": "con-tra-con-cep-ti-vo",
    "contracorriente": "con-tra-co-rrien-te",
    "contracosta": "con-tra-cos-ta",
    "contractación": "con-trac-ta-ción",
    "contractibilidad": "con-trac-ti-bi-li-dad",
    "contráctil": "con-trác-til",
    "contractilidad": "con-trac-ti-li-dad",
    "contractiva": "con-trac-ti-va",
    "contractivo": "con-trac-ti-vo",
    "contracto": "con-trac-to",
    "contractual": "con-trac-tual",
    "contractualmente": "con-trac-tual-men-te",
    "contractura": "con-trac-tu-ra",
    "contracuartelada": "con-tra-cuar-te-la-da",
    "contracuartelado": "con-tra-cuar-te-la-do",
    "contracubierta": "con-tra-cu-bier-ta",
    "contracultura": "con-tra-cul-tu-ra",
    "contracultural": "con-tra-cul-tu-ral",
    "contracurva": "con-tra-cur-va",
    "contrada": "con-tra-da",
    "contradanza": "con-tra-dan-za",
    "contradecidor": "con-tra-de-ci-dor",
    "contradecidora": "con-tra-de-ci-do-ra",
    "contradecir": "con-tra-de-cir",
    "contradicción": "con-tra-dic-ción",
    "contradicha": "con-tra-di-cha",
    "contradicho": "con-tra-di-cho",
    "contradictor": "con-tra-dic-tor",
    "contradictora": "con-tra-dic-to-ra",
    "contradictoria": "con-tra-dic-to-ria",
    "contradictoriamente": "con-tra-dic-to-ria-men-te",
    "contradictorio": "con-tra-dic-to-rio",
    "contradiós": "con-tra-diós",
    "contradique": "con-tra-di-que",
    "contradriza": "con-tra-dri-za",
    "contradurmente": "con-tra-dur-men-te",
    "contradurmiente": "con-tra-dur-mien-te",
    "contraejemplo": "con-tra-e-jem-plo",
    "contraelectromotriz": "con-tra-e-lec-tro-mo-triz",
    "contraemboscada": "con-tra-em-bos-ca-da",
    "contraembozo": "con-tra-em-bo-zo",
    "contraenvite": "con-tra-en-vi-te",
    "contraer": "con-tra-er",
    "contraescarpa": "con-tra-es-car-pa",
    "contraescota": "con-tra-es-co-ta",
    "contraescotín": "con-tra-es-co-tín",
    "contraescritura": "con-tra-es-cri-tu-ra",
    "contraespionaje": "con-tra-es-pio-na-je",
    "contraestay": "con-tra-es-tay",
    "contrafacción": "con-tra-fac-ción",
    "contrafacer": "con-tra-fa-cer",
    "contrafagot": "con-tra-fa-got",
    "contrafajada": "con-tra-fa-ja-da",
    "contrafajado": "con-tra-fa-ja-do",
    "contrafallar": "con-tra-fa-llar",
    "contrafallo": "con-tra-fa-llo",
    "contrafigura": "con-tra-fi-gu-ra",
    "contrafilo": "con-tra-fi-lo",
    "contraflorada": "con-tra-flo-ra-da",
    "contraflorado": "con-tra-flo-ra-do",
    "contrafoque": "con-tra-fo-que",
    "contrafoso": "con-tra-fo-so",
    "contrafuego": "con-tra-fue-go",
    "contrafuero": "con-tra-fue-ro",
    "contrafuerte": "con-tra-fuer-te",
    "contrafuga": "con-tra-fu-ga",
    "contragolpe": "con-tra-gol-pe",
    "contragolpear": "con-tra-gol-pe-ar",
    "contraguardia": "con-tra-guar-dia",
    "contraguerrilla": "con-tra-gue-rri-lla",
    "contraguía": "con-tra-guí-a",
    "contrahacedor": "con-tra-ha-ce-dor",
    "contrahacedora": "con-tra-ha-ce-do-ra",
    "contrahacer": "con-tra-ha-cer",
    "contrahacimiento": "con-tra-ha-ci-mien-to",
    "contrahaz": "con-tra-haz",
    "contrahecha": "con-tra-he-cha",
    "contrahecho": "con-tra-he-cho",
    "contrahechura": "con-tra-he-chu-ra",
    "contrahierba": "con-tra-hier-ba",
    "contrahilera": "con-trahi-le-ra",
    "contrahílo": "con-tra-hí-lo",
    "contrahorte": "con-tra-hor-te",
    "contrahuella": "con-tra-hue-lla",
    "contraindicación": "con-train-di-ca-ción",
    "contraindicado": "con-train-di-ca-do",
    "contraindicante": "con-train-di-can-te",
    "contraindicar": "con-train-di-car",
    "contrainsurgencia": "con-train-sur-gen-cia",
    "contrainteligencia": "con-train-te-li-gen-cia",
    "contraír": "con-tra-ír",
    "contrajudía": "con-tra-ju-dí-a",
    "contralecho": "con-tra-le-cho",
    "contralizo": "con-tra-li-zo",
    "contralla": "con-tra-lla",
    "contrallar": "con-tra-llar",
    "contrallo": "con-tra-llo",
    "contralmirantazgo": "con-tral-mi-ran-taz-go",
    "contralmirante": "con-tral-mi-ran-te",
    "contralor": "con-tra-lor",
    "contralorear": "con-tra-lo-re-ar",
    "contraloría": "con-tra-lo-rí-a",
    "contralto": "con-tral-to",
    "contraluz": "con-tra-luz",
    "contramaestre": "con-tra-ma-es-tre",
    "contramalla": "con-tra-ma-lla",
    "contramalladura": "con-tra-ma-lla-du-ra",
    "contramallar": "con-tra-ma-llar",
    "contramandar": "con-tra-man-dar",
    "contramandato": "con-tra-man-da-to",
    "contramangas": "con-tra-man-gas",
    "contramanifestación": "con-tra-ma-ni-fes-ta-ción",
    "contramano": "con-tra-ma-no",
    "contramarca": "con-tra-mar-ca",
    "contramarcar": "con-tra-mar-car",
    "contramarcha": "con-tra-mar-cha",
    "contramarchar": "con-tra-mar-char",
    "contramarco": "con-tra-mar-co",
    "contramarea": "con-tra-ma-re-a",
    "contramatada": "con-tra-ma-ta-da",
    "contramatar": "con-tra-ma-tar",
    "contramedida": "con-tra-me-di-da",
    "contramesana": "con-tra-me-sa-na",
    "contramina": "con-tra-mi-na",
    "contraminar": "con-tra-mi-nar",
    "contramuelle": "con-tra-mue-lle",
    "contramuralla": "con-tra-mu-ra-lla",
    "contramuro": "con-tra-mu-ro",
    "contranatural": "con-tra-na-tu-ral",
    "contranota": "con-tra-no-ta",
    "contraofensiva": "con-tra-o-fen-si-va",
    "contraoferta": "con-tra-o-fer-ta",
    "contraorden": "con-tra-or-den",
    "contrapalada": "con-tra-pa-la-da",
    "contrapalado": "con-tra-pa-la-do",
    "contrapalanquín": "con-tra-pa-lan-quín",
    "contrapar": "con-tra-par",
    "contrapariente": "con-tra-pa-rien-te",
    "contrapartida": "con-tra-par-ti-da",
    "contrapás": "con-tra-pás",
    "contrapasamiento": "con-tra-pa-sa-mien-to",
    "contrapasar": "con-tra-pa-sar",
    "contrapaso": "con-tra-pa-so",
    "contrapear": "con-tra-pe-ar",
    "contrapechar": "con-tra-pe-char",
    "contrapelear": "con-tra-pe-le-ar",
    "contrapelo": "con-tra-pe-lo",
    "contrapesar": "con-tra-pe-sar",
    "contrapeso": "con-tra-pe-so",
    "contrapeste": "con-tra-pes-te",
    "contrapicado": "con-tra-pi-ca-do",
    "contrapilastra": "con-tra-pi-las-tra",
    "contraplano": "con-tra-pla-no",
    "contrapoder": "con-tra-po-der",
    "contraponedor": "con-tra-po-ne-dor",
    "contraponedora": "con-tra-po-ne-do-ra",
    "contraponer": "con-tra-po-ner",
    "contraportada": "con-tra-por-ta-da",
    "contraposición": "con-tra-po-si-ción",
    "contrapotenzada": "con-tra-po-ten-za-da",
    "contrapotenzado": "con-tra-po-ten-za-do",
    "contrapozo": "con-tra-po-zo",
    "contraprestación": "con-tra-pres-ta-ción",
    "contraprincipio": "con-tra-prin-ci-pio",
    "contraproducente": "con-tra-pro-du-cen-te",
    "contraprogramación": "con-tra-pro-gra-ma-ción",
    "contraproposición": "con-tra-pro-po-si-ción",
    "contrapropuesta": "con-tra-pro-pues-ta",
    "contraproyecto": "con-tra-pro-yec-to",
    "contraprueba": "con-tra-prue-ba",
    "contrapuerta": "con-tra-puer-ta",
    "contrapuesta": "con-tra-pues-ta",
    "contrapuesto": "con-tra-pues-to",
    "contrapugnar": "con-tra-pug-nar",
    "contrapunta": "con-tra-pun-ta",
    "contrapuntante": "con-tra-pun-tan-te",
    "contrapuntar": "con-tra-pun-tar",
    "contrapuntarse": "con-tra-pun-tar-se",
    "contrapuntear": "con-tra-pun-te-ar",
    "contrapunteo": "con-tra-pun-te-o",
    "contrapuntista": "con-tra-pun-tis-ta",
    "contrapuntístico": "con-tra-pun-tís-ti-co",
    "contrapunto": "con-tra-pun-to",
    "contrapunzar": "con-tra-pun-zar",
    "contrapunzón": "con-tra-pun-zón",
    "contraquilla": "con-tra-qui-lla",
    "contraria": "con-tra-ria",
    "contrariado": "con-tra-ria-do",
    "contrariador": "con-tra-ria-dor",
    "contrariadora": "con-tra-ria-do-ra",
    "contrariamente": "con-tra-ria-men-te",
    "contrariar": "con-tra-riar",
    "contraridad": "con-tra-ri-dad",
    "contrariedad": "con-tra-rie-dad",
    "contrario": "con-tra-rio",
    "contrarraya": "con-tra-rra-ya",
    "contrarreforma": "con-tra-rre-for-ma",
    "contrarreformista": "con-tra-rre-for-mis-ta",
    "contrarregistro": "con-tra-rre-gis-tro",
    "contrarreguera": "con-tra-rre-gue-ra",
    "contrarreloj": "con-tra-rre-loj",
    "contrarrelojista": "con-tra-rre-lo-jis-ta",
    "contrarréplica": "con-tra-rré-pli-ca",
    "contrarrestar": "con-tra-rres-tar",
    "contrarresto": "con-tra-rres-to",
    "contrarrevolución": "con-tra-rre-vo-lu-ción",
    "contrarrevolucionaria": "con-tra-rre-vo-lu-cio-na-ria",
    "contrarrevolucionario": "con-tra-rre-vo-lu-cio-na-rio",
    "contrarroda": "con-tra-rro-da",
    "contrarronda": "con-tra-rron-da",
    "contrarrotura": "con-tra-rro-tu-ra",
    "contrasalva": "con-tra-sal-va",
    "contraseguro": "con-tra-se-gu-ro",
    "contrasellar": "con-tra-se-llar",
    "contrasello": "con-tra-se-llo",
    "contraseña": "con-tra-se-ña",
    "contraseñar": "con-tra-se-ñar",
    "contraseño": "con-tra-se-ño",
    "contrasentido": "con-tra-sen-ti-do",
    "contrastabilidad": "con-tras-ta-bi-li-dad",
    "contrastable": "con-tras-ta-ble",
    "contrastación": "con-tras-ta-ción",
    "contrastante": "con-tras-tan-te",
    "contrastar": "con-tras-tar",
    "contraste": "con-tras-te",
    "contrastivo": "con-tras-ti-vo",
    "contrasto": "con-tras-to",
    "contrasuelazo": "con-tra-sue-la-zo",
    "contrata": "con-tra-ta",
    "contratación": "con-tra-ta-ción",
    "contratamiento": "con-tra-ta-mien-to",
    "contratante": "con-tra-tan-te",
    "contratapa": "con-tra-ta-pa",
    "contratar": "con-tra-tar",
    "contratela": "con-tra-te-la",
    "contratenor": "con-tra-te-nor",
    "contraterrorismo": "con-tra-te-rro-ris-mo",
    "contraterrorista": "con-tra-te-rro-ris-ta",
    "contratiempo": "con-tra-tiem-po",
    "contratista": "con-tra-tis-ta",
    "contrato": "con-tra-to",
    "contratorpedero": "con-tra-tor-pe-de-ro",
    "contratransferencia": "con-tra-trans-fe-ren-cia",
    "contratreta": "con-tra-tre-ta",
    "contratrinchera": "con-tra-trin-che-ra",
    "contratuerca": "con-tra-tuer-ca",
    "contravalación": "con-tra-va-la-ción",
    "contravalar": "con-tra-va-lar",
    "contravalor": "con-tra-va-lor",
    "contravapor": "con-tra-va-por",
    "contravención": "con-tra-ven-ción",
    "contraveneno": "con-tra-ve-ne-no",
    "contravenidor": "con-tra-ve-ni-dor",
    "contravenidora": "con-tra-ve-ni-do-ra",
    "contravenimiento": "con-tra-ve-ni-mien-to",
    "contravenir": "con-tra-ve-nir",
    "contraventana": "con-tra-ven-ta-na",
    "contraventor": "con-tra-ven-tor",
    "contraventora": "con-tra-ven-to-ra",
    "contraventura": "con-tra-ven-tu-ra",
    "contraverada": "con-tra-ve-ra-da",
    "contraverado": "con-tra-ve-ra-do",
    "contraveros": "con-tra-ve-ros",
    "contravía": "con-tra-ví-a",
    "contravidriera": "con-tra-vi-drie-ra",
    "contravoluta": "con-tra-vo-lu-ta",
    "contray": "con-tray",
    "contrayente": "con-tra-yen-te",
    "contre": "con-tre",
    "contrecha": "con-tre-cha",
    "contrecho": "con-tre-cho",
    "contremecer": "con-tre-me-cer",
    "contrera": "con-tre-ra",
    "contreras": "con-tre-ras",
    "contrero": "con-tre-ro",
    "contrete": "con-tre-te",
    "contri": "con-tri",
    "contribución": "con-tri-bu-ción",
    "contribuidor": "con-tri-bui-dor",
    "contribuidora": "con-tri-bui-do-ra",
    "contribuir": "con-tri-buir",
    "contribular": "con-tri-bu-lar",
    "contributaria": "con-tri-bu-ta-ria",
    "contributario": "con-tri-bu-ta-rio",
    "contributiva": "con-tri-bu-ti-va",
    "contributivo": "con-tri-bu-ti-vo",
    "contribuyente": "con-tri-bu-yen-te",
    "contrición": "con-tri-ción",
    "contrincante": "con-trin-can-te",
    "contristar": "con-tris-tar",
    "contrita": "con-tri-ta",
    "contritamente": "con-tri-ta-men-te",
    "contrito": "con-tri-to",
    "control": "con-trol",
    "controlable": "con-tro-la-ble",
    "controlador": "con-tro-la-dor",
    "controladora": "con-tro-la-do-ra",
    "controlar": "con-tro-lar",
    "controversia": "con-tro-ver-sia",
    "controversial": "con-tro-ver-sial",
    "controversista": "con-tro-ver-sis-ta",
    "controvertible": "con-tro-ver-ti-ble",
    "controvertido": "con-tro-ver-ti-do",
    "controvertir": "con-tro-ver-tir",
    "contubernal": "con-tu-ber-nal",
    "contubernio": "con-tu-ber-nio",
    "contumacia": "con-tu-ma-cia",
    "contumaz": "con-tu-maz",
    "contumazmente": "con-tu-maz-men-te",
    "contumelia": "con-tu-me-lia",
    "contumeliosa": "con-tu-me-lio-sa",
    "contumelioso": "con-tu-me-lio-so",
    "contumeria": "con-tu-me-ria",
    "contumeriar": "con-tu-me-riar",
    "contumerioso": "con-tu-me-rio-so",
    "contundencia": "con-tun-den-cia",
    "contundente": "con-tun-den-te",
    "contundentemente": "con-tun-den-te-men-te",
    "contundir": "con-tun-dir",
    "conturbación": "con-tur-ba-ción",
    "conturbada": "con-tur-ba-da",
    "conturbado": "con-tur-ba-do",
    "conturbador": "con-tur-ba-dor",
    "conturbadora": "con-tur-ba-do-ra",
    "conturbar": "con-tur-bar",
    "conturbativa": "con-tur-ba-ti-va",
    "conturbativo": "con-tur-ba-ti-vo",
    "contusa": "con-tu-sa",
    "contusión": "con-tu-sión",
    "contusionar": "con-tu-sio-nar",
    "contuso": "con-tu-so",
    "contutor": "con-tu-tor",
    "conuco": "co-nu-co",
    "conuquera": "co-nu-que-ra",
    "conuquero": "co-nu-que-ro",
    "conurbación": "co-nur-ba-ción",
    "conurbado": "co-nur-ba-do",
    "conurbano": "co-nur-ba-no",
    "convalaria": "con-va-la-ria",
    "convalecencia": "con-va-le-cen-cia",
    "convalecer": "con-va-le-cer",
    "convaleciente": "con-va-le-cien-te",
    "convalecimiento": "con-va-le-ci-mien-to",
    "convalidación": "con-va-li-da-ción",
    "convalidar": "con-va-li-dar",
    "convección": "con-vec-ción",
    "convecina": "con-ve-ci-na",
    "convecino": "con-ve-ci-no",
    "convectivo": "con-vec-ti-vo",
    "convector": "con-vec-tor",
    "convencedor": "con-ven-ce-dor",
    "convencedora": "con-ven-ce-do-ra",
    "convencer": "con-ven-cer",
    "convencimiento": "con-ven-ci-mien-to",
    "convención": "con-ven-ción",
    "convencional": "con-ven-cio-nal",
    "convencionalidad": "con-ven-cio-na-li-dad",
    "convencionalismo": "con-ven-cio-na-lis-mo",
    "convencionalista": "con-ven-cio-na-lis-ta",
    "convencionalmente": "con-ven-cio-nal-men-te",
    "convenencia": "con-ve-nen-cia",
    "convenenciero": "con-ve-nen-cie-ro",
    "convenible": "con-ve-ni-ble",
    "convenido": "con-ve-ni-do",
    "conveniencia": "con-ve-nien-cia",
    "conveniente": "con-ve-nien-te",
    "convenientemente": "con-ve-nien-te-men-te",
    "convenio": "con-ve-nio",
    "convenir": "con-ve-nir",
    "conventico": "con-ven-ti-co",
    "conventícula": "con-ven-tí-cu-la",
    "conventículo": "con-ven-tí-cu-lo",
    "conventillear": "con-ven-ti-lle-ar",
    "conventilleo": "con-ven-ti-lle-o",
    "conventillera": "con-ven-ti-lle-ra",
    "conventillero": "con-ven-ti-lle-ro",
    "conventillo": "con-ven-ti-llo",
    "convento": "con-ven-to",
    "conventual": "con-ven-tual",
    "conventualidad": "con-ven-tua-li-dad",
    "conventualmente": "con-ven-tual-men-te",
    "convergencia": "con-ver-gen-cia",
    "convergente": "con-ver-gen-te",
    "converger": "con-ver-ger",
    "convergir": "con-ver-gir",
    "conversa": "con-ver-sa",
    "conversable": "con-ver-sa-ble",
    "conversación": "con-ver-sa-ción",
    "conversacional": "con-ver-sa-cio-nal",
    "conversacionista": "con-ver-sa-cio-nis-ta",
    "conversada": "con-ver-sa-da",
    "conversadera": "con-ver-sa-de-ra",
    "conversador": "con-ver-sa-dor",
    "conversadora": "con-ver-sa-do-ra",
    "conversamiento": "con-ver-sa-mien-to",
    "conversar": "con-ver-sar",
    "conversativa": "con-ver-sa-ti-va",
    "conversativo": "con-ver-sa-ti-vo",
    "conversatorio": "con-ver-sa-to-rio",
    "conversión": "con-ver-sión",
    "conversiva": "con-ver-si-va",
    "conversivo": "con-ver-si-vo",
    "converso": "con-ver-so",
    "conversón": "con-ver-són",
    "conversona": "con-ver-so-na",
    "convertibilidad": "con-ver-ti-bi-li-dad",
    "convertible": "con-ver-ti-ble",
    "convertidor": "con-ver-ti-dor",
    "convertimiento": "con-ver-ti-mien-to",
    "convertir": "con-ver-tir",
    "convexa": "con-ve-xa",
    "convexidad": "con-ve-xi-dad",
    "convexo": "con-ve-xo",
    "convexocóncavo": "con-ve-xo-cón-ca-vo",
    "convicción": "con-vic-ción",
    "convicio": "con-vi-cio",
    "convicta": "con-vic-ta",
    "convicto": "con-vic-to",
    "convictor": "con-vic-tor",
    "convictorio": "con-vic-to-rio",
    "convidada": "con-vi-da-da",
    "convidado": "con-vi-da-do",
    "convidador": "con-vi-da-dor",
    "convidadora": "con-vi-da-do-ra",
    "convidar": "con-vi-dar",
    "convincente": "con-vin-cen-te",
    "convincentemente": "con-vin-cen-te-men-te",
    "convite": "con-vi-te",
    "convival": "con-vi-val",
    "convivencia": "con-vi-ven-cia",
    "convivialidad": "con-vi-via-li-dad",
    "conviviente": "con-vi-vien-te",
    "convivio": "con-vi-vio",
    "convivir": "con-vi-vir",
    "convocación": "con-vo-ca-ción",
    "convocadera": "con-vo-ca-de-ra",
    "convocadero": "con-vo-ca-de-ro",
    "convocador": "con-vo-ca-dor",
    "convocadora": "con-vo-ca-do-ra",
    "convocante": "con-vo-can-te",
    "convocar": "con-vo-car",
    "convocatoria": "con-vo-ca-to-ria",
    "convocatorio": "con-vo-ca-to-rio",
    "convolar": "con-vo-lar",
    "convolvulácea": "con-vol-vu-lá-ce-a",
    "convolvuláceo": "con-vol-vu-lá-ce-o",
    "convólvulo": "con-vól-vu-lo",
    "convoy": "con-voy",
    "convoyar": "con-vo-yar",
    "convulsa": "con-vul-sa",
    "convulsamente": "con-vul-sa-men-te",
    "convulsión": "con-vul-sión",
    "convulsionante": "con-vul-sio-nan-te",
    "convulsionar": "con-vul-sio-nar",
    "convulsionaria": "con-vul-sio-na-ria",
    "convulsionario": "con-vul-sio-na-rio",
    "convulsiva": "con-vul-si-va",
    "convulsivamente": "con-vul-si-va-men-te",
    "convulsivo": "con-vul-si-vo",
    "convulso": "con-vul-so",
    "convusco": "con-vus-co",
    "conyector": "con-yec-tor",
    "conyúdice": "con-yú-di-ce",
    "conyugada": "con-yu-ga-da",
    "conyugado": "con-yu-ga-do",
    "conyugal": "con-yu-gal",
    "conyugalmente": "con-yu-gal-men-te",
    "cónyuge": "cón-yu-ge",
    "conyugicida": "con-yu-gi-ci-da",
    "conyugicidio": "con-yu-gi-ci-dio",
    "cooficial": "co-o-fi-cial",
    "cooficialidad": "co-o-fi-cia-li-dad",
    "coona": "co-o-na",
    "cooperación": "co-o-pe-ra-ción",
    "cooperador": "co-o-pe-ra-dor",
    "cooperadora": "co-o-pe-ra-do-ra",
    "cooperante": "co-o-pe-ran-te",
    "cooperar": "co-o-pe-rar",
    "cooperario": "co-o-pe-ra-rio",
    "cooperativa": "co-o-pe-ra-ti-va",
    "cooperativamente": "co-o-pe-ra-ti-va-men-te",
    "cooperativismo": "co-o-pe-ra-ti-vis-mo",
    "cooperativista": "co-o-pe-ra-ti-vis-ta",
    "cooperativo": "co-o-pe-ra-ti-vo",
    "coopositor": "co-o-po-si-tor",
    "coopositora": "co-o-po-si-to-ra",
    "cooptación": "co-op-ta-ción",
    "cooptar": "co-op-tar",
    "coordenada": "co-or-de-na-da",
    "coordenadas": "co-or-de-na-das",
    "coordenado": "co-or-de-na-do",
    "coordinación": "co-or-di-na-ción",
    "coordinada": "co-or-di-na-da",
    "coordinadamente": "co-or-di-na-da-men-te",
    "coordinado": "co-or-di-na-do",
    "coordinador": "co-or-di-na-dor",
    "coordinadora": "co-or-di-na-do-ra",
    "coordinamiento": "co-or-di-na-mien-to",
    "coordinante": "co-or-di-nan-te",
    "coordinar": "co-or-di-nar",
    "coordinativa": "co-or-di-na-ti-va",
    "coordinativo": "co-or-di-na-ti-vo",
    "copa": "co-pa",
    "copacabaneña": "co-pa-ca-ba-ne-ña",
    "copacabaneño": "co-pa-ca-ba-ne-ño",
    "copada": "co-pa-da",
    "copado": "co-pa-do",
    "copador": "co-pa-dor",
    "copaiba": "co-pai-ba",
    "copaína": "co-pa-í-na",
    "copal": "co-pal",
    "copalchí": "co-pal-chí",
    "copalear": "co-pa-le-ar",
    "copaleo": "co-pa-le-o",
    "copalillo": "co-pa-li-llo",
    "copaneca": "co-pa-ne-ca",
    "copaneco": "co-pa-ne-co",
    "cópano": "có-pa-no",
    "copante": "co-pan-te",
    "copaquira": "co-pa-qui-ra",
    "copar": "co-par",
    "coparticipación": "co-par-ti-ci-pa-ción",
    "copartícipe": "co-par-tí-ci-pe",
    "copartidaria": "co-par-ti-da-ria",
    "copartidario": "co-par-ti-da-rio",
    "copatrocinador": "co-pa-tro-ci-na-dor",
    "copatrocinar": "co-pa-tro-ci-nar",
    "copayero": "co-pa-ye-ro",
    "copazo": "co-pa-zo",
    "cope": "co-pe",
    "copé": "co-pé",
    "copeado": "co-pe-a-do",
    "copear": "co-pe-ar",
    "copec": "co-pec",
    "copeca": "co-pe-ca",
    "copeicillo": "co-pei-ci-llo",
    "copela": "co-pe-la",
    "copelación": "co-pe-la-ción",
    "copelar": "co-pe-lar",
    "copeo": "co-pe-o",
    "copépodo": "co-pé-po-do",
    "copera": "co-pe-ra",
    "coperacha": "co-pe-ra-cha",
    "copernicana": "co-per-ni-ca-na",
    "copernicanismo": "co-per-ni-ca-nis-mo",
    "copernicano": "co-per-ni-ca-no",
    "copero": "co-pe-ro",
    "copeta": "co-pe-ta",
    "copete": "co-pe-te",
    "copetear": "co-pe-te-ar",
    "copetín": "co-pe-tín",
    "copetinera": "co-pe-ti-ne-ra",
    "copetón": "co-pe-tón",
    "copetona": "co-pe-to-na",
    "copetuda": "co-pe-tu-da",
    "copetudo": "co-pe-tu-do",
    "copey": "co-pey",
    "copeyano": "co-pe-ya-no",
    "copia": "co-pia",
    "copiada": "co-pia-da",
    "copiador": "co-pia-dor",
    "copiadora": "co-pia-do-ra",
    "copiante": "co-pian-te",
    "copiapina": "co-pia-pi-na",
    "copiapino": "co-pia-pi-no",
    "copiar": "co-piar",
    "copichuela": "co-pi-chue-la",
    "copihue": "co-pi-hue",
    "copilación": "co-pi-la-ción",
    "copilador": "co-pi-la-dor",
    "copiladora": "co-pi-la-do-ra",
    "copilar": "co-pi-lar",
    "copilla": "co-pi-lla",
    "copiloto": "co-pi-lo-to",
    "copín": "co-pín",
    "copina": "co-pi-na",
    "copinar": "co-pi-nar",
    "copino": "co-pi-no",
    "copinol": "co-pi-nol",
    "copión": "co-pión",
    "copiona": "co-pio-na",
    "copiosa": "co-pio-sa",
    "copiosamente": "co-pio-sa-men-te",
    "copiosidad": "co-pio-si-dad",
    "copioso": "co-pio-so",
    "copista": "co-pis-ta",
    "copistera": "co-pis-te-ra",
    "copistería": "co-pis-te-rí-a",
    "copistero": "co-pis-te-ro",
    "copito": "co-pi-to",
    "copla": "co-pla",
    "coplanario": "co-pla-na-rio",
    "copleador": "co-ple-a-dor",
    "coplear": "co-ple-ar",
    "coplera": "co-ple-ra",
    "coplería": "co-ple-rí-a",
    "coplero": "co-ple-ro",
    "coplista": "co-plis-ta",
    "coplón": "co-plón",
    "coplona": "co-plo-na",
    "copo": "co-po",
    "copón": "co-pón",
    "coposa": "co-po-sa",
    "coposesión": "co-po-se-sión",
    "coposesor": "co-po-se-sor",
    "coposesora": "co-po-se-so-ra",
    "coposo": "co-po-so",
    "copra": "co-pra",
    "copresidenta": "co-pre-si-den-ta",
    "copresidente": "co-pre-si-den-te",
    "copretérito": "co-pre-té-ri-to",
    "copríncipe": "co-prín-ci-pe",
    "coproducción": "co-pro-duc-ción",
    "coproducir": "co-pro-du-cir",
    "coproductor": "co-pro-duc-tor",
    "coproductora": "co-pro-duc-to-ra",
    "coprófaga": "co-pró-fa-ga",
    "coprofagia": "co-pro-fa-gia",
    "coprófago": "co-pró-fa-go",
    "coprolalia": "co-pro-la-lia",
    "coprolito": "co-pro-li-to",
    "coprología": "co-pro-lo-gí-a",
    "coprológico": "co-pro-ló-gi-co",
    "copropiedad": "co-pro-pie-dad",
    "copropietaria": "co-pro-pie-ta-ria",
    "copropietario": "co-pro-pie-ta-rio",
    "coprotagonista": "co-pro-ta-go-nis-ta",
    "coprotagonizar": "co-pro-ta-go-ni-zar",
    "copta": "cop-ta",
    "cóptica": "cóp-ti-ca",
    "cóptico": "cóp-ti-co",
    "copto": "cop-to",
    "copucha": "co-pu-cha",
    "copuchar": "co-pu-char",
    "copuchear": "co-pu-che-ar",
    "copuchento": "co-pu-chen-to",
    "copuda": "co-pu-da",
    "copudo": "co-pu-do",
    "cópula": "có-pu-la",
    "copulación": "co-pu-la-ción",
    "copulador": "co-pu-la-dor",
    "copular": "co-pu-lar",
    "copulativa": "co-pu-la-ti-va",
    "copulativamente": "co-pu-la-ti-va-men-te",
    "copulativo": "co-pu-la-ti-vo",
    "coque": "co-que",
    "coquear": "co-que-ar",
    "coquera": "co-que-ra",
    "coquería": "co-que-rí-a",
    "coquero": "co-que-ro",
    "coqueta": "co-que-ta",
    "coquetamente": "co-que-ta-men-te",
    "coquetear": "co-que-te-ar",
    "coqueteo": "co-que-te-o",
    "coquetería": "co-que-te-rí-a",
    "coquetismo": "co-que-tis-mo",
    "coqueto": "co-que-to",
    "coquetón": "co-que-tón",
    "coquetona": "co-que-to-na",
    "coquetonamente": "co-que-to-na-men-te",
    "coquí": "co-quí",
    "coquilla": "co-qui-lla",
    "coquillo": "co-qui-llo",
    "coquimbana": "co-quim-ba-na",
    "coquimbano": "co-quim-ba-no",
    "coquina": "co-qui-na",
    "coquinaria": "co-qui-na-ria",
    "coquinario": "co-qui-na-rio",
    "coquinera": "co-qui-ne-ra",
    "coquinero": "co-qui-ne-ro",
    "coquino": "co-qui-no",
    "coquito": "co-qui-to",
    "coquizable": "co-qui-za-ble",
    "coquización": "co-qui-za-ción",
    "coquizar": "co-qui-zar",
    "cora": "co-ra",
    "coracán": "co-ra-cán",
    "corácea": "co-rá-ce-a",
    "coráceo": "co-rá-ce-o",
    "coracero": "co-ra-ce-ro",
    "coracha": "co-ra-cha",
    "coraciforme": "co-ra-ci-for-me",
    "coracina": "co-ra-ci-na",
    "coracoides": "co-ra-coi-des",
    "corada": "co-ra-da",
    "coraje": "co-ra-je",
    "corajina": "co-ra-ji-na",
    "corajosa": "co-ra-jo-sa",
    "corajoso": "co-ra-jo-so",
    "corajuda": "co-ra-ju-da",
    "corajudamente": "co-ra-ju-da-men-te",
    "corajudo": "co-ra-ju-do",
    "coral": "co-ral",
    "coralario": "co-ra-la-rio",
    "coralera": "co-ra-le-ra",
    "coralero": "co-ra-le-ro",
    "coralífera": "co-ra-lí-fe-ra",
    "coralífero": "co-ra-lí-fe-ro",
    "coralígena": "co-ra-lí-ge-na",
    "coralígeno": "co-ra-lí-ge-no",
    "coralillo": "co-ra-li-llo",
    "coralina": "co-ra-li-na",
    "coralino": "co-ra-li-no",
    "coralito": "co-ra-li-to",
    "corambre": "co-ram-bre",
    "corambrero": "co-ram-bre-ro",
    "coramvobis": "co-ram-vo-bis",
    "corán": "co-rán",
    "corana": "co-ra-na",
    "coránica": "co-rá-ni-ca",
    "coránico": "co-rá-ni-co",
    "corar": "co-rar",
    "coras": "co-ras",
    "coraza": "co-ra-za",
    "coraznada": "co-raz-na-da",
    "corazón": "co-ra-zón",
    "corazonada": "co-ra-zo-na-da",
    "corazoncillo": "co-ra-zon-ci-llo",
    "corazonista": "co-ra-zo-nis-ta",
    "corbachada": "cor-ba-cha-da",
    "corbacho": "cor-ba-cho",
    "corbata": "cor-ba-ta",
    "corbatear": "cor-ba-te-ar",
    "corbatera": "cor-ba-te-ra",
    "corbatería": "cor-ba-te-rí-a",
    "corbatero": "cor-ba-te-ro",
    "corbatín": "cor-ba-tín",
    "corbato": "cor-ba-to",
    "corbe": "cor-be",
    "corbela": "cor-be-la",
    "corbeta": "cor-be-ta",
    "corbillo": "cor-bi-llo",
    "corbona": "cor-bo-na",
    "corca": "cor-ca",
    "corcar": "cor-car",
    "corcarse": "cor-car-se",
    "corcel": "cor-cel",
    "corcesca": "cor-ces-ca",
    "corcha": "cor-cha",
    "corchapín": "cor-cha-pín",
    "corchar": "cor-char",
    "corche": "cor-che",
    "corchea": "cor-che-a",
    "corchera": "cor-che-ra",
    "corchero": "cor-che-ro",
    "corcheta": "cor-che-ta",
    "corchetada": "cor-che-ta-da",
    "corchete": "cor-che-te",
    "corchetera": "cor-che-te-ra",
    "corcho": "cor-cho",
    "corcholata": "cor-cho-la-ta",
    "corcholear": "cor-cho-le-ar",
    "córcholis": "cór-cho-lis",
    "corchosa": "cor-cho-sa",
    "corchoso": "cor-cho-so",
    "corchotaponera": "cor-cho-ta-po-ne-ra",
    "corchotaponero": "cor-cho-ta-po-ne-ro",
    "corcino": "cor-ci-no",
    "corco": "cor-co",
    "corcolén": "cor-co-lén",
    "corconera": "cor-co-ne-ra",
    "corcor": "cor-cor",
    "corcova": "cor-co-va",
    "corcovada": "cor-co-va-da",
    "corcovado": "cor-co-va-do",
    "corcovar": "cor-co-var",
    "corcovear": "cor-co-ve-ar",
    "corcoveo": "cor-co-ve-o",
    "corcoveta": "cor-co-ve-ta",
    "corcovo": "cor-co-vo",
    "corcuncho": "cor-cun-cho",
    "corcusido": "cor-cu-si-do",
    "corcusir": "cor-cu-sir",
    "corda": "cor-da",
    "cordada": "cor-da-da",
    "cordado": "cor-da-do",
    "cordaje": "cor-da-je",
    "cordal": "cor-dal",
    "cordata": "cor-da-ta",
    "cordato": "cor-da-to",
    "cordel": "cor-del",
    "cordelada": "cor-de-la-da",
    "cordelado": "cor-de-la-do",
    "cordelar": "cor-de-lar",
    "cordelazo": "cor-de-la-zo",
    "cordelejo": "cor-de-le-jo",
    "cordelera": "cor-de-le-ra",
    "cordelería": "cor-de-le-rí-a",
    "cordelero": "cor-de-le-ro",
    "cordellate": "cor-de-lla-te",
    "cordera": "cor-de-ra",
    "corderaje": "cor-de-ra-je",
    "cordería": "cor-de-rí-a",
    "corderil": "cor-de-ril",
    "corderillo": "cor-de-ri-llo",
    "corderina": "cor-de-ri-na",
    "corderino": "cor-de-ri-no",
    "cordero": "cor-de-ro",
    "corderuna": "cor-de-ru-na",
    "cordeta": "cor-de-ta",
    "cordiaca": "cor-dia-ca",
    "cordiaco": "cor-dia-co",
    "cordial": "cor-dial",
    "cordialidad": "cor-dia-li-dad",
    "cordialmente": "cor-dial-men-te",
    "cordierita": "cor-die-ri-ta",
    "cordiforme": "cor-di-for-me",
    "cordila": "cor-di-la",
    "cordilla": "cor-di-lla",
    "cordillera": "cor-di-lle-ra",
    "cordillerana": "cor-di-lle-ra-na",
    "cordillerano": "cor-di-lle-ra-no",
    "cordilo": "cor-di-lo",
    "cordimariana": "cor-di-ma-ria-na",
    "cordimariano": "cor-di-ma-ria-no",
    "cordino": "cor-di-no",
    "cordita": "cor-di-ta",
    "corditis": "cor-di-tis",
    "córdoba": "cór-do-ba",
    "cordobán": "cor-do-bán",
    "cordobana": "cor-do-ba-na",
    "cordobanero": "cor-do-ba-ne-ro",
    "cordobeña": "cor-do-be-ña",
    "cordobeño": "cor-do-be-ño",
    "cordobense": "cor-do-ben-se",
    "cordobés": "cor-do-bés",
    "cordobesa": "cor-do-be-sa",
    "cordófono": "cor-dó-fo-no",
    "cordojo": "cor-do-jo",
    "cordojosa": "cor-do-jo-sa",
    "cordojoso": "cor-do-jo-so",
    "cordón": "cor-dón",
    "cordonazo": "cor-do-na-zo",
    "cordoncillo": "cor-don-ci-llo",
    "cordonera": "cor-do-ne-ra",
    "cordonería": "cor-do-ne-rí-a",
    "cordonero": "cor-do-ne-ro",
    "cordubense": "cor-du-ben-se",
    "cordula": "cor-du-la",
    "cordura": "cor-du-ra",
    "corea": "co-re-a",
    "coreana": "co-re-a-na",
    "coreano": "co-re-a-no",
    "corear": "co-re-ar",
    "corecico": "co-re-ci-co",
    "corecillo": "co-re-ci-llo",
    "corega": "co-re-ga",
    "corego": "co-re-go",
    "corégono": "co-ré-go-no",
    "coreo": "co-re-o",
    "coreógrafa": "co-re-ó-gra-fa",
    "coreografía": "co-re-o-gra-fí-a",
    "coreografiar": "co-re-o-gra-fiar",
    "coreográfica": "co-re-o-grá-fi-ca",
    "coreográfico": "co-re-o-grá-fi-co",
    "coreógrafo": "co-re-ó-gra-fo",
    "coreopsis": "co-re-op-sis",
    "corepíscopo": "co-re-pís-co-po",
    "corete": "co-re-te",
    "coreuta": "co-reu-ta",
    "corezuelo": "co-re-zue-lo",
    "cori": "co-ri",
    "corí": "co-rí",
    "coria": "co-ria",
    "coriácea": "co-riá-ce-a",
    "coriáceo": "co-riá-ce-o",
    "coriámbica": "co-riám-bi-ca",
    "coriámbico": "co-riám-bi-co",
    "coriambo": "co-riam-bo",
    "coriana": "co-ria-na",
    "coriandro": "co-rian-dro",
    "coriano": "co-ria-no",
    "coriariácea": "co-ria-riá-ce-a",
    "coriariáceas": "co-ria-riá-ce-as",
    "coriariáceo": "co-ria-riá-ce-o",
    "coribante": "co-ri-ban-te",
    "corifeo": "co-ri-fe-o",
    "corilácea": "co-ri-lá-ce-a",
    "coriláceo": "co-ri-lá-ce-o",
    "corimbo": "co-rim-bo",
    "corindón": "co-rin-dón",
    "corinteña": "co-rin-te-ña",
    "corinteño": "co-rin-te-ño",
    "corintia": "co-rin-tia",
    "coríntica": "co-rín-ti-ca",
    "coríntico": "co-rín-ti-co",
    "corintio": "co-rin-tio",
    "corinto": "co-rin-to",
    "corío": "co-rí-o",
    "corion": "co-rion",
    "coripateña": "co-ri-pa-te-ña",
    "coripateño": "co-ri-pa-te-ño",
    "corisanto": "co-ri-san-to",
    "corista": "co-ris-ta",
    "corita": "co-ri-ta",
    "corito": "co-ri-to",
    "coriza": "co-ri-za",
    "corla": "cor-la",
    "corlador": "cor-la-dor",
    "corladora": "cor-la-do-ra",
    "corladura": "cor-la-du-ra",
    "corlar": "cor-lar",
    "corleador": "cor-le-a-dor",
    "corleadora": "cor-le-a-do-ra",
    "corlear": "cor-le-ar",
    "corma": "cor-ma",
    "cormana": "cor-ma-na",
    "cormano": "cor-ma-no",
    "cormiera": "cor-mie-ra",
    "cormo": "cor-mo",
    "cormorán": "cor-mo-rán",
    "cornac": "cor-nac",
    "cornaca": "cor-na-ca",
    "cornácea": "cor-ná-ce-a",
    "cornáceo": "cor-ná-ce-o",
    "cornada": "cor-na-da",
    "cornadillo": "cor-na-di-llo",
    "cornado": "cor-na-do",
    "cornadura": "cor-na-du-ra",
    "cornal": "cor-nal",
    "cornalina": "cor-na-li-na",
    "cornalón": "cor-na-lón",
    "cornamenta": "cor-na-men-ta",
    "cornamusa": "cor-na-mu-sa",
    "cornatillo": "cor-na-ti-llo",
    "córnea": "cór-ne-a",
    "corneada": "cor-ne-a-da",
    "corneado": "cor-ne-a-do",
    "corneador": "cor-ne-a-dor",
    "corneadora": "cor-ne-a-do-ra",
    "corneal": "cor-ne-al",
    "cornear": "cor-ne-ar",
    "corneja": "cor-ne-ja",
    "cornejal": "cor-ne-jal",
    "cornejo": "cor-ne-jo",
    "cornelina": "cor-ne-li-na",
    "córneo": "cór-ne-o",
    "córner": "cór-ner",
    "cornerina": "cor-ne-ri-na",
    "cornero": "cor-ne-ro",
    "corneta": "cor-ne-ta",
    "cornetazo": "cor-ne-ta-zo",
    "cornete": "cor-ne-te",
    "cornetilla": "cor-ne-ti-lla",
    "cornetín": "cor-ne-tín",
    "corneto": "cor-ne-to",
    "cornezuelo": "cor-ne-zue-lo",
    "corniabierta": "cor-nia-bier-ta",
    "corniabierto": "cor-nia-bier-to",
    "cornial": "cor-nial",
    "corniapretada": "cor-nia-pre-ta-da",
    "corniapretado": "cor-nia-pre-ta-do",
    "cornibrocho": "cor-ni-bro-cho",
    "cornicabra": "cor-ni-ca-bra",
    "corniforme": "cor-ni-for-me",
    "cornigacha": "cor-ni-ga-cha",
    "cornigacho": "cor-ni-ga-cho",
    "cornígera": "cor-ní-ge-ra",
    "cornígero": "cor-ní-ge-ro",
    "cornigordo": "cor-ni-gor-do",
    "cornija": "cor-ni-ja",
    "cornijal": "cor-ni-jal",
    "cornijamento": "cor-ni-ja-men-to",
    "cornijamiento": "cor-ni-ja-mien-to",
    "cornijón": "cor-ni-jón",
    "cornil": "cor-nil",
    "corniola": "cor-nio-la",
    "cornisa": "cor-ni-sa",
    "cornisamento": "cor-ni-sa-men-to",
    "cornisamiento": "cor-ni-sa-mien-to",
    "cornisón": "cor-ni-són",
    "cornista": "cor-nis-ta",
    "corniveleta": "cor-ni-ve-le-ta",
    "corniveleto": "cor-ni-ve-le-to",
    "cornizo": "cor-ni-zo",
    "corno": "cor-no",
    "cornucopia": "cor-nu-co-pia",
    "cornuda": "cor-nu-da",
    "cornudilla": "cor-nu-di-lla",
    "cornudo": "cor-nu-do",
    "cornúpeta": "cor-nú-pe-ta",
    "cornúpeto": "cor-nú-pe-to",
    "cornuto": "cor-nu-to",
    "coro": "co-ro",
    "corocha": "co-ro-cha",
    "corocoreña": "co-ro-co-re-ña",
    "corocoreño": "co-ro-co-re-ño",
    "corografía": "co-ro-gra-fí-a",
    "corográfica": "co-ro-grá-fi-ca",
    "corográficamente": "co-ro-grá-fi-ca-men-te",
    "corográfico": "co-ro-grá-fi-co",
    "corógrafo": "co-ró-gra-fo",
    "coroidea": "co-roi-de-a",
    "coroideo": "co-roi-de-o",
    "coroides": "co-roi-des",
    "coroiqueña": "co-roi-que-ña",
    "coroiqueño": "co-roi-que-ño",
    "corojo": "co-ro-jo",
    "corola": "co-ro-la",
    "corolario": "co-ro-la-rio",
    "coroliflora": "co-ro-li-flo-ra",
    "corolino": "co-ro-li-no",
    "corolla": "co-ro-lla",
    "corona": "co-ro-na",
    "coronación": "co-ro-na-ción",
    "coronada": "co-ro-na-da",
    "coronado": "co-ro-na-do",
    "coronador": "co-ro-na-dor",
    "coronadora": "co-ro-na-do-ra",
    "coronal": "co-ro-nal",
    "coronamento": "co-ro-na-men-to",
    "coronamiento": "co-ro-na-mien-to",
    "coronar": "co-ro-nar",
    "coronaria": "co-ro-na-ria",
    "coronario": "co-ro-na-rio",
    "coronda": "co-ron-da",
    "corondel": "co-ron-del",
    "coroneja": "co-ro-ne-ja",
    "coronel": "co-ro-nel",
    "coronela": "co-ro-ne-la",
    "coronelía": "co-ro-ne-lí-a",
    "coronguina": "co-ron-gui-na",
    "coronguino": "co-ron-gui-no",
    "corónica": "co-ró-ni-ca",
    "corónide": "co-ró-ni-de",
    "coronilla": "co-ro-ni-lla",
    "coronillo": "co-ro-ni-llo",
    "coronio": "co-ro-nio",
    "coronista": "co-ro-nis-ta",
    "coronta": "co-ron-ta",
    "corosol": "co-ro-sol",
    "coroto": "co-ro-to",
    "coroza": "co-ro-za",
    "corozal": "co-ro-zal",
    "corozo": "co-ro-zo",
    "corpa": "cor-pa",
    "corpachón": "cor-pa-chón",
    "corpanchón": "cor-pan-chón",
    "corpecico": "cor-pe-ci-co",
    "corpezuelo": "cor-pe-zue-lo",
    "corpiño": "cor-pi-ño",
    "corporación": "cor-po-ra-ción",
    "corporal": "cor-po-ral",
    "corporalidad": "cor-po-ra-li-dad",
    "corporalmente": "cor-po-ral-men-te",
    "corporativa": "cor-po-ra-ti-va",
    "corporativamente": "cor-po-ra-ti-va-men-te",
    "corporativismo": "cor-po-ra-ti-vis-mo",
    "corporativista": "cor-po-ra-ti-vis-ta",
    "corporativo": "cor-po-ra-ti-vo",
    "corpórea": "cor-pó-re-a",
    "corporeidad": "cor-po-rei-dad",
    "corporeización": "cor-po-rei-za-ción",
    "corporeizar": "cor-po-rei-zar",
    "corpóreo": "cor-pó-re-o",
    "corporificar": "cor-po-ri-fi-car",
    "corporizar": "cor-po-ri-zar",
    "corpuda": "cor-pu-da",
    "corpudo": "cor-pu-do",
    "corpulencia": "cor-pu-len-cia",
    "corpulenta": "cor-pu-len-ta",
    "corpulento": "cor-pu-len-to",
    "corpus": "cor-pus",
    "corpus": "cor-pus",
    "corpuscular": "cor-pus-cu-lar",
    "corpusculista": "cor-pus-cu-lis-ta",
    "corpúsculo": "cor-pús-cu-lo",
    "corra": "co-rra",
    "corral": "co-rral",
    "corrala": "co-rra-la",
    "corralada": "co-rra-la-da",
    "corraleja": "co-rra-le-ja",
    "corralera": "co-rra-le-ra",
    "corralero": "co-rra-le-ro",
    "corraleta": "co-rra-le-ta",
    "corralito": "co-rra-li-to",
    "corraliza": "co-rra-li-za",
    "corralmeca": "co-rral-me-ca",
    "corralón": "co-rra-lón",
    "correa": "co-rre-a",
    "correaje": "co-rre-a-je",
    "correal": "co-rre-al",
    "correar": "co-rre-ar",
    "correazo": "co-rre-a-zo",
    "correcalles": "co-rre-ca-lles",
    "correcaminos": "co-rre-ca-mi-nos",
    "corrección": "co-rrec-ción",
    "correccional": "co-rrec-cio-nal",
    "correccionalismo": "co-rrec-cio-na-lis-mo",
    "correccionalista": "co-rrec-cio-na-lis-ta",
    "correccionalmente": "co-rrec-cio-nal-men-te",
    "correcha": "co-rre-cha",
    "correcho": "co-rre-cho",
    "correcta": "co-rrec-ta",
    "correctamente": "co-rrec-ta-men-te",
    "correctibilidad": "co-rrec-ti-bi-li-dad",
    "correctiva": "co-rrec-ti-va",
    "correctivo": "co-rrec-ti-vo",
    "correcto": "co-rrec-to",
    "corrector": "co-rrec-tor",
    "correctora": "co-rrec-to-ra",
    "corredentor": "co-rre-den-tor",
    "corredentora": "co-rre-den-to-ra",
    "corredera": "co-rre-de-ra",
    "corredero": "co-rre-de-ro",
    "corrediza": "co-rre-di-za",
    "corredizo": "co-rre-di-zo",
    "corredor": "co-rre-dor",
    "corredora": "co-rre-do-ra",
    "corredura": "co-rre-du-ra",
    "correduría": "co-rre-du-rí-a",
    "correera": "co-rre-e-ra",
    "correería": "co-rre-e-rí-a",
    "correero": "co-rre-e-ro",
    "corregencia": "co-rre-gen-cia",
    "corregente": "co-rre-gen-te",
    "corregibilidad": "co-rre-gi-bi-li-dad",
    "corregible": "co-rre-gi-ble",
    "corregidor": "co-rre-gi-dor",
    "corregidora": "co-rre-gi-do-ra",
    "corregimiento": "co-rre-gi-mien-to",
    "corregir": "co-rre-gir",
    "corregüela": "co-rre-güe-la",
    "correhuela": "co-rre-hue-la",
    "correinado": "co-rrei-na-do",
    "correinante": "co-rrei-nan-te",
    "correjel": "co-rre-jel",
    "correlación": "co-rre-la-ción",
    "correlacionar": "co-rre-la-cio-nar",
    "correlata": "co-rre-la-ta",
    "correlativa": "co-rre-la-ti-va",
    "correlativamente": "co-rre-la-ti-va-men-te",
    "correlativo": "co-rre-la-ti-vo",
    "correlato": "co-rre-la-to",
    "correligionaria": "co-rre-li-gio-na-ria",
    "correligionario": "co-rre-li-gio-na-rio",
    "correlimos": "co-rre-li-mos",
    "correlón": "co-rre-lón",
    "correncia": "co-rren-cia",
    "correndilla": "co-rren-di-lla",
    "correntada": "co-rren-ta-da",
    "correntía": "co-rren-tí-a",
    "correntiar": "co-rren-tiar",
    "correntina": "co-rren-ti-na",
    "correntino": "co-rren-ti-no",
    "correntío": "co-rren-tí-o",
    "correntómetro": "co-rren-tó-me-tro",
    "correntón": "co-rren-tón",
    "correntosa": "co-rren-to-sa",
    "correntoso": "co-rren-to-so",
    "correo": "co-rre-o",
    "correón": "co-rre-ón",
    "correosa": "co-rre-o-sa",
    "correoso": "co-rre-o-so",
    "correpiés": "co-rre-piés",
    "correr": "co-rrer",
    "correría": "co-rre-rí-a",
    "correspondencia": "co-rres-pon-den-cia",
    "corresponder": "co-rres-pon-der",
    "correspondiente": "co-rres-pon-dien-te",
    "correspondientemente": "co-rres-pon-dien-te-men-te",
    "corresponsabilidad": "co-rres-pon-sa-bi-li-dad",
    "corresponsabilización": "co-rres-pon-sa-bi-li-za-ción",
    "corresponsabilizar": "co-rres-pon-sa-bi-li-zar",
    "corresponsable": "co-rres-pon-sa-ble",
    "corresponsal": "co-rres-pon-sal",
    "corresponsalía": "co-rres-pon-sa-lí-a",
    "corresponsión": "co-rres-pon-sión",
    "corretaje": "co-rre-ta-je",
    "correteada": "co-rre-te-a-da",
    "corretear": "co-rre-te-ar",
    "correteo": "co-rre-te-o",
    "corretero": "co-rre-te-ro",
    "corretiza": "co-rre-ti-za",
    "corretón": "co-rre-tón",
    "corretora": "co-rre-to-ra",
    "correturnos": "co-rre-tur-nos",
    "correvedile": "co-rre-ve-di-le",
    "correveidile": "co-rre-vei-di-le",
    "correverás": "co-rre-ve-rás",
    "correyuela": "co-rre-yue-la",
    "corricorri": "co-rri-co-rri",
    "corrida": "co-rri-da",
    "corridamente": "co-rri-da-men-te",
    "corrido": "co-rri-do",
    "corrientazo": "co-rrien-ta-zo",
    "corriente": "co-rrien-te",
    "corrientemente": "co-rrien-te-men-te",
    "corrigenda": "co-rri-gen-da",
    "corrigendo": "co-rri-gen-do",
    "corrillera": "co-rri-lle-ra",
    "corrillero": "co-rri-lle-ro",
    "corrillo": "co-rri-llo",
    "corrimiento": "co-rri-mien-to",
    "corrincho": "co-rrin-cho",
    "corrivación": "co-rri-va-ción",
    "corriverás": "co-rri-ve-rás",
    "corro": "co-rro",
    "corroboración": "co-rro-bo-ra-ción",
    "corroborante": "co-rro-bo-ran-te",
    "corroborar": "co-rro-bo-rar",
    "corroborativa": "co-rro-bo-ra-ti-va",
    "corroborativo": "co-rro-bo-ra-ti-vo",
    "corrobra": "co-rro-bra",
    "corroedor": "co-rro-e-dor",
    "corroer": "co-rro-er",
    "corrompedor": "co-rrom-pe-dor",
    "corrompedora": "co-rrom-pe-do-ra",
    "corromper": "co-rrom-per",
    "corrompible": "co-rrom-pi-ble",
    "corrompidamente": "co-rrom-pi-da-men-te",
    "corrompimiento": "co-rrom-pi-mien-to",
    "corroncha": "co-rron-cha",
    "corroncho": "co-rron-cho",
    "corronchoso": "co-rron-cho-so",
    "corrongo": "co-rron-go",
    "corrosal": "co-rro-sal",
    "corrosca": "co-rros-ca",
    "corrosible": "co-rro-si-ble",
    "corrosión": "co-rro-sión",
    "corrosiva": "co-rro-si-va",
    "corrosivo": "co-rro-si-vo",
    "corrote": "co-rro-te",
    "corroyente": "co-rro-yen-te",
    "corrozar": "co-rro-zar",
    "corrozo": "co-rro-zo",
    "corruco": "co-rru-co",
    "corrugación": "co-rru-ga-ción",
    "corrugar": "co-rru-gar",
    "córrugo": "có-rru-go",
    "corrulla": "co-rru-lla",
    "corrumpente": "co-rrum-pen-te",
    "corrupción": "co-rrup-ción",
    "corrupta": "co-rrup-ta",
    "corruptamente": "co-rrup-ta-men-te",
    "corruptela": "co-rrup-te-la",
    "corruptibilidad": "co-rrup-ti-bi-li-dad",
    "corruptible": "co-rrup-ti-ble",
    "corruptiva": "co-rrup-ti-va",
    "corruptivo": "co-rrup-ti-vo",
    "corrupto": "co-rrup-to",
    "corruptor": "co-rrup-tor",
    "corruptora": "co-rrup-to-ra",
    "corruscante": "co-rrus-can-te",
    "corrusco": "co-rrus-co",
    "corsa": "cor-sa",
    "corsaria": "cor-sa-ria",
    "corsariamente": "cor-sa-ria-men-te",
    "corsario": "cor-sa-rio",
    "corsé": "cor-sé",
    "corsear": "cor-se-ar",
    "corselete": "cor-se-le-te",
    "corsetera": "cor-se-te-ra",
    "corsetería": "cor-se-te-rí-a",
    "corsetero": "cor-se-te-ro",
    "corso": "cor-so",
    "corta": "cor-ta",
    "cortabolsas": "cor-ta-bol-sas",
    "cortacallos": "cor-ta-ca-llos",
    "cortacésped": "cor-ta-cés-ped",
    "cortacigarros": "cor-ta-ci-ga-rros",
    "cortacircuitos": "cor-ta-cir-cui-tos",
    "cortacorriente": "cor-ta-co-rrien-te",
    "cortada": "cor-ta-da",
    "cortadera": "cor-ta-de-ra",
    "cortadilla": "cor-ta-di-lla",
    "cortadillo": "cor-ta-di-llo",
    "cortado": "cor-ta-do",
    "cortador": "cor-ta-dor",
    "cortadora": "cor-ta-do-ra",
    "cortadura": "cor-ta-du-ra",
    "cortafierro": "cor-ta-fie-rro",
    "cortafrío": "cor-ta-frí-o",
    "cortafuego": "cor-ta-fue-go",
    "cortafuegos": "cor-ta-fue-gos",
    "cortagrama": "cor-ta-gra-ma",
    "cortalápices": "cor-ta-lá-pi-ces",
    "cortamente": "cor-ta-men-te",
    "cortamiento": "cor-ta-mien-to",
    "cortante": "cor-tan-te",
    "cortao": "cor-ta-o",
    "cortapapel": "cor-ta-pa-pel",
    "cortapapeles": "cor-ta-pa-pe-les",
    "cortapastas": "cor-ta-pas-tas",
    "cortapicos": "cor-ta-pi-cos",
    "cortapiés": "cor-ta-piés",
    "cortapisa": "cor-ta-pi-sa",
    "cortaplumas": "cor-ta-plu-mas",
    "cortapuros": "cor-ta-pu-ros",
    "cortar": "cor-tar",
    "cortaúñas": "cor-ta-ú-ñas",
    "cortaviento": "cor-ta-vien-to",
    "corte": "cor-te",
    "cortedad": "cor-te-dad",
    "cortega": "cor-te-ga",
    "cortejador": "cor-te-ja-dor",
    "cortejadora": "cor-te-ja-do-ra",
    "cortejar": "cor-te-jar",
    "cortejo": "cor-te-jo",
    "cortero": "cor-te-ro",
    "cortés": "cor-tés",
    "cortesana": "cor-te-sa-na",
    "cortesanamente": "cor-te-sa-na-men-te",
    "cortesanaza": "cor-te-sa-na-za",
    "cortesanazo": "cor-te-sa-na-zo",
    "cortesanía": "cor-te-sa-ní-a",
    "cortesano": "cor-te-sa-no",
    "corteseño": "cor-te-se-ño",
    "cortesense": "cor-te-sen-se",
    "cortesía": "cor-te-sí-a",
    "cortésmente": "cor-tés-men-te",
    "corteza": "cor-te-za",
    "cortezo": "cor-te-zo",
    "cortezoso": "cor-te-zo-so",
    "cortezuda": "cor-te-zu-da",
    "cortezudo": "cor-te-zu-do",
    "cortical": "cor-ti-cal",
    "corticoide": "cor-ti-coi-de",
    "corticosteroide": "cor-ti-cos-te-roi-de",
    "cortijada": "cor-ti-ja-da",
    "cortijera": "cor-ti-je-ra",
    "cortijero": "cor-ti-je-ro",
    "cortijo": "cor-ti-jo",
    "cortil": "cor-til",
    "cortina": "cor-ti-na",
    "cortinada": "cor-ti-na-da",
    "cortinado": "cor-ti-na-do",
    "cortinaje": "cor-ti-na-je",
    "cortinal": "cor-ti-nal",
    "cortinilla": "cor-ti-ni-lla",
    "cortinón": "cor-ti-nón",
    "cortisol": "cor-ti-sol",
    "cortisona": "cor-ti-so-na",
    "cortisquear": "cor-tis-que-ar",
    "corto": "cor-to",
    "cortocircuitado": "cor-to-cir-cui-ta-do",
    "cortocircuitar": "cor-to-cir-cui-tar",
    "cortocircuito": "cor-to-cir-cui-to",
    "cortometraje": "cor-to-me-tra-je",
    "cortón": "cor-tón",
    "corúa": "co-rú-a",
    "corucha": "co-ru-cha",
    "coruja": "co-ru-ja",
    "corulla": "co-ru-lla",
    "coruña": "co-ru-ña",
    "corundo": "co-run-do",
    "coruñés": "co-ru-ñés",
    "coruñesa": "co-ru-ñe-sa",
    "corupán": "co-ru-pán",
    "corusca": "co-rus-ca",
    "coruscante": "co-rus-can-te",
    "coruscar": "co-rus-car",
    "corusco": "co-rus-co",
    "corva": "cor-va",
    "corvadura": "cor-va-du-ra",
    "corval": "cor-val",
    "corvar": "cor-var",
    "corvato": "cor-va-to",
    "corvaza": "cor-va-za",
    "corvejón": "cor-ve-jón",
    "corvejos": "cor-ve-jos",
    "corveña": "cor-ve-ña",
    "corveño": "cor-ve-ño",
    "corveta": "cor-ve-ta",
    "corvetear": "cor-ve-te-ar",
    "córvido": "cór-vi-do",
    "corvillo": "cor-vi-llo",
    "corvina": "cor-vi-na",
    "corvinera": "cor-vi-ne-ra",
    "corvino": "cor-vi-no",
    "corvo": "cor-vo",
    "corza": "cor-za",
    "corzo": "cor-zo",
    "corzuelo": "cor-zue-lo",
    "cosa": "co-sa",
    "cosaca": "co-sa-ca",
    "cosaco": "co-sa-co",
    "cosante": "co-san-te",
    "cosaria": "co-sa-ria",
    "cosario": "co-sa-rio",
    "coscachear": "cos-ca-che-ar",
    "coscacho": "cos-ca-cho",
    "coscar": "cos-car",
    "coscarana": "cos-ca-ra-na",
    "coscarrón": "cos-ca-rrón",
    "coscarse": "cos-car-se",
    "coscas": "cos-cas",
    "coscoja": "cos-co-ja",
    "coscojal": "cos-co-jal",
    "coscojar": "cos-co-jar",
    "coscojera": "cos-co-je-ra",
    "coscojero": "cos-co-je-ro",
    "coscojita": "cos-co-ji-ta",
    "coscojo": "cos-co-jo",
    "coscolina": "cos-co-li-na",
    "coscolino": "cos-co-li-no",
    "coscomate": "cos-co-ma-te",
    "coscón": "cos-cón",
    "coscona": "cos-co-na",
    "coscoroba": "cos-co-ro-ba",
    "coscorrón": "cos-co-rrón",
    "coscorronera": "cos-co-rro-ne-ra",
    "coscurro": "cos-cu-rro",
    "cosecante": "co-se-can-te",
    "cosecha": "co-se-cha",
    "cosechador": "co-se-cha-dor",
    "cosechadora": "co-se-cha-do-ra",
    "cosechar": "co-se-char",
    "cosechera": "co-se-che-ra",
    "cosechero": "co-se-che-ro",
    "cosechón": "co-se-chón",
    "cosedora": "co-se-do-ra",
    "cosedura": "co-se-du-ra",
    "coselete": "co-se-le-te",
    "coseno": "co-se-no",
    "coser": "co-ser",
    "cosera": "co-se-ra",
    "cosetada": "co-se-ta-da",
    "cosetana": "co-se-ta-na",
    "cosetano": "co-se-ta-no",
    "cosetear": "co-se-te-ar",
    "cosiaca": "co-sia-ca",
    "cosible": "co-si-ble",
    "cosicosa": "co-si-co-sa",
    "cosido": "co-si-do",
    "cosidura": "co-si-du-ra",
    "cosificación": "co-si-fi-ca-ción",
    "cosificar": "co-si-fi-car",
    "cosija": "co-si-ja",
    "cosijo": "co-si-jo",
    "cositera": "co-si-te-ra",
    "cositero": "co-si-te-ro",
    "cosmética": "cos-mé-ti-ca",
    "cosmético": "cos-mé-ti-co",
    "cosmetiquera": "cos-me-ti-que-ra",
    "cosmetiquero": "cos-me-ti-que-ro",
    "cosmetóloga": "cos-me-tó-lo-ga",
    "cosmetología": "cos-me-to-lo-gí-a",
    "cosmetólogo": "cos-me-tó-lo-go",
    "cósmica": "cós-mi-ca",
    "cósmico": "cós-mi-co",
    "cosmódromo": "cos-mó-dro-mo",
    "cosmogonía": "cos-mo-go-ní-a",
    "cosmogónica": "cos-mo-gó-ni-ca",
    "cosmogónico": "cos-mo-gó-ni-co",
    "cosmogonista": "cos-mo-go-nis-ta",
    "cosmógrafa": "cos-mó-gra-fa",
    "cosmografía": "cos-mo-gra-fí-a",
    "cosmográfica": "cos-mo-grá-fi-ca",
    "cosmográfico": "cos-mo-grá-fi-co",
    "cosmógrafo": "cos-mó-gra-fo",
    "cosmóloga": "cos-mó-lo-ga",
    "cosmología": "cos-mo-lo-gí-a",
    "cosmológica": "cos-mo-ló-gi-ca",
    "cosmológico": "cos-mo-ló-gi-co",
    "cosmólogo": "cos-mó-lo-go",
    "cosmonauta": "cos-mo-nau-ta",
    "cosmonáutica": "cos-mo-náu-ti-ca",
    "cosmonáutico": "cos-mo-náu-ti-co",
    "cosmonave": "cos-mo-na-ve",
    "cosmópolis": "cos-mó-po-lis",
    "cosmopolita": "cos-mo-po-li-ta",
    "cosmopolitismo": "cos-mo-po-li-tis-mo",
    "cosmorama": "cos-mo-ra-ma",
    "cosmos": "cos-mos",
    "cosmovisión": "cos-mo-vi-sión",
    "coso": "co-so",
    "cosoria": "co-so-ria",
    "cosoriola": "co-so-rio-la",
    "cospe": "cos-pe",
    "cospel": "cos-pel",
    "cospillo": "cos-pi-llo",
    "cosque": "cos-que",
    "cosqui": "cos-qui",
    "cosquillar": "cos-qui-llar",
    "cosquillas": "cos-qui-llas",
    "cosquillear": "cos-qui-lle-ar",
    "cosquilleo": "cos-qui-lle-o",
    "cosquillosa": "cos-qui-llo-sa",
    "cosquilloso": "cos-qui-llo-so",
    "cosquilludo": "cos-qui-llu-do",
    "costa": "cos-ta",
    "costado": "cos-ta-do",
    "costal": "cos-tal",
    "costalada": "cos-ta-la-da",
    "costalar": "cos-ta-lar",
    "costalazo": "cos-ta-la-zo",
    "costalear": "cos-ta-le-ar",
    "costalero": "cos-ta-le-ro",
    "costamarfileña": "cos-ta-mar-fi-le-ña",
    "costamarfileño": "cos-ta-mar-fi-le-ño",
    "costana": "cos-ta-na",
    "costanera": "cos-ta-ne-ra",
    "costanero": "cos-ta-ne-ro",
    "costanilla": "cos-ta-ni-lla",
    "costar": "cos-tar",
    "costarricense": "cos-ta-rri-cen-se",
    "costarriqueña": "cos-ta-rri-que-ña",
    "costarriqueñismo": "cos-ta-rri-que-ñis-mo",
    "costarriqueño": "cos-ta-rri-que-ño",
    "costasoleño": "cos-ta-so-le-ño",
    "coste": "cos-te",
    "costeador": "cos-te-a-dor",
    "costear": "cos-te-ar",
    "costelación": "cos-te-la-ción",
    "costeña": "cos-te-ña",
    "costeño": "cos-te-ño",
    "costeo": "cos-te-o",
    "costera": "cos-te-ra",
    "costero": "cos-te-ro",
    "costezuela": "cos-te-zue-la",
    "costil": "cos-til",
    "costilla": "cos-ti-lla",
    "costillaje": "cos-ti-lla-je",
    "costillar": "cos-ti-llar",
    "costiller": "cos-ti-ller",
    "costilluda": "cos-ti-llu-da",
    "costilludo": "cos-ti-llu-do",
    "costina": "cos-ti-na",
    "costino": "cos-ti-no",
    "costo": "cos-to",
    "costón": "cos-tón",
    "costosa": "cos-to-sa",
    "costosamente": "cos-to-sa-men-te",
    "costoso": "cos-to-so",
    "costra": "cos-tra",
    "costrada": "cos-tra-da",
    "costreñir": "cos-tre-ñir",
    "costribación": "cos-tri-ba-ción",
    "costribar": "cos-tri-bar",
    "costribo": "cos-tri-bo",
    "costringir": "cos-trin-gir",
    "costriñir": "cos-tri-ñir",
    "costro": "cos-tro",
    "costrón": "cos-trón",
    "costrosa": "cos-tro-sa",
    "costroso": "cos-tro-so",
    "costumbrar": "cos-tum-brar",
    "costumbre": "cos-tum-bre",
    "costumbrismo": "cos-tum-bris-mo",
    "costumbrista": "cos-tum-bris-ta",
    "costura": "cos-tu-ra",
    "costurar": "cos-tu-rar",
    "costurear": "cos-tu-re-ar",
    "costureo": "cos-tu-re-o",
    "costurera": "cos-tu-re-ra",
    "costurero": "cos-tu-re-ro",
    "costurón": "cos-tu-rón",
    "cota": "co-ta",
    "cotana": "co-ta-na",
    "cotangente": "co-tan-gen-te",
    "cotanza": "co-tan-za",
    "cotar": "co-tar",
    "cotardía": "co-tar-dí-a",
    "cotarra": "co-ta-rra",
    "cotarrera": "co-ta-rre-ra",
    "cotarro": "co-ta-rro",
    "cote": "co-te",
    "cotear": "co-te-ar",
    "cotejable": "co-te-ja-ble",
    "cotejar": "co-te-jar",
    "cotejo": "co-te-jo",
    "cotense": "co-ten-se",
    "cotera": "co-te-ra",
    "cotero": "co-te-ro",
    "coterránea": "co-te-rrá-ne-a",
    "coterráneo": "co-te-rrá-ne-o",
    "cotexto": "co-tex-to",
    "cotí": "co-tí",
    "cotica": "co-ti-ca",
    "cotidiana": "co-ti-dia-na",
    "cotidianamente": "co-ti-dia-na-men-te",
    "cotidianeidad": "co-ti-dia-nei-dad",
    "cotidianidad": "co-ti-dia-ni-dad",
    "cotidiano": "co-ti-dia-no",
    "cotila": "co-ti-la",
    "cotiledón": "co-ti-le-dón",
    "cotiledónea": "co-ti-le-dó-ne-a",
    "cotiledóneas": "co-ti-le-dó-ne-as",
    "cotiledóneo": "co-ti-le-dó-ne-o",
    "cotilla": "co-ti-lla",
    "cotillear": "co-ti-lle-ar",
    "cotilleo": "co-ti-lle-o",
    "cotillera": "co-ti-lle-ra",
    "cotillería": "co-ti-lle-rí-a",
    "cotillero": "co-ti-lle-ro",
    "cotillo": "co-ti-llo",
    "cotillón": "co-ti-llón",
    "cotilo": "co-ti-lo",
    "cotín": "co-tín",
    "cotinga": "co-tin-ga",
    "cotiza": "co-ti-za",
    "cotizable": "co-ti-za-ble",
    "cotización": "co-ti-za-ción",
    "cotizada": "co-ti-za-da",
    "cotizado": "co-ti-za-do",
    "cotizar": "co-ti-zar",
    "coto": "co-to",
    "cotobelo": "co-to-be-lo",
    "cotofle": "co-to-fle",
    "cotofre": "co-to-fre",
    "cotomono": "co-to-mo-no",
    "cotón": "co-tón",
    "cotona": "co-to-na",
    "cotonada": "co-to-na-da",
    "cotoncillo": "co-ton-ci-llo",
    "cotonete": "co-to-ne-te",
    "cotonía": "co-to-ní-a",
    "cotopaxense": "co-to-pa-xen-se",
    "cotoperís": "co-to-pe-rís",
    "cotorra": "co-to-rra",
    "cotorrear": "co-to-rre-ar",
    "cotorreo": "co-to-rre-o",
    "cotorrera": "co-to-rre-ra",
    "cotorrita": "co-to-rri-ta",
    "cotorro": "co-to-rro",
    "cotorrón": "co-to-rrón",
    "cotorrona": "co-to-rro-na",
    "cototo": "co-to-to",
    "cototudo": "co-to-tu-do",
    "cotovía": "co-to-ví-a",
    "cotral": "co-tral",
    "cotrofe": "co-tro-fe",
    "cotúa": "co-tú-a",
    "cotuda": "co-tu-da",
    "cotudo": "co-tu-do",
    "cotufa": "co-tu-fa",
    "cotufas": "co-tu-fas",
    "cotuisana": "co-tui-sa-na",
    "cotuisano": "co-tui-sa-no",
    "cotunto": "co-tun-to",
    "coturnicultura": "co-tur-ni-cul-tu-ra",
    "coturno": "co-tur-no",
    "cotuza": "co-tu-za",
    "coulomb": "cou-lomb",
    "coupé": "cou-pé",
    "covacha": "co-va-cha",
    "covachuela": "co-va-chue-la",
    "covachuelista": "co-va-chue-lis-ta",
    "covachuelo": "co-va-chue-lo",
    "covada": "co-va-da",
    "covadera": "co-va-de-ra",
    "covalencia": "co-va-len-cia",
    "covalente": "co-va-len-te",
    "covalonga": "co-va-lon-ga",
    "covanilla": "co-va-ni-lla",
    "covar": "co-var",
    "coxa": "co-xa",
    "coxal": "co-xal",
    "coxalgia": "co-xal-gia",
    "coxálgico": "co-xál-gi-co",
    "coxcojilla": "cox-co-ji-lla",
    "coxcojita": "cox-co-ji-ta",
    "coxcox": "cox-cox",
    "coxis": "co-xis",
    "coxofemoral": "co-xo-fe-mo-ral",
    "coxquear": "cox-que-ar",
    "coya": "co-ya",
    "coyán": "co-yán",
    "coyocho": "co-yo-cho",
    "coyol": "co-yol",
    "coyolar": "co-yo-lar",
    "coyoleo": "co-yo-le-o",
    "coyolero": "co-yo-le-ro",
    "coyota": "co-yo-ta",
    "coyotaje": "co-yo-ta-je",
    "coyote": "co-yo-te",
    "coyotear": "co-yo-te-ar",
    "coyoteo": "co-yo-te-o",
    "coyotera": "co-yo-te-ra",
    "coyotería": "co-yo-te-rí-a",
    "coyotero": "co-yo-te-ro",
    "coyunda": "co-yun-da",
    "coyundada": "co-yun-da-da",
    "coyundado": "co-yun-da-do",
    "coyundazo": "co-yun-da-zo",
    "coyundear": "co-yun-de-ar",
    "coyuntero": "co-yun-te-ro",
    "coyuntura": "co-yun-tu-ra",
    "coyuntural": "co-yun-tu-ral",
    "coyunturalmente": "co-yun-tu-ral-men-te",
    "coyuyo": "co-yu-yo",
    "cozolmeca": "co-zol-me-ca",
    "crabrón": "cra-brón",
    "cracoviana": "cra-co-via-na",
    "cracoviano": "cra-co-via-no",
    "crampón": "cram-pón",
    "cramponada": "cram-po-na-da",
    "cramponado": "cram-po-na-do",
    "craneada": "cra-ne-a-da",
    "craneal": "cra-ne-al",
    "craneana": "cra-ne-a-na",
    "craneano": "cra-ne-a-no",
    "cranear": "cra-ne-ar",
    "cráneo": "crá-ne-o",
    "craneoencefálico": "cra-ne-o-en-ce-fá-li-co",
    "craneofacial": "cra-ne-o-fa-cial",
    "craneología": "cra-ne-o-lo-gí-a",
    "craneopatía": "cra-ne-o-pa-tí-a",
    "craneoscopia": "cra-ne-os-co-pia",
    "craniana": "cra-nia-na",
    "craniano": "cra-nia-no",
    "crápula": "crá-pu-la",
    "crapulosa": "cra-pu-lo-sa",
    "crapuloso": "cra-pu-lo-so",
    "craquear": "cra-que-ar",
    "craquelenque": "cra-que-len-que",
    "craqueo": "cra-que-o",
    "crasa": "cra-sa",
    "crasamente": "cra-sa-men-te",
    "crascitar": "cras-ci-tar",
    "crasicie": "cra-si-cie",
    "crasienta": "cra-sien-ta",
    "crasiento": "cra-sien-to",
    "crasitud": "cra-si-tud",
    "craso": "cra-so",
    "crasulácea": "cra-su-lá-ce-a",
    "crasuláceas": "cra-su-lá-ce-as",
    "crasuláceo": "cra-su-lá-ce-o",
    "cráter": "crá-ter",
    "crátera": "crá-te-ra",
    "crateriforme": "cra-te-ri-for-me",
    "cratícula": "cra-tí-cu-la",
    "crayola": "cra-yo-la",
    "crayón": "cra-yón",
    "craza": "cra-za",
    "crazada": "cra-za-da",
    "crea": "cre-a",
    "creable": "cre-a-ble",
    "creación": "cre-a-ción",
    "creacionismo": "cre-a-cio-nis-mo",
    "creacionista": "cre-a-cio-nis-ta",
    "creador": "cre-a-dor",
    "creadora": "cre-a-do-ra",
    "creamiento": "cre-a-mien-to",
    "crear": "cre-ar",
    "creatina": "cre-a-ti-na",
    "creatinina": "cre-a-ti-ni-na",
    "creativa": "cre-a-ti-va",
    "creatividad": "cre-a-ti-vi-dad",
    "creativo": "cre-a-ti-vo",
    "creatura": "cre-a-tu-ra",
    "crecal": "cre-cal",
    "crecedera": "cre-ce-de-ra",
    "crecedero": "cre-ce-de-ro",
    "crecencia": "cre-cen-cia",
    "crecentar": "cre-cen-tar",
    "crecepelo": "cre-ce-pe-lo",
    "crecer": "cre-cer",
    "creces": "cre-ces",
    "crecida": "cre-ci-da",
    "crecidamente": "cre-ci-da-men-te",
    "crecido": "cre-ci-do",
    "creciente": "cre-cien-te",
    "crecientemente": "cre-cien-te-men-te",
    "crecimiento": "cre-ci-mien-to",
    "credencia": "cre-den-cia",
    "credencial": "cre-den-cial",
    "credenciero": "cre-den-cie-ro",
    "credensa": "cre-den-sa",
    "credibilidad": "cre-di-bi-li-dad",
    "crediticia": "cre-di-ti-cia",
    "crediticio": "cre-di-ti-cio",
    "crédito": "cré-di-to",
    "credo": "cre-do",
    "crédula": "cré-du-la",
    "crédulamente": "cré-du-la-men-te",
    "credulidad": "cre-du-li-dad",
    "crédulo": "cré-du-lo",
    "creedera": "cre-e-de-ra",
    "creederas": "cre-e-de-ras",
    "creedero": "cre-e-de-ro",
    "creedor": "cre-e-dor",
    "creedora": "cre-e-do-ra",
    "creencia": "cre-en-cia",
    "creendero": "cre-en-de-ro",
    "creer": "cre-er",
    "crehuela": "cre-hue-la",
    "creíble": "cre-í-ble",
    "creíblemente": "cre-í-ble-men-te",
    "creído": "cre-í-do",
    "crema": "cre-ma",
    "cremación": "cre-ma-ción",
    "cremallera": "cre-ma-lle-ra",
    "cremar": "cre-mar",
    "crematística": "cre-ma-tís-ti-ca",
    "crematístico": "cre-ma-tís-ti-co",
    "crematoria": "cre-ma-to-ria",
    "crematorio": "cre-ma-to-rio",
    "cremento": "cre-men-to",
    "cremería": "cre-me-rí-a",
    "cremómetro": "cre-mó-me-tro",
    "cremona": "cre-mo-na",
    "cremonés": "cre-mo-nés",
    "cremonesa": "cre-mo-ne-sa",
    "crémor": "cré-mor",
    "cremora": "cre-mo-ra",
    "cremosa": "cre-mo-sa",
    "cremosidad": "cre-mo-si-dad",
    "cremoso": "cre-mo-so",
    "crencha": "cren-cha",
    "crenchar": "cren-char",
    "crenche": "cren-che",
    "creosota": "cre-o-so-ta",
    "creosotada": "cre-o-so-ta-da",
    "creosotado": "cre-o-so-ta-do",
    "creosotar": "cre-o-so-tar",
    "crepa": "cre-pa",
    "crepar": "cre-par",
    "crepé": "cre-pé",
    "crepería": "cre-pe-rí-a",
    "crepitación": "cre-pi-ta-ción",
    "crepitante": "cre-pi-tan-te",
    "crepitar": "cre-pi-tar",
    "crepuscular": "cre-pus-cu-lar",
    "crepusculina": "cre-pus-cu-li-na",
    "crepusculino": "cre-pus-cu-li-no",
    "crepúsculo": "cre-pús-cu-lo",
    "crequeté": "cre-que-té",
    "cresa": "cre-sa",
    "crescendo": "cres-cen-do",
    "creso": "cre-so",
    "crespa": "cres-pa",
    "crespar": "cres-par",
    "crespera": "cres-pe-ra",
    "crespilla": "cres-pi-lla",
    "crespillo": "cres-pi-llo",
    "crespín": "cres-pín",
    "crespina": "cres-pi-na",
    "crespo": "cres-po",
    "crespón": "cres-pón",
    "cresta": "cres-ta",
    "crestada": "cres-ta-da",
    "crestado": "cres-ta-do",
    "crestería": "cres-te-rí-a",
    "crestomatía": "cres-to-ma-tí-a",
    "crestón": "cres-tón",
    "crestuda": "cres-tu-da",
    "crestudo": "cres-tu-do",
    "creta": "cre-ta",
    "cretácea": "cre-tá-ce-a",
    "cretáceo": "cre-tá-ce-o",
    "cretácico": "cre-tá-ci-co",
    "cretense": "cre-ten-se",
    "crética": "cré-ti-ca",
    "crético": "cré-ti-co",
    "cretina": "cre-ti-na",
    "cretinez": "cre-ti-nez",
    "cretinismo": "cre-ti-nis-mo",
    "cretino": "cre-ti-no",
    "cretona": "cre-to-na",
    "creyente": "cre-yen-te",
    "creyer": "cre-yer",
    "creyón": "cre-yón",
    "crezneja": "crez-ne-ja",
    "cría": "crí-a",
    "criación": "cria-ción",
    "criada": "cria-da",
    "criadera": "cria-de-ra",
    "criadero": "cria-de-ro",
    "criadilla": "cria-di-lla",
    "criado": "cria-do",
    "criador": "cria-dor",
    "criadora": "cria-do-ra",
    "críalo": "crí-a-lo",
    "criamiento": "cria-mien-to",
    "criancera": "crian-ce-ra",
    "criancero": "crian-ce-ro",
    "criandera": "crian-de-ra",
    "crianza": "crian-za",
    "criatura": "cria-tu-ra",
    "criazón": "cria-zón",
    "criba": "cri-ba",
    "cribada": "cri-ba-da",
    "cribado": "cri-ba-do",
    "cribador": "cri-ba-dor",
    "cribadora": "cri-ba-do-ra",
    "cribar": "cri-bar",
    "cribas": "cri-bas",
    "cribelo": "cri-be-lo",
    "cribete": "cri-be-te",
    "cribo": "cri-bo",
    "criboso": "cri-bo-so",
    "crica": "cri-ca",
    "cricket": "cric-ket",
    "cricoides": "cri-coi-des",
    "cricrí": "cri-crí",
    "crida": "cri-da",
    "cridar": "cri-dar",
    "crimen": "cri-men",
    "criminación": "cri-mi-na-ción",
    "criminador": "cri-mi-na-dor",
    "criminal": "cri-mi-nal",
    "criminalidad": "cri-mi-na-li-dad",
    "criminalista": "cri-mi-na-lis-ta",
    "criminalización": "cri-mi-na-li-za-ción",
    "criminalizar": "cri-mi-na-li-zar",
    "criminalmente": "cri-mi-nal-men-te",
    "criminar": "cri-mi-nar",
    "criminógeno": "cri-mi-nó-ge-no",
    "criminóloga": "cri-mi-nó-lo-ga",
    "criminología": "cri-mi-no-lo-gí-a",
    "criminológica": "cri-mi-no-ló-gi-ca",
    "criminológico": "cri-mi-no-ló-gi-co",
    "criminólogo": "cri-mi-nó-lo-go",
    "criminosa": "cri-mi-no-sa",
    "criminoso": "cri-mi-no-so",
    "crimno": "crim-no",
    "crinada": "cri-na-da",
    "crinado": "cri-na-do",
    "crinar": "cri-nar",
    "crineja": "cri-ne-ja",
    "crinera": "cri-ne-ra",
    "crinita": "cri-ni-ta",
    "crinito": "cri-ni-to",
    "crinoideo": "cri-noi-de-o",
    "crinolina": "cri-no-li-na",
    "crío": "crí-o",
    "criobiología": "crio-bio-lo-gí-a",
    "criocauterio": "crio-cau-te-rio",
    "criocirugía": "crio-ci-ru-gí-a",
    "criocoagulación": "crio-co-a-gu-la-ción",
    "criogenia": "crio-ge-nia",
    "criogénico": "crio-gé-ni-co",
    "criogenización": "crio-ge-ni-za-ción",
    "criogenizar": "crio-ge-ni-zar",
    "criolla": "crio-lla",
    "criollaje": "crio-lla-je",
    "criollismo": "crio-llis-mo",
    "criollo": "crio-llo",
    "criónica": "crió-ni-ca",
    "crioprotector": "crio-pro-tec-tor",
    "crioscopía": "crios-co-pí-a",
    "crioscopia": "crios-co-pia",
    "criostato": "crios-ta-to",
    "crioterapia": "crio-te-ra-pia",
    "cripta": "crip-ta",
    "crípticamente": "críp-ti-ca-men-te",
    "cripticismo": "crip-ti-cis-mo",
    "críptico": "críp-ti-co",
    "criptoanálisis": "crip-to-a-ná-li-sis",
    "criptofícea": "crip-to-fí-ce-a",
    "criptofíceas": "crip-to-fí-ce-as",
    "criptofíceo": "crip-to-fí-ce-o",
    "criptógama": "crip-tó-ga-ma",
    "criptógamas": "crip-tó-ga-mas",
    "criptógamo": "crip-tó-ga-mo",
    "criptografía": "crip-to-gra-fí-a",
    "criptográfica": "crip-to-grá-fi-ca",
    "criptográfico": "crip-to-grá-fi-co",
    "criptograma": "crip-to-gra-ma",
    "criptón": "crip-tón",
    "criptorquidia": "crip-tor-qui-dia",
    "críquet": "crí-quet",
    "crisálida": "cri-sá-li-da",
    "crisanta": "cri-san-ta",
    "crisantema": "cri-san-te-ma",
    "crisantemo": "cri-san-te-mo",
    "crisis": "cri-sis",
    "crisma": "cris-ma",
    "crismar": "cris-mar",
    "crismazo": "cris-ma-zo",
    "crismera": "cris-me-ra",
    "crismón": "cris-món",
    "crisneja": "cris-ne-ja",
    "crisobalanácea": "cri-so-ba-la-ná-ce-a",
    "crisobalanáceo": "cri-so-ba-la-ná-ce-o",
    "crisoberilo": "cri-so-be-ri-lo",
    "crisocola": "cri-so-co-la",
    "crisol": "cri-sol",
    "crisolada": "cri-so-la-da",
    "crisolar": "cri-so-lar",
    "crisólito": "cri-só-li-to",
    "crisomélido": "cri-so-mé-li-do",
    "crisopa": "cri-so-pa",
    "crisopacio": "cri-so-pa-cio",
    "crisopeya": "cri-so-pe-ya",
    "crisoprasa": "cri-so-pra-sa",
    "crispación": "cris-pa-ción",
    "crispadura": "cris-pa-du-ra",
    "crispamiento": "cris-pa-mien-to",
    "crispante": "cris-pan-te",
    "crispar": "cris-par",
    "crispatura": "cris-pa-tu-ra",
    "crispir": "cris-pir",
    "crista": "cris-ta",
    "cristal": "cris-tal",
    "cristalazo": "cris-ta-la-zo",
    "cristalera": "cris-ta-le-ra",
    "cristalería": "cris-ta-le-rí-a",
    "cristalero": "cris-ta-le-ro",
    "cristalina": "cris-ta-li-na",
    "cristalinamente": "cris-ta-li-na-men-te",
    "cristalino": "cris-ta-li-no",
    "cristalizable": "cris-ta-li-za-ble",
    "cristalización": "cris-ta-li-za-ción",
    "cristalizado": "cris-ta-li-za-do",
    "cristalizar": "cris-ta-li-zar",
    "cristalografía": "cris-ta-lo-gra-fí-a",
    "cristalográfica": "cris-ta-lo-grá-fi-ca",
    "cristalográfico": "cris-ta-lo-grá-fi-co",
    "cristaloide": "cris-ta-loi-de",
    "cristaloidea": "cris-ta-loi-de-a",
    "cristaloideo": "cris-ta-loi-de-o",
    "cristel": "cris-tel",
    "cristera": "cris-te-ra",
    "cristero": "cris-te-ro",
    "cristiana": "cris-tia-na",
    "cristianamente": "cris-tia-na-men-te",
    "cristianar": "cris-tia-nar",
    "cristiandad": "cris-tian-dad",
    "cristianega": "cris-tia-ne-ga",
    "cristianego": "cris-tia-ne-go",
    "cristianería": "cris-tia-ne-rí-a",
    "cristianesca": "cris-tia-nes-ca",
    "cristianesco": "cris-tia-nes-co",
    "cristianísima": "cris-tia-ní-si-ma",
    "cristianísimo": "cris-tia-ní-si-mo",
    "cristianismo": "cris-tia-nis-mo",
    "cristianización": "cris-tia-ni-za-ción",
    "cristianizar": "cris-tia-ni-zar",
    "cristiano": "cris-tia-no",
    "cristianodemócrata": "cris-tia-no-de-mó-cra-ta",
    "cristina": "cris-ti-na",
    "cristino": "cris-ti-no",
    "cristo": "cris-to",
    "cristobalense": "cris-to-ba-len-se",
    "cristofué": "cris-to-fué",
    "cristología": "cris-to-lo-gí-a",
    "cristológico": "cris-to-ló-gi-co",
    "cristus": "cris-tus",
    "crisuela": "cri-sue-la",
    "crisuelo": "cri-sue-lo",
    "criterio": "cri-te-rio",
    "criteriología": "cri-te-rio-lo-gí-a",
    "criteriológico": "cri-te-rio-ló-gi-co",
    "critérium": "cri-té-rium",
    "crítica": "crí-ti-ca",
    "criticable": "cri-ti-ca-ble",
    "criticador": "cri-ti-ca-dor",
    "criticadora": "cri-ti-ca-do-ra",
    "críticamente": "crí-ti-ca-men-te",
    "criticar": "cri-ti-car",
    "criticastro": "cri-ti-cas-tro",
    "criticidad": "cri-ti-ci-dad",
    "criticismo": "cri-ti-cis-mo",
    "crítico": "crí-ti-co",
    "criticón": "cri-ti-cón",
    "criticona": "cri-ti-co-na",
    "critiqueo": "cri-ti-que-o",
    "critiquizar": "cri-ti-qui-zar",
    "crizneja": "criz-ne-ja",
    "croajar": "cro-a-jar",
    "croar": "cro-ar",
    "croata": "cro-a-ta",
    "crocante": "cro-can-te",
    "crocanti": "cro-can-ti",
    "croché": "cro-ché",
    "crochel": "cro-chel",
    "crochet": "cro-chet",
    "crocina": "cro-ci-na",
    "crocino": "cro-ci-no",
    "crocitar": "cro-ci-tar",
    "croco": "cro-co",
    "crocodiliano": "cro-co-di-lia-no",
    "crocodilo": "cro-co-di-lo",
    "croissant": "crois-sant",
    "croissantería": "crois-san-te-rí-a",
    "croissanterie": "crois-san-te-rie",
    "crolista": "cro-lis-ta",
    "cromado": "cro-ma-do",
    "cromar": "cro-mar",
    "cromática": "cro-má-ti-ca",
    "cromáticamente": "cro-má-ti-ca-men-te",
    "cromático": "cro-má-ti-co",
    "cromátida": "cro-má-ti-da",
    "cromatina": "cro-ma-ti-na",
    "cromatismo": "cro-ma-tis-mo",
    "cromatografía": "cro-ma-to-gra-fí-a",
    "cromatógrafo": "cro-ma-tó-gra-fo",
    "crómico": "cró-mi-co",
    "cromita": "cro-mi-ta",
    "crómlech": "cróm-lech",
    "cromo": "cro-mo",
    "cromófora": "cro-mó-fo-ra",
    "cromóforo": "cro-mó-fo-ro",
    "cromógena": "cro-mó-ge-na",
    "cromógeno": "cro-mó-ge-no",
    "cromolitógrafa": "cro-mo-li-tó-gra-fa",
    "cromolitografía": "cro-mo-li-to-gra-fí-a",
    "cromolitografiar": "cro-mo-li-to-gra-fiar",
    "cromolitográfica": "cro-mo-li-to-grá-fi-ca",
    "cromolitográfico": "cro-mo-li-to-grá-fi-co",
    "cromolitógrafo": "cro-mo-li-tó-gra-fo",
    "cromosfera": "cro-mos-fe-ra",
    "cromósfera": "cro-mós-fe-ra",
    "cromosoma": "cro-mo-so-ma",
    "cromosómico": "cro-mo-só-mi-co",
    "cromosomopatía": "cro-mo-so-mo-pa-tí-a",
    "cromoterapia": "cro-mo-te-ra-pia",
    "cromotipia": "cro-mo-ti-pia",
    "cromotipografía": "cro-mo-ti-po-gra-fí-a",
    "cromotipográfica": "cro-mo-ti-po-grá-fi-ca",
    "cromotipográfico": "cro-mo-ti-po-grá-fi-co",
    "crónica": "cró-ni-ca",
    "crónicamente": "cró-ni-ca-men-te",
    "cronicidad": "cro-ni-ci-dad",
    "cronicismo": "cro-ni-cis-mo",
    "crónico": "cró-ni-co",
    "cronicón": "cro-ni-cón",
    "cronificación": "cro-ni-fi-ca-ción",
    "cronificar": "cro-ni-fi-car",
    "cronista": "cro-nis-ta",
    "cronística": "cro-nís-ti-ca",
    "cronístico": "cro-nís-ti-co",
    "crónlech": "crón-lech",
    "crono": "cro-no",
    "cronobiología": "cro-no-bio-lo-gí-a",
    "cronoescalada": "cro-no-es-ca-la-da",
    "cronógrafa": "cro-nó-gra-fa",
    "cronografía": "cro-no-gra-fí-a",
    "cronógrafo": "cro-nó-gra-fo",
    "cronograma": "cro-no-gra-ma",
    "cronóloga": "cro-nó-lo-ga",
    "cronología": "cro-no-lo-gí-a",
    "cronológica": "cro-no-ló-gi-ca",
    "cronológicamente": "cro-no-ló-gi-ca-men-te",
    "cronológico": "cro-no-ló-gi-co",
    "cronologista": "cro-no-lo-gis-ta",
    "cronólogo": "cro-nó-lo-go",
    "cronometrador": "cro-no-me-tra-dor",
    "cronometradora": "cro-no-me-tra-do-ra",
    "cronometraje": "cro-no-me-tra-je",
    "cronometrar": "cro-no-me-trar",
    "cronometría": "cro-no-me-trí-a",
    "cronométrica": "cro-no-mé-tri-ca",
    "cronométrico": "cro-no-mé-tri-co",
    "cronómetro": "cro-nó-me-tro",
    "croque": "cro-que",
    "croquero": "cro-que-ro",
    "croquet": "cro-quet",
    "croqueta": "cro-que-ta",
    "croquis": "cro-quis",
    "croscitar": "cros-ci-tar",
    "crossista": "cros-sis-ta",
    "crota": "cro-ta",
    "crótalo": "cró-ta-lo",
    "croto": "cro-to",
    "crotón": "cro-tón",
    "crotoniata": "cro-to-nia-ta",
    "crotorar": "cro-to-rar",
    "croza": "cro-za",
    "crúamente": "crú-a-men-te",
    "cruasán": "crua-sán",
    "cruasantería": "crua-san-te-rí-a",
    "cruce": "cru-ce",
    "cruceiro": "cru-cei-ro",
    "cruceña": "cru-ce-ña",
    "cruceño": "cru-ce-ño",
    "crucera": "cru-ce-ra",
    "crucería": "cru-ce-rí-a",
    "crucero": "cru-ce-ro",
    "cruceta": "cru-ce-ta",
    "crucial": "cru-cial",
    "cruciata": "cru-cia-ta",
    "crucífera": "cru-cí-fe-ra",
    "cruciferario": "cru-ci-fe-ra-rio",
    "crucíferas": "cru-cí-fe-ras",
    "crucífero": "cru-cí-fe-ro",
    "crucificada": "cru-ci-fi-ca-da",
    "crucificado": "cru-ci-fi-ca-do",
    "crucificar": "cru-ci-fi-car",
    "crucifijo": "cru-ci-fi-jo",
    "crucifixión": "cru-ci-fi-xión",
    "crucifixor": "cru-ci-fi-xor",
    "cruciforme": "cru-ci-for-me",
    "crucígera": "cru-cí-ge-ra",
    "crucígero": "cru-cí-ge-ro",
    "crucigrama": "cru-ci-gra-ma",
    "crucigramista": "cru-ci-gra-mis-ta",
    "crucillo": "cru-ci-llo",
    "cruda": "cru-da",
    "crudamente": "cru-da-men-te",
    "crudelísima": "cru-de-lí-si-ma",
    "crudelísimo": "cru-de-lí-si-mo",
    "crudeza": "cru-de-za",
    "crudillo": "cru-di-llo",
    "crudío": "cru-dí-o",
    "crudo": "cru-do",
    "crueldad": "cruel-dad",
    "cruelmente": "cruel-men-te",
    "cruenta": "cruen-ta",
    "cruentación": "cruen-ta-ción",
    "cruentamente": "cruen-ta-men-te",
    "cruentar": "cruen-tar",
    "cruentidad": "cruen-ti-dad",
    "cruento": "cruen-to",
    "crueza": "crue-za",
    "crujía": "cru-jí-a",
    "crujidera": "cru-ji-de-ra",
    "crujidero": "cru-ji-de-ro",
    "crujido": "cru-ji-do",
    "crujiente": "cru-jien-te",
    "crujir": "cru-jir",
    "crumiro": "cru-mi-ro",
    "crúor": "crú-or",
    "cruórica": "cruó-ri-ca",
    "cruórico": "cruó-ri-co",
    "crupal": "cru-pal",
    "crupier": "cru-pier",
    "crural": "cru-ral",
    "crustácea": "crus-tá-ce-a",
    "crustáceo": "crus-tá-ce-o",
    "crústula": "crús-tu-la",
    "cruza": "cru-za",
    "cruzada": "cru-za-da",
    "cruzado": "cru-za-do",
    "cruzador": "cru-za-dor",
    "cruzadora": "cru-za-do-ra",
    "cruzamiento": "cru-za-mien-to",
    "cruzar": "cru-zar",
    "cruzeiro": "cru-zei-ro",
    "ctenóforo": "cte-nó-fo-ro",
    "cuaba": "cua-ba",
    "cuacar": "cua-car",
    "cuacha": "cua-cha",
    "cuache": "cua-che",
    "cuaco": "cua-co",
    "cuada": "cua-da",
    "cuaderna": "cua-der-na",
    "cuadernal": "cua-der-nal",
    "cuadernaria": "cua-der-na-ria",
    "cuadernario": "cua-der-na-rio",
    "cuadernillo": "cua-der-ni-llo",
    "cuaderno": "cua-der-no",
    "cuado": "cua-do",
    "cuadra": "cua-dra",
    "cuadrada": "cua-dra-da",
    "cuadradamente": "cua-dra-da-men-te",
    "cuadradillo": "cua-dra-di-llo",
    "cuadrado": "cua-dra-do",
    "cuadradura": "cua-dra-du-ra",
    "cuadrafonía": "cua-dra-fo-ní-a",
    "cuadrafónico": "cua-dra-fó-ni-co",
    "cuadragenaria": "cua-dra-ge-na-ria",
    "cuadragenario": "cua-dra-ge-na-rio",
    "cuadragésima": "cua-dra-gé-si-ma",
    "cuadragesimal": "cua-dra-ge-si-mal",
    "cuadragésimo": "cua-dra-gé-si-mo",
    "cuadral": "cua-dral",
    "cuadrángula": "cua-drán-gu-la",
    "cuadrangular": "cua-dran-gu-lar",
    "cuadrángulo": "cua-drán-gu-lo",
    "cuadrantal": "cua-dran-tal",
    "cuadrante": "cua-dran-te",
    "cuadranura": "cua-dra-nu-ra",
    "cuadrar": "cua-drar",
    "cuadrático": "cua-drá-ti-co",
    "cuadratín": "cua-dra-tín",
    "cuadratura": "cua-dra-tu-ra",
    "cuadri": "cua-dri",
    "cuádrica": "cuá-dri-ca",
    "cuadricenal": "cua-dri-ce-nal",
    "cuádriceps": "cuá-dri-ceps",
    "cuadrícula": "cua-drí-cu-la",
    "cuadriculación": "cua-dri-cu-la-ción",
    "cuadriculado": "cua-dri-cu-la-do",
    "cuadricular": "cua-dri-cu-lar",
    "cuadrienal": "cua-drie-nal",
    "cuadrienio": "cua-drie-nio",
    "cuadrifolia": "cua-dri-fo-lia",
    "cuadrifoliado": "cua-dri-fo-lia-do",
    "cuadrifolio": "cua-dri-fo-lio",
    "cuadriforme": "cua-dri-for-me",
    "cuadriga": "cua-dri-ga",
    "cuadrigato": "cua-dri-ga-to",
    "cuadriguero": "cua-dri-gue-ro",
    "cuadril": "cua-dril",
    "cuadrilátera": "cua-dri-lá-te-ra",
    "cuadrilátero": "cua-dri-lá-te-ro",
    "cuadrilítera": "cua-dri-lí-te-ra",
    "cuadriliteral": "cua-dri-li-te-ral",
    "cuadrilítero": "cua-dri-lí-te-ro",
    "cuadrilla": "cua-dri-lla",
    "cuadrillazo": "cua-dri-lla-zo",
    "cuadrillero": "cua-dri-lle-ro",
    "cuadrillo": "cua-dri-llo",
    "cuadrilón": "cua-dri-lón",
    "cuadrilona": "cua-dri-lo-na",
    "cuadrilonga": "cua-dri-lon-ga",
    "cuadrilongo": "cua-dri-lon-go",
    "cuadrimestre": "cua-dri-mes-tre",
    "cuadringentésima": "cua-drin-gen-té-si-ma",
    "cuadringentésimo": "cua-drin-gen-té-si-mo",
    "cuadrinieta": "cua-dri-nie-ta",
    "cuadrinieto": "cua-dri-nie-to",
    "cuadrinomio": "cua-dri-no-mio",
    "cuadriplicar": "cua-dri-pli-car",
    "cuadrisílaba": "cua-dri-sí-la-ba",
    "cuadrisílabo": "cua-dri-sí-la-bo",
    "cuadrivio": "cua-dri-vio",
    "cuadrivista": "cua-dri-vis-ta",
    "cuadriyugo": "cua-dri-yu-go",
    "cuadro": "cua-dro",
    "cuadropea": "cua-dro-pe-a",
    "cuadrumana": "cua-dru-ma-na",
    "cuadrúmana": "cua-drú-ma-na",
    "cuadrumano": "cua-dru-ma-no",
    "cuadrupedal": "cua-dru-pe-dal",
    "cuadrupedante": "cua-dru-pe-dan-te",
    "cuadrúpede": "cua-drú-pe-de",
    "cuadrúpedo": "cua-drú-pe-do",
    "cuádrupla": "cuá-dru-pla",
    "cuádruple": "cuá-dru-ple",
    "cuadruplicación": "cua-dru-pli-ca-ción",
    "cuadruplicar": "cua-dru-pli-car",
    "cuádruplo": "cuá-dru-plo",
    "cuaima": "cuai-ma",
    "cuairón": "cuai-rón",
    "cuajada": "cua-ja-da",
    "cuajadera": "cua-ja-de-ra",
    "cuajadillo": "cua-ja-di-llo",
    "cuajado": "cua-ja-do",
    "cuajadura": "cua-ja-du-ra",
    "cuajaenredos": "cua-ja-en-re-dos",
    "cuajaleche": "cua-ja-le-che",
    "cuajamiento": "cua-ja-mien-to",
    "cuajaní": "cua-ja-ní",
    "cuajar": "cua-jar",
    "cuajarón": "cua-ja-rón",
    "cuajicote": "cua-ji-co-te",
    "cuajilote": "cua-ji-lo-te",
    "cuajinicuil": "cua-ji-ni-cuil",
    "cuajiote": "cua-jio-te",
    "cuajo": "cua-jo",
    "cuákera": "cuá-ke-ra",
    "cuakerismo": "cua-ke-ris-mo",
    "cuákero": "cuá-ke-ro",
    "cualesquier": "cua-les-quier",
    "cualesquiera": "cua-les-quie-ra",
    "cualidad": "cua-li-dad",
    "cualificación": "cua-li-fi-ca-ción",
    "cualificado": "cua-li-fi-ca-do",
    "cualificar": "cua-li-fi-car",
    "cualitativa": "cua-li-ta-ti-va",
    "cualitativo": "cua-li-ta-ti-vo",
    "cualque": "cual-que",
    "cualquier": "cual-quier",
    "cualquiera": "cual-quie-ra",
    "cuamaña": "cua-ma-ña",
    "cuamaño": "cua-ma-ño",
    "cuamil": "cua-mil",
    "cuando": "cuan-do",
    "cuándo": "cuán-do",
    "cuanta": "cuan-ta",
    "cuantía": "cuan-tí-a",
    "cuantiar": "cuan-tiar",
    "cuántica": "cuán-ti-ca",
    "cuántico": "cuán-ti-co",
    "cuantidad": "cuan-ti-dad",
    "cuantificable": "cuan-ti-fi-ca-ble",
    "cuantificación": "cuan-ti-fi-ca-ción",
    "cuantificado": "cuan-ti-fi-ca-do",
    "cuantificador": "cuan-ti-fi-ca-dor",
    "cuantificar": "cuan-ti-fi-car",
    "cuantimás": "cuan-ti-más",
    "cuantiosa": "cuan-tio-sa",
    "cuantiosamente": "cuan-tio-sa-men-te",
    "cuantioso": "cuan-tio-so",
    "cuantitativa": "cuan-ti-ta-ti-va",
    "cuantitativo": "cuan-ti-ta-ti-vo",
    "cuantizar": "cuan-ti-zar",
    "cuanto": "cuan-to",
    "cuánto": "cuán-to",
    "cuape": "cua-pe",
    "cuáquera": "cuá-que-ra",
    "cuaquerismo": "cua-que-ris-mo",
    "cuáquero": "cuá-que-ro",
    "cuarango": "cua-ran-go",
    "cuarcífero": "cuar-cí-fe-ro",
    "cuarcita": "cuar-ci-ta",
    "cuarenta": "cua-ren-ta",
    "cuarentañera": "cua-ren-ta-ñe-ra",
    "cuarentañero": "cua-ren-ta-ñe-ro",
    "cuarentava": "cua-ren-ta-va",
    "cuarentavo": "cua-ren-ta-vo",
    "cuarentén": "cua-ren-tén",
    "cuarentena": "cua-ren-te-na",
    "cuarentenal": "cua-ren-te-nal",
    "cuarenteno": "cua-ren-te-no",
    "cuarentón": "cua-ren-tón",
    "cuarentona": "cua-ren-to-na",
    "cuaresma": "cua-res-ma",
    "cuaresmal": "cua-res-mal",
    "cuaresmar": "cua-res-mar",
    "cuaresmario": "cua-res-ma-rio",
    "cuarta": "cuar-ta",
    "cuartago": "cuar-ta-go",
    "cuartal": "cuar-tal",
    "cuartamente": "cuar-ta-men-te",
    "cuartán": "cuar-tán",
    "cuartana": "cuar-ta-na",
    "cuartanal": "cuar-ta-nal",
    "cuartanaria": "cuar-ta-na-ria",
    "cuartanario": "cuar-ta-na-rio",
    "cuartar": "cuar-tar",
    "cuartazo": "cuar-ta-zo",
    "cuartazos": "cuar-ta-zos",
    "cuarteador": "cuar-te-a-dor",
    "cuarteadora": "cuar-te-a-do-ra",
    "cuarteamiento": "cuar-te-a-mien-to",
    "cuartear": "cuar-te-ar",
    "cuartel": "cuar-tel",
    "cuartelada": "cuar-te-la-da",
    "cuartelado": "cuar-te-la-do",
    "cuartelar": "cuar-te-lar",
    "cuartelario": "cuar-te-la-rio",
    "cuartelazo": "cuar-te-la-zo",
    "cuartelera": "cuar-te-le-ra",
    "cuartelero": "cuar-te-le-ro",
    "cuartelillo": "cuar-te-li-llo",
    "cuarteo": "cuar-te-o",
    "cuartera": "cuar-te-ra",
    "cuarterada": "cuar-te-ra-da",
    "cuartería": "cuar-te-rí-a",
    "cuartero": "cuar-te-ro",
    "cuarterola": "cuar-te-ro-la",
    "cuarterón": "cuar-te-rón",
    "cuarterona": "cuar-te-ro-na",
    "cuarteta": "cuar-te-ta",
    "cuartete": "cuar-te-te",
    "cuarteto": "cuar-te-to",
    "cuartil": "cuar-til",
    "cuartilla": "cuar-ti-lla",
    "cuartillero": "cuar-ti-lle-ro",
    "cuartillo": "cuar-ti-llo",
    "cuartilluda": "cuar-ti-llu-da",
    "cuartilludo": "cuar-ti-llu-do",
    "cuartizo": "cuar-ti-zo",
    "cuarto": "cuar-to",
    "cuartodecimana": "cuar-to-de-ci-ma-na",
    "cuartodecimano": "cuar-to-de-ci-ma-no",
    "cuartofinalista": "cuar-to-fi-na-lis-ta",
    "cuartogénita": "cuar-to-gé-ni-ta",
    "cuartogénito": "cuar-to-gé-ni-to",
    "cuartón": "cuar-tón",
    "cuartucho": "cuar-tu-cho",
    "cuarzo": "cuar-zo",
    "cuarzosa": "cuar-zo-sa",
    "cuarzoso": "cuar-zo-so",
    "cuásar": "cuá-sar",
    "cuasi": "cua-si",
    "cuasia": "cua-sia",
    "cuasicontrato": "cua-si-con-tra-to",
    "cuasidelito": "cua-si-de-li-to",
    "cuasimodo": "cua-si-mo-do",
    "cuata": "cua-ta",
    "cuatacha": "cua-ta-cha",
    "cuatachismo": "cua-ta-chis-mo",
    "cuatacho": "cua-ta-cho",
    "cuate": "cua-te",
    "cuatequil": "cua-te-quil",
    "cuaterna": "cua-ter-na",
    "cuaternaria": "cua-ter-na-ria",
    "cuaternario": "cua-ter-na-rio",
    "cuaternidad": "cua-ter-ni-dad",
    "cuaterno": "cua-ter-no",
    "cuatezón": "cua-te-zón",
    "cuatezona": "cua-te-zo-na",
    "cuatí": "cua-tí",
    "cuatorvirato": "cua-tor-vi-ra-to",
    "cuatorviro": "cua-tor-vi-ro",
    "cuatralba": "cua-tral-ba",
    "cuatralbo": "cua-tral-bo",
    "cuatratua": "cua-tra-tua",
    "cuatratuo": "cua-tra-tuo",
    "cuatreña": "cua-tre-ña",
    "cuatreño": "cua-tre-ño",
    "cuatrera": "cua-tre-ra",
    "cuatrerismo": "cua-tre-ris-mo",
    "cuatrero": "cua-tre-ro",
    "cuatri": "cua-tri",
    "cuatriboleada": "cua-tri-bo-le-a-da",
    "cuatriboleado": "cua-tri-bo-le-a-do",
    "cuatricromía": "cua-tri-cro-mí-a",
    "cuatriduana": "cua-tri-dua-na",
    "cuatriduano": "cua-tri-dua-no",
    "cuatrienal": "cua-trie-nal",
    "cuatrienio": "cua-trie-nio",
    "cuatrilliza": "cua-tri-lli-za",
    "cuatrillizo": "cua-tri-lli-zo",
    "cuatrillo": "cua-tri-llo",
    "cuatrillón": "cua-tri-llón",
    "cuatrimestral": "cua-tri-mes-tral",
    "cuatrimestre": "cua-tri-mes-tre",
    "cuatrimotor": "cua-tri-mo-tor",
    "cuatrín": "cua-trín",
    "cuatrinca": "cua-trin-ca",
    "cuatripartito": "cua-tri-par-ti-to",
    "cuatrisílaba": "cua-tri-sí-la-ba",
    "cuatrisílabo": "cua-tri-sí-la-bo",
    "cuatro": "cua-tro",
    "cuatrocentista": "cua-tro-cen-tis-ta",
    "cuatrocientas": "cua-tro-cien-tas",
    "cuatrocientos": "cua-tro-cien-tos",
    "cuatrodoblar": "cua-tro-do-blar",
    "cuatrojos": "cua-tro-jos",
    "cuatromilpas": "cua-tro-mil-pas",
    "cuatronarices": "cua-tro-na-ri-ces",
    "cuatropea": "cua-tro-pe-a",
    "cuatropeado": "cua-tro-pe-a-do",
    "cuatropeo": "cua-tro-pe-o",
    "cuatrotanto": "cua-tro-tan-to",
    "cuauhnahuacense": "cuauh-na-hua-cen-se",
    "cuauhxicalli": "cuauh-xi-ca-lli",
    "cuayote": "cua-yo-te",
    "cuba": "cu-ba",
    "cubalibre": "cu-ba-li-bre",
    "cubana": "cu-ba-na",
    "cubanismo": "cu-ba-nis-mo",
    "cubanito": "cu-ba-ni-to",
    "cubano": "cu-ba-no",
    "cubata": "cu-ba-ta",
    "cubayera": "cu-ba-ye-ra",
    "cubeba": "cu-be-ba",
    "cubera": "cu-be-ra",
    "cubereta": "cu-be-re-ta",
    "cubería": "cu-be-rí-a",
    "cubero": "cu-be-ro",
    "cubertería": "cu-ber-te-rí-a",
    "cubertura": "cu-ber-tu-ra",
    "cubeta": "cu-be-ta",
    "cubetada": "cu-be-ta-da",
    "cubetera": "cu-be-te-ra",
    "cubeto": "cu-be-to",
    "cúbica": "cú-bi-ca",
    "cubicación": "cu-bi-ca-ción",
    "cubicar": "cu-bi-car",
    "cubichete": "cu-bi-che-te",
    "cúbico": "cú-bi-co",
    "cubiculario": "cu-bi-cu-la-rio",
    "cubículo": "cu-bí-cu-lo",
    "cubierta": "cu-bier-ta",
    "cubiertamente": "cu-bier-ta-men-te",
    "cubiertería": "cu-bier-te-rí-a",
    "cubierto": "cu-bier-to",
    "cubijar": "cu-bi-jar",
    "cubil": "cu-bil",
    "cubilar": "cu-bi-lar",
    "cubilete": "cu-bi-le-te",
    "cubiletear": "cu-bi-le-te-ar",
    "cubileteo": "cu-bi-le-te-o",
    "cubiletero": "cu-bi-le-te-ro",
    "cubilla": "cu-bi-lla",
    "cubillo": "cu-bi-llo",
    "cubilote": "cu-bi-lo-te",
    "cubio": "cu-bio",
    "cubismo": "cu-bis-mo",
    "cubista": "cu-bis-ta",
    "cubital": "cu-bi-tal",
    "cubitera": "cu-bi-te-ra",
    "cubito": "cu-bi-to",
    "cúbito": "cú-bi-to",
    "cubo": "cu-bo",
    "cuboides": "cu-boi-des",
    "cubrebañera": "cu-bre-ba-ñe-ra",
    "cubrebotones": "cu-bre-bo-to-nes",
    "cubrecabeza": "cu-bre-ca-be-za",
    "cubrecabezas": "cu-bre-ca-be-zas",
    "cubrecadena": "cu-bre-ca-de-na",
    "cubrecama": "cu-bre-ca-ma",
    "cubrecorsé": "cu-bre-cor-sé",
    "cubrecosturas": "cu-bre-cos-tu-ras",
    "cubrenuca": "cu-bre-nu-ca",
    "cubreobjeto": "cu-bre-ob-je-to",
    "cubreobjetos": "cu-bre-ob-je-tos",
    "cubrepán": "cu-bre-pán",
    "cubrición": "cu-bri-ción",
    "cubrimiento": "cu-bri-mien-to",
    "cubrir": "cu-brir",
    "cuca": "cu-ca",
    "cucaburra": "cu-ca-bu-rra",
    "cucalón": "cu-ca-lón",
    "cucamba": "cu-cam-ba",
    "cucamente": "cu-ca-men-te",
    "cucamonas": "cu-ca-mo-nas",
    "cucaña": "cu-ca-ña",
    "cucañera": "cu-ca-ñe-ra",
    "cucañero": "cu-ca-ñe-ro",
    "cucar": "cu-car",
    "cucaracha": "cu-ca-ra-cha",
    "cucarachera": "cu-ca-ra-che-ra",
    "cucarachero": "cu-ca-ra-che-ro",
    "cucarda": "cu-car-da",
    "cucarra": "cu-ca-rra",
    "cucarro": "cu-ca-rro",
    "cucayo": "cu-ca-yo",
    "cucha": "cu-cha",
    "cuchar": "cu-char",
    "cuchara": "cu-cha-ra",
    "cucharada": "cu-cha-ra-da",
    "cucharadita": "cu-cha-ra-di-ta",
    "cucharal": "cu-cha-ral",
    "cucharear": "cu-cha-re-ar",
    "cucharera": "cu-cha-re-ra",
    "cucharero": "cu-cha-re-ro",
    "cucharilla": "cu-cha-ri-lla",
    "cucharita": "cu-cha-ri-ta",
    "cucharrena": "cu-cha-rre-na",
    "cuchepo": "cu-che-po",
    "cucheta": "cu-che-ta",
    "cuchí": "cu-chí",
    "cuchichear": "cu-chi-che-ar",
    "cuchicheo": "cu-chi-che-o",
    "cuchichí": "cu-chi-chí",
    "cuchilear": "cu-chi-le-ar",
    "cuchillada": "cu-chi-lla-da",
    "cuchillar": "cu-chi-llar",
    "cuchillazo": "cu-chi-lla-zo",
    "cuchillería": "cu-chi-lle-rí-a",
    "cuchillero": "cu-chi-lle-ro",
    "cuchillo": "cu-chi-llo",
    "cuchipanda": "cu-chi-pan-da",
    "cuchitos": "cu-chi-tos",
    "cuchitril": "cu-chi-tril",
    "cucho": "cu-cho",
    "cuchubal": "cu-chu-bal",
    "cuchuchear": "cu-chu-che-ar",
    "cuchuco": "cu-chu-co",
    "cuchufleta": "cu-chu-fle-ta",
    "cuchufletera": "cu-chu-fle-te-ra",
    "cuchufletero": "cu-chu-fle-te-ro",
    "cuchuflí": "cu-chu-flí",
    "cuchugo": "cu-chu-go",
    "cuchumbo": "cu-chum-bo",
    "cuchuvalear": "cu-chu-va-le-ar",
    "cuclí": "cu-clí",
    "cuclillas": "cu-cli-llas",
    "cuclillo": "cu-cli-llo",
    "cuco": "cu-co",
    "cucú": "cu-cú",
    "cucubá": "cu-cu-bá",
    "cucubano": "cu-cu-ba-no",
    "cucubo": "cu-cu-bo",
    "cucufata": "cu-cu-fa-ta",
    "cucufato": "cu-cu-fa-to",
    "cucuiza": "cu-cui-za",
    "cuculí": "cu-cu-lí",
    "cuculiforme": "cu-cu-li-for-me",
    "cuculla": "cu-cu-lla",
    "cuculmeca": "cu-cul-me-ca",
    "cuculmeque": "cu-cul-me-que",
    "cucúrbita": "cu-cúr-bi-ta",
    "cucurbitácea": "cu-cur-bi-tá-ce-a",
    "cucurbitáceas": "cu-cur-bi-tá-ce-as",
    "cucurbitáceo": "cu-cur-bi-tá-ce-o",
    "cucurbitales": "cu-cur-bi-ta-les",
    "cucuruca": "cu-cu-ru-ca",
    "cucurucho": "cu-cu-ru-cho",
    "cucuteña": "cu-cu-te-ña",
    "cucuteño": "cu-cu-te-ño",
    "cucuy": "cu-cuy",
    "cucuya": "cu-cu-ya",
    "cucuyo": "cu-cu-yo",
    "cudicia": "cu-di-cia",
    "cudría": "cu-drí-a",
    "cudrío": "cu-drí-o",
    "cueca": "cue-ca",
    "cuecada": "cue-ca-da",
    "cuechar": "cue-char",
    "cuechero": "cue-che-ro",
    "cueco": "cue-co",
    "cuélebre": "cué-le-bre",
    "cuelga": "cuel-ga",
    "cuelgacapas": "cuel-ga-ca-pas",
    "cuelgaplatos": "cuel-ga-pla-tos",
    "cuelgue": "cuel-gue",
    "cuellicorta": "cue-lli-cor-ta",
    "cuellicorto": "cue-lli-cor-to",
    "cuellidegollada": "cue-lli-de-go-lla-da",
    "cuellidegollado": "cue-lli-de-go-lla-do",
    "cuellierguida": "cue-llier-gui-da",
    "cuellierguido": "cue-llier-gui-do",
    "cuellilarga": "cue-lli-lar-ga",
    "cuellilargo": "cue-lli-lar-go",
    "cuellinegro": "cue-lli-ne-gro",
    "cuellirrojo": "cue-lli-rro-jo",
    "cuello": "cue-llo",
    "cuelmo": "cuel-mo",
    "cuenca": "cuen-ca",
    "cuencana": "cuen-ca-na",
    "cuencano": "cuen-ca-no",
    "cuenco": "cuen-co",
    "cuenda": "cuen-da",
    "cuenta": "cuen-ta",
    "cuentacacao": "cuen-ta-ca-ca-o",
    "cuentachiles": "cuen-ta-chi-les",
    "cuentacorrentista": "cuen-ta-co-rren-tis-ta",
    "cuentacuentos": "cuen-ta-cuen-tos",
    "cuentadante": "cuen-ta-dan-te",
    "cuentagotas": "cuen-ta-go-tas",
    "cuentahabiente": "cuen-ta-ha-bien-te",
    "cuentahílos": "cuen-ta-hí-los",
    "cuentakilómetros": "cuen-ta-ki-ló-me-tros",
    "cuentapasos": "cuen-ta-pa-sos",
    "cuentapropista": "cuen-ta-pro-pis-ta",
    "cuentarrevoluciones": "cuen-ta-rre-vo-lu-cio-nes",
    "cuentavueltas": "cuen-ta-vuel-tas",
    "cuentear": "cuen-te-ar",
    "cuentera": "cuen-te-ra",
    "cuentero": "cuen-te-ro",
    "cuentista": "cuen-tis-ta",
    "cuentística": "cuen-tís-ti-ca",
    "cuentístico": "cuen-tís-ti-co",
    "cuento": "cuen-to",
    "cuentón": "cuen-tón",
    "cuentona": "cuen-to-na",
    "cuequería": "cue-que-rí-a",
    "cuera": "cue-ra",
    "cuerazo": "cue-ra-zo",
    "cuerda": "cuer-da",
    "cuerdamente": "cuer-da-men-te",
    "cuerdear": "cuer-de-ar",
    "cuerdo": "cuer-do",
    "cuereada": "cue-re-a-da",
    "cuerear": "cue-re-ar",
    "cuerero": "cue-re-ro",
    "cuereta": "cue-re-ta",
    "cuerezuelo": "cue-re-zue-lo",
    "cuerina": "cue-ri-na",
    "cueriza": "cue-ri-za",
    "cuerna": "cuer-na",
    "cuérnago": "cuér-na-go",
    "cuernavaquense": "cuer-na-va-quen-se",
    "cuernezuelo": "cuer-ne-zue-lo",
    "cuernito": "cuer-ni-to",
    "cuerno": "cuer-no",
    "cuero": "cue-ro",
    "cuerpear": "cuer-pe-ar",
    "cuerpo": "cuer-po",
    "cuérrago": "cué-rra-go",
    "cuerria": "cue-rria",
    "cuerudo": "cue-ru-do",
    "cuerva": "cuer-va",
    "cuervera": "cuer-ve-ra",
    "cuervo": "cuer-vo",
    "cuesco": "cues-co",
    "cueshte": "cuesh-te",
    "cuesquiza": "cues-qui-za",
    "cuesta": "cues-ta",
    "cuestación": "cues-ta-ción",
    "cuestión": "cues-tión",
    "cuestionable": "cues-tio-na-ble",
    "cuestionamiento": "cues-tio-na-mien-to",
    "cuestionar": "cues-tio-nar",
    "cuestionario": "cues-tio-na-rio",
    "cuesto": "cues-to",
    "cuestor": "cues-tor",
    "cuestuaria": "cues-tua-ria",
    "cuestuario": "cues-tua-rio",
    "cuestuosa": "cues-tuo-sa",
    "cuestuoso": "cues-tuo-so",
    "cuestura": "cues-tu-ra",
    "cuétano": "cué-ta-no",
    "cuete": "cue-te",
    "cueto": "cue-to",
    "cueva": "cue-va",
    "cuévano": "cué-va-no",
    "cuevero": "cue-ve-ro",
    "cuevudo": "cue-vu-do",
    "cuexca": "cuex-ca",
    "cueza": "cue-za",
    "cuezo": "cue-zo",
    "cúfica": "cú-fi-ca",
    "cúfico": "cú-fi-co",
    "cufifo": "cu-fi-fo",
    "cugujada": "cu-gu-ja-da",
    "cugulla": "cu-gu-lla",
    "cuica": "cui-ca",
    "cuicacoche": "cui-ca-co-che",
    "cuico": "cui-co",
    "cuicuy": "cui-cuy",
    "cuida": "cui-da",
    "cuidado": "cui-da-do",
    "cuidador": "cui-da-dor",
    "cuidadora": "cui-da-do-ra",
    "cuidadosa": "cui-da-do-sa",
    "cuidadosamente": "cui-da-do-sa-men-te",
    "cuidadoso": "cui-da-do-so",
    "cuidar": "cui-dar",
    "cuido": "cui-do",
    "cuidosa": "cui-do-sa",
    "cuidosamente": "cui-do-sa-men-te",
    "cuidoso": "cui-do-so",
    "cuija": "cui-ja",
    "cuijen": "cui-jen",
    "cuilapaneca": "cui-la-pa-ne-ca",
    "cuilapaneco": "cui-la-pa-ne-co",
    "cuilío": "cui-lí-o",
    "cuilio": "cui-lio",
    "cuillar": "cui-llar",
    "cuillo": "cui-llo",
    "cuilo": "cui-lo",
    "cuilón": "cui-lón",
    "cuina": "cui-na",
    "cuino": "cui-no",
    "cuita": "cui-ta",
    "cuitada": "cui-ta-da",
    "cuitadamente": "cui-ta-da-men-te",
    "cuitadez": "cui-ta-dez",
    "cuitado": "cui-ta-do",
    "cuitamiento": "cui-ta-mien-to",
    "cuitar": "cui-tar",
    "cuitear": "cui-te-ar",
    "cuitero": "cui-te-ro",
    "cuitlacoche": "cui-tla-co-che",
    "cuitosa": "cui-to-sa",
    "cuitoso": "cui-to-so",
    "cuja": "cu-ja",
    "cujara": "cu-ja-ra",
    "cuje": "cu-je",
    "cují": "cu-jí",
    "cujín": "cu-jín",
    "cujinicuil": "cu-ji-ni-cuil",
    "cujinillo": "cu-ji-ni-llo",
    "cujisal": "cu-ji-sal",
    "cujito": "cu-ji-to",
    "cujón": "cu-jón",
    "culada": "cu-la-da",
    "culantrillo": "cu-lan-tri-llo",
    "culantro": "cu-lan-tro",
    "cular": "cu-lar",
    "culas": "cu-las",
    "culata": "cu-la-ta",
    "culatazo": "cu-la-ta-zo",
    "culatear": "cu-la-te-ar",
    "culatín": "cu-la-tín",
    "culcusido": "cul-cu-si-do",
    "culé": "cu-lé",
    "culear": "cu-le-ar",
    "culebra": "cu-le-bra",
    "culebrazo": "cu-le-bra-zo",
    "culebrear": "cu-le-bre-ar",
    "culebreo": "cu-le-bre-o",
    "culebrera": "cu-le-bre-ra",
    "culebrero": "cu-le-bre-ro",
    "culebrilla": "cu-le-bri-lla",
    "culebrina": "cu-le-bri-na",
    "culebro": "cu-le-bro",
    "culebrón": "cu-le-brón",
    "culeca": "cu-le-ca",
    "culeco": "cu-le-co",
    "culén": "cu-lén",
    "culera": "cu-le-ra",
    "culero": "cu-le-ro",
    "culi": "cu-li",
    "culiacanense": "cu-lia-ca-nen-se",
    "culiacano": "cu-lia-ca-no",
    "culibajo": "cu-li-ba-jo",
    "culicacho": "cu-li-ca-cho",
    "culichi": "cu-li-chi",
    "culichoso": "cu-li-cho-so",
    "culícido": "cu-lí-ci-do",
    "culicunco": "cu-li-cun-co",
    "culillera": "cu-li-lle-ra",
    "culillo": "cu-li-llo",
    "culín": "cu-lín",
    "culinaria": "cu-li-na-ria",
    "culinario": "cu-li-na-rio",
    "culinegra": "cu-li-ne-gra",
    "culinegro": "cu-li-ne-gro",
    "culío": "cu-lí-o",
    "culipandear": "cu-li-pan-de-ar",
    "culito": "cu-li-to",
    "culle": "cu-lle",
    "cullerense": "cu-lle-ren-se",
    "culmen": "cul-men",
    "culminación": "cul-mi-na-ción",
    "culminante": "cul-mi-nan-te",
    "culminar": "cul-mi-nar",
    "culo": "cu-lo",
    "culombio": "cu-lom-bio",
    "culón": "cu-lón",
    "culona": "cu-lo-na",
    "culote": "cu-lo-te",
    "culpa": "cul-pa",
    "culpabilidad": "cul-pa-bi-li-dad",
    "culpabilísimo": "cul-pa-bi-lí-si-mo",
    "culpabilización": "cul-pa-bi-li-za-ción",
    "culpabilizar": "cul-pa-bi-li-zar",
    "culpable": "cul-pa-ble",
    "culpablemente": "cul-pa-ble-men-te",
    "culpación": "cul-pa-ción",
    "culpada": "cul-pa-da",
    "culpado": "cul-pa-do",
    "culpante": "cul-pan-te",
    "culpar": "cul-par",
    "culpeo": "cul-pe-o",
    "culposa": "cul-po-sa",
    "culposamente": "cul-po-sa-men-te",
    "culposo": "cul-po-so",
    "culta": "cul-ta",
    "cultalatiniparla": "cul-ta-la-ti-ni-par-la",
    "cultamente": "cul-ta-men-te",
    "cultedad": "cul-te-dad",
    "cultera": "cul-te-ra",
    "culterana": "cul-te-ra-na",
    "culteranismo": "cul-te-ra-nis-mo",
    "culterano": "cul-te-ra-no",
    "cultería": "cul-te-rí-a",
    "cultero": "cul-te-ro",
    "cultiparlar": "cul-ti-par-lar",
    "cultiparlista": "cul-ti-par-lis-ta",
    "cultipicaña": "cul-ti-pi-ca-ña",
    "cultipicaño": "cul-ti-pi-ca-ño",
    "cultismo": "cul-tis-mo",
    "cultivable": "cul-ti-va-ble",
    "cultivación": "cul-ti-va-ción",
    "cultivado": "cul-ti-va-do",
    "cultivador": "cul-ti-va-dor",
    "cultivadora": "cul-ti-va-do-ra",
    "cultivar": "cul-ti-var",
    "cultivo": "cul-ti-vo",
    "culto": "cul-to",
    "cultor": "cul-tor",
    "cultora": "cul-to-ra",
    "cultosa": "cul-to-sa",
    "cultoso": "cul-to-so",
    "cultrún": "cul-trún",
    "cultual": "cul-tual",
    "cultura": "cul-tu-ra",
    "cultural": "cul-tu-ral",
    "culturalismo": "cul-tu-ra-lis-mo",
    "culturalista": "cul-tu-ra-lis-ta",
    "culturalmente": "cul-tu-ral-men-te",
    "culturar": "cul-tu-rar",
    "culturismo": "cul-tu-ris-mo",
    "culturista": "cul-tu-ris-ta",
    "culturización": "cul-tu-ri-za-ción",
    "culturizar": "cul-tu-ri-zar",
    "culturoso": "cul-tu-ro-so",
    "culuca": "cu-lu-ca",
    "cuma": "cu-ma",
    "cumana": "cu-ma-na",
    "cumanagota": "cu-ma-na-go-ta",
    "cumanagoto": "cu-ma-na-go-to",
    "cumanana": "cu-ma-na-na",
    "cumanés": "cu-ma-nés",
    "cumanesa": "cu-ma-ne-sa",
    "cumano": "cu-ma-no",
    "cumarú": "cu-ma-rú",
    "cumba": "cum-ba",
    "cumbamba": "cum-bam-ba",
    "cumbancha": "cum-ban-cha",
    "cumbarí": "cum-ba-rí",
    "cumbe": "cum-be",
    "cumbé": "cum-bé",
    "cumbear": "cum-be-ar",
    "cumbia": "cum-bia",
    "cumbiamba": "cum-biam-ba",
    "cumbo": "cum-bo",
    "cumbral": "cum-bral",
    "cumbre": "cum-bre",
    "cumbrera": "cum-bre-ra",
    "cúmel": "cú-mel",
    "cumiche": "cu-mi-che",
    "cumínico": "cu-mí-ni-co",
    "cuminol": "cu-mi-nol",
    "cumpa": "cum-pa",
    "cúmplase": "cúm-pla-se",
    "cumpleañera": "cum-ple-a-ñe-ra",
    "cumpleañero": "cum-ple-a-ñe-ro",
    "cumpleaños": "cum-ple-a-ños",
    "cumplida": "cum-pli-da",
    "cumplidamente": "cum-pli-da-men-te",
    "cumplidera": "cum-pli-de-ra",
    "cumplidero": "cum-pli-de-ro",
    "cumplido": "cum-pli-do",
    "cumplidor": "cum-pli-dor",
    "cumplidora": "cum-pli-do-ra",
    "cumplimentación": "cum-pli-men-ta-ción",
    "cumplimentar": "cum-pli-men-tar",
    "cumplimentera": "cum-pli-men-te-ra",
    "cumplimentero": "cum-pli-men-te-ro",
    "cumplimento": "cum-pli-men-to",
    "cumplimiento": "cum-pli-mien-to",
    "cumplir": "cum-plir",
    "cumquibus": "cum-qui-bus",
    "cumulación": "cu-mu-la-ción",
    "cumulador": "cu-mu-la-dor",
    "cumuladora": "cu-mu-la-do-ra",
    "cumular": "cu-mu-lar",
    "cumulativo": "cu-mu-la-ti-vo",
    "cúmulo": "cú-mu-lo",
    "cumulonimbo": "cu-mu-lo-nim-bo",
    "cuna": "cu-na",
    "cuña": "cu-ña",
    "cunacho": "cu-na-cho",
    "cuñada": "cu-ña-da",
    "cuñadería": "cu-ña-de-rí-a",
    "cuñadía": "cu-ña-dí-a",
    "cuñado": "cu-ña-do",
    "cunaguaro": "cu-na-gua-ro",
    "cuñal": "cu-ñal",
    "cuñapé": "cu-ña-pé",
    "cunar": "cu-nar",
    "cuñar": "cu-ñar",
    "cuncho": "cun-cho",
    "cunchu": "cun-chu",
    "cuncuna": "cun-cu-na",
    "cunda": "cun-da",
    "cundango": "cun-dan-go",
    "cundeamor": "cun-de-a-mor",
    "cundiamor": "cun-dia-mor",
    "cundido": "cun-di-do",
    "cundidor": "cun-di-dor",
    "cundinamarqués": "cun-di-na-mar-qués",
    "cundinamarquesa": "cun-di-na-mar-que-sa",
    "cundir": "cun-dir",
    "cundundear": "cun-dun-de-ar",
    "cunear": "cu-ne-ar",
    "cuneca": "cu-ne-ca",
    "cuneco": "cu-ne-co",
    "cuneiforme": "cu-nei-for-me",
    "cuneo": "cu-ne-o",
    "cúneo": "cú-ne-o",
    "cunera": "cu-ne-ra",
    "cunero": "cu-ne-ro",
    "cuneta": "cu-ne-ta",
    "cuñete": "cu-ñe-te",
    "cunicultor": "cu-ni-cul-tor",
    "cunicultora": "cu-ni-cul-to-ra",
    "cunicultura": "cu-ni-cul-tu-ra",
    "cunnilingus": "cun-ni-lin-gus",
    "cuño": "cu-ño",
    "cuodlibetal": "cuod-li-be-tal",
    "cuodlibética": "cuod-li-bé-ti-ca",
    "cuodlibético": "cuod-li-bé-ti-co",
    "cuodlibeto": "cuod-li-be-to",
    "cuota": "cuo-ta",
    "cuotalitis": "cuo-ta-li-tis",
    "cuotear": "cuo-te-ar",
    "cuotidiana": "cuo-ti-dia-na",
    "cuotidiano": "cuo-ti-dia-no",
    "cupana": "cu-pa-na",
    "cupé": "cu-pé",
    "cupido": "cu-pi-do",
    "cupilca": "cu-pil-ca",
    "cupitel": "cu-pi-tel",
    "cuplé": "cu-plé",
    "cupletista": "cu-ple-tis-ta",
    "cupo": "cu-po",
    "cupón": "cu-pón",
    "cuprero": "cu-pre-ro",
    "cupresácea": "cu-pre-sá-ce-a",
    "cupresáceo": "cu-pre-sá-ce-o",
    "cupresina": "cu-pre-si-na",
    "cupresino": "cu-pre-si-no",
    "cúprica": "cú-pri-ca",
    "cúprico": "cú-pri-co",
    "cuprífera": "cu-prí-fe-ra",
    "cuprífero": "cu-prí-fe-ro",
    "cuproníquel": "cu-pro-ní-quel",
    "cuprosa": "cu-pro-sa",
    "cuproso": "cu-pro-so",
    "cúpula": "cú-pu-la",
    "cupulado": "cu-pu-la-do",
    "cupulífera": "cu-pu-lí-fe-ra",
    "cupulífero": "cu-pu-lí-fe-ro",
    "cupulino": "cu-pu-li-no",
    "cuquear": "cu-que-ar",
    "cuquera": "cu-que-ra",
    "cuquería": "cu-que-rí-a",
    "cuquero": "cu-que-ro",
    "cuquillo": "cu-qui-llo",
    "cura": "cu-ra",
    "curable": "cu-ra-ble",
    "curaca": "cu-ra-ca",
    "curación": "cu-ra-ción",
    "curada": "cu-ra-da",
    "curadera": "cu-ra-de-ra",
    "curadillo": "cu-ra-di-llo",
    "curado": "cu-ra-do",
    "curador": "cu-ra-dor",
    "curadora": "cu-ra-do-ra",
    "curadoría": "cu-ra-do-rí-a",
    "curaduría": "cu-ra-du-rí-a",
    "curagua": "cu-ra-gua",
    "cural": "cu-ral",
    "curalle": "cu-ra-lle",
    "curalotodo": "cu-ra-lo-to-do",
    "curamagüey": "cu-ra-ma-güey",
    "curamichate": "cu-ra-mi-cha-te",
    "curandera": "cu-ran-de-ra",
    "curandería": "cu-ran-de-rí-a",
    "curanderil": "cu-ran-de-ril",
    "curanderismo": "cu-ran-de-ris-mo",
    "curandero": "cu-ran-de-ro",
    "curángano": "cu-rán-ga-no",
    "curanto": "cu-ran-to",
    "curar": "cu-rar",
    "curare": "cu-ra-re",
    "curarina": "cu-ra-ri-na",
    "curasao": "cu-ra-sa-o",
    "curatela": "cu-ra-te-la",
    "curativa": "cu-ra-ti-va",
    "curativo": "cu-ra-ti-vo",
    "curato": "cu-ra-to",
    "curazao": "cu-ra-za-o",
    "curazgo": "cu-raz-go",
    "curazoleña": "cu-ra-zo-le-ña",
    "curazoleño": "cu-ra-zo-le-ño",
    "cúrbana": "cúr-ba-na",
    "curbaril": "cur-ba-ril",
    "curbasá": "cur-ba-sá",
    "curca": "cur-ca",
    "curco": "cur-co",
    "curcucha": "cur-cu-cha",
    "curcucho": "cur-cu-cho",
    "cúrcuma": "cúr-cu-ma",
    "curcuncha": "cur-cun-cha",
    "curcuncho": "cur-cun-cho",
    "curcusilla": "cur-cu-si-lla",
    "curda": "cur-da",
    "curdela": "cur-de-la",
    "curdo": "cur-do",
    "cureña": "cu-re-ña",
    "cureñaje": "cu-re-ña-je",
    "curesca": "cu-res-ca",
    "curetuí": "cu-re-tuí",
    "curí": "cu-rí",
    "curia": "cu-ria",
    "curial": "cu-rial",
    "curialesca": "cu-ria-les-ca",
    "curialesco": "cu-ria-les-co",
    "curialidad": "cu-ria-li-dad",
    "curiana": "cu-ria-na",
    "curiar": "cu-riar",
    "curiara": "cu-ria-ra",
    "curicana": "cu-ri-ca-na",
    "curicano": "cu-ri-ca-no",
    "curiche": "cu-ri-che",
    "curie": "cu-rie",
    "curiel": "cu-riel",
    "curiela": "cu-rie-la",
    "curio": "cu-rio",
    "curiosa": "cu-rio-sa",
    "curiosamente": "cu-rio-sa-men-te",
    "curiosear": "cu-rio-se-ar",
    "curioseo": "cu-rio-se-o",
    "curiosidad": "cu-rio-si-dad",
    "curioso": "cu-rio-so",
    "curiquingue": "cu-ri-quin-gue",
    "curita": "cu-ri-ta",
    "curlandés": "cur-lan-dés",
    "curlandesa": "cur-lan-de-sa",
    "curling": "cur-ling",
    "curo": "cu-ro",
    "curra": "cu-rra",
    "curranta": "cu-rran-ta",
    "currante": "cu-rran-te",
    "currar": "cu-rrar",
    "curre": "cu-rre",
    "currelanta": "cu-rre-lan-ta",
    "currelante": "cu-rre-lan-te",
    "currelar": "cu-rre-lar",
    "currele": "cu-rre-le",
    "currelo": "cu-rre-lo",
    "curricán": "cu-rri-cán",
    "curricular": "cu-rri-cu-lar",
    "currículo": "cu-rrí-cu-lo",
    "currinche": "cu-rrin-che",
    "currito": "cu-rri-to",
    "curro": "cu-rro",
    "curruca": "cu-rru-ca",
    "currucha": "cu-rru-cha",
    "currucho": "cu-rru-cho",
    "curruña": "cu-rru-ña",
    "curruscante": "cu-rrus-can-te",
    "currusco": "cu-rrus-co",
    "currutaca": "cu-rru-ta-ca",
    "currutaco": "cu-rru-ta-co",
    "cursada": "cur-sa-da",
    "cursado": "cur-sa-do",
    "cursar": "cur-sar",
    "cursaria": "cur-sa-ria",
    "cursario": "cur-sa-rio",
    "cursera": "cur-se-ra",
    "cursería": "cur-se-rí-a",
    "cursi": "cur-si",
    "cursilada": "cur-si-la-da",
    "cursilería": "cur-si-le-rí-a",
    "cursilísimo": "cur-si-lí-si-mo",
    "cursillista": "cur-si-llis-ta",
    "cursillo": "cur-si-llo",
    "cursilón": "cur-si-lón",
    "cursilona": "cur-si-lo-na",
    "cursiva": "cur-si-va",
    "cursivo": "cur-si-vo",
    "curso": "cur-so",
    "cursómetro": "cur-só-me-tro",
    "cursor": "cur-sor",
    "curta": "cur-ta",
    "curtación": "cur-ta-ción",
    "curtida": "cur-ti-da",
    "curtido": "cur-ti-do",
    "curtidor": "cur-ti-dor",
    "curtidora": "cur-ti-do-ra",
    "curtidura": "cur-ti-du-ra",
    "curtiduría": "cur-ti-du-rí-a",
    "curtiembre": "cur-tiem-bre",
    "curtiente": "cur-tien-te",
    "curtimbre": "cur-tim-bre",
    "curtimiento": "cur-ti-mien-to",
    "curtir": "cur-tir",
    "curto": "cur-to",
    "curuba": "cu-ru-ba",
    "curubo": "cu-ru-bo",
    "curuca": "cu-ru-ca",
    "curuchupa": "cu-ru-chu-pa",
    "curucú": "cu-ru-cú",
    "curucusí": "cu-ru-cu-sí",
    "curucutear": "cu-ru-cu-te-ar",
    "curueña": "cu-rue-ña",
    "curuguá": "cu-ru-guá",
    "curuja": "cu-ru-ja",
    "curujey": "cu-ru-jey",
    "curul": "cu-rul",
    "curuma": "cu-ru-ma",
    "curumba": "cu-rum-ba",
    "curupay": "cu-ru-pay",
    "cururasca": "cu-ru-ras-ca",
    "cururo": "cu-ru-ro",
    "cururú": "cu-ru-rú",
    "curuvica": "cu-ru-vi-ca",
    "curva": "cur-va",
    "curvada": "cur-va-da",
    "curvado": "cur-va-do",
    "curvar": "cur-var",
    "curvatón": "cur-va-tón",
    "curvatura": "cur-va-tu-ra",
    "curvería": "cur-ve-rí-a",
    "curvidad": "cur-vi-dad",
    "curvilínea": "cur-vi-lí-ne-a",
    "curvilíneo": "cur-vi-lí-ne-o",
    "curvímetro": "cur-ví-me-tro",
    "curvo": "cur-vo",
    "cusca": "cus-ca",
    "cuscatleco": "cus-ca-tle-co",
    "cusco": "cus-co",
    "cuscú": "cus-cú",
    "cuscungo": "cus-cun-go",
    "cuscurro": "cus-cu-rro",
    "cuscús": "cus-cús",
    "cuscuta": "cus-cu-ta",
    "cusifai": "cu-si-fai",
    "cusinga": "cu-sin-ga",
    "cusir": "cu-sir",
    "cusita": "cu-si-ta",
    "cusma": "cus-ma",
    "cusnaca": "cus-na-ca",
    "cuspa": "cus-pa",
    "cúspide": "cús-pi-de",
    "custodia": "cus-to-dia",
    "custodiar": "cus-to-diar",
    "custodio": "cus-to-dio",
    "custrir": "cus-trir",
    "cusubé": "cu-su-bé",
    "cusuco": "cu-su-co",
    "cusul": "cu-sul",
    "cusumbe": "cu-sum-be",
    "cusumbo": "cu-sum-bo",
    "cususa": "cu-su-sa",
    "cuta": "cu-ta",
    "cutacha": "cu-ta-cha",
    "cutama": "cu-ta-ma",
    "cutánea": "cu-tá-ne-a",
    "cutáneo": "cu-tá-ne-o",
    "cutara": "cu-ta-ra",
    "cutarra": "cu-ta-rra",
    "cute": "cu-te",
    "cúter": "cú-ter",
    "cutete": "cu-te-te",
    "cutí": "cu-tí",
    "cutiana": "cu-tia-na",
    "cutiano": "cu-tia-no",
    "cutícula": "cu-tí-cu-la",
    "cuticular": "cu-ti-cu-lar",
    "cutidero": "cu-ti-de-ro",
    "cutina": "cu-ti-na",
    "cutio": "cu-tio",
    "cutir": "cu-tir",
    "cutis": "cu-tis",
    "cuto": "cu-to",
    "cutra": "cu-tra",
    "cutral": "cu-tral",
    "cutre": "cu-tre",
    "cutredad": "cu-tre-dad",
    "cutrería": "cu-tre-rí-a",
    "cutrerío": "cu-tre-rí-o",
    "cutrez": "cu-trez",
    "cutuco": "cu-tu-co",
    "cutusa": "cu-tu-sa",
    "cututear": "cu-tu-te-ar",
    "cuya": "cu-ya",
    "cuyá": "cu-yá",
    "cuyada": "cu-ya-da",
    "cuyamel": "cu-ya-mel",
    "cuyana": "cu-ya-na",
    "cuyano": "cu-ya-no",
    "cuye": "cu-ye",
    "cuyeo": "cu-ye-o",
    "cuyero": "cu-ye-ro",
    "cuyo": "cu-yo",
    "cúyo": "cú-yo",
    "cuyují": "cu-yu-jí",
    "cuza": "cu-za",
    "cuzcatleca": "cuz-ca-tle-ca",
    "cuzcatleco": "cuz-ca-tle-co",
    "cuzco": "cuz-co",
    "cuzcuz": "cuz-cuz",
    "cuzma": "cuz-ma",
    "cuzo": "cu-zo",
    "cuzqueña": "cuz-que-ña",
    "cuzqueño": "cuz-que-ño",
    "cuzul": "cu-zul",
    "czardas": "czar-das",
    "dable": "da-ble",
    "dabuten": "da-bu-ten",
    "dabuti": "da-bu-ti",
    "daca": "da-ca",
    "dacá": "da-cá",
    "dacha": "da-cha",
    "dacia": "da-cia",
    "dacio": "da-cio",
    "dación": "da-ción",
    "dacriocistitis": "da-crio-cis-ti-tis",
    "dacriología": "da-crio-lo-gí-a",
    "dacriorrea": "da-crio-rre-a",
    "dacrón": "da-crón",
    "dactilada": "dac-ti-la-da",
    "dactilado": "dac-ti-la-do",
    "dactilar": "dac-ti-lar",
    "dactílica": "dac-tí-li-ca",
    "dactílico": "dac-tí-li-co",
    "dactiliforme": "dac-ti-li-for-me",
    "dactiliología": "dac-ti-lio-lo-gí-a",
    "dactilión": "dac-ti-lión",
    "dáctilo": "dác-ti-lo",
    "dactilógrafa": "dac-ti-ló-gra-fa",
    "dactilografía": "dac-ti-lo-gra-fí-a",
    "dactilografiar": "dac-ti-lo-gra-fiar",
    "dactilográfica": "dac-ti-lo-grá-fi-ca",
    "dactilográfico": "dac-ti-lo-grá-fi-co",
    "dactilógrafo": "dac-ti-ló-gra-fo",
    "dactilograma": "dac-ti-lo-gra-ma",
    "dactilología": "dac-ti-lo-lo-gí-a",
    "dactilológico": "dac-ti-lo-ló-gi-co",
    "dactiloscopia": "dac-ti-los-co-pia",
    "dactiloscópica": "dac-ti-los-có-pi-ca",
    "dactiloscópicamente": "dac-ti-los-có-pi-ca-men-te",
    "dactiloscópico": "dac-ti-los-có-pi-co",
    "dactiloscopista": "dac-ti-los-co-pis-ta",
    "dada": "da-da",
    "dadá": "da-dá",
    "dadaísmo": "da-da-ís-mo",
    "dadaísta": "da-da-ís-ta",
    "dadera": "da-de-ra",
    "dadero": "da-de-ro",
    "dádiva": "dá-di-va",
    "dadivada": "da-di-va-da",
    "dadivado": "da-di-va-do",
    "dadivar": "da-di-var",
    "dadivosa": "da-di-vo-sa",
    "dadivosamente": "da-di-vo-sa-men-te",
    "dadivosidad": "da-di-vo-si-dad",
    "dadivoso": "da-di-vo-so",
    "dado": "da-do",
    "dador": "da-dor",
    "dadora": "da-do-ra",
    "daga": "da-ga",
    "dagame": "da-ga-me",
    "daguerreotipo": "da-gue-rre-o-ti-po",
    "daguerrotipar": "da-gue-rro-ti-par",
    "daguerrotipia": "da-gue-rro-ti-pia",
    "daguerrotipo": "da-gue-rro-ti-po",
    "daguestana": "da-gues-ta-na",
    "daguestano": "da-gues-ta-no",
    "daguilla": "da-gui-lla",
    "dahír": "da-hír",
    "daifa": "dai-fa",
    "daimiel": "dai-miel",
    "daimio": "dai-mio",
    "daiquiri": "dai-qui-ri",
    "dajabonera": "da-ja-bo-ne-ra",
    "dajabonero": "da-ja-bo-ne-ro",
    "dajao": "da-ja-o",
    "dala": "da-la",
    "dalaga": "da-la-ga",
    "dalgo": "dal-go",
    "dalia": "da-lia",
    "dalind": "da-lind",
    "daliniano": "da-li-nia-no",
    "dalla": "da-lla",
    "dallá": "da-llá",
    "dallador": "da-lla-dor",
    "dalladora": "da-lla-do-ra",
    "dallar": "da-llar",
    "dalle": "da-lle",
    "dálmata": "dál-ma-ta",
    "dalmática": "dal-má-ti-ca",
    "dalmático": "dal-má-ti-co",
    "daltoniana": "dal-to-nia-na",
    "daltoniano": "dal-to-nia-no",
    "daltónica": "dal-tó-ni-ca",
    "daltónico": "dal-tó-ni-co",
    "daltonismo": "dal-to-nis-mo",
    "dama": "da-ma",
    "damacena": "da-ma-ce-na",
    "damaceno": "da-ma-ce-no",
    "damacuao": "da-ma-cua-o",
    "damajagua": "da-ma-ja-gua",
    "damajuana": "da-ma-jua-na",
    "damajuao": "da-ma-jua-o",
    "damán": "da-mán",
    "damasana": "da-ma-sa-na",
    "damascada": "da-mas-ca-da",
    "damascado": "da-mas-ca-do",
    "damascena": "da-mas-ce-na",
    "damasceno": "da-mas-ce-no",
    "damascense": "da-mas-cen-se",
    "damasco": "da-mas-co",
    "damasina": "da-ma-si-na",
    "damasonio": "da-ma-so-nio",
    "damasquillo": "da-mas-qui-llo",
    "damasquina": "da-mas-qui-na",
    "damasquinado": "da-mas-qui-na-do",
    "damasquinador": "da-mas-qui-na-dor",
    "damasquinadora": "da-mas-qui-na-do-ra",
    "damasquinar": "da-mas-qui-nar",
    "damasquino": "da-mas-qui-no",
    "damería": "da-me-rí-a",
    "damero": "da-me-ro",
    "damerograma": "da-me-ro-gra-ma",
    "damiana": "da-mia-na",
    "damil": "da-mil",
    "damisela": "da-mi-se-la",
    "damnable": "dam-na-ble",
    "damnación": "dam-na-ción",
    "damnada": "dam-na-da",
    "damnado": "dam-na-do",
    "damnificada": "dam-ni-fi-ca-da",
    "damnificado": "dam-ni-fi-ca-do",
    "damnificador": "dam-ni-fi-ca-dor",
    "damnificadora": "dam-ni-fi-ca-do-ra",
    "damnificar": "dam-ni-fi-car",
    "dañable": "da-ña-ble",
    "dañación": "da-ña-ción",
    "dañada": "da-ña-da",
    "dañado": "da-ña-do",
    "dañador": "da-ña-dor",
    "dañadora": "da-ña-do-ra",
    "danaide": "da-nai-de",
    "dañar": "da-ñar",
    "dance": "dan-ce",
    "danchada": "dan-cha-da",
    "danchado": "dan-cha-do",
    "dandi": "dan-di",
    "dandismo": "dan-dis-mo",
    "danés": "da-nés",
    "danesa": "da-ne-sa",
    "dango": "dan-go",
    "dánica": "dá-ni-ca",
    "dánico": "dá-ni-co",
    "dañina": "da-ñi-na",
    "dañino": "da-ñi-no",
    "danlideña": "dan-li-de-ña",
    "danlideño": "dan-li-de-ño",
    "daño": "da-ño",
    "dañosa": "da-ño-sa",
    "dañoso": "da-ño-so",
    "danta": "dan-ta",
    "dante": "dan-te",
    "dantellada": "dan-te-lla-da",
    "dantellado": "dan-te-lla-do",
    "dantesca": "dan-tes-ca",
    "dantesco": "dan-tes-co",
    "dantismo": "dan-tis-mo",
    "dantista": "dan-tis-ta",
    "danto": "dan-to",
    "danubiana": "da-nu-bia-na",
    "danubiano": "da-nu-bia-no",
    "danza": "dan-za",
    "danzado": "dan-za-do",
    "danzador": "dan-za-dor",
    "danzadora": "dan-za-do-ra",
    "danzanta": "dan-zan-ta",
    "danzante": "dan-zan-te",
    "danzar": "dan-zar",
    "danzarín": "dan-za-rín",
    "danzarina": "dan-za-ri-na",
    "danzón": "dan-zón",
    "daquí": "da-quí",
    "dardabasí": "dar-da-ba-sí",
    "dardada": "dar-da-da",
    "dárdana": "dár-da-na",
    "dardania": "dar-da-nia",
    "dardanio": "dar-da-nio",
    "dardanismo": "dar-da-nis-mo",
    "dárdano": "dár-da-no",
    "dardo": "dar-do",
    "dares": "da-res",
    "darga": "dar-ga",
    "darico": "da-ri-co",
    "darienita": "da-rie-ni-ta",
    "dársena": "dár-se-na",
    "darviniano": "dar-vi-nia-no",
    "darvinismo": "dar-vi-nis-mo",
    "darwinista": "dar-wi-nis-ta",
    "dasocracia": "da-so-cra-cia",
    "dasocrática": "da-so-crá-ti-ca",
    "dasocrático": "da-so-crá-ti-co",
    "dasonomía": "da-so-no-mí-a",
    "dasonómica": "da-so-nó-mi-ca",
    "dasonómico": "da-so-nó-mi-co",
    "data": "da-ta",
    "datación": "da-ta-ción",
    "datáfono": "da-tá-fo-no",
    "datar": "da-tar",
    "dataría": "da-ta-rí-a",
    "datario": "da-ta-rio",
    "datear": "da-te-ar",
    "dateo": "da-te-o",
    "datera": "da-te-ra",
    "datero": "da-te-ro",
    "dátil": "dá-til",
    "datilada": "da-ti-la-da",
    "datilado": "da-ti-la-do",
    "datilera": "da-ti-le-ra",
    "datismo": "da-tis-mo",
    "dativa": "da-ti-va",
    "dativo": "da-ti-vo",
    "dato": "da-to",
    "datura": "da-tu-ra",
    "daturina": "da-tu-ri-na",
    "dauco": "dau-co",
    "daudá": "dau-dá",
    "dauleña": "dau-le-ña",
    "dauleño": "dau-le-ño",
    "davalar": "da-va-lar",
    "david": "da-vid",
    "davideña": "da-vi-de-ña",
    "davideño": "da-vi-de-ño",
    "davídica": "da-ví-di-ca",
    "davídico": "da-ví-di-co",
    "daza": "da-za",
    "dazibao": "da-zi-ba-o",
    "dea": "de-a",
    "deadjetival": "de-ad-je-ti-val",
    "deadverbial": "de-ad-ver-bial",
    "deal": "de-al",
    "deambulación": "de-am-bu-la-ción",
    "deambular": "de-am-bu-lar",
    "deambulatorio": "de-am-bu-la-to-rio",
    "deán": "de-án",
    "deanato": "de-a-na-to",
    "deanazgo": "de-a-naz-go",
    "debacle": "de-ba-cle",
    "debajero": "de-ba-je-ro",
    "debajo": "de-ba-jo",
    "debandar": "de-ban-dar",
    "debate": "de-ba-te",
    "debatir": "de-ba-tir",
    "debda": "deb-da",
    "debdo": "deb-do",
    "debe": "de-be",
    "debelación": "de-be-la-ción",
    "debelador": "de-be-la-dor",
    "debeladora": "de-be-la-do-ra",
    "debelar": "de-be-lar",
    "deber": "de-ber",
    "debida": "de-bi-da",
    "debidamente": "de-bi-da-men-te",
    "debido": "de-bi-do",
    "débil": "dé-bil",
    "debilidad": "de-bi-li-dad",
    "debilitación": "de-bi-li-ta-ción",
    "debilitamiento": "de-bi-li-ta-mien-to",
    "debilitante": "de-bi-li-tan-te",
    "debilitar": "de-bi-li-tar",
    "débilmente": "dé-bil-men-te",
    "debilucha": "de-bi-lu-cha",
    "debilucho": "de-bi-lu-cho",
    "debitar": "de-bi-tar",
    "débito": "dé-bi-to",
    "debla": "de-bla",
    "debó": "de-bó",
    "debocar": "de-bo-car",
    "debrocar": "de-bro-car",
    "debruzar": "de-bru-zar",
    "debut": "de-but",
    "debutante": "de-bu-tan-te",
    "debutar": "de-bu-tar",
    "deca": "de-ca",
    "década": "dé-ca-da",
    "decadencia": "de-ca-den-cia",
    "decadente": "de-ca-den-te",
    "decadentemente": "de-ca-den-te-men-te",
    "decadentismo": "de-ca-den-tis-mo",
    "decadentista": "de-ca-den-tis-ta",
    "decaedro": "de-ca-e-dro",
    "decaer": "de-ca-er",
    "decágona": "de-cá-go-na",
    "decagonal": "de-ca-go-nal",
    "decágono": "de-cá-go-no",
    "decagramo": "de-ca-gra-mo",
    "decaíble": "de-ca-í-ble",
    "decaída": "de-ca-í-da",
    "decaído": "de-ca-í-do",
    "decaimiento": "de-cai-mien-to",
    "decalcificación": "de-cal-ci-fi-ca-ción",
    "decalcificar": "de-cal-ci-fi-car",
    "decalitro": "de-ca-li-tro",
    "decálogo": "de-cá-lo-go",
    "decalvación": "de-cal-va-ción",
    "decalvar": "de-cal-var",
    "decámetro": "de-cá-me-tro",
    "decampar": "de-cam-par",
    "decana": "de-ca-na",
    "decanato": "de-ca-na-to",
    "decanatura": "de-ca-na-tu-ra",
    "decania": "de-ca-nia",
    "decano": "de-ca-no",
    "decantación": "de-can-ta-ción",
    "decantador": "de-can-ta-dor",
    "decantar": "de-can-tar",
    "decapitación": "de-ca-pi-ta-ción",
    "decapitar": "de-ca-pi-tar",
    "decápodo": "de-cá-po-do",
    "decárea": "de-cá-re-a",
    "decasílaba": "de-ca-sí-la-ba",
    "decasílabo": "de-ca-sí-la-bo",
    "decatlón": "de-ca-tlón",
    "decatloniana": "de-ca-tlo-nia-na",
    "decatloniano": "de-ca-tlo-nia-no",
    "decebimiento": "de-ce-bi-mien-to",
    "decebir": "de-ce-bir",
    "deceleración": "de-ce-le-ra-ción",
    "decelerar": "de-ce-le-rar",
    "decembrino": "de-cem-bri-no",
    "decemnovenal": "de-cem-no-ve-nal",
    "decemnovenario": "de-cem-no-ve-na-rio",
    "decena": "de-ce-na",
    "decenal": "de-ce-nal",
    "decenar": "de-ce-nar",
    "decenaria": "de-ce-na-ria",
    "decenario": "de-ce-na-rio",
    "decencia": "de-cen-cia",
    "decendencia": "de-cen-den-cia",
    "decender": "de-cen-der",
    "decendida": "de-cen-di-da",
    "decendimiento": "de-cen-di-mien-to",
    "decenio": "de-ce-nio",
    "deceno": "de-ce-no",
    "decenso": "de-cen-so",
    "decentar": "de-cen-tar",
    "decente": "de-cen-te",
    "decentemente": "de-cen-te-men-te",
    "decenvir": "de-cen-vir",
    "decenviral": "de-cen-vi-ral",
    "decenvirato": "de-cen-vi-ra-to",
    "decenviro": "de-cen-vi-ro",
    "decepar": "de-ce-par",
    "decepción": "de-cep-ción",
    "decepcionante": "de-cep-cio-nan-te",
    "decepcionar": "de-cep-cio-nar",
    "deceptoria": "de-cep-to-ria",
    "deceptorio": "de-cep-to-rio",
    "decercar": "de-cer-car",
    "decernir": "de-cer-nir",
    "decesado": "de-ce-sa-do",
    "decesión": "de-ce-sión",
    "deceso": "de-ce-so",
    "dechado": "de-cha-do",
    "deci": "de-ci",
    "deciárea": "de-ciá-re-a",
    "decibel": "de-ci-bel",
    "decibelímetro": "de-ci-be-lí-me-tro",
    "decibelio": "de-ci-be-lio",
    "decible": "de-ci-ble",
    "decidera": "de-ci-de-ra",
    "decidero": "de-ci-de-ro",
    "decidida": "de-ci-di-da",
    "decididamente": "de-ci-di-da-men-te",
    "decidido": "de-ci-di-do",
    "decidir": "de-ci-dir",
    "decidor": "de-ci-dor",
    "decidora": "de-ci-do-ra",
    "deciembre": "de-ciem-bre",
    "deciente": "de-cien-te",
    "decigramo": "de-ci-gra-mo",
    "decilitro": "de-ci-li-tro",
    "décima": "dé-ci-ma",
    "decimacuarta": "de-ci-ma-cuar-ta",
    "decimal": "de-ci-mal",
    "decimalmente": "de-ci-mal-men-te",
    "decimanona": "de-ci-ma-no-na",
    "decimanovena": "de-ci-ma-no-ve-na",
    "decimaoctava": "de-ci-ma-oc-ta-va",
    "decimaquinta": "de-ci-ma-quin-ta",
    "decimaséptima": "de-ci-ma-sép-ti-ma",
    "decimasexta": "de-ci-ma-sex-ta",
    "decimatercera": "de-ci-ma-ter-ce-ra",
    "decimatercia": "de-ci-ma-ter-cia",
    "decimero": "de-ci-me-ro",
    "decímetro": "de-cí-me-tro",
    "décimo": "dé-ci-mo",
    "decimoctava": "de-ci-moc-ta-va",
    "decimoctavo": "de-ci-moc-ta-vo",
    "decimocuarta": "de-ci-mo-cuar-ta",
    "decimocuarto": "de-ci-mo-cuar-to",
    "decimonona": "de-ci-mo-no-na",
    "decimonónico": "de-ci-mo-nó-ni-co",
    "decimonono": "de-ci-mo-no-no",
    "decimonovena": "de-ci-mo-no-ve-na",
    "decimonoveno": "de-ci-mo-no-ve-no",
    "decimoquinta": "de-ci-mo-quin-ta",
    "decimoquinto": "de-ci-mo-quin-to",
    "decimoséptima": "de-ci-mo-sép-ti-ma",
    "decimoséptimo": "de-ci-mo-sép-ti-mo",
    "decimosexta": "de-ci-mo-sex-ta",
    "decimosexto": "de-ci-mo-sex-to",
    "decimotercera": "de-ci-mo-ter-ce-ra",
    "decimotercero": "de-ci-mo-ter-ce-ro",
    "decimotercia": "de-ci-mo-ter-cia",
    "decimotercio": "de-ci-mo-ter-cio",
    "deciochena": "de-cio-che-na",
    "deciocheno": "de-cio-che-no",
    "decir": "de-cir",
    "decisión": "de-ci-sión",
    "decisiva": "de-ci-si-va",
    "decisivamente": "de-ci-si-va-men-te",
    "decisivo": "de-ci-si-vo",
    "decisorio": "de-ci-so-rio",
    "decitex": "de-ci-tex",
    "declamación": "de-cla-ma-ción",
    "declamador": "de-cla-ma-dor",
    "declamadora": "de-cla-ma-do-ra",
    "declamar": "de-cla-mar",
    "declamatoria": "de-cla-ma-to-ria",
    "declamatoriamente": "de-cla-ma-to-ria-men-te",
    "declamatorio": "de-cla-ma-to-rio",
    "declarable": "de-cla-ra-ble",
    "declaración": "de-cla-ra-ción",
    "declarada": "de-cla-ra-da",
    "declaradamente": "de-cla-ra-da-men-te",
    "declarado": "de-cla-ra-do",
    "declarador": "de-cla-ra-dor",
    "declaradora": "de-cla-ra-do-ra",
    "declarante": "de-cla-ran-te",
    "declarar": "de-cla-rar",
    "declarativa": "de-cla-ra-ti-va",
    "declarativo": "de-cla-ra-ti-vo",
    "declaratoria": "de-cla-ra-to-ria",
    "declaratorio": "de-cla-ra-to-rio",
    "declinable": "de-cli-na-ble",
    "declinación": "de-cli-na-ción",
    "declinante": "de-cli-nan-te",
    "declinar": "de-cli-nar",
    "declinatoria": "de-cli-na-to-ria",
    "declinatorio": "de-cli-na-to-rio",
    "declinómetro": "de-cli-nó-me-tro",
    "declive": "de-cli-ve",
    "declividad": "de-cli-vi-dad",
    "declivio": "de-cli-vio",
    "decocción": "de-coc-ción",
    "decodificación": "de-co-di-fi-ca-ción",
    "decodificador": "de-co-di-fi-ca-dor",
    "decodificar": "de-co-di-fi-car",
    "decolaje": "de-co-la-je",
    "decolar": "de-co-lar",
    "decolgar": "de-col-gar",
    "decoloración": "de-co-lo-ra-ción",
    "decolorante": "de-co-lo-ran-te",
    "decolorar": "de-co-lo-rar",
    "decomisar": "de-co-mi-sar",
    "decomiso": "de-co-mi-so",
    "deconstrucción": "de-cons-truc-ción",
    "deconstruccionismo": "de-cons-truc-cio-nis-mo",
    "deconstruir": "de-cons-truir",
    "decor": "de-cor",
    "decora": "de-co-ra",
    "decoración": "de-co-ra-ción",
    "decorado": "de-co-ra-do",
    "decorador": "de-co-ra-dor",
    "decoradora": "de-co-ra-do-ra",
    "decorar": "de-co-rar",
    "decorativa": "de-co-ra-ti-va",
    "decorativismo": "de-co-ra-ti-vis-mo",
    "decorativista": "de-co-ra-ti-vis-ta",
    "decorativo": "de-co-ra-ti-vo",
    "decoro": "de-co-ro",
    "decorosa": "de-co-ro-sa",
    "decorosamente": "de-co-ro-sa-men-te",
    "decoroso": "de-co-ro-so",
    "decorrer": "de-co-rrer",
    "decorrerse": "de-co-rrer-se",
    "decorrimiento": "de-co-rri-mien-to",
    "decorticación": "de-cor-ti-ca-ción",
    "decorticar": "de-cor-ti-car",
    "decoupage": "de-cou-pa-ge",
    "decrecer": "de-cre-cer",
    "decreciente": "de-cre-cien-te",
    "decrecimiento": "de-cre-ci-mien-to",
    "decremento": "de-cre-men-to",
    "decrépita": "de-cré-pi-ta",
    "decrepitación": "de-cre-pi-ta-ción",
    "decrepitar": "de-cre-pi-tar",
    "decrépito": "de-cré-pi-to",
    "decrepitud": "de-cre-pi-tud",
    "decrescendo": "de-cres-cen-do",
    "decretación": "de-cre-ta-ción",
    "decretal": "de-cre-tal",
    "decretalista": "de-cre-ta-lis-ta",
    "decretar": "de-cre-tar",
    "decretazo": "de-cre-ta-zo",
    "decretero": "de-cre-te-ro",
    "decretista": "de-cre-tis-ta",
    "decreto": "de-cre-to",
    "decretorio": "de-cre-to-rio",
    "decúbito": "de-cú-bi-to",
    "decumbente": "de-cum-ben-te",
    "décupla": "dé-cu-pla",
    "decuplar": "de-cu-plar",
    "decuplicar": "de-cu-pli-car",
    "décuplo": "dé-cu-plo",
    "decuria": "de-cu-ria",
    "decuriato": "de-cu-ria-to",
    "decurión": "de-cu-rión",
    "decurionato": "de-cu-rio-na-to",
    "decurrente": "de-cu-rren-te",
    "decurso": "de-cur-so",
    "decusa": "de-cu-sa",
    "decusación": "de-cu-sa-ción",
    "decusada": "de-cu-sa-da",
    "decusado": "de-cu-sa-do",
    "decusata": "de-cu-sa-ta",
    "decuso": "de-cu-so",
    "dedada": "de-da-da",
    "dedal": "de-dal",
    "dedalera": "de-da-le-ra",
    "dédalo": "dé-da-lo",
    "dedazo": "de-da-zo",
    "dedeo": "de-de-o",
    "dedeté": "de-de-té",
    "dedicación": "de-di-ca-ción",
    "dedicado": "de-di-ca-do",
    "dedicar": "de-di-car",
    "dedicativa": "de-di-ca-ti-va",
    "dedicativo": "de-di-ca-ti-vo",
    "dedicatoria": "de-di-ca-to-ria",
    "dedicatorio": "de-di-ca-to-rio",
    "dedición": "de-di-ción",
    "dedignar": "de-dig-nar",
    "dedil": "de-dil",
    "dedillo": "de-di-llo",
    "dedo": "de-do",
    "dedocracia": "de-do-cra-cia",
    "dedocrático": "de-do-crá-ti-co",
    "dedolar": "de-do-lar",
    "deducción": "de-duc-ción",
    "deducibilidad": "de-du-ci-bi-li-dad",
    "deducible": "de-du-ci-ble",
    "deducir": "de-du-cir",
    "deductibilidad": "de-duc-ti-bi-li-dad",
    "deductible": "de-duc-ti-ble",
    "deductiva": "de-duc-ti-va",
    "deductivo": "de-duc-ti-vo",
    "deesa": "de-e-sa",
    "defalcar": "de-fal-car",
    "defallecida": "de-fa-lle-ci-da",
    "defallecido": "de-fa-lle-ci-do",
    "defallecimiento": "de-fa-lle-ci-mien-to",
    "defamar": "de-fa-mar",
    "defatigante": "de-fa-ti-gan-te",
    "defecación": "de-fe-ca-ción",
    "defecador": "de-fe-ca-dor",
    "defecadora": "de-fe-ca-do-ra",
    "defecar": "de-fe-car",
    "defección": "de-fec-ción",
    "defeccionar": "de-fec-cio-nar",
    "defectibilidad": "de-fec-ti-bi-li-dad",
    "defectible": "de-fec-ti-ble",
    "defectiva": "de-fec-ti-va",
    "defectivo": "de-fec-ti-vo",
    "defecto": "de-fec-to",
    "defectuosa": "de-fec-tuo-sa",
    "defectuosamente": "de-fec-tuo-sa-men-te",
    "defectuoso": "de-fec-tuo-so",
    "defeña": "de-fe-ña",
    "defendedera": "de-fen-de-de-ra",
    "defendedero": "de-fen-de-de-ro",
    "defendedor": "de-fen-de-dor",
    "defendedora": "de-fen-de-do-ra",
    "defender": "de-fen-der",
    "defendible": "de-fen-di-ble",
    "defendida": "de-fen-di-da",
    "defendido": "de-fen-di-do",
    "defendimiento": "de-fen-di-mien-to",
    "defenestración": "de-fe-nes-tra-ción",
    "defenestrar": "de-fe-nes-trar",
    "defeño": "de-fe-ño",
    "defensa": "de-fen-sa",
    "defensable": "de-fen-sa-ble",
    "defensar": "de-fen-sar",
    "defensión": "de-fen-sión",
    "defensiva": "de-fen-si-va",
    "defensivo": "de-fen-si-vo",
    "defensor": "de-fen-sor",
    "defensora": "de-fen-so-ra",
    "defensoría": "de-fen-so-rí-a",
    "defensorio": "de-fen-so-rio",
    "deferencia": "de-fe-ren-cia",
    "deferente": "de-fe-ren-te",
    "deferentemente": "de-fe-ren-te-men-te",
    "deferir": "de-fe-rir",
    "defesa": "de-fe-sa",
    "defeso": "de-fe-so",
    "defianza": "de-fian-za",
    "defiar": "de-fiar",
    "deficiencia": "de-fi-cien-cia",
    "deficiente": "de-fi-cien-te",
    "deficientemente": "de-fi-cien-te-men-te",
    "déficit": "dé-fi-cit",
    "deficitariamente": "de-fi-ci-ta-ria-men-te",
    "deficitario": "de-fi-ci-ta-rio",
    "definible": "de-fi-ni-ble",
    "definición": "de-fi-ni-ción",
    "definido": "de-fi-ni-do",
    "definidor": "de-fi-ni-dor",
    "definidora": "de-fi-ni-do-ra",
    "definir": "de-fi-nir",
    "definitiva": "de-fi-ni-ti-va",
    "definitivamente": "de-fi-ni-ti-va-men-te",
    "definitivo": "de-fi-ni-ti-vo",
    "definitorio": "de-fi-ni-to-rio",
    "deflación": "de-fla-ción",
    "deflacionario": "de-fla-cio-na-rio",
    "deflacionista": "de-fla-cio-nis-ta",
    "deflactar": "de-flac-tar",
    "deflactor": "de-flac-tor",
    "deflagración": "de-fla-gra-ción",
    "deflagrador": "de-fla-gra-dor",
    "deflagradora": "de-fla-gra-do-ra",
    "deflagrar": "de-fla-grar",
    "deflector": "de-flec-tor",
    "deflectora": "de-flec-to-ra",
    "deflegmar": "de-fleg-mar",
    "deflexión": "de-fle-xión",
    "deflujo": "de-flu-jo",
    "defoliación": "de-fo-lia-ción",
    "defoliante": "de-fo-lian-te",
    "defoliar": "de-fo-liar",
    "defondonar": "de-fon-do-nar",
    "deforestación": "de-fo-res-ta-ción",
    "deforestar": "de-fo-res-tar",
    "deformable": "de-for-ma-ble",
    "deformación": "de-for-ma-ción",
    "deformador": "de-for-ma-dor",
    "deformadora": "de-for-ma-do-ra",
    "deformante": "de-for-man-te",
    "deformar": "de-for-mar",
    "deformatoria": "de-for-ma-to-ria",
    "deformatorio": "de-for-ma-to-rio",
    "deforme": "de-for-me",
    "deformidad": "de-for-mi-dad",
    "defraudación": "de-frau-da-ción",
    "defraudador": "de-frau-da-dor",
    "defraudadora": "de-frau-da-do-ra",
    "defraudar": "de-frau-dar",
    "defuera": "de-fue-ra",
    "defuir": "de-fuir",
    "defunción": "de-fun-ción",
    "defunta": "de-fun-ta",
    "defunto": "de-fun-to",
    "degañero": "de-ga-ñe-ro",
    "degano": "de-ga-no",
    "degeneración": "de-ge-ne-ra-ción",
    "degenerada": "de-ge-ne-ra-da",
    "degenerado": "de-ge-ne-ra-do",
    "degenerante": "de-ge-ne-ran-te",
    "degenerar": "de-ge-ne-rar",
    "degenerativa": "de-ge-ne-ra-ti-va",
    "degenerativo": "de-ge-ne-ra-ti-vo",
    "degenere": "de-ge-ne-re",
    "deglución": "de-glu-ción",
    "deglutir": "de-glu-tir",
    "deglutorio": "de-glu-to-rio",
    "degollación": "de-go-lla-ción",
    "degolladero": "de-go-lla-de-ro",
    "degollado": "de-go-lla-do",
    "degollador": "de-go-lla-dor",
    "degolladora": "de-go-lla-do-ra",
    "degolladura": "de-go-lla-du-ra",
    "degollamiento": "de-go-lla-mien-to",
    "degollante": "de-go-llan-te",
    "degollar": "de-go-llar",
    "degollina": "de-go-lli-na",
    "degradable": "de-gra-da-ble",
    "degradación": "de-gra-da-ción",
    "degradada": "de-gra-da-da",
    "degradado": "de-gra-da-do",
    "degradador": "de-gra-da-dor",
    "degradante": "de-gra-dan-te",
    "degradar": "de-gra-dar",
    "degredo": "de-gre-do",
    "degüella": "de-güe-lla",
    "degüello": "de-güe-llo",
    "degustación": "de-gus-ta-ción",
    "degustador": "de-gus-ta-dor",
    "degustadora": "de-gus-ta-do-ra",
    "degustar": "de-gus-tar",
    "dehender": "de-hen-der",
    "dehendimiento": "de-hen-di-mien-to",
    "dehesa": "de-he-sa",
    "dehesar": "de-he-sar",
    "dehesero": "de-he-se-ro",
    "dehiscencia": "dehis-cen-cia",
    "dehiscente": "dehis-cen-te",
    "dehortar": "de-hor-tar",
    "deicida": "dei-ci-da",
    "deicidio": "dei-ci-dio",
    "deícticamente": "de-íc-ti-ca-men-te",
    "deíctico": "de-íc-ti-co",
    "deidad": "dei-dad",
    "deífica": "de-í-fi-ca",
    "deificación": "dei-fi-ca-ción",
    "deificar": "dei-fi-car",
    "deífico": "de-í-fi-co",
    "deiforme": "dei-for-me",
    "deípara": "de-í-pa-ra",
    "deísmo": "de-ís-mo",
    "deísta": "de-ís-ta",
    "deitana": "dei-ta-na",
    "deitano": "dei-ta-no",
    "deixis": "dei-xis",
    "deja": "de-ja",
    "dejación": "de-ja-ción",
    "dejada": "de-ja-da",
    "dejadera": "de-ja-de-ra",
    "dejadero": "de-ja-de-ro",
    "dejadez": "de-ja-dez",
    "dejado": "de-ja-do",
    "dejador": "de-ja-dor",
    "dejadora": "de-ja-do-ra",
    "dejamiento": "de-ja-mien-to",
    "dejante": "de-jan-te",
    "dejar": "de-jar",
    "dejarretar": "de-ja-rre-tar",
    "dejativa": "de-ja-ti-va",
    "dejativo": "de-ja-ti-vo",
    "dejazón": "de-ja-zón",
    "deje": "de-je",
    "dejemplar": "de-jem-plar",
    "dejillo": "de-ji-llo",
    "dejo": "de-jo",
    "dejugar": "de-ju-gar",
    "dejuramente": "de-ju-ra-men-te",
    "delación": "de-la-ción",
    "delado": "de-la-do",
    "delant": "de-lant",
    "delantal": "de-lan-tal",
    "delante": "de-lan-te",
    "delantealtar": "de-lan-te-al-tar",
    "delantera": "de-lan-te-ra",
    "delantero": "de-lan-te-ro",
    "delasolré": "de-la-sol-ré",
    "delatable": "de-la-ta-ble",
    "delatador": "de-la-ta-dor",
    "delatar": "de-la-tar",
    "delator": "de-la-tor",
    "delatora": "de-la-to-ra",
    "delaxar": "de-la-xar",
    "delco": "del-co",
    "dele": "de-le",
    "deleble": "de-le-ble",
    "delectable": "de-lec-ta-ble",
    "delectación": "de-lec-ta-ción",
    "delecto": "de-lec-to",
    "delegable": "de-le-ga-ble",
    "delegación": "de-le-ga-ción",
    "delegada": "de-le-ga-da",
    "delegado": "de-le-ga-do",
    "delegar": "de-le-gar",
    "delegataria": "de-le-ga-ta-ria",
    "delegatario": "de-le-ga-ta-rio",
    "delegatoria": "de-le-ga-to-ria",
    "delegatorio": "de-le-ga-to-rio",
    "deleitable": "de-lei-ta-ble",
    "deleitación": "de-lei-ta-ción",
    "deleitamiento": "de-lei-ta-mien-to",
    "deleitante": "de-lei-tan-te",
    "deleitar": "de-lei-tar",
    "deleite": "de-lei-te",
    "deleitosa": "de-lei-to-sa",
    "deleitosamente": "de-lei-to-sa-men-te",
    "deleitoso": "de-lei-to-so",
    "delejar": "de-le-jar",
    "deleta": "de-le-ta",
    "deletérea": "de-le-té-re-a",
    "deletéreo": "de-le-té-re-o",
    "deleto": "de-le-to",
    "deletreada": "de-le-tre-a-da",
    "deletreado": "de-le-tre-a-do",
    "deletreador": "de-le-tre-a-dor",
    "deletreadora": "de-le-tre-a-do-ra",
    "deletrear": "de-le-tre-ar",
    "deletreo": "de-le-tre-o",
    "deleznable": "de-lez-na-ble",
    "deleznadiza": "de-lez-na-di-za",
    "deleznadizo": "de-lez-na-di-zo",
    "deleznamiento": "de-lez-na-mien-to",
    "deleznar": "de-lez-nar",
    "deleznarse": "de-lez-nar-se",
    "délfica": "dél-fi-ca",
    "délfico": "dél-fi-co",
    "delfín": "del-fín",
    "delfina": "del-fi-na",
    "delfinario": "del-fi-na-rio",
    "delga": "del-ga",
    "delgada": "del-ga-da",
    "delgadamente": "del-ga-da-men-te",
    "delgadez": "del-ga-dez",
    "delgadeza": "del-ga-de-za",
    "delgado": "del-ga-do",
    "delgaducha": "del-ga-du-cha",
    "delgaducho": "del-ga-du-cho",
    "delgazar": "del-ga-zar",
    "delhí": "del-hí",
    "delia": "de-lia",
    "deliberación": "de-li-be-ra-ción",
    "deliberada": "de-li-be-ra-da",
    "deliberadamente": "de-li-be-ra-da-men-te",
    "deliberado": "de-li-be-ra-do",
    "deliberante": "de-li-be-ran-te",
    "deliberar": "de-li-be-rar",
    "deliberativa": "de-li-be-ra-ti-va",
    "deliberativo": "de-li-be-ra-ti-vo",
    "delibrar": "de-li-brar",
    "delicada": "de-li-ca-da",
    "delicadamente": "de-li-ca-da-men-te",
    "delicadez": "de-li-ca-dez",
    "delicadeza": "de-li-ca-de-za",
    "delicado": "de-li-ca-do",
    "delicaducha": "de-li-ca-du-cha",
    "delicaducho": "de-li-ca-du-cho",
    "delicadura": "de-li-ca-du-ra",
    "delicamiento": "de-li-ca-mien-to",
    "delicatessen": "de-li-ca-tes-sen",
    "delicia": "de-li-cia",
    "deliciar": "de-li-ciar",
    "deliciarse": "de-li-ciar-se",
    "delicio": "de-li-cio",
    "deliciosa": "de-li-cio-sa",
    "deliciosamente": "de-li-cio-sa-men-te",
    "delicioso": "de-li-cio-so",
    "delictiva": "de-lic-ti-va",
    "delictivo": "de-lic-ti-vo",
    "delicto": "de-lic-to",
    "delictual": "de-lic-tual",
    "delictuosa": "de-lic-tuo-sa",
    "delictuoso": "de-lic-tuo-so",
    "delicuescencia": "de-li-cues-cen-cia",
    "delicuescente": "de-li-cues-cen-te",
    "delimitación": "de-li-mi-ta-ción",
    "delimitador": "de-li-mi-ta-dor",
    "delimitar": "de-li-mi-tar",
    "deliñar": "de-li-ñar",
    "delincuencia": "de-lin-cuen-cia",
    "delincuencial": "de-lin-cuen-cial",
    "delincuente": "de-lin-cuen-te",
    "delineación": "de-li-ne-a-ción",
    "delineador": "de-li-ne-a-dor",
    "delineadora": "de-li-ne-a-do-ra",
    "delineamento": "de-li-ne-a-men-to",
    "delineamiento": "de-li-ne-a-mien-to",
    "delineante": "de-li-ne-an-te",
    "delinear": "de-li-ne-ar",
    "delinquimiento": "de-lin-qui-mien-to",
    "delinquir": "de-lin-quir",
    "delio": "de-lio",
    "deliquio": "de-li-quio",
    "delirante": "de-li-ran-te",
    "delirantemente": "de-li-ran-te-men-te",
    "delirar": "de-li-rar",
    "delirio": "de-li-rio",
    "delitescencia": "de-li-tes-cen-cia",
    "delito": "de-li-to",
    "della": "de-lla",
    "dello": "de-llo",
    "delongar": "de-lon-gar",
    "delta": "del-ta",
    "deltaico": "del-tai-co",
    "deltana": "del-ta-na",
    "deltano": "del-ta-no",
    "deltoides": "del-toi-des",
    "deludir": "de-lu-dir",
    "delusión": "de-lu-sión",
    "delusiva": "de-lu-si-va",
    "delusivo": "de-lu-si-vo",
    "delusor": "de-lu-sor",
    "delusora": "de-lu-so-ra",
    "delusoria": "de-lu-so-ria",
    "delusorio": "de-lu-so-rio",
    "demacración": "de-ma-cra-ción",
    "demacrada": "de-ma-cra-da",
    "demacrado": "de-ma-cra-do",
    "demacrar": "de-ma-crar",
    "demagoga": "de-ma-go-ga",
    "demagogia": "de-ma-go-gia",
    "demagógica": "de-ma-gó-gi-ca",
    "demagógicamente": "de-ma-gó-gi-ca-men-te",
    "demagógico": "de-ma-gó-gi-co",
    "demagogo": "de-ma-go-go",
    "demanda": "de-man-da",
    "demandable": "de-man-da-ble",
    "demandada": "de-man-da-da",
    "demandadera": "de-man-da-de-ra",
    "demandadero": "de-man-da-de-ro",
    "demandado": "de-man-da-do",
    "demandador": "de-man-da-dor",
    "demandadora": "de-man-da-do-ra",
    "demandante": "de-man-dan-te",
    "demandanza": "de-man-dan-za",
    "demandar": "de-man-dar",
    "demanial": "de-ma-nial",
    "demanio": "de-ma-nio",
    "demarcación": "de-mar-ca-ción",
    "demarcador": "de-mar-ca-dor",
    "demarcadora": "de-mar-ca-do-ra",
    "demarcar": "de-mar-car",
    "demarraje": "de-ma-rra-je",
    "demarrar": "de-ma-rrar",
    "demarrarse": "de-ma-rrar-se",
    "demás": "de-más",
    "demasía": "de-ma-sí-a",
    "demasiada": "de-ma-sia-da",
    "demasiadamente": "de-ma-sia-da-men-te",
    "demasiado": "de-ma-sia-do",
    "demasiar": "de-ma-siar",
    "demasiarse": "de-ma-siar-se",
    "demediar": "de-me-diar",
    "demencia": "de-men-cia",
    "demenciada": "de-men-cia-da",
    "demenciado": "de-men-cia-do",
    "demencial": "de-men-cial",
    "demencialmente": "de-men-cial-men-te",
    "dementar": "de-men-tar",
    "demente": "de-men-te",
    "demergida": "de-mer-gi-da",
    "demergido": "de-mer-gi-do",
    "demeritar": "de-me-ri-tar",
    "demérito": "de-mé-ri-to",
    "demeritoria": "de-me-ri-to-ria",
    "demeritorio": "de-me-ri-to-rio",
    "demientra": "de-mien-tra",
    "demigar": "de-mi-gar",
    "demisión": "de-mi-sión",
    "demiúrgico": "de-miúr-gi-co",
    "demiurgo": "de-miur-go",
    "demo": "de-mo",
    "democracia": "de-mo-cra-cia",
    "demócrata": "de-mó-cra-ta",
    "democratacristiana": "de-mo-cra-ta-cris-tia-na",
    "democratacristiano": "de-mo-cra-ta-cris-tia-no",
    "democrática": "de-mo-crá-ti-ca",
    "democráticamente": "de-mo-crá-ti-ca-men-te",
    "democrático": "de-mo-crá-ti-co",
    "democratización": "de-mo-cra-ti-za-ción",
    "democratizador": "de-mo-cra-ti-za-dor",
    "democratizar": "de-mo-cra-ti-zar",
    "democristiana": "de-mo-cris-tia-na",
    "democristiano": "de-mo-cris-tia-no",
    "demodé": "de-mo-dé",
    "demodulador": "de-mo-du-la-dor",
    "demógrafa": "de-mó-gra-fa",
    "demografía": "de-mo-gra-fí-a",
    "demográfica": "de-mo-grá-fi-ca",
    "demográfico": "de-mo-grá-fi-co",
    "demógrafo": "de-mó-gra-fo",
    "demoledor": "de-mo-le-dor",
    "demoledora": "de-mo-le-do-ra",
    "demoler": "de-mo-ler",
    "demolición": "de-mo-li-ción",
    "demonche": "de-mon-che",
    "demoníaca": "de-mo-ní-a-ca",
    "demoniaca": "de-mo-nia-ca",
    "demoníaco": "de-mo-ní-a-co",
    "demoniaco": "de-mo-nia-co",
    "demoniada": "de-mo-nia-da",
    "demoniado": "de-mo-nia-do",
    "demonial": "de-mo-nial",
    "demonio": "de-mo-nio",
    "demoniomanía": "de-mo-nio-ma-ní-a",
    "demonismo": "de-mo-nis-mo",
    "demonizar": "de-mo-ni-zar",
    "demonólatra": "de-mo-nó-la-tra",
    "demonolatría": "de-mo-no-la-trí-a",
    "demonóloga": "de-mo-nó-lo-ga",
    "demonología": "de-mo-no-lo-gí-a",
    "demonológico": "de-mo-no-ló-gi-co",
    "demonólogo": "de-mo-nó-lo-go",
    "demonomancía": "de-mo-no-man-cí-a",
    "demonomancia": "de-mo-no-man-cia",
    "demonomanía": "de-mo-no-ma-ní-a",
    "demonstración": "de-mons-tra-ción",
    "demonstrador": "de-mons-tra-dor",
    "demonstradora": "de-mons-tra-do-ra",
    "demonstrar": "de-mons-trar",
    "demontre": "de-mon-tre",
    "demoñuelo": "de-mo-ñue-lo",
    "demora": "de-mo-ra",
    "demorar": "de-mo-rar",
    "demorón": "de-mo-rón",
    "demorosa": "de-mo-ro-sa",
    "demoroso": "de-mo-ro-so",
    "demoscopia": "de-mos-co-pia",
    "demoscópico": "de-mos-có-pi-co",
    "demosofía": "de-mo-so-fí-a",
    "demóstenes": "de-mós-te-nes",
    "demostina": "de-mos-ti-na",
    "demostino": "de-mos-ti-no",
    "demostrable": "de-mos-tra-ble",
    "demostración": "de-mos-tra-ción",
    "demostrador": "de-mos-tra-dor",
    "demostradora": "de-mos-tra-do-ra",
    "demostranza": "de-mos-tran-za",
    "demostrar": "de-mos-trar",
    "demostrativa": "de-mos-tra-ti-va",
    "demostrativamente": "de-mos-tra-ti-va-men-te",
    "demostrativo": "de-mos-tra-ti-vo",
    "demótica": "de-mó-ti-ca",
    "demótico": "de-mó-ti-co",
    "demudación": "de-mu-da-ción",
    "demudamiento": "de-mu-da-mien-to",
    "demudar": "de-mu-dar",
    "demuestra": "de-mues-tra",
    "demulcente": "de-mul-cen-te",
    "demulcir": "de-mul-cir",
    "denante": "de-nan-te",
    "denantes": "de-nan-tes",
    "deñar": "de-ñar",
    "denaria": "de-na-ria",
    "denario": "de-na-rio",
    "dende": "den-de",
    "dendeveras": "den-de-ve-ras",
    "dendriforme": "den-dri-for-me",
    "dendrita": "den-dri-ta",
    "dendrítica": "den-drí-ti-ca",
    "dendrítico": "den-drí-ti-co",
    "dendrocronología": "den-dro-cro-no-lo-gí-a",
    "dendrografía": "den-dro-gra-fí-a",
    "dendrográfica": "den-dro-grá-fi-ca",
    "dendrográfico": "den-dro-grá-fi-co",
    "dendroide": "den-droi-de",
    "dendroidea": "den-droi-de-a",
    "dendroideo": "den-droi-de-o",
    "dendrómetro": "den-dró-me-tro",
    "dendrotráquea": "den-dro-trá-que-a",
    "denegación": "de-ne-ga-ción",
    "denegar": "de-ne-gar",
    "denegatoria": "de-ne-ga-to-ria",
    "denegatorio": "de-ne-ga-to-rio",
    "denegrecer": "de-ne-gre-cer",
    "denegrida": "de-ne-gri-da",
    "denegrido": "de-ne-gri-do",
    "denegrir": "de-ne-grir",
    "dengosa": "den-go-sa",
    "dengoso": "den-go-so",
    "dengue": "den-gue",
    "denguear": "den-gue-ar",
    "denguera": "den-gue-ra",
    "denguero": "den-gue-ro",
    "denigración": "de-ni-gra-ción",
    "denigrador": "de-ni-gra-dor",
    "denigrante": "de-ni-gran-te",
    "denigrar": "de-ni-grar",
    "denigrativa": "de-ni-gra-ti-va",
    "denigrativo": "de-ni-gra-ti-vo",
    "denigratorio": "de-ni-gra-to-rio",
    "denodada": "de-no-da-da",
    "denodadamente": "de-no-da-da-men-te",
    "denodado": "de-no-da-do",
    "denodar": "de-no-dar",
    "denodarse": "de-no-dar-se",
    "denominación": "de-no-mi-na-ción",
    "denominadamente": "de-no-mi-na-da-men-te",
    "denominador": "de-no-mi-na-dor",
    "denominadora": "de-no-mi-na-do-ra",
    "denominal": "de-no-mi-nal",
    "denominar": "de-no-mi-nar",
    "denominativo": "de-no-mi-na-ti-vo",
    "denostable": "de-nos-ta-ble",
    "denostación": "de-nos-ta-ción",
    "denostada": "de-nos-ta-da",
    "denostadamente": "de-nos-ta-da-men-te",
    "denostador": "de-nos-ta-dor",
    "denostadora": "de-nos-ta-do-ra",
    "denostar": "de-nos-tar",
    "denostosa": "de-nos-to-sa",
    "denostosamente": "de-nos-to-sa-men-te",
    "denostoso": "de-nos-to-so",
    "denotación": "de-no-ta-ción",
    "denotar": "de-no-tar",
    "denotativa": "de-no-ta-ti-va",
    "denotativo": "de-no-ta-ti-vo",
    "densa": "den-sa",
    "densamente": "den-sa-men-te",
    "densar": "den-sar",
    "densidad": "den-si-dad",
    "densificación": "den-si-fi-ca-ción",
    "densificar": "den-si-fi-car",
    "densimetría": "den-si-me-trí-a",
    "densímetro": "den-sí-me-tro",
    "densitometría": "den-si-to-me-trí-a",
    "densitómetro": "den-si-tó-me-tro",
    "denso": "den-so",
    "dentada": "den-ta-da",
    "dentado": "den-ta-do",
    "dentadura": "den-ta-du-ra",
    "dental": "den-tal",
    "dentar": "den-tar",
    "dentaria": "den-ta-ria",
    "dentario": "den-ta-rio",
    "dentecer": "den-te-cer",
    "dentejón": "den-te-jón",
    "dentellada": "den-te-lla-da",
    "dentellado": "den-te-lla-do",
    "dentellar": "den-te-llar",
    "dentellear": "den-te-lle-ar",
    "dentellón": "den-te-llón",
    "dentera": "den-te-ra",
    "dentezuelo": "den-te-zue-lo",
    "denticina": "den-ti-ci-na",
    "dentición": "den-ti-ción",
    "denticonejuna": "den-ti-co-ne-ju-na",
    "denticonejuno": "den-ti-co-ne-ju-no",
    "denticulación": "den-ti-cu-la-ción",
    "denticulada": "den-ti-cu-la-da",
    "denticulado": "den-ti-cu-la-do",
    "denticular": "den-ti-cu-lar",
    "dentículo": "den-tí-cu-lo",
    "dentífrica": "den-tí-fri-ca",
    "dentífrico": "den-tí-fri-co",
    "dentina": "den-ti-na",
    "dentirrostro": "den-ti-rros-tro",
    "dentista": "den-tis-ta",
    "dentistería": "den-tis-te-rí-a",
    "dentivana": "den-ti-va-na",
    "dentivano": "den-ti-va-no",
    "dentoalveolar": "den-to-al-ve-o-lar",
    "dentón": "den-tón",
    "dentona": "den-to-na",
    "dentorno": "den-tor-no",
    "dentrambas": "den-tram-bas",
    "dentrambos": "den-tram-bos",
    "dentro": "den-tro",
    "dentrodera": "den-tro-de-ra",
    "dentrotraer": "den-tro-tra-er",
    "dentuda": "den-tu-da",
    "dentudo": "den-tu-do",
    "denudación": "de-nu-da-ción",
    "denudar": "de-nu-dar",
    "denuedo": "de-nue-do",
    "denuesto": "de-nues-to",
    "denuncia": "de-nun-cia",
    "denunciable": "de-nun-cia-ble",
    "denunciación": "de-nun-cia-ción",
    "denunciador": "de-nun-cia-dor",
    "denunciadora": "de-nun-cia-do-ra",
    "denunciante": "de-nun-cian-te",
    "denunciar": "de-nun-ciar",
    "denunciatoria": "de-nun-cia-to-ria",
    "denunciatorio": "de-nun-cia-to-rio",
    "denuncio": "de-nun-cio",
    "deodara": "de-o-da-ra",
    "deontología": "de-on-to-lo-gí-a",
    "deontológico": "de-on-to-ló-gi-co",
    "deparador": "de-pa-ra-dor",
    "deparadora": "de-pa-ra-do-ra",
    "deparar": "de-pa-rar",
    "departamental": "de-par-ta-men-tal",
    "departamento": "de-par-ta-men-to",
    "departidamente": "de-par-ti-da-men-te",
    "departidor": "de-par-ti-dor",
    "departidora": "de-par-ti-do-ra",
    "departimiento": "de-par-ti-mien-to",
    "departir": "de-par-tir",
    "depauperación": "de-pau-pe-ra-ción",
    "depauperar": "de-pau-pe-rar",
    "dependencia": "de-pen-den-cia",
    "dependente": "de-pen-den-te",
    "depender": "de-pen-der",
    "dependienta": "de-pen-dien-ta",
    "dependiente": "de-pen-dien-te",
    "depilación": "de-pi-la-ción",
    "depilar": "de-pi-lar",
    "depilatoria": "de-pi-la-to-ria",
    "depilatorio": "de-pi-la-to-rio",
    "depirar": "de-pi-rar",
    "deplorable": "de-plo-ra-ble",
    "deplorablemente": "de-plo-ra-ble-men-te",
    "deplorar": "de-plo-rar",
    "deponente": "de-po-nen-te",
    "deponer": "de-po-ner",
    "depopulación": "de-po-pu-la-ción",
    "depopulador": "de-po-pu-la-dor",
    "depopuladora": "de-po-pu-la-do-ra",
    "deportación": "de-por-ta-ción",
    "deportar": "de-por-tar",
    "deporte": "de-por-te",
    "deportismo": "de-por-tis-mo",
    "deportista": "de-por-tis-ta",
    "deportiva": "de-por-ti-va",
    "deportivamente": "de-por-ti-va-men-te",
    "deportivas": "de-por-ti-vas",
    "deportividad": "de-por-ti-vi-dad",
    "deportivista": "de-por-ti-vis-ta",
    "deportivo": "de-por-ti-vo",
    "deportosa": "de-por-to-sa",
    "deportoso": "de-por-to-so",
    "deposar": "de-po-sar",
    "deposición": "de-po-si-ción",
    "depositada": "de-po-si-ta-da",
    "depositador": "de-po-si-ta-dor",
    "depositadora": "de-po-si-ta-do-ra",
    "depositante": "de-po-si-tan-te",
    "depositar": "de-po-si-tar",
    "depositaría": "de-po-si-ta-rí-a",
    "depositaria": "de-po-si-ta-ria",
    "depositario": "de-po-si-ta-rio",
    "depósito": "de-pó-si-to",
    "depravación": "de-pra-va-ción",
    "depravada": "de-pra-va-da",
    "depravadamente": "de-pra-va-da-men-te",
    "depravado": "de-pra-va-do",
    "depravador": "de-pra-va-dor",
    "depravadora": "de-pra-va-do-ra",
    "depravar": "de-pra-var",
    "depre": "de-pre",
    "deprecación": "de-pre-ca-ción",
    "deprecante": "de-pre-can-te",
    "deprecar": "de-pre-car",
    "deprecativa": "de-pre-ca-ti-va",
    "deprecativo": "de-pre-ca-ti-vo",
    "deprecatoria": "de-pre-ca-to-ria",
    "deprecatorio": "de-pre-ca-to-rio",
    "depreces": "de-pre-ces",
    "depreciación": "de-pre-cia-ción",
    "depreciar": "de-pre-ciar",
    "depredación": "de-pre-da-ción",
    "depredador": "de-pre-da-dor",
    "depredadora": "de-pre-da-do-ra",
    "depredar": "de-pre-dar",
    "deprehender": "de-pre-hen-der",
    "deprendador": "de-pren-da-dor",
    "deprendadora": "de-pren-da-do-ra",
    "deprender": "de-pren-der",
    "depresión": "de-pre-sión",
    "depresiva": "de-pre-si-va",
    "depresivo": "de-pre-si-vo",
    "depresor": "de-pre-sor",
    "depresora": "de-pre-so-ra",
    "deprimente": "de-pri-men-te",
    "deprimido": "de-pri-mi-do",
    "deprimir": "de-pri-mir",
    "deprisa": "de-pri-sa",
    "depuesta": "de-pues-ta",
    "depuesto": "de-pues-to",
    "depuración": "de-pu-ra-ción",
    "depurada": "de-pu-ra-da",
    "depuradamente": "de-pu-ra-da-men-te",
    "depurado": "de-pu-ra-do",
    "depurador": "de-pu-ra-dor",
    "depuradora": "de-pu-ra-do-ra",
    "depurar": "de-pu-rar",
    "depurativa": "de-pu-ra-ti-va",
    "depurativo": "de-pu-ra-ti-vo",
    "depuratoria": "de-pu-ra-to-ria",
    "depuratorio": "de-pu-ra-to-rio",
    "deputar": "de-pu-tar",
    "deque": "de-que",
    "dequeísmo": "de-que-ís-mo",
    "dequeísta": "de-que-ís-ta",
    "derbi": "der-bi",
    "derecera": "de-re-ce-ra",
    "derecha": "de-re-cha",
    "derechamente": "de-re-cha-men-te",
    "derechazo": "de-re-cha-zo",
    "derechera": "de-re-che-ra",
    "derechero": "de-re-che-ro",
    "derechez": "de-re-chez",
    "derecheza": "de-re-che-za",
    "derechismo": "de-re-chis-mo",
    "derechista": "de-re-chis-ta",
    "derechito": "de-re-chi-to",
    "derechización": "de-re-chi-za-ción",
    "derechizar": "de-re-chi-zar",
    "derecho": "de-re-cho",
    "derechohabiente": "de-re-cho-ha-bien-te",
    "derechuelo": "de-re-chue-lo",
    "derechura": "de-re-chu-ra",
    "derechurera": "de-re-chu-re-ra",
    "derechureramente": "de-re-chu-re-ra-men-te",
    "derechurero": "de-re-chu-re-ro",
    "derelicción": "de-re-lic-ción",
    "derelicto": "de-re-lic-to",
    "derelinquir": "de-re-lin-quir",
    "derezar": "de-re-zar",
    "deriva": "de-ri-va",
    "derivación": "de-ri-va-ción",
    "derivada": "de-ri-va-da",
    "derivado": "de-ri-va-do",
    "derivar": "de-ri-var",
    "derivativa": "de-ri-va-ti-va",
    "derivativo": "de-ri-va-ti-vo",
    "derivo": "de-ri-vo",
    "dermalgia": "der-mal-gia",
    "dermáptero": "der-máp-te-ro",
    "dermatitis": "der-ma-ti-tis",
    "dermatoesqueleto": "der-ma-to-es-que-le-to",
    "dermatóloga": "der-ma-tó-lo-ga",
    "dermatología": "der-ma-to-lo-gí-a",
    "dermatológica": "der-ma-to-ló-gi-ca",
    "dermatológico": "der-ma-to-ló-gi-co",
    "dermatólogo": "der-ma-tó-lo-go",
    "dermatosis": "der-ma-to-sis",
    "dermesto": "der-mes-to",
    "dérmica": "dér-mi-ca",
    "dérmico": "dér-mi-co",
    "dermis": "der-mis",
    "dermitis": "der-mi-tis",
    "dermofarmacéutico": "der-mo-far-ma-céu-ti-co",
    "dermofarmacia": "der-mo-far-ma-cia",
    "dermohidratante": "der-mohi-dra-tan-te",
    "dermoprotección": "der-mo-pro-tec-ción",
    "dermoprotector": "der-mo-pro-tec-tor",
    "dermóptero": "der-móp-te-ro",
    "derogable": "de-ro-ga-ble",
    "derogación": "de-ro-ga-ción",
    "derogador": "de-ro-ga-dor",
    "derogadora": "de-ro-ga-do-ra",
    "derogar": "de-ro-gar",
    "derogatoria": "de-ro-ga-to-ria",
    "derogatorio": "de-ro-ga-to-rio",
    "derrabadura": "de-rra-ba-du-ra",
    "derrabar": "de-rra-bar",
    "derrabe": "de-rra-be",
    "derraigamiento": "de-rrai-ga-mien-to",
    "derraigar": "de-rrai-gar",
    "derrama": "de-rra-ma",
    "derramada": "de-rra-ma-da",
    "derramadamente": "de-rra-ma-da-men-te",
    "derramadero": "de-rra-ma-de-ro",
    "derramado": "de-rra-ma-do",
    "derramador": "de-rra-ma-dor",
    "derramadora": "de-rra-ma-do-ra",
    "derramamiento": "de-rra-ma-mien-to",
    "derramaplaceres": "de-rra-ma-pla-ce-res",
    "derramar": "de-rra-mar",
    "derramasolaces": "de-rra-ma-so-la-ces",
    "derrame": "de-rra-me",
    "derramo": "de-rra-mo",
    "derrancadamente": "de-rran-ca-da-men-te",
    "derrancar": "de-rran-car",
    "derranchada": "de-rran-cha-da",
    "derranchadamente": "de-rran-cha-da-men-te",
    "derranchado": "de-rran-cha-do",
    "derranchar": "de-rran-char",
    "derrapaje": "de-rra-pa-je",
    "derrapar": "de-rra-par",
    "derrape": "de-rra-pe",
    "derraspado": "de-rras-pa-do",
    "derredor": "de-rre-dor",
    "derrelicto": "de-rre-lic-to",
    "derrelinquir": "de-rre-lin-quir",
    "derrenegar": "de-rre-ne-gar",
    "derrengada": "de-rren-ga-da",
    "derrengadera": "de-rren-ga-de-ra",
    "derrengado": "de-rren-ga-do",
    "derrengadura": "de-rren-ga-du-ra",
    "derrengar": "de-rren-gar",
    "derreniego": "de-rre-nie-go",
    "derrería": "de-rre-rí-a",
    "derretida": "de-rre-ti-da",
    "derretido": "de-rre-ti-do",
    "derretimiento": "de-rre-ti-mien-to",
    "derretir": "de-rre-tir",
    "derriba": "de-rri-ba",
    "derribada": "de-rri-ba-da",
    "derribado": "de-rri-ba-do",
    "derribador": "de-rri-ba-dor",
    "derribamiento": "de-rri-ba-mien-to",
    "derribar": "de-rri-bar",
    "derribo": "de-rri-bo",
    "derrick": "de-rrick",
    "derripiador": "de-rri-pia-dor",
    "derriscar": "de-rris-car",
    "derrisión": "de-rri-sión",
    "derrocadero": "de-rro-ca-de-ro",
    "derrocamiento": "de-rro-ca-mien-to",
    "derrocar": "de-rro-car",
    "derrochador": "de-rro-cha-dor",
    "derrochadora": "de-rro-cha-do-ra",
    "derrochar": "de-rro-char",
    "derroche": "de-rro-che",
    "derrochón": "de-rro-chón",
    "derrochona": "de-rro-cho-na",
    "derromper": "de-rrom-per",
    "derronchar": "de-rron-char",
    "derrostrar": "de-rros-trar",
    "derrostrarse": "de-rros-trar-se",
    "derrota": "de-rro-ta",
    "derrotada": "de-rro-ta-da",
    "derrotado": "de-rro-ta-do",
    "derrotar": "de-rro-tar",
    "derrote": "de-rro-te",
    "derrotero": "de-rro-te-ro",
    "derrotismo": "de-rro-tis-mo",
    "derrotista": "de-rro-tis-ta",
    "derrubiar": "de-rru-biar",
    "derrubio": "de-rru-bio",
    "derruir": "de-rruir",
    "derrumbadero": "de-rrum-ba-de-ro",
    "derrumbamiento": "de-rrum-ba-mien-to",
    "derrumbar": "de-rrum-bar",
    "derrumbe": "de-rrum-be",
    "derrumbo": "de-rrum-bo",
    "derviche": "der-vi-che",
    "desabarrancar": "de-sa-ba-rran-car",
    "desabastecer": "de-sa-bas-te-cer",
    "desabastecimiento": "de-sa-bas-te-ci-mien-to",
    "desabatir": "de-sa-ba-tir",
    "desabejar": "de-sa-be-jar",
    "desabida": "de-sa-bi-da",
    "desabido": "de-sa-bi-do",
    "desabollador": "de-sa-bo-lla-dor",
    "desabollar": "de-sa-bo-llar",
    "desabonar": "de-sa-bo-nar",
    "desabonarse": "de-sa-bo-nar-se",
    "desabono": "de-sa-bo-no",
    "desabor": "de-sa-bor",
    "desaborada": "de-sa-bo-ra-da",
    "desaborado": "de-sa-bo-ra-do",
    "desaborar": "de-sa-bo-rar",
    "desabordar": "de-sa-bor-dar",
    "desabordarse": "de-sa-bor-dar-se",
    "desaborición": "de-sa-bo-ri-ción",
    "desaborida": "de-sa-bo-ri-da",
    "desaborido": "de-sa-bo-ri-do",
    "desabotonar": "de-sa-bo-to-nar",
    "desabrida": "de-sa-bri-da",
    "desabridamente": "de-sa-bri-da-men-te",
    "desabrido": "de-sa-bri-do",
    "desabrigada": "de-sa-bri-ga-da",
    "desabrigado": "de-sa-bri-ga-do",
    "desabrigar": "de-sa-bri-gar",
    "desabrigo": "de-sa-bri-go",
    "desabrimiento": "de-sa-bri-mien-to",
    "desabrir": "de-sa-brir",
    "desabrochar": "de-sa-bro-char",
    "desacalorar": "de-sa-ca-lo-rar",
    "desacalorarse": "de-sa-ca-lo-rar-se",
    "desacantonamiento": "de-sa-can-to-na-mien-to",
    "desacantonar": "de-sa-can-to-nar",
    "desacatadamente": "de-sa-ca-ta-da-men-te",
    "desacatador": "de-sa-ca-ta-dor",
    "desacatadora": "de-sa-ca-ta-do-ra",
    "desacatamiento": "de-sa-ca-ta-mien-to",
    "desacatar": "de-sa-ca-tar",
    "desacato": "de-sa-ca-to",
    "desacedar": "de-sa-ce-dar",
    "desaceitada": "de-sa-cei-ta-da",
    "desaceitado": "de-sa-cei-ta-do",
    "desaceitar": "de-sa-cei-tar",
    "desaceleración": "de-sa-ce-le-ra-ción",
    "desacelerar": "de-sa-ce-le-rar",
    "desacerar": "de-sa-ce-rar",
    "desacerbar": "de-sa-cer-bar",
    "desacertada": "de-sa-cer-ta-da",
    "desacertadamente": "de-sa-cer-ta-da-men-te",
    "desacertado": "de-sa-cer-ta-do",
    "desacertar": "de-sa-cer-tar",
    "desacidificar": "de-sa-ci-di-fi-car",
    "desacierto": "de-sa-cier-to",
    "desaclimatar": "de-sa-cli-ma-tar",
    "desacobardar": "de-sa-co-bar-dar",
    "desacollar": "de-sa-co-llar",
    "desacomedido": "de-sa-co-me-di-do",
    "desacomodada": "de-sa-co-mo-da-da",
    "desacomodadamente": "de-sa-co-mo-da-da-men-te",
    "desacomodado": "de-sa-co-mo-da-do",
    "desacomodamiento": "de-sa-co-mo-da-mien-to",
    "desacomodar": "de-sa-co-mo-dar",
    "desacomodo": "de-sa-co-mo-do",
    "desacompañamiento": "de-sa-com-pa-ña-mien-to",
    "desacompañar": "de-sa-com-pa-ñar",
    "desacompasadamente": "de-sa-com-pa-sa-da-men-te",
    "desacompasado": "de-sa-com-pa-sa-do",
    "desacompasar": "de-sa-com-pa-sar",
    "desaconsejable": "de-sa-con-se-ja-ble",
    "desaconsejada": "de-sa-con-se-ja-da",
    "desaconsejadamente": "de-sa-con-se-ja-da-men-te",
    "desaconsejado": "de-sa-con-se-ja-do",
    "desaconsejar": "de-sa-con-se-jar",
    "desacoplamiento": "de-sa-co-pla-mien-to",
    "desacoplar": "de-sa-co-plar",
    "desacordada": "de-sa-cor-da-da",
    "desacordadamente": "de-sa-cor-da-da-men-te",
    "desacordado": "de-sa-cor-da-do",
    "desacordamiento": "de-sa-cor-da-mien-to",
    "desacordar": "de-sa-cor-dar",
    "desacorde": "de-sa-cor-de",
    "desacorralar": "de-sa-co-rra-lar",
    "desacostumbrada": "de-sa-cos-tum-bra-da",
    "desacostumbradamente": "de-sa-cos-tum-bra-da-men-te",
    "desacostumbrado": "de-sa-cos-tum-bra-do",
    "desacostumbrar": "de-sa-cos-tum-brar",
    "desacotar": "de-sa-co-tar",
    "desacoto": "de-sa-co-to",
    "desacralización": "de-sa-cra-li-za-ción",
    "desacralizar": "de-sa-cra-li-zar",
    "desacreditada": "de-sa-cre-di-ta-da",
    "desacreditado": "de-sa-cre-di-ta-do",
    "desacreditador": "de-sa-cre-di-ta-dor",
    "desacreditadora": "de-sa-cre-di-ta-do-ra",
    "desacreditar": "de-sa-cre-di-tar",
    "desactivación": "de-sac-ti-va-ción",
    "desactivar": "de-sac-ti-var",
    "desactualizado": "de-sac-tua-li-za-do",
    "desacuartelamiento": "de-sa-cuar-te-la-mien-to",
    "desacuartelar": "de-sa-cuar-te-lar",
    "desacuerdo": "de-sa-cuer-do",
    "desaderezar": "de-sa-de-re-zar",
    "desadeudar": "de-sa-deu-dar",
    "desadorar": "de-sa-do-rar",
    "desadormecer": "de-sa-dor-me-cer",
    "desadornar": "de-sa-dor-nar",
    "desadorno": "de-sa-dor-no",
    "desaduanaje": "de-sa-dua-na-je",
    "desaduanar": "de-sa-dua-nar",
    "desadvertida": "de-sad-ver-ti-da",
    "desadvertido": "de-sad-ver-ti-do",
    "desadvertir": "de-sad-ver-tir",
    "desafear": "de-sa-fe-ar",
    "desafección": "de-sa-fec-ción",
    "desafecta": "de-sa-fec-ta",
    "desafectación": "de-sa-fec-ta-ción",
    "desafectado": "de-sa-fec-ta-do",
    "desafectar": "de-sa-fec-tar",
    "desafecto": "de-sa-fec-to",
    "desafeitar": "de-sa-fei-tar",
    "desaferrar": "de-sa-fe-rrar",
    "desafiadero": "de-sa-fia-de-ro",
    "desafiador": "de-sa-fia-dor",
    "desafiadora": "de-sa-fia-do-ra",
    "desafiamiento": "de-sa-fia-mien-to",
    "desafiante": "de-sa-fian-te",
    "desafiar": "de-sa-fiar",
    "desafición": "de-sa-fi-ción",
    "desaficionar": "de-sa-fi-cio-nar",
    "desafijación": "de-sa-fi-ja-ción",
    "desafijar": "de-sa-fi-jar",
    "desafilar": "de-sa-fi-lar",
    "desafinación": "de-sa-fi-na-ción",
    "desafinadamente": "de-sa-fi-na-da-men-te",
    "desafinar": "de-sa-fi-nar",
    "desafío": "de-sa-fí-o",
    "desafiuciar": "de-sa-fiu-ciar",
    "desafiuzar": "de-sa-fiu-zar",
    "desaforada": "de-sa-fo-ra-da",
    "desaforadamente": "de-sa-fo-ra-da-men-te",
    "desaforado": "de-sa-fo-ra-do",
    "desaforar": "de-sa-fo-rar",
    "desafornadura": "de-sa-for-na-du-ra",
    "desafornar": "de-sa-for-nar",
    "desaforrar": "de-sa-fo-rrar",
    "desafortunada": "de-sa-for-tu-na-da",
    "desafortunadamente": "de-sa-for-tu-na-da-men-te",
    "desafortunado": "de-sa-for-tu-na-do",
    "desafuciamiento": "de-sa-fu-cia-mien-to",
    "desafuciar": "de-sa-fu-ciar",
    "desafuero": "de-sa-fue-ro",
    "desagarrar": "de-sa-ga-rrar",
    "desagotar": "de-sa-go-tar",
    "desagraciada": "de-sa-gra-cia-da",
    "desagraciado": "de-sa-gra-cia-do",
    "desagraciar": "de-sa-gra-ciar",
    "desagradable": "de-sa-gra-da-ble",
    "desagradablemente": "de-sa-gra-da-ble-men-te",
    "desagradar": "de-sa-gra-dar",
    "desagradecer": "de-sa-gra-de-cer",
    "desagradecida": "de-sa-gra-de-ci-da",
    "desagradecido": "de-sa-gra-de-ci-do",
    "desagradecimiento": "de-sa-gra-de-ci-mien-to",
    "desagrado": "de-sa-gra-do",
    "desagraviar": "de-sa-gra-viar",
    "desagravio": "de-sa-gra-vio",
    "desagregación": "de-sa-gre-ga-ción",
    "desagregar": "de-sa-gre-gar",
    "desaguadero": "de-sa-gua-de-ro",
    "desaguador": "de-sa-gua-dor",
    "desaguar": "de-sa-guar",
    "desaguazar": "de-sa-gua-zar",
    "desagüe": "de-sa-güe",
    "desaguisada": "de-sa-gui-sa-da",
    "desaguisadamente": "de-sa-gui-sa-da-men-te",
    "desaguisado": "de-sa-gui-sa-do",
    "desaherrojar": "de-sa-he-rro-jar",
    "desahijar": "de-sahi-jar",
    "desahitar": "de-sahi-tar",
    "desahitarse": "de-sahi-tar-se",
    "desahogada": "de-sa-ho-ga-da",
    "desahogadamente": "de-sa-ho-ga-da-men-te",
    "desahogado": "de-sa-ho-ga-do",
    "desahogamiento": "de-sa-ho-ga-mien-to",
    "desahogar": "de-sa-ho-gar",
    "desahogo": "de-sa-ho-go",
    "desahuciadamente": "de-sahu-cia-da-men-te",
    "desahuciar": "de-sahu-ciar",
    "desahucio": "de-sahu-cio",
    "desahumada": "de-sahu-ma-da",
    "desahumado": "de-sahu-ma-do",
    "desahumar": "de-sahu-mar",
    "desainadura": "de-sai-na-du-ra",
    "desainar": "de-sai-nar",
    "desairada": "de-sai-ra-da",
    "desairadamente": "de-sai-ra-da-men-te",
    "desairado": "de-sai-ra-do",
    "desairar": "de-sai-rar",
    "desaire": "de-sai-re",
    "desaislar": "de-sais-lar",
    "desaislarse": "de-sais-lar-se",
    "desajacar": "de-sa-ja-car",
    "desajacarse": "de-sa-ja-car-se",
    "desajuntar": "de-sa-jun-tar",
    "desajustar": "de-sa-jus-tar",
    "desajuste": "de-sa-jus-te",
    "desalabanza": "de-sa-la-ban-za",
    "desalabar": "de-sa-la-bar",
    "desalabear": "de-sa-la-be-ar",
    "desalabeo": "de-sa-la-be-o",
    "desalación": "de-sa-la-ción",
    "desalada": "de-sa-la-da",
    "desaladamente": "de-sa-la-da-men-te",
    "desalado": "de-sa-la-do",
    "desalagar": "de-sa-la-gar",
    "desalar": "de-sa-lar",
    "desalbardar": "de-sal-bar-dar",
    "desalentadamente": "de-sa-len-ta-da-men-te",
    "desalentador": "de-sa-len-ta-dor",
    "desalentadora": "de-sa-len-ta-do-ra",
    "desalentar": "de-sa-len-tar",
    "desalfombrar": "de-sal-fom-brar",
    "desalforjar": "de-sal-for-jar",
    "desalhajar": "de-sal-ha-jar",
    "desaliento": "de-sa-lien-to",
    "desaliñada": "de-sa-li-ña-da",
    "desaliñadamente": "de-sa-li-ña-da-men-te",
    "desaliñado": "de-sa-li-ña-do",
    "desaliñar": "de-sa-li-ñar",
    "desalineación": "de-sa-li-ne-a-ción",
    "desalinear": "de-sa-li-ne-ar",
    "desalinización": "de-sa-li-ni-za-ción",
    "desalinizador": "de-sa-li-ni-za-dor",
    "desalinizadora": "de-sa-li-ni-za-do-ra",
    "desalinizar": "de-sa-li-ni-zar",
    "desaliño": "de-sa-li-ño",
    "desalivar": "de-sa-li-var",
    "desalmada": "de-sal-ma-da",
    "desalmadamente": "de-sal-ma-da-men-te",
    "desalmado": "de-sal-ma-do",
    "desalmamiento": "de-sal-ma-mien-to",
    "desalmar": "de-sal-mar",
    "desalmenada": "de-sal-me-na-da",
    "desalmenado": "de-sal-me-na-do",
    "desalmenar": "de-sal-me-nar",
    "desalmidonar": "de-sal-mi-do-nar",
    "desalojamiento": "de-sa-lo-ja-mien-to",
    "desalojar": "de-sa-lo-jar",
    "desalojo": "de-sa-lo-jo",
    "desalquilar": "de-sal-qui-lar",
    "desalterar": "de-sal-te-rar",
    "desalumbrada": "de-sa-lum-bra-da",
    "desalumbradamente": "de-sa-lum-bra-da-men-te",
    "desalumbrado": "de-sa-lum-bra-do",
    "desalumbramiento": "de-sa-lum-bra-mien-to",
    "desalzar": "de-sal-zar",
    "desamable": "de-sa-ma-ble",
    "desamador": "de-sa-ma-dor",
    "desamadora": "de-sa-ma-do-ra",
    "desamar": "de-sa-mar",
    "desamarrar": "de-sa-ma-rrar",
    "desamartelar": "de-sa-mar-te-lar",
    "desamasada": "de-sa-ma-sa-da",
    "desamasado": "de-sa-ma-sa-do",
    "desambientado": "de-sam-bien-ta-do",
    "desambiguación": "de-sam-bi-gua-ción",
    "desambiguar": "de-sam-bi-guar",
    "desamigar": "de-sa-mi-gar",
    "desamistad": "de-sa-mis-tad",
    "desamistar": "de-sa-mis-tar",
    "desamistarse": "de-sa-mis-tar-se",
    "desamoblar": "de-sa-mo-blar",
    "desamoldar": "de-sa-mol-dar",
    "desamor": "de-sa-mor",
    "desamorada": "de-sa-mo-ra-da",
    "desamoradamente": "de-sa-mo-ra-da-men-te",
    "desamorado": "de-sa-mo-ra-do",
    "desamorar": "de-sa-mo-rar",
    "desamorosa": "de-sa-mo-ro-sa",
    "desamoroso": "de-sa-mo-ro-so",
    "desamorrar": "de-sa-mo-rrar",
    "desamortizable": "de-sa-mor-ti-za-ble",
    "desamortización": "de-sa-mor-ti-za-ción",
    "desamortizador": "de-sa-mor-ti-za-dor",
    "desamortizadora": "de-sa-mor-ti-za-do-ra",
    "desamortizar": "de-sa-mor-ti-zar",
    "desamotinar": "de-sa-mo-ti-nar",
    "desamotinarse": "de-sa-mo-ti-nar-se",
    "desamparada": "de-sam-pa-ra-da",
    "desamparadamente": "de-sam-pa-ra-da-men-te",
    "desamparado": "de-sam-pa-ra-do",
    "desamparador": "de-sam-pa-ra-dor",
    "desamparadora": "de-sam-pa-ra-do-ra",
    "desamparamiento": "de-sam-pa-ra-mien-to",
    "desamparar": "de-sam-pa-rar",
    "desamparo": "de-sam-pa-ro",
    "desamueblar": "de-sa-mue-blar",
    "desamurar": "de-sa-mu-rar",
    "desanclar": "de-san-clar",
    "desancorar": "de-san-co-rar",
    "desandar": "de-san-dar",
    "desandrajada": "de-san-dra-ja-da",
    "desandrajado": "de-san-dra-ja-do",
    "desangelado": "de-san-ge-la-do",
    "desangramiento": "de-san-gra-mien-to",
    "desangrar": "de-san-grar",
    "desangre": "de-san-gre",
    "desanidar": "de-sa-ni-dar",
    "desanimación": "de-sa-ni-ma-ción",
    "desanimadamente": "de-sa-ni-ma-da-men-te",
    "desanimado": "de-sa-ni-ma-do",
    "desanimar": "de-sa-ni-mar",
    "desánimo": "de-sá-ni-mo",
    "desanublar": "de-sa-nu-blar",
    "desanudadura": "de-sa-nu-da-du-ra",
    "desanudar": "de-sa-nu-dar",
    "desañudar": "de-sa-ñu-dar",
    "desaojadera": "de-sa-o-ja-de-ra",
    "desaojar": "de-sa-o-jar",
    "desapacibilidad": "de-sa-pa-ci-bi-li-dad",
    "desapacible": "de-sa-pa-ci-ble",
    "desapaciblemente": "de-sa-pa-ci-ble-men-te",
    "desapadrinar": "de-sa-pa-dri-nar",
    "desapañar": "de-sa-pa-ñar",
    "desaparcar": "de-sa-par-car",
    "desaparear": "de-sa-pa-re-ar",
    "desaparecer": "de-sa-pa-re-cer",
    "desaparecida": "de-sa-pa-re-ci-da",
    "desaparecido": "de-sa-pa-re-ci-do",
    "desaparecimiento": "de-sa-pa-re-ci-mien-to",
    "desaparejar": "de-sa-pa-re-jar",
    "desaparición": "de-sa-pa-ri-ción",
    "desaparroquiar": "de-sa-pa-rro-quiar",
    "desapartar": "de-sa-par-tar",
    "desapasionada": "de-sa-pa-sio-na-da",
    "desapasionadamente": "de-sa-pa-sio-na-da-men-te",
    "desapasionado": "de-sa-pa-sio-na-do",
    "desapasionar": "de-sa-pa-sio-nar",
    "desapegar": "de-sa-pe-gar",
    "desapego": "de-sa-pe-go",
    "desapercebida": "de-sa-per-ce-bi-da",
    "desapercebido": "de-sa-per-ce-bi-do",
    "desapercibida": "de-sa-per-ci-bi-da",
    "desapercibidamente": "de-sa-per-ci-bi-da-men-te",
    "desapercibido": "de-sa-per-ci-bi-do",
    "desapercibimiento": "de-sa-per-ci-bi-mien-to",
    "desapestar": "de-sa-pes-tar",
    "desapiadada": "de-sa-pia-da-da",
    "desapiadado": "de-sa-pia-da-do",
    "desapiolar": "de-sa-pio-lar",
    "desaplacible": "de-sa-pla-ci-ble",
    "desaplicación": "de-sa-pli-ca-ción",
    "desaplicada": "de-sa-pli-ca-da",
    "desaplicadamente": "de-sa-pli-ca-da-men-te",
    "desaplicado": "de-sa-pli-ca-do",
    "desaplicar": "de-sa-pli-car",
    "desaplomar": "de-sa-plo-mar",
    "desapoderada": "de-sa-po-de-ra-da",
    "desapoderadamente": "de-sa-po-de-ra-da-men-te",
    "desapoderado": "de-sa-po-de-ra-do",
    "desapoderamiento": "de-sa-po-de-ra-mien-to",
    "desapoderar": "de-sa-po-de-rar",
    "desapolillar": "de-sa-po-li-llar",
    "desaporcar": "de-sa-por-car",
    "desaposentar": "de-sa-po-sen-tar",
    "desaposesionar": "de-sa-po-se-sio-nar",
    "desapostura": "de-sa-pos-tu-ra",
    "desapoyar": "de-sa-po-yar",
    "desapreciar": "de-sa-pre-ciar",
    "desaprender": "de-sa-pren-der",
    "desaprensar": "de-sa-pren-sar",
    "desaprensión": "de-sa-pren-sión",
    "desaprensiva": "de-sa-pren-si-va",
    "desaprensivamente": "de-sa-pren-si-va-men-te",
    "desaprensivo": "de-sa-pren-si-vo",
    "desapretar": "de-sa-pre-tar",
    "desaprir": "de-sa-prir",
    "desaprisionar": "de-sa-pri-sio-nar",
    "desaprobación": "de-sa-pro-ba-ción",
    "desaprobar": "de-sa-pro-bar",
    "desapropiación": "de-sa-pro-pia-ción",
    "desapropiamiento": "de-sa-pro-pia-mien-to",
    "desapropiar": "de-sa-pro-piar",
    "desapropiarse": "de-sa-pro-piar-se",
    "desapropio": "de-sa-pro-pio",
    "desaprovechada": "de-sa-pro-ve-cha-da",
    "desaprovechado": "de-sa-pro-ve-cha-do",
    "desaprovechamiento": "de-sa-pro-ve-cha-mien-to",
    "desaprovechar": "de-sa-pro-ve-char",
    "desaprovechoso": "de-sa-pro-ve-cho-so",
    "desapta": "de-sap-ta",
    "desapteza": "de-sap-te-za",
    "desapto": "de-sap-to",
    "desapuesta": "de-sa-pues-ta",
    "desapuesto": "de-sa-pues-to",
    "desapuntalar": "de-sa-pun-ta-lar",
    "desapuntar": "de-sa-pun-tar",
    "desaquellar": "de-sa-que-llar",
    "desaquellarse": "de-sa-que-llar-se",
    "desarbolado": "de-sar-bo-la-do",
    "desarbolar": "de-sar-bo-lar",
    "desarbolo": "de-sar-bo-lo",
    "desarenar": "de-sa-re-nar",
    "desareno": "de-sa-re-no",
    "desarmable": "de-sar-ma-ble",
    "desarmada": "de-sar-ma-da",
    "desarmado": "de-sar-ma-do",
    "desarmador": "de-sar-ma-dor",
    "desarmadura": "de-sar-ma-du-ra",
    "desarmaduría": "de-sar-ma-du-rí-a",
    "desarmamiento": "de-sar-ma-mien-to",
    "desarmar": "de-sar-mar",
    "desarme": "de-sar-me",
    "desarmonía": "de-sar-mo-ní-a",
    "desarmonizar": "de-sar-mo-ni-zar",
    "desaromatizar": "de-sa-ro-ma-ti-zar",
    "desarraigada": "de-sa-rrai-ga-da",
    "desarraigado": "de-sa-rrai-ga-do",
    "desarraigamiento": "de-sa-rrai-ga-mien-to",
    "desarraigar": "de-sa-rrai-gar",
    "desarraigo": "de-sa-rrai-go",
    "desarrancar": "de-sa-rran-car",
    "desarrancarse": "de-sa-rran-car-se",
    "desarrapada": "de-sa-rra-pa-da",
    "desarrapado": "de-sa-rra-pa-do",
    "desarrebozadamente": "de-sa-rre-bo-za-da-men-te",
    "desarrebozar": "de-sa-rre-bo-zar",
    "desarrebujar": "de-sa-rre-bu-jar",
    "desarreglada": "de-sa-rre-gla-da",
    "desarreglado": "de-sa-rre-gla-do",
    "desarreglar": "de-sa-rre-glar",
    "desarreglo": "de-sa-rre-glo",
    "desarrendado": "de-sa-rren-da-do",
    "desarrendar": "de-sa-rren-dar",
    "desarrevolver": "de-sa-rre-vol-ver",
    "desarrimar": "de-sa-rri-mar",
    "desarrimo": "de-sa-rri-mo",
    "desarrollable": "de-sa-rro-lla-ble",
    "desarrollado": "de-sa-rro-lla-do",
    "desarrolladora": "de-sa-rro-lla-do-ra",
    "desarrollar": "de-sa-rro-llar",
    "desarrollismo": "de-sa-rro-llis-mo",
    "desarrollista": "de-sa-rro-llis-ta",
    "desarrollo": "de-sa-rro-llo",
    "desarropado": "de-sa-rro-pa-do",
    "desarropar": "de-sa-rro-par",
    "desarrugadura": "de-sa-rru-ga-du-ra",
    "desarrugar": "de-sa-rru-gar",
    "desarrumar": "de-sa-rru-mar",
    "desarticulación": "de-sar-ti-cu-la-ción",
    "desarticulado": "de-sar-ti-cu-la-do",
    "desarticular": "de-sar-ti-cu-lar",
    "desartillar": "de-sar-ti-llar",
    "desarzonar": "de-sar-zo-nar",
    "desasada": "de-sa-sa-da",
    "desasado": "de-sa-sa-do",
    "desaseada": "de-sa-se-a-da",
    "desaseadamente": "de-sa-se-a-da-men-te",
    "desaseado": "de-sa-se-a-do",
    "desasear": "de-sa-se-ar",
    "desasegurar": "de-sa-se-gu-rar",
    "desasentar": "de-sa-sen-tar",
    "desaseo": "de-sa-se-o",
    "desasimiento": "de-sa-si-mien-to",
    "desasimilación": "de-sa-si-mi-la-ción",
    "desasir": "de-sa-sir",
    "desasistencia": "de-sa-sis-ten-cia",
    "desasistir": "de-sa-sis-tir",
    "desasnar": "de-sas-nar",
    "desasociable": "de-sa-so-cia-ble",
    "desasociar": "de-sa-so-ciar",
    "desasosegado": "de-sa-so-se-ga-do",
    "desasosegador": "de-sa-so-se-ga-dor",
    "desasosegante": "de-sa-so-se-gan-te",
    "desasosegar": "de-sa-so-se-gar",
    "desasosiego": "de-sa-so-sie-go",
    "desastillar": "de-sas-ti-llar",
    "desastrada": "de-sas-tra-da",
    "desastradamente": "de-sas-tra-da-men-te",
    "desastrado": "de-sas-tra-do",
    "desastre": "de-sas-tre",
    "desastrosa": "de-sas-tro-sa",
    "desastrosamente": "de-sas-tro-sa-men-te",
    "desastroso": "de-sas-tro-so",
    "desatacar": "de-sa-ta-car",
    "desatadamente": "de-sa-ta-da-men-te",
    "desatado": "de-sa-ta-do",
    "desatador": "de-sa-ta-dor",
    "desatadora": "de-sa-ta-do-ra",
    "desatadura": "de-sa-ta-du-ra",
    "desatalentada": "de-sa-ta-len-ta-da",
    "desatalentado": "de-sa-ta-len-ta-do",
    "desatamiento": "de-sa-ta-mien-to",
    "desatancar": "de-sa-tan-car",
    "desatapar": "de-sa-ta-par",
    "desatar": "de-sa-tar",
    "desatascador": "de-sa-tas-ca-dor",
    "desatascar": "de-sa-tas-car",
    "desatasco": "de-sa-tas-co",
    "desataviar": "de-sa-ta-viar",
    "desatavío": "de-sa-ta-ví-o",
    "desate": "de-sa-te",
    "desatemplar": "de-sa-tem-plar",
    "desatemplarse": "de-sa-tem-plar-se",
    "desatención": "de-sa-ten-ción",
    "desatender": "de-sa-ten-der",
    "desatendible": "de-sa-ten-di-ble",
    "desatentada": "de-sa-ten-ta-da",
    "desatentadamente": "de-sa-ten-ta-da-men-te",
    "desatentado": "de-sa-ten-ta-do",
    "desatentamente": "de-sa-ten-ta-men-te",
    "desatentar": "de-sa-ten-tar",
    "desatento": "de-sa-ten-to",
    "desaterrar": "de-sa-te-rrar",
    "desatesada": "de-sa-te-sa-da",
    "desatesado": "de-sa-te-sa-do",
    "desatesorar": "de-sa-te-so-rar",
    "desatibar": "de-sa-ti-bar",
    "desatiento": "de-sa-tien-to",
    "desatierre": "de-sa-tie-rre",
    "desatinada": "de-sa-ti-na-da",
    "desatinadamente": "de-sa-ti-na-da-men-te",
    "desatinado": "de-sa-ti-na-do",
    "desatinar": "de-sa-ti-nar",
    "desatino": "de-sa-ti-no",
    "desatollar": "de-sa-to-llar",
    "desatolondrar": "de-sa-to-lon-drar",
    "desatontar": "de-sa-ton-tar",
    "desatontarse": "de-sa-ton-tar-se",
    "desatorar": "de-sa-to-rar",
    "desatornillador": "de-sa-tor-ni-lla-dor",
    "desatornillar": "de-sa-tor-ni-llar",
    "desatracar": "de-sa-tra-car",
    "desatraer": "de-sa-tra-er",
    "desatraillar": "de-sa-trai-llar",
    "desatrampar": "de-sa-tram-par",
    "desatrancar": "de-sa-tran-car",
    "desatranco": "de-sa-tran-co",
    "desatravesar": "de-sa-tra-ve-sar",
    "desatufar": "de-sa-tu-far",
    "desatufarse": "de-sa-tu-far-se",
    "desaturdir": "de-sa-tur-dir",
    "desautoridad": "de-sau-to-ri-dad",
    "desautorización": "de-sau-to-ri-za-ción",
    "desautorizada": "de-sau-to-ri-za-da",
    "desautorizadamente": "de-sau-to-ri-za-da-men-te",
    "desautorizado": "de-sau-to-ri-za-do",
    "desautorizar": "de-sau-to-ri-zar",
    "desavahada": "de-sa-va-ha-da",
    "desavahado": "de-sa-va-ha-do",
    "desavahamiento": "de-sa-va-ha-mien-to",
    "desavahar": "de-sa-va-har",
    "desavecindada": "de-sa-ve-cin-da-da",
    "desavecindado": "de-sa-ve-cin-da-do",
    "desavecindar": "de-sa-ve-cin-dar",
    "desavecindarse": "de-sa-ve-cin-dar-se",
    "desavenencia": "de-sa-ve-nen-cia",
    "desavenida": "de-sa-ve-ni-da",
    "desavenido": "de-sa-ve-ni-do",
    "desavenimiento": "de-sa-ve-ni-mien-to",
    "desavenir": "de-sa-ve-nir",
    "desaventajada": "de-sa-ven-ta-ja-da",
    "desaventajadamente": "de-sa-ven-ta-ja-da-men-te",
    "desaventajado": "de-sa-ven-ta-ja-do",
    "desaventura": "de-sa-ven-tu-ra",
    "desaventurada": "de-sa-ven-tu-ra-da",
    "desaventurado": "de-sa-ven-tu-ra-do",
    "desavezar": "de-sa-ve-zar",
    "desaviar": "de-sa-viar",
    "desavío": "de-sa-ví-o",
    "desavisada": "de-sa-vi-sa-da",
    "desavisado": "de-sa-vi-sa-do",
    "desavisar": "de-sa-vi-sar",
    "desayudar": "de-sa-yu-dar",
    "desayunador": "de-sa-yu-na-dor",
    "desayunar": "de-sa-yu-nar",
    "desayuno": "de-sa-yu-no",
    "desayuntamiento": "de-sa-yun-ta-mien-to",
    "desayuntar": "de-sa-yun-tar",
    "desazogar": "de-sa-zo-gar",
    "desazolvar": "de-sa-zol-var",
    "desazolve": "de-sa-zol-ve",
    "desazón": "de-sa-zón",
    "desazonada": "de-sa-zo-na-da",
    "desazonadamente": "de-sa-zo-na-da-men-te",
    "desazonado": "de-sa-zo-na-do",
    "desazonador": "de-sa-zo-na-dor",
    "desazonadora": "de-sa-zo-na-do-ra",
    "desazonar": "de-sa-zo-nar",
    "desbabadero": "des-ba-ba-de-ro",
    "desbabar": "des-ba-bar",
    "desbagar": "des-ba-gar",
    "desbalagar": "des-ba-la-gar",
    "desballestar": "des-ba-lles-tar",
    "desbañado": "des-ba-ña-do",
    "desbancar": "des-ban-car",
    "desbandada": "des-ban-da-da",
    "desbandar": "des-ban-dar",
    "desbandarse": "des-ban-dar-se",
    "desbande": "des-ban-de",
    "desbarahustar": "des-ba-rahus-tar",
    "desbarahúste": "des-ba-ra-hús-te",
    "desbarajustar": "des-ba-ra-jus-tar",
    "desbarajuste": "des-ba-ra-jus-te",
    "desbaratada": "des-ba-ra-ta-da",
    "desbaratadamente": "des-ba-ra-ta-da-men-te",
    "desbaratado": "des-ba-ra-ta-do",
    "desbaratador": "des-ba-ra-ta-dor",
    "desbaratadora": "des-ba-ra-ta-do-ra",
    "desbaratamiento": "des-ba-ra-ta-mien-to",
    "desbaratar": "des-ba-ra-tar",
    "desbarate": "des-ba-ra-te",
    "desbarato": "des-ba-ra-to",
    "desbarbada": "des-bar-ba-da",
    "desbarbado": "des-bar-ba-do",
    "desbarbar": "des-bar-bar",
    "desbarbillar": "des-bar-bi-llar",
    "desbardar": "des-bar-dar",
    "desbarrada": "des-ba-rra-da",
    "desbarrancadero": "des-ba-rran-ca-de-ro",
    "desbarrancar": "des-ba-rran-car",
    "desbarrar": "des-ba-rrar",
    "desbarre": "des-ba-rre",
    "desbarretar": "des-ba-rre-tar",
    "desbarrigada": "des-ba-rri-ga-da",
    "desbarrigado": "des-ba-rri-ga-do",
    "desbarrigar": "des-ba-rri-gar",
    "desbarro": "des-ba-rro",
    "desbarrumbar": "des-ba-rrum-bar",
    "desbastador": "des-bas-ta-dor",
    "desbastadura": "des-bas-ta-du-ra",
    "desbastar": "des-bas-tar",
    "desbaste": "des-bas-te",
    "desbastecida": "des-bas-te-ci-da",
    "desbastecido": "des-bas-te-ci-do",
    "desbautizar": "des-bau-ti-zar",
    "desbautizarse": "des-bau-ti-zar-se",
    "desbazadero": "des-ba-za-de-ro",
    "desbeber": "des-be-ber",
    "desbecerrar": "des-be-ce-rrar",
    "desbichinar": "des-bi-chi-nar",
    "desbinzar": "des-bin-zar",
    "desblanquecida": "des-blan-que-ci-da",
    "desblanquecido": "des-blan-que-ci-do",
    "desblanquiñada": "des-blan-qui-ña-da",
    "desblanquiñado": "des-blan-qui-ña-do",
    "desbloquear": "des-blo-que-ar",
    "desbloqueo": "des-blo-que-o",
    "desbocada": "des-bo-ca-da",
    "desbocadamente": "des-bo-ca-da-men-te",
    "desbocado": "des-bo-ca-do",
    "desbocamiento": "des-bo-ca-mien-to",
    "desbocar": "des-bo-car",
    "desbolada": "des-bo-la-da",
    "desbolado": "des-bo-la-do",
    "desbolar": "des-bo-lar",
    "desbole": "des-bo-le",
    "desbonetar": "des-bo-ne-tar",
    "desbonetarse": "des-bo-ne-tar-se",
    "desboquillar": "des-bo-qui-llar",
    "desbordamiento": "des-bor-da-mien-to",
    "desbordante": "des-bor-dan-te",
    "desbordar": "des-bor-dar",
    "desborde": "des-bor-de",
    "desbornizar": "des-bor-ni-zar",
    "desboronar": "des-bo-ro-nar",
    "desborradora": "des-bo-rra-do-ra",
    "desborrar": "des-bo-rrar",
    "desborregar": "des-bo-rre-gar",
    "desbotonar": "des-bo-to-nar",
    "desbragada": "des-bra-ga-da",
    "desbragado": "des-bra-ga-do",
    "desbragar": "des-bra-gar",
    "desbraguetado": "des-bra-gue-ta-do",
    "desbravador": "des-bra-va-dor",
    "desbravar": "des-bra-var",
    "desbravecer": "des-bra-ve-cer",
    "desbrazar": "des-bra-zar",
    "desbrazarse": "des-bra-zar-se",
    "desbridamiento": "des-bri-da-mien-to",
    "desbridar": "des-bri-dar",
    "desbriznar": "des-briz-nar",
    "desbroce": "des-bro-ce",
    "desbrozadora": "des-bro-za-do-ra",
    "desbrozamiento": "des-bro-za-mien-to",
    "desbrozar": "des-bro-zar",
    "desbrozo": "des-bro-zo",
    "desbruar": "des-bruar",
    "desbrujar": "des-bru-jar",
    "desbuchar": "des-bu-char",
    "desbulla": "des-bu-lla",
    "desbullador": "des-bu-lla-dor",
    "desbullar": "des-bu-llar",
    "desburrungar": "des-bu-rrun-gar",
    "desca": "des-ca",
    "descabal": "des-ca-bal",
    "descabalado": "des-ca-ba-la-do",
    "descabalamiento": "des-ca-ba-la-mien-to",
    "descabalar": "des-ca-ba-lar",
    "descabalgadura": "des-ca-bal-ga-du-ra",
    "descabalgar": "des-ca-bal-gar",
    "descabellada": "des-ca-be-lla-da",
    "descabelladamente": "des-ca-be-lla-da-men-te",
    "descabellado": "des-ca-be-lla-do",
    "descabelladura": "des-ca-be-lla-du-ra",
    "descabellamiento": "des-ca-be-lla-mien-to",
    "descabellar": "des-ca-be-llar",
    "descabello": "des-ca-be-llo",
    "descabeñar": "des-ca-be-ñar",
    "descabeñarse": "des-ca-be-ñar-se",
    "descabestrar": "des-ca-bes-trar",
    "descabezada": "des-ca-be-za-da",
    "descabezadamente": "des-ca-be-za-da-men-te",
    "descabezado": "des-ca-be-za-do",
    "descabezamiento": "des-ca-be-za-mien-to",
    "descabezar": "des-ca-be-zar",
    "descabildadamente": "des-ca-bil-da-da-men-te",
    "descabritar": "des-ca-bri-tar",
    "descabullir": "des-ca-bu-llir",
    "descabullirse": "des-ca-bu-llir-se",
    "descachalandrado": "des-ca-cha-lan-dra-do",
    "descachalandrar": "des-ca-cha-lan-drar",
    "descachar": "des-ca-char",
    "descacharrado": "des-ca-cha-rra-do",
    "descacharrante": "des-ca-cha-rran-te",
    "descacharrar": "des-ca-cha-rrar",
    "descachazar": "des-ca-cha-zar",
    "descachimbado": "des-ca-chim-ba-do",
    "descachimbar": "des-ca-chim-bar",
    "descacilar": "des-ca-ci-lar",
    "descaderar": "des-ca-de-rar",
    "descadillador": "des-ca-di-lla-dor",
    "descadilladora": "des-ca-di-lla-do-ra",
    "descadillar": "des-ca-di-llar",
    "descaecer": "des-ca-e-cer",
    "descaecimiento": "des-ca-e-ci-mien-to",
    "descaer": "des-ca-er",
    "descafeinado": "des-ca-fei-na-do",
    "descafeinar": "des-ca-fei-nar",
    "descafilar": "des-ca-fi-lar",
    "descaimiento": "des-cai-mien-to",
    "descalabazar": "des-ca-la-ba-zar",
    "descalabazarse": "des-ca-la-ba-zar-se",
    "descalabrada": "des-ca-la-bra-da",
    "descalabrado": "des-ca-la-bra-do",
    "descalabradura": "des-ca-la-bra-du-ra",
    "descalabrar": "des-ca-la-brar",
    "descalabro": "des-ca-la-bro",
    "descalandrajar": "des-ca-lan-dra-jar",
    "descalcador": "des-cal-ca-dor",
    "descalcar": "des-cal-car",
    "descalcez": "des-cal-cez",
    "descalcificación": "des-cal-ci-fi-ca-ción",
    "descalcificar": "des-cal-ci-fi-car",
    "descalichar": "des-ca-li-char",
    "descalicharse": "des-ca-li-char-se",
    "descalificación": "des-ca-li-fi-ca-ción",
    "descalificador": "des-ca-li-fi-ca-dor",
    "descalificar": "des-ca-li-fi-car",
    "descalificatorio": "des-ca-li-fi-ca-to-rio",
    "descallador": "des-ca-lla-dor",
    "descalostrada": "des-ca-los-tra-da",
    "descalostrado": "des-ca-los-tra-do",
    "descalza": "des-cal-za",
    "descalzadero": "des-cal-za-de-ro",
    "descalzaperros": "des-cal-za-pe-rros",
    "descalzar": "des-cal-zar",
    "descalzo": "des-cal-zo",
    "descamación": "des-ca-ma-ción",
    "descamar": "des-ca-mar",
    "descamativo": "des-ca-ma-ti-vo",
    "descambiar": "des-cam-biar",
    "descaminada": "des-ca-mi-na-da",
    "descaminadamente": "des-ca-mi-na-da-men-te",
    "descaminado": "des-ca-mi-na-do",
    "descaminar": "des-ca-mi-nar",
    "descamino": "des-ca-mi-no",
    "descamisada": "des-ca-mi-sa-da",
    "descamisado": "des-ca-mi-sa-do",
    "descamisar": "des-ca-mi-sar",
    "descampada": "des-cam-pa-da",
    "descampado": "des-cam-pa-do",
    "descampar": "des-cam-par",
    "descañar": "des-ca-ñar",
    "descangallar": "des-can-ga-llar",
    "descañonar": "des-ca-ño-nar",
    "descansada": "des-can-sa-da",
    "descansadamente": "des-can-sa-da-men-te",
    "descansadero": "des-can-sa-de-ro",
    "descansado": "des-can-sa-do",
    "descansapiés": "des-can-sa-piés",
    "descansar": "des-can-sar",
    "descansillo": "des-can-si-llo",
    "descanso": "des-can-so",
    "descantar": "des-can-tar",
    "descantear": "des-can-te-ar",
    "descanterar": "des-can-te-rar",
    "descantillar": "des-can-ti-llar",
    "descantillón": "des-can-ti-llón",
    "descantonar": "des-can-to-nar",
    "descaperuzar": "des-ca-pe-ru-zar",
    "descaperuzo": "des-ca-pe-ru-zo",
    "descapillar": "des-ca-pi-llar",
    "descapirotar": "des-ca-pi-ro-tar",
    "descapitalización": "des-ca-pi-ta-li-za-ción",
    "descapitalizar": "des-ca-pi-ta-li-zar",
    "descapotable": "des-ca-po-ta-ble",
    "descapotar": "des-ca-po-tar",
    "descapullar": "des-ca-pu-llar",
    "descarada": "des-ca-ra-da",
    "descaradamente": "des-ca-ra-da-men-te",
    "descarado": "des-ca-ra-do",
    "descaramiento": "des-ca-ra-mien-to",
    "descarapelado": "des-ca-ra-pe-la-do",
    "descarapelar": "des-ca-ra-pe-lar",
    "descarar": "des-ca-rar",
    "descararse": "des-ca-rar-se",
    "descarbonatar": "des-car-bo-na-tar",
    "descarburación": "des-car-bu-ra-ción",
    "descarburar": "des-car-bu-rar",
    "descarcañalar": "des-car-ca-ña-lar",
    "descarga": "des-car-ga",
    "descargada": "des-car-ga-da",
    "descargadas": "des-car-ga-das",
    "descargadero": "des-car-ga-de-ro",
    "descargador": "des-car-ga-dor",
    "descargadora": "des-car-ga-do-ra",
    "descargadura": "des-car-ga-du-ra",
    "descargamiento": "des-car-ga-mien-to",
    "descargar": "des-car-gar",
    "descargo": "des-car-go",
    "descargue": "des-car-gue",
    "descariñar": "des-ca-ri-ñar",
    "descariñarse": "des-ca-ri-ñar-se",
    "descariño": "des-ca-ri-ño",
    "descarnada": "des-car-na-da",
    "descarnadamente": "des-car-na-da-men-te",
    "descarnado": "des-car-na-do",
    "descarnador": "des-car-na-dor",
    "descarnadura": "des-car-na-du-ra",
    "descarnar": "des-car-nar",
    "descarne": "des-car-ne",
    "descaro": "des-ca-ro",
    "descarozar": "des-ca-ro-zar",
    "descarretillar": "des-ca-rre-ti-llar",
    "descarriamiento": "des-ca-rria-mien-to",
    "descarriar": "des-ca-rriar",
    "descarriladura": "des-ca-rri-la-du-ra",
    "descarrilamiento": "des-ca-rri-la-mien-to",
    "descarrilar": "des-ca-rri-lar",
    "descarrilladura": "des-ca-rri-lla-du-ra",
    "descarrillar": "des-ca-rri-llar",
    "descarrío": "des-ca-rrí-o",
    "descartable": "des-car-ta-ble",
    "descartar": "des-car-tar",
    "descarte": "des-car-te",
    "descartes": "des-car-tes",
    "descasamiento": "des-ca-sa-mien-to",
    "descasar": "des-ca-sar",
    "descascar": "des-cas-car",
    "descascarar": "des-cas-ca-rar",
    "descascarillado": "des-cas-ca-ri-lla-do",
    "descascarillar": "des-cas-ca-ri-llar",
    "descaspar": "des-cas-par",
    "descasque": "des-cas-que",
    "descastada": "des-cas-ta-da",
    "descastado": "des-cas-ta-do",
    "descastar": "des-cas-tar",
    "descaste": "des-cas-te",
    "descasullar": "des-ca-su-llar",
    "descatalogado": "des-ca-ta-lo-ga-do",
    "descatalogar": "des-ca-ta-lo-gar",
    "descatolización": "des-ca-to-li-za-ción",
    "descatolizar": "des-ca-to-li-zar",
    "descaudalada": "des-cau-da-la-da",
    "descaudalado": "des-cau-da-la-do",
    "descaudilladamente": "des-cau-di-lla-da-men-te",
    "descaudillar": "des-cau-di-llar",
    "descebar": "des-ce-bar",
    "descendencia": "des-cen-den-cia",
    "descendente": "des-cen-den-te",
    "descender": "des-cen-der",
    "descendida": "des-cen-di-da",
    "descendiente": "des-cen-dien-te",
    "descendimiento": "des-cen-di-mien-to",
    "descendir": "des-cen-dir",
    "desceñidura": "des-ce-ñi-du-ra",
    "desceñir": "des-ce-ñir",
    "descensión": "des-cen-sión",
    "descenso": "des-cen-so",
    "descensor": "des-cen-sor",
    "descentrada": "des-cen-tra-da",
    "descentrado": "des-cen-tra-do",
    "descentralización": "des-cen-tra-li-za-ción",
    "descentralizador": "des-cen-tra-li-za-dor",
    "descentralizadora": "des-cen-tra-li-za-do-ra",
    "descentralizar": "des-cen-tra-li-zar",
    "descentramiento": "des-cen-tra-mien-to",
    "descentrar": "des-cen-trar",
    "descepar": "des-ce-par",
    "descerar": "des-ce-rar",
    "descercada": "des-cer-ca-da",
    "descercado": "des-cer-ca-do",
    "descercador": "des-cer-ca-dor",
    "descercar": "des-cer-car",
    "descerco": "des-cer-co",
    "descerebración": "des-ce-re-bra-ción",
    "descerebrada": "des-ce-re-bra-da",
    "descerebrado": "des-ce-re-bra-do",
    "descerebrar": "des-ce-re-brar",
    "descerezadora": "des-ce-re-za-do-ra",
    "descerezar": "des-ce-re-zar",
    "descerrajada": "des-ce-rra-ja-da",
    "descerrajado": "des-ce-rra-ja-do",
    "descerrajadura": "des-ce-rra-ja-du-ra",
    "descerrajar": "des-ce-rra-jar",
    "descerrar": "des-ce-rrar",
    "descerrumar": "des-ce-rru-mar",
    "descerrumarse": "des-ce-rru-mar-se",
    "descervigamiento": "des-cer-vi-ga-mien-to",
    "descervigar": "des-cer-vi-gar",
    "deschabar": "des-cha-bar",
    "deschabe": "des-cha-be",
    "deschambar": "des-cham-bar",
    "deschapar": "des-cha-par",
    "descharchado": "des-char-cha-do",
    "descharchar": "des-char-char",
    "deschavar": "des-cha-var",
    "deschavetada": "des-cha-ve-ta-da",
    "deschavetado": "des-cha-ve-ta-do",
    "deschavetar": "des-cha-ve-tar",
    "deschincacado": "des-chin-ca-ca-do",
    "deschingar": "des-chin-gar",
    "deschorchar": "des-chor-char",
    "deschuponar": "des-chu-po-nar",
    "descifrable": "des-ci-fra-ble",
    "descifrador": "des-ci-fra-dor",
    "descifradora": "des-ci-fra-do-ra",
    "desciframiento": "des-ci-fra-mien-to",
    "descifrar": "des-ci-frar",
    "descifre": "des-ci-fre",
    "descimbramiento": "des-cim-bra-mien-to",
    "descimbrar": "des-cim-brar",
    "descimentar": "des-ci-men-tar",
    "descinchar": "des-cin-char",
    "desclasada": "des-cla-sa-da",
    "desclasado": "des-cla-sa-do",
    "desclasamiento": "des-cla-sa-mien-to",
    "desclasar": "des-cla-sar",
    "desclasificación": "des-cla-si-fi-ca-ción",
    "desclasificar": "des-cla-si-fi-car",
    "desclavador": "des-cla-va-dor",
    "desclavar": "des-cla-var",
    "descoagulante": "des-co-a-gu-lan-te",
    "descoagular": "des-co-a-gu-lar",
    "descobajar": "des-co-ba-jar",
    "descobijar": "des-co-bi-jar",
    "descocada": "des-co-ca-da",
    "descocadamente": "des-co-ca-da-men-te",
    "descocado": "des-co-ca-do",
    "descocar": "des-co-car",
    "descocarse": "des-co-car-se",
    "descocedura": "des-co-ce-du-ra",
    "descocer": "des-co-cer",
    "descocha": "des-co-cha",
    "descocho": "des-co-cho",
    "descoco": "des-co-co",
    "descocotar": "des-co-co-tar",
    "descodar": "des-co-dar",
    "descodificación": "des-co-di-fi-ca-ción",
    "descodificador": "des-co-di-fi-ca-dor",
    "descodificar": "des-co-di-fi-car",
    "descoger": "des-co-ger",
    "descogollar": "des-co-go-llar",
    "descogotada": "des-co-go-ta-da",
    "descogotado": "des-co-go-ta-do",
    "descogotar": "des-co-go-tar",
    "descojonamiento": "des-co-jo-na-mien-to",
    "descojonante": "des-co-jo-nan-te",
    "descojonar": "des-co-jo-nar",
    "descojone": "des-co-jo-ne",
    "descojono": "des-co-jo-no",
    "descolar": "des-co-lar",
    "descolchar": "des-col-char",
    "descolgada": "des-col-ga-da",
    "descolgado": "des-col-ga-do",
    "descolgar": "des-col-gar",
    "descoligada": "des-co-li-ga-da",
    "descoligado": "des-co-li-ga-do",
    "descollada": "des-co-lla-da",
    "descolladamente": "des-co-lla-da-men-te",
    "descollado": "des-co-lla-do",
    "descollamiento": "des-co-lla-mien-to",
    "descollante": "des-co-llan-te",
    "descollar": "des-co-llar",
    "descolmar": "des-col-mar",
    "descolmillar": "des-col-mi-llar",
    "descolocación": "des-co-lo-ca-ción",
    "descolocada": "des-co-lo-ca-da",
    "descolocado": "des-co-lo-ca-do",
    "descolocar": "des-co-lo-car",
    "descolonización": "des-co-lo-ni-za-ción",
    "descolonizador": "des-co-lo-ni-za-dor",
    "descolonizar": "des-co-lo-ni-zar",
    "descoloramiento": "des-co-lo-ra-mien-to",
    "descolorar": "des-co-lo-rar",
    "descolorida": "des-co-lo-ri-da",
    "descolorido": "des-co-lo-ri-do",
    "descolorimiento": "des-co-lo-ri-mien-to",
    "descolorir": "des-co-lo-rir",
    "descombrar": "des-com-brar",
    "descombro": "des-com-bro",
    "descomedida": "des-co-me-di-da",
    "descomedidamente": "des-co-me-di-da-men-te",
    "descomedido": "des-co-me-di-do",
    "descomedimiento": "des-co-me-di-mien-to",
    "descomedir": "des-co-me-dir",
    "descomedirse": "des-co-me-dir-se",
    "descomer": "des-co-mer",
    "descomimiento": "des-co-mi-mien-to",
    "descómoda": "des-có-mo-da",
    "descomodidad": "des-co-mo-di-dad",
    "descómodo": "des-có-mo-do",
    "descompadrar": "des-com-pa-drar",
    "descompaginar": "des-com-pa-gi-nar",
    "descompás": "des-com-pás",
    "descompasada": "des-com-pa-sa-da",
    "descompasadamente": "des-com-pa-sa-da-men-te",
    "descompasado": "des-com-pa-sa-do",
    "descompasar": "des-com-pa-sar",
    "descompasarse": "des-com-pa-sar-se",
    "descompensación": "des-com-pen-sa-ción",
    "descompensar": "des-com-pen-sar",
    "descompletar": "des-com-ple-tar",
    "descomponer": "des-com-po-ner",
    "descomponible": "des-com-po-ni-ble",
    "descomposición": "des-com-po-si-ción",
    "descompostura": "des-com-pos-tu-ra",
    "descompresión": "des-com-pre-sión",
    "descompresor": "des-com-pre-sor",
    "descomprimir": "des-com-pri-mir",
    "descompuesta": "des-com-pues-ta",
    "descompuestamente": "des-com-pues-ta-men-te",
    "descompuesto": "des-com-pues-to",
    "descomulgada": "des-co-mul-ga-da",
    "descomulgado": "des-co-mul-ga-do",
    "descomulgador": "des-co-mul-ga-dor",
    "descomulgar": "des-co-mul-gar",
    "descomunal": "des-co-mu-nal",
    "descomunalmente": "des-co-mu-nal-men-te",
    "descomunión": "des-co-mu-nión",
    "desconcentrado": "des-con-cen-tra-do",
    "desconceptuación": "des-con-cep-tua-ción",
    "desconceptuar": "des-con-cep-tuar",
    "desconcertada": "des-con-cer-ta-da",
    "desconcertadamente": "des-con-cer-ta-da-men-te",
    "desconcertado": "des-con-cer-ta-do",
    "desconcertador": "des-con-cer-ta-dor",
    "desconcertadora": "des-con-cer-ta-do-ra",
    "desconcertadura": "des-con-cer-ta-du-ra",
    "desconcertante": "des-con-cer-tan-te",
    "desconcertantemente": "des-con-cer-tan-te-men-te",
    "desconcertar": "des-con-cer-tar",
    "desconchabar": "des-con-cha-bar",
    "desconchado": "des-con-cha-do",
    "desconchadura": "des-con-cha-du-ra",
    "desconchar": "des-con-char",
    "desconchinflado": "des-con-chin-fla-do",
    "desconchinflar": "des-con-chin-flar",
    "desconchón": "des-con-chón",
    "desconcierto": "des-con-cier-to",
    "desconcordia": "des-con-cor-dia",
    "desconectado": "des-co-nec-ta-do",
    "desconectar": "des-co-nec-tar",
    "descoñetado": "des-co-ñe-ta-do",
    "descoñetar": "des-co-ñe-tar",
    "desconexión": "des-co-ne-xión",
    "desconfiada": "des-con-fia-da",
    "desconfiadamente": "des-con-fia-da-men-te",
    "desconfiado": "des-con-fia-do",
    "desconfianza": "des-con-fian-za",
    "desconfiar": "des-con-fiar",
    "desconformar": "des-con-for-mar",
    "desconforme": "des-con-for-me",
    "desconformidad": "des-con-for-mi-dad",
    "descongelación": "des-con-ge-la-ción",
    "descongelar": "des-con-ge-lar",
    "descongestión": "des-con-ges-tión",
    "descongestionante": "des-con-ges-tio-nan-te",
    "descongestionar": "des-con-ges-tio-nar",
    "descongestivo": "des-con-ges-ti-vo",
    "descongojar": "des-con-go-jar",
    "desconhortar": "des-con-hor-tar",
    "desconhorte": "des-con-hor-te",
    "desconocedor": "des-co-no-ce-dor",
    "desconocedora": "des-co-no-ce-do-ra",
    "desconocer": "des-co-no-cer",
    "desconocida": "des-co-no-ci-da",
    "desconocidamente": "des-co-no-ci-da-men-te",
    "desconocido": "des-co-no-ci-do",
    "desconocimiento": "des-co-no-ci-mien-to",
    "desconsejar": "des-con-se-jar",
    "desconsentir": "des-con-sen-tir",
    "desconsideración": "des-con-si-de-ra-ción",
    "desconsiderada": "des-con-si-de-ra-da",
    "desconsideradamente": "des-con-si-de-ra-da-men-te",
    "desconsiderado": "des-con-si-de-ra-do",
    "desconsiderar": "des-con-si-de-rar",
    "desconsolación": "des-con-so-la-ción",
    "desconsolada": "des-con-so-la-da",
    "desconsoladamente": "des-con-so-la-da-men-te",
    "desconsolado": "des-con-so-la-do",
    "desconsolador": "des-con-so-la-dor",
    "desconsoladora": "des-con-so-la-do-ra",
    "desconsolar": "des-con-so-lar",
    "desconsuelo": "des-con-sue-lo",
    "descontado": "des-con-ta-do",
    "descontagiar": "des-con-ta-giar",
    "descontaminación": "des-con-ta-mi-na-ción",
    "descontaminar": "des-con-ta-mi-nar",
    "descontar": "des-con-tar",
    "descontenta": "des-con-ten-ta",
    "descontentadiza": "des-con-ten-ta-di-za",
    "descontentadizo": "des-con-ten-ta-di-zo",
    "descontentamiento": "des-con-ten-ta-mien-to",
    "descontentar": "des-con-ten-tar",
    "descontento": "des-con-ten-to",
    "descontextualización": "des-con-tex-tua-li-za-ción",
    "descontextualizar": "des-con-tex-tua-li-zar",
    "descontinua": "des-con-ti-nua",
    "descontinuación": "des-con-ti-nua-ción",
    "descontinuar": "des-con-ti-nuar",
    "descontinuo": "des-con-ti-nuo",
    "descontón": "des-con-tón",
    "descontrol": "des-con-trol",
    "descontrolar": "des-con-tro-lar",
    "desconvenible": "des-con-ve-ni-ble",
    "desconveniblemente": "des-con-ve-ni-ble-men-te",
    "desconveniencia": "des-con-ve-nien-cia",
    "desconveniente": "des-con-ve-nien-te",
    "desconvenir": "des-con-ve-nir",
    "desconversable": "des-con-ver-sa-ble",
    "desconversar": "des-con-ver-sar",
    "desconvidar": "des-con-vi-dar",
    "desconvocar": "des-con-vo-car",
    "desconvocatoria": "des-con-vo-ca-to-ria",
    "descoordinación": "des-co-or-di-na-ción",
    "descoordinado": "des-co-or-di-na-do",
    "descoque": "des-co-que",
    "descorazonadamente": "des-co-ra-zo-na-da-men-te",
    "descorazonador": "des-co-ra-zo-na-dor",
    "descorazonamiento": "des-co-ra-zo-na-mien-to",
    "descorazonar": "des-co-ra-zo-nar",
    "descorbatado": "des-cor-ba-ta-do",
    "descorchada": "des-cor-cha-da",
    "descorchado": "des-cor-cha-do",
    "descorchador": "des-cor-cha-dor",
    "descorchar": "des-cor-char",
    "descorche": "des-cor-che",
    "descordar": "des-cor-dar",
    "descorderar": "des-cor-de-rar",
    "descordojo": "des-cor-do-jo",
    "descoritar": "des-co-ri-tar",
    "descornar": "des-cor-nar",
    "descoronar": "des-co-ro-nar",
    "descoronte": "des-co-ron-te",
    "descorrear": "des-co-rre-ar",
    "descorregida": "des-co-rre-gi-da",
    "descorregido": "des-co-rre-gi-do",
    "descorrer": "des-co-rrer",
    "descorrimiento": "des-co-rri-mien-to",
    "descortés": "des-cor-tés",
    "descortesía": "des-cor-te-sí-a",
    "descortezador": "des-cor-te-za-dor",
    "descortezadora": "des-cor-te-za-do-ra",
    "descortezadura": "des-cor-te-za-du-ra",
    "descortezamiento": "des-cor-te-za-mien-to",
    "descortezar": "des-cor-te-zar",
    "descortezo": "des-cor-te-zo",
    "descortinar": "des-cor-ti-nar",
    "descosedura": "des-co-se-du-ra",
    "descoser": "des-co-ser",
    "descosida": "des-co-si-da",
    "descosidamente": "des-co-si-da-men-te",
    "descosido": "des-co-si-do",
    "descostar": "des-cos-tar",
    "descostarse": "des-cos-tar-se",
    "descostillar": "des-cos-ti-llar",
    "descostrar": "des-cos-trar",
    "descostreñimiento": "des-cos-tre-ñi-mien-to",
    "descostumbre": "des-cos-tum-bre",
    "descotar": "des-co-tar",
    "descote": "des-co-te",
    "descoyuntamiento": "des-co-yun-ta-mien-to",
    "descoyuntar": "des-co-yun-tar",
    "descoyunto": "des-co-yun-to",
    "descrecencia": "des-cre-cen-cia",
    "descrecer": "des-cre-cer",
    "descrecimiento": "des-cre-ci-mien-to",
    "descrédito": "des-cré-di-to",
    "descreencia": "des-cre-en-cia",
    "descreer": "des-cre-er",
    "descreída": "des-cre-í-da",
    "descreído": "des-cre-í-do",
    "descreimiento": "des-crei-mien-to",
    "descremado": "des-cre-ma-do",
    "descremadora": "des-cre-ma-do-ra",
    "descremar": "des-cre-mar",
    "descrestada": "des-cres-ta-da",
    "descrestar": "des-cres-tar",
    "descriado": "des-cria-do",
    "descriar": "des-criar",
    "descriarse": "des-criar-se",
    "describible": "des-cri-bi-ble",
    "describir": "des-cri-bir",
    "descrinar": "des-cri-nar",
    "descripción": "des-crip-ción",
    "descripta": "des-crip-ta",
    "descriptible": "des-crip-ti-ble",
    "descriptiva": "des-crip-ti-va",
    "descriptivo": "des-crip-ti-vo",
    "descripto": "des-crip-to",
    "descriptor": "des-crip-tor",
    "descriptoria": "des-crip-to-ria",
    "descriptorio": "des-crip-to-rio",
    "descrismar": "des-cris-mar",
    "descristianar": "des-cris-tia-nar",
    "descristianización": "des-cris-tia-ni-za-ción",
    "descristianizada": "des-cris-tia-ni-za-da",
    "descristianizado": "des-cris-tia-ni-za-do",
    "descristianizar": "des-cris-tia-ni-zar",
    "descrita": "des-cri-ta",
    "descrito": "des-cri-to",
    "descrucificar": "des-cru-ci-fi-car",
    "descruzar": "des-cru-zar",
    "descuacharrangado": "des-cua-cha-rran-ga-do",
    "descuadernar": "des-cua-der-nar",
    "descuadrar": "des-cua-drar",
    "descuadre": "des-cua-dre",
    "descuadrilar": "des-cua-dri-lar",
    "descuadrillada": "des-cua-dri-lla-da",
    "descuadrillado": "des-cua-dri-lla-do",
    "descuadrillar": "des-cua-dri-llar",
    "descuadrillarse": "des-cua-dri-llar-se",
    "descuajar": "des-cua-jar",
    "descuajaringar": "des-cua-ja-rin-gar",
    "descuaje": "des-cua-je",
    "descuajeringado": "des-cua-je-rin-ga-do",
    "descuajeringar": "des-cua-je-rin-gar",
    "descuajo": "des-cua-jo",
    "descuartelar": "des-cuar-te-lar",
    "descuartizador": "des-cuar-ti-za-dor",
    "descuartizadora": "des-cuar-ti-za-do-ra",
    "descuartizamiento": "des-cuar-ti-za-mien-to",
    "descuartizar": "des-cuar-ti-zar",
    "descube": "des-cu-be",
    "descubierta": "des-cu-bier-ta",
    "descubiertamente": "des-cu-bier-ta-men-te",
    "descubierto": "des-cu-bier-to",
    "descubrición": "des-cu-bri-ción",
    "descubridero": "des-cu-bri-de-ro",
    "descubridor": "des-cu-bri-dor",
    "descubridora": "des-cu-bri-do-ra",
    "descubrimiento": "des-cu-bri-mien-to",
    "descubrir": "des-cu-brir",
    "descuelgue": "des-cuel-gue",
    "descuello": "des-cue-llo",
    "descuento": "des-cuen-to",
    "descuerar": "des-cue-rar",
    "descuernacabras": "des-cuer-na-ca-bras",
    "descuerno": "des-cuer-no",
    "descueve": "des-cue-ve",
    "descuidada": "des-cui-da-da",
    "descuidadamente": "des-cui-da-da-men-te",
    "descuidado": "des-cui-da-do",
    "descuidar": "des-cui-dar",
    "descuidera": "des-cui-de-ra",
    "descuidero": "des-cui-de-ro",
    "descuidista": "des-cui-dis-ta",
    "descuido": "des-cui-do",
    "descuitada": "des-cui-ta-da",
    "descuitado": "des-cui-ta-do",
    "descular": "des-cu-lar",
    "descumbrada": "des-cum-bra-da",
    "descumbrado": "des-cum-bra-do",
    "descunchar": "des-cun-char",
    "descura": "des-cu-ra",
    "descurtir": "des-cur-tir",
    "desdar": "des-dar",
    "desde": "des-de",
    "desdecir": "des-de-cir",
    "desdel": "des-del",
    "desdén": "des-dén",
    "desdeñable": "des-de-ña-ble",
    "desdeñador": "des-de-ña-dor",
    "desdeñadora": "des-de-ña-do-ra",
    "desdeñar": "des-de-ñar",
    "desdende": "des-den-de",
    "desdeño": "des-de-ño",
    "desdeñosa": "des-de-ño-sa",
    "desdeñosamente": "des-de-ño-sa-men-te",
    "desdeñoso": "des-de-ño-so",
    "desdentada": "des-den-ta-da",
    "desdentado": "des-den-ta-do",
    "desdentar": "des-den-tar",
    "desdevanar": "des-de-va-nar",
    "desdibujada": "des-di-bu-ja-da",
    "desdibujado": "des-di-bu-ja-do",
    "desdibujar": "des-di-bu-jar",
    "desdibujarse": "des-di-bu-jar-se",
    "desdicha": "des-di-cha",
    "desdichada": "des-di-cha-da",
    "desdichadamente": "des-di-cha-da-men-te",
    "desdichado": "des-di-cha-do",
    "desdicho": "des-di-cho",
    "desdoblamiento": "des-do-bla-mien-to",
    "desdoblar": "des-do-blar",
    "desdoble": "des-do-ble",
    "desdón": "des-dón",
    "desdonada": "des-do-na-da",
    "desdonado": "des-do-na-do",
    "desdonar": "des-do-nar",
    "desdorar": "des-do-rar",
    "desdormida": "des-dor-mi-da",
    "desdormido": "des-dor-mi-do",
    "desdoro": "des-do-ro",
    "desdorosa": "des-do-ro-sa",
    "desdoroso": "des-do-ro-so",
    "desdramatización": "des-dra-ma-ti-za-ción",
    "desdramatizador": "des-dra-ma-ti-za-dor",
    "desdramatizadora": "des-dra-ma-ti-za-do-ra",
    "desdramatizar": "des-dra-ma-ti-zar",
    "dese": "de-se",
    "deseabilidad": "de-se-a-bi-li-dad",
    "deseable": "de-se-a-ble",
    "deseablemente": "de-se-a-ble-men-te",
    "deseador": "de-se-a-dor",
    "deseadora": "de-se-a-do-ra",
    "desear": "de-se-ar",
    "desecación": "de-se-ca-ción",
    "desecador": "de-se-ca-dor",
    "desecadora": "de-se-ca-do-ra",
    "desecamiento": "de-se-ca-mien-to",
    "desecante": "de-se-can-te",
    "desecar": "de-se-car",
    "desecativa": "de-se-ca-ti-va",
    "desecativo": "de-se-ca-ti-vo",
    "desecha": "de-se-cha",
    "desechable": "de-se-cha-ble",
    "desechadamente": "de-se-cha-da-men-te",
    "desechar": "de-se-char",
    "desecho": "de-se-cho",
    "desedificación": "de-se-di-fi-ca-ción",
    "desedificar": "de-se-di-fi-car",
    "deseducador": "de-se-du-ca-dor",
    "deseducar": "de-se-du-car",
    "deseguida": "de-se-gui-da",
    "deselectrización": "de-se-lec-tri-za-ción",
    "deselectrizar": "de-se-lec-tri-zar",
    "deselladura": "de-se-lla-du-ra",
    "desellar": "de-se-llar",
    "desembalaje": "de-sem-ba-la-je",
    "desembalar": "de-sem-ba-lar",
    "desembaldosar": "de-sem-bal-do-sar",
    "desemballestar": "de-sem-ba-lles-tar",
    "desembalsar": "de-sem-bal-sar",
    "desembalse": "de-sem-bal-se",
    "desembanastar": "de-sem-ba-nas-tar",
    "desembarazada": "de-sem-ba-ra-za-da",
    "desembarazadamente": "de-sem-ba-ra-za-da-men-te",
    "desembarazado": "de-sem-ba-ra-za-do",
    "desembarazar": "de-sem-ba-ra-zar",
    "desembarazo": "de-sem-ba-ra-zo",
    "desembarcación": "de-sem-bar-ca-ción",
    "desembarcadero": "de-sem-bar-ca-de-ro",
    "desembarcar": "de-sem-bar-car",
    "desembarco": "de-sem-bar-co",
    "desembargadamente": "de-sem-bar-ga-da-men-te",
    "desembargador": "de-sem-bar-ga-dor",
    "desembargar": "de-sem-bar-gar",
    "desembargo": "de-sem-bar-go",
    "desembarque": "de-sem-bar-que",
    "desembarrancar": "de-sem-ba-rran-car",
    "desembarrar": "de-sem-ba-rrar",
    "desembaular": "de-sem-bau-lar",
    "desembebecer": "de-sem-be-be-cer",
    "desembebecerse": "de-sem-be-be-cer-se",
    "desembelesar": "de-sem-be-le-sar",
    "desembelesarse": "de-sem-be-le-sar-se",
    "desemblantada": "de-sem-blan-ta-da",
    "desemblantado": "de-sem-blan-ta-do",
    "desemblantar": "de-sem-blan-tar",
    "desemblantarse": "de-sem-blan-tar-se",
    "desembocadero": "de-sem-bo-ca-de-ro",
    "desembocadura": "de-sem-bo-ca-du-ra",
    "desembocar": "de-sem-bo-car",
    "desembojadera": "de-sem-bo-ja-de-ra",
    "desembojar": "de-sem-bo-jar",
    "desembolsar": "de-sem-bol-sar",
    "desembolso": "de-sem-bol-so",
    "desemboque": "de-sem-bo-que",
    "desemborrachar": "de-sem-bo-rra-char",
    "desemboscar": "de-sem-bos-car",
    "desemboscarse": "de-sem-bos-car-se",
    "desembotar": "de-sem-bo-tar",
    "desembozadamente": "de-sem-bo-za-da-men-te",
    "desembozado": "de-sem-bo-za-do",
    "desembozar": "de-sem-bo-zar",
    "desembozo": "de-sem-bo-zo",
    "desembragar": "de-sem-bra-gar",
    "desembrague": "de-sem-bra-gue",
    "desembravecer": "de-sem-bra-ve-cer",
    "desembravecimiento": "de-sem-bra-ve-ci-mien-to",
    "desembrazar": "de-sem-bra-zar",
    "desembriagar": "de-sem-bria-gar",
    "desembridar": "de-sem-bri-dar",
    "desembrocar": "de-sem-bro-car",
    "desembrollar": "de-sem-bro-llar",
    "desembrozar": "de-sem-bro-zar",
    "desembrujar": "de-sem-bru-jar",
    "desembuchar": "de-sem-bu-char",
    "desemejable": "de-se-me-ja-ble",
    "desemejada": "de-se-me-ja-da",
    "desemejado": "de-se-me-ja-do",
    "desemejante": "de-se-me-jan-te",
    "desemejanza": "de-se-me-jan-za",
    "desemejar": "de-se-me-jar",
    "desempacar": "de-sem-pa-car",
    "desempacarse": "de-sem-pa-car-se",
    "desempachar": "de-sem-pa-char",
    "desempacho": "de-sem-pa-cho",
    "desempajar": "de-sem-pa-jar",
    "desempalagar": "de-sem-pa-la-gar",
    "desempalmar": "de-sem-pal-mar",
    "desempañador": "de-sem-pa-ña-dor",
    "desempañar": "de-sem-pa-ñar",
    "desempapelar": "de-sem-pa-pe-lar",
    "desempaque": "de-sem-pa-que",
    "desempaquetar": "de-sem-pa-que-tar",
    "desemparejado": "de-sem-pa-re-ja-do",
    "desemparejar": "de-sem-pa-re-jar",
    "desemparentada": "de-sem-pa-ren-ta-da",
    "desemparentado": "de-sem-pa-ren-ta-do",
    "desemparvar": "de-sem-par-var",
    "desempastelar": "de-sem-pas-te-lar",
    "desempatar": "de-sem-pa-tar",
    "desempate": "de-sem-pa-te",
    "desempavonar": "de-sem-pa-vo-nar",
    "desempedrador": "de-sem-pe-dra-dor",
    "desempedrar": "de-sem-pe-drar",
    "desempegar": "de-sem-pe-gar",
    "desempeñar": "de-sem-pe-ñar",
    "desempeño": "de-sem-pe-ño",
    "desempeorar": "de-sem-pe-o-rar",
    "desempeorarse": "de-sem-pe-o-rar-se",
    "desempercudir": "de-sem-per-cu-dir",
    "desemperezar": "de-sem-pe-re-zar",
    "desempernar": "de-sem-per-nar",
    "desempleada": "de-sem-ple-a-da",
    "desempleado": "de-sem-ple-a-do",
    "desempleo": "de-sem-ple-o",
    "desempolvadura": "de-sem-pol-va-du-ra",
    "desempolvar": "de-sem-pol-var",
    "desempolvoradura": "de-sem-pol-vo-ra-du-ra",
    "desempolvorar": "de-sem-pol-vo-rar",
    "desemponzoñar": "de-sem-pon-zo-ñar",
    "desempotrar": "de-sem-po-trar",
    "desempozar": "de-sem-po-zar",
    "desempulgadura": "de-sem-pul-ga-du-ra",
    "desempulgar": "de-sem-pul-gar",
    "desempuñar": "de-sem-pu-ñar",
    "desempurrar": "de-sem-pu-rrar",
    "desenalbardar": "de-se-nal-bar-dar",
    "desenamoramiento": "de-se-na-mo-ra-mien-to",
    "desenamorar": "de-se-na-mo-rar",
    "deseñar": "de-se-ñar",
    "desenastar": "de-se-nas-tar",
    "desencabalgada": "de-sen-ca-bal-ga-da",
    "desencabalgado": "de-sen-ca-bal-ga-do",
    "desencabalgar": "de-sen-ca-bal-gar",
    "desencabestrar": "de-sen-ca-bes-trar",
    "desencadenamiento": "de-sen-ca-de-na-mien-to",
    "desencadenante": "de-sen-ca-de-nan-te",
    "desencadenar": "de-sen-ca-de-nar",
    "desencajadura": "de-sen-ca-ja-du-ra",
    "desencajamiento": "de-sen-ca-ja-mien-to",
    "desencajar": "de-sen-ca-jar",
    "desencaje": "de-sen-ca-je",
    "desencajonamiento": "de-sen-ca-jo-na-mien-to",
    "desencajonar": "de-sen-ca-jo-nar",
    "desencalabrinar": "de-sen-ca-la-bri-nar",
    "desencalcar": "de-sen-cal-car",
    "desencallar": "de-sen-ca-llar",
    "desencamar": "de-sen-ca-mar",
    "desencaminado": "de-sen-ca-mi-na-do",
    "desencaminar": "de-sen-ca-mi-nar",
    "desencantado": "de-sen-can-ta-do",
    "desencantamiento": "de-sen-can-ta-mien-to",
    "desencantar": "de-sen-can-tar",
    "desencanto": "de-sen-can-to",
    "desencapar": "de-sen-ca-par",
    "desencapillar": "de-sen-ca-pi-llar",
    "desencapotadura": "de-sen-ca-po-ta-du-ra",
    "desencapotar": "de-sen-ca-po-tar",
    "desencaprichar": "de-sen-ca-pri-char",
    "desencarcelar": "de-sen-car-ce-lar",
    "desencarecer": "de-sen-ca-re-cer",
    "desencargar": "de-sen-car-gar",
    "desencariñar": "de-sen-ca-ri-ñar",
    "desencarnar": "de-sen-car-nar",
    "desencarpetar": "de-sen-car-pe-tar",
    "desencasadura": "de-sen-ca-sa-du-ra",
    "desencasar": "de-sen-ca-sar",
    "desencasquillar": "de-sen-cas-qui-llar",
    "desencastillar": "de-sen-cas-ti-llar",
    "desencentrar": "de-sen-cen-trar",
    "desencerrar": "de-sen-ce-rrar",
    "desencharcar": "de-sen-char-car",
    "desenchilar": "de-sen-chi-lar",
    "desenchuecar": "de-sen-chue-car",
    "desenchufar": "de-sen-chu-far",
    "desencintar": "de-sen-cin-tar",
    "desenclavar": "de-sen-cla-var",
    "desenclavijar": "de-sen-cla-vi-jar",
    "desencochar": "de-sen-co-char",
    "desencofrado": "de-sen-co-fra-do",
    "desencofrar": "de-sen-co-frar",
    "desencoger": "de-sen-co-ger",
    "desencogimiento": "de-sen-co-gi-mien-to",
    "desencoladura": "de-sen-co-la-du-ra",
    "desencolar": "de-sen-co-lar",
    "desencolerizar": "de-sen-co-le-ri-zar",
    "desenconamiento": "de-sen-co-na-mien-to",
    "desenconar": "de-sen-co-nar",
    "desencono": "de-sen-co-no",
    "desencordar": "de-sen-cor-dar",
    "desencordelar": "de-sen-cor-de-lar",
    "desencorvar": "de-sen-cor-var",
    "desencovar": "de-sen-co-var",
    "desencrespar": "de-sen-cres-par",
    "desencuadernado": "de-sen-cua-der-na-do",
    "desencuadernar": "de-sen-cua-der-nar",
    "desencuentro": "de-sen-cuen-tro",
    "desencuevar": "de-sen-cue-var",
    "desend": "de-send",
    "desendemoniar": "de-sen-de-mo-niar",
    "desendiablar": "de-sen-dia-blar",
    "desendiosar": "de-sen-dio-sar",
    "desenfadada": "de-sen-fa-da-da",
    "desenfadadamente": "de-sen-fa-da-da-men-te",
    "desenfadaderas": "de-sen-fa-da-de-ras",
    "desenfadado": "de-sen-fa-da-do",
    "desenfadar": "de-sen-fa-dar",
    "desenfado": "de-sen-fa-do",
    "desenfaldar": "de-sen-fal-dar",
    "desenfardar": "de-sen-far-dar",
    "desenfardelar": "de-sen-far-de-lar",
    "desenfilada": "de-sen-fi-la-da",
    "desenfilar": "de-sen-fi-lar",
    "desenfocar": "de-sen-fo-car",
    "desenfoque": "de-sen-fo-que",
    "desenfrailar": "de-sen-frai-lar",
    "desenfrenada": "de-sen-fre-na-da",
    "desenfrenadamente": "de-sen-fre-na-da-men-te",
    "desenfrenado": "de-sen-fre-na-do",
    "desenfrenamiento": "de-sen-fre-na-mien-to",
    "desenfrenar": "de-sen-fre-nar",
    "desenfreno": "de-sen-fre-no",
    "desenfundar": "de-sen-fun-dar",
    "desenfurecer": "de-sen-fu-re-cer",
    "desenfurruñar": "de-sen-fu-rru-ñar",
    "desengañada": "de-sen-ga-ña-da",
    "desengañadamente": "de-sen-ga-ña-da-men-te",
    "desengañado": "de-sen-ga-ña-do",
    "desengañador": "de-sen-ga-ña-dor",
    "desengañadora": "de-sen-ga-ña-do-ra",
    "desengañar": "de-sen-ga-ñar",
    "desenganchar": "de-sen-gan-char",
    "desenganche": "de-sen-gan-che",
    "desengañilar": "de-sen-ga-ñi-lar",
    "desengaño": "de-sen-ga-ño",
    "desengarrafar": "de-sen-ga-rra-far",
    "desengarzar": "de-sen-gar-zar",
    "desengastar": "de-sen-gas-tar",
    "desengavetar": "de-sen-ga-ve-tar",
    "desengomante": "de-sen-go-man-te",
    "desengomar": "de-sen-go-mar",
    "desengoznar": "de-sen-goz-nar",
    "desengranar": "de-sen-gra-nar",
    "desengrapar": "de-sen-gra-par",
    "desengrasante": "de-sen-gra-san-te",
    "desengrasar": "de-sen-gra-sar",
    "desengrase": "de-sen-gra-se",
    "desengrilletar": "de-sen-gri-lle-tar",
    "desengrosar": "de-sen-gro-sar",
    "desengrudamiento": "de-sen-gru-da-mien-to",
    "desengrudar": "de-sen-gru-dar",
    "desenguantar": "de-sen-guan-tar",
    "desenguantarse": "de-sen-guan-tar-se",
    "desenguaracar": "de-sen-gua-ra-car",
    "desenhadamiento": "de-sen-ha-da-mien-to",
    "desenhadar": "de-sen-ha-dar",
    "desenhastiar": "de-sen-has-tiar",
    "desenhebrar": "de-sen-he-brar",
    "desenhetrable": "de-sen-he-tra-ble",
    "desenhetramiento": "de-sen-he-tra-mien-to",
    "desenhetrar": "de-sen-he-trar",
    "desenhornar": "de-sen-hor-nar",
    "desenjaezar": "de-sen-ja-e-zar",
    "desenjalmar": "de-sen-jal-mar",
    "desenjaular": "de-sen-jau-lar",
    "desenlabonar": "de-sen-la-bo-nar",
    "desenlace": "de-sen-la-ce",
    "desenladrillado": "de-sen-la-dri-lla-do",
    "desenladrillar": "de-sen-la-dri-llar",
    "desenlazar": "de-sen-la-zar",
    "desenlodar": "de-sen-lo-dar",
    "desenlosar": "de-sen-lo-sar",
    "desenlutar": "de-sen-lu-tar",
    "desenmallar": "de-sen-ma-llar",
    "desenmarañar": "de-sen-ma-ra-ñar",
    "desenmascaradamente": "de-sen-mas-ca-ra-da-men-te",
    "desenmascaramiento": "de-sen-mas-ca-ra-mien-to",
    "desenmascarar": "de-sen-mas-ca-rar",
    "desenmohecer": "de-sen-mo-he-cer",
    "desenmudecer": "de-sen-mu-de-cer",
    "deseño": "de-se-ño",
    "desenojar": "de-se-no-jar",
    "desenojo": "de-se-no-jo",
    "desenojosa": "de-se-no-jo-sa",
    "desenojoso": "de-se-no-jo-so",
    "desenraizar": "de-sen-rai-zar",
    "desenrazonada": "de-sen-ra-zo-na-da",
    "desenrazonado": "de-sen-ra-zo-na-do",
    "desenredar": "de-sen-re-dar",
    "desenredo": "de-sen-re-do",
    "desenrejar": "de-sen-re-jar",
    "desenrizar": "de-sen-ri-zar",
    "desenrollar": "de-sen-ro-llar",
    "desenronar": "de-sen-ro-nar",
    "desenroscar": "de-sen-ros-car",
    "desenrudecer": "de-sen-ru-de-cer",
    "desensamblar": "de-sen-sam-blar",
    "desensañar": "de-sen-sa-ñar",
    "desensartar": "de-sen-sar-tar",
    "desensebar": "de-sen-se-bar",
    "desenseñamiento": "de-sen-se-ña-mien-to",
    "desenseñar": "de-sen-se-ñar",
    "desensibilizar": "de-sen-si-bi-li-zar",
    "desensillar": "de-sen-si-llar",
    "desensoberbecer": "de-sen-so-ber-be-cer",
    "desensortijada": "de-sen-sor-ti-ja-da",
    "desensortijado": "de-sen-sor-ti-ja-do",
    "desentablar": "de-sen-ta-blar",
    "desentablillar": "de-sen-ta-bli-llar",
    "desentalingar": "de-sen-ta-lin-gar",
    "desentarimar": "de-sen-ta-ri-mar",
    "desentechar": "de-sen-te-char",
    "desentejar": "de-sen-te-jar",
    "desentender": "de-sen-ten-der",
    "desentenderse": "de-sen-ten-der-se",
    "desentendida": "de-sen-ten-di-da",
    "desentendido": "de-sen-ten-di-do",
    "desentendimiento": "de-sen-ten-di-mien-to",
    "desenterrador": "de-sen-te-rra-dor",
    "desenterradora": "de-sen-te-rra-do-ra",
    "desenterramiento": "de-sen-te-rra-mien-to",
    "desenterrar": "de-sen-te-rrar",
    "desentida": "de-sen-ti-da",
    "desentido": "de-sen-ti-do",
    "desentierramuertos": "de-sen-tie-rra-muer-tos",
    "desentierro": "de-sen-tie-rro",
    "desentoldar": "de-sen-tol-dar",
    "desentollecer": "de-sen-to-lle-cer",
    "desentonación": "de-sen-to-na-ción",
    "desentonamiento": "de-sen-to-na-mien-to",
    "desentonar": "de-sen-to-nar",
    "desentono": "de-sen-to-no",
    "desentornillar": "de-sen-tor-ni-llar",
    "desentorpecer": "de-sen-tor-pe-cer",
    "desentrampar": "de-sen-tram-par",
    "desentrañamiento": "de-sen-tra-ña-mien-to",
    "desentrañar": "de-sen-tra-ñar",
    "desentrenado": "de-sen-tre-na-do",
    "desentrenamiento": "de-sen-tre-na-mien-to",
    "desentrenar": "de-sen-tre-nar",
    "desentronizar": "de-sen-tro-ni-zar",
    "desentropezar": "de-sen-tro-pe-zar",
    "desentubar": "de-sen-tu-bar",
    "desentumecer": "de-sen-tu-me-cer",
    "desentumecimiento": "de-sen-tu-me-ci-mien-to",
    "desentumir": "de-sen-tu-mir",
    "desenvainar": "de-sen-vai-nar",
    "desenvelejar": "de-sen-ve-le-jar",
    "desenvendar": "de-sen-ven-dar",
    "desenvergar": "de-sen-ver-gar",
    "desenviolar": "de-sen-vio-lar",
    "desenvoltura": "de-sen-vol-tu-ra",
    "desenvolvedor": "de-sen-vol-ve-dor",
    "desenvolvedora": "de-sen-vol-ve-do-ra",
    "desenvolver": "de-sen-vol-ver",
    "desenvolvimiento": "de-sen-vol-vi-mien-to",
    "desenvuelta": "de-sen-vuel-ta",
    "desenvueltamente": "de-sen-vuel-ta-men-te",
    "desenvuelto": "de-sen-vuel-to",
    "desenyugar": "de-sen-yu-gar",
    "desenyuntar": "de-sen-yun-tar",
    "desenzarzar": "de-sen-zar-zar",
    "desenzolvar": "de-sen-zol-var",
    "deseo": "de-se-o",
    "deseosa": "de-se-o-sa",
    "deseoso": "de-se-o-so",
    "desequida": "de-se-qui-da",
    "desequido": "de-se-qui-do",
    "desequilibrada": "de-se-qui-li-bra-da",
    "desequilibrado": "de-se-qui-li-bra-do",
    "desequilibrar": "de-se-qui-li-brar",
    "desequilibrio": "de-se-qui-li-brio",
    "deserción": "de-ser-ción",
    "deserrada": "de-se-rra-da",
    "deserrado": "de-se-rra-do",
    "desertar": "de-ser-tar",
    "desértica": "de-sér-ti-ca",
    "desértico": "de-sér-ti-co",
    "desertícola": "de-ser-tí-co-la",
    "desertificación": "de-ser-ti-fi-ca-ción",
    "desertificar": "de-ser-ti-fi-car",
    "desertización": "de-ser-ti-za-ción",
    "desertizar": "de-ser-ti-zar",
    "desertor": "de-ser-tor",
    "desertora": "de-ser-to-ra",
    "deservicio": "de-ser-vi-cio",
    "deservidor": "de-ser-vi-dor",
    "deservidora": "de-ser-vi-do-ra",
    "deservir": "de-ser-vir",
    "desescamar": "de-ses-ca-mar",
    "desescombrar": "de-ses-com-brar",
    "desescombro": "de-ses-com-bro",
    "deseslabonar": "de-ses-la-bo-nar",
    "desespaldar": "de-ses-pal-dar",
    "desespañolizar": "de-ses-pa-ño-li-zar",
    "desesperación": "de-ses-pe-ra-ción",
    "desesperada": "de-ses-pe-ra-da",
    "desesperadamente": "de-ses-pe-ra-da-men-te",
    "desesperado": "de-ses-pe-ra-do",
    "desesperante": "de-ses-pe-ran-te",
    "desesperantemente": "de-ses-pe-ran-te-men-te",
    "desesperanza": "de-ses-pe-ran-za",
    "desesperanzador": "de-ses-pe-ran-za-dor",
    "desesperanzar": "de-ses-pe-ran-zar",
    "desesperar": "de-ses-pe-rar",
    "desespero": "de-ses-pe-ro",
    "desespumar": "de-ses-pu-mar",
    "desestabilidad": "de-ses-ta-bi-li-dad",
    "desestabilización": "de-ses-ta-bi-li-za-ción",
    "desestabilizador": "de-ses-ta-bi-li-za-dor",
    "desestabilizar": "de-ses-ta-bi-li-zar",
    "desestañar": "de-ses-ta-ñar",
    "desestancar": "de-ses-tan-car",
    "desestanco": "de-ses-tan-co",
    "desesterar": "de-ses-te-rar",
    "desestero": "de-ses-te-ro",
    "desestiba": "de-ses-ti-ba",
    "desestibar": "de-ses-ti-bar",
    "desestima": "de-ses-ti-ma",
    "desestimable": "de-ses-ti-ma-ble",
    "desestimación": "de-ses-ti-ma-ción",
    "desestimador": "de-ses-ti-ma-dor",
    "desestimadora": "de-ses-ti-ma-do-ra",
    "desestimar": "de-ses-ti-mar",
    "desestimatorio": "de-ses-ti-ma-to-rio",
    "desetiquetar": "de-se-ti-que-tar",
    "desfacción": "des-fac-ción",
    "desfacedor": "des-fa-ce-dor",
    "desfacedora": "des-fa-ce-do-ra",
    "desfacer": "des-fa-cer",
    "desfachatada": "des-fa-cha-ta-da",
    "desfachatado": "des-fa-cha-ta-do",
    "desfachatez": "des-fa-cha-tez",
    "desfacimiento": "des-fa-ci-mien-to",
    "desfajar": "des-fa-jar",
    "desfalcador": "des-fal-ca-dor",
    "desfalcadora": "des-fal-ca-do-ra",
    "desfalcar": "des-fal-car",
    "desfalco": "des-fal-co",
    "desfallecer": "des-fa-lle-cer",
    "desfallecido": "des-fa-lle-ci-do",
    "desfalleciente": "des-fa-lle-cien-te",
    "desfallecimiento": "des-fa-lle-ci-mien-to",
    "desfamamiento": "des-fa-ma-mien-to",
    "desfamar": "des-fa-mar",
    "desfasado": "des-fa-sa-do",
    "desfasar": "des-fa-sar",
    "desfase": "des-fa-se",
    "desfavor": "des-fa-vor",
    "desfavorable": "des-fa-vo-ra-ble",
    "desfavorablemente": "des-fa-vo-ra-ble-men-te",
    "desfavorecer": "des-fa-vo-re-cer",
    "desfavorecido": "des-fa-vo-re-ci-do",
    "desfazada": "des-fa-za-da",
    "desfazado": "des-fa-za-do",
    "desfear": "des-fe-ar",
    "desfecha": "des-fe-cha",
    "desfecho": "des-fe-cho",
    "desferra": "des-fe-rra",
    "desferrar": "des-fe-rrar",
    "desfibrado": "des-fi-bra-do",
    "desfibrador": "des-fi-bra-dor",
    "desfibradora": "des-fi-bra-do-ra",
    "desfibrar": "des-fi-brar",
    "desfibrilación": "des-fi-bri-la-ción",
    "desfibrilador": "des-fi-bri-la-dor",
    "desfibrinación": "des-fi-bri-na-ción",
    "desfiguración": "des-fi-gu-ra-ción",
    "desfiguramiento": "des-fi-gu-ra-mien-to",
    "desfigurar": "des-fi-gu-rar",
    "desfiguro": "des-fi-gu-ro",
    "desfijar": "des-fi-jar",
    "desfilachar": "des-fi-la-char",
    "desfiladero": "des-fi-la-de-ro",
    "desfiladiz": "des-fi-la-diz",
    "desfilar": "des-fi-lar",
    "desfile": "des-fi-le",
    "desfiuciada": "des-fiu-cia-da",
    "desfiuciado": "des-fiu-cia-do",
    "desfiuza": "des-fiu-za",
    "desfiuzar": "des-fiu-zar",
    "desflaquecer": "des-fla-que-cer",
    "desflaquecimiento": "des-fla-que-ci-mien-to",
    "desflecar": "des-fle-car",
    "desflemar": "des-fle-mar",
    "desflocar": "des-flo-car",
    "desfloración": "des-flo-ra-ción",
    "desfloramiento": "des-flo-ra-mien-to",
    "desflorar": "des-flo-rar",
    "desflorecer": "des-flo-re-cer",
    "desflorecimiento": "des-flo-re-ci-mien-to",
    "desfogar": "des-fo-gar",
    "desfogonar": "des-fo-go-nar",
    "desfogue": "des-fo-gue",
    "desfollar": "des-fo-llar",
    "desfollonar": "des-fo-llo-nar",
    "desfondamiento": "des-fon-da-mien-to",
    "desfondar": "des-fon-dar",
    "desfonde": "des-fon-de",
    "desfonologización": "des-fo-no-lo-gi-za-ción",
    "desforestación": "des-fo-res-ta-ción",
    "desforestar": "des-fo-res-tar",
    "desformar": "des-for-mar",
    "desforrar": "des-fo-rrar",
    "desfortalecer": "des-for-ta-le-cer",
    "desforzar": "des-for-zar",
    "desforzarse": "des-for-zar-se",
    "desfrenamiento": "des-fre-na-mien-to",
    "desfrenar": "des-fre-nar",
    "desfruncir": "des-frun-cir",
    "desfrutar": "des-fru-tar",
    "desfrute": "des-fru-te",
    "desfundar": "des-fun-dar",
    "desga": "des-ga",
    "desgabilado": "des-ga-bi-la-do",
    "desgaire": "des-gai-re",
    "desgajadura": "des-ga-ja-du-ra",
    "desgajamiento": "des-ga-ja-mien-to",
    "desgajar": "des-ga-jar",
    "desgaje": "des-ga-je",
    "desgalgadero": "des-gal-ga-de-ro",
    "desgalgar": "des-gal-gar",
    "desgalichada": "des-ga-li-cha-da",
    "desgalichado": "des-ga-li-cha-do",
    "desgalichadura": "des-ga-li-cha-du-ra",
    "desgalillar": "des-ga-li-llar",
    "desgana": "des-ga-na",
    "desganada": "des-ga-na-da",
    "desganadamente": "des-ga-na-da-men-te",
    "desganado": "des-ga-na-do",
    "desganar": "des-ga-nar",
    "desganchar": "des-gan-char",
    "desgañifar": "des-ga-ñi-far",
    "desgañifarse": "des-ga-ñi-far-se",
    "desgañitar": "des-ga-ñi-tar",
    "desgañitarse": "des-ga-ñi-tar-se",
    "desgano": "des-ga-no",
    "desgarbadamente": "des-gar-ba-da-men-te",
    "desgarbado": "des-gar-ba-do",
    "desgarbilada": "des-gar-bi-la-da",
    "desgarbilado": "des-gar-bi-la-do",
    "desgarbo": "des-gar-bo",
    "desgargantar": "des-gar-gan-tar",
    "desgargantarse": "des-gar-gan-tar-se",
    "desgargolar": "des-gar-go-lar",
    "desgaritar": "des-ga-ri-tar",
    "desgarrada": "des-ga-rra-da",
    "desgarradamente": "des-ga-rra-da-men-te",
    "desgarrado": "des-ga-rra-do",
    "desgarrador": "des-ga-rra-dor",
    "desgarradora": "des-ga-rra-do-ra",
    "desgarradura": "des-ga-rra-du-ra",
    "desgarramiento": "des-ga-rra-mien-to",
    "desgarranchar": "des-ga-rran-char",
    "desgarrar": "des-ga-rrar",
    "desgarre": "des-ga-rre",
    "desgarreate": "des-ga-rre-a-te",
    "desgarriate": "des-ga-rria-te",
    "desgarro": "des-ga-rro",
    "desgarrón": "des-ga-rrón",
    "desgasificar": "des-ga-si-fi-car",
    "desgastador": "des-gas-ta-dor",
    "desgastadora": "des-gas-ta-do-ra",
    "desgastamiento": "des-gas-ta-mien-to",
    "desgastar": "des-gas-tar",
    "desgaste": "des-gas-te",
    "desgatar": "des-ga-tar",
    "desgaznatar": "des-gaz-na-tar",
    "desgaznatarse": "des-gaz-na-tar-se",
    "desglosar": "des-glo-sar",
    "desglose": "des-glo-se",
    "desgobernada": "des-go-ber-na-da",
    "desgobernado": "des-go-ber-na-do",
    "desgobernadura": "des-go-ber-na-du-ra",
    "desgobernar": "des-go-ber-nar",
    "desgobierno": "des-go-bier-no",
    "desgolletar": "des-go-lle-tar",
    "desgomar": "des-go-mar",
    "desgonzada": "des-gon-za-da",
    "desgonzado": "des-gon-za-do",
    "desgonzar": "des-gon-zar",
    "desgorrar": "des-go-rrar",
    "desgorrarse": "des-go-rrar-se",
    "desgorre": "des-go-rre",
    "desgotar": "des-go-tar",
    "desgoznar": "des-goz-nar",
    "desgracia": "des-gra-cia",
    "desgraciada": "des-gra-cia-da",
    "desgraciadamente": "des-gra-cia-da-men-te",
    "desgraciadez": "des-gra-cia-dez",
    "desgraciado": "des-gra-cia-do",
    "desgraciar": "des-gra-ciar",
    "desgradar": "des-gra-dar",
    "desgradecida": "des-gra-de-ci-da",
    "desgradecido": "des-gra-de-ci-do",
    "desgrado": "des-gra-do",
    "desgraduar": "des-gra-duar",
    "desgramar": "des-gra-mar",
    "desgranada": "des-gra-na-da",
    "desgranado": "des-gra-na-do",
    "desgranador": "des-gra-na-dor",
    "desgranadora": "des-gra-na-do-ra",
    "desgranamiento": "des-gra-na-mien-to",
    "desgranar": "des-gra-nar",
    "desgrane": "des-gra-ne",
    "desgranzar": "des-gran-zar",
    "desgrasante": "des-gra-san-te",
    "desgrasar": "des-gra-sar",
    "desgrase": "des-gra-se",
    "desgravación": "des-gra-va-ción",
    "desgravar": "des-gra-var",
    "desgreñada": "des-gre-ña-da",
    "desgreñado": "des-gre-ña-do",
    "desgreñar": "des-gre-ñar",
    "desgreño": "des-gre-ño",
    "desguabilado": "des-gua-bi-la-do",
    "desguabilar": "des-gua-bi-lar",
    "desguace": "des-gua-ce",
    "desgualdrajar": "des-gual-dra-jar",
    "desguambilado": "des-guam-bi-la-do",
    "desguañangado": "des-gua-ñan-ga-do",
    "desguañangar": "des-gua-ñan-gar",
    "desguanzada": "des-guan-za-da",
    "desguanzado": "des-guan-za-do",
    "desguapar": "des-gua-par",
    "desguaralada": "des-gua-ra-la-da",
    "desguaralado": "des-gua-ra-la-do",
    "desguarnecer": "des-guar-ne-cer",
    "desguarnir": "des-guar-nir",
    "desguazar": "des-gua-zar",
    "desguince": "des-guin-ce",
    "desguindar": "des-guin-dar",
    "desguindo": "des-guin-do",
    "desguinzar": "des-guin-zar",
    "desguisada": "des-gui-sa-da",
    "desguisado": "des-gui-sa-do",
    "deshabida": "des-ha-bi-da",
    "deshabido": "des-ha-bi-do",
    "deshabillé": "des-ha-bi-llé",
    "deshabitada": "des-ha-bi-ta-da",
    "deshabitado": "des-ha-bi-ta-do",
    "deshabitar": "des-ha-bi-tar",
    "deshabituación": "des-ha-bi-tua-ción",
    "deshabituar": "des-ha-bi-tuar",
    "deshacedor": "des-ha-ce-dor",
    "deshacedora": "des-ha-ce-do-ra",
    "deshacer": "des-ha-cer",
    "deshacimiento": "des-ha-ci-mien-to",
    "deshaldo": "des-hal-do",
    "deshambrida": "des-ham-bri-da",
    "deshambrido": "des-ham-bri-do",
    "desharrapada": "des-ha-rra-pa-da",
    "desharrapadamente": "des-ha-rra-pa-da-men-te",
    "desharrapado": "des-ha-rra-pa-do",
    "desharrapamiento": "des-ha-rra-pa-mien-to",
    "deshebillar": "des-he-bi-llar",
    "deshebrar": "des-he-brar",
    "deshecha": "des-he-cha",
    "deshechizar": "des-he-chi-zar",
    "deshecho": "des-he-cho",
    "deshechura": "des-he-chu-ra",
    "deshelar": "des-he-lar",
    "desherbar": "des-her-bar",
    "desheredación": "des-he-re-da-ción",
    "desheredada": "des-he-re-da-da",
    "desheredado": "des-he-re-da-do",
    "desheredamiento": "des-he-re-da-mien-to",
    "desheredar": "des-he-re-dar",
    "deshermanar": "des-her-ma-nar",
    "desherradura": "des-he-rra-du-ra",
    "desherrar": "des-he-rrar",
    "desherrumbramiento": "des-he-rrum-bra-mien-to",
    "desherrumbrar": "des-he-rrum-brar",
    "deshidratación": "des-hi-dra-ta-ción",
    "deshidratado": "des-hi-dra-ta-do",
    "deshidratador": "des-hi-dra-ta-dor",
    "deshidratante": "des-hi-dra-tan-te",
    "deshidratar": "des-hi-dra-tar",
    "deshidrogenación": "des-hi-dro-ge-na-ción",
    "deshidrogenar": "des-hi-dro-ge-nar",
    "deshielo": "des-hie-lo",
    "deshierba": "des-hier-ba",
    "deshierbar": "des-hier-bar",
    "deshierbe": "des-hier-be",
    "deshijada": "des-hi-ja-da",
    "deshijado": "des-hi-ja-do",
    "deshijar": "des-hi-jar",
    "deshilachar": "des-hi-la-char",
    "deshilada": "des-hi-la-da",
    "deshilado": "des-hi-la-do",
    "deshiladura": "des-hi-la-du-ra",
    "deshilar": "des-hi-lar",
    "deshilo": "des-hi-lo",
    "deshilvanada": "des-hil-va-na-da",
    "deshilvanadamente": "des-hil-va-na-da-men-te",
    "deshilvanado": "des-hil-va-na-do",
    "deshilvanar": "des-hil-va-nar",
    "deshincadura": "des-hin-ca-du-ra",
    "deshincar": "des-hin-car",
    "deshinchadura": "des-hin-cha-du-ra",
    "deshinchar": "des-hin-char",
    "deshipotecar": "des-hi-po-te-car",
    "deshoja": "des-ho-ja",
    "deshojador": "des-ho-ja-dor",
    "deshojadora": "des-ho-ja-do-ra",
    "deshojadura": "des-ho-ja-du-ra",
    "deshojamiento": "des-ho-ja-mien-to",
    "deshojar": "des-ho-jar",
    "deshoje": "des-ho-je",
    "deshollejar": "des-ho-lle-jar",
    "deshollinadera": "des-ho-lli-na-de-ra",
    "deshollinador": "des-ho-lli-na-dor",
    "deshollinadora": "des-ho-lli-na-do-ra",
    "deshollinar": "des-ho-lli-nar",
    "deshonesta": "des-ho-nes-ta",
    "deshonestamente": "des-ho-nes-ta-men-te",
    "deshonestar": "des-ho-nes-tar",
    "deshonestidad": "des-ho-nes-ti-dad",
    "deshonesto": "des-ho-nes-to",
    "deshonor": "des-ho-nor",
    "deshonorar": "des-ho-no-rar",
    "deshonra": "des-hon-ra",
    "deshonrabuenos": "des-hon-ra-bue-nos",
    "deshonrador": "des-hon-ra-dor",
    "deshonradora": "des-hon-ra-do-ra",
    "deshonrar": "des-hon-rar",
    "deshonrible": "des-hon-ri-ble",
    "deshonrosa": "des-hon-ro-sa",
    "deshonroso": "des-hon-ro-so",
    "deshora": "des-ho-ra",
    "deshornar": "des-hor-nar",
    "deshospedada": "des-hos-pe-da-da",
    "deshospedado": "des-hos-pe-da-do",
    "deshospedamiento": "des-hos-pe-da-mien-to",
    "deshuesado": "des-hue-sa-do",
    "deshuesador": "des-hue-sa-dor",
    "deshuesadora": "des-hue-sa-do-ra",
    "deshuesar": "des-hue-sar",
    "deshumana": "des-hu-ma-na",
    "deshumanización": "des-hu-ma-ni-za-ción",
    "deshumanizadamente": "des-hu-ma-ni-za-da-men-te",
    "deshumanizado": "des-hu-ma-ni-za-do",
    "deshumanizador": "des-hu-ma-ni-za-dor",
    "deshumanizante": "des-hu-ma-ni-zan-te",
    "deshumanizar": "des-hu-ma-ni-zar",
    "deshumano": "des-hu-ma-no",
    "deshumedecer": "des-hu-me-de-cer",
    "deshumidificador": "des-hu-mi-di-fi-ca-dor",
    "desideologización": "de-si-de-o-lo-gi-za-ción",
    "desideologizado": "de-si-de-o-lo-gi-za-do",
    "desideologizar": "de-si-de-o-lo-gi-zar",
    "desiderable": "de-si-de-ra-ble",
    "desiderata": "de-si-de-ra-ta",
    "desiderativa": "de-si-de-ra-ti-va",
    "desiderativo": "de-si-de-ra-ti-vo",
    "desiderátum": "de-si-de-rá-tum",
    "desidia": "de-si-dia",
    "desidiosa": "de-si-dio-sa",
    "desidioso": "de-si-dio-so",
    "desierta": "de-sier-ta",
    "desierto": "de-sier-to",
    "designación": "de-sig-na-ción",
    "designada": "de-sig-na-da",
    "designado": "de-sig-na-do",
    "designar": "de-sig-nar",
    "designativa": "de-sig-na-ti-va",
    "designativo": "de-sig-na-ti-vo",
    "designio": "de-sig-nio",
    "desigual": "de-si-gual",
    "desigualar": "de-si-gua-lar",
    "desigualdad": "de-si-gual-dad",
    "desigualmente": "de-si-gual-men-te",
    "desilusión": "de-si-lu-sión",
    "desilusionar": "de-si-lu-sio-nar",
    "desimaginar": "de-si-ma-gi-nar",
    "desimanación": "de-si-ma-na-ción",
    "desimanar": "de-si-ma-nar",
    "desimantación": "de-si-man-ta-ción",
    "desimantar": "de-si-man-tar",
    "desimponer": "de-sim-po-ner",
    "desimpresionar": "de-sim-pre-sio-nar",
    "desincentivación": "de-sin-cen-ti-va-ción",
    "desincentivador": "de-sin-cen-ti-va-dor",
    "desincentivar": "de-sin-cen-ti-var",
    "desinclinar": "de-sin-cli-nar",
    "desincorporar": "de-sin-cor-po-rar",
    "desincrustante": "de-sin-crus-tan-te",
    "desincrustar": "de-sin-crus-tar",
    "desindustrialización": "de-sin-dus-tria-li-za-ción",
    "desinencia": "de-si-nen-cia",
    "desinencial": "de-si-nen-cial",
    "desinente": "de-si-nen-te",
    "desinfartar": "de-sin-far-tar",
    "desinfección": "de-sin-fec-ción",
    "desinfectante": "de-sin-fec-tan-te",
    "desinfectar": "de-sin-fec-tar",
    "desinfestar": "de-sin-fes-tar",
    "desinficionar": "de-sin-fi-cio-nar",
    "desinflamar": "de-sin-fla-mar",
    "desinflamatorio": "de-sin-fla-ma-to-rio",
    "desinflar": "de-sin-flar",
    "desinformación": "de-sin-for-ma-ción",
    "desinformar": "de-sin-for-mar",
    "desinhibición": "de-sin-hi-bi-ción",
    "desinhibido": "de-sin-hi-bi-do",
    "desinhibir": "de-sin-hi-bir",
    "desiño": "de-si-ño",
    "desinsaculación": "de-sin-sa-cu-la-ción",
    "desinsacular": "de-sin-sa-cu-lar",
    "desinsectación": "de-sin-sec-ta-ción",
    "desinsectador": "de-sin-sec-ta-dor",
    "desinsectar": "de-sin-sec-tar",
    "desinstalación": "de-sins-ta-la-ción",
    "desinstalar": "de-sins-ta-lar",
    "desintegración": "de-sin-te-gra-ción",
    "desintegrar": "de-sin-te-grar",
    "desinteligencia": "de-sin-te-li-gen-cia",
    "desinterés": "de-sin-te-rés",
    "desinteresada": "de-sin-te-re-sa-da",
    "desinteresadamente": "de-sin-te-re-sa-da-men-te",
    "desinteresado": "de-sin-te-re-sa-do",
    "desinteresal": "de-sin-te-re-sal",
    "desinteresar": "de-sin-te-re-sar",
    "desinteresarse": "de-sin-te-re-sar-se",
    "desintestinar": "de-sin-tes-ti-nar",
    "desintoxicación": "de-sin-to-xi-ca-ción",
    "desintoxicar": "de-sin-to-xi-car",
    "desintubar": "de-sin-tu-bar",
    "desinvernar": "de-sin-ver-nar",
    "desinversión": "de-sin-ver-sión",
    "desinvertir": "de-sin-ver-tir",
    "desipiencia": "de-si-pien-cia",
    "desistencia": "de-sis-ten-cia",
    "desistimiento": "de-sis-ti-mien-to",
    "desistir": "de-sis-tir",
    "desjarretadera": "des-ja-rre-ta-de-ra",
    "desjarretar": "des-ja-rre-tar",
    "desjarrete": "des-ja-rre-te",
    "desjugar": "des-ju-gar",
    "desjuiciada": "des-jui-cia-da",
    "desjuiciado": "des-jui-cia-do",
    "desjuntamiento": "des-jun-ta-mien-to",
    "desjuntar": "des-jun-tar",
    "deslabonar": "des-la-bo-nar",
    "desladrillar": "des-la-dri-llar",
    "deslaidar": "des-lai-dar",
    "deslamar": "des-la-mar",
    "deslánguida": "des-lán-gui-da",
    "deslánguido": "des-lán-gui-do",
    "deslardar": "des-lar-dar",
    "deslardarse": "des-lar-dar-se",
    "deslastrar": "des-las-trar",
    "deslatar": "des-la-tar",
    "deslate": "des-la-te",
    "deslateralización": "des-la-te-ra-li-za-ción",
    "deslateralizar": "des-la-te-ra-li-zar",
    "deslavada": "des-la-va-da",
    "deslavado": "des-la-va-do",
    "deslavadura": "des-la-va-du-ra",
    "deslavamiento": "des-la-va-mien-to",
    "deslavar": "des-la-var",
    "deslavazado": "des-la-va-za-do",
    "deslavazar": "des-la-va-zar",
    "deslave": "des-la-ve",
    "deslayo": "des-la-yo",
    "deslazamiento": "des-la-za-mien-to",
    "deslazar": "des-la-zar",
    "desleal": "des-le-al",
    "deslealmente": "des-le-al-men-te",
    "deslealtad": "des-le-al-tad",
    "deslechugador": "des-le-chu-ga-dor",
    "deslechugadora": "des-le-chu-ga-do-ra",
    "deslechugar": "des-le-chu-gar",
    "deslechuguillar": "des-le-chu-gui-llar",
    "deslegalizar": "des-le-ga-li-zar",
    "deslegitimar": "des-le-gi-ti-mar",
    "desleidura": "des-lei-du-ra",
    "desleimiento": "des-lei-mien-to",
    "desleír": "des-le-ír",
    "deslendrar": "des-len-drar",
    "deslenguada": "des-len-gua-da",
    "deslenguado": "des-len-gua-do",
    "deslenguamiento": "des-len-gua-mien-to",
    "deslenguar": "des-len-guar",
    "desliar": "des-liar",
    "desligadura": "des-li-ga-du-ra",
    "desligar": "des-li-gar",
    "deslinajar": "des-li-na-jar",
    "deslinar": "des-li-nar",
    "desliñar": "des-li-ñar",
    "deslindador": "des-lin-da-dor",
    "deslindadora": "des-lin-da-do-ra",
    "deslindamiento": "des-lin-da-mien-to",
    "deslindar": "des-lin-dar",
    "deslinde": "des-lin-de",
    "deslío": "des-lí-o",
    "desliz": "des-liz",
    "deslizable": "des-li-za-ble",
    "deslizadera": "des-li-za-de-ra",
    "deslizadero": "des-li-za-de-ro",
    "deslizadizo": "des-li-za-di-zo",
    "deslizador": "des-li-za-dor",
    "deslizamiento": "des-li-za-mien-to",
    "deslizante": "des-li-zan-te",
    "deslizar": "des-li-zar",
    "desloar": "des-lo-ar",
    "deslocalización": "des-lo-ca-li-za-ción",
    "deslocalizar": "des-lo-ca-li-zar",
    "deslomadura": "des-lo-ma-du-ra",
    "deslomar": "des-lo-mar",
    "desloor": "des-lo-or",
    "deslucida": "des-lu-ci-da",
    "deslucidamente": "des-lu-ci-da-men-te",
    "deslucido": "des-lu-ci-do",
    "deslucimiento": "des-lu-ci-mien-to",
    "deslucir": "des-lu-cir",
    "deslumbrador": "des-lum-bra-dor",
    "deslumbradora": "des-lum-bra-do-ra",
    "deslumbramiento": "des-lum-bra-mien-to",
    "deslumbrante": "des-lum-bran-te",
    "deslumbrantemente": "des-lum-bran-te-men-te",
    "deslumbrar": "des-lum-brar",
    "deslumbre": "des-lum-bre",
    "deslustrador": "des-lus-tra-dor",
    "deslustradora": "des-lus-tra-do-ra",
    "deslustrar": "des-lus-trar",
    "deslustre": "des-lus-tre",
    "deslustrosa": "des-lus-tro-sa",
    "deslustroso": "des-lus-tro-so",
    "desmadejada": "des-ma-de-ja-da",
    "desmadejadamente": "des-ma-de-ja-da-men-te",
    "desmadejado": "des-ma-de-ja-do",
    "desmadejamiento": "des-ma-de-ja-mien-to",
    "desmadejar": "des-ma-de-jar",
    "desmadrada": "des-ma-dra-da",
    "desmadrado": "des-ma-dra-do",
    "desmadrar": "des-ma-drar",
    "desmadre": "des-ma-dre",
    "desmadroso": "des-ma-dro-so",
    "desmagnetizar": "des-mag-ne-ti-zar",
    "desmajolar": "des-ma-jo-lar",
    "desmalazada": "des-ma-la-za-da",
    "desmalazado": "des-ma-la-za-do",
    "desmalezar": "des-ma-le-zar",
    "desmalingrar": "des-ma-lin-grar",
    "desmallador": "des-ma-lla-dor",
    "desmalladora": "des-ma-lla-do-ra",
    "desmalladura": "des-ma-lla-du-ra",
    "desmallar": "des-ma-llar",
    "desmamar": "des-ma-mar",
    "desmambichar": "des-mam-bi-char",
    "desmamonar": "des-ma-mo-nar",
    "desmamparar": "des-mam-pa-rar",
    "desmán": "des-mán",
    "desmaña": "des-ma-ña",
    "desmañada": "des-ma-ña-da",
    "desmañadamente": "des-ma-ña-da-men-te",
    "desmañado": "des-ma-ña-do",
    "desmañanar": "des-ma-ña-nar",
    "desmanar": "des-ma-nar",
    "desmañar": "des-ma-ñar",
    "desmanchar": "des-man-char",
    "desmanche": "des-man-che",
    "desmancho": "des-man-cho",
    "desmandada": "des-man-da-da",
    "desmandado": "des-man-da-do",
    "desmandamiento": "des-man-da-mien-to",
    "desmandar": "des-man-dar",
    "desmanear": "des-ma-ne-ar",
    "desmangar": "des-man-gar",
    "desmaño": "des-ma-ño",
    "desmanotada": "des-ma-no-ta-da",
    "desmanotadamente": "des-ma-no-ta-da-men-te",
    "desmanotado": "des-ma-no-ta-do",
    "desmantecar": "des-man-te-car",
    "desmantelada": "des-man-te-la-da",
    "desmantelado": "des-man-te-la-do",
    "desmantelamiento": "des-man-te-la-mien-to",
    "desmantelar": "des-man-te-lar",
    "desmaquillador": "des-ma-qui-lla-dor",
    "desmaquillar": "des-ma-qui-llar",
    "desmarañar": "des-ma-ra-ñar",
    "desmarcar": "des-mar-car",
    "desmaridar": "des-ma-ri-dar",
    "desmarimbar": "des-ma-rim-bar",
    "desmarojador": "des-ma-ro-ja-dor",
    "desmarojadora": "des-ma-ro-ja-do-ra",
    "desmarojar": "des-ma-ro-jar",
    "desmarque": "des-mar-que",
    "desmarrida": "des-ma-rri-da",
    "desmarrido": "des-ma-rri-do",
    "desmatar": "des-ma-tar",
    "desmayada": "des-ma-ya-da",
    "desmayado": "des-ma-ya-do",
    "desmayar": "des-ma-yar",
    "desmayo": "des-ma-yo",
    "desmazalada": "des-ma-za-la-da",
    "desmazalado": "des-ma-za-la-do",
    "desmechar": "des-me-char",
    "desmedida": "des-me-di-da",
    "desmedidamente": "des-me-di-da-men-te",
    "desmedido": "des-me-di-do",
    "desmedir": "des-me-dir",
    "desmedirse": "des-me-dir-se",
    "desmedra": "des-me-dra",
    "desmedrada": "des-me-dra-da",
    "desmedrado": "des-me-dra-do",
    "desmedrar": "des-me-drar",
    "desmedro": "des-me-dro",
    "desmejora": "des-me-jo-ra",
    "desmejorado": "des-me-jo-ra-do",
    "desmejoramiento": "des-me-jo-ra-mien-to",
    "desmejorar": "des-me-jo-rar",
    "desmelancolizar": "des-me-lan-co-li-zar",
    "desmelar": "des-me-lar",
    "desmelenada": "des-me-le-na-da",
    "desmelenadamente": "des-me-le-na-da-men-te",
    "desmelenado": "des-me-le-na-do",
    "desmelenamiento": "des-me-le-na-mien-to",
    "desmelenar": "des-me-le-nar",
    "desmelene": "des-me-le-ne",
    "desmembración": "des-mem-bra-ción",
    "desmembrado": "des-mem-bra-do",
    "desmembrador": "des-mem-bra-dor",
    "desmembradora": "des-mem-bra-do-ra",
    "desmembramiento": "des-mem-bra-mien-to",
    "desmembrar": "des-mem-brar",
    "desmemoria": "des-me-mo-ria",
    "desmemoriada": "des-me-mo-ria-da",
    "desmemoriado": "des-me-mo-ria-do",
    "desmemoriar": "des-me-mo-riar",
    "desmemoriarse": "des-me-mo-riar-se",
    "desmenguar": "des-men-guar",
    "desmentida": "des-men-ti-da",
    "desmentido": "des-men-ti-do",
    "desmentidor": "des-men-ti-dor",
    "desmentidora": "des-men-ti-do-ra",
    "desmentir": "des-men-tir",
    "desmenuzable": "des-me-nu-za-ble",
    "desmenuzador": "des-me-nu-za-dor",
    "desmenuzadora": "des-me-nu-za-do-ra",
    "desmenuzamiento": "des-me-nu-za-mien-to",
    "desmenuzar": "des-me-nu-zar",
    "desmeollamiento": "des-me-o-lla-mien-to",
    "desmeollar": "des-me-o-llar",
    "desmerecedor": "des-me-re-ce-dor",
    "desmerecedora": "des-me-re-ce-do-ra",
    "desmerecer": "des-me-re-cer",
    "desmerecimiento": "des-me-re-ci-mien-to",
    "desmesura": "des-me-su-ra",
    "desmesurada": "des-me-su-ra-da",
    "desmesuradamente": "des-me-su-ra-da-men-te",
    "desmesurado": "des-me-su-ra-do",
    "desmesurar": "des-me-su-rar",
    "desmidácea": "des-mi-dá-ce-a",
    "desmigajar": "des-mi-ga-jar",
    "desmigar": "des-mi-gar",
    "desmilitarización": "des-mi-li-ta-ri-za-ción",
    "desmilitarizar": "des-mi-li-ta-ri-zar",
    "desminado": "des-mi-na-do",
    "desminar": "des-mi-nar",
    "desmineralización": "des-mi-ne-ra-li-za-ción",
    "desmineralizar": "des-mi-ne-ra-li-zar",
    "desmiramiento": "des-mi-ra-mien-to",
    "desmirlada": "des-mir-la-da",
    "desmirlado": "des-mir-la-do",
    "desmirriada": "des-mi-rria-da",
    "desmirriado": "des-mi-rria-do",
    "desmitificación": "des-mi-ti-fi-ca-ción",
    "desmitificador": "des-mi-ti-fi-ca-dor",
    "desmitificar": "des-mi-ti-fi-car",
    "desmocadero": "des-mo-ca-de-ro",
    "desmocar": "des-mo-car",
    "desmocha": "des-mo-cha",
    "desmochadura": "des-mo-cha-du-ra",
    "desmochar": "des-mo-char",
    "desmoche": "des-mo-che",
    "desmocho": "des-mo-cho",
    "desmoderadamente": "des-mo-de-ra-da-men-te",
    "desmodulación": "des-mo-du-la-ción",
    "desmogar": "des-mo-gar",
    "desmogue": "des-mo-gue",
    "desmolada": "des-mo-la-da",
    "desmolado": "des-mo-la-do",
    "desmoldar": "des-mol-dar",
    "desmolde": "des-mol-de",
    "desmoldear": "des-mol-de-ar",
    "desmoldeo": "des-mol-de-o",
    "desmoledura": "des-mo-le-du-ra",
    "desmoler": "des-mo-ler",
    "desmoñar": "des-mo-ñar",
    "desmonetización": "des-mo-ne-ti-za-ción",
    "desmonetizar": "des-mo-ne-ti-zar",
    "desmontable": "des-mon-ta-ble",
    "desmontado": "des-mon-ta-do",
    "desmontadura": "des-mon-ta-du-ra",
    "desmontaje": "des-mon-ta-je",
    "desmontar": "des-mon-tar",
    "desmonte": "des-mon-te",
    "desmoralización": "des-mo-ra-li-za-ción",
    "desmoralizador": "des-mo-ra-li-za-dor",
    "desmoralizadora": "des-mo-ra-li-za-do-ra",
    "desmoralizar": "des-mo-ra-li-zar",
    "desmorecer": "des-mo-re-cer",
    "desmorecerse": "des-mo-re-cer-se",
    "desmoronadiza": "des-mo-ro-na-di-za",
    "desmoronadizo": "des-mo-ro-na-di-zo",
    "desmoronamiento": "des-mo-ro-na-mien-to",
    "desmoronar": "des-mo-ro-nar",
    "desmostar": "des-mos-tar",
    "desmostarse": "des-mos-tar-se",
    "desmotadera": "des-mo-ta-de-ra",
    "desmotador": "des-mo-ta-dor",
    "desmotadora": "des-mo-ta-do-ra",
    "desmotar": "des-mo-tar",
    "desmote": "des-mo-te",
    "desmotivación": "des-mo-ti-va-ción",
    "desmotivar": "des-mo-ti-var",
    "desmovilización": "des-mo-vi-li-za-ción",
    "desmovilizar": "des-mo-vi-li-zar",
    "desmuelado": "des-mue-la-do",
    "desmugrar": "des-mu-grar",
    "desmullir": "des-mu-llir",
    "desmultiplicación": "des-mul-ti-pli-ca-ción",
    "desmultiplicador": "des-mul-ti-pli-ca-dor",
    "desmultiplicar": "des-mul-ti-pli-car",
    "desmurar": "des-mu-rar",
    "desnacionalización": "des-na-cio-na-li-za-ción",
    "desnacionalizar": "des-na-cio-na-li-zar",
    "desnarigada": "des-na-ri-ga-da",
    "desnarigado": "des-na-ri-ga-do",
    "desnarigar": "des-na-ri-gar",
    "desnatado": "des-na-ta-do",
    "desnatador": "des-na-ta-dor",
    "desnatadora": "des-na-ta-do-ra",
    "desnatar": "des-na-tar",
    "desnatural": "des-na-tu-ral",
    "desnaturalización": "des-na-tu-ra-li-za-ción",
    "desnaturalizada": "des-na-tu-ra-li-za-da",
    "desnaturalizado": "des-na-tu-ra-li-za-do",
    "desnaturalizar": "des-na-tu-ra-li-zar",
    "desnaturar": "des-na-tu-rar",
    "desnecesaria": "des-ne-ce-sa-ria",
    "desnecesario": "des-ne-ce-sa-rio",
    "desnegar": "des-ne-gar",
    "desnervar": "des-ner-var",
    "desnevada": "des-ne-va-da",
    "desnevado": "des-ne-va-do",
    "desnevar": "des-ne-var",
    "desnieve": "des-nie-ve",
    "desniñar": "des-ni-ñar",
    "desnivel": "des-ni-vel",
    "desnivelación": "des-ni-ve-la-ción",
    "desnivelar": "des-ni-ve-lar",
    "desnoblecer": "des-no-ble-cer",
    "desnortar": "des-nor-tar",
    "desnucamiento": "des-nu-ca-mien-to",
    "desnucar": "des-nu-car",
    "desnuclearización": "des-nu-cle-a-ri-za-ción",
    "desnuclearizado": "des-nu-cle-a-ri-za-do",
    "desnuclearizar": "des-nu-cle-a-ri-zar",
    "desnuda": "des-nu-da",
    "desnudador": "des-nu-da-dor",
    "desnudadora": "des-nu-da-do-ra",
    "desnudamente": "des-nu-da-men-te",
    "desnudamiento": "des-nu-da-mien-to",
    "desnudar": "des-nu-dar",
    "desnudez": "des-nu-dez",
    "desnudismo": "des-nu-dis-mo",
    "desnudista": "des-nu-dis-ta",
    "desnudo": "des-nu-do",
    "desnutrición": "des-nu-tri-ción",
    "desnutrido": "des-nu-tri-do",
    "desnutrir": "des-nu-trir",
    "desnutrirse": "des-nu-trir-se",
    "desobedecer": "de-so-be-de-cer",
    "desobediencia": "de-so-be-dien-cia",
    "desobediente": "de-so-be-dien-te",
    "desobligado": "de-so-bli-ga-do",
    "desobligar": "de-so-bli-gar",
    "desobligo": "de-so-bli-go",
    "desobstrucción": "de-sobs-truc-ción",
    "desobstruir": "de-sobs-truir",
    "desocasionada": "de-so-ca-sio-na-da",
    "desocasionado": "de-so-ca-sio-na-do",
    "desocupación": "de-so-cu-pa-ción",
    "desocupada": "de-so-cu-pa-da",
    "desocupadamente": "de-so-cu-pa-da-men-te",
    "desocupado": "de-so-cu-pa-do",
    "desocupar": "de-so-cu-par",
    "desodorante": "de-so-do-ran-te",
    "desodorizante": "de-so-do-ri-zan-te",
    "desodorizar": "de-so-do-ri-zar",
    "desoír": "de-so-ír",
    "desojar": "de-so-jar",
    "desolación": "de-so-la-ción",
    "desoladamente": "de-so-la-da-men-te",
    "desolado": "de-so-la-do",
    "desolador": "de-so-la-dor",
    "desoladora": "de-so-la-do-ra",
    "desolar": "de-so-lar",
    "desolazar": "de-so-la-zar",
    "desoldar": "de-sol-dar",
    "desollada": "de-so-lla-da",
    "desolladamente": "de-so-lla-da-men-te",
    "desolladero": "de-so-lla-de-ro",
    "desollado": "de-so-lla-do",
    "desollador": "de-so-lla-dor",
    "desolladora": "de-so-lla-do-ra",
    "desolladura": "de-so-lla-du-ra",
    "desollamiento": "de-so-lla-mien-to",
    "desollar": "de-so-llar",
    "desollón": "de-so-llón",
    "desonzar": "de-son-zar",
    "desopilación": "de-so-pi-la-ción",
    "desopilante": "de-so-pi-lan-te",
    "desopilar": "de-so-pi-lar",
    "desopilativa": "de-so-pi-la-ti-va",
    "desopilativo": "de-so-pi-la-ti-vo",
    "desopinar": "de-so-pi-nar",
    "desopresión": "de-so-pre-sión",
    "desoprimir": "de-so-pri-mir",
    "desorbitadamente": "de-sor-bi-ta-da-men-te",
    "desorbitado": "de-sor-bi-ta-do",
    "desorbitar": "de-sor-bi-tar",
    "desorción": "de-sor-ción",
    "desorden": "de-sor-den",
    "desordenación": "de-sor-de-na-ción",
    "desordenada": "de-sor-de-na-da",
    "desordenadamente": "de-sor-de-na-da-men-te",
    "desordenado": "de-sor-de-na-do",
    "desordenamiento": "de-sor-de-na-mien-to",
    "desordenar": "de-sor-de-nar",
    "desorejada": "de-so-re-ja-da",
    "desorejado": "de-so-re-ja-do",
    "desorejamiento": "de-so-re-ja-mien-to",
    "desorejar": "de-so-re-jar",
    "desorganización": "de-sor-ga-ni-za-ción",
    "desorganizadamente": "de-sor-ga-ni-za-da-men-te",
    "desorganizador": "de-sor-ga-ni-za-dor",
    "desorganizadora": "de-sor-ga-ni-za-do-ra",
    "desorganizar": "de-sor-ga-ni-zar",
    "desorientación": "de-so-rien-ta-ción",
    "desorientador": "de-so-rien-ta-dor",
    "desorientadora": "de-so-rien-ta-do-ra",
    "desorientar": "de-so-rien-tar",
    "desorillar": "de-so-ri-llar",
    "desornamentada": "de-sor-na-men-ta-da",
    "desornamentado": "de-sor-na-men-ta-do",
    "desortijada": "de-sor-ti-ja-da",
    "desortijado": "de-sor-ti-ja-do",
    "desortijar": "de-sor-ti-jar",
    "desosar": "de-so-sar",
    "desosegar": "de-so-se-gar",
    "desosiego": "de-so-sie-go",
    "desovadero": "de-so-va-de-ro",
    "desovar": "de-so-var",
    "desove": "de-so-ve",
    "desovillar": "de-so-vi-llar",
    "desoxidable": "de-so-xi-da-ble",
    "desoxidación": "de-so-xi-da-ción",
    "desoxidante": "de-so-xi-dan-te",
    "desoxidar": "de-so-xi-dar",
    "desoxigenación": "de-so-xi-ge-na-ción",
    "desoxigenar": "de-so-xi-ge-nar",
    "desoxirribonucleico": "de-so-xi-rri-bo-nu-clei-co",
    "desoxirribonucleótido": "de-so-xi-rri-bo-nu-cle-ó-ti-do",
    "desoxirribosa": "de-so-xi-rri-bo-sa",
    "despabilada": "des-pa-bi-la-da",
    "despabiladeras": "des-pa-bi-la-de-ras",
    "despabilado": "des-pa-bi-la-do",
    "despabilador": "des-pa-bi-la-dor",
    "despabiladura": "des-pa-bi-la-du-ra",
    "despabilar": "des-pa-bi-lar",
    "despabilo": "des-pa-bi-lo",
    "despachada": "des-pa-cha-da",
    "despachadamente": "des-pa-cha-da-men-te",
    "despachaderas": "des-pa-cha-de-ras",
    "despachado": "des-pa-cha-do",
    "despachador": "des-pa-cha-dor",
    "despachadora": "des-pa-cha-do-ra",
    "despachamiento": "des-pa-cha-mien-to",
    "despachante": "des-pa-chan-te",
    "despachar": "des-pa-char",
    "despachera": "des-pa-che-ra",
    "despachero": "des-pa-che-ro",
    "despacho": "des-pa-cho",
    "despachurrada": "des-pa-chu-rra-da",
    "despachurrado": "des-pa-chu-rra-do",
    "despachurramiento": "des-pa-chu-rra-mien-to",
    "despachurrar": "des-pa-chu-rrar",
    "despachurro": "des-pa-chu-rro",
    "despacio": "des-pa-cio",
    "despaciosa": "des-pa-cio-sa",
    "despaciosamente": "des-pa-cio-sa-men-te",
    "despacioso": "des-pa-cio-so",
    "despacito": "des-pa-ci-to",
    "despagada": "des-pa-ga-da",
    "despagado": "des-pa-ga-do",
    "despagamiento": "des-pa-ga-mien-to",
    "despagar": "des-pa-gar",
    "despajador": "des-pa-ja-dor",
    "despajadora": "des-pa-ja-do-ra",
    "despajadura": "des-pa-ja-du-ra",
    "despajar": "des-pa-jar",
    "despajo": "des-pa-jo",
    "despaladinar": "des-pa-la-di-nar",
    "despaldar": "des-pal-dar",
    "despaldilladura": "des-pal-di-lla-du-ra",
    "despaldillar": "des-pal-di-llar",
    "despale": "des-pa-le",
    "despaletillar": "des-pa-le-ti-llar",
    "despalillado": "des-pa-li-lla-do",
    "despalillador": "des-pa-li-lla-dor",
    "despalilladora": "des-pa-li-lla-do-ra",
    "despalillar": "des-pa-li-llar",
    "despalillo": "des-pa-li-llo",
    "despalmador": "des-pal-ma-dor",
    "despalmadura": "des-pal-ma-du-ra",
    "despalmar": "des-pal-mar",
    "despalme": "des-pal-me",
    "despalomada": "des-pa-lo-ma-da",
    "despalomado": "des-pa-lo-ma-do",
    "despampanador": "des-pam-pa-na-dor",
    "despampanadora": "des-pam-pa-na-do-ra",
    "despampanadura": "des-pam-pa-na-du-ra",
    "despampanante": "des-pam-pa-nan-te",
    "despampanar": "des-pam-pa-nar",
    "despampanillar": "des-pam-pa-ni-llar",
    "despampano": "des-pam-pa-no",
    "despamplonar": "des-pam-plo-nar",
    "despancar": "des-pan-car",
    "despanchurrar": "des-pan-chu-rrar",
    "despancijar": "des-pan-ci-jar",
    "despanzurramiento": "des-pan-zu-rra-mien-to",
    "despanzurrar": "des-pan-zu-rrar",
    "despanzurro": "des-pan-zu-rro",
    "despapar": "des-pa-par",
    "despapaye": "des-pa-pa-ye",
    "despapucho": "des-pa-pu-cho",
    "desparada": "des-pa-ra-da",
    "desparado": "des-pa-ra-do",
    "desparar": "des-pa-rar",
    "desparasitar": "des-pa-ra-si-tar",
    "desparcir": "des-par-cir",
    "desparear": "des-pa-re-ar",
    "desparecer": "des-pa-re-cer",
    "desparedar": "des-pa-re-dar",
    "despareja": "des-pa-re-ja",
    "desparejado": "des-pa-re-ja-do",
    "desparejar": "des-pa-re-jar",
    "desparejo": "des-pa-re-jo",
    "desparpajada": "des-par-pa-ja-da",
    "desparpajado": "des-par-pa-ja-do",
    "desparpajar": "des-par-pa-jar",
    "desparpajo": "des-par-pa-jo",
    "desparramada": "des-pa-rra-ma-da",
    "desparramado": "des-pa-rra-ma-do",
    "desparramador": "des-pa-rra-ma-dor",
    "desparramadora": "des-pa-rra-ma-do-ra",
    "desparramamiento": "des-pa-rra-ma-mien-to",
    "desparramar": "des-pa-rra-mar",
    "desparrame": "des-pa-rra-me",
    "desparramo": "des-pa-rra-mo",
    "desparrancada": "des-pa-rran-ca-da",
    "desparrancado": "des-pa-rran-ca-do",
    "desparrancar": "des-pa-rran-car",
    "desparrancarse": "des-pa-rran-car-se",
    "despartidero": "des-par-ti-de-ro",
    "despartidor": "des-par-ti-dor",
    "despartidora": "des-par-ti-do-ra",
    "despartimiento": "des-par-ti-mien-to",
    "despartir": "des-par-tir",
    "desparvar": "des-par-var",
    "despasar": "des-pa-sar",
    "despasmar": "des-pas-mar",
    "despasmarse": "des-pas-mar-se",
    "despatarrada": "des-pa-ta-rra-da",
    "despatarrar": "des-pa-ta-rrar",
    "despatillado": "des-pa-ti-lla-do",
    "despatillar": "des-pa-ti-llar",
    "despaturrada": "des-pa-tu-rra-da",
    "despaturrado": "des-pa-tu-rra-do",
    "despaturrar": "des-pa-tu-rrar",
    "despavesaderas": "des-pa-ve-sa-de-ras",
    "despavesadura": "des-pa-ve-sa-du-ra",
    "despavesar": "des-pa-ve-sar",
    "despavonar": "des-pa-vo-nar",
    "despavorida": "des-pa-vo-ri-da",
    "despavoridamente": "des-pa-vo-ri-da-men-te",
    "despavorido": "des-pa-vo-ri-do",
    "despeado": "des-pe-a-do",
    "despeadura": "des-pe-a-du-ra",
    "despeamiento": "des-pe-a-mien-to",
    "despear": "des-pe-ar",
    "despearse": "des-pe-ar-se",
    "despechadamente": "des-pe-cha-da-men-te",
    "despechado": "des-pe-cha-do",
    "despechador": "des-pe-cha-dor",
    "despechamiento": "des-pe-cha-mien-to",
    "despechar": "des-pe-char",
    "despecheretado": "des-pe-che-re-ta-do",
    "despecho": "des-pe-cho",
    "despechosa": "des-pe-cho-sa",
    "despechoso": "des-pe-cho-so",
    "despechugadura": "des-pe-chu-ga-du-ra",
    "despechugar": "des-pe-chu-gar",
    "despectiva": "des-pec-ti-va",
    "despectivamente": "des-pec-ti-va-men-te",
    "despectivo": "des-pec-ti-vo",
    "despedazador": "des-pe-da-za-dor",
    "despedazadora": "des-pe-da-za-do-ra",
    "despedazamiento": "des-pe-da-za-mien-to",
    "despedazar": "des-pe-da-zar",
    "despedida": "des-pe-di-da",
    "despedido": "des-pe-di-do",
    "despediente": "des-pe-dien-te",
    "despedimiento": "des-pe-di-mien-to",
    "despedir": "des-pe-dir",
    "despedrar": "des-pe-drar",
    "despedregar": "des-pe-dre-gar",
    "despegable": "des-pe-ga-ble",
    "despegada": "des-pe-ga-da",
    "despegadamente": "des-pe-ga-da-men-te",
    "despegado": "des-pe-ga-do",
    "despegador": "des-pe-ga-dor",
    "despegadora": "des-pe-ga-do-ra",
    "despegadura": "des-pe-ga-du-ra",
    "despegamiento": "des-pe-ga-mien-to",
    "despegar": "des-pe-gar",
    "despego": "des-pe-go",
    "despegue": "des-pe-gue",
    "despeinado": "des-pei-na-do",
    "despeinar": "des-pei-nar",
    "despejada": "des-pe-ja-da",
    "despejadamente": "des-pe-ja-da-men-te",
    "despejado": "des-pe-ja-do",
    "despejar": "des-pe-jar",
    "despeje": "des-pe-je",
    "despejo": "des-pe-jo",
    "despellejada": "des-pe-lle-ja-da",
    "despellejadura": "des-pe-lle-ja-du-ra",
    "despellejar": "des-pe-lle-jar",
    "despelotada": "des-pe-lo-ta-da",
    "despelotado": "des-pe-lo-ta-do",
    "despelotar": "des-pe-lo-tar",
    "despelote": "des-pe-lo-te",
    "despelucar": "des-pe-lu-car",
    "despeluchar": "des-pe-lu-char",
    "despeluzamiento": "des-pe-lu-za-mien-to",
    "despeluzar": "des-pe-lu-zar",
    "despeluznante": "des-pe-luz-nan-te",
    "despeluznar": "des-pe-luz-nar",
    "despeñadamente": "des-pe-ña-da-men-te",
    "despeñadera": "des-pe-ña-de-ra",
    "despeñadero": "des-pe-ña-de-ro",
    "despeñadiza": "des-pe-ña-di-za",
    "despeñadizo": "des-pe-ña-di-zo",
    "despenador": "des-pe-na-dor",
    "despenadora": "des-pe-na-do-ra",
    "despenalización": "des-pe-na-li-za-ción",
    "despenalizador": "des-pe-na-li-za-dor",
    "despenalizar": "des-pe-na-li-zar",
    "despeñamiento": "des-pe-ña-mien-to",
    "despenar": "des-pe-nar",
    "despeñar": "des-pe-ñar",
    "despendedor": "des-pen-de-dor",
    "despendedora": "des-pen-de-do-ra",
    "despender": "des-pen-der",
    "despendolar": "des-pen-do-lar",
    "despendole": "des-pen-do-le",
    "despeño": "des-pe-ño",
    "despenolar": "des-pe-no-lar",
    "despensa": "des-pen-sa",
    "despensera": "des-pen-se-ra",
    "despensería": "des-pen-se-rí-a",
    "despensero": "des-pen-se-ro",
    "despeo": "des-pe-o",
    "despepitado": "des-pe-pi-ta-do",
    "despepitador": "des-pe-pi-ta-dor",
    "despepitadora": "des-pe-pi-ta-do-ra",
    "despepitar": "des-pe-pi-tar",
    "desperación": "des-pe-ra-ción",
    "desperada": "des-pe-ra-da",
    "desperado": "des-pe-ra-do",
    "desperar": "des-pe-rar",
    "despercudido": "des-per-cu-di-do",
    "despercudir": "des-per-cu-dir",
    "desperdiciada": "des-per-di-cia-da",
    "desperdiciado": "des-per-di-cia-do",
    "desperdiciador": "des-per-di-cia-dor",
    "desperdiciadora": "des-per-di-cia-do-ra",
    "desperdiciamiento": "des-per-di-cia-mien-to",
    "desperdiciar": "des-per-di-ciar",
    "desperdicio": "des-per-di-cio",
    "desperdigado": "des-per-di-ga-do",
    "desperdigamiento": "des-per-di-ga-mien-to",
    "desperdigar": "des-per-di-gar",
    "desperecer": "des-pe-re-cer",
    "desperezar": "des-pe-re-zar",
    "desperezarse": "des-pe-re-zar-se",
    "desperezo": "des-pe-re-zo",
    "desperfecto": "des-per-fec-to",
    "desperfilar": "des-per-fi-lar",
    "desperfollar": "des-per-fo-llar",
    "despernada": "des-per-na-da",
    "despernado": "des-per-na-do",
    "despernancada": "des-per-nan-ca-da",
    "despernancado": "des-per-nan-ca-do",
    "despernancar": "des-per-nan-car",
    "despernancarse": "des-per-nan-car-se",
    "despernar": "des-per-nar",
    "desperrar": "des-pe-rrar",
    "desperrugida": "des-pe-rru-gi-da",
    "desperrugido": "des-pe-rru-gi-do",
    "despersonalización": "des-per-so-na-li-za-ción",
    "despersonalizar": "des-per-so-na-li-zar",
    "despertador": "des-per-ta-dor",
    "despertadora": "des-per-ta-do-ra",
    "despertamiento": "des-per-ta-mien-to",
    "despertar": "des-per-tar",
    "desperteza": "des-per-te-za",
    "despesa": "des-pe-sa",
    "despesar": "des-pe-sar",
    "despesca": "des-pes-ca",
    "despescar": "des-pes-car",
    "despesco": "des-pes-co",
    "despestañar": "des-pes-ta-ñar",
    "despezar": "des-pe-zar",
    "despezo": "des-pe-zo",
    "despezonar": "des-pe-zo-nar",
    "despezuñar": "des-pe-zu-ñar",
    "despezuñarse": "des-pe-zu-ñar-se",
    "despiadada": "des-pia-da-da",
    "despiadadamente": "des-pia-da-da-men-te",
    "despiadado": "des-pia-da-do",
    "despicar": "des-pi-car",
    "despichar": "des-pi-char",
    "despiche": "des-pi-che",
    "despidida": "des-pi-di-da",
    "despidiente": "des-pi-dien-te",
    "despido": "des-pi-do",
    "despiece": "des-pie-ce",
    "despierta": "des-pier-ta",
    "despiertamente": "des-pier-ta-men-te",
    "despierto": "des-pier-to",
    "despiezar": "des-pie-zar",
    "despiezo": "des-pie-zo",
    "despije": "des-pi-je",
    "despilaramiento": "des-pi-la-ra-mien-to",
    "despilarar": "des-pi-la-rar",
    "despilfarrada": "des-pil-fa-rra-da",
    "despilfarradamente": "des-pil-fa-rra-da-men-te",
    "despilfarrado": "des-pil-fa-rra-do",
    "despilfarrador": "des-pil-fa-rra-dor",
    "despilfarradora": "des-pil-fa-rra-do-ra",
    "despilfarrar": "des-pil-fa-rrar",
    "despilfarro": "des-pil-fa-rro",
    "despimpollar": "des-pim-po-llar",
    "despinces": "des-pin-ces",
    "despinochar": "des-pi-no-char",
    "despintar": "des-pin-tar",
    "despinte": "des-pin-te",
    "despinzadera": "des-pin-za-de-ra",
    "despinzado": "des-pin-za-do",
    "despinzador": "des-pin-za-dor",
    "despinzadora": "des-pin-za-do-ra",
    "despinzar": "des-pin-zar",
    "despinzas": "des-pin-zas",
    "despiojador": "des-pio-ja-dor",
    "despiojar": "des-pio-jar",
    "despioje": "des-pio-je",
    "despiole": "des-pio-le",
    "despipe": "des-pi-pe",
    "despiporre": "des-pi-po-rre",
    "despique": "des-pi-que",
    "despiritada": "des-pi-ri-ta-da",
    "despiritado": "des-pi-ri-ta-do",
    "despistada": "des-pis-ta-da",
    "despistadamente": "des-pis-ta-da-men-te",
    "despistado": "des-pis-ta-do",
    "despistaje": "des-pis-ta-je",
    "despistar": "des-pis-tar",
    "despiste": "des-pis-te",
    "despistolización": "des-pis-to-li-za-ción",
    "despitorrado": "des-pi-to-rra-do",
    "despizcar": "des-piz-car",
    "desplacer": "des-pla-cer",
    "desplaciente": "des-pla-cien-te",
    "desplanar": "des-pla-nar",
    "desplanchar": "des-plan-char",
    "desplantación": "des-plan-ta-ción",
    "desplantador": "des-plan-ta-dor",
    "desplantadora": "des-plan-ta-do-ra",
    "desplantar": "des-plan-tar",
    "desplante": "des-plan-te",
    "desplatación": "des-pla-ta-ción",
    "desplatar": "des-pla-tar",
    "desplate": "des-pla-te",
    "desplayado": "des-pla-ya-do",
    "desplayar": "des-pla-yar",
    "desplaye": "des-pla-ye",
    "desplazada": "des-pla-za-da",
    "desplazado": "des-pla-za-do",
    "desplazamiento": "des-pla-za-mien-to",
    "desplazar": "des-pla-zar",
    "desplegable": "des-ple-ga-ble",
    "desplegadamente": "des-ple-ga-da-men-te",
    "desplegadura": "des-ple-ga-du-ra",
    "desplegar": "des-ple-gar",
    "desplego": "des-ple-go",
    "despleguetear": "des-ple-gue-te-ar",
    "despliegue": "des-plie-gue",
    "desplomar": "des-plo-mar",
    "desplome": "des-plo-me",
    "desplomo": "des-plo-mo",
    "desplumadero": "des-plu-ma-de-ro",
    "desplumado": "des-plu-ma-do",
    "desplumador": "des-plu-ma-dor",
    "desplumadora": "des-plu-ma-do-ra",
    "desplumadura": "des-plu-ma-du-ra",
    "desplumar": "des-plu-mar",
    "desplume": "des-plu-me",
    "despoblación": "des-po-bla-ción",
    "despoblada": "des-po-bla-da",
    "despoblado": "des-po-bla-do",
    "despoblador": "des-po-bla-dor",
    "despobladora": "des-po-bla-do-ra",
    "despoblamiento": "des-po-bla-mien-to",
    "despoblar": "des-po-blar",
    "despoderada": "des-po-de-ra-da",
    "despoderado": "des-po-de-ra-do",
    "despoetizar": "des-po-e-ti-zar",
    "despojador": "des-po-ja-dor",
    "despojadora": "des-po-ja-do-ra",
    "despojamiento": "des-po-ja-mien-to",
    "despojar": "des-po-jar",
    "despojo": "des-po-jo",
    "despolarización": "des-po-la-ri-za-ción",
    "despolarizador": "des-po-la-ri-za-dor",
    "despolarizadora": "des-po-la-ri-za-do-ra",
    "despolarizar": "des-po-la-ri-zar",
    "despolitización": "des-po-li-ti-za-ción",
    "despolitizar": "des-po-li-ti-zar",
    "despolvar": "des-pol-var",
    "despolvorear": "des-pol-vo-re-ar",
    "despolvoreo": "des-pol-vo-re-o",
    "desponer": "des-po-ner",
    "despopularización": "des-po-pu-la-ri-za-ción",
    "despopularizar": "des-po-pu-la-ri-zar",
    "desporrondingar": "des-po-rron-din-gar",
    "desportilladura": "des-por-ti-lla-du-ra",
    "desportillar": "des-por-ti-llar",
    "desposada": "des-po-sa-da",
    "desposado": "des-po-sa-do",
    "desposamiento": "des-po-sa-mien-to",
    "desposanda": "des-po-san-da",
    "desposando": "des-po-san-do",
    "desposar": "des-po-sar",
    "desposeer": "des-po-se-er",
    "desposeída": "des-po-se-í-da",
    "desposeído": "des-po-se-í-do",
    "desposeimiento": "des-po-sei-mien-to",
    "desposesión": "des-po-se-sión",
    "desposorio": "des-po-so-rio",
    "despostadero": "des-pos-ta-de-ro",
    "despostador": "des-pos-ta-dor",
    "despostar": "des-pos-tar",
    "desposte": "des-pos-te",
    "despostillar": "des-pos-ti-llar",
    "déspota": "dés-po-ta",
    "despótica": "des-pó-ti-ca",
    "despóticamente": "des-pó-ti-ca-men-te",
    "despótico": "des-pó-ti-co",
    "despotiquez": "des-po-ti-quez",
    "despotismo": "des-po-tis-mo",
    "despotizar": "des-po-ti-zar",
    "déspoto": "dés-po-to",
    "despotricar": "des-po-tri-car",
    "despotrique": "des-po-tri-que",
    "despozolar": "des-po-zo-lar",
    "despreciable": "des-pre-cia-ble",
    "despreciador": "des-pre-cia-dor",
    "despreciadora": "des-pre-cia-do-ra",
    "despreciar": "des-pre-ciar",
    "despreciativa": "des-pre-cia-ti-va",
    "despreciativo": "des-pre-cia-ti-vo",
    "desprecio": "des-pre-cio",
    "desprender": "des-pren-der",
    "desprendida": "des-pren-di-da",
    "desprendido": "des-pren-di-do",
    "desprendimiento": "des-pren-di-mien-to",
    "despreocupación": "des-pre-o-cu-pa-ción",
    "despreocupada": "des-pre-o-cu-pa-da",
    "despreocupado": "des-pre-o-cu-pa-do",
    "despreocupar": "des-pre-o-cu-par",
    "despreocuparse": "des-pre-o-cu-par-se",
    "despresar": "des-pre-sar",
    "desprestigiar": "des-pres-ti-giar",
    "desprestigio": "des-pres-ti-gio",
    "despresurización": "des-pre-su-ri-za-ción",
    "despresurizar": "des-pre-su-ri-zar",
    "desprevención": "des-pre-ven-ción",
    "desprevenida": "des-pre-ve-ni-da",
    "desprevenidamente": "des-pre-ve-ni-da-men-te",
    "desprevenido": "des-pre-ve-ni-do",
    "desprez": "des-prez",
    "desprivanza": "des-pri-van-za",
    "desprivar": "des-pri-var",
    "desprivatización": "des-pri-va-ti-za-ción",
    "desprivatizar": "des-pri-va-ti-zar",
    "desprogramación": "des-pro-gra-ma-ción",
    "desprogramar": "des-pro-gra-mar",
    "desprolija": "des-pro-li-ja",
    "desprolijo": "des-pro-li-jo",
    "despropiar": "des-pro-piar",
    "desproporción": "des-pro-por-ción",
    "desproporcionada": "des-pro-por-cio-na-da",
    "desproporcionado": "des-pro-por-cio-na-do",
    "desproporcionar": "des-pro-por-cio-nar",
    "despropositada": "des-pro-po-si-ta-da",
    "despropositado": "des-pro-po-si-ta-do",
    "despropósito": "des-pro-pó-si-to",
    "desprotección": "des-pro-tec-ción",
    "desproteger": "des-pro-te-ger",
    "desprotegida": "des-pro-te-gi-da",
    "desprotegido": "des-pro-te-gi-do",
    "desproveer": "des-pro-ve-er",
    "desproveídamente": "des-pro-ve-í-da-men-te",
    "desproveimiento": "des-pro-vei-mien-to",
    "desprovista": "des-pro-vis-ta",
    "desprovisto": "des-pro-vis-to",
    "despueble": "des-pue-ble",
    "después": "des-pués",
    "despuesito": "des-pue-si-to",
    "despulgar": "des-pul-gar",
    "despullar": "des-pu-llar",
    "despulpado": "des-pul-pa-do",
    "despulpador": "des-pul-pa-dor",
    "despulpadora": "des-pul-pa-do-ra",
    "despulpar": "des-pul-par",
    "despulsamiento": "des-pul-sa-mien-to",
    "despulsar": "des-pul-sar",
    "despumación": "des-pu-ma-ción",
    "despumar": "des-pu-mar",
    "despuntado": "des-pun-ta-do",
    "despuntador": "des-pun-ta-dor",
    "despuntadura": "des-pun-ta-du-ra",
    "despuntar": "des-pun-tar",
    "despunte": "des-pun-te",
    "despupusar": "des-pu-pu-sar",
    "desque": "des-que",
    "desquebrajar": "des-que-bra-jar",
    "desquejar": "des-que-jar",
    "desqueje": "des-que-je",
    "desquerer": "des-que-rer",
    "desquiciada": "des-qui-cia-da",
    "desquiciado": "des-qui-cia-do",
    "desquiciador": "des-qui-cia-dor",
    "desquiciadora": "des-qui-cia-do-ra",
    "desquiciamiento": "des-qui-cia-mien-to",
    "desquiciar": "des-qui-ciar",
    "desquicio": "des-qui-cio",
    "desquijaramiento": "des-qui-ja-ra-mien-to",
    "desquijarar": "des-qui-ja-rar",
    "desquijerar": "des-qui-je-rar",
    "desquilar": "des-qui-lar",
    "desquilatar": "des-qui-la-tar",
    "desquilo": "des-qui-lo",
    "desquitar": "des-qui-tar",
    "desquite": "des-qui-te",
    "desrabar": "des-ra-bar",
    "desrabotar": "des-ra-bo-tar",
    "desraigar": "des-rai-gar",
    "desraizar": "des-rai-zar",
    "desramar": "des-ra-mar",
    "desranchar": "des-ran-char",
    "desraspado": "des-ras-pa-do",
    "desraspar": "des-ras-par",
    "desratización": "des-ra-ti-za-ción",
    "desratizar": "des-ra-ti-zar",
    "desrazonable": "des-ra-zo-na-ble",
    "desrealizar": "des-re-a-li-zar",
    "desreglar": "des-re-glar",
    "desregulación": "des-re-gu-la-ción",
    "desregular": "des-re-gu-lar",
    "desrelingar": "des-re-lin-gar",
    "desrengar": "des-ren-gar",
    "desreputación": "des-re-pu-ta-ción",
    "desrielar": "des-rie-lar",
    "desriñonar": "des-ri-ño-nar",
    "desriscar": "des-ris-car",
    "desrizar": "des-ri-zar",
    "desroblar": "des-ro-blar",
    "desroñar": "des-ro-ñar",
    "desrostrar": "des-ros-trar",
    "desta": "des-ta",
    "destablar": "des-ta-blar",
    "destacable": "des-ta-ca-ble",
    "destacado": "des-ta-ca-do",
    "destacador": "des-ta-ca-dor",
    "destacamento": "des-ta-ca-men-to",
    "destacar": "des-ta-car",
    "destachonar": "des-ta-cho-nar",
    "destaconar": "des-ta-co-nar",
    "destajador": "des-ta-ja-dor",
    "destajamiento": "des-ta-ja-mien-to",
    "destajar": "des-ta-jar",
    "destajera": "des-ta-je-ra",
    "destajero": "des-ta-je-ro",
    "destajista": "des-ta-jis-ta",
    "destajo": "des-ta-jo",
    "destallar": "des-ta-llar",
    "destalonar": "des-ta-lo-nar",
    "destanteada": "des-tan-te-a-da",
    "destantear": "des-tan-te-ar",
    "destapada": "des-ta-pa-da",
    "destapador": "des-ta-pa-dor",
    "destapadura": "des-ta-pa-du-ra",
    "destapar": "des-ta-par",
    "destape": "des-ta-pe",
    "destapiado": "des-ta-pia-do",
    "destapiar": "des-ta-piar",
    "destaponar": "des-ta-po-nar",
    "destaque": "des-ta-que",
    "destara": "des-ta-ra",
    "destarar": "des-ta-rar",
    "destartalada": "des-tar-ta-la-da",
    "destartalado": "des-tar-ta-la-do",
    "destartalar": "des-tar-ta-lar",
    "destartalo": "des-tar-ta-lo",
    "destazador": "des-ta-za-dor",
    "destazar": "des-ta-zar",
    "deste": "des-te",
    "destechadura": "des-te-cha-du-ra",
    "destechar": "des-te-char",
    "destejar": "des-te-jar",
    "destejer": "des-te-jer",
    "destellar": "des-te-llar",
    "destello": "des-te-llo",
    "destemperada": "des-tem-pe-ra-da",
    "destemperado": "des-tem-pe-ra-do",
    "destemplada": "des-tem-pla-da",
    "destempladamente": "des-tem-pla-da-men-te",
    "destemplado": "des-tem-pla-do",
    "destemplador": "des-tem-pla-dor",
    "destempladora": "des-tem-pla-do-ra",
    "destemplanza": "des-tem-plan-za",
    "destemplar": "des-tem-plar",
    "destemple": "des-tem-ple",
    "desteñido": "des-te-ñi-do",
    "desteñir": "des-te-ñir",
    "destensar": "des-ten-sar",
    "destentar": "des-ten-tar",
    "desteridad": "des-te-ri-dad",
    "desterminar": "des-ter-mi-nar",
    "desternerar": "des-ter-ne-rar",
    "desternillante": "des-ter-ni-llan-te",
    "desternillar": "des-ter-ni-llar",
    "desternillarse": "des-ter-ni-llar-se",
    "desterrada": "des-te-rra-da",
    "desterradero": "des-te-rra-de-ro",
    "desterrado": "des-te-rra-do",
    "desterrar": "des-te-rrar",
    "desterronamiento": "des-te-rro-na-mien-to",
    "desterronar": "des-te-rro-nar",
    "destetadera": "des-te-ta-de-ra",
    "destetar": "des-te-tar",
    "destete": "des-te-te",
    "desteto": "des-te-to",
    "destez": "des-tez",
    "destiempo": "des-tiem-po",
    "destiento": "des-tien-to",
    "destierro": "des-tie-rro",
    "destilable": "des-ti-la-ble",
    "destilación": "des-ti-la-ción",
    "destiladera": "des-ti-la-de-ra",
    "destilador": "des-ti-la-dor",
    "destiladora": "des-ti-la-do-ra",
    "destilar": "des-ti-lar",
    "destilatoria": "des-ti-la-to-ria",
    "destilatorio": "des-ti-la-to-rio",
    "destilería": "des-ti-le-rí-a",
    "destín": "des-tín",
    "destinación": "des-ti-na-ción",
    "destinada": "des-ti-na-da",
    "destinado": "des-ti-na-do",
    "destinar": "des-ti-nar",
    "destiñar": "des-ti-ñar",
    "destinataria": "des-ti-na-ta-ria",
    "destinatario": "des-ti-na-ta-rio",
    "destino": "des-ti-no",
    "destiño": "des-ti-ño",
    "destiranizada": "des-ti-ra-ni-za-da",
    "destiranizado": "des-ti-ra-ni-za-do",
    "destirpar": "des-tir-par",
    "destitución": "des-ti-tu-ción",
    "destituible": "des-ti-tui-ble",
    "destituidor": "des-ti-tui-dor",
    "destituidora": "des-ti-tui-do-ra",
    "destituir": "des-ti-tuir",
    "destitulada": "des-ti-tu-la-da",
    "destitulado": "des-ti-tu-la-do",
    "desto": "des-to",
    "destocar": "des-to-car",
    "destorcedura": "des-tor-ce-du-ra",
    "destorcer": "des-tor-cer",
    "destorgar": "des-tor-gar",
    "destormar": "des-tor-mar",
    "destornillada": "des-tor-ni-lla-da",
    "destornillado": "des-tor-ni-lla-do",
    "destornillador": "des-tor-ni-lla-dor",
    "destornillamiento": "des-tor-ni-lla-mien-to",
    "destornillar": "des-tor-ni-llar",
    "destorpadura": "des-tor-pa-du-ra",
    "destorpar": "des-tor-par",
    "destoser": "des-to-ser",
    "destoserse": "des-to-ser-se",
    "destostuzar": "des-tos-tu-zar",
    "destotra": "des-to-tra",
    "destotro": "des-to-tro",
    "destrabar": "des-tra-bar",
    "destrabazón": "des-tra-ba-zón",
    "destral": "des-tral",
    "destraleja": "des-tra-le-ja",
    "destralero": "des-tra-le-ro",
    "destramar": "des-tra-mar",
    "destrancar": "des-tran-car",
    "destrato": "des-tra-to",
    "destrejar": "des-tre-jar",
    "destrenzar": "des-tren-zar",
    "destrera": "des-tre-ra",
    "destrero": "des-tre-ro",
    "destreza": "des-tre-za",
    "destributar": "des-tri-bu-tar",
    "destricia": "des-tri-cia",
    "destrincar": "des-trin-car",
    "destripacuentos": "des-tri-pa-cuen-tos",
    "destripador": "des-tri-pa-dor",
    "destripadora": "des-tri-pa-do-ra",
    "destripamiento": "des-tri-pa-mien-to",
    "destripar": "des-tri-par",
    "destripaterrones": "des-tri-pa-te-rro-nes",
    "destrísima": "des-trí-si-ma",
    "destrísimo": "des-trí-si-mo",
    "destriunfar": "des-triun-far",
    "destrizar": "des-tri-zar",
    "destrocar": "des-tro-car",
    "destrón": "des-trón",
    "destronamiento": "des-tro-na-mien-to",
    "destronar": "des-tro-nar",
    "destroncamiento": "des-tron-ca-mien-to",
    "destroncar": "des-tron-car",
    "destronchar": "des-tron-char",
    "destronque": "des-tron-que",
    "destropar": "des-tro-par",
    "destrozador": "des-tro-za-dor",
    "destrozadora": "des-tro-za-do-ra",
    "destrozar": "des-tro-zar",
    "destrozo": "des-tro-zo",
    "destrozón": "des-tro-zón",
    "destrozona": "des-tro-zo-na",
    "destrucción": "des-truc-ción",
    "destructibilidad": "des-truc-ti-bi-li-dad",
    "destructible": "des-truc-ti-ble",
    "destructiva": "des-truc-ti-va",
    "destructivamente": "des-truc-ti-va-men-te",
    "destructividad": "des-truc-ti-vi-dad",
    "destructivo": "des-truc-ti-vo",
    "destructor": "des-truc-tor",
    "destructora": "des-truc-to-ra",
    "destrueco": "des-true-co",
    "destrueque": "des-true-que",
    "destruible": "des-trui-ble",
    "destruición": "des-trui-ción",
    "destruidor": "des-trui-dor",
    "destruidora": "des-trui-do-ra",
    "destruimiento": "des-trui-mien-to",
    "destruir": "des-truir",
    "destullecer": "des-tu-lle-cer",
    "destupición": "des-tu-pi-ción",
    "destupir": "des-tu-pir",
    "desturbar": "des-tur-bar",
    "desturcar": "des-tur-car",
    "destusar": "des-tu-sar",
    "destustuzar": "des-tus-tu-zar",
    "destutanar": "des-tu-ta-nar",
    "desubicado": "de-su-bi-ca-do",
    "desubicar": "de-su-bi-car",
    "desubstanciar": "de-subs-tan-ciar",
    "desucación": "de-su-ca-ción",
    "desucar": "de-su-car",
    "desudación": "de-su-da-ción",
    "desudar": "de-su-dar",
    "desuellacaras": "de-sue-lla-ca-ras",
    "desuello": "de-sue-llo",
    "desuerar": "de-sue-rar",
    "desulfuración": "de-sul-fu-ra-ción",
    "desuñar": "de-su-ñar",
    "desuncir": "de-sun-cir",
    "desunidamente": "de-su-ni-da-men-te",
    "desunión": "de-su-nión",
    "desunir": "de-su-nir",
    "desuñir": "de-su-ñir",
    "desuno": "de-su-no",
    "desurcar": "de-sur-car",
    "desurdir": "de-sur-dir",
    "desurtido": "de-sur-ti-do",
    "desús": "de-sús",
    "desusadamente": "de-su-sa-da-men-te",
    "desusado": "de-su-sa-do",
    "desusar": "de-su-sar",
    "desuso": "de-su-so",
    "desustanciar": "de-sus-tan-ciar",
    "desvahar": "des-va-har",
    "desvaída": "des-va-í-da",
    "desvaído": "des-va-í-do",
    "desvaidura": "des-vai-du-ra",
    "desvainadura": "des-vai-na-du-ra",
    "desvainar": "des-vai-nar",
    "desvaír": "des-va-ír",
    "desvalida": "des-va-li-da",
    "desvalido": "des-va-li-do",
    "desvalijador": "des-va-li-ja-dor",
    "desvalijadora": "des-va-li-ja-do-ra",
    "desvalijamiento": "des-va-li-ja-mien-to",
    "desvalijar": "des-va-li-jar",
    "desvalijo": "des-va-li-jo",
    "desvalimiento": "des-va-li-mien-to",
    "desvalor": "des-va-lor",
    "desvalorar": "des-va-lo-rar",
    "desvalorización": "des-va-lo-ri-za-ción",
    "desvalorizar": "des-va-lo-ri-zar",
    "desván": "des-ván",
    "desvanecedor": "des-va-ne-ce-dor",
    "desvanecedora": "des-va-ne-ce-do-ra",
    "desvanecer": "des-va-ne-cer",
    "desvanecida": "des-va-ne-ci-da",
    "desvanecidamente": "des-va-ne-ci-da-men-te",
    "desvanecido": "des-va-ne-ci-do",
    "desvanecimiento": "des-va-ne-ci-mien-to",
    "desvaporizadero": "des-va-po-ri-za-de-ro",
    "desvarar": "des-va-rar",
    "desvaretar": "des-va-re-tar",
    "desvariada": "des-va-ria-da",
    "desvariadamente": "des-va-ria-da-men-te",
    "desvariado": "des-va-ria-do",
    "desvariamiento": "des-va-ria-mien-to",
    "desvariar": "des-va-riar",
    "desvarío": "des-va-rí-o",
    "desvastigar": "des-vas-ti-gar",
    "desvedar": "des-ve-dar",
    "desvelada": "des-ve-la-da",
    "desveladamente": "des-ve-la-da-men-te",
    "desvelamiento": "des-ve-la-mien-to",
    "desvelar": "des-ve-lar",
    "desvelizar": "des-ve-li-zar",
    "desvelo": "des-ve-lo",
    "desvenar": "des-ve-nar",
    "desvencijar": "des-ven-ci-jar",
    "desvendar": "des-ven-dar",
    "desveno": "des-ve-no",
    "desventaja": "des-ven-ta-ja",
    "desventajosa": "des-ven-ta-jo-sa",
    "desventajoso": "des-ven-ta-jo-so",
    "desventar": "des-ven-tar",
    "desventura": "des-ven-tu-ra",
    "desventurada": "des-ven-tu-ra-da",
    "desventurado": "des-ven-tu-ra-do",
    "desvergonzada": "des-ver-gon-za-da",
    "desvergonzadamente": "des-ver-gon-za-da-men-te",
    "desvergonzado": "des-ver-gon-za-do",
    "desvergonzar": "des-ver-gon-zar",
    "desvergonzarse": "des-ver-gon-zar-se",
    "desvergue": "des-ver-gue",
    "desvergüenza": "des-ver-güen-za",
    "desvestir": "des-ves-tir",
    "desvezar": "des-ve-zar",
    "desviación": "des-via-ción",
    "desviacionismo": "des-via-cio-nis-mo",
    "desviacionista": "des-via-cio-nis-ta",
    "desviador": "des-via-dor",
    "desviadora": "des-via-do-ra",
    "desviamiento": "des-via-mien-to",
    "desviar": "des-viar",
    "desviejadero": "des-vie-ja-de-ro",
    "desviejar": "des-vie-jar",
    "desvinculación": "des-vin-cu-la-ción",
    "desvinculador": "des-vin-cu-la-dor",
    "desvincular": "des-vin-cu-lar",
    "desvío": "des-ví-o",
    "desvirar": "des-vi-rar",
    "desvirgar": "des-vir-gar",
    "desvirtuación": "des-vir-tua-ción",
    "desvirtuar": "des-vir-tuar",
    "desvitalizar": "des-vi-ta-li-zar",
    "desvitrificar": "des-vi-tri-fi-car",
    "desvivir": "des-vi-vir",
    "desvivirse": "des-vi-vir-se",
    "desvolvedor": "des-vol-ve-dor",
    "desvolver": "des-vol-ver",
    "desvuelta": "des-vuel-ta",
    "desvuelto": "des-vuel-to",
    "desyemar": "des-ye-mar",
    "desyerba": "des-yer-ba",
    "desyerbador": "des-yer-ba-dor",
    "desyerbadora": "des-yer-ba-do-ra",
    "desyerbar": "des-yer-bar",
    "desyerbe": "des-yer-be",
    "desyugar": "des-yu-gar",
    "desyuncir": "des-yun-cir",
    "deszafrar": "des-za-frar",
    "deszafre": "des-za-fre",
    "deszocar": "des-zo-car",
    "deszulacar": "des-zu-la-car",
    "deszumar": "des-zu-mar",
    "detal": "de-tal",
    "detallada": "de-ta-lla-da",
    "detalladamente": "de-ta-lla-da-men-te",
    "detallado": "de-ta-lla-do",
    "detallar": "de-ta-llar",
    "detalle": "de-ta-lle",
    "detallismo": "de-ta-llis-mo",
    "detallista": "de-ta-llis-ta",
    "detardamiento": "de-tar-da-mien-to",
    "detardar": "de-tar-dar",
    "detasa": "de-ta-sa",
    "detección": "de-tec-ción",
    "detectable": "de-tec-ta-ble",
    "detectar": "de-tec-tar",
    "detective": "de-tec-ti-ve",
    "detectivesco": "de-tec-ti-ves-co",
    "detector": "de-tec-tor",
    "detención": "de-ten-ción",
    "detenedor": "de-te-ne-dor",
    "detenedora": "de-te-ne-do-ra",
    "detenencia": "de-te-nen-cia",
    "detener": "de-te-ner",
    "detenida": "de-te-ni-da",
    "detenidamente": "de-te-ni-da-men-te",
    "detenido": "de-te-ni-do",
    "detenimiento": "de-te-ni-mien-to",
    "detentación": "de-ten-ta-ción",
    "detentador": "de-ten-ta-dor",
    "detentadora": "de-ten-ta-do-ra",
    "detentar": "de-ten-tar",
    "detente": "de-ten-te",
    "detergente": "de-ter-gen-te",
    "deterger": "de-ter-ger",
    "deterior": "de-te-rior",
    "deterioración": "de-te-rio-ra-ción",
    "deteriorar": "de-te-rio-rar",
    "deterioro": "de-te-rio-ro",
    "determinable": "de-ter-mi-na-ble",
    "determinación": "de-ter-mi-na-ción",
    "determinada": "de-ter-mi-na-da",
    "determinadamente": "de-ter-mi-na-da-men-te",
    "determinado": "de-ter-mi-na-do",
    "determinante": "de-ter-mi-nan-te",
    "determinar": "de-ter-mi-nar",
    "determinativa": "de-ter-mi-na-ti-va",
    "determinativo": "de-ter-mi-na-ti-vo",
    "determinismo": "de-ter-mi-nis-mo",
    "determinista": "de-ter-mi-nis-ta",
    "detersión": "de-ter-sión",
    "detersiva": "de-ter-si-va",
    "detersivo": "de-ter-si-vo",
    "detersoria": "de-ter-so-ria",
    "detersorio": "de-ter-so-rio",
    "detestable": "de-tes-ta-ble",
    "detestación": "de-tes-ta-ción",
    "detestar": "de-tes-tar",
    "detienebuey": "de-tie-ne-buey",
    "detinencia": "de-ti-nen-cia",
    "detonación": "de-to-na-ción",
    "detonador": "de-to-na-dor",
    "detonadora": "de-to-na-do-ra",
    "detonante": "de-to-nan-te",
    "detonar": "de-to-nar",
    "detornar": "de-tor-nar",
    "detorsión": "de-tor-sión",
    "detracción": "de-trac-ción",
    "detractar": "de-trac-tar",
    "detractor": "de-trac-tor",
    "detractora": "de-trac-to-ra",
    "detraedor": "de-tra-e-dor",
    "detraer": "de-tra-er",
    "detraimiento": "de-trai-mien-to",
    "detrás": "de-trás",
    "detrasito": "de-tra-si-to",
    "detrimento": "de-tri-men-to",
    "detrítica": "de-trí-ti-ca",
    "detrítico": "de-trí-ti-co",
    "detrito": "de-tri-to",
    "detritus": "de-tri-tus",
    "deturpación": "de-tur-pa-ción",
    "deturpar": "de-tur-par",
    "deuce": "deu-ce",
    "deuda": "deu-da",
    "deudo": "deu-do",
    "deudor": "deu-dor",
    "deudora": "deu-do-ra",
    "deudosa": "deu-do-sa",
    "deudoso": "deu-do-so",
    "deuteragonista": "deu-te-ra-go-nis-ta",
    "deuterio": "deu-te-rio",
    "deuterón": "deu-te-rón",
    "deutón": "deu-tón",
    "devalar": "de-va-lar",
    "devaluación": "de-va-lua-ción",
    "devaluar": "de-va-luar",
    "devaluatorio": "de-va-lua-to-rio",
    "devanadera": "de-va-na-de-ra",
    "devanado": "de-va-na-do",
    "devanador": "de-va-na-dor",
    "devanadora": "de-va-na-do-ra",
    "devanagari": "de-va-na-ga-ri",
    "devanar": "de-va-nar",
    "devandicha": "de-van-di-cha",
    "devandicho": "de-van-di-cho",
    "devaneador": "de-va-ne-a-dor",
    "devaneadora": "de-va-ne-a-do-ra",
    "devanear": "de-va-ne-ar",
    "devaneo": "de-va-ne-o",
    "devant": "de-vant",
    "devantal": "de-van-tal",
    "devastación": "de-vas-ta-ción",
    "devastador": "de-vas-ta-dor",
    "devastadora": "de-vas-ta-do-ra",
    "devastar": "de-vas-tar",
    "develación": "de-ve-la-ción",
    "develar": "de-ve-lar",
    "develizar": "de-ve-li-zar",
    "devengar": "de-ven-gar",
    "devengo": "de-ven-go",
    "devenir": "de-ve-nir",
    "deverbal": "de-ver-bal",
    "deverbativa": "de-ver-ba-ti-va",
    "deverbativo": "de-ver-ba-ti-vo",
    "deviación": "de-via-ción",
    "deviedo": "de-vie-do",
    "devieso": "de-vie-so",
    "devina": "de-vi-na",
    "devino": "de-vi-no",
    "devinta": "de-vin-ta",
    "devinto": "de-vin-to",
    "devisa": "de-vi-sa",
    "devisar": "de-vi-sar",
    "devisero": "de-vi-se-ro",
    "devoción": "de-vo-ción",
    "devocional": "de-vo-cio-nal",
    "devocionario": "de-vo-cio-na-rio",
    "devodar": "de-vo-dar",
    "devolución": "de-vo-lu-ción",
    "devolutiva": "de-vo-lu-ti-va",
    "devolutivo": "de-vo-lu-ti-vo",
    "devolver": "de-vol-ver",
    "devoniana": "de-vo-nia-na",
    "devoniano": "de-vo-nia-no",
    "devónica": "de-vó-ni-ca",
    "devónico": "de-vó-ni-co",
    "devorador": "de-vo-ra-dor",
    "devoradora": "de-vo-ra-do-ra",
    "devorar": "de-vo-rar",
    "devoraz": "de-vo-raz",
    "devota": "de-vo-ta",
    "devotamente": "de-vo-ta-men-te",
    "devotería": "de-vo-te-rí-a",
    "devoto": "de-vo-to",
    "devover": "de-vo-ver",
    "devuelta": "de-vuel-ta",
    "devuelto": "de-vuel-to",
    "dexiocardia": "de-xio-car-dia",
    "dextrina": "dex-tri-na",
    "dextrismo": "dex-tris-mo",
    "dextro": "dex-tro",
    "dextrógira": "dex-tró-gi-ra",
    "dextrógiro": "dex-tró-gi-ro",
    "dextrorsa": "dex-tror-sa",
    "dextrorso": "dex-tror-so",
    "dextrosa": "dex-tro-sa",
    "deyección": "de-yec-ción",
    "deyecta": "de-yec-ta",
    "deyecto": "de-yec-to",
    "dezmable": "dez-ma-ble",
    "dezmar": "dez-mar",
    "dezmatorio": "dez-ma-to-rio",
    "dezmeña": "dez-me-ña",
    "dezmeño": "dez-me-ño",
    "dezmera": "dez-me-ra",
    "dezmería": "dez-me-rí-a",
    "dezmero": "dez-me-ro",
    "día": "dí-a",
    "diabasa": "dia-ba-sa",
    "diabático": "dia-bá-ti-co",
    "diabetes": "dia-be-tes",
    "diabética": "dia-bé-ti-ca",
    "diabético": "dia-bé-ti-co",
    "diabeto": "dia-be-to",
    "diabetóloga": "dia-be-tó-lo-ga",
    "diabetología": "dia-be-to-lo-gí-a",
    "diabetólogo": "dia-be-tó-lo-go",
    "diabla": "dia-bla",
    "diablada": "dia-bla-da",
    "diablado": "dia-bla-do",
    "diablear": "dia-ble-ar",
    "diablero": "dia-ble-ro",
    "diablesa": "dia-ble-sa",
    "diablesca": "dia-bles-ca",
    "diablesco": "dia-bles-co",
    "diablillo": "dia-bli-llo",
    "diablito": "dia-bli-to",
    "diablo": "dia-blo",
    "diablura": "dia-blu-ra",
    "diabólica": "dia-bó-li-ca",
    "diabólicamente": "dia-bó-li-ca-men-te",
    "diabólico": "dia-bó-li-co",
    "diabolín": "dia-bo-lín",
    "diabolismo": "dia-bo-lis-mo",
    "diábolo": "diá-bo-lo",
    "diacatolicón": "dia-ca-to-li-cón",
    "diacitrón": "dia-ci-trón",
    "diaclasa": "dia-cla-sa",
    "diacodión": "dia-co-dión",
    "diaconado": "dia-co-na-do",
    "diaconal": "dia-co-nal",
    "diaconar": "dia-co-nar",
    "diaconato": "dia-co-na-to",
    "diaconía": "dia-co-ní-a",
    "diaconisa": "dia-co-ni-sa",
    "diácono": "diá-co-no",
    "diacrítica": "dia-crí-ti-ca",
    "diacrítico": "dia-crí-ti-co",
    "diacronía": "dia-cro-ní-a",
    "diacrónico": "dia-cró-ni-co",
    "diacústica": "dia-cús-ti-ca",
    "díada": "dí-a-da",
    "diadelfo": "dia-del-fo",
    "diadelfos": "dia-del-fos",
    "diadema": "dia-de-ma",
    "diademada": "dia-de-ma-da",
    "diademado": "dia-de-ma-do",
    "diádico": "diá-di-co",
    "diado": "dia-do",
    "diádoco": "diá-do-co",
    "diáfana": "diá-fa-na",
    "diafanidad": "dia-fa-ni-dad",
    "diafanizar": "dia-fa-ni-zar",
    "diáfano": "diá-fa-no",
    "diafanómetro": "dia-fa-nó-me-tro",
    "diafásico": "dia-fá-si-co",
    "diáfisis": "diá-fi-sis",
    "diafonía": "dia-fo-ní-a",
    "diaforesis": "dia-fo-re-sis",
    "diaforética": "dia-fo-ré-ti-ca",
    "diaforético": "dia-fo-ré-ti-co",
    "diafragma": "dia-frag-ma",
    "diafragmar": "dia-frag-mar",
    "diafragmática": "dia-frag-má-ti-ca",
    "diafragmático": "dia-frag-má-ti-co",
    "diagénesis": "dia-gé-ne-sis",
    "diagenético": "dia-ge-né-ti-co",
    "diagnosis": "diag-no-sis",
    "diagnóstica": "diag-nós-ti-ca",
    "diagnosticable": "diag-nos-ti-ca-ble",
    "diagnosticar": "diag-nos-ti-car",
    "diagnóstico": "diag-nós-ti-co",
    "diagonal": "dia-go-nal",
    "diagonalmente": "dia-go-nal-men-te",
    "diágrafo": "diá-gra-fo",
    "diagrama": "dia-gra-ma",
    "diagramación": "dia-gra-ma-ción",
    "diagramar": "dia-gra-mar",
    "diaguita": "dia-gui-ta",
    "diálaga": "diá-la-ga",
    "dialectal": "dia-lec-tal",
    "dialectalismo": "dia-lec-ta-lis-mo",
    "dialéctica": "dia-léc-ti-ca",
    "dialéctico": "dia-léc-ti-co",
    "dialecto": "dia-lec-to",
    "dialectóloga": "dia-lec-tó-lo-ga",
    "dialectología": "dia-lec-to-lo-gí-a",
    "dialectológico": "dia-lec-to-ló-gi-co",
    "dialectólogo": "dia-lec-tó-lo-go",
    "dialefa": "dia-le-fa",
    "dialipétala": "dia-li-pé-ta-la",
    "dialipétalo": "dia-li-pé-ta-lo",
    "dialisépala": "dia-li-sé-pa-la",
    "dialisépalo": "dia-li-sé-pa-lo",
    "diálisis": "diá-li-sis",
    "dialítica": "dia-lí-ti-ca",
    "dialítico": "dia-lí-ti-co",
    "dializador": "dia-li-za-dor",
    "dializar": "dia-li-zar",
    "dialogador": "dia-lo-ga-dor",
    "dialogadora": "dia-lo-ga-do-ra",
    "dialogal": "dia-lo-gal",
    "dialogante": "dia-lo-gan-te",
    "dialogar": "dia-lo-gar",
    "dialógico": "dia-ló-gi-co",
    "dialogismo": "dia-lo-gis-mo",
    "dialogística": "dia-lo-gís-ti-ca",
    "dialogístico": "dia-lo-gís-ti-co",
    "dialogizar": "dia-lo-gi-zar",
    "diálogo": "diá-lo-go",
    "dialoguista": "dia-lo-guis-ta",
    "dialtea": "dial-te-a",
    "diamagnético": "dia-mag-né-ti-co",
    "diamantada": "dia-man-ta-da",
    "diamantado": "dia-man-ta-do",
    "diamantar": "dia-man-tar",
    "diamante": "dia-man-te",
    "diamantífero": "dia-man-tí-fe-ro",
    "diamantina": "dia-man-ti-na",
    "diamantino": "dia-man-ti-no",
    "diamantista": "dia-man-tis-ta",
    "diamela": "dia-me-la",
    "diametral": "dia-me-tral",
    "diametralmente": "dia-me-tral-men-te",
    "diamétrica": "dia-mé-tri-ca",
    "diamétrico": "dia-mé-tri-co",
    "diámetro": "diá-me-tro",
    "diana": "dia-na",
    "dianche": "dian-che",
    "diandra": "dian-dra",
    "diandro": "dian-dro",
    "dianense": "dia-nen-se",
    "diaño": "dia-ño",
    "dianto": "dian-to",
    "diantre": "dian-tre",
    "diapalma": "dia-pal-ma",
    "diapasón": "dia-pa-són",
    "diapédesis": "dia-pé-de-sis",
    "diapente": "dia-pen-te",
    "diaporama": "dia-po-ra-ma",
    "diapositiva": "dia-po-si-ti-va",
    "diaprea": "dia-pre-a",
    "diapreada": "dia-pre-a-da",
    "diapreado": "dia-pre-a-do",
    "diaquenio": "dia-que-nio",
    "diaquilón": "dia-qui-lón",
    "diarera": "dia-re-ra",
    "diarero": "dia-re-ro",
    "diaria": "dia-ria",
    "diariamente": "dia-ria-men-te",
    "diariera": "dia-rie-ra",
    "diariero": "dia-rie-ro",
    "diario": "dia-rio",
    "diarismo": "dia-ris-mo",
    "diarista": "dia-ris-ta",
    "diarquía": "diar-quí-a",
    "diarrea": "dia-rre-a",
    "diarreica": "dia-rrei-ca",
    "diarreico": "dia-rrei-co",
    "diartrosis": "diar-tro-sis",
    "diascordio": "dias-cor-dio",
    "diasén": "dia-sén",
    "diáspero": "diás-pe-ro",
    "diáspora": "diás-po-ra",
    "diásporo": "diás-po-ro",
    "diaspro": "dias-pro",
    "diastasa": "dias-ta-sa",
    "diastema": "dias-te-ma",
    "diástilo": "diás-ti-lo",
    "diástole": "diás-to-le",
    "diastólica": "dias-tó-li-ca",
    "diastólico": "dias-tó-li-co",
    "diastrático": "dias-trá-ti-co",
    "diastrofia": "dias-tro-fia",
    "diatérmana": "dia-tér-ma-na",
    "diatérmano": "dia-tér-ma-no",
    "diatermia": "dia-ter-mia",
    "diatérmico": "dia-tér-mi-co",
    "diatesarón": "dia-te-sa-rón",
    "diatésica": "dia-té-si-ca",
    "diatésico": "dia-té-si-co",
    "diátesis": "diá-te-sis",
    "diatomáceo": "dia-to-má-ce-o",
    "diatomea": "dia-to-me-a",
    "diatomita": "dia-to-mi-ta",
    "diatónica": "dia-tó-ni-ca",
    "diatónicamente": "dia-tó-ni-ca-men-te",
    "diatónico": "dia-tó-ni-co",
    "diatonismo": "dia-to-nis-mo",
    "diatópico": "dia-tó-pi-co",
    "diatriba": "dia-tri-ba",
    "diávolo": "diá-vo-lo",
    "diazoar": "dia-zo-ar",
    "diazotar": "dia-zo-tar",
    "dibranquial": "di-bran-quial",
    "dibujador": "di-bu-ja-dor",
    "dibujadora": "di-bu-ja-do-ra",
    "dibujante": "di-bu-jan-te",
    "dibujar": "di-bu-jar",
    "dibujístico": "di-bu-jís-ti-co",
    "dibujo": "di-bu-jo",
    "dicacidad": "di-ca-ci-dad",
    "dicarboxílico": "di-car-bo-xí-li-co",
    "dicasterio": "di-cas-te-rio",
    "dicaz": "di-caz",
    "dicción": "dic-ción",
    "diccionario": "dic-cio-na-rio",
    "diccionarista": "dic-cio-na-ris-ta",
    "dicente": "di-cen-te",
    "díceres": "dí-ce-res",
    "dicha": "di-cha",
    "dicharachera": "di-cha-ra-che-ra",
    "dicharachero": "di-cha-ra-che-ro",
    "dicharacho": "di-cha-ra-cho",
    "dichera": "di-che-ra",
    "dichero": "di-che-ro",
    "dicheya": "di-che-ya",
    "dicho": "di-cho",
    "dichosa": "di-cho-sa",
    "dichosamente": "di-cho-sa-men-te",
    "dichoso": "di-cho-so",
    "diciembre": "di-ciem-bre",
    "diciente": "di-cien-te",
    "dicigótico": "di-ci-gó-ti-co",
    "diciplina": "di-ci-pli-na",
    "diciplinante": "di-ci-pli-nan-te",
    "diciplinar": "di-ci-pli-nar",
    "diclina": "di-cli-na",
    "diclino": "di-cli-no",
    "dicoreo": "di-co-re-o",
    "dicotiledón": "di-co-ti-le-dón",
    "dicotiledónea": "di-co-ti-le-dó-ne-a",
    "dicotiledóneas": "di-co-ti-le-dó-ne-as",
    "dicotiledóneo": "di-co-ti-le-dó-ne-o",
    "dicótoma": "di-có-to-ma",
    "dicotomía": "di-co-to-mí-a",
    "dicotómica": "di-co-tó-mi-ca",
    "dicotómico": "di-co-tó-mi-co",
    "dicótomo": "di-có-to-mo",
    "dicroica": "di-croi-ca",
    "dicroico": "di-croi-co",
    "dicroísmo": "di-cro-ís-mo",
    "dicromática": "di-cro-má-ti-ca",
    "dicromático": "di-cro-má-ti-co",
    "dicromato": "di-cro-ma-to",
    "dictablanda": "dic-ta-blan-da",
    "dictado": "dic-ta-do",
    "dictador": "dic-ta-dor",
    "dictadora": "dic-ta-do-ra",
    "dictadura": "dic-ta-du-ra",
    "dictaduría": "dic-ta-du-rí-a",
    "dictáfono": "dic-tá-fo-no",
    "dictamen": "dic-ta-men",
    "dictaminador": "dic-ta-mi-na-dor",
    "dictaminadora": "dic-ta-mi-na-do-ra",
    "dictaminar": "dic-ta-mi-nar",
    "díctamo": "díc-ta-mo",
    "dictar": "dic-tar",
    "dictatoria": "dic-ta-to-ria",
    "dictatorial": "dic-ta-to-rial",
    "dictatorio": "dic-ta-to-rio",
    "dictatura": "dic-ta-tu-ra",
    "dicterio": "dic-te-rio",
    "díctico": "díc-ti-co",
    "dictióptero": "dic-tióp-te-ro",
    "didáctica": "di-dác-ti-ca",
    "didacticismo": "di-dac-ti-cis-mo",
    "didáctico": "di-dác-ti-co",
    "didáctila": "di-dác-ti-la",
    "didáctilo": "di-dác-ti-lo",
    "didactismo": "di-dac-tis-mo",
    "didascalia": "di-das-ca-lia",
    "didascálica": "di-das-cá-li-ca",
    "didascálico": "di-das-cá-li-co",
    "didelfo": "di-del-fo",
    "dídima": "dí-di-ma",
    "didimeo": "di-di-me-o",
    "didimio": "di-di-mio",
    "dídimo": "dí-di-mo",
    "didracma": "di-drac-ma",
    "diecinueve": "die-ci-nue-ve",
    "diecinueveava": "die-ci-nue-ve-a-va",
    "diecinueveavo": "die-ci-nue-ve-a-vo",
    "dieciochava": "die-cio-cha-va",
    "dieciochavo": "die-cio-cha-vo",
    "dieciochena": "die-cio-che-na",
    "dieciocheno": "die-cio-che-no",
    "dieciochero": "die-cio-che-ro",
    "dieciochesca": "die-cio-ches-ca",
    "dieciochesco": "die-cio-ches-co",
    "dieciochismo": "die-cio-chis-mo",
    "dieciochista": "die-cio-chis-ta",
    "dieciocho": "die-cio-cho",
    "dieciochoavo": "die-cio-cho-a-vo",
    "dieciséis": "die-ci-séis",
    "dieciseisava": "die-ci-sei-sa-va",
    "dieciseisavo": "die-ci-sei-sa-vo",
    "dieciseisena": "die-ci-sei-se-na",
    "dieciseiseno": "die-ci-sei-se-no",
    "diecisiete": "die-ci-sie-te",
    "diecisieteava": "die-ci-sie-te-a-va",
    "diecisieteavo": "die-ci-sie-te-a-vo",
    "diedro": "die-dro",
    "diégesis": "dié-ge-sis",
    "diego": "die-go",
    "dieléctrica": "die-léc-tri-ca",
    "dieléctrico": "die-léc-tri-co",
    "diencéfalo": "dien-cé-fa-lo",
    "dientazo": "dien-ta-zo",
    "diente": "dien-te",
    "dientimellada": "dien-ti-me-lla-da",
    "dientimellado": "dien-ti-me-lla-do",
    "dientón": "dien-tón",
    "dientona": "dien-to-na",
    "dientuda": "dien-tu-da",
    "dientudo": "dien-tu-do",
    "diéresis": "dié-re-sis",
    "diésel": "dié-sel",
    "diesi": "die-si",
    "diesis": "die-sis",
    "diestra": "dies-tra",
    "diestramente": "dies-tra-men-te",
    "diestro": "dies-tro",
    "dieta": "die-ta",
    "dietar": "die-tar",
    "dietario": "die-ta-rio",
    "dietética": "die-té-ti-ca",
    "dietético": "die-té-ti-co",
    "dietista": "die-tis-ta",
    "diezma": "diez-ma",
    "diezmal": "diez-mal",
    "diezmar": "diez-mar",
    "diezmera": "diez-me-ra",
    "diezmero": "diez-me-ro",
    "diezmesina": "diez-me-si-na",
    "diezmesino": "diez-me-si-no",
    "diezmilésima": "diez-mi-lé-si-ma",
    "diezmilésimo": "diez-mi-lé-si-mo",
    "diezmilímetro": "diez-mi-lí-me-tro",
    "diezmillo": "diez-mi-llo",
    "diezmillonésima": "diez-mi-llo-né-si-ma",
    "diezmillonésimo": "diez-mi-llo-né-si-mo",
    "diezmilmillonésima": "diez-mil-mi-llo-né-si-ma",
    "diezmilmillonésimo": "diez-mil-mi-llo-né-si-mo",
    "diezmo": "diez-mo",
    "difamación": "di-fa-ma-ción",
    "difamado": "di-fa-ma-do",
    "difamador": "di-fa-ma-dor",
    "difamadora": "di-fa-ma-do-ra",
    "difamar": "di-fa-mar",
    "difamatoria": "di-fa-ma-to-ria",
    "difamatorio": "di-fa-ma-to-rio",
    "difamia": "di-fa-mia",
    "difarear": "di-fa-re-ar",
    "difarreación": "di-fa-rre-a-ción",
    "diferecer": "di-fe-re-cer",
    "diferencia": "di-fe-ren-cia",
    "diferenciación": "di-fe-ren-cia-ción",
    "diferenciador": "di-fe-ren-cia-dor",
    "diferencial": "di-fe-ren-cial",
    "diferenciar": "di-fe-ren-ciar",
    "diferendo": "di-fe-ren-do",
    "diferente": "di-fe-ren-te",
    "diferentemente": "di-fe-ren-te-men-te",
    "diferido": "di-fe-ri-do",
    "diferir": "di-fe-rir",
    "difícil": "di-fí-cil",
    "difícilmente": "di-fí-cil-men-te",
    "dificultad": "di-fi-cul-tad",
    "dificultador": "di-fi-cul-ta-dor",
    "dificultadora": "di-fi-cul-ta-do-ra",
    "dificultar": "di-fi-cul-tar",
    "dificultosa": "di-fi-cul-to-sa",
    "dificultosamente": "di-fi-cul-to-sa-men-te",
    "dificultoso": "di-fi-cul-to-so",
    "difidencia": "di-fi-den-cia",
    "difidente": "di-fi-den-te",
    "difilo": "di-fi-lo",
    "difinecer": "di-fi-ne-cer",
    "difinición": "di-fi-ni-ción",
    "difinidura": "di-fi-ni-du-ra",
    "difinir": "di-fi-nir",
    "difinitorio": "di-fi-ni-to-rio",
    "difiuciar": "di-fiu-ciar",
    "difluencia": "di-fluen-cia",
    "difluente": "di-fluen-te",
    "difluir": "di-fluir",
    "difracción": "di-frac-ción",
    "difractar": "di-frac-tar",
    "difrangente": "di-fran-gen-te",
    "difteria": "dif-te-ria",
    "diftérica": "dif-té-ri-ca",
    "diftérico": "dif-té-ri-co",
    "difteritis": "dif-te-ri-tis",
    "difugio": "di-fu-gio",
    "difumar": "di-fu-mar",
    "difuminar": "di-fu-mi-nar",
    "difumino": "di-fu-mi-no",
    "difundidor": "di-fun-di-dor",
    "difundidora": "di-fun-di-do-ra",
    "difundir": "di-fun-dir",
    "difunta": "di-fun-ta",
    "difuntear": "di-fun-te-ar",
    "difunto": "di-fun-to",
    "difusa": "di-fu-sa",
    "difusamente": "di-fu-sa-men-te",
    "difusión": "di-fu-sión",
    "difusiva": "di-fu-si-va",
    "difusivo": "di-fu-si-vo",
    "difuso": "di-fu-so",
    "difusor": "di-fu-sor",
    "difusora": "di-fu-so-ra",
    "digamma": "di-gam-ma",
    "digástrico": "di-gás-tri-co",
    "digerible": "di-ge-ri-ble",
    "digerir": "di-ge-rir",
    "digestibilidad": "di-ges-ti-bi-li-dad",
    "digestible": "di-ges-ti-ble",
    "digestión": "di-ges-tión",
    "digestir": "di-ges-tir",
    "digestiva": "di-ges-ti-va",
    "digestivo": "di-ges-ti-vo",
    "digesto": "di-ges-to",
    "digestor": "di-ges-tor",
    "digitación": "di-gi-ta-ción",
    "digitada": "di-gi-ta-da",
    "digitado": "di-gi-ta-do",
    "digitador": "di-gi-ta-dor",
    "digitadora": "di-gi-ta-do-ra",
    "digital": "di-gi-tal",
    "digitalina": "di-gi-ta-li-na",
    "digitalización": "di-gi-ta-li-za-ción",
    "digitalizar": "di-gi-ta-li-zar",
    "digitar": "di-gi-tar",
    "digitiforme": "di-gi-ti-for-me",
    "digitígrada": "di-gi-tí-gra-da",
    "digitígrado": "di-gi-tí-gra-do",
    "dígito": "dí-gi-to",
    "digladiar": "di-gla-diar",
    "diglosia": "di-glo-sia",
    "digna": "dig-na",
    "dignación": "dig-na-ción",
    "dignamente": "dig-na-men-te",
    "dignar": "dig-nar",
    "dignarse": "dig-nar-se",
    "dignataria": "dig-na-ta-ria",
    "dignatario": "dig-na-ta-rio",
    "dignidad": "dig-ni-dad",
    "dignificable": "dig-ni-fi-ca-ble",
    "dignificación": "dig-ni-fi-ca-ción",
    "dignificante": "dig-ni-fi-can-te",
    "dignificar": "dig-ni-fi-car",
    "digno": "dig-no",
    "dígrafo": "dí-gra-fo",
    "digrama": "di-gra-ma",
    "digresión": "di-gre-sión",
    "dihueñe": "di-hue-ñe",
    "dihueñi": "di-hue-ñi",
    "dije": "di-je",
    "dijes": "di-jes",
    "dilaceración": "di-la-ce-ra-ción",
    "dilacerar": "di-la-ce-rar",
    "dilación": "di-la-ción",
    "dilapidación": "di-la-pi-da-ción",
    "dilapidador": "di-la-pi-da-dor",
    "dilapidadora": "di-la-pi-da-do-ra",
    "dilapidar": "di-la-pi-dar",
    "dilatabilidad": "di-la-ta-bi-li-dad",
    "dilatable": "di-la-ta-ble",
    "dilatación": "di-la-ta-ción",
    "dilatada": "di-la-ta-da",
    "dilatadamente": "di-la-ta-da-men-te",
    "dilatado": "di-la-ta-do",
    "dilatador": "di-la-ta-dor",
    "dilatadora": "di-la-ta-do-ra",
    "dilatar": "di-la-tar",
    "dilatativa": "di-la-ta-ti-va",
    "dilatativo": "di-la-ta-ti-vo",
    "dilatometría": "di-la-to-me-trí-a",
    "dilatómetro": "di-la-tó-me-tro",
    "dilatoria": "di-la-to-ria",
    "dilatorio": "di-la-to-rio",
    "dilección": "di-lec-ción",
    "dilecta": "di-lec-ta",
    "dilecto": "di-lec-to",
    "dilema": "di-le-ma",
    "dilemática": "di-le-má-ti-ca",
    "dilemático": "di-le-má-ti-co",
    "dileniácea": "di-le-niá-ce-a",
    "dileniáceo": "di-le-niá-ce-o",
    "diletante": "di-le-tan-te",
    "diletantismo": "di-le-tan-tis-mo",
    "diligencia": "di-li-gen-cia",
    "diligenciamiento": "di-li-gen-cia-mien-to",
    "diligenciar": "di-li-gen-ciar",
    "diligenciero": "di-li-gen-cie-ro",
    "diligente": "di-li-gen-te",
    "diligentemente": "di-li-gen-te-men-te",
    "dilogía": "di-lo-gí-a",
    "dilucidación": "di-lu-ci-da-ción",
    "dilucidador": "di-lu-ci-da-dor",
    "dilucidadora": "di-lu-ci-da-do-ra",
    "dilucidar": "di-lu-ci-dar",
    "dilucidario": "di-lu-ci-da-rio",
    "dilución": "di-lu-ción",
    "dilúculo": "di-lú-cu-lo",
    "diluente": "di-luen-te",
    "diluir": "di-luir",
    "dilusiva": "di-lu-si-va",
    "dilusivo": "di-lu-si-vo",
    "diluvial": "di-lu-vial",
    "diluviana": "di-lu-via-na",
    "diluviano": "di-lu-via-no",
    "diluviar": "di-lu-viar",
    "diluvio": "di-lu-vio",
    "diluyente": "di-lu-yen-te",
    "dimanación": "di-ma-na-ción",
    "dimanar": "di-ma-nar",
    "dimensión": "di-men-sión",
    "dimensional": "di-men-sio-nal",
    "dimensionalidad": "di-men-sio-na-li-dad",
    "dimensionar": "di-men-sio-nar",
    "dímero": "dí-me-ro",
    "dimes": "di-mes",
    "dímetro": "dí-me-tro",
    "dimiario": "di-mia-rio",
    "dimicado": "di-mi-ca-do",
    "dimidiar": "di-mi-diar",
    "dimidor": "di-mi-dor",
    "diminución": "di-mi-nu-ción",
    "diminuecer": "di-mi-nue-cer",
    "diminuir": "di-mi-nuir",
    "diminuta": "di-mi-nu-ta",
    "diminutamente": "di-mi-nu-ta-men-te",
    "diminutiva": "di-mi-nu-ti-va",
    "diminutivamente": "di-mi-nu-ti-va-men-te",
    "diminutivo": "di-mi-nu-ti-vo",
    "diminuto": "di-mi-nu-to",
    "dimir": "di-mir",
    "dimisión": "di-mi-sión",
    "dimisionaria": "di-mi-sio-na-ria",
    "dimisionario": "di-mi-sio-na-rio",
    "dimisorias": "di-mi-so-rias",
    "dimitente": "di-mi-ten-te",
    "dimitir": "di-mi-tir",
    "dimorfa": "di-mor-fa",
    "dimorfismo": "di-mor-fis-mo",
    "dimorfo": "di-mor-fo",
    "dina": "di-na",
    "dinacho": "di-na-cho",
    "dinamarqués": "di-na-mar-qués",
    "dinamarquesa": "di-na-mar-que-sa",
    "dinamia": "di-na-mia",
    "dinámica": "di-ná-mi-ca",
    "dinámicamente": "di-ná-mi-ca-men-te",
    "dinamicidad": "di-na-mi-ci-dad",
    "dinámico": "di-ná-mi-co",
    "dinamismo": "di-na-mis-mo",
    "dinamista": "di-na-mis-ta",
    "dinamita": "di-na-mi-ta",
    "dinamitar": "di-na-mi-tar",
    "dinamitazo": "di-na-mi-ta-zo",
    "dinamitera": "di-na-mi-te-ra",
    "dinamitero": "di-na-mi-te-ro",
    "dinamización": "di-na-mi-za-ción",
    "dinamizador": "di-na-mi-za-dor",
    "dinamizadora": "di-na-mi-za-do-ra",
    "dinamizante": "di-na-mi-zan-te",
    "dinamizar": "di-na-mi-zar",
    "dinamo": "di-na-mo",
    "dinamoeléctrica": "di-na-mo-e-léc-tri-ca",
    "dinamoeléctrico": "di-na-mo-e-léc-tri-co",
    "dinamógeno": "di-na-mó-ge-no",
    "dinamometría": "di-na-mo-me-trí-a",
    "dinamométrica": "di-na-mo-mé-tri-ca",
    "dinamométrico": "di-na-mo-mé-tri-co",
    "dinamómetro": "di-na-mó-me-tro",
    "dinar": "di-nar",
    "diñar": "di-ñar",
    "dinarada": "di-na-ra-da",
    "dinasta": "di-nas-ta",
    "dinastía": "di-nas-tí-a",
    "dinástica": "di-nás-ti-ca",
    "dinástico": "di-nás-ti-co",
    "dinastismo": "di-nas-tis-mo",
    "dinerada": "di-ne-ra-da",
    "dineral": "di-ne-ral",
    "dineralada": "di-ne-ra-la-da",
    "dineraria": "di-ne-ra-ria",
    "dinerario": "di-ne-ra-rio",
    "dinerillo": "di-ne-ri-llo",
    "dinero": "di-ne-ro",
    "dinerosa": "di-ne-ro-sa",
    "dineroso": "di-ne-ro-so",
    "dingo": "din-go",
    "dingolondango": "din-go-lon-dan-go",
    "dingui": "din-gui",
    "dino": "di-no",
    "dinornis": "di-nor-nis",
    "dinosaurio": "di-no-sau-rio",
    "dinoterio": "di-no-te-rio",
    "dintel": "din-tel",
    "dintelar": "din-te-lar",
    "dintorno": "din-tor-no",
    "diocesana": "dio-ce-sa-na",
    "diocesano": "dio-ce-sa-no",
    "diócesi": "dió-ce-si",
    "diócesis": "dió-ce-sis",
    "diodo": "dio-do",
    "dioica": "dioi-ca",
    "dioico": "dioi-co",
    "dionea": "dio-ne-a",
    "dionisia": "dio-ni-sia",
    "dionisíaca": "dio-ni-sí-a-ca",
    "dionisiaca": "dio-ni-sia-ca",
    "dionisíaco": "dio-ni-sí-a-co",
    "dionisiaco": "dio-ni-sia-co",
    "dioptra": "diop-tra",
    "dioptría": "diop-trí-a",
    "dióptrica": "dióp-tri-ca",
    "dióptrico": "dióp-tri-co",
    "diorama": "dio-ra-ma",
    "diorita": "dio-ri-ta",
    "diosa": "dio-sa",
    "dioscórea": "dios-có-re-a",
    "dioscoreácea": "dios-co-re-á-ce-a",
    "dioscoreáceo": "dios-co-re-á-ce-o",
    "dioscóreo": "dios-có-re-o",
    "diosma": "dios-ma",
    "dioso": "dio-so",
    "diostedé": "dios-te-dé",
    "dióxido": "dió-xi-do",
    "dioxina": "dio-xi-na",
    "dipétala": "di-pé-ta-la",
    "dipétalo": "di-pé-ta-lo",
    "diploclamídeo": "di-plo-cla-mí-de-o",
    "diplococo": "di-plo-co-co",
    "diplodoco": "di-plo-do-co",
    "diplodocus": "di-plo-do-cus",
    "diplofase": "di-plo-fa-se",
    "diploide": "di-ploi-de",
    "diploma": "di-plo-ma",
    "diplomacia": "di-plo-ma-cia",
    "diplomada": "di-plo-ma-da",
    "diplomado": "di-plo-ma-do",
    "diplomar": "di-plo-mar",
    "diplomática": "di-plo-má-ti-ca",
    "diplomático": "di-plo-má-ti-co",
    "diplomatista": "di-plo-ma-tis-ta",
    "diplomatura": "di-plo-ma-tu-ra",
    "diplopía": "di-plo-pí-a",
    "diplópodo": "di-pló-po-do",
    "dipnea": "dip-ne-a",
    "dipneo": "dip-ne-o",
    "dipnoo": "dip-no-o",
    "dipodia": "di-po-dia",
    "dipolo": "di-po-lo",
    "dipsacácea": "dip-sa-cá-ce-a",
    "dipsacáceo": "dip-sa-cá-ce-o",
    "dipsácea": "dip-sá-ce-a",
    "dipsáceo": "dip-sá-ce-o",
    "dipsómana": "dip-só-ma-na",
    "dipsomanía": "dip-so-ma-ní-a",
    "dipsomaníaca": "dip-so-ma-ní-a-ca",
    "dipsomaniaca": "dip-so-ma-nia-ca",
    "dipsomaníaco": "dip-so-ma-ní-a-co",
    "dipsomaniaco": "dip-so-ma-nia-co",
    "dipsómano": "dip-só-ma-no",
    "díptero": "díp-te-ro",
    "dipterocarpácea": "dip-te-ro-car-pá-ce-a",
    "dipterocarpáceo": "dip-te-ro-car-pá-ce-o",
    "dipterocárpea": "dip-te-ro-cár-pe-a",
    "dipterocárpeo": "dip-te-ro-cár-pe-o",
    "díptica": "díp-ti-ca",
    "díptico": "díp-ti-co",
    "diptografía": "dip-to-gra-fí-a",
    "diptongación": "dip-ton-ga-ción",
    "diptongar": "dip-ton-gar",
    "diptongo": "dip-ton-go",
    "diputación": "di-pu-ta-ción",
    "diputada": "di-pu-ta-da",
    "diputado": "di-pu-ta-do",
    "diputador": "di-pu-ta-dor",
    "diputadora": "di-pu-ta-do-ra",
    "diputar": "di-pu-tar",
    "dique": "di-que",
    "diquelar": "di-que-lar",
    "dircea": "dir-ce-a",
    "dirceo": "dir-ce-o",
    "dirección": "di-rec-ción",
    "direccional": "di-rec-cio-nal",
    "direccionalidad": "di-rec-cio-na-li-dad",
    "directa": "di-rec-ta",
    "directamente": "di-rec-ta-men-te",
    "directe": "di-rec-te",
    "directiva": "di-rec-ti-va",
    "directivo": "di-rec-ti-vo",
    "directo": "di-rec-to",
    "director": "di-rec-tor",
    "directora": "di-rec-to-ra",
    "directoral": "di-rec-to-ral",
    "directoria": "di-rec-to-ria",
    "directorio": "di-rec-to-rio",
    "directriz": "di-rec-triz",
    "dírham": "dí-rham",
    "dírhem": "dí-rhem",
    "diriambina": "di-riam-bi-na",
    "diriambino": "di-riam-bi-no",
    "dirigencia": "di-ri-gen-cia",
    "dirigente": "di-ri-gen-te",
    "dirigible": "di-ri-gi-ble",
    "dirigir": "di-ri-gir",
    "dirigismo": "di-ri-gis-mo",
    "dirigista": "di-ri-gis-ta",
    "dirimente": "di-ri-men-te",
    "dirimible": "di-ri-mi-ble",
    "dirimir": "di-ri-mir",
    "disacárido": "di-sa-cá-ri-do",
    "disán": "di-sán",
    "disantera": "di-san-te-ra",
    "disantero": "di-san-te-ro",
    "disanto": "di-san-to",
    "disartria": "di-sar-tria",
    "discado": "dis-ca-do",
    "discal": "dis-cal",
    "discantada": "dis-can-ta-da",
    "discantado": "dis-can-ta-do",
    "discantar": "dis-can-tar",
    "discante": "dis-can-te",
    "discapacidad": "dis-ca-pa-ci-dad",
    "discapacitada": "dis-ca-pa-ci-ta-da",
    "discapacitado": "dis-ca-pa-ci-ta-do",
    "discapacitar": "dis-ca-pa-ci-tar",
    "discar": "dis-car",
    "discente": "dis-cen-te",
    "disceptación": "dis-cep-ta-ción",
    "disceptar": "dis-cep-tar",
    "discerner": "dis-cer-ner",
    "discernible": "dis-cer-ni-ble",
    "discernidor": "dis-cer-ni-dor",
    "discernidora": "dis-cer-ni-do-ra",
    "discernimiento": "dis-cer-ni-mien-to",
    "discernir": "dis-cer-nir",
    "disciplina": "dis-ci-pli-na",
    "disciplinable": "dis-ci-pli-na-ble",
    "disciplinada": "dis-ci-pli-na-da",
    "disciplinado": "dis-ci-pli-na-do",
    "disciplinal": "dis-ci-pli-nal",
    "disciplinante": "dis-ci-pli-nan-te",
    "disciplinar": "dis-ci-pli-nar",
    "disciplinaria": "dis-ci-pli-na-ria",
    "disciplinario": "dis-ci-pli-na-rio",
    "disciplinazo": "dis-ci-pli-na-zo",
    "discípula": "dis-cí-pu-la",
    "discipulado": "dis-ci-pu-la-do",
    "discipular": "dis-ci-pu-lar",
    "discípulo": "dis-cí-pu-lo",
    "disco": "dis-co",
    "discóbolo": "dis-có-bo-lo",
    "discófila": "dis-có-fi-la",
    "discófilo": "dis-có-fi-lo",
    "discografía": "dis-co-gra-fí-a",
    "discográfica": "dis-co-grá-fi-ca",
    "discográfico": "dis-co-grá-fi-co",
    "discoidal": "dis-coi-dal",
    "díscola": "dís-co-la",
    "díscolo": "dís-co-lo",
    "discolor": "dis-co-lor",
    "discolora": "dis-co-lo-ra",
    "discoloro": "dis-co-lo-ro",
    "discomóvil": "dis-co-mó-vil",
    "disconforme": "dis-con-for-me",
    "disconformidad": "dis-con-for-mi-dad",
    "discontinua": "dis-con-ti-nua",
    "discontinuación": "dis-con-ti-nua-ción",
    "discontinuar": "dis-con-ti-nuar",
    "discontinuidad": "dis-con-ti-nui-dad",
    "discontinuo": "dis-con-ti-nuo",
    "disconveniencia": "dis-con-ve-nien-cia",
    "disconvenir": "dis-con-ve-nir",
    "discopub": "dis-co-pub",
    "discordancia": "dis-cor-dan-cia",
    "discordante": "dis-cor-dan-te",
    "discordar": "dis-cor-dar",
    "discorde": "dis-cor-de",
    "discordia": "dis-cor-dia",
    "discoteca": "dis-co-te-ca",
    "discotequera": "dis-co-te-que-ra",
    "discotequero": "dis-co-te-que-ro",
    "discrasia": "dis-cra-sia",
    "discreción": "dis-cre-ción",
    "discrecional": "dis-cre-cio-nal",
    "discrecionalidad": "dis-cre-cio-na-li-dad",
    "discrepancia": "dis-cre-pan-cia",
    "discrepante": "dis-cre-pan-te",
    "discrepar": "dis-cre-par",
    "discreta": "dis-cre-ta",
    "discretamente": "dis-cre-ta-men-te",
    "discretear": "dis-cre-te-ar",
    "discreteo": "dis-cre-te-o",
    "discreto": "dis-cre-to",
    "discretorio": "dis-cre-to-rio",
    "discrimen": "dis-cri-men",
    "discriminación": "dis-cri-mi-na-ción",
    "discriminador": "dis-cri-mi-na-dor",
    "discriminante": "dis-cri-mi-nan-te",
    "discriminar": "dis-cri-mi-nar",
    "discriminatorio": "dis-cri-mi-na-to-rio",
    "discromatopsia": "dis-cro-ma-top-sia",
    "discromía": "dis-cro-mí-a",
    "discuento": "dis-cuen-to",
    "disculpa": "dis-cul-pa",
    "disculpable": "dis-cul-pa-ble",
    "disculpación": "dis-cul-pa-ción",
    "disculpadamente": "dis-cul-pa-da-men-te",
    "disculpar": "dis-cul-par",
    "discurrimiento": "dis-cu-rri-mien-to",
    "discurrir": "dis-cu-rrir",
    "discursar": "dis-cur-sar",
    "discurseador": "dis-cur-se-a-dor",
    "discurseadora": "dis-cur-se-a-do-ra",
    "discursear": "dis-cur-se-ar",
    "discurseo": "dis-cur-se-o",
    "discursera": "dis-cur-se-ra",
    "discursero": "dis-cur-se-ro",
    "discursible": "dis-cur-si-ble",
    "discursista": "dis-cur-sis-ta",
    "discursiva": "dis-cur-si-va",
    "discursivo": "dis-cur-si-vo",
    "discurso": "dis-cur-so",
    "discusión": "dis-cu-sión",
    "discusiva": "dis-cu-si-va",
    "discusivo": "dis-cu-si-vo",
    "discutible": "dis-cu-ti-ble",
    "discutidor": "dis-cu-ti-dor",
    "discutidora": "dis-cu-ti-do-ra",
    "discutir": "dis-cu-tir",
    "disecable": "di-se-ca-ble",
    "disecación": "di-se-ca-ción",
    "disecado": "di-se-ca-do",
    "disecador": "di-se-ca-dor",
    "disecadora": "di-se-ca-do-ra",
    "disecar": "di-se-car",
    "disección": "di-sec-ción",
    "diseccionar": "di-sec-cio-nar",
    "disectivo": "di-sec-ti-vo",
    "disector": "di-sec-tor",
    "disectora": "di-sec-to-ra",
    "diseminación": "di-se-mi-na-ción",
    "diseminado": "di-se-mi-na-do",
    "diseminador": "di-se-mi-na-dor",
    "diseminadora": "di-se-mi-na-do-ra",
    "diseminar": "di-se-mi-nar",
    "diseñador": "di-se-ña-dor",
    "diseñadora": "di-se-ña-do-ra",
    "diseñar": "di-se-ñar",
    "diseño": "di-se-ño",
    "disensión": "di-sen-sión",
    "disenso": "di-sen-so",
    "disentería": "di-sen-te-rí-a",
    "disentérica": "di-sen-té-ri-ca",
    "disentérico": "di-sen-té-ri-co",
    "disentimiento": "di-sen-ti-mien-to",
    "disentir": "di-sen-tir",
    "disépala": "di-sé-pa-la",
    "disépalo": "di-sé-pa-lo",
    "diserta": "di-ser-ta",
    "disertación": "di-ser-ta-ción",
    "disertador": "di-ser-ta-dor",
    "disertadora": "di-ser-ta-do-ra",
    "disertante": "di-ser-tan-te",
    "disertar": "di-ser-tar",
    "diserto": "di-ser-to",
    "disestesia": "di-ses-te-sia",
    "disfagia": "dis-fa-gia",
    "disfamación": "dis-fa-ma-ción",
    "disfamador": "dis-fa-ma-dor",
    "disfamadora": "dis-fa-ma-do-ra",
    "disfamar": "dis-fa-mar",
    "disfamatoria": "dis-fa-ma-to-ria",
    "disfamatorio": "dis-fa-ma-to-rio",
    "disfasia": "dis-fa-sia",
    "disfavor": "dis-fa-vor",
    "disfemismo": "dis-fe-mis-mo",
    "disfonía": "dis-fo-ní-a",
    "disformar": "dis-for-mar",
    "disforme": "dis-for-me",
    "disformidad": "dis-for-mi-dad",
    "disfraz": "dis-fraz",
    "disfrazar": "dis-fra-zar",
    "disfrez": "dis-frez",
    "disfrezar": "dis-fre-zar",
    "disfrezarse": "dis-fre-zar-se",
    "disfrutar": "dis-fru-tar",
    "disfrute": "dis-fru-te",
    "disfuerzo": "dis-fuer-zo",
    "disfumar": "dis-fu-mar",
    "disfumino": "dis-fu-mi-no",
    "disfunción": "dis-fun-ción",
    "disfuncional": "dis-fun-cio-nal",
    "disgrafía": "dis-gra-fí-a",
    "disgrafia": "dis-gra-fia",
    "disgregación": "dis-gre-ga-ción",
    "disgregador": "dis-gre-ga-dor",
    "disgregadora": "dis-gre-ga-do-ra",
    "disgregante": "dis-gre-gan-te",
    "disgregar": "dis-gre-gar",
    "disgregativa": "dis-gre-ga-ti-va",
    "disgregativo": "dis-gre-ga-ti-vo",
    "disgresión": "dis-gre-sión",
    "disgustada": "dis-gus-ta-da",
    "disgustadamente": "dis-gus-ta-da-men-te",
    "disgustado": "dis-gus-ta-do",
    "disgustar": "dis-gus-tar",
    "disgusto": "dis-gus-to",
    "disgustosa": "dis-gus-to-sa",
    "disgustoso": "dis-gus-to-so",
    "disidencia": "di-si-den-cia",
    "disidente": "di-si-den-te",
    "disidir": "di-si-dir",
    "disílaba": "di-sí-la-ba",
    "disilábico": "di-si-lá-bi-co",
    "disílabo": "di-sí-la-bo",
    "disímbola": "di-sím-bo-la",
    "disímbolo": "di-sím-bo-lo",
    "disimetría": "di-si-me-trí-a",
    "disimétrica": "di-si-mé-tri-ca",
    "disimétrico": "di-si-mé-tri-co",
    "disímil": "di-sí-mil",
    "disimilación": "di-si-mi-la-ción",
    "disimilar": "di-si-mi-lar",
    "disimilitud": "di-si-mi-li-tud",
    "disimulable": "di-si-mu-la-ble",
    "disimulación": "di-si-mu-la-ción",
    "disimulada": "di-si-mu-la-da",
    "disimuladamente": "di-si-mu-la-da-men-te",
    "disimulado": "di-si-mu-la-do",
    "disimulador": "di-si-mu-la-dor",
    "disimuladora": "di-si-mu-la-do-ra",
    "disimular": "di-si-mu-lar",
    "disimulo": "di-si-mu-lo",
    "disipable": "di-si-pa-ble",
    "disipación": "di-si-pa-ción",
    "disipada": "di-si-pa-da",
    "disipado": "di-si-pa-do",
    "disipador": "di-si-pa-dor",
    "disipadora": "di-si-pa-do-ra",
    "disipar": "di-si-par",
    "dislalia": "dis-la-lia",
    "dislálico": "dis-lá-li-co",
    "dislate": "dis-la-te",
    "dislexia": "dis-le-xia",
    "disléxica": "dis-lé-xi-ca",
    "disléxico": "dis-lé-xi-co",
    "dislocación": "dis-lo-ca-ción",
    "dislocadura": "dis-lo-ca-du-ra",
    "dislocar": "dis-lo-car",
    "disloque": "dis-lo-que",
    "dismembración": "dis-mem-bra-ción",
    "dismenorrea": "dis-me-no-rre-a",
    "disminución": "dis-mi-nu-ción",
    "disminuida": "dis-mi-nui-da",
    "disminuido": "dis-mi-nui-do",
    "disminuir": "dis-mi-nuir",
    "dismnesia": "dism-ne-sia",
    "disnea": "dis-ne-a",
    "disneica": "dis-nei-ca",
    "disneico": "dis-nei-co",
    "disociable": "di-so-cia-ble",
    "disociación": "di-so-cia-ción",
    "disociador": "di-so-cia-dor",
    "disociadora": "di-so-cia-do-ra",
    "disociar": "di-so-ciar",
    "disolubilidad": "di-so-lu-bi-li-dad",
    "disoluble": "di-so-lu-ble",
    "disolución": "di-so-lu-ción",
    "disoluta": "di-so-lu-ta",
    "disolutiva": "di-so-lu-ti-va",
    "disolutivo": "di-so-lu-ti-vo",
    "disoluto": "di-so-lu-to",
    "disolvente": "di-sol-ven-te",
    "disolver": "di-sol-ver",
    "disón": "di-són",
    "dísona": "dí-so-na",
    "disonancia": "di-so-nan-cia",
    "disonante": "di-so-nan-te",
    "disonar": "di-so-nar",
    "dísono": "dí-so-no",
    "disosmia": "di-sos-mia",
    "dispar": "dis-par",
    "disparada": "dis-pa-ra-da",
    "disparadamente": "dis-pa-ra-da-men-te",
    "disparadero": "dis-pa-ra-de-ro",
    "disparado": "dis-pa-ra-do",
    "disparador": "dis-pa-ra-dor",
    "disparadora": "dis-pa-ra-do-ra",
    "disparar": "dis-pa-rar",
    "disparata": "dis-pa-ra-ta",
    "disparatada": "dis-pa-ra-ta-da",
    "disparatadamente": "dis-pa-ra-ta-da-men-te",
    "disparatado": "dis-pa-ra-ta-do",
    "disparatador": "dis-pa-ra-ta-dor",
    "disparatadora": "dis-pa-ra-ta-do-ra",
    "disparatar": "dis-pa-ra-tar",
    "disparate": "dis-pa-ra-te",
    "disparatera": "dis-pa-ra-te-ra",
    "disparatero": "dis-pa-ra-te-ro",
    "disparato": "dis-pa-ra-to",
    "disparatorio": "dis-pa-ra-to-rio",
    "disparcialidad": "dis-par-cia-li-dad",
    "dispareja": "dis-pa-re-ja",
    "disparejo": "dis-pa-re-jo",
    "disparidad": "dis-pa-ri-dad",
    "disparo": "dis-pa-ro",
    "dispendio": "dis-pen-dio",
    "dispendiosa": "dis-pen-dio-sa",
    "dispendioso": "dis-pen-dio-so",
    "dispensa": "dis-pen-sa",
    "dispensabilidad": "dis-pen-sa-bi-li-dad",
    "dispensable": "dis-pen-sa-ble",
    "dispensación": "dis-pen-sa-ción",
    "dispensador": "dis-pen-sa-dor",
    "dispensadora": "dis-pen-sa-do-ra",
    "dispensar": "dis-pen-sar",
    "dispensario": "dis-pen-sa-rio",
    "dispepsia": "dis-pep-sia",
    "dispéptica": "dis-pép-ti-ca",
    "dispéptico": "dis-pép-ti-co",
    "dispersa": "dis-per-sa",
    "dispersante": "dis-per-san-te",
    "dispersar": "dis-per-sar",
    "dispersión": "dis-per-sión",
    "dispersivo": "dis-per-si-vo",
    "disperso": "dis-per-so",
    "dispersor": "dis-per-sor",
    "dispersora": "dis-per-so-ra",
    "dispertador": "dis-per-ta-dor",
    "dispertadora": "dis-per-ta-do-ra",
    "dispertar": "dis-per-tar",
    "dispierta": "dis-pier-ta",
    "dispierto": "dis-pier-to",
    "displacer": "dis-pla-cer",
    "displasia": "dis-pla-sia",
    "displásico": "dis-plá-si-co",
    "displástico": "dis-plás-ti-co",
    "display": "dis-play",
    "displicencia": "dis-pli-cen-cia",
    "displicente": "dis-pli-cen-te",
    "dispondeo": "dis-pon-de-o",
    "disponedor": "dis-po-ne-dor",
    "disponedora": "dis-po-ne-do-ra",
    "disponer": "dis-po-ner",
    "disponibilidad": "dis-po-ni-bi-li-dad",
    "disponible": "dis-po-ni-ble",
    "disposición": "dis-po-si-ción",
    "dispositiva": "dis-po-si-ti-va",
    "dispositivamente": "dis-po-si-ti-va-men-te",
    "dispositivo": "dis-po-si-ti-vo",
    "disprosio": "dis-pro-sio",
    "dispuesta": "dis-pues-ta",
    "dispuesto": "dis-pues-to",
    "disputa": "dis-pu-ta",
    "disputable": "dis-pu-ta-ble",
    "disputación": "dis-pu-ta-ción",
    "disputador": "dis-pu-ta-dor",
    "disputadora": "dis-pu-ta-do-ra",
    "disputar": "dis-pu-tar",
    "disputativamente": "dis-pu-ta-ti-va-men-te",
    "disquera": "dis-que-ra",
    "disquería": "dis-que-rí-a",
    "disquero": "dis-que-ro",
    "disquete": "dis-que-te",
    "disquetera": "dis-que-te-ra",
    "disquisición": "dis-qui-si-ción",
    "disruptivo": "dis-rup-ti-vo",
    "distal": "dis-tal",
    "distanasia": "dis-ta-na-sia",
    "distancia": "dis-tan-cia",
    "distanciación": "dis-tan-cia-ción",
    "distanciador": "dis-tan-cia-dor",
    "distanciamiento": "dis-tan-cia-mien-to",
    "distanciar": "dis-tan-ciar",
    "distante": "dis-tan-te",
    "distantemente": "dis-tan-te-men-te",
    "distar": "dis-tar",
    "distender": "dis-ten-der",
    "distensible": "dis-ten-si-ble",
    "distensión": "dis-ten-sión",
    "distermia": "dis-ter-mia",
    "disterminar": "dis-ter-mi-nar",
    "dística": "dís-ti-ca",
    "dístico": "dís-ti-co",
    "distilación": "dis-ti-la-ción",
    "distilar": "dis-ti-lar",
    "distilatorio": "dis-ti-la-to-rio",
    "distinción": "dis-tin-ción",
    "distingo": "dis-tin-go",
    "distinguible": "dis-tin-gui-ble",
    "distinguida": "dis-tin-gui-da",
    "distinguido": "dis-tin-gui-do",
    "distinguidor": "dis-tin-gui-dor",
    "distinguidora": "dis-tin-gui-do-ra",
    "distinguir": "dis-tin-guir",
    "distinta": "dis-tin-ta",
    "distintiva": "dis-tin-ti-va",
    "distintivo": "dis-tin-ti-vo",
    "distinto": "dis-tin-to",
    "distocia": "dis-to-cia",
    "distócica": "dis-tó-ci-ca",
    "distócico": "dis-tó-ci-co",
    "dístomo": "dís-to-mo",
    "distonía": "dis-to-ní-a",
    "distorsión": "dis-tor-sión",
    "distorsionador": "dis-tor-sio-na-dor",
    "distorsionadora": "dis-tor-sio-na-do-ra",
    "distorsionar": "dis-tor-sio-nar",
    "distracción": "dis-trac-ción",
    "distraer": "dis-tra-er",
    "distraída": "dis-tra-í-da",
    "distraído": "dis-tra-í-do",
    "distraimiento": "dis-trai-mien-to",
    "distribución": "dis-tri-bu-ción",
    "distribucionalismo": "dis-tri-bu-cio-na-lis-mo",
    "distribucionalista": "dis-tri-bu-cio-na-lis-ta",
    "distribuidor": "dis-tri-bui-dor",
    "distribuidora": "dis-tri-bui-do-ra",
    "distribuir": "dis-tri-buir",
    "distributiva": "dis-tri-bu-ti-va",
    "distributivo": "dis-tri-bu-ti-vo",
    "distributor": "dis-tri-bu-tor",
    "distributora": "dis-tri-bu-to-ra",
    "distrito": "dis-tri-to",
    "distrofia": "dis-tro-fia",
    "distrófico": "dis-tró-fi-co",
    "disturbar": "dis-tur-bar",
    "disturbio": "dis-tur-bio",
    "disuadir": "di-sua-dir",
    "disuasión": "di-sua-sión",
    "disuasiva": "di-sua-si-va",
    "disuasivo": "di-sua-si-vo",
    "disuasor": "di-sua-sor",
    "disuasorio": "di-sua-so-rio",
    "disuelta": "di-suel-ta",
    "disuelto": "di-suel-to",
    "disuria": "di-su-ria",
    "disúrica": "di-sú-ri-ca",
    "disúrico": "di-sú-ri-co",
    "disyunción": "dis-yun-ción",
    "disyunta": "dis-yun-ta",
    "disyuntiva": "dis-yun-ti-va",
    "disyuntivamente": "dis-yun-ti-va-men-te",
    "disyuntivo": "dis-yun-ti-vo",
    "disyunto": "dis-yun-to",
    "disyuntor": "dis-yun-tor",
    "dita": "di-ta",
    "ditá": "di-tá",
    "ditado": "di-ta-do",
    "ditaína": "di-ta-í-na",
    "diteísmo": "di-te-ís-mo",
    "diteísta": "di-te-ís-ta",
    "ditera": "di-te-ra",
    "ditero": "di-te-ro",
    "ditirámbica": "di-ti-rám-bi-ca",
    "ditirámbico": "di-ti-rám-bi-co",
    "ditirambo": "di-ti-ram-bo",
    "dítono": "dí-to-no",
    "diuca": "diu-ca",
    "diucón": "diu-cón",
    "diuresis": "diu-re-sis",
    "diurética": "diu-ré-ti-ca",
    "diurético": "diu-ré-ti-co",
    "diurna": "diur-na",
    "diurno": "diur-no",
    "diuturna": "diu-tur-na",
    "diuturnidad": "diu-tur-ni-dad",
    "diuturno": "diu-tur-no",
    "diva": "di-va",
    "divagación": "di-va-ga-ción",
    "divagador": "di-va-ga-dor",
    "divagadora": "di-va-ga-do-ra",
    "divagar": "di-va-gar",
    "divalente": "di-va-len-te",
    "diván": "di-ván",
    "divergencia": "di-ver-gen-cia",
    "divergente": "di-ver-gen-te",
    "divergir": "di-ver-gir",
    "diversa": "di-ver-sa",
    "diversamente": "di-ver-sa-men-te",
    "diversidad": "di-ver-si-dad",
    "diversificación": "di-ver-si-fi-ca-ción",
    "diversificar": "di-ver-si-fi-car",
    "diversiforme": "di-ver-si-for-me",
    "diversión": "di-ver-sión",
    "diversiva": "di-ver-si-va",
    "diversivo": "di-ver-si-vo",
    "diverso": "di-ver-so",
    "diversorio": "di-ver-so-rio",
    "divertículo": "di-ver-tí-cu-lo",
    "divertida": "di-ver-ti-da",
    "divertido": "di-ver-ti-do",
    "divertimento": "di-ver-ti-men-to",
    "divertimiento": "di-ver-ti-mien-to",
    "divertir": "di-ver-tir",
    "dividendo": "di-vi-den-do",
    "divididera": "di-vi-di-de-ra",
    "divididero": "di-vi-di-de-ro",
    "dividir": "di-vi-dir",
    "dividivi": "di-vi-di-vi",
    "divierta": "di-vier-ta",
    "divieso": "di-vie-so",
    "divina": "di-vi-na",
    "divinación": "di-vi-na-ción",
    "divinador": "di-vi-na-dor",
    "divinadora": "di-vi-na-do-ra",
    "divinal": "di-vi-nal",
    "divinamente": "di-vi-na-men-te",
    "divinar": "di-vi-nar",
    "divinatoria": "di-vi-na-to-ria",
    "divinatorio": "di-vi-na-to-rio",
    "divinidad": "di-vi-ni-dad",
    "divinización": "di-vi-ni-za-ción",
    "divinizar": "di-vi-ni-zar",
    "divino": "di-vi-no",
    "divisa": "di-vi-sa",
    "divisable": "di-vi-sa-ble",
    "divisadero": "di-vi-sa-de-ro",
    "divisar": "di-vi-sar",
    "divisibilidad": "di-vi-si-bi-li-dad",
    "divisible": "di-vi-si-ble",
    "división": "di-vi-sión",
    "divisional": "di-vi-sio-nal",
    "divisionaria": "di-vi-sio-na-ria",
    "divisionario": "di-vi-sio-na-rio",
    "divisionismo": "di-vi-sio-nis-mo",
    "divisionista": "di-vi-sio-nis-ta",
    "divisiva": "di-vi-si-va",
    "divisivo": "di-vi-si-vo",
    "divismo": "di-vis-mo",
    "divisor": "di-vi-sor",
    "divisora": "di-vi-so-ra",
    "divisoria": "di-vi-so-ria",
    "divisorio": "di-vi-so-rio",
    "divo": "di-vo",
    "divorciada": "di-vor-cia-da",
    "divorciado": "di-vor-cia-do",
    "divorciar": "di-vor-ciar",
    "divorcio": "di-vor-cio",
    "divulgable": "di-vul-ga-ble",
    "divulgación": "di-vul-ga-ción",
    "divulgador": "di-vul-ga-dor",
    "divulgadora": "di-vul-ga-do-ra",
    "divulgar": "di-vul-gar",
    "divulgativo": "di-vul-ga-ti-vo",
    "dixie": "di-xie",
    "diyámbica": "di-yám-bi-ca",
    "diyámbico": "di-yám-bi-co",
    "diyambo": "di-yam-bo",
    "dizigótico": "di-zi-gó-ti-co",
    "dizque": "diz-que",
    "dóberman": "dó-ber-man",
    "dobermann": "do-ber-mann",
    "dobla": "do-bla",
    "doblada": "do-bla-da",
    "dobladamente": "do-bla-da-men-te",
    "dobladilla": "do-bla-di-lla",
    "dobladillar": "do-bla-di-llar",
    "dobladillo": "do-bla-di-llo",
    "doblado": "do-bla-do",
    "doblador": "do-bla-dor",
    "dobladora": "do-bla-do-ra",
    "dobladura": "do-bla-du-ra",
    "doblaje": "do-bla-je",
    "doblamiento": "do-bla-mien-to",
    "doblar": "do-blar",
    "doble": "do-ble",
    "doblegable": "do-ble-ga-ble",
    "doblegadiza": "do-ble-ga-di-za",
    "doblegadizo": "do-ble-ga-di-zo",
    "doblegadura": "do-ble-ga-du-ra",
    "doblegamiento": "do-ble-ga-mien-to",
    "doblegar": "do-ble-gar",
    "doblemente": "do-ble-men-te",
    "doblería": "do-ble-rí-a",
    "doblero": "do-ble-ro",
    "doblescudo": "do-bles-cu-do",
    "doblete": "do-ble-te",
    "doblez": "do-blez",
    "doblilla": "do-bli-lla",
    "doblo": "do-blo",
    "doblón": "do-blón",
    "doblonada": "do-blo-na-da",
    "doca": "do-ca",
    "doce": "do-ce",
    "doceañista": "do-ce-a-ñis-ta",
    "doceavo": "do-ce-a-vo",
    "docemesino": "do-ce-me-si-no",
    "docena": "do-ce-na",
    "docenal": "do-ce-nal",
    "doceñal": "do-ce-ñal",
    "docenaria": "do-ce-na-ria",
    "docenario": "do-ce-na-rio",
    "docencia": "do-cen-cia",
    "doceno": "do-ce-no",
    "docente": "do-cen-te",
    "doceta": "do-ce-ta",
    "docético": "do-cé-ti-co",
    "docetismo": "do-ce-tis-mo",
    "docible": "do-ci-ble",
    "docientas": "do-cien-tas",
    "docientos": "do-cien-tos",
    "dócil": "dó-cil",
    "docilidad": "do-ci-li-dad",
    "docilitar": "do-ci-li-tar",
    "dócilmente": "dó-cil-men-te",
    "docimasia": "do-ci-ma-sia",
    "docimástica": "do-ci-más-ti-ca",
    "docimástico": "do-ci-más-ti-co",
    "docta": "doc-ta",
    "doctamente": "doc-ta-men-te",
    "doctitud": "doc-ti-tud",
    "docto": "doc-to",
    "doctor": "doc-tor",
    "doctora": "doc-to-ra",
    "doctorado": "doc-to-ra-do",
    "doctoral": "doc-to-ral",
    "doctoramiento": "doc-to-ra-mien-to",
    "doctoranda": "doc-to-ran-da",
    "doctorando": "doc-to-ran-do",
    "doctorar": "doc-to-rar",
    "doctrina": "doc-tri-na",
    "doctrinable": "doc-tri-na-ble",
    "doctrinador": "doc-tri-na-dor",
    "doctrinadora": "doc-tri-na-do-ra",
    "doctrinal": "doc-tri-nal",
    "doctrinanza": "doc-tri-nan-za",
    "doctrinar": "doc-tri-nar",
    "doctrinaria": "doc-tri-na-ria",
    "doctrinario": "doc-tri-na-rio",
    "doctrinarismo": "doc-tri-na-ris-mo",
    "doctrinero": "doc-tri-ne-ro",
    "doctrino": "doc-tri-no",
    "docudrama": "do-cu-dra-ma",
    "documentación": "do-cu-men-ta-ción",
    "documentada": "do-cu-men-ta-da",
    "documentado": "do-cu-men-ta-do",
    "documental": "do-cu-men-tal",
    "documentalismo": "do-cu-men-ta-lis-mo",
    "documentalista": "do-cu-men-ta-lis-ta",
    "documentar": "do-cu-men-tar",
    "documentario": "do-cu-men-ta-rio",
    "documento": "do-cu-men-to",
    "dodecaedro": "do-de-ca-e-dro",
    "dodecafonía": "do-de-ca-fo-ní-a",
    "dodecafónico": "do-de-ca-fó-ni-co",
    "dodecafonismo": "do-de-ca-fo-nis-mo",
    "dodecágona": "do-de-cá-go-na",
    "dodecágono": "do-de-cá-go-no",
    "dodecasílaba": "do-de-ca-sí-la-ba",
    "dodecasílabo": "do-de-ca-sí-la-bo",
    "dodo": "do-do",
    "dodrante": "do-dran-te",
    "doga": "do-ga",
    "dogal": "do-gal",
    "dogaresa": "do-ga-re-sa",
    "dogma": "dog-ma",
    "dogmática": "dog-má-ti-ca",
    "dogmáticamente": "dog-má-ti-ca-men-te",
    "dogmático": "dog-má-ti-co",
    "dogmatismo": "dog-ma-tis-mo",
    "dogmatista": "dog-ma-tis-ta",
    "dogmatizador": "dog-ma-ti-za-dor",
    "dogmatizante": "dog-ma-ti-zan-te",
    "dogmatizar": "dog-ma-ti-zar",
    "dogo": "do-go",
    "dogón": "do-gón",
    "dogre": "do-gre",
    "dola": "do-la",
    "dolada": "do-la-da",
    "doladera": "do-la-de-ra",
    "dolado": "do-la-do",
    "dolador": "do-la-dor",
    "doladora": "do-la-do-ra",
    "doladura": "do-la-du-ra",
    "dolaje": "do-la-je",
    "dolama": "do-la-ma",
    "dolame": "do-la-me",
    "dolar": "do-lar",
    "dólar": "dó-lar",
    "dolarización": "do-la-ri-za-ción",
    "dolarizar": "do-la-ri-zar",
    "dolencia": "do-len-cia",
    "doler": "do-ler",
    "dolerita": "do-le-ri-ta",
    "dolicocéfala": "do-li-co-cé-fa-la",
    "dolicocefalia": "do-li-co-ce-fa-lia",
    "dolicocéfalo": "do-li-co-cé-fa-lo",
    "dolida": "do-li-da",
    "dolido": "do-li-do",
    "doliente": "do-lien-te",
    "dolina": "do-li-na",
    "dóllimo": "dó-lli-mo",
    "dolmán": "dol-mán",
    "dolmen": "dol-men",
    "dolménica": "dol-mé-ni-ca",
    "dolménico": "dol-mé-ni-co",
    "dolo": "do-lo",
    "dolobre": "do-lo-bre",
    "dolomía": "do-lo-mí-a",
    "dolomita": "do-lo-mi-ta",
    "dolomítica": "do-lo-mí-ti-ca",
    "dolomítico": "do-lo-mí-ti-co",
    "dólope": "dó-lo-pe",
    "dolor": "do-lor",
    "dolora": "do-lo-ra",
    "dolorida": "do-lo-ri-da",
    "dolorido": "do-lo-ri-do",
    "dolorimiento": "do-lo-ri-mien-to",
    "doloriosa": "do-lo-rio-sa",
    "dolorioso": "do-lo-rio-so",
    "dolorosa": "do-lo-ro-sa",
    "dolorosamente": "do-lo-ro-sa-men-te",
    "doloroso": "do-lo-ro-so",
    "dolosa": "do-lo-sa",
    "dolosamente": "do-lo-sa-men-te",
    "doloso": "do-lo-so",
    "doma": "do-ma",
    "domable": "do-ma-ble",
    "domada": "do-ma-da",
    "domador": "do-ma-dor",
    "domadora": "do-ma-do-ra",
    "domadura": "do-ma-du-ra",
    "domanio": "do-ma-nio",
    "domar": "do-mar",
    "dombenitense": "dom-be-ni-ten-se",
    "dombo": "dom-bo",
    "domeñable": "do-me-ña-ble",
    "domeñar": "do-me-ñar",
    "doméstica": "do-més-ti-ca",
    "domesticable": "do-mes-ti-ca-ble",
    "domesticación": "do-mes-ti-ca-ción",
    "domesticado": "do-mes-ti-ca-do",
    "domésticamente": "do-més-ti-ca-men-te",
    "domesticar": "do-mes-ti-car",
    "domesticidad": "do-mes-ti-ci-dad",
    "doméstico": "do-més-ti-co",
    "domestiquez": "do-mes-ti-quez",
    "domestiqueza": "do-mes-ti-que-za",
    "domiciliación": "do-mi-ci-lia-ción",
    "domiciliar": "do-mi-ci-liar",
    "domiciliaria": "do-mi-ci-lia-ria",
    "domiciliario": "do-mi-ci-lia-rio",
    "domicilio": "do-mi-ci-lio",
    "dominación": "do-mi-na-ción",
    "dominador": "do-mi-na-dor",
    "dominadora": "do-mi-na-do-ra",
    "dominancia": "do-mi-nan-cia",
    "dominante": "do-mi-nan-te",
    "dominar": "do-mi-nar",
    "dominativa": "do-mi-na-ti-va",
    "dominativo": "do-mi-na-ti-vo",
    "dominatriz": "do-mi-na-triz",
    "dómine": "dó-mi-ne",
    "domingada": "do-min-ga-da",
    "domingas": "do-min-gas",
    "domingo": "do-min-go",
    "dominguejo": "do-min-gue-jo",
    "dominguera": "do-min-gue-ra",
    "dominguero": "do-min-gue-ro",
    "dominguillo": "do-min-gui-llo",
    "dominica": "do-mi-ni-ca",
    "domínica": "do-mí-ni-ca",
    "dominical": "do-mi-ni-cal",
    "dominicana": "do-mi-ni-ca-na",
    "dominicanismo": "do-mi-ni-ca-nis-mo",
    "dominicano": "do-mi-ni-ca-no",
    "dominico": "do-mi-ni-co",
    "domínico": "do-mí-ni-co",
    "dominio": "do-mi-nio",
    "dominiqués": "do-mi-ni-qués",
    "dominiquesa": "do-mi-ni-que-sa",
    "dominó": "do-mi-nó",
    "dómino": "dó-mi-no",
    "domo": "do-mo",
    "domótica": "do-mó-ti-ca",
    "domótico": "do-mó-ti-co",
    "dompedro": "dom-pe-dro",
    "dona": "do-na",
    "doña": "do-ña",
    "donación": "do-na-ción",
    "donada": "do-na-da",
    "donadío": "do-na-dí-o",
    "donado": "do-na-do",
    "donador": "do-na-dor",
    "donadora": "do-na-do-ra",
    "doñaguil": "do-ña-guil",
    "donaire": "do-nai-re",
    "donairosa": "do-nai-ro-sa",
    "donairoso": "do-nai-ro-so",
    "donante": "do-nan-te",
    "donar": "do-nar",
    "donataria": "do-na-ta-ria",
    "donatario": "do-na-ta-rio",
    "donatismo": "do-na-tis-mo",
    "donatista": "do-na-tis-ta",
    "donativo": "do-na-ti-vo",
    "doncel": "don-cel",
    "doncella": "don-ce-lla",
    "doncellería": "don-ce-lle-rí-a",
    "doncellez": "don-ce-llez",
    "doncellil": "don-ce-llil",
    "doncello": "don-ce-llo",
    "doncellueca": "don-ce-llue-ca",
    "donde": "don-de",
    "dónde": "dón-de",
    "dondequiera": "don-de-quie-ra",
    "dondiego": "don-die-go",
    "doneador": "do-ne-a-dor",
    "doñeador": "do-ñe-a-dor",
    "donear": "do-ne-ar",
    "doñear": "do-ñe-ar",
    "doñegal": "do-ñe-gal",
    "doñeguil": "do-ñe-guil",
    "doneo": "do-ne-o",
    "donfrón": "don-frón",
    "donguindo": "don-guin-do",
    "doñigal": "do-ñi-gal",
    "donillero": "do-ni-lle-ro",
    "donjuán": "don-juán",
    "donjuanear": "don-jua-ne-ar",
    "donjuanesca": "don-jua-nes-ca",
    "donjuanesco": "don-jua-nes-co",
    "donjuanismo": "don-jua-nis-mo",
    "donosa": "do-no-sa",
    "donosidad": "do-no-si-dad",
    "donosilla": "do-no-si-lla",
    "donoso": "do-no-so",
    "donostiarra": "do-nos-tia-rra",
    "donosura": "do-no-su-ra",
    "donquijotesco": "don-qui-jo-tes-co",
    "donut": "do-nut",
    "dopa": "do-pa",
    "dopado": "do-pa-do",
    "dopaje": "do-pa-je",
    "dopamina": "do-pa-mi-na",
    "dopante": "do-pan-te",
    "dopar": "do-par",
    "doping": "do-ping",
    "doquier": "do-quier",
    "doquiera": "do-quie-ra",
    "doquiere": "do-quie-re",
    "dorace": "do-ra-ce",
    "dorada": "do-ra-da",
    "doradilla": "do-ra-di-lla",
    "doradillo": "do-ra-di-llo",
    "dorado": "do-ra-do",
    "dorador": "do-ra-dor",
    "doradora": "do-ra-do-ra",
    "doradura": "do-ra-du-ra",
    "doral": "do-ral",
    "dorar": "do-rar",
    "doria": "do-ria",
    "dórica": "dó-ri-ca",
    "dórico": "dó-ri-co",
    "dorio": "do-rio",
    "dormán": "dor-mán",
    "dormición": "dor-mi-ción",
    "dormida": "dor-mi-da",
    "dormidera": "dor-mi-de-ra",
    "dormidero": "dor-mi-de-ro",
    "dormido": "dor-mi-do",
    "dormidor": "dor-mi-dor",
    "dormidora": "dor-mi-do-ra",
    "dormiente": "dor-mien-te",
    "dormijosa": "dor-mi-jo-sa",
    "dormijoso": "dor-mi-jo-so",
    "dormilón": "dor-mi-lón",
    "dormilona": "dor-mi-lo-na",
    "dormir": "dor-mir",
    "dormirlas": "dor-mir-las",
    "dormitación": "dor-mi-ta-ción",
    "dormitar": "dor-mi-tar",
    "dormitiva": "dor-mi-ti-va",
    "dormitivo": "dor-mi-ti-vo",
    "dormitorio": "dor-mi-to-rio",
    "dormivela": "dor-mi-ve-la",
    "dorna": "dor-na",
    "dornajo": "dor-na-jo",
    "dornillero": "dor-ni-lle-ro",
    "dornillo": "dor-ni-llo",
    "dorondón": "do-ron-dón",
    "dorsal": "dor-sal",
    "dorso": "dor-so",
    "dorsoventral": "dor-so-ven-tral",
    "dosalba": "do-sal-ba",
    "dosalbo": "do-sal-bo",
    "dosañal": "do-sa-ñal",
    "doscientas": "dos-cien-tas",
    "doscientos": "dos-cien-tos",
    "dosel": "do-sel",
    "doselera": "do-se-le-ra",
    "doselete": "do-se-le-te",
    "dosificable": "do-si-fi-ca-ble",
    "dosificación": "do-si-fi-ca-ción",
    "dosificador": "do-si-fi-ca-dor",
    "dosificar": "do-si-fi-car",
    "dosillo": "do-si-llo",
    "dosimetría": "do-si-me-trí-a",
    "dosimétrica": "do-si-mé-tri-ca",
    "dosimétrico": "do-si-mé-tri-co",
    "dosímetro": "do-sí-me-tro",
    "dosis": "do-sis",
    "dossier": "dos-sier",
    "dotación": "do-ta-ción",
    "dotado": "do-ta-do",
    "dotador": "do-ta-dor",
    "dotadora": "do-ta-do-ra",
    "dotal": "do-tal",
    "dotar": "do-tar",
    "dote": "do-te",
    "dotor": "do-tor",
    "dotrina": "do-tri-na",
    "dotrinar": "do-tri-nar",
    "dotrinero": "do-tri-ne-ro",
    "dovela": "do-ve-la",
    "dovelaje": "do-ve-la-je",
    "dovelar": "do-ve-lar",
    "doxología": "do-xo-lo-gí-a",
    "dozava": "do-za-va",
    "dozavada": "do-za-va-da",
    "dozavado": "do-za-va-do",
    "dozavo": "do-za-vo",
    "draba": "dra-ba",
    "dracaena": "dra-ca-e-na",
    "dracma": "drac-ma",
    "draconiana": "dra-co-nia-na",
    "draconiano": "dra-co-nia-no",
    "draga": "dra-ga",
    "dragado": "dra-ga-do",
    "dragaminas": "dra-ga-mi-nas",
    "dragante": "dra-gan-te",
    "dragar": "dra-gar",
    "dragea": "dra-ge-a",
    "drago": "dra-go",
    "dragomán": "dra-go-mán",
    "dragón": "dra-gón",
    "dragona": "dra-go-na",
    "dragoncillo": "dra-gon-ci-llo",
    "dragonear": "dra-go-ne-ar",
    "dragoneo": "dra-go-ne-o",
    "dragonete": "dra-go-ne-te",
    "dragonites": "dra-go-ni-tes",
    "dragontea": "dra-gon-te-a",
    "dragontina": "dra-gon-ti-na",
    "dragontino": "dra-gon-ti-no",
    "dragster": "drags-ter",
    "drakar": "dra-kar",
    "dralón": "dra-lón",
    "drama": "dra-ma",
    "dramática": "dra-má-ti-ca",
    "dramáticamente": "dra-má-ti-ca-men-te",
    "dramaticidad": "dra-ma-ti-ci-dad",
    "dramático": "dra-má-ti-co",
    "dramatismo": "dra-ma-tis-mo",
    "dramatizable": "dra-ma-ti-za-ble",
    "dramatización": "dra-ma-ti-za-ción",
    "dramatizar": "dra-ma-ti-zar",
    "dramaturga": "dra-ma-tur-ga",
    "dramaturgia": "dra-ma-tur-gia",
    "dramatúrgico": "dra-ma-túr-gi-co",
    "dramaturgista": "dra-ma-tur-gis-ta",
    "dramaturgo": "dra-ma-tur-go",
    "dramón": "dra-món",
    "drapeado": "dra-pe-a-do",
    "drapear": "dra-pe-ar",
    "drapero": "dra-pe-ro",
    "draque": "dra-que",
    "drástica": "drás-ti-ca",
    "drástico": "drás-ti-co",
    "dravidiano": "dra-vi-dia-no",
    "dravídica": "dra-ví-di-ca",
    "dravídico": "dra-ví-di-co",
    "drea": "dre-a",
    "drenaje": "dre-na-je",
    "drenar": "dre-nar",
    "drepanocitosis": "dre-pa-no-ci-to-sis",
    "dría": "drí-a",
    "dríada": "drí-a-da",
    "dríade": "drí-a-de",
    "dribbling": "drib-bling",
    "driblar": "dri-blar",
    "driblear": "dri-ble-ar",
    "dribling": "dri-bling",
    "drino": "dri-no",
    "drive": "dri-ve",
    "driver": "dri-ver",
    "driza": "dri-za",
    "droga": "dro-ga",
    "drogada": "dro-ga-da",
    "drogadicción": "dro-ga-dic-ción",
    "drogadicta": "dro-ga-dic-ta",
    "drogadicto": "dro-ga-dic-to",
    "drogado": "dro-ga-do",
    "drogar": "dro-gar",
    "drogata": "dro-ga-ta",
    "drogmán": "drog-mán",
    "drogodependencia": "dro-go-de-pen-den-cia",
    "drogodependiente": "dro-go-de-pen-dien-te",
    "drogota": "dro-go-ta",
    "droguera": "dro-gue-ra",
    "droguería": "dro-gue-rí-a",
    "droguero": "dro-gue-ro",
    "droguete": "dro-gue-te",
    "droguista": "dro-guis-ta",
    "dromedal": "dro-me-dal",
    "dromedario": "dro-me-da-rio",
    "dromomanía": "dro-mo-ma-ní-a",
    "dromomaníaco": "dro-mo-ma-ní-a-co",
    "dropacismo": "dro-pa-cis-mo",
    "dropar": "dro-par",
    "drope": "dro-pe",
    "drosera": "dro-se-ra",
    "droserácea": "dro-se-rá-ce-a",
    "droseráceo": "dro-se-rá-ce-o",
    "drosómetro": "dro-só-me-tro",
    "drugstore": "drugs-to-re",
    "druida": "drui-da",
    "druídica": "druí-di-ca",
    "druídico": "druí-di-co",
    "druidismo": "drui-dis-mo",
    "drupa": "dru-pa",
    "drupácea": "dru-pá-ce-a",
    "drupáceo": "dru-pá-ce-o",
    "drusa": "dru-sa",
    "druso": "dru-so",
    "dúa": "dú-a",
    "dualidad": "dua-li-dad",
    "dualismo": "dua-lis-mo",
    "dualista": "dua-lis-ta",
    "dualística": "dua-lís-ti-ca",
    "dualístico": "dua-lís-ti-co",
    "duarte": "duar-te",
    "duba": "du-ba",
    "dubda": "dub-da",
    "dubio": "du-bio",
    "dubitable": "du-bi-ta-ble",
    "dubitación": "du-bi-ta-ción",
    "dubitante": "du-bi-tan-te",
    "dubitativa": "du-bi-ta-ti-va",
    "dubitativo": "du-bi-ta-ti-vo",
    "dubles": "du-bles",
    "dublinés": "du-bli-nés",
    "dublinesa": "du-bli-ne-sa",
    "dubnio": "dub-nio",
    "ducado": "du-ca-do",
    "ducal": "du-cal",
    "ducas": "du-cas",
    "ducentésima": "du-cen-té-si-ma",
    "ducentésimo": "du-cen-té-si-mo",
    "ducha": "du-cha",
    "duchar": "du-char",
    "duchazo": "du-cha-zo",
    "duchero": "du-che-ro",
    "ducho": "du-cho",
    "ducientos": "du-cien-tos",
    "duco": "du-co",
    "dúctil": "dúc-til",
    "ductilidad": "duc-ti-li-dad",
    "ductiva": "duc-ti-va",
    "ductivo": "duc-ti-vo",
    "ducto": "duc-to",
    "ductor": "duc-tor",
    "ductriz": "duc-triz",
    "duda": "du-da",
    "dudable": "du-da-ble",
    "dudanza": "du-dan-za",
    "dudar": "du-dar",
    "dudosa": "du-do-sa",
    "dudosamente": "du-do-sa-men-te",
    "dudoso": "du-do-so",
    "duecha": "due-cha",
    "duecho": "due-cho",
    "duela": "due-la",
    "duelaje": "due-la-je",
    "duelero": "due-le-ro",
    "duelista": "due-lis-ta",
    "duelo": "due-lo",
    "dueña": "due-ña",
    "duenario": "due-na-rio",
    "duenda": "duen-da",
    "duende": "duen-de",
    "duendo": "duen-do",
    "dueñesca": "due-ñes-ca",
    "dueñesco": "due-ñes-co",
    "dueño": "due-ño",
    "duermevela": "duer-me-ve-la",
    "duerna": "duer-na",
    "duerno": "duer-no",
    "dueto": "due-to",
    "dugo": "du-go",
    "dugón": "du-gón",
    "dúho": "dú-ho",
    "dujo": "du-jo",
    "dula": "du-la",
    "dular": "du-lar",
    "dulcamara": "dul-ca-ma-ra",
    "dulce": "dul-ce",
    "dulceacuícola": "dul-ce-a-cuí-co-la",
    "dulcedumbre": "dul-ce-dum-bre",
    "dulcémele": "dul-cé-me-le",
    "dulcemente": "dul-ce-men-te",
    "dulcera": "dul-ce-ra",
    "dulcería": "dul-ce-rí-a",
    "dulcero": "dul-ce-ro",
    "dulceza": "dul-ce-za",
    "dulciacuícola": "dul-cia-cuí-co-la",
    "dulcificación": "dul-ci-fi-ca-ción",
    "dulcificar": "dul-ci-fi-car",
    "dulcinea": "dul-ci-ne-a",
    "dulcísona": "dul-cí-so-na",
    "dulcísono": "dul-cí-so-no",
    "dulero": "du-le-ro",
    "dulía": "du-lí-a",
    "dulimán": "du-li-mán",
    "dulleta": "du-lle-ta",
    "dulzaina": "dul-zai-na",
    "dulzainera": "dul-zai-ne-ra",
    "dulzainero": "dul-zai-ne-ro",
    "dulzaino": "dul-zai-no",
    "dulzamara": "dul-za-ma-ra",
    "dulzarrón": "dul-za-rrón",
    "dulzarrona": "dul-za-rro-na",
    "dulzón": "dul-zón",
    "dulzona": "dul-zo-na",
    "dulzor": "dul-zor",
    "dulzorar": "dul-zo-rar",
    "dulzudo": "dul-zu-do",
    "dulzura": "dul-zu-ra",
    "dulzurar": "dul-zu-rar",
    "duma": "du-ma",
    "dumidor": "du-mi-dor",
    "dumir": "du-mir",
    "dumping": "dum-ping",
    "duna": "du-na",
    "dunda": "dun-da",
    "dundeco": "dun-de-co",
    "dundera": "dun-de-ra",
    "dundo": "dun-do",
    "dunita": "du-ni-ta",
    "dúo": "dú-o",
    "duodécima": "duo-dé-ci-ma",
    "duodecimal": "duo-de-ci-mal",
    "duodécimo": "duo-dé-ci-mo",
    "duodécupla": "duo-dé-cu-pla",
    "duodécuplo": "duo-dé-cu-plo",
    "duodena": "duo-de-na",
    "duodenal": "duo-de-nal",
    "duodenaria": "duo-de-na-ria",
    "duodenario": "duo-de-na-rio",
    "duodenitis": "duo-de-ni-tis",
    "duodeno": "duo-de-no",
    "duomesina": "duo-me-si-na",
    "duomesino": "duo-me-si-no",
    "duopolio": "duo-po-lio",
    "dupla": "du-pla",
    "duplada": "du-pla-da",
    "duplado": "du-pla-do",
    "duples": "du-ples",
    "dúplex": "dú-plex",
    "dúplica": "dú-pli-ca",
    "duplicación": "du-pli-ca-ción",
    "duplicadamente": "du-pli-ca-da-men-te",
    "duplicado": "du-pli-ca-do",
    "duplicar": "du-pli-car",
    "duplicativa": "du-pli-ca-ti-va",
    "duplicativo": "du-pli-ca-ti-vo",
    "duplicatura": "du-pli-ca-tu-ra",
    "dúplice": "dú-pli-ce",
    "duplicidad": "du-pli-ci-dad",
    "duplo": "du-plo",
    "duplografía": "du-plo-gra-fí-a",
    "duque": "du-que",
    "duquesa": "du-que-sa",
    "dura": "du-ra",
    "durabilidad": "du-ra-bi-li-dad",
    "durable": "du-ra-ble",
    "duración": "du-ra-ción",
    "duradera": "du-ra-de-ra",
    "duraderamente": "du-ra-de-ra-men-te",
    "duradero": "du-ra-de-ro",
    "durador": "du-ra-dor",
    "duradora": "du-ra-do-ra",
    "duraluminio": "du-ra-lu-mi-nio",
    "duramadre": "du-ra-ma-dre",
    "duramáter": "du-ra-má-ter",
    "duramen": "du-ra-men",
    "duramente": "du-ra-men-te",
    "duranas": "du-ra-nas",
    "durando": "du-ran-do",
    "durangueño": "du-ran-gue-ño",
    "duranguense": "du-ran-guen-se",
    "durangués": "du-ran-gués",
    "duranguesa": "du-ran-gue-sa",
    "durañón": "du-ra-ñón",
    "durante": "du-ran-te",
    "durar": "du-rar",
    "durativa": "du-ra-ti-va",
    "durativo": "du-ra-ti-vo",
    "duraznal": "du-raz-nal",
    "duraznate": "du-raz-na-te",
    "duraznense": "du-raz-nen-se",
    "duraznero": "du-raz-ne-ro",
    "duraznilla": "du-raz-ni-lla",
    "duraznillo": "du-raz-ni-llo",
    "durazno": "du-raz-no",
    "dureza": "du-re-za",
    "duricia": "du-ri-cia",
    "durillo": "du-ri-llo",
    "durina": "du-ri-na",
    "durlines": "dur-li-nes",
    "durmiente": "dur-mien-te",
    "duro": "du-ro",
    "durofrío": "du-ro-frí-o",
    "duunvir": "du-un-vir",
    "duunviral": "du-un-vi-ral",
    "duunvirato": "du-un-vi-ra-to",
    "duunviro": "du-un-vi-ro",
    "ea": "e-a",
    "eagle": "e-a-gle",
    "easonense": "e-a-so-nen-se",
    "ebanista": "e-ba-nis-ta",
    "ebanistería": "e-ba-nis-te-rí-a",
    "ébano": "é-ba-no",
    "ebenácea": "e-be-ná-ce-a",
    "ebenáceo": "e-be-ná-ce-o",
    "ebionita": "e-bio-ni-ta",
    "ébola": "é-bo-la",
    "ebonita": "e-bo-ni-ta",
    "eboraria": "e-bo-ra-ria",
    "eborario": "e-bo-ra-rio",
    "ebrancada": "e-bran-ca-da",
    "ebrancado": "e-bran-ca-do",
    "ebria": "e-bria",
    "ebriedad": "e-brie-dad",
    "ebrio": "e-brio",
    "ebriosa": "e-brio-sa",
    "ebrioso": "e-brio-so",
    "ebulición": "e-bu-li-ción",
    "ebullición": "e-bu-lli-ción",
    "ebullómetro": "e-bu-lló-me-tro",
    "ebulloscopia": "e-bu-llos-co-pia",
    "eburnación": "e-bur-na-ción",
    "ebúrnea": "e-búr-ne-a",
    "ebúrneo": "e-búr-ne-o",
    "eburno": "e-bur-no",
    "ecapacle": "e-ca-pa-cle",
    "ecarté": "e-car-té",
    "eccehomo": "ec-ce-ho-mo",
    "eccema": "ec-ce-ma",
    "eccematosa": "ec-ce-ma-to-sa",
    "eccematoso": "ec-ce-ma-to-so",
    "ecdisis": "ec-di-sis",
    "ecdótica": "ec-dó-ti-ca",
    "ecdótico": "ec-dó-ti-co",
    "ecepto": "e-cep-to",
    "eceptuar": "e-cep-tuar",
    "echacantos": "e-cha-can-tos",
    "echacorvear": "e-cha-cor-ve-ar",
    "echacorvería": "e-cha-cor-ve-rí-a",
    "echacuervos": "e-cha-cuer-vos",
    "echada": "e-cha-da",
    "echadera": "e-cha-de-ra",
    "echadero": "e-cha-de-ro",
    "echadilla": "e-cha-di-lla",
    "echadillo": "e-cha-di-llo",
    "echadiza": "e-cha-di-za",
    "echadizo": "e-cha-di-zo",
    "echado": "e-cha-do",
    "echador": "e-cha-dor",
    "echadora": "e-cha-do-ra",
    "echadura": "e-cha-du-ra",
    "echamiento": "e-cha-mien-to",
    "echapellas": "e-cha-pe-llas",
    "echaperros": "e-cha-pe-rros",
    "echar": "e-char",
    "echarpe": "e-char-pe",
    "echazón": "e-cha-zón",
    "echo": "e-cho",
    "echón": "e-chón",
    "echona": "e-cho-na",
    "echonería": "e-cho-ne-rí-a",
    "ecijana": "e-ci-ja-na",
    "ecijano": "e-ci-ja-no",
    "eclampsia": "e-clamp-sia",
    "ecléctica": "e-cléc-ti-ca",
    "eclecticismo": "e-clec-ti-cis-mo",
    "ecléctico": "e-cléc-ti-co",
    "eclesial": "e-cle-sial",
    "eclesiástica": "e-cle-siás-ti-ca",
    "eclesiásticamente": "e-cle-siás-ti-ca-men-te",
    "eclesiástico": "e-cle-siás-ti-co",
    "eclesiología": "e-cle-sio-lo-gí-a",
    "eclímetro": "e-clí-me-tro",
    "eclipsable": "e-clip-sa-ble",
    "eclipsar": "e-clip-sar",
    "eclipse": "e-clip-se",
    "eclipsi": "e-clip-si",
    "eclíptica": "e-clíp-ti-ca",
    "eclíptico": "e-clíp-ti-co",
    "eclisa": "e-cli-sa",
    "écloga": "é-clo-ga",
    "eclógico": "e-cló-gi-co",
    "eclosión": "e-clo-sión",
    "eclosionar": "e-clo-sio-nar",
    "eco": "e-co",
    "ecocardiografía": "e-co-car-dio-gra-fí-a",
    "ecocardiograma": "e-co-car-dio-gra-ma",
    "ecoencefalografía": "e-co-en-ce-fa-lo-gra-fí-a",
    "ecoetiqueta": "e-co-e-ti-que-ta",
    "ecografía": "e-co-gra-fí-a",
    "ecográfico": "e-co-grá-fi-co",
    "ecografista": "e-co-gra-fis-ta",
    "ecógrafo": "e-có-gra-fo",
    "ecoica": "e-coi-ca",
    "ecoico": "e-coi-co",
    "ecoindustria": "e-coin-dus-tria",
    "ecolalia": "e-co-la-lia",
    "ecolocación": "e-co-lo-ca-ción",
    "ecóloga": "e-có-lo-ga",
    "ecología": "e-co-lo-gí-a",
    "ecológica": "e-co-ló-gi-ca",
    "ecológico": "e-co-ló-gi-co",
    "ecologismo": "e-co-lo-gis-mo",
    "ecologista": "e-co-lo-gis-ta",
    "ecologizar": "e-co-lo-gi-zar",
    "ecólogo": "e-có-lo-go",
    "economato": "e-co-no-ma-to",
    "económetra": "e-co-nó-me-tra",
    "econometría": "e-co-no-me-trí-a",
    "econométrico": "e-co-no-mé-tri-co",
    "economía": "e-co-no-mí-a",
    "económica": "e-co-nó-mi-ca",
    "económicamente": "e-co-nó-mi-ca-men-te",
    "economicidad": "e-co-no-mi-ci-dad",
    "economicismo": "e-co-no-mi-cis-mo",
    "economicista": "e-co-no-mi-cis-ta",
    "económico": "e-co-nó-mi-co",
    "economismo": "e-co-no-mis-mo",
    "economista": "e-co-no-mis-ta",
    "economizador": "e-co-no-mi-za-dor",
    "economizar": "e-co-no-mi-zar",
    "ecónomo": "e-có-no-mo",
    "ecosistema": "e-co-sis-te-ma",
    "ecosonda": "e-co-son-da",
    "ecotada": "e-co-ta-da",
    "ecotado": "e-co-ta-do",
    "ecotasa": "e-co-ta-sa",
    "ecotóxico": "e-co-tó-xi-co",
    "ecotoxicología": "e-co-to-xi-co-lo-gí-a",
    "ecoturismo": "e-co-tu-ris-mo",
    "ectasia": "ec-ta-sia",
    "éctasis": "éc-ta-sis",
    "ectima": "ec-ti-ma",
    "ectodérmica": "ec-to-dér-mi-ca",
    "ectodérmico": "ec-to-dér-mi-co",
    "ectodermo": "ec-to-der-mo",
    "ectomorfa": "ec-to-mor-fa",
    "ectomorfo": "ec-to-mor-fo",
    "ectópago": "ec-tó-pa-go",
    "ectoparásita": "ec-to-pa-rá-si-ta",
    "ectoparásito": "ec-to-pa-rá-si-to",
    "ectopia": "ec-to-pia",
    "ectópico": "ec-tó-pi-co",
    "ectoplasma": "ec-to-plas-ma",
    "ectoplasmia": "ec-to-plas-mia",
    "ectropión": "ec-tro-pión",
    "ecu": "e-cu",
    "ecua": "e-cua",
    "ecuable": "e-cua-ble",
    "ecuación": "e-cua-ción",
    "ecuador": "e-cua-dor",
    "ecualización": "e-cua-li-za-ción",
    "ecualizador": "e-cua-li-za-dor",
    "ecualizar": "e-cua-li-zar",
    "ecuamente": "e-cua-men-te",
    "ecuánime": "e-cuá-ni-me",
    "ecuanimidad": "e-cua-ni-mi-dad",
    "ecuante": "e-cuan-te",
    "ecuatoguineana": "e-cua-to-gui-ne-a-na",
    "ecuatoguineano": "e-cua-to-gui-ne-a-no",
    "ecuatorial": "e-cua-to-rial",
    "ecuatoriana": "e-cua-to-ria-na",
    "ecuatorianismo": "e-cua-to-ria-nis-mo",
    "ecuatoriano": "e-cua-to-ria-no",
    "ecuestre": "e-cues-tre",
    "ecúleo": "e-cú-le-o",
    "ecúmene": "e-cú-me-ne",
    "ecuménica": "e-cu-mé-ni-ca",
    "ecuménico": "e-cu-mé-ni-co",
    "ecumenismo": "e-cu-me-nis-mo",
    "ecúmeno": "e-cú-me-no",
    "ecuo": "e-cuo",
    "ecuórea": "e-cuó-re-a",
    "ecuóreo": "e-cuó-re-o",
    "eczema": "ec-ze-ma",
    "eczematoso": "ec-ze-ma-to-so",
    "edad": "e-dad",
    "edáfico": "e-dá-fi-co",
    "edafóloga": "e-da-fó-lo-ga",
    "edafología": "e-da-fo-lo-gí-a",
    "edafológico": "e-da-fo-ló-gi-co",
    "edafólogo": "e-da-fó-lo-go",
    "edecán": "e-de-cán",
    "edema": "e-de-ma",
    "edematosa": "e-de-ma-to-sa",
    "edematoso": "e-de-ma-to-so",
    "edén": "e-dén",
    "edénica": "e-dé-ni-ca",
    "edénico": "e-dé-ni-co",
    "edentado": "e-den-ta-do",
    "edetana": "e-de-ta-na",
    "edetano": "e-de-ta-no",
    "edición": "e-di-ción",
    "edicto": "e-dic-to",
    "edículo": "e-dí-cu-lo",
    "edificabilidad": "e-di-fi-ca-bi-li-dad",
    "edificable": "e-di-fi-ca-ble",
    "edificación": "e-di-fi-ca-ción",
    "edificador": "e-di-fi-ca-dor",
    "edificadora": "e-di-fi-ca-do-ra",
    "edificante": "e-di-fi-can-te",
    "edificar": "e-di-fi-car",
    "edificativa": "e-di-fi-ca-ti-va",
    "edificativo": "e-di-fi-ca-ti-vo",
    "edificatoria": "e-di-fi-ca-to-ria",
    "edificatorio": "e-di-fi-ca-to-rio",
    "edificio": "e-di-fi-cio",
    "edil": "e-dil",
    "edila": "e-di-la",
    "edilicia": "e-di-li-cia",
    "edilicio": "e-di-li-cio",
    "edilidad": "e-di-li-dad",
    "edípico": "e-dí-pi-co",
    "editar": "e-di-tar",
    "editor": "e-di-tor",
    "editora": "e-di-to-ra",
    "editorial": "e-di-to-rial",
    "editorialista": "e-di-to-ria-lis-ta",
    "editorializar": "e-di-to-ria-li-zar",
    "editorialmente": "e-di-to-rial-men-te",
    "edrar": "e-drar",
    "edredón": "e-dre-dón",
    "edrisí": "e-dri-sí",
    "educable": "e-du-ca-ble",
    "educación": "e-du-ca-ción",
    "educacional": "e-du-ca-cio-nal",
    "educacionista": "e-du-ca-cio-nis-ta",
    "educado": "e-du-ca-do",
    "educador": "e-du-ca-dor",
    "educadora": "e-du-ca-do-ra",
    "educanda": "e-du-can-da",
    "educando": "e-du-can-do",
    "educar": "e-du-car",
    "educativa": "e-du-ca-ti-va",
    "educativo": "e-du-ca-ti-vo",
    "educción": "e-duc-ción",
    "educir": "e-du-cir",
    "edulcoración": "e-dul-co-ra-ción",
    "edulcorado": "e-dul-co-ra-do",
    "edulcoramiento": "e-dul-co-ra-mien-to",
    "edulcorante": "e-dul-co-ran-te",
    "edulcorar": "e-dul-co-rar",
    "efabilidad": "e-fa-bi-li-dad",
    "efable": "e-fa-ble",
    "efe": "e-fe",
    "efébico": "e-fé-bi-co",
    "efebo": "e-fe-bo",
    "efectismo": "e-fec-tis-mo",
    "efectista": "e-fec-tis-ta",
    "efectiva": "e-fec-ti-va",
    "efectivamente": "e-fec-ti-va-men-te",
    "efectivar": "e-fec-ti-var",
    "efectividad": "e-fec-ti-vi-dad",
    "efectivo": "e-fec-ti-vo",
    "efecto": "e-fec-to",
    "efector": "e-fec-tor",
    "efectora": "e-fec-to-ra",
    "efectuación": "e-fec-tua-ción",
    "efectuar": "e-fec-tuar",
    "efedra": "e-fe-dra",
    "efedrácea": "e-fe-drá-ce-a",
    "efedráceas": "e-fe-drá-ce-as",
    "efedráceo": "e-fe-drá-ce-o",
    "efedrina": "e-fe-dri-na",
    "efélide": "e-fé-li-de",
    "efeméride": "e-fe-mé-ri-de",
    "efemérides": "e-fe-mé-ri-des",
    "efémero": "e-fé-me-ro",
    "efeminada": "e-fe-mi-na-da",
    "efeminado": "e-fe-mi-na-do",
    "efeminar": "e-fe-mi-nar",
    "efendi": "e-fen-di",
    "eferencia": "e-fe-ren-cia",
    "eferente": "e-fe-ren-te",
    "efervescencia": "e-fer-ves-cen-cia",
    "efervescente": "e-fer-ves-cen-te",
    "efesia": "e-fe-sia",
    "efesina": "e-fe-si-na",
    "efesino": "e-fe-si-no",
    "efesio": "e-fe-sio",
    "efetá": "e-fe-tá",
    "éfeta": "é-fe-ta",
    "efeto": "e-fe-to",
    "eficacia": "e-fi-ca-cia",
    "eficacidad": "e-fi-ca-ci-dad",
    "eficaz": "e-fi-caz",
    "eficazmente": "e-fi-caz-men-te",
    "eficiencia": "e-fi-cien-cia",
    "eficiente": "e-fi-cien-te",
    "eficientemente": "e-fi-cien-te-men-te",
    "efigiada": "e-fi-gia-da",
    "efigiado": "e-fi-gia-do",
    "efigiar": "e-fi-giar",
    "efigie": "e-fi-gie",
    "efímera": "e-fí-me-ra",
    "efimeral": "e-fi-me-ral",
    "efímero": "e-fí-me-ro",
    "eflorecer": "e-flo-re-cer",
    "eflorecerse": "e-flo-re-cer-se",
    "eflorescencia": "e-flo-res-cen-cia",
    "eflorescente": "e-flo-res-cen-te",
    "eflorescer": "e-flo-res-cer",
    "efluente": "e-fluen-te",
    "efluir": "e-fluir",
    "efluvio": "e-flu-vio",
    "efluxión": "e-flu-xión",
    "efod": "e-fod",
    "éforo": "é-fo-ro",
    "efraimita": "e-frai-mi-ta",
    "efratea": "e-fra-te-a",
    "efrateo": "e-fra-te-o",
    "efugio": "e-fu-gio",
    "efundir": "e-fun-dir",
    "efusión": "e-fu-sión",
    "efusiva": "e-fu-si-va",
    "efusividad": "e-fu-si-vi-dad",
    "efusivo": "e-fu-si-vo",
    "egabrense": "e-ga-bren-se",
    "egarense": "e-ga-ren-se",
    "egena": "e-ge-na",
    "egeno": "e-ge-no",
    "egestad": "e-ges-tad",
    "egestión": "e-ges-tión",
    "egetana": "e-ge-ta-na",
    "egetano": "e-ge-ta-no",
    "egiciana": "e-gi-cia-na",
    "egiciano": "e-gi-cia-no",
    "égida": "é-gi-da",
    "egilope": "e-gi-lo-pe",
    "egílope": "e-gí-lo-pe",
    "egineta": "e-gi-ne-ta",
    "egipán": "e-gi-pán",
    "egipcia": "e-gip-cia",
    "egipcíaca": "e-gip-cí-a-ca",
    "egipciaca": "e-gip-cia-ca",
    "egipcíaco": "e-gip-cí-a-co",
    "egipciaco": "e-gip-cia-co",
    "egipciana": "e-gip-cia-na",
    "egipciano": "e-gip-cia-no",
    "egipcio": "e-gip-cio",
    "egiptana": "e-gip-ta-na",
    "egiptano": "e-gip-ta-no",
    "egipto": "e-gip-to",
    "egiptóloga": "e-gip-tó-lo-ga",
    "egiptología": "e-gip-to-lo-gí-a",
    "egiptológica": "e-gip-to-ló-gi-ca",
    "egiptológico": "e-gip-to-ló-gi-co",
    "egiptólogo": "e-gip-tó-lo-go",
    "eglefino": "e-gle-fi-no",
    "eglesia": "e-gle-sia",
    "égloga": "é-glo-ga",
    "eglógico": "e-gló-gi-co",
    "ego": "e-go",
    "egocéntrica": "e-go-cén-tri-ca",
    "egocéntrico": "e-go-cén-tri-co",
    "egocentrismo": "e-go-cen-tris-mo",
    "egofonía": "e-go-fo-ní-a",
    "egoísmo": "e-go-ís-mo",
    "egoísta": "e-go-ís-ta",
    "ególatra": "e-gó-la-tra",
    "egolatría": "e-go-la-trí-a",
    "egolátrica": "e-go-lá-tri-ca",
    "egolátrico": "e-go-lá-tri-co",
    "egotismo": "e-go-tis-mo",
    "egotista": "e-go-tis-ta",
    "egregia": "e-gre-gia",
    "egregiamente": "e-gre-gia-men-te",
    "egregio": "e-gre-gio",
    "egresada": "e-gre-sa-da",
    "egresado": "e-gre-sa-do",
    "egresar": "e-gre-sar",
    "egresión": "e-gre-sión",
    "egreso": "e-gre-so",
    "eguar": "e-guar",
    "eibarrés": "ei-ba-rrés",
    "eibarresa": "ei-ba-rre-sa",
    "eidético": "ei-dé-ti-co",
    "eidetismo": "ei-de-tis-mo",
    "einstenio": "eins-te-nio",
    "eirá": "ei-rá",
    "ejabrir": "e-ja-brir",
    "ejarbe": "e-jar-be",
    "eje": "e-je",
    "eject": "e-ject",
    "ejecución": "e-je-cu-ción",
    "ejecutable": "e-je-cu-ta-ble",
    "ejecutadera": "e-je-cu-ta-de-ra",
    "ejecutadero": "e-je-cu-ta-de-ro",
    "ejecutante": "e-je-cu-tan-te",
    "ejecutar": "e-je-cu-tar",
    "ejecutiva": "e-je-cu-ti-va",
    "ejecutivamente": "e-je-cu-ti-va-men-te",
    "ejecutivo": "e-je-cu-ti-vo",
    "ejecutor": "e-je-cu-tor",
    "ejecutora": "e-je-cu-to-ra",
    "ejecutoria": "e-je-cu-to-ria",
    "ejecutoriar": "e-je-cu-to-riar",
    "ejecutorio": "e-je-cu-to-rio",
    "ejem": "e-jem",
    "ejemplar": "e-jem-plar",
    "ejemplaridad": "e-jem-pla-ri-dad",
    "ejemplario": "e-jem-pla-rio",
    "ejemplarización": "e-jem-pla-ri-za-ción",
    "ejemplarizador": "e-jem-pla-ri-za-dor",
    "ejemplarizante": "e-jem-pla-ri-zan-te",
    "ejemplarizar": "e-jem-pla-ri-zar",
    "ejemplarmente": "e-jem-plar-men-te",
    "ejemplificación": "e-jem-pli-fi-ca-ción",
    "ejemplificar": "e-jem-pli-fi-car",
    "ejemplo": "e-jem-plo",
    "ejercer": "e-jer-cer",
    "ejercicio": "e-jer-ci-cio",
    "ejercida": "e-jer-ci-da",
    "ejercido": "e-jer-ci-do",
    "ejercitación": "e-jer-ci-ta-ción",
    "ejercitador": "e-jer-ci-ta-dor",
    "ejercitadora": "e-jer-ci-ta-do-ra",
    "ejercitante": "e-jer-ci-tan-te",
    "ejercitar": "e-jer-ci-tar",
    "ejercitativa": "e-jer-ci-ta-ti-va",
    "ejercitativo": "e-jer-ci-ta-ti-vo",
    "ejército": "e-jér-ci-to",
    "ejidal": "e-ji-dal",
    "ejidataria": "e-ji-da-ta-ria",
    "ejidatario": "e-ji-da-ta-rio",
    "ejido": "e-ji-do",
    "ejión": "e-jión",
    "ejote": "e-jo-te",
    "ekeko": "e-ke-ko",
    "elaborable": "e-la-bo-ra-ble",
    "elaboración": "e-la-bo-ra-ción",
    "elaborado": "e-la-bo-ra-do",
    "elaborador": "e-la-bo-ra-dor",
    "elaboradora": "e-la-bo-ra-do-ra",
    "elaborar": "e-la-bo-rar",
    "elación": "e-la-ción",
    "elaiómetro": "e-laió-me-tro",
    "elaiotecnia": "e-laio-tec-nia",
    "elamí": "e-la-mí",
    "elamita": "e-la-mi-ta",
    "elanio": "e-la-nio",
    "elápido": "e-lá-pi-do",
    "elasmobranquio": "e-las-mo-bran-quio",
    "elasmosaurio": "e-las-mo-sau-rio",
    "elástica": "e-lás-ti-ca",
    "elásticas": "e-lás-ti-cas",
    "elasticidad": "e-las-ti-ci-dad",
    "elástico": "e-lás-ti-co",
    "elastina": "e-las-ti-na",
    "elastómero": "e-las-tó-me-ro",
    "elata": "e-la-ta",
    "elaterio": "e-la-te-rio",
    "elativo": "e-la-ti-vo",
    "elato": "e-la-to",
    "elche": "el-che",
    "ele": "e-le",
    "eleagnácea": "e-le-ag-ná-ce-a",
    "eleagnáceo": "e-le-ag-ná-ce-o",
    "eleática": "e-le-á-ti-ca",
    "eleático": "e-le-á-ti-co",
    "eleatismo": "e-le-a-tis-mo",
    "elébor": "e-lé-bor",
    "eléboro": "e-lé-bo-ro",
    "elección": "e-lec-ción",
    "eleccionario": "e-lec-cio-na-rio",
    "electa": "e-lec-ta",
    "electiva": "e-lec-ti-va",
    "electivo": "e-lec-ti-vo",
    "electo": "e-lec-to",
    "elector": "e-lec-tor",
    "electora": "e-lec-to-ra",
    "electorado": "e-lec-to-ra-do",
    "electoral": "e-lec-to-ral",
    "electoralismo": "e-lec-to-ra-lis-mo",
    "electoralista": "e-lec-to-ra-lis-ta",
    "electorera": "e-lec-to-re-ra",
    "electorero": "e-lec-to-re-ro",
    "eléctrica": "e-léc-tri-ca",
    "electricidad": "e-lec-tri-ci-dad",
    "electricista": "e-lec-tri-cis-ta",
    "eléctrico": "e-léc-tri-co",
    "electrificación": "e-lec-tri-fi-ca-ción",
    "electrificar": "e-lec-tri-fi-car",
    "electriz": "e-lec-triz",
    "electrizable": "e-lec-tri-za-ble",
    "electrización": "e-lec-tri-za-ción",
    "electrizador": "e-lec-tri-za-dor",
    "electrizadora": "e-lec-tri-za-do-ra",
    "electrizante": "e-lec-tri-zan-te",
    "electrizar": "e-lec-tri-zar",
    "electro": "e-lec-tro",
    "electroacústica": "e-lec-tro-a-cús-ti-ca",
    "electroacústico": "e-lec-tro-a-cús-ti-co",
    "electrobiología": "e-lec-tro-bio-lo-gí-a",
    "electrobiológico": "e-lec-tro-bio-ló-gi-co",
    "electrocardiografía": "e-lec-tro-car-dio-gra-fí-a",
    "electrocardiógrafo": "e-lec-tro-car-dió-gra-fo",
    "electrocardiograma": "e-lec-tro-car-dio-gra-ma",
    "electrochoque": "e-lec-tro-cho-que",
    "electrocinética": "e-lec-tro-ci-né-ti-ca",
    "electrocirugía": "e-lec-tro-ci-ru-gí-a",
    "electrocoagulación": "e-lec-tro-co-a-gu-la-ción",
    "electrocromo": "e-lec-tro-cro-mo",
    "electrocución": "e-lec-tro-cu-ción",
    "electrocutar": "e-lec-tro-cu-tar",
    "electrodiagnóstico": "e-lec-tro-diag-nós-ti-co",
    "electrodiálisis": "e-lec-tro-diá-li-sis",
    "electrodinámica": "e-lec-tro-di-ná-mi-ca",
    "electrodinámico": "e-lec-tro-di-ná-mi-co",
    "electrodo": "e-lec-tro-do",
    "electrodoméstico": "e-lec-tro-do-més-ti-co",
    "electroencefalografía": "e-lec-tro-en-ce-fa-lo-gra-fí-a",
    "electroencefalográfico": "e-lec-tro-en-ce-fa-lo-grá-fi-co",
    "electroencefalografista": "e-lec-tro-en-ce-fa-lo-gra-fis-ta",
    "electroencefalógrafo": "e-lec-tro-en-ce-fa-ló-gra-fo",
    "electroencefalograma": "e-lec-tro-en-ce-fa-lo-gra-ma",
    "electroerosión": "e-lec-tro-e-ro-sión",
    "electroestricción": "e-lec-tro-es-tric-ción",
    "electrofisiología": "e-lec-tro-fi-sio-lo-gí-a",
    "electrofisiológico": "e-lec-tro-fi-sio-ló-gi-co",
    "electrófono": "e-lec-tró-fo-no",
    "electroforesis": "e-lec-tro-fo-re-sis",
    "electróforo": "e-lec-tró-fo-ro",
    "electrógena": "e-lec-tró-ge-na",
    "electrógeno": "e-lec-tró-ge-no",
    "electroimán": "e-lec-troi-mán",
    "electrolisis": "e-lec-tro-li-sis",
    "electrólisis": "e-lec-tró-li-sis",
    "electrolítica": "e-lec-tro-lí-ti-ca",
    "electrolítico": "e-lec-tro-lí-ti-co",
    "electrolito": "e-lec-tro-li-to",
    "electrólito": "e-lec-tró-li-to",
    "electrolización": "e-lec-tro-li-za-ción",
    "electrolizador": "e-lec-tro-li-za-dor",
    "electrolizadora": "e-lec-tro-li-za-do-ra",
    "electrolizar": "e-lec-tro-li-zar",
    "electroluminiscente": "e-lec-tro-lu-mi-nis-cen-te",
    "electromagnética": "e-lec-tro-mag-né-ti-ca",
    "electromagnético": "e-lec-tro-mag-né-ti-co",
    "electromagnetismo": "e-lec-tro-mag-ne-tis-mo",
    "electromecánica": "e-lec-tro-me-cá-ni-ca",
    "electromecánico": "e-lec-tro-me-cá-ni-co",
    "electromedicina": "e-lec-tro-me-di-ci-na",
    "electrometalurgia": "e-lec-tro-me-ta-lur-gia",
    "electrometalúrgico": "e-lec-tro-me-ta-lúr-gi-co",
    "electrometría": "e-lec-tro-me-trí-a",
    "electrométrica": "e-lec-tro-mé-tri-ca",
    "electrométrico": "e-lec-tro-mé-tri-co",
    "electrómetro": "e-lec-tró-me-tro",
    "electromotor": "e-lec-tro-mo-tor",
    "electromotora": "e-lec-tro-mo-to-ra",
    "electromotriz": "e-lec-tro-mo-triz",
    "electrón": "e-lec-trón",
    "electronegativa": "e-lec-tro-ne-ga-ti-va",
    "electronegativo": "e-lec-tro-ne-ga-ti-vo",
    "electroneurografía": "e-lec-tro-neu-ro-gra-fí-a",
    "electrónica": "e-lec-tró-ni-ca",
    "electrónicamente": "e-lec-tró-ni-ca-men-te",
    "electrónico": "e-lec-tró-ni-co",
    "electronistagmografía": "e-lec-tro-nis-tag-mo-gra-fí-a",
    "electronvoltio": "e-lec-tron-vol-tio",
    "electroóptico": "e-lec-tro-óp-ti-co",
    "electropositiva": "e-lec-tro-po-si-ti-va",
    "electropositivo": "e-lec-tro-po-si-ti-vo",
    "electroquímica": "e-lec-tro-quí-mi-ca",
    "electroquímico": "e-lec-tro-quí-mi-co",
    "electroscopio": "e-lec-tros-co-pio",
    "electrostática": "e-lec-tros-tá-ti-ca",
    "electrostático": "e-lec-tros-tá-ti-co",
    "electrostricción": "e-lec-tros-tric-ción",
    "electrotecnia": "e-lec-tro-tec-nia",
    "electrotécnica": "e-lec-tro-téc-ni-ca",
    "electrotécnico": "e-lec-tro-téc-ni-co",
    "electroterapia": "e-lec-tro-te-ra-pia",
    "electroterápica": "e-lec-tro-te-rá-pi-ca",
    "electroterápico": "e-lec-tro-te-rá-pi-co",
    "electrotermia": "e-lec-tro-ter-mia",
    "electrotérmico": "e-lec-tro-tér-mi-co",
    "electrotipia": "e-lec-tro-ti-pia",
    "electrotípica": "e-lec-tro-tí-pi-ca",
    "electrotípico": "e-lec-tro-tí-pi-co",
    "electrotrén": "e-lec-tro-trén",
    "electroválvula": "e-lec-tro-vál-vu-la",
    "electroventilador": "e-lec-tro-ven-ti-la-dor",
    "electuario": "e-lec-tua-rio",
    "elefancía": "e-le-fan-cí-a",
    "elefancia": "e-le-fan-cia",
    "elefancíaca": "e-le-fan-cí-a-ca",
    "elefanciaca": "e-le-fan-cia-ca",
    "elefancíaco": "e-le-fan-cí-a-co",
    "elefanciaco": "e-le-fan-cia-co",
    "elefanta": "e-le-fan-ta",
    "elefante": "e-le-fan-te",
    "elefantiásica": "e-le-fan-tiá-si-ca",
    "elefantiásico": "e-le-fan-tiá-si-co",
    "elefantiasis": "e-le-fan-tia-sis",
    "elefantina": "e-le-fan-ti-na",
    "elefantino": "e-le-fan-ti-no",
    "élega": "é-le-ga",
    "elegancia": "e-le-gan-cia",
    "elegante": "e-le-gan-te",
    "eleganteada": "e-le-gan-te-a-da",
    "elegantear": "e-le-gan-te-ar",
    "elegantemente": "e-le-gan-te-men-te",
    "elegantiosa": "e-le-gan-tio-sa",
    "elegantioso": "e-le-gan-tio-so",
    "elegantizar": "e-le-gan-ti-zar",
    "elegantoso": "e-le-gan-to-so",
    "elegía": "e-le-gí-a",
    "elegiaca": "e-le-gia-ca",
    "elegíaco": "e-le-gí-a-co",
    "elegiaco": "e-le-gia-co",
    "elegibilidad": "e-le-gi-bi-li-dad",
    "elegible": "e-le-gi-ble",
    "elegido": "e-le-gi-do",
    "elegidor": "e-le-gi-dor",
    "elegio": "e-le-gio",
    "elegir": "e-le-gir",
    "élego": "é-le-go",
    "elementada": "e-le-men-ta-da",
    "elementado": "e-le-men-ta-do",
    "elemental": "e-le-men-tal",
    "elementalidad": "e-le-men-ta-li-dad",
    "elementalmente": "e-le-men-tal-men-te",
    "elementar": "e-le-men-tar",
    "elemento": "e-le-men-to",
    "elemí": "e-le-mí",
    "elenco": "e-len-co",
    "eleotecnia": "e-le-o-tec-nia",
    "elepé": "e-le-pé",
    "elequeme": "e-le-que-me",
    "eleta": "e-le-ta",
    "eleto": "e-le-to",
    "eleusina": "e-leu-si-na",
    "eleusino": "e-leu-si-no",
    "elevable": "e-le-va-ble",
    "elevación": "e-le-va-ción",
    "elevada": "e-le-va-da",
    "elevadamente": "e-le-va-da-men-te",
    "elevado": "e-le-va-do",
    "elevador": "e-le-va-dor",
    "elevadora": "e-le-va-do-ra",
    "elevadorista": "e-le-va-do-ris-ta",
    "elevalunas": "e-le-va-lu-nas",
    "elevamiento": "e-le-va-mien-to",
    "elevar": "e-le-var",
    "elevavidrio": "e-le-va-vi-drio",
    "elfina": "el-fi-na",
    "elfo": "el-fo",
    "elidir": "e-li-dir",
    "eligible": "e-li-gi-ble",
    "eligir": "e-li-gir",
    "elijable": "e-li-ja-ble",
    "elijación": "e-li-ja-ción",
    "elijan": "e-li-jan",
    "elijar": "e-li-jar",
    "eliminación": "e-li-mi-na-ción",
    "eliminador": "e-li-mi-na-dor",
    "eliminadora": "e-li-mi-na-do-ra",
    "eliminar": "e-li-mi-nar",
    "eliminatoria": "e-li-mi-na-to-ria",
    "eliminatorio": "e-li-mi-na-to-rio",
    "elipse": "e-lip-se",
    "elipsis": "e-lip-sis",
    "elipsógrafo": "e-lip-só-gra-fo",
    "elipsoidal": "e-lip-soi-dal",
    "elipsoide": "e-lip-soi-de",
    "elíptica": "e-líp-ti-ca",
    "elípticamente": "e-líp-ti-ca-men-te",
    "elíptico": "e-líp-ti-co",
    "elisana": "e-li-sa-na",
    "elisano": "e-li-sa-no",
    "elísea": "e-lí-se-a",
    "elíseo": "e-lí-se-o",
    "elisia": "e-li-sia",
    "elisio": "e-li-sio",
    "elisión": "e-li-sión",
    "elitario": "e-li-ta-rio",
    "elite": "e-li-te",
    "élite": "é-li-te",
    "elitismo": "e-li-tis-mo",
    "elitista": "e-li-tis-ta",
    "élitro": "é-li-tro",
    "elixir": "e-li-xir",
    "elíxir": "e-lí-xir",
    "ella": "e-lla",
    "ellas": "e-llas",
    "elle": "e-lle",
    "ello": "e-llo",
    "ellos": "e-llos",
    "elmete": "el-me-te",
    "elocución": "e-lo-cu-ción",
    "elocuencia": "e-lo-cuen-cia",
    "elocuente": "e-lo-cuen-te",
    "elocuentemente": "e-lo-cuen-te-men-te",
    "elocutivo": "e-lo-cu-ti-vo",
    "elogiable": "e-lo-gia-ble",
    "elogiador": "e-lo-gia-dor",
    "elogiadora": "e-lo-gia-do-ra",
    "elogiar": "e-lo-giar",
    "elogio": "e-lo-gio",
    "elogiosa": "e-lo-gio-sa",
    "elogioso": "e-lo-gio-so",
    "elongación": "e-lon-ga-ción",
    "elongar": "e-lon-gar",
    "eloquio": "e-lo-quio",
    "elotada": "e-lo-ta-da",
    "elote": "e-lo-te",
    "elotear": "e-lo-te-ar",
    "elotera": "e-lo-te-ra",
    "elotero": "e-lo-te-ro",
    "elquina": "el-qui-na",
    "elquino": "el-qui-no",
    "elucidación": "e-lu-ci-da-ción",
    "elucidar": "e-lu-ci-dar",
    "elucidario": "e-lu-ci-da-rio",
    "eluctable": "e-luc-ta-ble",
    "elucubración": "e-lu-cu-bra-ción",
    "elucubrador": "e-lu-cu-bra-dor",
    "elucubradora": "e-lu-cu-bra-do-ra",
    "elucubrar": "e-lu-cu-brar",
    "eludible": "e-lu-di-ble",
    "eludir": "e-lu-dir",
    "elusión": "e-lu-sión",
    "elusivo": "e-lu-si-vo",
    "elzevir": "el-ze-vir",
    "elzeviriana": "el-ze-vi-ria-na",
    "elzeviriano": "el-ze-vi-ria-no",
    "elzevirio": "el-ze-vi-rio",
    "emaciación": "e-ma-cia-ción",
    "emanación": "e-ma-na-ción",
    "emanadero": "e-ma-na-de-ro",
    "emanantismo": "e-ma-nan-tis-mo",
    "emanantista": "e-ma-nan-tis-ta",
    "emanar": "e-ma-nar",
    "emanatismo": "e-ma-na-tis-mo",
    "emanatista": "e-ma-na-tis-ta",
    "emancipación": "e-man-ci-pa-ción",
    "emancipador": "e-man-ci-pa-dor",
    "emancipadora": "e-man-ci-pa-do-ra",
    "emancipar": "e-man-ci-par",
    "emasculación": "e-mas-cu-la-ción",
    "emascular": "e-mas-cu-lar",
    "embabiamiento": "em-ba-bia-mien-to",
    "embabucar": "em-ba-bu-car",
    "embachar": "em-ba-char",
    "embadurnador": "em-ba-dur-na-dor",
    "embadurnadora": "em-ba-dur-na-do-ra",
    "embadurnar": "em-ba-dur-nar",
    "embaición": "em-bai-ción",
    "embaidor": "em-bai-dor",
    "embaidora": "em-bai-do-ra",
    "embaimiento": "em-bai-mien-to",
    "embaír": "em-ba-ír",
    "embajada": "em-ba-ja-da",
    "embajador": "em-ba-ja-dor",
    "embajadora": "em-ba-ja-do-ra",
    "embajatoria": "em-ba-ja-to-ria",
    "embajatorio": "em-ba-ja-to-rio",
    "embajo": "em-ba-jo",
    "embalador": "em-ba-la-dor",
    "embaladora": "em-ba-la-do-ra",
    "embaladura": "em-ba-la-du-ra",
    "embalaje": "em-ba-la-je",
    "embalar": "em-ba-lar",
    "embaldosado": "em-bal-do-sa-do",
    "embaldosadura": "em-bal-do-sa-du-ra",
    "embaldosar": "em-bal-do-sar",
    "embale": "em-ba-le",
    "emballenado": "em-ba-lle-na-do",
    "emballenador": "em-ba-lle-na-dor",
    "emballenadora": "em-ba-lle-na-do-ra",
    "emballenar": "em-ba-lle-nar",
    "emballestada": "em-ba-lles-ta-da",
    "emballestado": "em-ba-lles-ta-do",
    "emballestadura": "em-ba-lles-ta-du-ra",
    "emballestar": "em-ba-lles-tar",
    "emballestarse": "em-ba-lles-tar-se",
    "embalo": "em-ba-lo",
    "embalsadero": "em-bal-sa-de-ro",
    "embalsado": "em-bal-sa-do",
    "embalsamador": "em-bal-sa-ma-dor",
    "embalsamadora": "em-bal-sa-ma-do-ra",
    "embalsamamiento": "em-bal-sa-ma-mien-to",
    "embalsamar": "em-bal-sa-mar",
    "embalsar": "em-bal-sar",
    "embalse": "em-bal-se",
    "embalumar": "em-ba-lu-mar",
    "embanastar": "em-ba-nas-tar",
    "embancar": "em-ban-car",
    "embancarse": "em-ban-car-se",
    "embanderar": "em-ban-de-rar",
    "embanquetar": "em-ban-que-tar",
    "embarajar": "em-ba-ra-jar",
    "embarao": "em-ba-ra-o",
    "embarazada": "em-ba-ra-za-da",
    "embarazadamente": "em-ba-ra-za-da-men-te",
    "embarazado": "em-ba-ra-za-do",
    "embarazador": "em-ba-ra-za-dor",
    "embarazadora": "em-ba-ra-za-do-ra",
    "embarazar": "em-ba-ra-zar",
    "embarazo": "em-ba-ra-zo",
    "embarazosa": "em-ba-ra-zo-sa",
    "embarazosamente": "em-ba-ra-zo-sa-men-te",
    "embarazoso": "em-ba-ra-zo-so",
    "embarbascar": "em-bar-bas-car",
    "embarbecer": "em-bar-be-cer",
    "embarbillado": "em-bar-bi-lla-do",
    "embarbillar": "em-bar-bi-llar",
    "embarcación": "em-bar-ca-ción",
    "embarcadero": "em-bar-ca-de-ro",
    "embarcador": "em-bar-ca-dor",
    "embarcadora": "em-bar-ca-do-ra",
    "embarcar": "em-bar-car",
    "embarco": "em-bar-co",
    "embardar": "em-bar-dar",
    "embargable": "em-bar-ga-ble",
    "embargada": "em-bar-ga-da",
    "embargado": "em-bar-ga-do",
    "embargador": "em-bar-ga-dor",
    "embargadora": "em-bar-ga-do-ra",
    "embargamiento": "em-bar-ga-mien-to",
    "embargante": "em-bar-gan-te",
    "embargar": "em-bar-gar",
    "embargo": "em-bar-go",
    "embargosa": "em-bar-go-sa",
    "embargoso": "em-bar-go-so",
    "embarnecer": "em-bar-ne-cer",
    "embarnecimiento": "em-bar-ne-ci-mien-to",
    "embarnizadura": "em-bar-ni-za-du-ra",
    "embarnizar": "em-bar-ni-zar",
    "embarque": "em-bar-que",
    "embarrada": "em-ba-rra-da",
    "embarradilla": "em-ba-rra-di-lla",
    "embarrado": "em-ba-rra-do",
    "embarrador": "em-ba-rra-dor",
    "embarradora": "em-ba-rra-do-ra",
    "embarradura": "em-ba-rra-du-ra",
    "embarrancamiento": "em-ba-rran-ca-mien-to",
    "embarrancar": "em-ba-rran-car",
    "embarrar": "em-ba-rrar",
    "embarriado": "em-ba-rria-do",
    "embarrialar": "em-ba-rria-lar",
    "embarriar": "em-ba-rriar",
    "embarrijo": "em-ba-rri-jo",
    "embarrilador": "em-ba-rri-la-dor",
    "embarrilar": "em-ba-rri-lar",
    "embarrotar": "em-ba-rro-tar",
    "embarrutar": "em-ba-rru-tar",
    "embarullador": "em-ba-ru-lla-dor",
    "embarulladora": "em-ba-ru-lla-do-ra",
    "embarullar": "em-ba-ru-llar",
    "embasamiento": "em-ba-sa-mien-to",
    "embastar": "em-bas-tar",
    "embaste": "em-bas-te",
    "embastecer": "em-bas-te-cer",
    "embatada": "em-ba-ta-da",
    "embate": "em-ba-te",
    "embatir": "em-ba-tir",
    "embatirse": "em-ba-tir-se",
    "embaucador": "em-bau-ca-dor",
    "embaucadora": "em-bau-ca-do-ra",
    "embaucamiento": "em-bau-ca-mien-to",
    "embaucar": "em-bau-car",
    "embauco": "em-bau-co",
    "embaulada": "em-bau-la-da",
    "embaulado": "em-bau-la-do",
    "embaular": "em-bau-lar",
    "embausamiento": "em-bau-sa-mien-to",
    "embayar": "em-ba-yar",
    "embazador": "em-ba-za-dor",
    "embazadura": "em-ba-za-du-ra",
    "embazar": "em-ba-zar",
    "embazarse": "em-ba-zar-se",
    "embebecer": "em-be-be-cer",
    "embebecidamente": "em-be-be-ci-da-men-te",
    "embebecimiento": "em-be-be-ci-mien-to",
    "embebedor": "em-be-be-dor",
    "embebedora": "em-be-be-do-ra",
    "embeber": "em-be-ber",
    "embebida": "em-be-bi-da",
    "embebido": "em-be-bi-do",
    "embecadura": "em-be-ca-du-ra",
    "embejucar": "em-be-ju-car",
    "embelecador": "em-be-le-ca-dor",
    "embelecadora": "em-be-le-ca-do-ra",
    "embelecamiento": "em-be-le-ca-mien-to",
    "embelecar": "em-be-le-car",
    "embeleco": "em-be-le-co",
    "embeleñar": "em-be-le-ñar",
    "embelequera": "em-be-le-que-ra",
    "embelequería": "em-be-le-que-rí-a",
    "embelequero": "em-be-le-que-ro",
    "embelesador": "em-be-le-sa-dor",
    "embelesamiento": "em-be-le-sa-mien-to",
    "embelesar": "em-be-le-sar",
    "embeleso": "em-be-le-so",
    "embelga": "em-bel-ga",
    "embellacar": "em-be-lla-car",
    "embellaquecer": "em-be-lla-que-cer",
    "embellaquecerse": "em-be-lla-que-cer-se",
    "embellecedor": "em-be-lle-ce-dor",
    "embellecer": "em-be-lle-cer",
    "embellecimiento": "em-be-lle-ci-mien-to",
    "embembar": "em-bem-bar",
    "embeodar": "em-be-o-dar",
    "embermejar": "em-ber-me-jar",
    "embermejecer": "em-ber-me-je-cer",
    "embero": "em-be-ro",
    "emberrenchinar": "em-be-rren-chi-nar",
    "emberrenchinarse": "em-be-rren-chi-nar-se",
    "emberretinamiento": "em-be-rre-ti-na-mien-to",
    "emberretinar": "em-be-rre-ti-nar",
    "emberrinchar": "em-be-rrin-char",
    "emberrincharse": "em-be-rrin-char-se",
    "emberriondada": "em-be-rrion-da-da",
    "embestida": "em-bes-ti-da",
    "embestidor": "em-bes-ti-dor",
    "embestidora": "em-bes-ti-do-ra",
    "embestidura": "em-bes-ti-du-ra",
    "embestir": "em-bes-tir",
    "embetunado": "em-be-tu-na-do",
    "embetunar": "em-be-tu-nar",
    "embicadura": "em-bi-ca-du-ra",
    "embicar": "em-bi-car",
    "embichar": "em-bi-char",
    "embijado": "em-bi-ja-do",
    "embijar": "em-bi-jar",
    "embije": "em-bi-je",
    "embizcar": "em-biz-car",
    "emblandecer": "em-blan-de-cer",
    "emblanqueada": "em-blan-que-a-da",
    "emblanqueado": "em-blan-que-a-do",
    "emblanquear": "em-blan-que-ar",
    "emblanquecer": "em-blan-que-cer",
    "emblanquecimiento": "em-blan-que-ci-mien-to",
    "emblema": "em-ble-ma",
    "emblemática": "em-ble-má-ti-ca",
    "emblemáticamente": "em-ble-má-ti-ca-men-te",
    "emblemático": "em-ble-má-ti-co",
    "emblematizar": "em-ble-ma-ti-zar",
    "embobamiento": "em-bo-ba-mien-to",
    "embobar": "em-bo-bar",
    "embobecer": "em-bo-be-cer",
    "embobecimiento": "em-bo-be-ci-mien-to",
    "embobinar": "em-bo-bi-nar",
    "embocada": "em-bo-ca-da",
    "embocadero": "em-bo-ca-de-ro",
    "embocado": "em-bo-ca-do",
    "embocadura": "em-bo-ca-du-ra",
    "embocar": "em-bo-car",
    "embochicar": "em-bo-chi-car",
    "embochinchar": "em-bo-chin-char",
    "embocicar": "em-bo-ci-car",
    "embocinada": "em-bo-ci-na-da",
    "embocinado": "em-bo-ci-na-do",
    "embodegar": "em-bo-de-gar",
    "embojar": "em-bo-jar",
    "embojo": "em-bo-jo",
    "embojotar": "em-bo-jo-tar",
    "embolada": "em-bo-la-da",
    "embolado": "em-bo-la-do",
    "embolador": "em-bo-la-dor",
    "emboladora": "em-bo-la-do-ra",
    "embolante": "em-bo-lan-te",
    "embolar": "em-bo-lar",
    "embolatar": "em-bo-la-tar",
    "embolate": "em-bo-la-te",
    "embole": "em-bo-le",
    "embolia": "em-bo-lia",
    "embolicar": "em-bo-li-car",
    "embolinar": "em-bo-li-nar",
    "embolismador": "em-bo-lis-ma-dor",
    "embolismadora": "em-bo-lis-ma-do-ra",
    "embolismal": "em-bo-lis-mal",
    "embolismar": "em-bo-lis-mar",
    "embolismática": "em-bo-lis-má-ti-ca",
    "embolismático": "em-bo-lis-má-ti-co",
    "embolismo": "em-bo-lis-mo",
    "émbolo": "ém-bo-lo",
    "embolsamiento": "em-bol-sa-mien-to",
    "embolsar": "em-bol-sar",
    "embolsicar": "em-bol-si-car",
    "embolsillar": "em-bol-si-llar",
    "embolso": "em-bol-so",
    "embonada": "em-bo-na-da",
    "embonar": "em-bo-nar",
    "emboñigar": "em-bo-ñi-gar",
    "embono": "em-bo-no",
    "emboque": "em-bo-que",
    "emboquera": "em-bo-que-ra",
    "emboquillado": "em-bo-qui-lla-do",
    "emboquillar": "em-bo-qui-llar",
    "emboriado": "em-bo-ria-do",
    "embornal": "em-bor-nal",
    "embornar": "em-bor-nar",
    "emborrachacabras": "em-bo-rra-cha-ca-bras",
    "emborrachador": "em-bo-rra-cha-dor",
    "emborrachadora": "em-bo-rra-cha-do-ra",
    "emborrachamiento": "em-bo-rra-cha-mien-to",
    "emborrachar": "em-bo-rra-char",
    "emborrajar": "em-bo-rra-jar",
    "emborrar": "em-bo-rrar",
    "emborrascar": "em-bo-rras-car",
    "emborrazamiento": "em-bo-rra-za-mien-to",
    "emborrazar": "em-bo-rra-zar",
    "emborricar": "em-bo-rri-car",
    "emborricarse": "em-bo-rri-car-se",
    "emborrizar": "em-bo-rri-zar",
    "emborronador": "em-bo-rro-na-dor",
    "emborronadora": "em-bo-rro-na-do-ra",
    "emborronar": "em-bo-rro-nar",
    "emborrullar": "em-bo-rru-llar",
    "emborrullarse": "em-bo-rru-llar-se",
    "emborucar": "em-bo-ru-car",
    "emborujar": "em-bo-ru-jar",
    "emboscada": "em-bos-ca-da",
    "emboscado": "em-bos-ca-do",
    "emboscadura": "em-bos-ca-du-ra",
    "emboscar": "em-bos-car",
    "embosquecer": "em-bos-que-cer",
    "embostadero": "em-bos-ta-de-ro",
    "embostar": "em-bos-tar",
    "embotador": "em-bo-ta-dor",
    "embotadora": "em-bo-ta-do-ra",
    "embotadura": "em-bo-ta-du-ra",
    "embotamiento": "em-bo-ta-mien-to",
    "embotar": "em-bo-tar",
    "embotarse": "em-bo-tar-se",
    "embotellado": "em-bo-te-lla-do",
    "embotellador": "em-bo-te-lla-dor",
    "embotelladora": "em-bo-te-lla-do-ra",
    "embotellamiento": "em-bo-te-lla-mien-to",
    "embotellar": "em-bo-te-llar",
    "emboticar": "em-bo-ti-car",
    "embotijar": "em-bo-ti-jar",
    "embotir": "em-bo-tir",
    "embovedada": "em-bo-ve-da-da",
    "embovedado": "em-bo-ve-da-do",
    "embovedar": "em-bo-ve-dar",
    "emboza": "em-bo-za",
    "embozadamente": "em-bo-za-da-men-te",
    "embozalar": "em-bo-za-lar",
    "embozar": "em-bo-zar",
    "embozo": "em-bo-zo",
    "embracilada": "em-bra-ci-la-da",
    "embracilado": "em-bra-ci-la-do",
    "embracilar": "em-bra-ci-lar",
    "embragar": "em-bra-gar",
    "embrague": "em-bra-gue",
    "embraguetar": "em-bra-gue-tar",
    "embramado": "em-bra-ma-do",
    "embramar": "em-bra-mar",
    "embravecer": "em-bra-ve-cer",
    "embravecimiento": "em-bra-ve-ci-mien-to",
    "embrazadura": "em-bra-za-du-ra",
    "embrazar": "em-bra-zar",
    "embreada": "em-bre-a-da",
    "embreado": "em-bre-a-do",
    "embreadura": "em-bre-a-du-ra",
    "embrear": "em-bre-ar",
    "embregar": "em-bre-gar",
    "embregarse": "em-bre-gar-se",
    "embreñar": "em-bre-ñar",
    "embreñarse": "em-bre-ñar-se",
    "embriaga": "em-bria-ga",
    "embriagador": "em-bria-ga-dor",
    "embriagadora": "em-bria-ga-do-ra",
    "embriagante": "em-bria-gan-te",
    "embriagar": "em-bria-gar",
    "embriago": "em-bria-go",
    "embriaguez": "em-bria-guez",
    "embribar": "em-bri-bar",
    "embridar": "em-bri-dar",
    "embriogénesis": "em-brio-gé-ne-sis",
    "embriogenia": "em-brio-ge-nia",
    "embriogénica": "em-brio-gé-ni-ca",
    "embriogénico": "em-brio-gé-ni-co",
    "embrióloga": "em-brió-lo-ga",
    "embriología": "em-brio-lo-gí-a",
    "embriológica": "em-brio-ló-gi-ca",
    "embriológico": "em-brio-ló-gi-co",
    "embriólogo": "em-brió-lo-go",
    "embrión": "em-brión",
    "embrionaria": "em-brio-na-ria",
    "embrionario": "em-brio-na-rio",
    "embriopatía": "em-brio-pa-tí-a",
    "embrisar": "em-bri-sar",
    "émbroca": "ém-bro-ca",
    "embrocación": "em-bro-ca-ción",
    "embrocado": "em-bro-ca-do",
    "embrocar": "em-bro-car",
    "embrochada": "em-bro-cha-da",
    "embrochado": "em-bro-cha-do",
    "embrochalar": "em-bro-cha-lar",
    "embrolla": "em-bro-lla",
    "embrolladamente": "em-bro-lla-da-men-te",
    "embrollador": "em-bro-lla-dor",
    "embrolladora": "em-bro-lla-do-ra",
    "embrollar": "em-bro-llar",
    "embrollista": "em-bro-llis-ta",
    "embrollo": "em-bro-llo",
    "embrollón": "em-bro-llón",
    "embrollona": "em-bro-llo-na",
    "embrollosa": "em-bro-llo-sa",
    "embrolloso": "em-bro-llo-so",
    "embromador": "em-bro-ma-dor",
    "embromadora": "em-bro-ma-do-ra",
    "embromar": "em-bro-mar",
    "embromón": "em-bro-món",
    "embroncado": "em-bron-ca-do",
    "embroncar": "em-bron-car",
    "embroque": "em-bro-que",
    "embroquelar": "em-bro-que-lar",
    "embroquelarse": "em-bro-que-lar-se",
    "embroquetar": "em-bro-que-tar",
    "embrosquilar": "em-bros-qui-lar",
    "embrujador": "em-bru-ja-dor",
    "embrujadora": "em-bru-ja-do-ra",
    "embrujamiento": "em-bru-ja-mien-to",
    "embrujar": "em-bru-jar",
    "embrujo": "em-bru-jo",
    "embrutecedor": "em-bru-te-ce-dor",
    "embrutecedora": "em-bru-te-ce-do-ra",
    "embrutecer": "em-bru-te-cer",
    "embrutecido": "em-bru-te-ci-do",
    "embrutecimiento": "em-bru-te-ci-mien-to",
    "embuchado": "em-bu-cha-do",
    "embuchador": "em-bu-cha-dor",
    "embuchadora": "em-bu-cha-do-ra",
    "embuchar": "em-bu-char",
    "embudador": "em-bu-da-dor",
    "embudadora": "em-bu-da-do-ra",
    "embudar": "em-bu-dar",
    "embudista": "em-bu-dis-ta",
    "embudo": "em-bu-do",
    "embulismar": "em-bu-lis-mar",
    "embullado": "em-bu-lla-do",
    "embullador": "em-bu-lla-dor",
    "embulladora": "em-bu-lla-do-ra",
    "embullar": "em-bu-llar",
    "embullo": "em-bu-llo",
    "embuñegar": "em-bu-ñe-gar",
    "emburrado": "em-bu-rra-do",
    "emburrar": "em-bu-rrar",
    "emburriar": "em-bu-rriar",
    "emburujar": "em-bu-ru-jar",
    "emburujo": "em-bu-ru-jo",
    "embuste": "em-bus-te",
    "embustear": "em-bus-te-ar",
    "embustera": "em-bus-te-ra",
    "embustería": "em-bus-te-rí-a",
    "embustero": "em-bus-te-ro",
    "embustidor": "em-bus-ti-dor",
    "embustidora": "em-bus-ti-do-ra",
    "embustir": "em-bus-tir",
    "embutar": "em-bu-tar",
    "embutiar": "em-bu-tiar",
    "embutición": "em-bu-ti-ción",
    "embutida": "em-bu-ti-da",
    "embutidera": "em-bu-ti-de-ra",
    "embutido": "em-bu-ti-do",
    "embutidor": "em-bu-ti-dor",
    "embutidora": "em-bu-ti-do-ra",
    "embutir": "em-bu-tir",
    "embuzonar": "em-bu-zo-nar",
    "eme": "e-me",
    "emelga": "e-mel-ga",
    "emenagogo": "e-me-na-go-go",
    "emendación": "e-men-da-ción",
    "emendar": "e-men-dar",
    "emergencia": "e-mer-gen-cia",
    "emergente": "e-mer-gen-te",
    "emerger": "e-mer-ger",
    "emérita": "e-mé-ri-ta",
    "emeritense": "e-me-ri-ten-se",
    "emérito": "e-mé-ri-to",
    "emersión": "e-mer-sión",
    "emesis": "e-me-sis",
    "emética": "e-mé-ti-ca",
    "emético": "e-mé-ti-co",
    "emetina": "e-me-ti-na",
    "emétrope": "e-mé-tro-pe",
    "emetropía": "e-me-tro-pí-a",
    "emídido": "e-mí-di-do",
    "emidosaurio": "e-mi-do-sau-rio",
    "emienda": "e-mien-da",
    "emigración": "e-mi-gra-ción",
    "emigrada": "e-mi-gra-da",
    "emigrado": "e-mi-gra-do",
    "emigrante": "e-mi-gran-te",
    "emigrar": "e-mi-grar",
    "emigratoria": "e-mi-gra-to-ria",
    "emigratorio": "e-mi-gra-to-rio",
    "emilio": "e-mi-lio",
    "eminencia": "e-mi-nen-cia",
    "eminencial": "e-mi-nen-cial",
    "eminencialmente": "e-mi-nen-cial-men-te",
    "eminente": "e-mi-nen-te",
    "eminentemente": "e-mi-nen-te-men-te",
    "eminentísima": "e-mi-nen-tí-si-ma",
    "eminentísimo": "e-mi-nen-tí-si-mo",
    "emir": "e-mir",
    "emirato": "e-mi-ra-to",
    "emisaria": "e-mi-sa-ria",
    "emisario": "e-mi-sa-rio",
    "emisión": "e-mi-sión",
    "emisividad": "e-mi-si-vi-dad",
    "emisor": "e-mi-sor",
    "emisora": "e-mi-so-ra",
    "emitir": "e-mi-tir",
    "emmental": "em-men-tal",
    "emmenthal": "e-mmen-thal",
    "emoción": "e-mo-ción",
    "emocionable": "e-mo-cio-na-ble",
    "emocional": "e-mo-cio-nal",
    "emocionalidad": "e-mo-cio-na-li-dad",
    "emocionalmente": "e-mo-cio-nal-men-te",
    "emocionante": "e-mo-cio-nan-te",
    "emocionar": "e-mo-cio-nar",
    "emoliente": "e-mo-lien-te",
    "emolumento": "e-mo-lu-men-to",
    "emoticono": "e-mo-ti-co-no",
    "emotiva": "e-mo-ti-va",
    "emotividad": "e-mo-ti-vi-dad",
    "emotivo": "e-mo-ti-vo",
    "empacada": "em-pa-ca-da",
    "empacador": "em-pa-ca-dor",
    "empacadora": "em-pa-ca-do-ra",
    "empacamiento": "em-pa-ca-mien-to",
    "empacar": "em-pa-car",
    "empacarse": "em-pa-car-se",
    "empachada": "em-pa-cha-da",
    "empachadamente": "em-pa-cha-da-men-te",
    "empachado": "em-pa-cha-do",
    "empachador": "em-pa-cha-dor",
    "empachadora": "em-pa-cha-do-ra",
    "empachar": "em-pa-char",
    "empacho": "em-pa-cho",
    "empachosa": "em-pa-cho-sa",
    "empachoso": "em-pa-cho-so",
    "empacón": "em-pa-cón",
    "empacona": "em-pa-co-na",
    "empadrar": "em-pa-drar",
    "empadrarse": "em-pa-drar-se",
    "empadronador": "em-pa-dro-na-dor",
    "empadronadora": "em-pa-dro-na-do-ra",
    "empadronamiento": "em-pa-dro-na-mien-to",
    "empadronar": "em-pa-dro-nar",
    "empajada": "em-pa-ja-da",
    "empajar": "em-pa-jar",
    "empaje": "em-pa-je",
    "empajolar": "em-pa-jo-lar",
    "empalagada": "em-pa-la-ga-da",
    "empalagamiento": "em-pa-la-ga-mien-to",
    "empalagar": "em-pa-la-gar",
    "empalago": "em-pa-la-go",
    "empalagosa": "em-pa-la-go-sa",
    "empalagoso": "em-pa-la-go-so",
    "empalamiento": "em-pa-la-mien-to",
    "empalar": "em-pa-lar",
    "empaliar": "em-pa-liar",
    "empalicar": "em-pa-li-car",
    "empalidecer": "em-pa-li-de-cer",
    "empalizada": "em-pa-li-za-da",
    "empalizar": "em-pa-li-zar",
    "empalletado": "em-pa-lle-ta-do",
    "empalmadura": "em-pal-ma-du-ra",
    "empalmar": "em-pal-mar",
    "empalme": "em-pal-me",
    "empalomado": "em-pa-lo-ma-do",
    "empalomadura": "em-pa-lo-ma-du-ra",
    "empalomar": "em-pa-lo-mar",
    "empampar": "em-pam-par",
    "empamparse": "em-pam-par-se",
    "empampirolada": "em-pam-pi-ro-la-da",
    "empampirolado": "em-pam-pi-ro-la-do",
    "empanada": "em-pa-na-da",
    "empanadilla": "em-pa-na-di-lla",
    "empanado": "em-pa-na-do",
    "empañadura": "em-pa-ña-du-ra",
    "empañamiento": "em-pa-ña-mien-to",
    "empanar": "em-pa-nar",
    "empañar": "em-pa-ñar",
    "empandar": "em-pan-dar",
    "empandillar": "em-pan-di-llar",
    "empandorgar": "em-pan-dor-gar",
    "empañetar": "em-pa-ñe-tar",
    "empañete": "em-pa-ñe-te",
    "empañicar": "em-pa-ñi-car",
    "empanizado": "em-pa-ni-za-do",
    "empanizar": "em-pa-ni-zar",
    "empantalonar": "em-pan-ta-lo-nar",
    "empantanada": "em-pan-ta-na-da",
    "empantanar": "em-pan-ta-nar",
    "empanzamiento": "em-pan-za-mien-to",
    "empanzar": "em-pan-zar",
    "empapada": "em-pa-pa-da",
    "empapamiento": "em-pa-pa-mien-to",
    "empapar": "em-pa-par",
    "empapayado": "em-pa-pa-ya-do",
    "empapelado": "em-pa-pe-la-do",
    "empapelador": "em-pa-pe-la-dor",
    "empapeladora": "em-pa-pe-la-do-ra",
    "empapelar": "em-pa-pe-lar",
    "empapelonar": "em-pa-pe-lo-nar",
    "empapirotar": "em-pa-pi-ro-tar",
    "empapizar": "em-pa-pi-zar",
    "empapuciar": "em-pa-pu-ciar",
    "empapujar": "em-pa-pu-jar",
    "empapuzar": "em-pa-pu-zar",
    "empaque": "em-pa-que",
    "empaquetado": "em-pa-que-ta-do",
    "empaquetador": "em-pa-que-ta-dor",
    "empaquetadora": "em-pa-que-ta-do-ra",
    "empaquetadura": "em-pa-que-ta-du-ra",
    "empaquetamiento": "em-pa-que-ta-mien-to",
    "empaquetar": "em-pa-que-tar",
    "emparafinado": "em-pa-ra-fi-na-do",
    "emparafinar": "em-pa-ra-fi-nar",
    "emparamar": "em-pa-ra-mar",
    "emparamentar": "em-pa-ra-men-tar",
    "emparchar": "em-par-char",
    "empardar": "em-par-dar",
    "emparedada": "em-pa-re-da-da",
    "emparedado": "em-pa-re-da-do",
    "emparedamiento": "em-pa-re-da-mien-to",
    "emparedar": "em-pa-re-dar",
    "emparejada": "em-pa-re-ja-da",
    "emparejado": "em-pa-re-ja-do",
    "emparejador": "em-pa-re-ja-dor",
    "emparejadora": "em-pa-re-ja-do-ra",
    "emparejadura": "em-pa-re-ja-du-ra",
    "emparejamiento": "em-pa-re-ja-mien-to",
    "emparejar": "em-pa-re-jar",
    "emparejo": "em-pa-re-jo",
    "emparentar": "em-pa-ren-tar",
    "emparrada": "em-pa-rra-da",
    "emparrado": "em-pa-rra-do",
    "emparrandado": "em-pa-rran-da-do",
    "emparrandar": "em-pa-rran-dar",
    "emparrar": "em-pa-rrar",
    "emparrillado": "em-pa-rri-lla-do",
    "emparrillar": "em-pa-rri-llar",
    "emparvar": "em-par-var",
    "empastado": "em-pas-ta-do",
    "empastador": "em-pas-ta-dor",
    "empastadora": "em-pas-ta-do-ra",
    "empastadura": "em-pas-ta-du-ra",
    "empastar": "em-pas-tar",
    "empaste": "em-pas-te",
    "empastelamiento": "em-pas-te-la-mien-to",
    "empastelar": "em-pas-te-lar",
    "empatacado": "em-pa-ta-ca-do",
    "empatadera": "em-pa-ta-de-ra",
    "empatar": "em-pa-tar",
    "empate": "em-pa-te",
    "empatía": "em-pa-tí-a",
    "empato": "em-pa-to",
    "empatucar": "em-pa-tu-car",
    "empautado": "em-pau-ta-do",
    "empavar": "em-pa-var",
    "empavesada": "em-pa-ve-sa-da",
    "empavesado": "em-pa-ve-sa-do",
    "empavesar": "em-pa-ve-sar",
    "empavonar": "em-pa-vo-nar",
    "empavorecer": "em-pa-vo-re-cer",
    "empecatada": "em-pe-ca-ta-da",
    "empecatado": "em-pe-ca-ta-do",
    "empecedera": "em-pe-ce-de-ra",
    "empecedero": "em-pe-ce-de-ro",
    "empecedor": "em-pe-ce-dor",
    "empecedora": "em-pe-ce-do-ra",
    "empecer": "em-pe-cer",
    "empechar": "em-pe-char",
    "empecible": "em-pe-ci-ble",
    "empeciente": "em-pe-cien-te",
    "empecimiento": "em-pe-ci-mien-to",
    "empecinada": "em-pe-ci-na-da",
    "empecinado": "em-pe-ci-na-do",
    "empecinamiento": "em-pe-ci-na-mien-to",
    "empecinar": "em-pe-ci-nar",
    "empecinarse": "em-pe-ci-nar-se",
    "empedar": "em-pe-dar",
    "empedecer": "em-pe-de-cer",
    "empedernecer": "em-pe-der-ne-cer",
    "empedernida": "em-pe-der-ni-da",
    "empedernido": "em-pe-der-ni-do",
    "empedernir": "em-pe-der-nir",
    "empedrada": "em-pe-dra-da",
    "empedrado": "em-pe-dra-do",
    "empedrador": "em-pe-dra-dor",
    "empedramiento": "em-pe-dra-mien-to",
    "empedrar": "em-pe-drar",
    "empega": "em-pe-ga",
    "empegado": "em-pe-ga-do",
    "empegadura": "em-pe-ga-du-ra",
    "empegar": "em-pe-gar",
    "empego": "em-pe-go",
    "empegotar": "em-pe-go-tar",
    "empeguntar": "em-pe-gun-tar",
    "empeine": "em-pei-ne",
    "empeinosa": "em-pei-no-sa",
    "empeinoso": "em-pei-no-so",
    "empelar": "em-pe-lar",
    "empelazgar": "em-pe-laz-gar",
    "empelazgarse": "em-pe-laz-gar-se",
    "empelechar": "em-pe-le-char",
    "empella": "em-pe-lla",
    "empellar": "em-pe-llar",
    "empellejar": "em-pe-lle-jar",
    "empeller": "em-pe-ller",
    "empellicar": "em-pe-lli-car",
    "empellón": "em-pe-llón",
    "empelotamiento": "em-pe-lo-ta-mien-to",
    "empelotar": "em-pe-lo-tar",
    "empelotarse": "em-pe-lo-tar-se",
    "empeloto": "em-pe-lo-to",
    "empelte": "em-pel-te",
    "empeltre": "em-pel-tre",
    "empelucado": "em-pe-lu-ca-do",
    "empeña": "em-pe-ña",
    "empenachada": "em-pe-na-cha-da",
    "empenachado": "em-pe-na-cha-do",
    "empenachar": "em-pe-na-char",
    "empeñada": "em-pe-ña-da",
    "empeñadamente": "em-pe-ña-da-men-te",
    "empeñado": "em-pe-ña-do",
    "empeñamiento": "em-pe-ña-mien-to",
    "empeñar": "em-pe-ñar",
    "empendolar": "em-pen-do-lar",
    "empeño": "em-pe-ño",
    "empeñosa": "em-pe-ño-sa",
    "empeñosamente": "em-pe-ño-sa-men-te",
    "empeñoso": "em-pe-ño-so",
    "empenta": "em-pen-ta",
    "empentar": "em-pen-tar",
    "empentón": "em-pen-tón",
    "empeoramiento": "em-pe-o-ra-mien-to",
    "empeorar": "em-pe-o-rar",
    "empepar": "em-pe-par",
    "empepitar": "em-pe-pi-tar",
    "empequeñecer": "em-pe-que-ñe-cer",
    "empequeñecimiento": "em-pe-que-ñe-ci-mien-to",
    "emperador": "em-pe-ra-dor",
    "emperadora": "em-pe-ra-do-ra",
    "emperatriz": "em-pe-ra-triz",
    "emperchado": "em-per-cha-do",
    "emperchar": "em-per-char",
    "empercudir": "em-per-cu-dir",
    "emperdigar": "em-per-di-gar",
    "emperejilar": "em-pe-re-ji-lar",
    "emperendengar": "em-pe-ren-den-gar",
    "emperezar": "em-pe-re-zar",
    "empergaminar": "em-per-ga-mi-nar",
    "empericar": "em-pe-ri-car",
    "empericuetar": "em-pe-ri-cue-tar",
    "emperifollado": "em-pe-ri-fo-lla-do",
    "emperifollar": "em-pe-ri-fo-llar",
    "empernar": "em-per-nar",
    "empero": "em-pe-ro",
    "emperrada": "em-pe-rra-da",
    "emperramiento": "em-pe-rra-mien-to",
    "emperrar": "em-pe-rrar",
    "emperrarse": "em-pe-rrar-se",
    "emperro": "em-pe-rro",
    "empersonar": "em-per-so-nar",
    "empesador": "em-pe-sa-dor",
    "empesgar": "em-pes-gar",
    "empesgue": "em-pes-gue",
    "empestar": "em-pes-tar",
    "empestillar": "em-pes-ti-llar",
    "empetatar": "em-pe-ta-tar",
    "empetro": "em-pe-tro",
    "empezamiento": "em-pe-za-mien-to",
    "empezar": "em-pe-zar",
    "empicar": "em-pi-car",
    "empicarse": "em-pi-car-se",
    "empichar": "em-pi-char",
    "empicotadura": "em-pi-co-ta-du-ra",
    "empicotar": "em-pi-co-tar",
    "empiece": "em-pie-ce",
    "empiema": "em-pie-ma",
    "empiernar": "em-pier-nar",
    "empiezo": "em-pie-zo",
    "empigüelar": "em-pi-güe-lar",
    "empilar": "em-pi-lar",
    "empilchado": "em-pil-cha-do",
    "empilchar": "em-pil-char",
    "empilonar": "em-pi-lo-nar",
    "empiltrar": "em-pil-trar",
    "empiluchar": "em-pi-lu-char",
    "empina": "em-pi-na",
    "empinada": "em-pi-na-da",
    "empinado": "em-pi-na-do",
    "empinadura": "em-pi-na-du-ra",
    "empinamiento": "em-pi-na-mien-to",
    "empinar": "em-pi-nar",
    "empiñatado": "em-pi-ña-ta-do",
    "empingorotada": "em-pin-go-ro-ta-da",
    "empingorotado": "em-pin-go-ro-ta-do",
    "empingorotar": "em-pin-go-ro-tar",
    "empino": "em-pi-no",
    "empiñonado": "em-pi-ño-na-do",
    "empiojar": "em-pio-jar",
    "empiolar": "em-pio-lar",
    "empipada": "em-pi-pa-da",
    "empipar": "em-pi-par",
    "empírea": "em-pí-re-a",
    "empíreo": "em-pí-re-o",
    "empireuma": "em-pi-reu-ma",
    "empireumática": "em-pi-reu-má-ti-ca",
    "empireumático": "em-pi-reu-má-ti-co",
    "empírica": "em-pí-ri-ca",
    "empíricamente": "em-pí-ri-ca-men-te",
    "empírico": "em-pí-ri-co",
    "empirismo": "em-pi-ris-mo",
    "empirista": "em-pi-ris-ta",
    "empirocriticismo": "em-pi-ro-cri-ti-cis-mo",
    "empistolado": "em-pis-to-la-do",
    "empistolar": "em-pis-to-lar",
    "empitonar": "em-pi-to-nar",
    "empizarrado": "em-pi-za-rra-do",
    "empizarrar": "em-pi-za-rrar",
    "empizcar": "em-piz-car",
    "emplantillar": "em-plan-ti-llar",
    "emplastadura": "em-plas-ta-du-ra",
    "emplastamiento": "em-plas-ta-mien-to",
    "emplastar": "em-plas-tar",
    "emplaste": "em-plas-te",
    "emplastecer": "em-plas-te-cer",
    "emplástica": "em-plás-ti-ca",
    "emplástico": "em-plás-ti-co",
    "emplasto": "em-plas-to",
    "emplástrica": "em-plás-tri-ca",
    "emplástrico": "em-plás-tri-co",
    "emplastro": "em-plas-tro",
    "emplatar": "em-pla-tar",
    "emplazador": "em-pla-za-dor",
    "emplazamiento": "em-pla-za-mien-to",
    "emplazar": "em-pla-zar",
    "emplea": "em-ple-a",
    "empleada": "em-ple-a-da",
    "empleado": "em-ple-a-do",
    "empleador": "em-ple-a-dor",
    "empleadora": "em-ple-a-do-ra",
    "emplear": "em-ple-ar",
    "emplebeyecer": "em-ple-be-ye-cer",
    "empleita": "em-plei-ta",
    "empleitar": "em-plei-tar",
    "empleitera": "em-plei-te-ra",
    "empleitero": "em-plei-te-ro",
    "emplenta": "em-plen-ta",
    "empleo": "em-ple-o",
    "empleomanía": "em-ple-o-ma-ní-a",
    "emplomado": "em-plo-ma-do",
    "emplomador": "em-plo-ma-dor",
    "emplomadura": "em-plo-ma-du-ra",
    "emplomar": "em-plo-mar",
    "emplumajar": "em-plu-ma-jar",
    "emplumar": "em-plu-mar",
    "emplumecer": "em-plu-me-cer",
    "empobrecedor": "em-po-bre-ce-dor",
    "empobrecedora": "em-po-bre-ce-do-ra",
    "empobrecer": "em-po-bre-cer",
    "empobrecimiento": "em-po-bre-ci-mien-to",
    "empoderar": "em-po-de-rar",
    "empodrecer": "em-po-dre-cer",
    "empolla": "em-po-lla",
    "empolladura": "em-po-lla-du-ra",
    "empollar": "em-po-llar",
    "empollón": "em-po-llón",
    "empollona": "em-po-llo-na",
    "empoltronecer": "em-pol-tro-ne-cer",
    "empoltronecerse": "em-pol-tro-ne-cer-se",
    "empolvado": "em-pol-va-do",
    "empolvar": "em-pol-var",
    "empolvoramiento": "em-pol-vo-ra-mien-to",
    "empolvorar": "em-pol-vo-rar",
    "empolvorizar": "em-pol-vo-ri-zar",
    "emponchada": "em-pon-cha-da",
    "emponchado": "em-pon-cha-do",
    "emponchar": "em-pon-char",
    "emponzoñador": "em-pon-zo-ña-dor",
    "emponzoñadora": "em-pon-zo-ña-do-ra",
    "emponzoñamiento": "em-pon-zo-ña-mien-to",
    "emponzoñar": "em-pon-zo-ñar",
    "empopada": "em-po-pa-da",
    "empopar": "em-po-par",
    "emporar": "em-po-rar",
    "emporcar": "em-por-car",
    "emporio": "em-po-rio",
    "emporitana": "em-po-ri-ta-na",
    "emporitano": "em-po-ri-ta-no",
    "emporrado": "em-po-rra-do",
    "emporrar": "em-po-rrar",
    "empós": "em-pós",
    "empotar": "em-po-tar",
    "empotrado": "em-po-tra-do",
    "empotrador": "em-po-tra-dor",
    "empotramiento": "em-po-tra-mien-to",
    "empotrar": "em-po-trar",
    "empotrerar": "em-po-tre-rar",
    "empotría": "em-po-trí-a",
    "empozar": "em-po-zar",
    "empradizar": "em-pra-di-zar",
    "emprar": "em-prar",
    "empreñación": "em-pre-ña-ción",
    "empreñador": "em-pre-ña-dor",
    "empreñar": "em-pre-ñar",
    "emprendedor": "em-pren-de-dor",
    "emprendedora": "em-pren-de-do-ra",
    "emprendengar": "em-pren-den-gar",
    "emprender": "em-pren-der",
    "emprensar": "em-pren-sar",
    "emprenta": "em-pren-ta",
    "emprentar": "em-pren-tar",
    "empresa": "em-pre-sa",
    "empresaria": "em-pre-sa-ria",
    "empresariado": "em-pre-sa-ria-do",
    "empresarial": "em-pre-sa-rial",
    "empresario": "em-pre-sa-rio",
    "empresentar": "em-pre-sen-tar",
    "emprestado": "em-pres-ta-do",
    "emprestador": "em-pres-ta-dor",
    "empréstamo": "em-prés-ta-mo",
    "emprestar": "em-pres-tar",
    "empréstido": "em-prés-ti-do",
    "emprestillador": "em-pres-ti-lla-dor",
    "emprestilladora": "em-pres-ti-lla-do-ra",
    "emprestillar": "em-pres-ti-llar",
    "emprestillón": "em-pres-ti-llón",
    "emprestillona": "em-pres-ti-llo-na",
    "empréstito": "em-prés-ti-to",
    "empretecer": "em-pre-te-cer",
    "emprima": "em-pri-ma",
    "emprimado": "em-pri-ma-do",
    "emprimar": "em-pri-mar",
    "emprimir": "em-pri-mir",
    "empringar": "em-prin-gar",
    "empuchar": "em-pu-char",
    "empuercar": "em-puer-car",
    "empuesta": "em-pues-ta",
    "empujada": "em-pu-ja-da",
    "empujador": "em-pu-ja-dor",
    "empujadora": "em-pu-ja-do-ra",
    "empujar": "em-pu-jar",
    "empuje": "em-pu-je",
    "empujo": "em-pu-jo",
    "empujón": "em-pu-jón",
    "empulgadera": "em-pul-ga-de-ra",
    "empulgadura": "em-pul-ga-du-ra",
    "empulgar": "em-pul-gar",
    "empulguera": "em-pul-gue-ra",
    "empulgueras": "em-pul-gue-ras",
    "empuñador": "em-pu-ña-dor",
    "empuñadora": "em-pu-ña-do-ra",
    "empuñadura": "em-pu-ña-du-ra",
    "empuñar": "em-pu-ñar",
    "empuñidura": "em-pu-ñi-du-ra",
    "empuntar": "em-pun-tar",
    "empurar": "em-pu-rar",
    "empurpurada": "em-pur-pu-ra-da",
    "empurpurado": "em-pur-pu-ra-do",
    "empurrada": "em-pu-rra-da",
    "empurrado": "em-pu-rra-do",
    "empurrar": "em-pu-rrar",
    "empurrarse": "em-pu-rrar-se",
    "emputar": "em-pu-tar",
    "empute": "em-pu-te",
    "emputecer": "em-pu-te-cer",
    "emputecimiento": "em-pu-te-ci-mien-to",
    "empuyar": "em-pu-yar",
    "empuyarse": "em-pu-yar-se",
    "emú": "e-mú",
    "émula": "é-mu-la",
    "emulación": "e-mu-la-ción",
    "emulador": "e-mu-la-dor",
    "emuladora": "e-mu-la-do-ra",
    "emular": "e-mu-lar",
    "emulativo": "e-mu-la-ti-vo",
    "emulgente": "e-mul-gen-te",
    "émulo": "é-mu-lo",
    "emulsión": "e-mul-sión",
    "emulsionante": "e-mul-sio-nan-te",
    "emulsionar": "e-mul-sio-nar",
    "emulsiva": "e-mul-si-va",
    "emulsivo": "e-mul-si-vo",
    "emulsor": "e-mul-sor",
    "emunción": "e-mun-ción",
    "emundación": "e-mun-da-ción",
    "emuntorio": "e-mun-to-rio",
    "enaceitar": "e-na-cei-tar",
    "enacerar": "e-na-ce-rar",
    "enaciada": "e-na-cia-da",
    "enaciado": "e-na-cia-do",
    "enaciyar": "e-na-ci-yar",
    "enagua": "e-na-gua",
    "enaguachar": "e-na-gua-char",
    "enaguar": "e-na-guar",
    "enaguazar": "e-na-gua-zar",
    "enagüetas": "e-na-güe-tas",
    "enagüillas": "e-na-güi-llas",
    "enajenable": "e-na-je-na-ble",
    "enajenación": "e-na-je-na-ción",
    "enajenada": "e-na-je-na-da",
    "enajenado": "e-na-je-na-do",
    "enajenador": "e-na-je-na-dor",
    "enajenadora": "e-na-je-na-do-ra",
    "enajenamiento": "e-na-je-na-mien-to",
    "enajenante": "e-na-je-nan-te",
    "enajenar": "e-na-je-nar",
    "enálage": "e-ná-la-ge",
    "enalbar": "e-nal-bar",
    "enalbardar": "e-nal-bar-dar",
    "enalmagrada": "e-nal-ma-gra-da",
    "enalmagrado": "e-nal-ma-gra-do",
    "enalmagrar": "e-nal-ma-grar",
    "enaltecedor": "e-nal-te-ce-dor",
    "enaltecedora": "e-nal-te-ce-do-ra",
    "enaltecer": "e-nal-te-cer",
    "enaltecimiento": "e-nal-te-ci-mien-to",
    "enamarillecer": "e-na-ma-ri-lle-cer",
    "enamorada": "e-na-mo-ra-da",
    "enamoradamente": "e-na-mo-ra-da-men-te",
    "enamoradiza": "e-na-mo-ra-di-za",
    "enamoradizo": "e-na-mo-ra-di-zo",
    "enamorado": "e-na-mo-ra-do",
    "enamorador": "e-na-mo-ra-dor",
    "enamoradora": "e-na-mo-ra-do-ra",
    "enamoramiento": "e-na-mo-ra-mien-to",
    "enamorar": "e-na-mo-rar",
    "enamoricar": "e-na-mo-ri-car",
    "enamoricarse": "e-na-mo-ri-car-se",
    "enamoriscar": "e-na-mo-ris-car",
    "enamoriscarse": "e-na-mo-ris-car-se",
    "enana": "e-na-na",
    "enanar": "e-na-nar",
    "enanarse": "e-na-nar-se",
    "enancar": "e-nan-car",
    "enancarse": "e-nan-car-se",
    "enanchar": "e-nan-char",
    "enangostar": "e-nan-gos-tar",
    "enanismo": "e-na-nis-mo",
    "enano": "e-na-no",
    "enante": "e-nan-te",
    "enantes": "e-nan-tes",
    "enanzar": "e-nan-zar",
    "enarbolado": "e-nar-bo-la-do",
    "enarbolar": "e-nar-bo-lar",
    "enarcar": "e-nar-car",
    "enardecedor": "e-nar-de-ce-dor",
    "enardecedora": "e-nar-de-ce-do-ra",
    "enardecer": "e-nar-de-cer",
    "enardecimiento": "e-nar-de-ci-mien-to",
    "enarenación": "e-na-re-na-ción",
    "enarenar": "e-na-re-nar",
    "enarmonar": "e-nar-mo-nar",
    "enarmonía": "e-nar-mo-ní-a",
    "enarmónica": "e-nar-mó-ni-ca",
    "enarmónico": "e-nar-mó-ni-co",
    "enarración": "e-na-rra-ción",
    "enarrar": "e-na-rrar",
    "enartamiento": "e-nar-ta-mien-to",
    "enartar": "e-nar-tar",
    "enartrosis": "e-nar-tro-sis",
    "enaspar": "e-nas-par",
    "enastada": "e-nas-ta-da",
    "enastado": "e-nas-ta-do",
    "enastar": "e-nas-tar",
    "enastilar": "e-nas-ti-lar",
    "enatía": "e-na-tí-a",
    "enatíamente": "e-na-tí-a-men-te",
    "enatieza": "e-na-tie-za",
    "enatío": "e-na-tí-o",
    "encabalgamiento": "en-ca-bal-ga-mien-to",
    "encabalgante": "en-ca-bal-gan-te",
    "encabalgar": "en-ca-bal-gar",
    "encaballado": "en-ca-ba-lla-do",
    "encaballar": "en-ca-ba-llar",
    "encabangado": "en-ca-ban-ga-do",
    "encabar": "en-ca-bar",
    "encabe": "en-ca-be",
    "encabellar": "en-ca-be-llar",
    "encabellecer": "en-ca-be-lle-cer",
    "encabellecerse": "en-ca-be-lle-cer-se",
    "encabestradura": "en-ca-bes-tra-du-ra",
    "encabestrar": "en-ca-bes-trar",
    "encabezado": "en-ca-be-za-do",
    "encabezamiento": "en-ca-be-za-mien-to",
    "encabezar": "en-ca-be-zar",
    "encabezonamiento": "en-ca-be-zo-na-mien-to",
    "encabezonar": "en-ca-be-zo-nar",
    "encabillado": "en-ca-bi-lla-do",
    "encabrahigar": "en-ca-brahi-gar",
    "encabrestar": "en-ca-bres-tar",
    "encabriar": "en-ca-briar",
    "encabrillar": "en-ca-bri-llar",
    "encabritar": "en-ca-bri-tar",
    "encabronar": "en-ca-bro-nar",
    "encabruñar": "en-ca-bru-ñar",
    "encabullar": "en-ca-bu-llar",
    "encabuyar": "en-ca-bu-yar",
    "encachada": "en-ca-cha-da",
    "encachado": "en-ca-cha-do",
    "encachar": "en-ca-char",
    "encachilar": "en-ca-chi-lar",
    "encachimbada": "en-ca-chim-ba-da",
    "encachimbado": "en-ca-chim-ba-do",
    "encachimbar": "en-ca-chim-bar",
    "encadar": "en-ca-dar",
    "encadarse": "en-ca-dar-se",
    "encadenación": "en-ca-de-na-ción",
    "encadenada": "en-ca-de-na-da",
    "encadenado": "en-ca-de-na-do",
    "encadenadura": "en-ca-de-na-du-ra",
    "encadenamiento": "en-ca-de-na-mien-to",
    "encadenar": "en-ca-de-nar",
    "encaecer": "en-ca-e-cer",
    "encaecida": "en-ca-e-ci-da",
    "encajadas": "en-ca-ja-das",
    "encajado": "en-ca-ja-do",
    "encajador": "en-ca-ja-dor",
    "encajadura": "en-ca-ja-du-ra",
    "encajamiento": "en-ca-ja-mien-to",
    "encajar": "en-ca-jar",
    "encaje": "en-ca-je",
    "encajera": "en-ca-je-ra",
    "encajerar": "en-ca-je-rar",
    "encajerarse": "en-ca-je-rar-se",
    "encajero": "en-ca-je-ro",
    "encajetillar": "en-ca-je-ti-llar",
    "encajonado": "en-ca-jo-na-do",
    "encajonamiento": "en-ca-jo-na-mien-to",
    "encajonar": "en-ca-jo-nar",
    "encajosa": "en-ca-jo-sa",
    "encajoso": "en-ca-jo-so",
    "encalabernado": "en-ca-la-ber-na-do",
    "encalabernar": "en-ca-la-ber-nar",
    "encalabozar": "en-ca-la-bo-zar",
    "encalabriar": "en-ca-la-briar",
    "encalabrinado": "en-ca-la-bri-na-do",
    "encalabrinamiento": "en-ca-la-bri-na-mien-to",
    "encalabrinar": "en-ca-la-bri-nar",
    "encalada": "en-ca-la-da",
    "encalado": "en-ca-la-do",
    "encalador": "en-ca-la-dor",
    "encaladora": "en-ca-la-do-ra",
    "encaladura": "en-ca-la-du-ra",
    "encalambrar": "en-ca-lam-brar",
    "encalambrarse": "en-ca-lam-brar-se",
    "encalamocar": "en-ca-la-mo-car",
    "encalar": "en-ca-lar",
    "encalatar": "en-ca-la-tar",
    "encalcar": "en-cal-car",
    "encaletar": "en-ca-le-tar",
    "encalichar": "en-ca-li-char",
    "encalillar": "en-ca-li-llar",
    "encalladero": "en-ca-lla-de-ro",
    "encalladura": "en-ca-lla-du-ra",
    "encallar": "en-ca-llar",
    "encallecer": "en-ca-lle-cer",
    "encallejonar": "en-ca-lle-jo-nar",
    "encalletrar": "en-ca-lle-trar",
    "encalmadura": "en-cal-ma-du-ra",
    "encalmar": "en-cal-mar",
    "encalo": "en-ca-lo",
    "encalostrar": "en-ca-los-trar",
    "encalostrarse": "en-ca-los-trar-se",
    "encalvar": "en-cal-var",
    "encalvecer": "en-cal-ve-cer",
    "encalzar": "en-cal-zar",
    "encamación": "en-ca-ma-ción",
    "encamada": "en-ca-ma-da",
    "encamado": "en-ca-ma-do",
    "encamar": "en-ca-mar",
    "encamarar": "en-ca-ma-rar",
    "encambijar": "en-cam-bi-jar",
    "encambrar": "en-cam-brar",
    "encambronar": "en-cam-bro-nar",
    "encame": "en-ca-me",
    "encaminadura": "en-ca-mi-na-du-ra",
    "encaminamiento": "en-ca-mi-na-mien-to",
    "encaminar": "en-ca-mi-nar",
    "encamisada": "en-ca-mi-sa-da",
    "encamisar": "en-ca-mi-sar",
    "encamonada": "en-ca-mo-na-da",
    "encamonado": "en-ca-mo-na-do",
    "encamorrar": "en-ca-mo-rrar",
    "encamotado": "en-ca-mo-ta-do",
    "encamotar": "en-ca-mo-tar",
    "encamotarse": "en-ca-mo-tar-se",
    "encampanada": "en-cam-pa-na-da",
    "encampanado": "en-cam-pa-na-do",
    "encampanar": "en-cam-pa-nar",
    "encañada": "en-ca-ña-da",
    "encañado": "en-ca-ña-do",
    "encañador": "en-ca-ña-dor",
    "encañadora": "en-ca-ña-do-ra",
    "encañadura": "en-ca-ña-du-ra",
    "encanalar": "en-ca-na-lar",
    "encanalizar": "en-ca-na-li-zar",
    "encanallamiento": "en-ca-na-lla-mien-to",
    "encanallar": "en-ca-na-llar",
    "encañamar": "en-ca-ña-mar",
    "encanamento": "en-ca-na-men-to",
    "encanar": "en-ca-nar",
    "encañar": "en-ca-ñar",
    "encanarse": "en-ca-nar-se",
    "encanastar": "en-ca-nas-tar",
    "encancerar": "en-can-ce-rar",
    "encancerarse": "en-can-ce-rar-se",
    "encandecer": "en-can-de-cer",
    "encandelar": "en-can-de-lar",
    "encandelillar": "en-can-de-li-llar",
    "encandilada": "en-can-di-la-da",
    "encandiladera": "en-can-di-la-de-ra",
    "encandilado": "en-can-di-la-do",
    "encandilador": "en-can-di-la-dor",
    "encandiladora": "en-can-di-la-do-ra",
    "encandilar": "en-can-di-lar",
    "encanecer": "en-ca-ne-cer",
    "encanecimiento": "en-ca-ne-ci-mien-to",
    "encangrejar": "en-can-gre-jar",
    "encanijado": "en-ca-ni-ja-do",
    "encanijamiento": "en-ca-ni-ja-mien-to",
    "encanijar": "en-ca-ni-jar",
    "encanillar": "en-ca-ni-llar",
    "encañizada": "en-ca-ñi-za-da",
    "encañizar": "en-ca-ñi-zar",
    "encañonada": "en-ca-ño-na-da",
    "encañonado": "en-ca-ño-na-do",
    "encañonar": "en-ca-ño-nar",
    "encantación": "en-can-ta-ción",
    "encantada": "en-can-ta-da",
    "encantadera": "en-can-ta-de-ra",
    "encantado": "en-can-ta-do",
    "encantador": "en-can-ta-dor",
    "encantadora": "en-can-ta-do-ra",
    "encantamento": "en-can-ta-men-to",
    "encantamiento": "en-can-ta-mien-to",
    "encantar": "en-can-tar",
    "encantarar": "en-can-ta-rar",
    "encante": "en-can-te",
    "encanto": "en-can-to",
    "encantorio": "en-can-to-rio",
    "encantusar": "en-can-tu-sar",
    "encanutar": "en-ca-nu-tar",
    "encañutar": "en-ca-ñu-tar",
    "encapacetada": "en-ca-pa-ce-ta-da",
    "encapacetado": "en-ca-pa-ce-ta-do",
    "encapachadura": "en-ca-pa-cha-du-ra",
    "encapachar": "en-ca-pa-char",
    "encapada": "en-ca-pa-da",
    "encapado": "en-ca-pa-do",
    "encapar": "en-ca-par",
    "encapazar": "en-ca-pa-zar",
    "encaperuzar": "en-ca-pe-ru-zar",
    "encapillada": "en-ca-pi-lla-da",
    "encapillado": "en-ca-pi-lla-do",
    "encapilladura": "en-ca-pi-lla-du-ra",
    "encapillar": "en-ca-pi-llar",
    "encapirotar": "en-ca-pi-ro-tar",
    "encapotadura": "en-ca-po-ta-du-ra",
    "encapotamiento": "en-ca-po-ta-mien-to",
    "encapotar": "en-ca-po-tar",
    "encaprichamiento": "en-ca-pri-cha-mien-to",
    "encaprichar": "en-ca-pri-char",
    "encapricharse": "en-ca-pri-char-se",
    "encapsular": "en-cap-su-lar",
    "encapuchada": "en-ca-pu-cha-da",
    "encapuchado": "en-ca-pu-cha-do",
    "encapuchar": "en-ca-pu-char",
    "encapullada": "en-ca-pu-lla-da",
    "encapullado": "en-ca-pu-lla-do",
    "encapuzar": "en-ca-pu-zar",
    "encarada": "en-ca-ra-da",
    "encarado": "en-ca-ra-do",
    "encarajinar": "en-ca-ra-ji-nar",
    "encaramadura": "en-ca-ra-ma-du-ra",
    "encaramar": "en-ca-ra-mar",
    "encaramiento": "en-ca-ra-mien-to",
    "encarar": "en-ca-rar",
    "encaratular": "en-ca-ra-tu-lar",
    "encaratularse": "en-ca-ra-tu-lar-se",
    "encarcajada": "en-car-ca-ja-da",
    "encarcajado": "en-car-ca-ja-do",
    "encarcavinar": "en-car-ca-vi-nar",
    "encarcelación": "en-car-ce-la-ción",
    "encarcelado": "en-car-ce-la-do",
    "encarcelador": "en-car-ce-la-dor",
    "encarceladora": "en-car-ce-la-do-ra",
    "encarcelamiento": "en-car-ce-la-mien-to",
    "encarcelar": "en-car-ce-lar",
    "encarcerar": "en-car-ce-rar",
    "encarecedor": "en-ca-re-ce-dor",
    "encarecedora": "en-ca-re-ce-do-ra",
    "encarecer": "en-ca-re-cer",
    "encarecidamente": "en-ca-re-ci-da-men-te",
    "encarecimiento": "en-ca-re-ci-mien-to",
    "encargada": "en-car-ga-da",
    "encargadamente": "en-car-ga-da-men-te",
    "encargado": "en-car-ga-do",
    "encargamiento": "en-car-ga-mien-to",
    "encargar": "en-car-gar",
    "encargo": "en-car-go",
    "encariñar": "en-ca-ri-ñar",
    "encarna": "en-car-na",
    "encarnacena": "en-car-na-ce-na",
    "encarnaceno": "en-car-na-ce-no",
    "encarnación": "en-car-na-ción",
    "encarnada": "en-car-na-da",
    "encarnadina": "en-car-na-di-na",
    "encarnadino": "en-car-na-di-no",
    "encarnado": "en-car-na-do",
    "encarnadura": "en-car-na-du-ra",
    "encarnamiento": "en-car-na-mien-to",
    "encarnar": "en-car-nar",
    "encarnativa": "en-car-na-ti-va",
    "encarnativo": "en-car-na-ti-vo",
    "encarne": "en-car-ne",
    "encarnecer": "en-car-ne-cer",
    "encarnizada": "en-car-ni-za-da",
    "encarnizadamente": "en-car-ni-za-da-men-te",
    "encarnizado": "en-car-ni-za-do",
    "encarnizamiento": "en-car-ni-za-mien-to",
    "encarnizar": "en-car-ni-zar",
    "encaro": "en-ca-ro",
    "encarpetar": "en-car-pe-tar",
    "encarrerar": "en-ca-rre-rar",
    "encarriladera": "en-ca-rri-la-de-ra",
    "encarrilar": "en-ca-rri-lar",
    "encarrillar": "en-ca-rri-llar",
    "encarroñar": "en-ca-rro-ñar",
    "encarrujado": "en-ca-rru-ja-do",
    "encarrujar": "en-ca-rru-jar",
    "encarrujarse": "en-ca-rru-jar-se",
    "encartación": "en-car-ta-ción",
    "encartada": "en-car-ta-da",
    "encartado": "en-car-ta-do",
    "encartamiento": "en-car-ta-mien-to",
    "encartar": "en-car-tar",
    "encarte": "en-car-te",
    "encartonado": "en-car-to-na-do",
    "encartonador": "en-car-to-na-dor",
    "encartonadora": "en-car-to-na-do-ra",
    "encartonar": "en-car-to-nar",
    "encartuchar": "en-car-tu-char",
    "encartujado": "en-car-tu-ja-do",
    "encasamento": "en-ca-sa-men-to",
    "encasamiento": "en-ca-sa-mien-to",
    "encasar": "en-ca-sar",
    "encascabelar": "en-cas-ca-be-lar",
    "encascar": "en-cas-car",
    "encascotar": "en-cas-co-tar",
    "encasillable": "en-ca-si-lla-ble",
    "encasillado": "en-ca-si-lla-do",
    "encasillamiento": "en-ca-si-lla-mien-to",
    "encasillar": "en-ca-si-llar",
    "encasquetar": "en-cas-que-tar",
    "encasquillador": "en-cas-qui-lla-dor",
    "encasquilladora": "en-cas-qui-lla-do-ra",
    "encasquillar": "en-cas-qui-llar",
    "encastado": "en-cas-ta-do",
    "encastar": "en-cas-tar",
    "encastillada": "en-cas-ti-lla-da",
    "encastillado": "en-cas-ti-lla-do",
    "encastillador": "en-cas-ti-lla-dor",
    "encastilladora": "en-cas-ti-lla-do-ra",
    "encastillamiento": "en-cas-ti-lla-mien-to",
    "encastillar": "en-cas-ti-llar",
    "encastrar": "en-cas-trar",
    "encatalejar": "en-ca-ta-le-jar",
    "encatarrada": "en-ca-ta-rra-da",
    "encatarrado": "en-ca-ta-rra-do",
    "encatrado": "en-ca-tra-do",
    "encatrinar": "en-ca-tri-nar",
    "encatusar": "en-ca-tu-sar",
    "encauchada": "en-cau-cha-da",
    "encauchado": "en-cau-cha-do",
    "encauchar": "en-cau-char",
    "encausada": "en-cau-sa-da",
    "encausado": "en-cau-sa-do",
    "encausar": "en-cau-sar",
    "encauste": "en-caus-te",
    "encáustica": "en-cáus-ti-ca",
    "encáustico": "en-cáus-ti-co",
    "encausto": "en-caus-to",
    "encauzamiento": "en-cau-za-mien-to",
    "encauzar": "en-cau-zar",
    "encavar": "en-ca-var",
    "encavarse": "en-ca-var-se",
    "encebadamiento": "en-ce-ba-da-mien-to",
    "encebadar": "en-ce-ba-dar",
    "encebollado": "en-ce-bo-lla-do",
    "encebollar": "en-ce-bo-llar",
    "encebra": "en-ce-bra",
    "encefalalgia": "en-ce-fa-lal-gia",
    "encefálica": "en-ce-fá-li-ca",
    "encefálico": "en-ce-fá-li-co",
    "encefalitis": "en-ce-fa-li-tis",
    "encéfalo": "en-cé-fa-lo",
    "encefalografía": "en-ce-fa-lo-gra-fí-a",
    "encefalograma": "en-ce-fa-lo-gra-ma",
    "encefalomielitis": "en-ce-fa-lo-mie-li-tis",
    "encefalopatía": "en-ce-fa-lo-pa-tí-a",
    "enceguecer": "en-ce-gue-cer",
    "encelada": "en-ce-la-da",
    "encelado": "en-ce-la-do",
    "encelajar": "en-ce-la-jar",
    "encelajarse": "en-ce-la-jar-se",
    "encelamiento": "en-ce-la-mien-to",
    "encelar": "en-ce-lar",
    "enceldamiento": "en-cel-da-mien-to",
    "enceldar": "en-cel-dar",
    "encella": "en-ce-lla",
    "encellar": "en-ce-llar",
    "encementar": "en-ce-men-tar",
    "encenagamiento": "en-ce-na-ga-mien-to",
    "encenagar": "en-ce-na-gar",
    "encenagarse": "en-ce-na-gar-se",
    "encencerrada": "en-cen-ce-rra-da",
    "encencerrado": "en-cen-ce-rra-do",
    "encendaja": "en-cen-da-ja",
    "encendedor": "en-cen-de-dor",
    "encendedora": "en-cen-de-do-ra",
    "encender": "en-cen-der",
    "encendida": "en-cen-di-da",
    "encendidamente": "en-cen-di-da-men-te",
    "encendido": "en-cen-di-do",
    "encendimiento": "en-cen-di-mien-to",
    "encendrar": "en-cen-drar",
    "encenegar": "en-ce-ne-gar",
    "encenizar": "en-ce-ni-zar",
    "encensuar": "en-cen-suar",
    "encentador": "en-cen-ta-dor",
    "encentadora": "en-cen-ta-do-ra",
    "encentadura": "en-cen-ta-du-ra",
    "encentamiento": "en-cen-ta-mien-to",
    "encentar": "en-cen-tar",
    "encentrar": "en-cen-trar",
    "encepador": "en-ce-pa-dor",
    "encepadura": "en-ce-pa-du-ra",
    "encepar": "en-ce-par",
    "encepe": "en-ce-pe",
    "encerada": "en-ce-ra-da",
    "encerado": "en-ce-ra-do",
    "encerador": "en-ce-ra-dor",
    "enceradora": "en-ce-ra-do-ra",
    "enceramiento": "en-ce-ra-mien-to",
    "encerar": "en-ce-rar",
    "encernadar": "en-cer-na-dar",
    "encerotar": "en-ce-ro-tar",
    "encerrada": "en-ce-rra-da",
    "encerradero": "en-ce-rra-de-ro",
    "encerrado": "en-ce-rra-do",
    "encerrador": "en-ce-rra-dor",
    "encerradora": "en-ce-rra-do-ra",
    "encerradura": "en-ce-rra-du-ra",
    "encerramiento": "en-ce-rra-mien-to",
    "encerrar": "en-ce-rrar",
    "encerrizar": "en-ce-rri-zar",
    "encerrona": "en-ce-rro-na",
    "encespedar": "en-ces-pe-dar",
    "encestador": "en-ces-ta-dor",
    "encestadora": "en-ces-ta-do-ra",
    "encestar": "en-ces-tar",
    "enceste": "en-ces-te",
    "encetadura": "en-ce-ta-du-ra",
    "encetar": "en-ce-tar",
    "enchachar": "en-cha-char",
    "enchagüitar": "en-cha-güi-tar",
    "enchamarrar": "en-cha-ma-rrar",
    "enchambar": "en-cham-bar",
    "enchamicado": "en-cha-mi-ca-do",
    "enchamicar": "en-cha-mi-car",
    "enchanchar": "en-chan-char",
    "enchancletar": "en-chan-cle-tar",
    "enchapado": "en-cha-pa-do",
    "enchapar": "en-cha-par",
    "enchapinada": "en-cha-pi-na-da",
    "enchapinado": "en-cha-pi-na-do",
    "enchapopotar": "en-cha-po-po-tar",
    "encharcada": "en-char-ca-da",
    "encharcamiento": "en-char-ca-mien-to",
    "encharcar": "en-char-car",
    "encharralar": "en-cha-rra-lar",
    "enchastrar": "en-chas-trar",
    "enchastre": "en-chas-tre",
    "enchavetar": "en-cha-ve-tar",
    "enchibolar": "en-chi-bo-lar",
    "enchicar": "en-chi-car",
    "enchichar": "en-chi-char",
    "enchilada": "en-chi-la-da",
    "enchilado": "en-chi-la-do",
    "enchilar": "en-chi-lar",
    "enchilorar": "en-chi-lo-rar",
    "enchiloso": "en-chi-lo-so",
    "enchinamiento": "en-chi-na-mien-to",
    "enchinar": "en-chi-nar",
    "enchinarrar": "en-chi-na-rrar",
    "enchinchado": "en-chin-cha-do",
    "enchinchar": "en-chin-char",
    "enchipar": "en-chi-par",
    "enchiqueramiento": "en-chi-que-ra-mien-to",
    "enchiquerar": "en-chi-que-rar",
    "enchironar": "en-chi-ro-nar",
    "enchispar": "en-chis-par",
    "enchisterado": "en-chis-te-ra-do",
    "enchivar": "en-chi-var",
    "enchivarse": "en-chi-var-se",
    "encholar": "en-cho-lar",
    "encholpar": "en-chol-par",
    "enchuchao": "en-chu-cha-o",
    "enchuchar": "en-chu-char",
    "enchuecar": "en-chue-car",
    "enchufada": "en-chu-fa-da",
    "enchufado": "en-chu-fa-do",
    "enchufar": "en-chu-far",
    "enchufe": "en-chu-fe",
    "enchufismo": "en-chu-fis-mo",
    "enchufista": "en-chu-fis-ta",
    "enchufle": "en-chu-fle",
    "enchular": "en-chu-lar",
    "enchuletar": "en-chu-le-tar",
    "enchumbar": "en-chum-bar",
    "enchutar": "en-chu-tar",
    "enchute": "en-chu-te",
    "encía": "en-cí-a",
    "encíclica": "en-cí-cli-ca",
    "enciclopedia": "en-ci-clo-pe-dia",
    "enciclopédica": "en-ci-clo-pé-di-ca",
    "enciclopédico": "en-ci-clo-pé-di-co",
    "enciclopedismo": "en-ci-clo-pe-dis-mo",
    "enciclopedista": "en-ci-clo-pe-dis-ta",
    "encielar": "en-cie-lar",
    "encienso": "en-cien-so",
    "encierre": "en-cie-rre",
    "encierro": "en-cie-rro",
    "encima": "en-ci-ma",
    "encimar": "en-ci-mar",
    "encimera": "en-ci-me-ra",
    "encimero": "en-ci-me-ro",
    "encimoso": "en-ci-mo-so",
    "encina": "en-ci-na",
    "encinal": "en-ci-nal",
    "encinar": "en-ci-nar",
    "encino": "en-ci-no",
    "encinta": "en-cin-ta",
    "encintado": "en-cin-ta-do",
    "encintar": "en-cin-tar",
    "encismar": "en-cis-mar",
    "enciso": "en-ci-so",
    "encitar": "en-ci-tar",
    "encizañador": "en-ci-za-ña-dor",
    "encizañadora": "en-ci-za-ña-do-ra",
    "encizañar": "en-ci-za-ñar",
    "enclaustramiento": "en-claus-tra-mien-to",
    "enclaustrar": "en-claus-trar",
    "enclavación": "en-cla-va-ción",
    "enclavada": "en-cla-va-da",
    "enclavado": "en-cla-va-do",
    "enclavadura": "en-cla-va-du-ra",
    "enclavar": "en-cla-var",
    "enclave": "en-cla-ve",
    "enclavijar": "en-cla-vi-jar",
    "enclenque": "en-clen-que",
    "enclisis": "en-cli-sis",
    "enclítica": "en-clí-ti-ca",
    "enclítico": "en-clí-ti-co",
    "enclocar": "en-clo-car",
    "enclochar": "en-clo-char",
    "encloquecer": "en-clo-que-cer",
    "encluecar": "en-clue-car",
    "encobador": "en-co-ba-dor",
    "encobadora": "en-co-ba-do-ra",
    "encobar": "en-co-bar",
    "encobertada": "en-co-ber-ta-da",
    "encobertado": "en-co-ber-ta-do",
    "encobijar": "en-co-bi-jar",
    "encobilar": "en-co-bi-lar",
    "encobilarse": "en-co-bi-lar-se",
    "encobrada": "en-co-bra-da",
    "encobrado": "en-co-bra-do",
    "encobrar": "en-co-brar",
    "encochada": "en-co-cha-da",
    "encochado": "en-co-cha-do",
    "encochar": "en-co-char",
    "encochimbado": "en-co-chim-ba-do",
    "encochinar": "en-co-chi-nar",
    "encoclar": "en-co-clar",
    "encocorar": "en-co-co-rar",
    "encodillar": "en-co-di-llar",
    "encodillarse": "en-co-di-llar-se",
    "encofinar": "en-co-fi-nar",
    "encofrado": "en-co-fra-do",
    "encofrador": "en-co-fra-dor",
    "encofradora": "en-co-fra-do-ra",
    "encofrar": "en-co-frar",
    "encoger": "en-co-ger",
    "encogida": "en-co-gi-da",
    "encogidamente": "en-co-gi-da-men-te",
    "encogido": "en-co-gi-do",
    "encogimiento": "en-co-gi-mien-to",
    "encogollar": "en-co-go-llar",
    "encogollarse": "en-co-go-llar-se",
    "encohetar": "en-co-he-tar",
    "encojar": "en-co-jar",
    "encojonar": "en-co-jo-nar",
    "encolada": "en-co-la-da",
    "encolado": "en-co-la-do",
    "encolador": "en-co-la-dor",
    "encoladora": "en-co-la-do-ra",
    "encoladura": "en-co-la-du-ra",
    "encolamiento": "en-co-la-mien-to",
    "encolar": "en-co-lar",
    "encolerizado": "en-co-le-ri-za-do",
    "encolerizar": "en-co-le-ri-zar",
    "encolochar": "en-co-lo-char",
    "encolumnar": "en-co-lum-nar",
    "encomendable": "en-co-men-da-ble",
    "encomendado": "en-co-men-da-do",
    "encomendamento": "en-co-men-da-men-to",
    "encomendamiento": "en-co-men-da-mien-to",
    "encomendar": "en-co-men-dar",
    "encomendera": "en-co-men-de-ra",
    "encomendería": "en-co-men-de-rí-a",
    "encomendero": "en-co-men-de-ro",
    "encomenzamiento": "en-co-men-za-mien-to",
    "encomenzar": "en-co-men-zar",
    "encomiable": "en-co-mia-ble",
    "encomiador": "en-co-mia-dor",
    "encomiadora": "en-co-mia-do-ra",
    "encomiar": "en-co-miar",
    "encomiasta": "en-co-mias-ta",
    "encomiástica": "en-co-miás-ti-ca",
    "encomiástico": "en-co-miás-ti-co",
    "encomienda": "en-co-mien-da",
    "encomio": "en-co-mio",
    "encomioso": "en-co-mio-so",
    "encompadrar": "en-com-pa-drar",
    "encomunalmente": "en-co-mu-nal-men-te",
    "enconada": "en-co-na-da",
    "enconadamente": "en-co-na-da-men-te",
    "enconado": "en-co-na-do",
    "enconadura": "en-co-na-du-ra",
    "enconamiento": "en-co-na-mien-to",
    "encoñamiento": "en-co-ña-mien-to",
    "enconar": "en-co-nar",
    "encoñar": "en-co-ñar",
    "enconchar": "en-con-char",
    "enconcharse": "en-con-char-se",
    "enconfitar": "en-con-fi-tar",
    "enconía": "en-co-ní-a",
    "encono": "en-co-no",
    "enconosa": "en-co-no-sa",
    "enconoso": "en-co-no-so",
    "enconrear": "en-con-re-ar",
    "encontentar": "en-con-ten-tar",
    "encontilar": "en-con-ti-lar",
    "encontinente": "en-con-ti-nen-te",
    "encontrada": "en-con-tra-da",
    "encontradamente": "en-con-tra-da-men-te",
    "encontradiza": "en-con-tra-di-za",
    "encontradizo": "en-con-tra-di-zo",
    "encontrado": "en-con-tra-do",
    "encontrar": "en-con-trar",
    "encontrón": "en-con-trón",
    "encontronazo": "en-con-tro-na-zo",
    "encopado": "en-co-pa-do",
    "encopetada": "en-co-pe-ta-da",
    "encopetado": "en-co-pe-ta-do",
    "encopetar": "en-co-pe-tar",
    "encorachar": "en-co-ra-char",
    "encorajar": "en-co-ra-jar",
    "encorajinar": "en-co-ra-ji-nar",
    "encorar": "en-co-rar",
    "encorazada": "en-co-ra-za-da",
    "encorazado": "en-co-ra-za-do",
    "encorbatado": "en-cor-ba-ta-do",
    "encorbatar": "en-cor-ba-tar",
    "encorchador": "en-cor-cha-dor",
    "encorchadora": "en-cor-cha-do-ra",
    "encorchadura": "en-cor-cha-du-ra",
    "encorchar": "en-cor-char",
    "encorchetar": "en-cor-che-tar",
    "encordadura": "en-cor-da-du-ra",
    "encordar": "en-cor-dar",
    "encordelar": "en-cor-de-lar",
    "encordonar": "en-cor-do-nar",
    "encorecer": "en-co-re-cer",
    "encoriación": "en-co-ria-ción",
    "encornada": "en-cor-na-da",
    "encornado": "en-cor-na-do",
    "encornadura": "en-cor-na-du-ra",
    "encornar": "en-cor-nar",
    "encornudar": "en-cor-nu-dar",
    "encorozar": "en-co-ro-zar",
    "encorralar": "en-co-rra-lar",
    "encorrear": "en-co-rre-ar",
    "encorselar": "en-cor-se-lar",
    "encorsetamiento": "en-cor-se-ta-mien-to",
    "encorsetar": "en-cor-se-tar",
    "encortar": "en-cor-tar",
    "encortinar": "en-cor-ti-nar",
    "encorujar": "en-co-ru-jar",
    "encorvada": "en-cor-va-da",
    "encorvadura": "en-cor-va-du-ra",
    "encorvamiento": "en-cor-va-mien-to",
    "encorvar": "en-cor-var",
    "encosadura": "en-co-sa-du-ra",
    "encostalar": "en-cos-ta-lar",
    "encostar": "en-cos-tar",
    "encostarse": "en-cos-tar-se",
    "encostillado": "en-cos-ti-lla-do",
    "encostradura": "en-cos-tra-du-ra",
    "encostrar": "en-cos-trar",
    "encovada": "en-co-va-da",
    "encovado": "en-co-va-do",
    "encovadura": "en-co-va-du-ra",
    "encovar": "en-co-var",
    "encrasar": "en-cra-sar",
    "encrespado": "en-cres-pa-do",
    "encrespador": "en-cres-pa-dor",
    "encrespadora": "en-cres-pa-do-ra",
    "encrespadura": "en-cres-pa-du-ra",
    "encrespamiento": "en-cres-pa-mien-to",
    "encrespar": "en-cres-par",
    "encrespo": "en-cres-po",
    "encrestada": "en-cres-ta-da",
    "encrestado": "en-cres-ta-do",
    "encrestar": "en-cres-tar",
    "encrestarse": "en-cres-tar-se",
    "encreyente": "en-cre-yen-te",
    "encrisnejada": "en-cris-ne-ja-da",
    "encrisnejado": "en-cris-ne-ja-do",
    "encristalar": "en-cris-ta-lar",
    "encrucijada": "en-cru-ci-ja-da",
    "encrudecer": "en-cru-de-cer",
    "encrudelecer": "en-cru-de-le-cer",
    "encruelecer": "en-crue-le-cer",
    "encuadernable": "en-cua-der-na-ble",
    "encuadernación": "en-cua-der-na-ción",
    "encuadernador": "en-cua-der-na-dor",
    "encuadernadora": "en-cua-der-na-do-ra",
    "encuadernar": "en-cua-der-nar",
    "encuadramiento": "en-cua-dra-mien-to",
    "encuadrar": "en-cua-drar",
    "encuadre": "en-cua-dre",
    "encuartar": "en-cuar-tar",
    "encuarte": "en-cuar-te",
    "encuartelar": "en-cuar-te-lar",
    "encuartero": "en-cuar-te-ro",
    "encubar": "en-cu-bar",
    "encubertar": "en-cu-ber-tar",
    "encubierta": "en-cu-bier-ta",
    "encubiertamente": "en-cu-bier-ta-men-te",
    "encubierto": "en-cu-bier-to",
    "encubridiza": "en-cu-bri-di-za",
    "encubridizo": "en-cu-bri-di-zo",
    "encubridor": "en-cu-bri-dor",
    "encubridora": "en-cu-bri-do-ra",
    "encubrimiento": "en-cu-bri-mien-to",
    "encubrir": "en-cu-brir",
    "encuclillar": "en-cu-cli-llar",
    "encuentro": "en-cuen-tro",
    "encuerado": "en-cue-ra-do",
    "encuerar": "en-cue-rar",
    "encueratriz": "en-cue-ra-triz",
    "encuero": "en-cue-ro",
    "encueroso": "en-cue-ro-so",
    "encuesta": "en-cues-ta",
    "encuestada": "en-cues-ta-da",
    "encuestado": "en-cues-ta-do",
    "encuestador": "en-cues-ta-dor",
    "encuestadora": "en-cues-ta-do-ra",
    "encuestar": "en-cues-tar",
    "encuetar": "en-cue-tar",
    "encuevar": "en-cue-var",
    "encuitar": "en-cui-tar",
    "encuitarse": "en-cui-tar-se",
    "encular": "en-cu-lar",
    "enculatar": "en-cu-la-tar",
    "enculebrado": "en-cu-le-bra-do",
    "enculillar": "en-cu-li-llar",
    "enculpar": "en-cul-par",
    "enculturación": "en-cul-tu-ra-ción",
    "encumbrada": "en-cum-bra-da",
    "encumbradamente": "en-cum-bra-da-men-te",
    "encumbrado": "en-cum-bra-do",
    "encumbramiento": "en-cum-bra-mien-to",
    "encumbrar": "en-cum-brar",
    "encunar": "en-cu-nar",
    "encunetar": "en-cu-ne-tar",
    "encurdar": "en-cur-dar",
    "encurdelar": "en-cur-de-lar",
    "encureñar": "en-cu-re-ñar",
    "encurrujado": "en-cu-rru-ja-do",
    "encurrujar": "en-cu-rru-jar",
    "encurtido": "en-cur-ti-do",
    "encurtir": "en-cur-tir",
    "endamar": "en-da-mar",
    "ende": "en-de",
    "endeble": "en-de-ble",
    "endeblez": "en-de-blez",
    "endeblucha": "en-de-blu-cha",
    "endeblucho": "en-de-blu-cho",
    "endécada": "en-dé-ca-da",
    "endecágona": "en-de-cá-go-na",
    "endecágono": "en-de-cá-go-no",
    "endecasílaba": "en-de-ca-sí-la-ba",
    "endecasilábica": "en-de-ca-si-lá-bi-ca",
    "endecasilábico": "en-de-ca-si-lá-bi-co",
    "endecasílabo": "en-de-ca-sí-la-bo",
    "endecha": "en-de-cha",
    "endechadera": "en-de-cha-de-ra",
    "endechar": "en-de-char",
    "endechera": "en-de-che-ra",
    "endechosa": "en-de-cho-sa",
    "endechoso": "en-de-cho-so",
    "endehesar": "en-de-he-sar",
    "endeja": "en-de-ja",
    "endeliñar": "en-de-li-ñar",
    "endemás": "en-de-más",
    "endemia": "en-de-mia",
    "endémica": "en-dé-mi-ca",
    "endémico": "en-dé-mi-co",
    "endemismo": "en-de-mis-mo",
    "endemoniada": "en-de-mo-nia-da",
    "endemoniado": "en-de-mo-nia-do",
    "endemoniar": "en-de-mo-niar",
    "endenantes": "en-de-nan-tes",
    "endeñar": "en-de-ñar",
    "endentada": "en-den-ta-da",
    "endentado": "en-den-ta-do",
    "endentar": "en-den-tar",
    "endentecer": "en-den-te-cer",
    "enderechar": "en-de-re-char",
    "endereza": "en-de-re-za",
    "enderezada": "en-de-re-za-da",
    "enderezadamente": "en-de-re-za-da-men-te",
    "enderezado": "en-de-re-za-do",
    "enderezador": "en-de-re-za-dor",
    "enderezadora": "en-de-re-za-do-ra",
    "enderezamiento": "en-de-re-za-mien-to",
    "enderezar": "en-de-re-zar",
    "enderezo": "en-de-re-zo",
    "endergónico": "en-der-gó-ni-co",
    "endespués": "en-des-pués",
    "endeudamiento": "en-deu-da-mien-to",
    "endeudar": "en-deu-dar",
    "endeudarse": "en-deu-dar-se",
    "endevotada": "en-de-vo-ta-da",
    "endevotado": "en-de-vo-ta-do",
    "endiablada": "en-dia-bla-da",
    "endiabladamente": "en-dia-bla-da-men-te",
    "endiablado": "en-dia-bla-do",
    "endiablar": "en-dia-blar",
    "endíadis": "en-dí-a-dis",
    "endibia": "en-di-bia",
    "endieciochado": "en-die-cio-cha-do",
    "endilgador": "en-dil-ga-dor",
    "endilgadora": "en-dil-ga-do-ra",
    "endilgar": "en-dil-gar",
    "endina": "en-di-na",
    "endino": "en-di-no",
    "endiosado": "en-dio-sa-do",
    "endiosamiento": "en-dio-sa-mien-to",
    "endiosar": "en-dio-sar",
    "enditar": "en-di-tar",
    "enditarse": "en-di-tar-se",
    "endivia": "en-di-via",
    "endoblado": "en-do-bla-do",
    "endoblar": "en-do-blar",
    "endoble": "en-do-ble",
    "endocardio": "en-do-car-dio",
    "endocarditis": "en-do-car-di-tis",
    "endocarpio": "en-do-car-pio",
    "endocarpo": "en-do-car-po",
    "endocéntrico": "en-do-cén-tri-co",
    "endocitosis": "en-do-ci-to-sis",
    "endocrina": "en-do-cri-na",
    "endocrino": "en-do-cri-no",
    "endócrino": "en-dó-cri-no",
    "endocrinóloga": "en-do-cri-nó-lo-ga",
    "endocrinología": "en-do-cri-no-lo-gí-a",
    "endocrinológico": "en-do-cri-no-ló-gi-co",
    "endocrinólogo": "en-do-cri-nó-lo-go",
    "endocrinopatía": "en-do-cri-no-pa-tí-a",
    "endodérmica": "en-do-dér-mi-ca",
    "endodérmico": "en-do-dér-mi-co",
    "endodermis": "en-do-der-mis",
    "endodermo": "en-do-der-mo",
    "endodoncia": "en-do-don-cia",
    "endoenergético": "en-do-e-ner-gé-ti-co",
    "endoesqueleto": "en-do-es-que-le-to",
    "endogamia": "en-do-ga-mia",
    "endogámico": "en-do-gá-mi-co",
    "endógena": "en-dó-ge-na",
    "endogénesis": "en-do-gé-ne-sis",
    "endógeno": "en-dó-ge-no",
    "endolencia": "en-do-len-cia",
    "endolinfa": "en-do-lin-fa",
    "endometrio": "en-do-me-trio",
    "endometriosis": "en-do-me-trio-sis",
    "endometritis": "en-do-me-tri-tis",
    "endometrosis": "en-do-me-tro-sis",
    "endomingada": "en-do-min-ga-da",
    "endomingado": "en-do-min-ga-do",
    "endomingar": "en-do-min-gar",
    "endomingarse": "en-do-min-gar-se",
    "endomorfa": "en-do-mor-fa",
    "endomorfo": "en-do-mor-fo",
    "endonar": "en-do-nar",
    "endoparásito": "en-do-pa-rá-si-to",
    "endoplasma": "en-do-plas-ma",
    "endoplasmático": "en-do-plas-má-ti-co",
    "endoplásmico": "en-do-plás-mi-co",
    "endorfina": "en-dor-fi-na",
    "endorreico": "en-do-rrei-co",
    "endorreísmo": "en-do-rre-ís-mo",
    "endorsar": "en-dor-sar",
    "endorso": "en-dor-so",
    "endosable": "en-do-sa-ble",
    "endosar": "en-do-sar",
    "endosataria": "en-do-sa-ta-ria",
    "endosatario": "en-do-sa-ta-rio",
    "endoscopia": "en-dos-co-pia",
    "endoscopio": "en-dos-co-pio",
    "endose": "en-do-se",
    "endoselar": "en-do-se-lar",
    "endosfera": "en-dos-fe-ra",
    "endosmómetro": "en-dos-mó-me-tro",
    "endósmosis": "en-dós-mo-sis",
    "endoso": "en-do-so",
    "endospermo": "en-dos-per-mo",
    "endosqueleto": "en-dos-que-le-to",
    "endotelial": "en-do-te-lial",
    "endotelio": "en-do-te-lio",
    "endotelioma": "en-do-te-lio-ma",
    "endoterma": "en-do-ter-ma",
    "endotermia": "en-do-ter-mia",
    "endotérmico": "en-do-tér-mi-co",
    "endotermo": "en-do-ter-mo",
    "endovenoso": "en-do-ve-no-so",
    "endrezar": "en-dre-zar",
    "endriago": "en-dria-go",
    "endrina": "en-dri-na",
    "endrinal": "en-dri-nal",
    "endrino": "en-dri-no",
    "endrogado": "en-dro-ga-do",
    "endrogar": "en-dro-gar",
    "endrogarse": "en-dro-gar-se",
    "endulce": "en-dul-ce",
    "endulcecer": "en-dul-ce-cer",
    "endulzadura": "en-dul-za-du-ra",
    "endulzamiento": "en-dul-za-mien-to",
    "endulzar": "en-dul-zar",
    "endulzorar": "en-dul-zo-rar",
    "endulzurar": "en-dul-zu-rar",
    "endurador": "en-du-ra-dor",
    "enduradora": "en-du-ra-do-ra",
    "endurar": "en-du-rar",
    "endurecedor": "en-du-re-ce-dor",
    "endurecer": "en-du-re-cer",
    "endurecidamente": "en-du-re-ci-da-men-te",
    "endurecimiento": "en-du-re-ci-mien-to",
    "enduro": "en-du-ro",
    "ene": "e-ne",
    "eñe": "e-ñe",
    "enea": "e-ne-a",
    "énea": "é-ne-a",
    "eneágona": "e-ne-á-go-na",
    "eneágono": "e-ne-á-go-no",
    "eneal": "e-ne-al",
    "eneasílaba": "e-ne-a-sí-la-ba",
    "eneasílabo": "e-ne-a-sí-la-bo",
    "enebral": "e-ne-bral",
    "enebrina": "e-ne-bri-na",
    "enebro": "e-ne-bro",
    "enechada": "e-ne-cha-da",
    "enechado": "e-ne-cha-do",
    "enechar": "e-ne-char",
    "enejar": "e-ne-jar",
    "eneldo": "e-nel-do",
    "enema": "e-ne-ma",
    "enemicísimo": "e-ne-mi-cí-si-mo",
    "enemiga": "e-ne-mi-ga",
    "enemigable": "e-ne-mi-ga-ble",
    "enemigablemente": "e-ne-mi-ga-ble-men-te",
    "enemigadera": "e-ne-mi-ga-de-ra",
    "enemigadero": "e-ne-mi-ga-de-ro",
    "enemigamente": "e-ne-mi-ga-men-te",
    "enemigar": "e-ne-mi-gar",
    "enemigo": "e-ne-mi-go",
    "enemistad": "e-ne-mis-tad",
    "enemistar": "e-ne-mis-tar",
    "éneo": "é-ne-o",
    "eneolítica": "e-ne-o-lí-ti-ca",
    "eneolítico": "e-ne-o-lí-ti-co",
    "energética": "e-ner-gé-ti-ca",
    "energético": "e-ner-gé-ti-co",
    "energía": "e-ner-gí-a",
    "enérgica": "e-nér-gi-ca",
    "enérgico": "e-nér-gi-co",
    "energizar": "e-ner-gi-zar",
    "energúmena": "e-ner-gú-me-na",
    "energúmeno": "e-ner-gú-me-no",
    "enerizar": "e-ne-ri-zar",
    "enero": "e-ne-ro",
    "enertar": "e-ner-tar",
    "enertarse": "e-ner-tar-se",
    "enervación": "e-ner-va-ción",
    "enervador": "e-ner-va-dor",
    "enervadora": "e-ner-va-do-ra",
    "enervamiento": "e-ner-va-mien-to",
    "enervante": "e-ner-van-te",
    "enervar": "e-ner-var",
    "enerve": "e-ner-ve",
    "enescar": "e-nes-car",
    "enésima": "e-né-si-ma",
    "enésimo": "e-né-si-mo",
    "enfadadiza": "en-fa-da-di-za",
    "enfadadizo": "en-fa-da-di-zo",
    "enfadamiento": "en-fa-da-mien-to",
    "enfadar": "en-fa-dar",
    "enfado": "en-fa-do",
    "enfadosa": "en-fa-do-sa",
    "enfadosamente": "en-fa-do-sa-men-te",
    "enfadoso": "en-fa-do-so",
    "enfaenada": "en-fa-e-na-da",
    "enfaenado": "en-fa-e-na-do",
    "enfajar": "en-fa-jar",
    "enfajillar": "en-fa-ji-llar",
    "enfalcado": "en-fal-ca-do",
    "enfaldado": "en-fal-da-do",
    "enfaldador": "en-fal-da-dor",
    "enfaldar": "en-fal-dar",
    "enfaldo": "en-fal-do",
    "enfangar": "en-fan-gar",
    "enfardador": "en-far-da-dor",
    "enfardadora": "en-far-da-do-ra",
    "enfardar": "en-far-dar",
    "enfardelador": "en-far-de-la-dor",
    "enfardeladora": "en-far-de-la-do-ra",
    "enfardeladura": "en-far-de-la-du-ra",
    "enfardelar": "en-far-de-lar",
    "énfasis": "én-fa-sis",
    "enfastiar": "en-fas-tiar",
    "enfática": "en-fá-ti-ca",
    "enfáticamente": "en-fá-ti-ca-men-te",
    "enfático": "en-fá-ti-co",
    "enfatización": "en-fa-ti-za-ción",
    "enfatizar": "en-fa-ti-zar",
    "enfebrecer": "en-fe-bre-cer",
    "enfebrecido": "en-fe-bre-ci-do",
    "enferma": "en-fer-ma",
    "enfermada": "en-fer-ma-da",
    "enfermamente": "en-fer-ma-men-te",
    "enfermar": "en-fer-mar",
    "enfermedad": "en-fer-me-dad",
    "enfermera": "en-fer-me-ra",
    "enfermería": "en-fer-me-rí-a",
    "enfermero": "en-fer-me-ro",
    "enfermiza": "en-fer-mi-za",
    "enfermizar": "en-fer-mi-zar",
    "enfermizo": "en-fer-mi-zo",
    "enfermo": "en-fer-mo",
    "enfermosa": "en-fer-mo-sa",
    "enfermoso": "en-fer-mo-so",
    "enfermucha": "en-fer-mu-cha",
    "enfermucho": "en-fer-mu-cho",
    "enferozar": "en-fe-ro-zar",
    "enfervorecer": "en-fer-vo-re-cer",
    "enfervorizador": "en-fer-vo-ri-za-dor",
    "enfervorizadora": "en-fer-vo-ri-za-do-ra",
    "enfervorizar": "en-fer-vo-ri-zar",
    "enfestar": "en-fes-tar",
    "enfeudación": "en-feu-da-ción",
    "enfeudar": "en-feu-dar",
    "enfiar": "en-fiar",
    "enficionar": "en-fi-cio-nar",
    "enfiebrar": "en-fie-brar",
    "enfielar": "en-fie-lar",
    "enfierecer": "en-fie-re-cer",
    "enfierecerse": "en-fie-re-cer-se",
    "enfierrador": "en-fie-rra-dor",
    "enfierrar": "en-fie-rrar",
    "enfiestar": "en-fies-tar",
    "enfiestarse": "en-fies-tar-se",
    "enfilación": "en-fi-la-ción",
    "enfilada": "en-fi-la-da",
    "enfilado": "en-fi-la-do",
    "enfilar": "en-fi-lar",
    "enfingir": "en-fin-gir",
    "enfinta": "en-fin-ta",
    "enfintosa": "en-fin-to-sa",
    "enfintoso": "en-fin-to-so",
    "enfirolar": "en-fi-ro-lar",
    "enfisema": "en-fi-se-ma",
    "enfisematoso": "en-fi-se-ma-to-so",
    "enfistolar": "en-fis-to-lar",
    "enfiteusis": "en-fi-teu-sis",
    "enfiteuta": "en-fi-teu-ta",
    "enfiteutecaria": "en-fi-teu-te-ca-ria",
    "enfiteutecario": "en-fi-teu-te-ca-rio",
    "enfitéutica": "en-fi-téu-ti-ca",
    "enfiteuticaria": "en-fi-teu-ti-ca-ria",
    "enfiteuticario": "en-fi-teu-ti-ca-rio",
    "enfitéutico": "en-fi-téu-ti-co",
    "enfiuzar": "en-fiu-zar",
    "enflacar": "en-fla-car",
    "enflaquecer": "en-fla-que-cer",
    "enflaquecimiento": "en-fla-que-ci-mien-to",
    "enflatar": "en-fla-tar",
    "enflautada": "en-flau-ta-da",
    "enflautado": "en-flau-ta-do",
    "enflautador": "en-flau-ta-dor",
    "enflautadora": "en-flau-ta-do-ra",
    "enflautar": "en-flau-tar",
    "enflechada": "en-fle-cha-da",
    "enflechado": "en-fle-cha-do",
    "enflorar": "en-flo-rar",
    "enflorecer": "en-flo-re-cer",
    "enflusado": "en-flu-sa-do",
    "enfocar": "en-fo-car",
    "enfogar": "en-fo-gar",
    "enfoque": "en-fo-que",
    "enforcar": "en-for-car",
    "enforcia": "en-for-cia",
    "enfornar": "en-for-nar",
    "enforradura": "en-fo-rra-du-ra",
    "enforrar": "en-fo-rrar",
    "enforro": "en-fo-rro",
    "enfortalecer": "en-for-ta-le-cer",
    "enfortalecimiento": "en-for-ta-le-ci-mien-to",
    "enfortecer": "en-for-te-cer",
    "enfortir": "en-for-tir",
    "enfosado": "en-fo-sa-do",
    "enfoscadero": "en-fos-ca-de-ro",
    "enfoscado": "en-fos-ca-do",
    "enfoscar": "en-fos-car",
    "enfotar": "en-fo-tar",
    "enfotarse": "en-fo-tar-se",
    "enfrailar": "en-frai-lar",
    "enfranque": "en-fran-que",
    "enfranquecer": "en-fran-que-cer",
    "enfrascamiento": "en-fras-ca-mien-to",
    "enfrascar": "en-fras-car",
    "enfrascarse": "en-fras-car-se",
    "enfrenador": "en-fre-na-dor",
    "enfrenadora": "en-fre-na-do-ra",
    "enfrenamiento": "en-fre-na-mien-to",
    "enfrenar": "en-fre-nar",
    "enfrenón": "en-fre-nón",
    "enfrentamiento": "en-fren-ta-mien-to",
    "enfrentar": "en-fren-tar",
    "enfrente": "en-fren-te",
    "enfriadera": "en-fria-de-ra",
    "enfriadero": "en-fria-de-ro",
    "enfriador": "en-fria-dor",
    "enfriadora": "en-fria-do-ra",
    "enfriamiento": "en-fria-mien-to",
    "enfriar": "en-friar",
    "enfrijolada": "en-fri-jo-la-da",
    "enfrontar": "en-fron-tar",
    "enfrontilar": "en-fron-ti-lar",
    "enfroscar": "en-fros-car",
    "enfroscarse": "en-fros-car-se",
    "enfullar": "en-fu-llar",
    "enfullinar": "en-fu-lli-nar",
    "enfuñar": "en-fu-ñar",
    "enfunchar": "en-fun-char",
    "enfundadura": "en-fun-da-du-ra",
    "enfundar": "en-fun-dar",
    "enfurción": "en-fur-ción",
    "enfurecer": "en-fu-re-cer",
    "enfurecimiento": "en-fu-re-ci-mien-to",
    "enfuriar": "en-fu-riar",
    "enfuriarse": "en-fu-riar-se",
    "enfurruñamiento": "en-fu-rru-ña-mien-to",
    "enfurruñar": "en-fu-rru-ñar",
    "enfurruñarse": "en-fu-rru-ñar-se",
    "enfurruscar": "en-fu-rrus-car",
    "enfurruscarse": "en-fu-rrus-car-se",
    "enfurtido": "en-fur-ti-do",
    "enfurtir": "en-fur-tir",
    "enfusar": "en-fu-sar",
    "enfusir": "en-fu-sir",
    "engabanada": "en-ga-ba-na-da",
    "engabanado": "en-ga-ba-na-do",
    "engace": "en-ga-ce",
    "engafar": "en-ga-far",
    "engafecer": "en-ga-fe-cer",
    "engafetar": "en-ga-fe-tar",
    "engaitador": "en-gai-ta-dor",
    "engaitadora": "en-gai-ta-do-ra",
    "engaitar": "en-gai-tar",
    "engalabernar": "en-ga-la-ber-nar",
    "engalanamiento": "en-ga-la-na-mien-to",
    "engalanar": "en-ga-la-nar",
    "engaletar": "en-ga-le-tar",
    "engalgar": "en-gal-gar",
    "engaliar": "en-ga-liar",
    "engallada": "en-ga-lla-da",
    "engallado": "en-ga-lla-do",
    "engallador": "en-ga-lla-dor",
    "engalladura": "en-ga-lla-du-ra",
    "engallamiento": "en-ga-lla-mien-to",
    "engallar": "en-ga-llar",
    "engalle": "en-ga-lle",
    "engalletar": "en-ga-lle-tar",
    "engañabobos": "en-ga-ña-bo-bos",
    "engañadiza": "en-ga-ña-di-za",
    "engañadizo": "en-ga-ña-di-zo",
    "engañador": "en-ga-ña-dor",
    "engañadora": "en-ga-ña-do-ra",
    "engañamundo": "en-ga-ña-mun-do",
    "engañamundos": "en-ga-ña-mun-dos",
    "engañanecios": "en-ga-ña-ne-cios",
    "engañapastores": "en-ga-ña-pas-to-res",
    "engañapichanga": "en-ga-ña-pi-chan-ga",
    "engañar": "en-ga-ñar",
    "enganchada": "en-gan-cha-da",
    "enganchado": "en-gan-cha-do",
    "enganchador": "en-gan-cha-dor",
    "enganchadora": "en-gan-cha-do-ra",
    "enganchamiento": "en-gan-cha-mien-to",
    "enganchar": "en-gan-char",
    "enganche": "en-gan-che",
    "enganchón": "en-gan-chón",
    "engandujar": "en-gan-du-jar",
    "engandujo": "en-gan-du-jo",
    "engañifa": "en-ga-ñi-fa",
    "engañifla": "en-ga-ñi-fla",
    "engaño": "en-ga-ño",
    "engañosa": "en-ga-ño-sa",
    "engañosamente": "en-ga-ño-sa-men-te",
    "engañoso": "en-ga-ño-so",
    "engarabatar": "en-ga-ra-ba-tar",
    "engarabitar": "en-ga-ra-bi-tar",
    "engaratusar": "en-ga-ra-tu-sar",
    "engarbada": "en-gar-ba-da",
    "engarbado": "en-gar-ba-do",
    "engarbar": "en-gar-bar",
    "engarbarse": "en-gar-bar-se",
    "engarberar": "en-gar-be-rar",
    "engarbullar": "en-gar-bu-llar",
    "engarce": "en-gar-ce",
    "engarfiar": "en-gar-fiar",
    "engargantadura": "en-gar-gan-ta-du-ra",
    "engargantar": "en-gar-gan-tar",
    "engargante": "en-gar-gan-te",
    "engargolado": "en-gar-go-la-do",
    "engargolar": "en-gar-go-lar",
    "engaritar": "en-ga-ri-tar",
    "engarmar": "en-gar-mar",
    "engarmarse": "en-gar-mar-se",
    "engarnio": "en-gar-nio",
    "engarrafador": "en-ga-rra-fa-dor",
    "engarrafadora": "en-ga-rra-fa-do-ra",
    "engarrafar": "en-ga-rra-far",
    "engarrapatar": "en-ga-rra-pa-tar",
    "engarrar": "en-ga-rrar",
    "engarro": "en-ga-rro",
    "engarronar": "en-ga-rro-nar",
    "engarrotar": "en-ga-rro-tar",
    "engarzador": "en-gar-za-dor",
    "engarzadora": "en-gar-za-do-ra",
    "engarzadura": "en-gar-za-du-ra",
    "engarzar": "en-gar-zar",
    "engasgar": "en-gas-gar",
    "engastador": "en-gas-ta-dor",
    "engastadora": "en-gas-ta-do-ra",
    "engastadura": "en-gas-ta-du-ra",
    "engastar": "en-gas-tar",
    "engaste": "en-gas-te",
    "engastonar": "en-gas-to-nar",
    "engatada": "en-ga-ta-da",
    "engatado": "en-ga-ta-do",
    "engatar": "en-ga-tar",
    "engatillada": "en-ga-ti-lla-da",
    "engatillado": "en-ga-ti-lla-do",
    "engatillar": "en-ga-ti-llar",
    "engatusador": "en-ga-tu-sa-dor",
    "engatusadora": "en-ga-tu-sa-do-ra",
    "engatusamiento": "en-ga-tu-sa-mien-to",
    "engatusar": "en-ga-tu-sar",
    "engavetar": "en-ga-ve-tar",
    "engaviar": "en-ga-viar",
    "engavillar": "en-ga-vi-llar",
    "engayolado": "en-ga-yo-la-do",
    "engayolar": "en-ga-yo-lar",
    "engazador": "en-ga-za-dor",
    "engazadora": "en-ga-za-do-ra",
    "engazamiento": "en-ga-za-mien-to",
    "engazar": "en-ga-zar",
    "engazo": "en-ga-zo",
    "engeñar": "en-ge-ñar",
    "engendrable": "en-gen-dra-ble",
    "engendración": "en-gen-dra-ción",
    "engendrador": "en-gen-dra-dor",
    "engendradora": "en-gen-dra-do-ra",
    "engendramiento": "en-gen-dra-mien-to",
    "engendrar": "en-gen-drar",
    "engendro": "en-gen-dro",
    "engenio": "en-ge-nio",
    "engeño": "en-ge-ño",
    "engeñosa": "en-ge-ño-sa",
    "engeñoso": "en-ge-ño-so",
    "engentar": "en-gen-tar",
    "engeridor": "en-ge-ri-dor",
    "engerimiento": "en-ge-ri-mien-to",
    "engerir": "en-ge-rir",
    "engestada": "en-ges-ta-da",
    "engestado": "en-ges-ta-do",
    "engibar": "en-gi-bar",
    "engina": "en-gi-na",
    "englandada": "en-glan-da-da",
    "englandado": "en-glan-da-do",
    "englantada": "en-glan-ta-da",
    "englantado": "en-glan-ta-do",
    "englobar": "en-glo-bar",
    "englutativa": "en-glu-ta-ti-va",
    "englutativo": "en-glu-ta-ti-vo",
    "englutir": "en-glu-tir",
    "engobe": "en-go-be",
    "engocetar": "en-go-ce-tar",
    "engolada": "en-go-la-da",
    "engolado": "en-go-la-do",
    "engolamiento": "en-go-la-mien-to",
    "engolar": "en-go-lar",
    "engolfar": "en-gol-far",
    "engolillada": "en-go-li-lla-da",
    "engolillado": "en-go-li-lla-do",
    "engollamiento": "en-go-lla-mien-to",
    "engolletada": "en-go-lle-ta-da",
    "engolletado": "en-go-lle-ta-do",
    "engolletar": "en-go-lle-tar",
    "engolletarse": "en-go-lle-tar-se",
    "engollipar": "en-go-lli-par",
    "engolliparse": "en-go-lli-par-se",
    "engolondrinar": "en-go-lon-dri-nar",
    "engolosinador": "en-go-lo-si-na-dor",
    "engolosinadora": "en-go-lo-si-na-do-ra",
    "engolosinamiento": "en-go-lo-si-na-mien-to",
    "engolosinar": "en-go-lo-si-nar",
    "engomada": "en-go-ma-da",
    "engomado": "en-go-ma-do",
    "engomadura": "en-go-ma-du-ra",
    "engomar": "en-go-mar",
    "engominar": "en-go-mi-nar",
    "engonzar": "en-gon-zar",
    "engorar": "en-go-rar",
    "engorda": "en-gor-da",
    "engordaderas": "en-gor-da-de-ras",
    "engordadero": "en-gor-da-de-ro",
    "engordador": "en-gor-da-dor",
    "engordadora": "en-gor-da-do-ra",
    "engordar": "en-gor-dar",
    "engorde": "en-gor-de",
    "engordecer": "en-gor-de-cer",
    "engorfa": "en-gor-fa",
    "engorgoritar": "en-gor-go-ri-tar",
    "engorilar": "en-go-ri-lar",
    "engorra": "en-go-rra",
    "engorrar": "en-go-rrar",
    "engorro": "en-go-rro",
    "engorronar": "en-go-rro-nar",
    "engorronarse": "en-go-rro-nar-se",
    "engorrosa": "en-go-rro-sa",
    "engorroso": "en-go-rro-so",
    "engoznar": "en-goz-nar",
    "engraciar": "en-gra-ciar",
    "engramar": "en-gra-mar",
    "engramear": "en-gra-me-ar",
    "engramillado": "en-gra-mi-lla-do",
    "engramillar": "en-gra-mi-llar",
    "engrampadora": "en-gram-pa-do-ra",
    "engrampar": "en-gram-par",
    "engranaje": "en-gra-na-je",
    "engranar": "en-gra-nar",
    "engrandar": "en-gran-dar",
    "engrandecer": "en-gran-de-cer",
    "engrandecimiento": "en-gran-de-ci-mien-to",
    "engrane": "en-gra-ne",
    "engranerar": "en-gra-ne-rar",
    "engranujar": "en-gra-nu-jar",
    "engranujarse": "en-gra-nu-jar-se",
    "engrapado": "en-gra-pa-do",
    "engrapadora": "en-gra-pa-do-ra",
    "engrapar": "en-gra-par",
    "engrasación": "en-gra-sa-ción",
    "engrasado": "en-gra-sa-do",
    "engrasador": "en-gra-sa-dor",
    "engrasadora": "en-gra-sa-do-ra",
    "engrasar": "en-gra-sar",
    "engrase": "en-gra-se",
    "engravecer": "en-gra-ve-cer",
    "engredar": "en-gre-dar",
    "engreída": "en-gre-í-da",
    "engreído": "en-gre-í-do",
    "engreimiento": "en-grei-mien-to",
    "engreír": "en-gre-ír",
    "engreñada": "en-gre-ña-da",
    "engreñado": "en-gre-ña-do",
    "engrescar": "en-gres-car",
    "engrifar": "en-gri-far",
    "engrillado": "en-gri-lla-do",
    "engrillar": "en-gri-llar",
    "engrillarse": "en-gri-llar-se",
    "engrilletar": "en-gri-lle-tar",
    "engrinchar": "en-grin-char",
    "engringar": "en-grin-gar",
    "engringarse": "en-grin-gar-se",
    "engripar": "en-gri-par",
    "engrosamiento": "en-gro-sa-mien-to",
    "engrosar": "en-gro-sar",
    "engrosecer": "en-gro-se-cer",
    "engrudador": "en-gru-da-dor",
    "engrudadora": "en-gru-da-do-ra",
    "engrudamiento": "en-gru-da-mien-to",
    "engrudar": "en-gru-dar",
    "engrudo": "en-gru-do",
    "engruesar": "en-grue-sar",
    "engrumecer": "en-gru-me-cer",
    "engrumecerse": "en-gru-me-cer-se",
    "engruñar": "en-gru-ñar",
    "engruño": "en-gru-ño",
    "engrupida": "en-gru-pi-da",
    "engrupido": "en-gru-pi-do",
    "engrupir": "en-gru-pir",
    "enguacar": "en-gua-car",
    "enguachinar": "en-gua-chi-nar",
    "engualdrapar": "en-gual-dra-par",
    "engualichar": "en-gua-li-char",
    "enguandocar": "en-guan-do-car",
    "enguandujar": "en-guan-du-jar",
    "enguantado": "en-guan-ta-do",
    "enguantar": "en-guan-tar",
    "enguaralar": "en-gua-ra-lar",
    "enguarapar": "en-gua-ra-par",
    "enguarapetar": "en-gua-ra-pe-tar",
    "enguarrar": "en-gua-rrar",
    "enguatada": "en-gua-ta-da",
    "enguatar": "en-gua-tar",
    "enguayabado": "en-gua-ya-ba-do",
    "enguayabar": "en-gua-ya-bar",
    "enguedejada": "en-gue-de-ja-da",
    "enguedejado": "en-gue-de-ja-do",
    "enguera": "en-gue-ra",
    "enguerar": "en-gue-rar",
    "engüerar": "en-güe-rar",
    "enguichada": "en-gui-cha-da",
    "enguichado": "en-gui-cha-do",
    "enguijarrado": "en-gui-ja-rra-do",
    "enguijarrar": "en-gui-ja-rrar",
    "enguillotar": "en-gui-llo-tar",
    "enguillotarse": "en-gui-llo-tar-se",
    "engüinchar": "en-güin-char",
    "enguirnaldar": "en-guir-nal-dar",
    "enguitarrar": "en-gui-ta-rrar",
    "enguizgar": "en-guiz-gar",
    "engullidor": "en-gu-lli-dor",
    "engullidora": "en-gu-lli-do-ra",
    "engullir": "en-gu-llir",
    "engurra": "en-gu-rra",
    "engurrar": "en-gu-rrar",
    "engurriada": "en-gu-rria-da",
    "engurriado": "en-gu-rria-do",
    "engurrio": "en-gu-rrio",
    "engurruminar": "en-gu-rru-mi-nar",
    "engurrumir": "en-gu-rru-mir",
    "engurruñar": "en-gu-rru-ñar",
    "engurruñir": "en-gu-rru-ñir",
    "engusanar": "en-gu-sa-nar",
    "engusgar": "en-gus-gar",
    "enhacendada": "en-ha-cen-da-da",
    "enhacendado": "en-ha-cen-da-do",
    "enhacinar": "en-ha-ci-nar",
    "enhadar": "en-ha-dar",
    "enhado": "en-ha-do",
    "enhadosa": "en-ha-do-sa",
    "enhadoso": "en-ha-do-so",
    "enharinar": "en-ha-ri-nar",
    "enhastiar": "en-has-tiar",
    "enhastillar": "en-has-ti-llar",
    "enhastiosa": "en-has-tio-sa",
    "enhastioso": "en-has-tio-so",
    "enhatijar": "en-ha-ti-jar",
    "enhebillar": "en-he-bi-llar",
    "enhebrar": "en-he-brar",
    "enhechizar": "en-he-chi-zar",
    "enhelgada": "en-hel-ga-da",
    "enhelgado": "en-hel-ga-do",
    "enhenar": "en-he-nar",
    "enherbolar": "en-her-bo-lar",
    "enhestador": "en-hes-ta-dor",
    "enhestadura": "en-hes-ta-du-ra",
    "enhestamiento": "en-hes-ta-mien-to",
    "enhestar": "en-hes-tar",
    "enhetradura": "en-he-tra-du-ra",
    "enhetrar": "en-he-trar",
    "enhielar": "en-hie-lar",
    "enhierbar": "en-hier-bar",
    "enhiesta": "en-hies-ta",
    "enhiesto": "en-hies-to",
    "enhilar": "en-hi-lar",
    "enhollinar": "en-ho-lli-nar",
    "enhorabuena": "en-ho-ra-bue-na",
    "enhoramala": "en-ho-ra-ma-la",
    "enhorcar": "en-hor-car",
    "enhornar": "en-hor-nar",
    "enhorquetar": "en-hor-que-tar",
    "enhotada": "en-ho-ta-da",
    "enhotado": "en-ho-ta-do",
    "enhotar": "en-ho-tar",
    "enhoto": "en-ho-to",
    "enhuecar": "en-hue-car",
    "enhuerar": "en-hue-rar",
    "enhuesar": "en-hue-sar",
    "enhuevar": "en-hue-var",
    "enhuinchar": "en-huin-char",
    "enhumedecer": "en-hu-me-de-cer",
    "enigma": "e-nig-ma",
    "enigmática": "e-nig-má-ti-ca",
    "enigmáticamente": "e-nig-má-ti-ca-men-te",
    "enigmático": "e-nig-má-ti-co",
    "enigmatista": "e-nig-ma-tis-ta",
    "enigmística": "e-nig-mís-ti-ca",
    "enjabar": "en-ja-bar",
    "enjabonada": "en-ja-bo-na-da",
    "enjabonado": "en-ja-bo-na-do",
    "enjabonadura": "en-ja-bo-na-du-ra",
    "enjabonar": "en-ja-bo-nar",
    "enjaezamiento": "en-ja-e-za-mien-to",
    "enjaezar": "en-ja-e-zar",
    "enjaguadura": "en-ja-gua-du-ra",
    "enjaguar": "en-ja-guar",
    "enjagüe": "en-ja-güe",
    "enjalbegado": "en-jal-be-ga-do",
    "enjalbegador": "en-jal-be-ga-dor",
    "enjalbegadora": "en-jal-be-ga-do-ra",
    "enjalbegadura": "en-jal-be-ga-du-ra",
    "enjalbegar": "en-jal-be-gar",
    "enjalbiego": "en-jal-bie-go",
    "enjalma": "en-jal-ma",
    "enjalmar": "en-jal-mar",
    "enjalmero": "en-jal-me-ro",
    "enjambradera": "en-jam-bra-de-ra",
    "enjambradero": "en-jam-bra-de-ro",
    "enjambrar": "en-jam-brar",
    "enjambrazón": "en-jam-bra-zón",
    "enjambre": "en-jam-bre",
    "enjaquimar": "en-ja-qui-mar",
    "enjaranar": "en-ja-ra-nar",
    "enjarciar": "en-jar-ciar",
    "enjardar": "en-jar-dar",
    "enjardinar": "en-jar-di-nar",
    "enjaretado": "en-ja-re-ta-do",
    "enjaretar": "en-ja-re-tar",
    "enjarje": "en-jar-je",
    "enjaulada": "en-jau-la-da",
    "enjaular": "en-jau-lar",
    "enjebar": "en-je-bar",
    "enjebe": "en-je-be",
    "enjeco": "en-je-co",
    "enjergada": "en-jer-ga-da",
    "enjergado": "en-jer-ga-do",
    "enjergar": "en-jer-gar",
    "enjerir": "en-je-rir",
    "enjero": "en-je-ro",
    "enjertación": "en-jer-ta-ción",
    "enjertal": "en-jer-tal",
    "enjertar": "en-jer-tar",
    "enjerto": "en-jer-to",
    "enjetado": "en-je-ta-do",
    "enjetar": "en-je-tar",
    "enjicar": "en-ji-car",
    "enjitomatar": "en-ji-to-ma-tar",
    "enjordanar": "en-jor-da-nar",
    "enjorguinar": "en-jor-gui-nar",
    "enjorguinarse": "en-jor-gui-nar-se",
    "enjorquetar": "en-jor-que-tar",
    "enjoyada": "en-jo-ya-da",
    "enjoyado": "en-jo-ya-do",
    "enjoyar": "en-jo-yar",
    "enjoyelada": "en-jo-ye-la-da",
    "enjoyelado": "en-jo-ye-la-do",
    "enjoyelador": "en-jo-ye-la-dor",
    "enjuagadientes": "en-jua-ga-dien-tes",
    "enjuagadura": "en-jua-ga-du-ra",
    "enjuagar": "en-jua-gar",
    "enjuagatorio": "en-jua-ga-to-rio",
    "enjuague": "en-jua-gue",
    "enjugador": "en-ju-ga-dor",
    "enjugadora": "en-ju-ga-do-ra",
    "enjugar": "en-ju-gar",
    "enjuiciable": "en-jui-cia-ble",
    "enjuiciamiento": "en-jui-cia-mien-to",
    "enjuiciar": "en-jui-ciar",
    "enjulio": "en-ju-lio",
    "enjullo": "en-ju-llo",
    "enjumar": "en-ju-mar",
    "enjuncar": "en-jun-car",
    "enjundia": "en-jun-dia",
    "enjundiosa": "en-jun-dio-sa",
    "enjundioso": "en-jun-dio-so",
    "enjunque": "en-jun-que",
    "enjuramiento": "en-ju-ra-mien-to",
    "enjurar": "en-ju-rar",
    "enjuta": "en-ju-ta",
    "enjutar": "en-ju-tar",
    "enjutez": "en-ju-tez",
    "enjuto": "en-ju-to",
    "enlabiador": "en-la-bia-dor",
    "enlabiadora": "en-la-bia-do-ra",
    "enlabiar": "en-la-biar",
    "enlabio": "en-la-bio",
    "enlace": "en-la-ce",
    "enlaciar": "en-la-ciar",
    "enladrillado": "en-la-dri-lla-do",
    "enladrillador": "en-la-dri-lla-dor",
    "enladrilladura": "en-la-dri-lla-du-ra",
    "enladrillar": "en-la-dri-llar",
    "enlagunar": "en-la-gu-nar",
    "enlajado": "en-la-ja-do",
    "enlamar": "en-la-mar",
    "enlaminar": "en-la-mi-nar",
    "enlaminarse": "en-la-mi-nar-se",
    "enlanada": "en-la-na-da",
    "enlanado": "en-la-na-do",
    "enlanchar": "en-lan-char",
    "enlardar": "en-lar-dar",
    "enlatado": "en-la-ta-do",
    "enlatar": "en-la-tar",
    "enlazable": "en-la-za-ble",
    "enlazador": "en-la-za-dor",
    "enlazadora": "en-la-za-do-ra",
    "enlazadura": "en-la-za-du-ra",
    "enlazamiento": "en-la-za-mien-to",
    "enlazar": "en-la-zar",
    "enlechar": "en-le-char",
    "enlechuguillada": "en-le-chu-gui-lla-da",
    "enlechuguillado": "en-le-chu-gui-lla-do",
    "enlegajar": "en-le-ga-jar",
    "enlegamar": "en-le-ga-mar",
    "enlejiar": "en-le-jiar",
    "enlentecer": "en-len-te-cer",
    "enlentecimiento": "en-len-te-ci-mien-to",
    "enlenzar": "en-len-zar",
    "enlerdar": "en-ler-dar",
    "enlevitado": "en-le-vi-ta-do",
    "enligar": "en-li-gar",
    "enlijar": "en-li-jar",
    "enlistar": "en-lis-tar",
    "enlistonado": "en-lis-to-na-do",
    "enlistonar": "en-lis-to-nar",
    "enlizar": "en-li-zar",
    "enllantar": "en-llan-tar",
    "enllavar": "en-lla-var",
    "enllenar": "en-lle-nar",
    "enllentecer": "en-llen-te-cer",
    "enllocar": "en-llo-car",
    "enlobreguecer": "en-lo-bre-gue-cer",
    "enlodadura": "en-lo-da-du-ra",
    "enlodamiento": "en-lo-da-mien-to",
    "enlodar": "en-lo-dar",
    "enlodazar": "en-lo-da-zar",
    "enlomar": "en-lo-mar",
    "enlomarse": "en-lo-mar-se",
    "enloquecedor": "en-lo-que-ce-dor",
    "enloquecedora": "en-lo-que-ce-do-ra",
    "enloquecedoramente": "en-lo-que-ce-do-ra-men-te",
    "enloquecer": "en-lo-que-cer",
    "enloquecidamente": "en-lo-que-ci-da-men-te",
    "enloquecido": "en-lo-que-ci-do",
    "enloquecimiento": "en-lo-que-ci-mien-to",
    "enlosado": "en-lo-sa-do",
    "enlosador": "en-lo-sa-dor",
    "enlosar": "en-lo-sar",
    "enlozado": "en-lo-za-do",
    "enlozanar": "en-lo-za-nar",
    "enlozanarse": "en-lo-za-nar-se",
    "enlozar": "en-lo-zar",
    "enlucernar": "en-lu-cer-nar",
    "enlucida": "en-lu-ci-da",
    "enlucido": "en-lu-ci-do",
    "enlucidor": "en-lu-ci-dor",
    "enlucidora": "en-lu-ci-do-ra",
    "enlucimiento": "en-lu-ci-mien-to",
    "enlucir": "en-lu-cir",
    "enlustrado": "en-lus-tra-do",
    "enlustrecer": "en-lus-tre-cer",
    "enlutada": "en-lu-ta-da",
    "enlutado": "en-lu-ta-do",
    "enlutar": "en-lu-tar",
    "enmadejar": "en-ma-de-jar",
    "enmaderación": "en-ma-de-ra-ción",
    "enmaderado": "en-ma-de-ra-do",
    "enmaderamiento": "en-ma-de-ra-mien-to",
    "enmaderar": "en-ma-de-rar",
    "enmadrar": "en-ma-drar",
    "enmadrarse": "en-ma-drar-se",
    "enmagrecer": "en-ma-gre-cer",
    "enmalecer": "en-ma-le-cer",
    "enmalecerse": "en-ma-le-cer-se",
    "enmallar": "en-ma-llar",
    "enmallarse": "en-ma-llar-se",
    "enmalle": "en-ma-lle",
    "enmangar": "en-man-gar",
    "enmaniguar": "en-ma-ni-guar",
    "enmaniguarse": "en-ma-ni-guar-se",
    "enmantar": "en-man-tar",
    "enmantillada": "en-man-ti-lla-da",
    "enmantillado": "en-man-ti-lla-do",
    "enmarañador": "en-ma-ra-ña-dor",
    "enmarañadora": "en-ma-ra-ña-do-ra",
    "enmarañamiento": "en-ma-ra-ña-mien-to",
    "enmarañar": "en-ma-ra-ñar",
    "enmarar": "en-ma-rar",
    "enmararse": "en-ma-rar-se",
    "enmarcar": "en-mar-car",
    "enmarchitable": "en-mar-chi-ta-ble",
    "enmarchitar": "en-mar-chi-tar",
    "enmaridar": "en-ma-ri-dar",
    "enmarihuanar": "en-ma-ri-hua-nar",
    "enmarillecer": "en-ma-ri-lle-cer",
    "enmarillecerse": "en-ma-ri-lle-cer-se",
    "enmaromar": "en-ma-ro-mar",
    "enmarquetar": "en-mar-que-tar",
    "enmarrocar": "en-ma-rro-car",
    "enmascarada": "en-mas-ca-ra-da",
    "enmascarado": "en-mas-ca-ra-do",
    "enmascaramiento": "en-mas-ca-ra-mien-to",
    "enmascarar": "en-mas-ca-rar",
    "enmasillar": "en-ma-si-llar",
    "enmatar": "en-ma-tar",
    "enmatarse": "en-ma-tar-se",
    "enmechar": "en-me-char",
    "enmelar": "en-me-lar",
    "enmendable": "en-men-da-ble",
    "enmendación": "en-men-da-ción",
    "enmendador": "en-men-da-dor",
    "enmendadora": "en-men-da-do-ra",
    "enmendadura": "en-men-da-du-ra",
    "enmendamiento": "en-men-da-mien-to",
    "enmendar": "en-men-dar",
    "enmendatura": "en-men-da-tu-ra",
    "enmerdar": "en-mer-dar",
    "enmicado": "en-mi-ca-do",
    "enmicar": "en-mi-car",
    "enmienda": "en-mien-da",
    "enmiente": "en-mien-te",
    "enmierdar": "en-mier-dar",
    "enmocecer": "en-mo-ce-cer",
    "enmohecer": "en-mo-he-cer",
    "enmohecimiento": "en-mo-he-ci-mien-to",
    "enmoldada": "en-mol-da-da",
    "enmoldado": "en-mol-da-do",
    "enmollecer": "en-mo-lle-cer",
    "enmonar": "en-mo-nar",
    "enmonarse": "en-mo-nar-se",
    "enmondar": "en-mon-dar",
    "enmontadura": "en-mon-ta-du-ra",
    "enmontañar": "en-mon-ta-ñar",
    "enmontar": "en-mon-tar",
    "enmontarse": "en-mon-tar-se",
    "enmoquetar": "en-mo-que-tar",
    "enmordazar": "en-mor-da-zar",
    "enmostar": "en-mos-tar",
    "enmotar": "en-mo-tar",
    "enmudecer": "en-mu-de-cer",
    "enmudecimiento": "en-mu-de-ci-mien-to",
    "enmugrar": "en-mu-grar",
    "enmugrecer": "en-mu-gre-cer",
    "enmugrentar": "en-mu-gren-tar",
    "enmustiar": "en-mus-tiar",
    "ennavajar": "en-na-va-jar",
    "enneciar": "en-ne-ciar",
    "enneciarse": "en-ne-ciar-se",
    "ennegrecer": "en-ne-gre-cer",
    "ennegrecimiento": "en-ne-gre-ci-mien-to",
    "ennoblecedor": "en-no-ble-ce-dor",
    "ennoblecedora": "en-no-ble-ce-do-ra",
    "ennoblecer": "en-no-ble-cer",
    "ennoblecimiento": "en-no-ble-ci-mien-to",
    "ennoviar": "en-no-viar",
    "ennudecer": "en-nu-de-cer",
    "enodio": "e-no-dio",
    "enodrido": "e-no-dri-do",
    "enografía": "e-no-gra-fí-a",
    "enojada": "e-no-ja-da",
    "enojadiza": "e-no-ja-di-za",
    "enojadizo": "e-no-ja-di-zo",
    "enojar": "e-no-jar",
    "enojo": "e-no-jo",
    "enojón": "e-no-jón",
    "enojona": "e-no-jo-na",
    "enojosa": "e-no-jo-sa",
    "enojosamente": "e-no-jo-sa-men-te",
    "enojoso": "e-no-jo-so",
    "enóloga": "e-nó-lo-ga",
    "enología": "e-no-lo-gí-a",
    "enológica": "e-no-ló-gi-ca",
    "enológico": "e-no-ló-gi-co",
    "enólogo": "e-nó-lo-go",
    "enorfanecida": "e-nor-fa-ne-ci-da",
    "enorfanecido": "e-nor-fa-ne-ci-do",
    "enorgullecedor": "e-nor-gu-lle-ce-dor",
    "enorgullecedora": "e-nor-gu-lle-ce-do-ra",
    "enorgullecer": "e-nor-gu-lle-cer",
    "enorgullecimiento": "e-nor-gu-lle-ci-mien-to",
    "enorme": "e-nor-me",
    "enormemente": "e-nor-me-men-te",
    "enormidad": "e-nor-mi-dad",
    "enotecnia": "e-no-tec-nia",
    "enotécnica": "e-no-téc-ni-ca",
    "enotécnico": "e-no-téc-ni-co",
    "enoyar": "e-no-yar",
    "enquenado": "en-que-na-do",
    "enquiciar": "en-qui-ciar",
    "enquillotrar": "en-qui-llo-trar",
    "enquilombar": "en-qui-lom-bar",
    "enquiridión": "en-qui-ri-dión",
    "enquistada": "en-quis-ta-da",
    "enquistado": "en-quis-ta-do",
    "enquistamiento": "en-quis-ta-mien-to",
    "enquistar": "en-quis-tar",
    "enrabar": "en-ra-bar",
    "enrabiar": "en-ra-biar",
    "enrabietar": "en-ra-bie-tar",
    "enracimar": "en-ra-ci-mar",
    "enracimarse": "en-ra-ci-mar-se",
    "enrafar": "en-ra-far",
    "enraigonar": "en-rai-go-nar",
    "enraizamiento": "en-rai-za-mien-to",
    "enraizar": "en-rai-zar",
    "enralecer": "en-ra-le-cer",
    "enramada": "en-ra-ma-da",
    "enramado": "en-ra-ma-do",
    "enramar": "en-ra-mar",
    "enramblar": "en-ram-blar",
    "enrame": "en-ra-me",
    "enranciar": "en-ran-ciar",
    "enrarecer": "en-ra-re-cer",
    "enrarecimiento": "en-ra-re-ci-mien-to",
    "enrasado": "en-ra-sa-do",
    "enrasamiento": "en-ra-sa-mien-to",
    "enrasar": "en-ra-sar",
    "enrase": "en-ra-se",
    "enrasillar": "en-ra-si-llar",
    "enratonado": "en-ra-to-na-do",
    "enratonar": "en-ra-to-nar",
    "enratonarse": "en-ra-to-nar-se",
    "enrayado": "en-ra-ya-do",
    "enrayar": "en-ra-yar",
    "enrazado": "en-ra-za-do",
    "enrazar": "en-ra-zar",
    "enreciar": "en-re-ciar",
    "enrectar": "en-rec-tar",
    "enredadera": "en-re-da-de-ra",
    "enredador": "en-re-da-dor",
    "enredadora": "en-re-da-do-ra",
    "enredamiento": "en-re-da-mien-to",
    "enredar": "en-re-dar",
    "enredijo": "en-re-di-jo",
    "enredista": "en-re-dis-ta",
    "enredo": "en-re-do",
    "enredosa": "en-re-do-sa",
    "enredoso": "en-re-do-so",
    "enrehojar": "en-re-ho-jar",
    "enrejada": "en-re-ja-da",
    "enrejado": "en-re-ja-do",
    "enrejadura": "en-re-ja-du-ra",
    "enrejalar": "en-re-ja-lar",
    "enrejar": "en-re-jar",
    "enresmar": "en-res-mar",
    "enrevesada": "en-re-ve-sa-da",
    "enrevesado": "en-re-ve-sa-do",
    "enriado": "en-ria-do",
    "enriador": "en-ria-dor",
    "enriadora": "en-ria-do-ra",
    "enriamiento": "en-ria-mien-to",
    "enriar": "en-riar",
    "enridar": "en-ri-dar",
    "enrielar": "en-rie-lar",
    "enriendar": "en-rien-dar",
    "enrigidecer": "en-ri-gi-de-cer",
    "enriostrar": "en-rios-trar",
    "enripiar": "en-ri-piar",
    "enrique": "en-ri-que",
    "enriquecedor": "en-ri-que-ce-dor",
    "enriquecedora": "en-ri-que-ce-do-ra",
    "enriquecer": "en-ri-que-cer",
    "enriquecimiento": "en-ri-que-ci-mien-to",
    "enriqueña": "en-ri-que-ña",
    "enriqueño": "en-ri-que-ño",
    "enriscada": "en-ris-ca-da",
    "enriscado": "en-ris-ca-do",
    "enriscamiento": "en-ris-ca-mien-to",
    "enriscar": "en-ris-car",
    "enristrar": "en-ris-trar",
    "enristre": "en-ris-tre",
    "enrizado": "en-ri-za-do",
    "enrizamiento": "en-ri-za-mien-to",
    "enrizar": "en-ri-zar",
    "enrobinar": "en-ro-bi-nar",
    "enrobinarse": "en-ro-bi-nar-se",
    "enrobrescida": "en-ro-bres-ci-da",
    "enrobrescido": "en-ro-bres-ci-do",
    "enrocar": "en-ro-car",
    "enrocarse": "en-ro-car-se",
    "enrodar": "en-ro-dar",
    "enrodelada": "en-ro-de-la-da",
    "enrodelado": "en-ro-de-la-do",
    "enrodrigar": "en-ro-dri-gar",
    "enrodrigonar": "en-ro-dri-go-nar",
    "enrojar": "en-ro-jar",
    "enrojecer": "en-ro-je-cer",
    "enrojecimiento": "en-ro-je-ci-mien-to",
    "enrolamiento": "en-ro-la-mien-to",
    "enrolar": "en-ro-lar",
    "enrollada": "en-ro-lla-da",
    "enrollado": "en-ro-lla-do",
    "enrollamiento": "en-ro-lla-mien-to",
    "enrollar": "en-ro-llar",
    "enrolle": "en-ro-lle",
    "enromar": "en-ro-mar",
    "enrona": "en-ro-na",
    "enronar": "en-ro-nar",
    "enroñar": "en-ro-ñar",
    "enronchar": "en-ron-char",
    "enronquecer": "en-ron-que-cer",
    "enronquecimiento": "en-ron-que-ci-mien-to",
    "enroque": "en-ro-que",
    "enroscadamente": "en-ros-ca-da-men-te",
    "enroscadura": "en-ros-ca-du-ra",
    "enroscamiento": "en-ros-ca-mien-to",
    "enroscar": "en-ros-car",
    "enrostrar": "en-ros-trar",
    "enrubescer": "en-ru-bes-cer",
    "enrubiador": "en-ru-bia-dor",
    "enrubiadora": "en-ru-bia-do-ra",
    "enrubiar": "en-ru-biar",
    "enrubio": "en-ru-bio",
    "enrudecer": "en-ru-de-cer",
    "enruga": "en-ru-ga",
    "enrugar": "en-ru-gar",
    "enruinecer": "en-rui-ne-cer",
    "enrumbada": "en-rum-ba-da",
    "enrumbar": "en-rum-bar",
    "enruna": "en-ru-na",
    "enrunar": "en-ru-nar",
    "ensabanada": "en-sa-ba-na-da",
    "ensabanado": "en-sa-ba-na-do",
    "ensabanar": "en-sa-ba-nar",
    "ensacador": "en-sa-ca-dor",
    "ensacadora": "en-sa-ca-do-ra",
    "ensacar": "en-sa-car",
    "ensaimada": "en-sai-ma-da",
    "ensalada": "en-sa-la-da",
    "ensaladera": "en-sa-la-de-ra",
    "ensaladilla": "en-sa-la-di-lla",
    "ensalitrar": "en-sa-li-trar",
    "ensalivar": "en-sa-li-var",
    "ensalmadera": "en-sal-ma-de-ra",
    "ensalmador": "en-sal-ma-dor",
    "ensalmadora": "en-sal-ma-do-ra",
    "ensalmar": "en-sal-mar",
    "ensalmo": "en-sal-mo",
    "ensalobrar": "en-sa-lo-brar",
    "ensalobrarse": "en-sa-lo-brar-se",
    "ensalzador": "en-sal-za-dor",
    "ensalzadora": "en-sal-za-do-ra",
    "ensalzamiento": "en-sal-za-mien-to",
    "ensalzar": "en-sal-zar",
    "ensambenitar": "en-sam-be-ni-tar",
    "ensamblado": "en-sam-bla-do",
    "ensamblador": "en-sam-bla-dor",
    "ensambladura": "en-sam-bla-du-ra",
    "ensamblaje": "en-sam-bla-je",
    "ensamblar": "en-sam-blar",
    "ensamble": "en-sam-ble",
    "ensañada": "en-sa-ña-da",
    "ensañado": "en-sa-ña-do",
    "ensañamiento": "en-sa-ña-mien-to",
    "ensañar": "en-sa-ñar",
    "ensancha": "en-san-cha",
    "ensanchador": "en-san-cha-dor",
    "ensanchadora": "en-san-cha-do-ra",
    "ensanchamiento": "en-san-cha-mien-to",
    "ensanchar": "en-san-char",
    "ensanche": "en-san-che",
    "ensandecer": "en-san-de-cer",
    "ensangostar": "en-san-gos-tar",
    "ensangrentamiento": "en-san-gren-ta-mien-to",
    "ensangrentar": "en-san-gren-tar",
    "ensarapada": "en-sa-ra-pa-da",
    "ensarapado": "en-sa-ra-pa-do",
    "ensarmentar": "en-sar-men-tar",
    "ensarnecer": "en-sar-ne-cer",
    "ensartado": "en-sar-ta-do",
    "ensartar": "en-sar-tar",
    "ensay": "en-say",
    "ensayado": "en-sa-ya-do",
    "ensayador": "en-sa-ya-dor",
    "ensayadora": "en-sa-ya-do-ra",
    "ensayalar": "en-sa-ya-lar",
    "ensayar": "en-sa-yar",
    "ensaye": "en-sa-ye",
    "ensayismo": "en-sa-yis-mo",
    "ensayista": "en-sa-yis-ta",
    "ensayística": "en-sa-yís-ti-ca",
    "ensayístico": "en-sa-yís-ti-co",
    "ensayo": "en-sa-yo",
    "ensebado": "en-se-ba-do",
    "ensebar": "en-se-bar",
    "ensecar": "en-se-car",
    "enseguida": "en-se-gui-da",
    "enselvada": "en-sel-va-da",
    "enselvado": "en-sel-va-do",
    "enselvar": "en-sel-var",
    "ensemble": "en-sem-ble",
    "enseña": "en-se-ña",
    "enseñable": "en-se-ña-ble",
    "ensenada": "en-se-na-da",
    "enseñada": "en-se-ña-da",
    "enseñadamente": "en-se-ña-da-men-te",
    "enseñadera": "en-se-ña-de-ra",
    "enseñadero": "en-se-ña-de-ro",
    "ensenado": "en-se-na-do",
    "enseñado": "en-se-ña-do",
    "enseñador": "en-se-ña-dor",
    "enseñadora": "en-se-ña-do-ra",
    "enseñamiento": "en-se-ña-mien-to",
    "enseñante": "en-se-ñan-te",
    "enseñanza": "en-se-ñan-za",
    "ensenar": "en-se-nar",
    "enseñar": "en-se-ñar",
    "enseño": "en-se-ño",
    "enseñoramiento": "en-se-ño-ra-mien-to",
    "enseñoreador": "en-se-ño-re-a-dor",
    "enseñorear": "en-se-ño-re-ar",
    "enserar": "en-se-rar",
    "enserenar": "en-se-re-nar",
    "enseres": "en-se-res",
    "enseriar": "en-se-riar",
    "enserir": "en-se-rir",
    "ensiforme": "en-si-for-me",
    "ensilado": "en-si-la-do",
    "ensiladora": "en-si-la-do-ra",
    "ensilaje": "en-si-la-je",
    "ensilar": "en-si-lar",
    "ensillada": "en-si-lla-da",
    "ensillado": "en-si-lla-do",
    "ensilladura": "en-si-lla-du-ra",
    "ensillar": "en-si-llar",
    "ensilvecer": "en-sil-ve-cer",
    "ensilvecerse": "en-sil-ve-cer-se",
    "ensimismado": "en-si-mis-ma-do",
    "ensimismamiento": "en-si-mis-ma-mien-to",
    "ensimismar": "en-si-mis-mar",
    "ensimismarse": "en-si-mis-mar-se",
    "ensobear": "en-so-be-ar",
    "ensoberbecer": "en-so-ber-be-cer",
    "ensoberbecimiento": "en-so-ber-be-ci-mien-to",
    "ensobinar": "en-so-bi-nar",
    "ensobinarse": "en-so-bi-nar-se",
    "ensobrado": "en-so-bra-do",
    "ensobrar": "en-so-brar",
    "ensobretar": "en-so-bre-tar",
    "ensogar": "en-so-gar",
    "ensolerar": "en-so-le-rar",
    "ensolvedera": "en-sol-ve-de-ra",
    "ensolvedor": "en-sol-ve-dor",
    "ensolvedora": "en-sol-ve-do-ra",
    "ensolver": "en-sol-ver",
    "ensombrecer": "en-som-bre-cer",
    "ensombrerada": "en-som-bre-ra-da",
    "ensombrerado": "en-som-bre-ra-do",
    "ensoñación": "en-so-ña-ción",
    "ensoñador": "en-so-ña-dor",
    "ensoñadora": "en-so-ña-do-ra",
    "ensoñar": "en-so-ñar",
    "ensopada": "en-so-pa-da",
    "ensopar": "en-so-par",
    "ensordamiento": "en-sor-da-mien-to",
    "ensordar": "en-sor-dar",
    "ensordecedor": "en-sor-de-ce-dor",
    "ensordecedora": "en-sor-de-ce-do-ra",
    "ensordecer": "en-sor-de-cer",
    "ensordecimiento": "en-sor-de-ci-mien-to",
    "ensortijado": "en-sor-ti-ja-do",
    "ensortijamiento": "en-sor-ti-ja-mien-to",
    "ensortijar": "en-sor-ti-jar",
    "ensotar": "en-so-tar",
    "ensotarse": "en-so-tar-se",
    "ensuciador": "en-su-cia-dor",
    "ensuciadora": "en-su-cia-do-ra",
    "ensuciamiento": "en-su-cia-mien-to",
    "ensuciar": "en-su-ciar",
    "ensuelar": "en-sue-lar",
    "ensueño": "en-sue-ño",
    "ensugar": "en-su-gar",
    "ensullo": "en-su-llo",
    "enta": "en-ta",
    "entabacar": "en-ta-ba-car",
    "entabacarse": "en-ta-ba-car-se",
    "entabanar": "en-ta-ba-nar",
    "entabicado": "en-ta-bi-ca-do",
    "entabicar": "en-ta-bi-car",
    "entablación": "en-ta-bla-ción",
    "entablada": "en-ta-bla-da",
    "entablado": "en-ta-bla-do",
    "entabladura": "en-ta-bla-du-ra",
    "entablamento": "en-ta-bla-men-to",
    "entablamiento": "en-ta-bla-mien-to",
    "entablar": "en-ta-blar",
    "entable": "en-ta-ble",
    "entablerar": "en-ta-ble-rar",
    "entablerarse": "en-ta-ble-rar-se",
    "entablillar": "en-ta-bli-llar",
    "entacuchar": "en-ta-cu-char",
    "entado": "en-ta-do",
    "entalamadura": "en-ta-la-ma-du-ra",
    "entalamar": "en-ta-la-mar",
    "entalegado": "en-ta-le-ga-do",
    "entalegar": "en-ta-le-gar",
    "entalingar": "en-ta-lin-gar",
    "entalla": "en-ta-lla",
    "entallable": "en-ta-lla-ble",
    "entallador": "en-ta-lla-dor",
    "entalladora": "en-ta-lla-do-ra",
    "entalladura": "en-ta-lla-du-ra",
    "entallamiento": "en-ta-lla-mien-to",
    "entallar": "en-ta-llar",
    "entalle": "en-ta-lle",
    "entallecer": "en-ta-lle-cer",
    "entallo": "en-ta-llo",
    "entalonar": "en-ta-lo-nar",
    "entalpía": "en-tal-pí-a",
    "entamar": "en-ta-mar",
    "entandar": "en-tan-dar",
    "entapecer": "en-ta-pe-cer",
    "entapetada": "en-ta-pe-ta-da",
    "entapetado": "en-ta-pe-ta-do",
    "entapizada": "en-ta-pi-za-da",
    "entapizado": "en-ta-pi-za-do",
    "entapizar": "en-ta-pi-zar",
    "entapujar": "en-ta-pu-jar",
    "entaquillar": "en-ta-qui-llar",
    "entarascar": "en-ta-ras-car",
    "entarimado": "en-ta-ri-ma-do",
    "entarimador": "en-ta-ri-ma-dor",
    "entarimar": "en-ta-ri-mar",
    "entarquinamiento": "en-tar-qui-na-mien-to",
    "entarquinar": "en-tar-qui-nar",
    "entarugado": "en-ta-ru-ga-do",
    "entarugar": "en-ta-ru-gar",
    "éntasis": "én-ta-sis",
    "ente": "en-te",
    "enteca": "en-te-ca",
    "entecada": "en-te-ca-da",
    "entecado": "en-te-ca-do",
    "entecar": "en-te-car",
    "entecarse": "en-te-car-se",
    "entechar": "en-te-char",
    "enteco": "en-te-co",
    "entejar": "en-te-jar",
    "entelar": "en-te-lar",
    "entelequia": "en-te-le-quia",
    "entelerida": "en-te-le-ri-da",
    "entelerido": "en-te-le-ri-do",
    "entena": "en-te-na",
    "entenada": "en-te-na-da",
    "entenado": "en-te-na-do",
    "entenciar": "en-ten-ciar",
    "entendederas": "en-ten-de-de-ras",
    "entendedor": "en-ten-de-dor",
    "entendedora": "en-ten-de-do-ra",
    "entender": "en-ten-der",
    "entendible": "en-ten-di-ble",
    "entendida": "en-ten-di-da",
    "entendidamente": "en-ten-di-da-men-te",
    "entendido": "en-ten-di-do",
    "entendimiento": "en-ten-di-mien-to",
    "entenebrar": "en-te-ne-brar",
    "entenebrecer": "en-te-ne-bre-cer",
    "entenga": "en-ten-ga",
    "entente": "en-ten-te",
    "entenzón": "en-ten-zón",
    "enteo": "en-te-o",
    "enteógeno": "en-te-ó-ge-no",
    "enteque": "en-te-que",
    "entera": "en-te-ra",
    "enterada": "en-te-ra-da",
    "enteradilla": "en-te-ra-di-lla",
    "enteradillo": "en-te-ra-di-llo",
    "enterado": "en-te-ra-do",
    "enteralgia": "en-te-ral-gia",
    "enteramente": "en-te-ra-men-te",
    "enteramiento": "en-te-ra-mien-to",
    "enterar": "en-te-rar",
    "entercar": "en-ter-car",
    "entercarse": "en-ter-car-se",
    "enterciar": "en-ter-ciar",
    "enterectomía": "en-te-rec-to-mí-a",
    "enterez": "en-te-rez",
    "entereza": "en-te-re-za",
    "entérica": "en-té-ri-ca",
    "entérico": "en-té-ri-co",
    "enteritis": "en-te-ri-tis",
    "enterito": "en-te-ri-to",
    "enteriza": "en-te-ri-za",
    "enterizo": "en-te-ri-zo",
    "enternecedor": "en-ter-ne-ce-dor",
    "enternecedora": "en-ter-ne-ce-do-ra",
    "enternecer": "en-ter-ne-cer",
    "enternecidamente": "en-ter-ne-ci-da-men-te",
    "enternecimiento": "en-ter-ne-ci-mien-to",
    "entero": "en-te-ro",
    "enterocolitis": "en-te-ro-co-li-tis",
    "enteropatía": "en-te-ro-pa-tí-a",
    "enterostomía": "en-te-ros-to-mí-a",
    "enterradero": "en-te-rra-de-ro",
    "enterrador": "en-te-rra-dor",
    "enterramiento": "en-te-rra-mien-to",
    "enterrar": "en-te-rrar",
    "entesada": "en-te-sa-da",
    "entesadamente": "en-te-sa-da-men-te",
    "entesado": "en-te-sa-do",
    "entesamiento": "en-te-sa-mien-to",
    "entesar": "en-te-sar",
    "entestada": "en-tes-ta-da",
    "entestado": "en-tes-ta-do",
    "entestar": "en-tes-tar",
    "entestecer": "en-tes-te-cer",
    "entibación": "en-ti-ba-ción",
    "entibador": "en-ti-ba-dor",
    "entibar": "en-ti-bar",
    "entibiadero": "en-ti-bia-de-ro",
    "entibiar": "en-ti-biar",
    "entibiecer": "en-ti-bie-cer",
    "entibo": "en-ti-bo",
    "entidad": "en-ti-dad",
    "entierrar": "en-tie-rrar",
    "entierro": "en-tie-rro",
    "entiesar": "en-tie-sar",
    "entigrecer": "en-ti-gre-cer",
    "entigrecerse": "en-ti-gre-cer-se",
    "entilar": "en-ti-lar",
    "entimbalado": "en-tim-ba-la-do",
    "entimema": "en-ti-me-ma",
    "entimemático": "en-ti-me-má-ti-co",
    "entinar": "en-ti-nar",
    "entintado": "en-tin-ta-do",
    "entintar": "en-tin-tar",
    "entirriar": "en-ti-rriar",
    "entisar": "en-ti-sar",
    "entitativa": "en-ti-ta-ti-va",
    "entitativo": "en-ti-ta-ti-vo",
    "entizar": "en-ti-zar",
    "entiznar": "en-tiz-nar",
    "entoladora": "en-to-la-do-ra",
    "entolar": "en-to-lar",
    "entoldado": "en-tol-da-do",
    "entoldadura": "en-tol-da-du-ra",
    "entoldamiento": "en-tol-da-mien-to",
    "entoldar": "en-tol-dar",
    "entoletar": "en-to-le-tar",
    "entoloma": "en-to-lo-ma",
    "entomatada": "en-to-ma-ta-da",
    "entomecer": "en-to-me-cer",
    "entomecimiento": "en-to-me-ci-mien-to",
    "entomizar": "en-to-mi-zar",
    "entomófila": "en-to-mó-fi-la",
    "entomófilo": "en-to-mó-fi-lo",
    "entomóloga": "en-to-mó-lo-ga",
    "entomología": "en-to-mo-lo-gí-a",
    "entomológica": "en-to-mo-ló-gi-ca",
    "entomológico": "en-to-mo-ló-gi-co",
    "entomólogo": "en-to-mó-lo-go",
    "entonación": "en-to-na-ción",
    "entonadera": "en-to-na-de-ra",
    "entonador": "en-to-na-dor",
    "entonadora": "en-to-na-do-ra",
    "entonamiento": "en-to-na-mien-to",
    "entonar": "en-to-nar",
    "entoñar": "en-to-ñar",
    "entonatorio": "en-to-na-to-rio",
    "entonce": "en-ton-ce",
    "entonces": "en-ton-ces",
    "entonelar": "en-to-ne-lar",
    "entongar": "en-ton-gar",
    "entono": "en-to-no",
    "entontecer": "en-ton-te-cer",
    "entontecimiento": "en-ton-te-ci-mien-to",
    "entorar": "en-to-rar",
    "entorcar": "en-tor-car",
    "entorcarse": "en-tor-car-se",
    "entorchado": "en-tor-cha-do",
    "entorchar": "en-tor-char",
    "entore": "en-to-re",
    "entorilar": "en-to-ri-lar",
    "entormecimiento": "en-tor-me-ci-mien-to",
    "entornar": "en-tor-nar",
    "entornillar": "en-tor-ni-llar",
    "entorno": "en-tor-no",
    "entorpecedor": "en-tor-pe-ce-dor",
    "entorpecedora": "en-tor-pe-ce-do-ra",
    "entorpecer": "en-tor-pe-cer",
    "entorpecimiento": "en-tor-pe-ci-mien-to",
    "entortadura": "en-tor-ta-du-ra",
    "entortar": "en-tor-tar",
    "entortijar": "en-tor-ti-jar",
    "entosicar": "en-to-si-car",
    "entosigar": "en-to-si-gar",
    "entotorar": "en-to-to-rar",
    "entozoario": "en-to-zo-a-rio",
    "entrabar": "en-tra-bar",
    "entrada": "en-tra-da",
    "entradero": "en-tra-de-ro",
    "entradilla": "en-tra-di-lla",
    "entrado": "en-tra-do",
    "entrador": "en-tra-dor",
    "entradora": "en-tra-do-ra",
    "entramado": "en-tra-ma-do",
    "entramar": "en-tra-mar",
    "entramas": "en-tra-mas",
    "entrambas": "en-tram-bas",
    "entrambos": "en-tram-bos",
    "entramiento": "en-tra-mien-to",
    "entramojar": "en-tra-mo-jar",
    "entramos": "en-tra-mos",
    "entrampar": "en-tram-par",
    "entrampillar": "en-tram-pi-llar",
    "entraña": "en-tra-ña",
    "entrañable": "en-tra-ña-ble",
    "entrañablemente": "en-tra-ña-ble-men-te",
    "entrañal": "en-tra-ñal",
    "entrañalmente": "en-tra-ñal-men-te",
    "entrañar": "en-tra-ñar",
    "entrañizar": "en-tra-ñi-zar",
    "entraño": "en-tra-ño",
    "entrante": "en-tran-te",
    "entrapada": "en-tra-pa-da",
    "entrapajar": "en-tra-pa-jar",
    "entrapar": "en-tra-par",
    "entrapazar": "en-tra-pa-zar",
    "entrar": "en-trar",
    "entrazada": "en-tra-za-da",
    "entrazado": "en-tra-za-do",
    "entre": "en-tre",
    "entreabierta": "en-tre-a-bier-ta",
    "entreabierto": "en-tre-a-bier-to",
    "entreabrir": "en-tre-a-brir",
    "entreacto": "en-tre-ac-to",
    "entreancha": "en-tre-an-cha",
    "entreancho": "en-tre-an-cho",
    "entrebarrera": "en-tre-ba-rre-ra",
    "entrecalle": "en-tre-ca-lle",
    "entrecana": "en-tre-ca-na",
    "entrecanal": "en-tre-ca-nal",
    "entrecano": "en-tre-ca-no",
    "entrecasco": "en-tre-cas-co",
    "entrecava": "en-tre-ca-va",
    "entrecavar": "en-tre-ca-var",
    "entrecejo": "en-tre-ce-jo",
    "entrecerca": "en-tre-cer-ca",
    "entrecerrar": "en-tre-ce-rrar",
    "entrechocamiento": "en-tre-cho-ca-mien-to",
    "entrechocar": "en-tre-cho-car",
    "entrecielo": "en-tre-cie-lo",
    "entrecinta": "en-tre-cin-ta",
    "entreclara": "en-tre-cla-ra",
    "entreclaro": "en-tre-cla-ro",
    "entrecogedura": "en-tre-co-ge-du-ra",
    "entrecoger": "en-tre-co-ger",
    "entrecomar": "en-tre-co-mar",
    "entrecomillado": "en-tre-co-mi-lla-do",
    "entrecomillar": "en-tre-co-mi-llar",
    "entrecoro": "en-tre-co-ro",
    "entrecortada": "en-tre-cor-ta-da",
    "entrecortado": "en-tre-cor-ta-do",
    "entrecortadura": "en-tre-cor-ta-du-ra",
    "entrecortar": "en-tre-cor-tar",
    "entrecorteza": "en-tre-cor-te-za",
    "entrecostilla": "en-tre-cos-ti-lla",
    "entrecot": "en-tre-cot",
    "entrecriar": "en-tre-criar",
    "entrecriarse": "en-tre-criar-se",
    "entrecruzamiento": "en-tre-cru-za-mien-to",
    "entrecruzar": "en-tre-cru-zar",
    "entrecubierta": "en-tre-cu-bier-ta",
    "entrecuesto": "en-tre-cues-to",
    "entredecir": "en-tre-de-cir",
    "entrederramar": "en-tre-de-rra-mar",
    "entredicho": "en-tre-di-cho",
    "entredoble": "en-tre-do-ble",
    "entredormir": "en-tre-dor-mir",
    "entredós": "en-tre-dós",
    "entrefina": "en-tre-fi-na",
    "entrefino": "en-tre-fi-no",
    "entreforro": "en-tre-fo-rro",
    "entrega": "en-tre-ga",
    "entregada": "en-tre-ga-da",
    "entregadamente": "en-tre-ga-da-men-te",
    "entregado": "en-tre-ga-do",
    "entregador": "en-tre-ga-dor",
    "entregadora": "en-tre-ga-do-ra",
    "entregamiento": "en-tre-ga-mien-to",
    "entregar": "en-tre-gar",
    "entregerir": "en-tre-ge-rir",
    "entrego": "en-tre-go",
    "entregoteada": "en-tre-go-te-a-da",
    "entregoteado": "en-tre-go-te-a-do",
    "entreguismo": "en-tre-guis-mo",
    "entreguista": "en-tre-guis-ta",
    "entrehierro": "en-tre-hie-rro",
    "entrejuntar": "en-tre-jun-tar",
    "entrelargo": "en-tre-lar-go",
    "entrelazado": "en-tre-la-za-do",
    "entrelazamiento": "en-tre-la-za-mien-to",
    "entrelazar": "en-tre-la-zar",
    "entrelazo": "en-tre-la-zo",
    "entrelínea": "en-tre-lí-ne-a",
    "entrelinear": "en-tre-li-ne-ar",
    "entreliño": "en-tre-li-ño",
    "entrelistada": "en-tre-lis-ta-da",
    "entrelistado": "en-tre-lis-ta-do",
    "entrellevar": "en-tre-lle-var",
    "entrelubricán": "en-tre-lu-bri-cán",
    "entrelucir": "en-tre-lu-cir",
    "entremediana": "en-tre-me-dia-na",
    "entremediano": "en-tre-me-dia-no",
    "entremediar": "en-tre-me-diar",
    "entremedias": "en-tre-me-dias",
    "entremedio": "en-tre-me-dio",
    "entremés": "en-tre-més",
    "entremesar": "en-tre-me-sar",
    "entremesear": "en-tre-me-se-ar",
    "entremesil": "en-tre-me-sil",
    "entremesista": "en-tre-me-sis-ta",
    "entremetedor": "en-tre-me-te-dor",
    "entremetedora": "en-tre-me-te-do-ra",
    "entremeter": "en-tre-me-ter",
    "entremetida": "en-tre-me-ti-da",
    "entremetido": "en-tre-me-ti-do",
    "entremetimiento": "en-tre-me-ti-mien-to",
    "entremezcladura": "en-tre-mez-cla-du-ra",
    "entremezclar": "en-tre-mez-clar",
    "entremiche": "en-tre-mi-che",
    "entremijo": "en-tre-mi-jo",
    "entremiso": "en-tre-mi-so",
    "entremorir": "en-tre-mo-rir",
    "entremostrar": "en-tre-mos-trar",
    "entrenador": "en-tre-na-dor",
    "entrenadora": "en-tre-na-do-ra",
    "entrenamiento": "en-tre-na-mien-to",
    "entrenar": "en-tre-nar",
    "entrencar": "en-tren-car",
    "entrenervio": "en-tre-ner-vio",
    "entrenervios": "en-tre-ner-vios",
    "entreno": "en-tre-no",
    "entrenudo": "en-tre-nu-do",
    "entrenzar": "en-tren-zar",
    "entreoír": "en-tre-o-ír",
    "entreordinaria": "en-tre-or-di-na-ria",
    "entreordinario": "en-tre-or-di-na-rio",
    "entreoscura": "en-tre-os-cu-ra",
    "entreoscuro": "en-tre-os-cu-ro",
    "entrepalmadura": "en-tre-pal-ma-du-ra",
    "entrepañada": "en-tre-pa-ña-da",
    "entrepañado": "en-tre-pa-ña-do",
    "entrepanes": "en-tre-pa-nes",
    "entrepaño": "en-tre-pa-ño",
    "entreparecer": "en-tre-pa-re-cer",
    "entreparecerse": "en-tre-pa-re-cer-se",
    "entrepaso": "en-tre-pa-so",
    "entrepechado": "en-tre-pe-cha-do",
    "entrepechuga": "en-tre-pe-chu-ga",
    "entrepeines": "en-tre-pei-nes",
    "entrepelada": "en-tre-pe-la-da",
    "entrepelado": "en-tre-pe-la-do",
    "entrepelar": "en-tre-pe-lar",
    "entrepernar": "en-tre-per-nar",
    "entrepierna": "en-tre-pier-na",
    "entrepiso": "en-tre-pi-so",
    "entrépita": "en-tré-pi-ta",
    "entrépito": "en-tré-pi-to",
    "entreplanta": "en-tre-plan-ta",
    "entreponer": "en-tre-po-ner",
    "entreportón": "en-tre-por-tón",
    "entrepostura": "en-tre-pos-tu-ra",
    "entrepretada": "en-tre-pre-ta-da",
    "entrepretado": "en-tre-pre-ta-do",
    "entrepuente": "en-tre-puen-te",
    "entrepunzadura": "en-tre-pun-za-du-ra",
    "entrepunzar": "en-tre-pun-zar",
    "entrerraída": "en-tre-rra-í-da",
    "entrerraído": "en-tre-rra-í-do",
    "entrerrenglonadura": "en-tre-rren-glo-na-du-ra",
    "entrerrenglonar": "en-tre-rren-glo-nar",
    "entrerriana": "en-tre-rria-na",
    "entrerriano": "en-tre-rria-no",
    "entrés": "en-trés",
    "entresaca": "en-tre-sa-ca",
    "entresacadura": "en-tre-sa-ca-du-ra",
    "entresacar": "en-tre-sa-car",
    "entresemana": "en-tre-se-ma-na",
    "entreseña": "en-tre-se-ña",
    "entresijo": "en-tre-si-jo",
    "entresuelo": "en-tre-sue-lo",
    "entresueño": "en-tre-sue-ño",
    "entresurco": "en-tre-sur-co",
    "entretalla": "en-tre-ta-lla",
    "entretalladura": "en-tre-ta-lla-du-ra",
    "entretallamiento": "en-tre-ta-lla-mien-to",
    "entretallar": "en-tre-ta-llar",
    "entretanto": "en-tre-tan-to",
    "entretecho": "en-tre-te-cho",
    "entretejedor": "en-tre-te-je-dor",
    "entretejedora": "en-tre-te-je-do-ra",
    "entretejedura": "en-tre-te-je-du-ra",
    "entretejer": "en-tre-te-jer",
    "entretejimiento": "en-tre-te-ji-mien-to",
    "entretela": "en-tre-te-la",
    "entretelar": "en-tre-te-lar",
    "entretención": "en-tre-ten-ción",
    "entretenedor": "en-tre-te-ne-dor",
    "entretenedora": "en-tre-te-ne-do-ra",
    "entretener": "en-tre-te-ner",
    "entretenida": "en-tre-te-ni-da",
    "entretenido": "en-tre-te-ni-do",
    "entretenimiento": "en-tre-te-ni-mien-to",
    "entretiempo": "en-tre-tiem-po",
    "entretomar": "en-tre-to-mar",
    "entreuntar": "en-treun-tar",
    "entrevar": "en-tre-var",
    "entrevenar": "en-tre-ve-nar",
    "entrevenarse": "en-tre-ve-nar-se",
    "entrevenimiento": "en-tre-ve-ni-mien-to",
    "entrevenir": "en-tre-ve-nir",
    "entreventana": "en-tre-ven-ta-na",
    "entrever": "en-tre-ver",
    "entreverada": "en-tre-ve-ra-da",
    "entreverado": "en-tre-ve-ra-do",
    "entreverar": "en-tre-ve-rar",
    "entrevero": "en-tre-ve-ro",
    "entrevía": "en-tre-ví-a",
    "entrevigado": "en-tre-vi-ga-do",
    "entrevigar": "en-tre-vi-gar",
    "entrevista": "en-tre-vis-ta",
    "entrevistada": "en-tre-vis-ta-da",
    "entrevistado": "en-tre-vis-ta-do",
    "entrevistador": "en-tre-vis-ta-dor",
    "entrevistadora": "en-tre-vis-ta-do-ra",
    "entrevistar": "en-tre-vis-tar",
    "entrevisto": "en-tre-vis-to",
    "entrevolver": "en-tre-vol-ver",
    "entrevuelta": "en-tre-vuel-ta",
    "entreyacer": "en-tre-ya-cer",
    "entricadamente": "en-tri-ca-da-men-te",
    "entricar": "en-tri-car",
    "entriega": "en-trie-ga",
    "entrillar": "en-tri-llar",
    "entripada": "en-tri-pa-da",
    "entripado": "en-tri-pa-do",
    "entripar": "en-tri-par",
    "entristecedor": "en-tris-te-ce-dor",
    "entristecedora": "en-tris-te-ce-do-ra",
    "entristecer": "en-tris-te-cer",
    "entristecimiento": "en-tris-te-ci-mien-to",
    "entrizar": "en-tri-zar",
    "entro": "en-tro",
    "entrojar": "en-tro-jar",
    "entrometer": "en-tro-me-ter",
    "entrometida": "en-tro-me-ti-da",
    "entrometido": "en-tro-me-ti-do",
    "entrometimiento": "en-tro-me-ti-mien-to",
    "entrompar": "en-trom-par",
    "entrón": "en-trón",
    "entronar": "en-tro-nar",
    "entroncamiento": "en-tron-ca-mien-to",
    "entroncar": "en-tron-car",
    "entronecer": "en-tro-ne-cer",
    "entronerar": "en-tro-ne-rar",
    "entronización": "en-tro-ni-za-ción",
    "entronizar": "en-tro-ni-zar",
    "entronque": "en-tron-que",
    "entropezada": "en-tro-pe-za-da",
    "entropezado": "en-tro-pe-za-do",
    "entropezar": "en-tro-pe-zar",
    "entropía": "en-tro-pí-a",
    "entrópico": "en-tró-pi-co",
    "entropillar": "en-tro-pi-llar",
    "entropión": "en-tro-pión",
    "entruchada": "en-tru-cha-da",
    "entruchado": "en-tru-cha-do",
    "entruchar": "en-tru-char",
    "entruchón": "en-tru-chón",
    "entruchona": "en-tru-cho-na",
    "entruejo": "en-true-jo",
    "entrujar": "en-tru-jar",
    "entubación": "en-tu-ba-ción",
    "entubado": "en-tu-ba-do",
    "entubajar": "en-tu-ba-jar",
    "entubamiento": "en-tu-ba-mien-to",
    "entubar": "en-tu-bar",
    "entuchar": "en-tu-char",
    "entuerto": "en-tuer-to",
    "entufado": "en-tu-fa-do",
    "entullecer": "en-tu-lle-cer",
    "entumecer": "en-tu-me-cer",
    "entumecimiento": "en-tu-me-ci-mien-to",
    "entumido": "en-tu-mi-do",
    "entumir": "en-tu-mir",
    "entumirse": "en-tu-mir-se",
    "entuñar": "en-tu-ñar",
    "entuñarse": "en-tu-ñar-se",
    "entundar": "en-tun-dar",
    "entunicar": "en-tu-ni-car",
    "entupir": "en-tu-pir",
    "enturar": "en-tu-rar",
    "enturbiador": "en-tur-bia-dor",
    "enturbiamiento": "en-tur-bia-mien-to",
    "enturbiar": "en-tur-biar",
    "enturcado": "en-tur-ca-do",
    "entusiasmar": "en-tu-sias-mar",
    "entusiasmo": "en-tu-sias-mo",
    "entusiasta": "en-tu-sias-ta",
    "entusiástica": "en-tu-siás-ti-ca",
    "entusiástico": "en-tu-siás-ti-co",
    "entuturutar": "en-tu-tu-ru-tar",
    "enucleación": "e-nu-cle-a-ción",
    "enuclear": "e-nu-cle-ar",
    "énula": "é-nu-la",
    "enumeración": "e-nu-me-ra-ción",
    "enumerar": "e-nu-me-rar",
    "enumerativa": "e-nu-me-ra-ti-va",
    "enumerativo": "e-nu-me-ra-ti-vo",
    "enunciación": "e-nun-cia-ción",
    "enunciado": "e-nun-cia-do",
    "enunciador": "e-nun-cia-dor",
    "enunciadora": "e-nun-cia-do-ra",
    "enunciar": "e-nun-ciar",
    "enunciativa": "e-nun-cia-ti-va",
    "enunciativo": "e-nun-cia-ti-vo",
    "enuresis": "e-nu-re-sis",
    "enurético": "e-nu-ré-ti-co",
    "envacar": "en-va-car",
    "envaguecer": "en-va-gue-cer",
    "envainador": "en-vai-na-dor",
    "envainadora": "en-vai-na-do-ra",
    "envainar": "en-vai-nar",
    "envalentonamiento": "en-va-len-to-na-mien-to",
    "envalentonar": "en-va-len-to-nar",
    "envalijar": "en-va-li-jar",
    "envanecer": "en-va-ne-cer",
    "envanecimiento": "en-va-ne-ci-mien-to",
    "envarada": "en-va-ra-da",
    "envarado": "en-va-ra-do",
    "envaramiento": "en-va-ra-mien-to",
    "envarar": "en-va-rar",
    "envarbascar": "en-var-bas-car",
    "envarescer": "en-va-res-cer",
    "envaronar": "en-va-ro-nar",
    "envarracar": "en-va-rra-car",
    "envasado": "en-va-sa-do",
    "envasador": "en-va-sa-dor",
    "envasadora": "en-va-sa-do-ra",
    "envasar": "en-va-sar",
    "envase": "en-va-se",
    "envedijar": "en-ve-di-jar",
    "envedijarse": "en-ve-di-jar-se",
    "envegar": "en-ve-gar",
    "envegarse": "en-ve-gar-se",
    "envejecer": "en-ve-je-cer",
    "envejecida": "en-ve-je-ci-da",
    "envejecido": "en-ve-je-ci-do",
    "envejecimiento": "en-ve-je-ci-mien-to",
    "envelar": "en-ve-lar",
    "envenenada": "en-ve-ne-na-da",
    "envenenado": "en-ve-ne-na-do",
    "envenenador": "en-ve-ne-na-dor",
    "envenenadora": "en-ve-ne-na-do-ra",
    "envenenamiento": "en-ve-ne-na-mien-to",
    "envenenar": "en-ve-ne-nar",
    "enverar": "en-ve-rar",
    "enverdecer": "en-ver-de-cer",
    "enverdir": "en-ver-dir",
    "envergadura": "en-ver-ga-du-ra",
    "envergar": "en-ver-gar",
    "envergonzante": "en-ver-gon-zan-te",
    "envergonzar": "en-ver-gon-zar",
    "envergue": "en-ver-gue",
    "enverjado": "en-ver-ja-do",
    "envernar": "en-ver-nar",
    "envero": "en-ve-ro",
    "enversada": "en-ver-sa-da",
    "enversado": "en-ver-sa-do",
    "envés": "en-vés",
    "envesada": "en-ve-sa-da",
    "envesado": "en-ve-sa-do",
    "envesar": "en-ve-sar",
    "envestidura": "en-ves-ti-du-ra",
    "envestir": "en-ves-tir",
    "enviada": "en-via-da",
    "enviadiza": "en-via-di-za",
    "enviadizo": "en-via-di-zo",
    "enviado": "en-via-do",
    "enviajada": "en-via-ja-da",
    "enviajado": "en-via-ja-do",
    "enviar": "en-viar",
    "enviciamiento": "en-vi-cia-mien-to",
    "enviciar": "en-vi-ciar",
    "enviciosar": "en-vi-cio-sar",
    "enviciosarse": "en-vi-cio-sar-se",
    "envidada": "en-vi-da-da",
    "envidador": "en-vi-da-dor",
    "envidadora": "en-vi-da-do-ra",
    "envidar": "en-vi-dar",
    "envidia": "en-vi-dia",
    "envidiable": "en-vi-dia-ble",
    "envidiador": "en-vi-dia-dor",
    "envidiadora": "en-vi-dia-do-ra",
    "envidiar": "en-vi-diar",
    "envidiosa": "en-vi-dio-sa",
    "envidioso": "en-vi-dio-so",
    "envido": "en-vi-do",
    "enviejar": "en-vie-jar",
    "envigado": "en-vi-ga-do",
    "envigar": "en-vi-gar",
    "envilecedor": "en-vi-le-ce-dor",
    "envilecedora": "en-vi-le-ce-do-ra",
    "envilecer": "en-vi-le-cer",
    "envilecimiento": "en-vi-le-ci-mien-to",
    "envilortar": "en-vi-lor-tar",
    "envinado": "en-vi-na-do",
    "envinagrar": "en-vi-na-grar",
    "envinar": "en-vi-nar",
    "envío": "en-ví-o",
    "envión": "en-vión",
    "envirar": "en-vi-rar",
    "envirotada": "en-vi-ro-ta-da",
    "envirotado": "en-vi-ro-ta-do",
    "envisa": "en-vi-sa",
    "enviscamiento": "en-vis-ca-mien-to",
    "enviscar": "en-vis-car",
    "enviso": "en-vi-so",
    "envite": "en-vi-te",
    "enviudar": "en-viu-dar",
    "envolatar": "en-vo-la-tar",
    "envoltorio": "en-vol-to-rio",
    "envoltura": "en-vol-tu-ra",
    "envolvedero": "en-vol-ve-de-ro",
    "envolvedor": "en-vol-ve-dor",
    "envolvente": "en-vol-ven-te",
    "envolver": "en-vol-ver",
    "envolvimiento": "en-vol-vi-mien-to",
    "envuelta": "en-vuel-ta",
    "envueltas": "en-vuel-tas",
    "envuelto": "en-vuel-to",
    "enyerbado": "en-yer-ba-do",
    "enyerbar": "en-yer-bar",
    "enyertar": "en-yer-tar",
    "enyesado": "en-ye-sa-do",
    "enyesadura": "en-ye-sa-du-ra",
    "enyesar": "en-ye-sar",
    "enyescar": "en-yes-car",
    "enyescarse": "en-yes-car-se",
    "enyoyar": "en-yo-yar",
    "enyucar": "en-yu-car",
    "enyugamiento": "en-yu-ga-mien-to",
    "enyugar": "en-yu-gar",
    "enyuntar": "en-yun-tar",
    "enza": "en-za",
    "enzacatar": "en-za-ca-tar",
    "enzainar": "en-zai-nar",
    "enzainarse": "en-zai-nar-se",
    "enzalamar": "en-za-la-mar",
    "enzamarrada": "en-za-ma-rra-da",
    "enzamarrado": "en-za-ma-rra-do",
    "enzarzar": "en-zar-zar",
    "enzima": "en-zi-ma",
    "enzimático": "en-zi-má-ti-co",
    "enzimología": "en-zi-mo-lo-gí-a",
    "enzolvar": "en-zol-var",
    "enzonzado": "en-zon-za-do",
    "enzootia": "en-zo-o-tia",
    "enzoquetar": "en-zo-que-tar",
    "enzorrar": "en-zo-rrar",
    "enzunchar": "en-zun-char",
    "enzurdecer": "en-zur-de-cer",
    "enzurizar": "en-zu-ri-zar",
    "enzurronar": "en-zu-rro-nar",
    "enzurronarse": "en-zu-rro-nar-se",
    "eocénico": "e-o-cé-ni-co",
    "eoceno": "e-o-ce-no",
    "eolia": "e-o-lia",
    "eólica": "e-ó-li-ca",
    "eólico": "e-ó-li-co",
    "eolio": "e-o-lio",
    "eolito": "e-o-li-to",
    "eón": "e-ón",
    "eosina": "e-o-si-na",
    "epa": "e-pa",
    "epacina": "e-pa-ci-na",
    "epacta": "e-pac-ta",
    "epactilla": "e-pac-ti-lla",
    "épale": "é-pa-le",
    "epanadiplosis": "e-pa-na-di-plo-sis",
    "epanáfora": "e-pa-ná-fo-ra",
    "epanalepsis": "e-pa-na-lep-sis",
    "epanástrofe": "e-pa-nás-tro-fe",
    "epanortosis": "e-pa-nor-to-sis",
    "epasote": "e-pa-so-te",
    "epatante": "e-pa-tan-te",
    "epatar": "e-pa-tar",
    "epazote": "e-pa-zo-te",
    "epéndimo": "e-pén-di-mo",
    "epéntesis": "e-pén-te-sis",
    "epentética": "e-pen-té-ti-ca",
    "epentético": "e-pen-té-ti-co",
    "eperlán": "e-per-lán",
    "eperlano": "e-per-la-no",
    "epi": "e-pi",
    "épica": "é-pi-ca",
    "épicamente": "é-pi-ca-men-te",
    "epicanto": "e-pi-can-to",
    "epicardio": "e-pi-car-dio",
    "epicarpio": "e-pi-car-pio",
    "epicarpo": "e-pi-car-po",
    "epicedio": "e-pi-ce-dio",
    "epiceno": "e-pi-ce-no",
    "epicentro": "e-pi-cen-tro",
    "epiceyo": "e-pi-ce-yo",
    "epicíclica": "e-pi-cí-cli-ca",
    "epicíclico": "e-pi-cí-cli-co",
    "epiciclo": "e-pi-ci-clo",
    "epicicloide": "e-pi-ci-cloi-de",
    "épico": "é-pi-co",
    "epicúrea": "e-pi-cú-re-a",
    "epicureísmo": "e-pi-cu-re-ís-mo",
    "epicúreo": "e-pi-cú-re-o",
    "epidemia": "e-pi-de-mia",
    "epidemial": "e-pi-de-mial",
    "epidémica": "e-pi-dé-mi-ca",
    "epidemicidad": "e-pi-de-mi-ci-dad",
    "epidémico": "e-pi-dé-mi-co",
    "epidemióloga": "e-pi-de-mió-lo-ga",
    "epidemiología": "e-pi-de-mio-lo-gí-a",
    "epidemiológico": "e-pi-de-mio-ló-gi-co",
    "epidemiólogo": "e-pi-de-mió-lo-go",
    "epidérmica": "e-pi-dér-mi-ca",
    "epidérmico": "e-pi-dér-mi-co",
    "epidermis": "e-pi-der-mis",
    "epidiascopio": "e-pi-dias-co-pio",
    "epidiáscopo": "e-pi-diás-co-po",
    "epidídimo": "e-pi-dí-di-mo",
    "epidural": "e-pi-du-ral",
    "epifanía": "e-pi-fa-ní-a",
    "epifenómeno": "e-pi-fe-nó-me-no",
    "epífisis": "e-pí-fi-sis",
    "epifita": "e-pi-fi-ta",
    "epifito": "e-pi-fi-to",
    "epifonema": "e-pi-fo-ne-ma",
    "epífora": "e-pí-fo-ra",
    "epigástrica": "e-pi-gás-tri-ca",
    "epigástrico": "e-pi-gás-tri-co",
    "epigastrio": "e-pi-gas-trio",
    "epigénesis": "e-pi-gé-ne-sis",
    "epigenético": "e-pi-ge-né-ti-co",
    "epigeo": "e-pi-ge-o",
    "epiglosis": "e-pi-glo-sis",
    "epiglotis": "e-pi-glo-tis",
    "epígono": "e-pí-go-no",
    "epígrafe": "e-pí-gra-fe",
    "epigrafía": "e-pi-gra-fí-a",
    "epigrafiar": "e-pi-gra-fiar",
    "epigráfica": "e-pi-grá-fi-ca",
    "epigráfico": "e-pi-grá-fi-co",
    "epigrafista": "e-pi-gra-fis-ta",
    "epigrama": "e-pi-gra-ma",
    "epigramataria": "e-pi-gra-ma-ta-ria",
    "epigramatario": "e-pi-gra-ma-ta-rio",
    "epigramática": "e-pi-gra-má-ti-ca",
    "epigramáticamente": "e-pi-gra-má-ti-ca-men-te",
    "epigramático": "e-pi-gra-má-ti-co",
    "epigramatista": "e-pi-gra-ma-tis-ta",
    "epigramatizar": "e-pi-gra-ma-ti-zar",
    "epigramista": "e-pi-gra-mis-ta",
    "epilense": "e-pi-len-se",
    "epilepsia": "e-pi-lep-sia",
    "epiléptica": "e-pi-lép-ti-ca",
    "epiléptico": "e-pi-lép-ti-co",
    "epileptiforme": "e-pi-lep-ti-for-me",
    "epilogación": "e-pi-lo-ga-ción",
    "epilogal": "e-pi-lo-gal",
    "epilogar": "e-pi-lo-gar",
    "epilogismo": "e-pi-lo-gis-mo",
    "epílogo": "e-pí-lo-go",
    "epímone": "e-pí-mo-ne",
    "epinefrina": "e-pi-ne-fri-na",
    "epinicio": "e-pi-ni-cio",
    "epiparásito": "e-pi-pa-rá-si-to",
    "epiplón": "e-pi-plón",
    "epiquerema": "e-pi-que-re-ma",
    "epiqueya": "e-pi-que-ya",
    "epirogénesis": "e-pi-ro-gé-ne-sis",
    "epirota": "e-pi-ro-ta",
    "epirótica": "e-pi-ró-ti-ca",
    "epirótico": "e-pi-ró-ti-co",
    "episcopado": "e-pis-co-pa-do",
    "episcopal": "e-pis-co-pal",
    "episcopaliana": "e-pis-co-pa-lia-na",
    "episcopaliano": "e-pis-co-pa-lia-no",
    "episcopalismo": "e-pis-co-pa-lis-mo",
    "episcopio": "e-pis-co-pio",
    "episcopologio": "e-pis-co-po-lo-gio",
    "episiotomía": "e-pi-sio-to-mí-a",
    "episódica": "e-pi-só-di-ca",
    "episódicamente": "e-pi-só-di-ca-men-te",
    "episódico": "e-pi-só-di-co",
    "episodio": "e-pi-so-dio",
    "epispástica": "e-pis-pás-ti-ca",
    "epispástico": "e-pis-pás-ti-co",
    "epistaxis": "e-pis-ta-xis",
    "episteme": "e-pis-te-me",
    "epistémico": "e-pis-té-mi-co",
    "epistemología": "e-pis-te-mo-lo-gí-a",
    "epistemológico": "e-pis-te-mo-ló-gi-co",
    "epístola": "e-pís-to-la",
    "epistolar": "e-pis-to-lar",
    "epistolario": "e-pis-to-la-rio",
    "epistolero": "e-pis-to-le-ro",
    "epistólica": "e-pis-tó-li-ca",
    "epistólico": "e-pis-tó-li-co",
    "epistolio": "e-pis-to-lio",
    "epistológrafa": "e-pis-to-ló-gra-fa",
    "epistológrafo": "e-pis-to-ló-gra-fo",
    "epístrofe": "e-pís-tro-fe",
    "epitáfico": "e-pi-tá-fi-co",
    "epitafio": "e-pi-ta-fio",
    "epitalámica": "e-pi-ta-lá-mi-ca",
    "epitalámico": "e-pi-ta-lá-mi-co",
    "epitalamio": "e-pi-ta-la-mio",
    "epítasis": "e-pí-ta-sis",
    "epitelial": "e-pi-te-lial",
    "epitelio": "e-pi-te-lio",
    "epitelioma": "e-pi-te-lio-ma",
    "epítema": "e-pí-te-ma",
    "epíteto": "e-pí-te-to",
    "epítima": "e-pí-ti-ma",
    "epitimar": "e-pi-ti-mar",
    "epítimo": "e-pí-ti-mo",
    "epitomadamente": "e-pi-to-ma-da-men-te",
    "epitomador": "e-pi-to-ma-dor",
    "epitomadora": "e-pi-to-ma-do-ra",
    "epitomar": "e-pi-to-mar",
    "epítome": "e-pí-to-me",
    "epítrito": "e-pí-tri-to",
    "epítrope": "e-pí-tro-pe",
    "epizoario": "e-pi-zo-a-rio",
    "epizootia": "e-pi-zo-o-tia",
    "epizoótica": "e-pi-zo-ó-ti-ca",
    "epizoótico": "e-pi-zo-ó-ti-co",
    "epizootiología": "e-pi-zo-o-tio-lo-gí-a",
    "epo": "e-po",
    "época": "é-po-ca",
    "epoda": "e-po-da",
    "epodo": "e-po-do",
    "epónima": "e-pó-ni-ma",
    "epónimo": "e-pó-ni-mo",
    "epopeya": "e-po-pe-ya",
    "epota": "e-po-ta",
    "epoto": "e-po-to",
    "epoxi": "e-po-xi",
    "épsilon": "ép-si-lon",
    "epsomita": "ep-so-mi-ta",
    "epulón": "e-pu-lón",
    "equeco": "e-que-co",
    "equi": "e-qui",
    "equiángula": "e-quián-gu-la",
    "equiángulo": "e-quián-gu-lo",
    "equidad": "e-qui-dad",
    "equidiferencia": "e-qui-di-fe-ren-cia",
    "equidistancia": "e-qui-dis-tan-cia",
    "equidistante": "e-qui-dis-tan-te",
    "equidistar": "e-qui-dis-tar",
    "equidistribución": "e-qui-dis-tri-bu-ción",
    "equidna": "e-quid-na",
    "équido": "é-qui-do",
    "equilátera": "e-qui-lá-te-ra",
    "equilátero": "e-qui-lá-te-ro",
    "equilibrada": "e-qui-li-bra-da",
    "equilibrado": "e-qui-li-bra-do",
    "equilibrador": "e-qui-li-bra-dor",
    "equilibrar": "e-qui-li-brar",
    "equilibre": "e-qui-li-bre",
    "equilibrio": "e-qui-li-brio",
    "equilibrismo": "e-qui-li-bris-mo",
    "equilibrista": "e-qui-li-bris-ta",
    "equimosis": "e-qui-mo-sis",
    "equina": "e-qui-na",
    "equino": "e-qui-no",
    "equinoccial": "e-qui-noc-cial",
    "equinoccio": "e-qui-noc-cio",
    "equinococo": "e-qui-no-co-co",
    "equinococosis": "e-qui-no-co-co-sis",
    "equinodermo": "e-qui-no-der-mo",
    "equinoideo": "e-qui-noi-de-o",
    "equipación": "e-qui-pa-ción",
    "equipaje": "e-qui-pa-je",
    "equipal": "e-qui-pal",
    "equipamiento": "e-qui-pa-mien-to",
    "equipar": "e-qui-par",
    "equiparable": "e-qui-pa-ra-ble",
    "equiparación": "e-qui-pa-ra-ción",
    "equiparar": "e-qui-pa-rar",
    "equipera": "e-qui-pe-ra",
    "equipero": "e-qui-pe-ro",
    "equipo": "e-qui-po",
    "equipolado": "e-qui-po-la-do",
    "equipolencia": "e-qui-po-len-cia",
    "equipolente": "e-qui-po-len-te",
    "equiponderancia": "e-qui-pon-de-ran-cia",
    "equiponderar": "e-qui-pon-de-rar",
    "equipotencial": "e-qui-po-ten-cial",
    "equipotente": "e-qui-po-ten-te",
    "equis": "e-quis",
    "equisetácea": "e-qui-se-tá-ce-a",
    "equisetáceo": "e-qui-se-tá-ce-o",
    "equisetínea": "e-qui-se-tí-ne-a",
    "equisetíneo": "e-qui-se-tí-ne-o",
    "equiseto": "e-qui-se-to",
    "equisonancia": "e-qui-so-nan-cia",
    "equitación": "e-qui-ta-ción",
    "equitador": "e-qui-ta-dor",
    "equitadora": "e-qui-ta-do-ra",
    "equitativa": "e-qui-ta-ti-va",
    "equitativamente": "e-qui-ta-ti-va-men-te",
    "equitativo": "e-qui-ta-ti-vo",
    "équite": "é-qui-te",
    "equivalencia": "e-qui-va-len-cia",
    "equivalente": "e-qui-va-len-te",
    "equivalentemente": "e-qui-va-len-te-men-te",
    "equivaler": "e-qui-va-ler",
    "equívoca": "e-quí-vo-ca",
    "equivocación": "e-qui-vo-ca-ción",
    "equivocadamente": "e-qui-vo-ca-da-men-te",
    "equivocado": "e-qui-vo-ca-do",
    "equívocamente": "e-quí-vo-ca-men-te",
    "equivocar": "e-qui-vo-car",
    "equivocidad": "e-qui-vo-ci-dad",
    "equívoco": "e-quí-vo-co",
    "equivoquista": "e-qui-vo-quis-ta",
    "era": "e-ra",
    "eradicativa": "e-ra-di-ca-ti-va",
    "eradicativo": "e-ra-di-ca-ti-vo",
    "eraje": "e-ra-je",
    "eral": "e-ral",
    "erala": "e-ra-la",
    "erar": "e-rar",
    "eraria": "e-ra-ria",
    "erario": "e-ra-rio",
    "erasmiana": "e-ras-mia-na",
    "erasmiano": "e-ras-mia-no",
    "erasmismo": "e-ras-mis-mo",
    "erasmista": "e-ras-mis-ta",
    "erbio": "er-bio",
    "ercavicense": "er-ca-vi-cen-se",
    "ercer": "er-cer",
    "ere": "e-re",
    "erebo": "e-re-bo",
    "erección": "e-rec-ción",
    "erecha": "e-re-cha",
    "erecta": "e-rec-ta",
    "eréctil": "e-réc-til",
    "erectilidad": "e-rec-ti-li-dad",
    "erecto": "e-rec-to",
    "erector": "e-rec-tor",
    "erectora": "e-rec-to-ra",
    "eremita": "e-re-mi-ta",
    "eremítica": "e-re-mí-ti-ca",
    "eremítico": "e-re-mí-ti-co",
    "eremitorio": "e-re-mi-to-rio",
    "eretismo": "e-re-tis-mo",
    "erétrica": "e-ré-tri-ca",
    "erétrico": "e-ré-tri-co",
    "ergástula": "er-gás-tu-la",
    "ergástulo": "er-gás-tu-lo",
    "ergio": "er-gio",
    "ergo": "er-go",
    "ergógrafo": "er-gó-gra-fo",
    "ergometría": "er-go-me-trí-a",
    "ergónoma": "er-gó-no-ma",
    "ergonomía": "er-go-no-mí-a",
    "ergonómico": "er-go-nó-mi-co",
    "ergonomista": "er-go-no-mis-ta",
    "ergónomo": "er-gó-no-mo",
    "ergoterapia": "er-go-te-ra-pia",
    "ergotina": "er-go-ti-na",
    "ergotismo": "er-go-tis-mo",
    "ergotista": "er-go-tis-ta",
    "ergotizar": "er-go-ti-zar",
    "erguén": "er-guén",
    "erguimiento": "er-gui-mien-to",
    "erguir": "er-guir",
    "ería": "e-rí-a",
    "erial": "e-rial",
    "eriaza": "e-ria-za",
    "eriazo": "e-ria-zo",
    "ericácea": "e-ri-cá-ce-a",
    "ericáceas": "e-ri-cá-ce-as",
    "ericáceo": "e-ri-cá-ce-o",
    "erigir": "e-ri-gir",
    "erina": "e-ri-na",
    "eringe": "e-rin-ge",
    "erío": "e-rí-o",
    "eriotecnia": "e-rio-tec-nia",
    "erisipela": "e-ri-si-pe-la",
    "erisipelar": "e-ri-si-pe-lar",
    "erisipelatosa": "e-ri-si-pe-la-to-sa",
    "erisipelatoso": "e-ri-si-pe-la-to-so",
    "erística": "e-rís-ti-ca",
    "erístico": "e-rís-ti-co",
    "eritema": "e-ri-te-ma",
    "eritematoso": "e-ri-te-ma-to-so",
    "eritrea": "e-ri-tre-a",
    "eritreo": "e-ri-tre-o",
    "eritroblastosis": "e-ri-tro-blas-to-sis",
    "eritrocito": "e-ri-tro-ci-to",
    "eritropoyesis": "e-ri-tro-po-ye-sis",
    "eritropoyetina": "e-ri-tro-po-ye-ti-na",
    "eritroxilácea": "e-ri-tro-xi-lá-ce-a",
    "eritroxiláceo": "e-ri-tro-xi-lá-ce-o",
    "eritroxílea": "e-ri-tro-xí-le-a",
    "eritroxíleo": "e-ri-tro-xí-le-o",
    "erizada": "e-ri-za-da",
    "erizado": "e-ri-za-do",
    "erizamiento": "e-ri-za-mien-to",
    "erizar": "e-ri-zar",
    "erizo": "e-ri-zo",
    "erizón": "e-ri-zón",
    "erke": "er-ke",
    "erkencho": "er-ken-cho",
    "ermador": "er-ma-dor",
    "ermadora": "er-ma-do-ra",
    "ermadura": "er-ma-du-ra",
    "ermamiento": "er-ma-mien-to",
    "ermar": "er-mar",
    "ermita": "er-mi-ta",
    "ermitaña": "er-mi-ta-ña",
    "ermitaño": "er-mi-ta-ño",
    "ermitorio": "er-mi-to-rio",
    "ermunio": "er-mu-nio",
    "ero": "e-ro",
    "erogación": "e-ro-ga-ción",
    "erogar": "e-ro-gar",
    "erogatorio": "e-ro-ga-to-rio",
    "erógeno": "e-ró-ge-no",
    "eros": "e-ros",
    "erosión": "e-ro-sión",
    "erosionable": "e-ro-sio-na-ble",
    "erosionar": "e-ro-sio-nar",
    "erosiva": "e-ro-si-va",
    "erosivo": "e-ro-si-vo",
    "erostratismo": "e-ros-tra-tis-mo",
    "erotema": "e-ro-te-ma",
    "erótica": "e-ró-ti-ca",
    "erótico": "e-ró-ti-co",
    "erotismo": "e-ro-tis-mo",
    "erotización": "e-ro-ti-za-ción",
    "erotizado": "e-ro-ti-za-do",
    "erotizante": "e-ro-ti-zan-te",
    "erotizar": "e-ro-ti-zar",
    "erotógeno": "e-ro-tó-ge-no",
    "erotómana": "e-ro-tó-ma-na",
    "erotomanía": "e-ro-to-ma-ní-a",
    "erotómano": "e-ro-tó-ma-no",
    "erque": "er-que",
    "erquencho": "er-quen-cho",
    "errabunda": "e-rra-bun-da",
    "errabundo": "e-rra-bun-do",
    "errada": "e-rra-da",
    "erradamente": "e-rra-da-men-te",
    "erradicación": "e-rra-di-ca-ción",
    "erradicar": "e-rra-di-car",
    "erradiza": "e-rra-di-za",
    "erradizo": "e-rra-di-zo",
    "errado": "e-rra-do",
    "erraj": "e-rraj",
    "errante": "e-rran-te",
    "errar": "e-rrar",
    "errata": "e-rra-ta",
    "errática": "e-rrá-ti-ca",
    "errático": "e-rrá-ti-co",
    "errátil": "e-rrá-til",
    "erre": "e-rre",
    "erreal": "e-rre-al",
    "erro": "e-rro",
    "errona": "e-rro-na",
    "errónea": "e-rró-ne-a",
    "erróneamente": "e-rró-ne-a-men-te",
    "erróneo": "e-rró-ne-o",
    "error": "e-rror",
    "ertzaina": "ert-zai-na",
    "erubescencia": "e-ru-bes-cen-cia",
    "erubescente": "e-ru-bes-cen-te",
    "eructación": "e-ruc-ta-ción",
    "eructar": "e-ruc-tar",
    "eructo": "e-ruc-to",
    "erudición": "e-ru-di-ción",
    "erudita": "e-ru-di-ta",
    "eruditamente": "e-ru-di-ta-men-te",
    "erudito": "e-ru-di-to",
    "eruginosa": "e-ru-gi-no-sa",
    "eruginoso": "e-ru-gi-no-so",
    "erumnosa": "e-rum-no-sa",
    "erumnoso": "e-rum-no-so",
    "erupción": "e-rup-ción",
    "erupcionar": "e-rup-cio-nar",
    "eruptiva": "e-rup-ti-va",
    "eruptivo": "e-rup-ti-vo",
    "erutación": "e-ru-ta-ción",
    "erutar": "e-ru-tar",
    "eruto": "e-ru-to",
    "ervato": "er-va-to",
    "ervilla": "er-vi-lla",
    "esa": "e-sa",
    "esbajeradora": "es-ba-je-ra-do-ra",
    "esbajerar": "es-ba-je-rar",
    "esbarar": "es-ba-rar",
    "esbardo": "es-bar-do",
    "esbarizar": "es-ba-ri-zar",
    "ésbate": "és-ba-te",
    "esbatimentar": "es-ba-ti-men-tar",
    "esbatimento": "es-ba-ti-men-to",
    "esbelta": "es-bel-ta",
    "esbeltez": "es-bel-tez",
    "esbelteza": "es-bel-te-za",
    "esbelto": "es-bel-to",
    "esbirro": "es-bi-rro",
    "esblandecer": "es-blan-de-cer",
    "esblencar": "es-blen-car",
    "esborregar": "es-bo-rre-gar",
    "esbozar": "es-bo-zar",
    "esbozo": "es-bo-zo",
    "esbrencar": "es-bren-car",
    "esbronce": "es-bron-ce",
    "esca": "es-ca",
    "escabechada": "es-ca-be-cha-da",
    "escabechado": "es-ca-be-cha-do",
    "escabechar": "es-ca-be-char",
    "escabeche": "es-ca-be-che",
    "escabechina": "es-ca-be-chi-na",
    "escabel": "es-ca-bel",
    "escabelo": "es-ca-be-lo",
    "escabinado": "es-ca-bi-na-do",
    "escabino": "es-ca-bi-no",
    "escabio": "es-ca-bio",
    "escabiosa": "es-ca-bio-sa",
    "escabioso": "es-ca-bio-so",
    "escabro": "es-ca-bro",
    "escabrosa": "es-ca-bro-sa",
    "escabrosamente": "es-ca-bro-sa-men-te",
    "escabrosear": "es-ca-bro-se-ar",
    "escabrosearse": "es-ca-bro-se-ar-se",
    "escabrosidad": "es-ca-bro-si-dad",
    "escabroso": "es-ca-bro-so",
    "escabuchar": "es-ca-bu-char",
    "escabuche": "es-ca-bu-che",
    "escabullar": "es-ca-bu-llar",
    "escabullimiento": "es-ca-bu-lli-mien-to",
    "escabullir": "es-ca-bu-llir",
    "escacada": "es-ca-ca-da",
    "escacado": "es-ca-ca-do",
    "escachar": "es-ca-char",
    "escacharrar": "es-ca-cha-rrar",
    "escachifollar": "es-ca-chi-fo-llar",
    "escaecer": "es-ca-e-cer",
    "escaencia": "es-ca-en-cia",
    "escafandra": "es-ca-fan-dra",
    "escafandrista": "es-ca-fan-dris-ta",
    "escafandro": "es-ca-fan-dro",
    "escafilar": "es-ca-fi-lar",
    "escafoides": "es-ca-foi-des",
    "escafópodo": "es-ca-fó-po-do",
    "escagarruciar": "es-ca-ga-rru-ciar",
    "escagarruzar": "es-ca-ga-rru-zar",
    "escajo": "es-ca-jo",
    "escajocote": "es-ca-jo-co-te",
    "escala": "es-ca-la",
    "escalable": "es-ca-la-ble",
    "escalaborne": "es-ca-la-bor-ne",
    "escalabrar": "es-ca-la-brar",
    "escalada": "es-ca-la-da",
    "escalado": "es-ca-la-do",
    "escalador": "es-ca-la-dor",
    "escaladora": "es-ca-la-do-ra",
    "escalafón": "es-ca-la-fón",
    "escalamiento": "es-ca-la-mien-to",
    "escálamo": "es-cá-la-mo",
    "escalar": "es-ca-lar",
    "escaldada": "es-cal-da-da",
    "escaldado": "es-cal-da-do",
    "escaldadura": "es-cal-da-du-ra",
    "escaldar": "es-cal-dar",
    "escaldo": "es-cal-do",
    "escaldrida": "es-cal-dri-da",
    "escaldrido": "es-cal-dri-do",
    "escaldufar": "es-cal-du-far",
    "escalecer": "es-ca-le-cer",
    "escaleno": "es-ca-le-no",
    "escalentador": "es-ca-len-ta-dor",
    "escalentamiento": "es-ca-len-ta-mien-to",
    "escalentar": "es-ca-len-tar",
    "escalera": "es-ca-le-ra",
    "escalerilla": "es-ca-le-ri-lla",
    "escalerón": "es-ca-le-rón",
    "escaleta": "es-ca-le-ta",
    "escalfada": "es-cal-fa-da",
    "escalfado": "es-cal-fa-do",
    "escalfador": "es-cal-fa-dor",
    "escalfamiento": "es-cal-fa-mien-to",
    "escalfar": "es-cal-far",
    "escalfarote": "es-cal-fa-ro-te",
    "escalfecer": "es-cal-fe-cer",
    "escalfecerse": "es-cal-fe-cer-se",
    "escalfeta": "es-cal-fe-ta",
    "escaliar": "es-ca-liar",
    "escalinata": "es-ca-li-na-ta",
    "escalio": "es-ca-lio",
    "escalivada": "es-ca-li-va-da",
    "escalivar": "es-ca-li-var",
    "escalla": "es-ca-lla",
    "escalmo": "es-cal-mo",
    "escalo": "es-ca-lo",
    "escalofriada": "es-ca-lo-fria-da",
    "escalofriado": "es-ca-lo-fria-do",
    "escalofriante": "es-ca-lo-frian-te",
    "escalofriar": "es-ca-lo-friar",
    "escalofrío": "es-ca-lo-frí-o",
    "escalón": "es-ca-lón",
    "escalona": "es-ca-lo-na",
    "escaloña": "es-ca-lo-ña",
    "escalonado": "es-ca-lo-na-do",
    "escalonamiento": "es-ca-lo-na-mien-to",
    "escalonar": "es-ca-lo-nar",
    "escalonia": "es-ca-lo-nia",
    "escalope": "es-ca-lo-pe",
    "escalpelo": "es-cal-pe-lo",
    "escalplo": "es-cal-plo",
    "escama": "es-ca-ma",
    "escamada": "es-ca-ma-da",
    "escamado": "es-ca-ma-do",
    "escamadura": "es-ca-ma-du-ra",
    "escamante": "es-ca-man-te",
    "escamar": "es-ca-mar",
    "escambrón": "es-cam-brón",
    "escambronal": "es-cam-bro-nal",
    "escamel": "es-ca-mel",
    "escamiforme": "es-ca-mi-for-me",
    "escamocha": "es-ca-mo-cha",
    "escamochar": "es-ca-mo-char",
    "escamoche": "es-ca-mo-che",
    "escamochear": "es-ca-mo-che-ar",
    "escamocho": "es-ca-mo-cho",
    "escamol": "es-ca-mol",
    "escamole": "es-ca-mo-le",
    "escamón": "es-ca-món",
    "escamona": "es-ca-mo-na",
    "escamonda": "es-ca-mon-da",
    "escamondadura": "es-ca-mon-da-du-ra",
    "escamondar": "es-ca-mon-dar",
    "escamondo": "es-ca-mon-do",
    "escamonea": "es-ca-mo-ne-a",
    "escamoneada": "es-ca-mo-ne-a-da",
    "escamoneado": "es-ca-mo-ne-a-do",
    "escamonear": "es-ca-mo-ne-ar",
    "escamonearse": "es-ca-mo-ne-ar-se",
    "escamosa": "es-ca-mo-sa",
    "escamoso": "es-ca-mo-so",
    "escamotar": "es-ca-mo-tar",
    "escamoteador": "es-ca-mo-te-a-dor",
    "escamoteadora": "es-ca-mo-te-a-do-ra",
    "escamotear": "es-ca-mo-te-ar",
    "escamoteo": "es-ca-mo-te-o",
    "escampada": "es-cam-pa-da",
    "escampado": "es-cam-pa-do",
    "escampamento": "es-cam-pa-men-to",
    "escampar": "es-cam-par",
    "escampavía": "es-cam-pa-ví-a",
    "escampilla": "es-cam-pi-lla",
    "escampo": "es-cam-po",
    "escamuda": "es-ca-mu-da",
    "escamudo": "es-ca-mu-do",
    "escamujar": "es-ca-mu-jar",
    "escamujo": "es-ca-mu-jo",
    "escaña": "es-ca-ña",
    "escañar": "es-ca-ñar",
    "escañarse": "es-ca-ñar-se",
    "escancia": "es-can-cia",
    "escanciador": "es-can-cia-dor",
    "escanciadora": "es-can-cia-do-ra",
    "escanciano": "es-can-cia-no",
    "escanciar": "es-can-ciar",
    "escanda": "es-can-da",
    "escandalar": "es-can-da-lar",
    "escandalera": "es-can-da-le-ra",
    "escandalizador": "es-can-da-li-za-dor",
    "escandalizadora": "es-can-da-li-za-do-ra",
    "escandalizar": "es-can-da-li-zar",
    "escandalizativa": "es-can-da-li-za-ti-va",
    "escandalizativo": "es-can-da-li-za-ti-vo",
    "escandallar": "es-can-da-llar",
    "escandallo": "es-can-da-llo",
    "escándalo": "es-cán-da-lo",
    "escandalosa": "es-can-da-lo-sa",
    "escandalosamente": "es-can-da-lo-sa-men-te",
    "escandaloso": "es-can-da-lo-so",
    "escandelar": "es-can-de-lar",
    "escandia": "es-can-dia",
    "escandinava": "es-can-di-na-va",
    "escandinavo": "es-can-di-na-vo",
    "escandio": "es-can-dio",
    "escandir": "es-can-dir",
    "escanear": "es-ca-ne-ar",
    "escáner": "es-cá-ner",
    "escañero": "es-ca-ñe-ro",
    "escañeto": "es-ca-ñe-to",
    "escañil": "es-ca-ñil",
    "escanilla": "es-ca-ni-lla",
    "escaño": "es-ca-ño",
    "escanógrafo": "es-ca-nó-gra-fo",
    "escanograma": "es-ca-no-gra-ma",
    "escansión": "es-can-sión",
    "escantador": "es-can-ta-dor",
    "escantadora": "es-can-ta-do-ra",
    "escantar": "es-can-tar",
    "escantillar": "es-can-ti-llar",
    "escantillón": "es-can-ti-llón",
    "escañuelo": "es-ca-ñue-lo",
    "escapada": "es-ca-pa-da",
    "escapado": "es-ca-pa-do",
    "escapamiento": "es-ca-pa-mien-to",
    "escapar": "es-ca-par",
    "escaparate": "es-ca-pa-ra-te",
    "escaparatismo": "es-ca-pa-ra-tis-mo",
    "escaparatista": "es-ca-pa-ra-tis-ta",
    "escapatoria": "es-ca-pa-to-ria",
    "escape": "es-ca-pe",
    "escapera": "es-ca-pe-ra",
    "escapero": "es-ca-pe-ro",
    "escapismo": "es-ca-pis-mo",
    "escapista": "es-ca-pis-ta",
    "escapo": "es-ca-po",
    "escápula": "es-cá-pu-la",
    "escapular": "es-ca-pu-lar",
    "escapulario": "es-ca-pu-la-rio",
    "escaque": "es-ca-que",
    "escaqueada": "es-ca-que-a-da",
    "escaqueado": "es-ca-que-a-do",
    "escaquear": "es-ca-que-ar",
    "escaqueo": "es-ca-que-o",
    "escara": "es-ca-ra",
    "escarabaja": "es-ca-ra-ba-ja",
    "escarabajear": "es-ca-ra-ba-je-ar",
    "escarabajeo": "es-ca-ra-ba-je-o",
    "escarabajo": "es-ca-ra-ba-jo",
    "escarabajuelo": "es-ca-ra-ba-jue-lo",
    "escarabeo": "es-ca-ra-be-o",
    "escaramucear": "es-ca-ra-mu-ce-ar",
    "escaramujo": "es-ca-ra-mu-jo",
    "escaramuza": "es-ca-ra-mu-za",
    "escaramuzador": "es-ca-ra-mu-za-dor",
    "escaramuzadora": "es-ca-ra-mu-za-do-ra",
    "escaramuzar": "es-ca-ra-mu-zar",
    "escarapela": "es-ca-ra-pe-la",
    "escarapelar": "es-ca-ra-pe-lar",
    "escarapulla": "es-ca-ra-pu-lla",
    "escarar": "es-ca-rar",
    "escarbadero": "es-car-ba-de-ro",
    "escarbadientes": "es-car-ba-dien-tes",
    "escarbador": "es-car-ba-dor",
    "escarbadora": "es-car-ba-do-ra",
    "escarbadura": "es-car-ba-du-ra",
    "escarbaorejas": "es-car-ba-o-re-jas",
    "escarbar": "es-car-bar",
    "escarbatear": "es-car-ba-te-ar",
    "escarbillos": "es-car-bi-llos",
    "escarbo": "es-car-bo",
    "escarcear": "es-car-ce-ar",
    "escarcela": "es-car-ce-la",
    "escarceo": "es-car-ce-o",
    "escarcha": "es-car-cha",
    "escarchada": "es-car-cha-da",
    "escarchado": "es-car-cha-do",
    "escarchar": "es-car-char",
    "escarche": "es-car-che",
    "escarcho": "es-car-cho",
    "escarcina": "es-car-ci-na",
    "escarcinazo": "es-car-ci-na-zo",
    "escarcuñar": "es-car-cu-ñar",
    "escarda": "es-car-da",
    "escardadera": "es-car-da-de-ra",
    "escardador": "es-car-da-dor",
    "escardadora": "es-car-da-do-ra",
    "escardadura": "es-car-da-du-ra",
    "escardar": "es-car-dar",
    "escardilla": "es-car-di-lla",
    "escardillar": "es-car-di-llar",
    "escardillo": "es-car-di-llo",
    "escarear": "es-ca-re-ar",
    "escarearse": "es-ca-re-ar-se",
    "escariador": "es-ca-ria-dor",
    "escariar": "es-ca-riar",
    "escarificación": "es-ca-ri-fi-ca-ción",
    "escarificada": "es-ca-ri-fi-ca-da",
    "escarificado": "es-ca-ri-fi-ca-do",
    "escarificador": "es-ca-ri-fi-ca-dor",
    "escarificar": "es-ca-ri-fi-car",
    "escariosa": "es-ca-rio-sa",
    "escarioso": "es-ca-rio-so",
    "escarizar": "es-ca-ri-zar",
    "escarlador": "es-car-la-dor",
    "escarlata": "es-car-la-ta",
    "escarlatín": "es-car-la-tín",
    "escarlatina": "es-car-la-ti-na",
    "escarlatinoso": "es-car-la-ti-no-so",
    "escarmenador": "es-car-me-na-dor",
    "escarmenar": "es-car-me-nar",
    "escarmentada": "es-car-men-ta-da",
    "escarmentado": "es-car-men-ta-do",
    "escarmentar": "es-car-men-tar",
    "escarmiento": "es-car-mien-to",
    "escarnar": "es-car-nar",
    "escarnecedor": "es-car-ne-ce-dor",
    "escarnecedora": "es-car-ne-ce-do-ra",
    "escarnecer": "es-car-ne-cer",
    "escarnecidamente": "es-car-ne-ci-da-men-te",
    "escarnecimiento": "es-car-ne-ci-mien-to",
    "escarnidor": "es-car-ni-dor",
    "escarnidora": "es-car-ni-do-ra",
    "escarnio": "es-car-nio",
    "escaro": "es-ca-ro",
    "escarola": "es-ca-ro-la",
    "escarolada": "es-ca-ro-la-da",
    "escarolado": "es-ca-ro-la-do",
    "escarolar": "es-ca-ro-lar",
    "escarótica": "es-ca-ró-ti-ca",
    "escarótico": "es-ca-ró-ti-co",
    "escarpa": "es-car-pa",
    "escarpada": "es-car-pa-da",
    "escarpado": "es-car-pa-do",
    "escarpadura": "es-car-pa-du-ra",
    "escarpar": "es-car-par",
    "escarpe": "es-car-pe",
    "escarpelo": "es-car-pe-lo",
    "escarpia": "es-car-pia",
    "escarpiador": "es-car-pia-dor",
    "escarpiar": "es-car-piar",
    "escarpidor": "es-car-pi-dor",
    "escarpín": "es-car-pín",
    "escarpión": "es-car-pión",
    "escarramán": "es-ca-rra-mán",
    "escarramanada": "es-ca-rra-ma-na-da",
    "escarramanado": "es-ca-rra-ma-na-do",
    "escarramanchones": "es-ca-rra-man-cho-nes",
    "escarranchar": "es-ca-rran-char",
    "escarrancharse": "es-ca-rran-char-se",
    "escarrio": "es-ca-rrio",
    "escartivana": "es-car-ti-va-na",
    "escarza": "es-car-za",
    "escarzador": "es-car-za-dor",
    "escarzano": "es-car-za-no",
    "escarzar": "es-car-zar",
    "escarzo": "es-car-zo",
    "escás": "es-cás",
    "escasa": "es-ca-sa",
    "escasamente": "es-ca-sa-men-te",
    "escasear": "es-ca-se-ar",
    "escasera": "es-ca-se-ra",
    "escasero": "es-ca-se-ro",
    "escasez": "es-ca-sez",
    "escaseza": "es-ca-se-za",
    "escaso": "es-ca-so",
    "escatima": "es-ca-ti-ma",
    "escatimar": "es-ca-ti-mar",
    "escatimosa": "es-ca-ti-mo-sa",
    "escatimosamente": "es-ca-ti-mo-sa-men-te",
    "escatimoso": "es-ca-ti-mo-so",
    "escatófaga": "es-ca-tó-fa-ga",
    "escatofagia": "es-ca-to-fa-gia",
    "escatófago": "es-ca-tó-fa-go",
    "escatófilo": "es-ca-tó-fi-lo",
    "escatología": "es-ca-to-lo-gí-a",
    "escatológica": "es-ca-to-ló-gi-ca",
    "escatológico": "es-ca-to-ló-gi-co",
    "escaupil": "es-cau-pil",
    "escavador": "es-ca-va-dor",
    "escavanar": "es-ca-va-nar",
    "escavar": "es-ca-var",
    "escavillar": "es-ca-vi-llar",
    "escavillo": "es-ca-vi-llo",
    "escay": "es-cay",
    "escayola": "es-ca-yo-la",
    "escayolar": "es-ca-yo-lar",
    "escayolista": "es-ca-yo-lis-ta",
    "escelerada": "es-ce-le-ra-da",
    "escelerado": "es-ce-le-ra-do",
    "escena": "es-ce-na",
    "escenario": "es-ce-na-rio",
    "escénica": "es-cé-ni-ca",
    "escénico": "es-cé-ni-co",
    "escenificable": "es-ce-ni-fi-ca-ble",
    "escenificación": "es-ce-ni-fi-ca-ción",
    "escenificar": "es-ce-ni-fi-car",
    "escenógrafa": "es-ce-nó-gra-fa",
    "escenografía": "es-ce-no-gra-fí-a",
    "escenográfica": "es-ce-no-grá-fi-ca",
    "escenográficamente": "es-ce-no-grá-fi-ca-men-te",
    "escenográfico": "es-ce-no-grá-fi-co",
    "escenógrafo": "es-ce-nó-gra-fo",
    "escéptica": "es-cép-ti-ca",
    "escepticismo": "es-cep-ti-cis-mo",
    "escéptico": "es-cép-ti-co",
    "escibar": "es-ci-bar",
    "escible": "es-ci-ble",
    "esciencia": "es-cien-cia",
    "esciente": "es-cien-te",
    "escientemente": "es-cien-te-men-te",
    "escifozoo": "es-ci-fo-zo-o",
    "escila": "es-ci-la",
    "escíncido": "es-cín-ci-do",
    "escinco": "es-cin-co",
    "escindible": "es-cin-di-ble",
    "escindir": "es-cin-dir",
    "escintilación": "es-cin-ti-la-ción",
    "escintilador": "es-cin-ti-la-dor",
    "escintilar": "es-cin-ti-lar",
    "escintilómetro": "es-cin-ti-ló-me-tro",
    "escirro": "es-ci-rro",
    "escirrosa": "es-ci-rro-sa",
    "escirroso": "es-ci-rro-so",
    "escisión": "es-ci-sión",
    "escita": "es-ci-ta",
    "escítica": "es-cí-ti-ca",
    "escítico": "es-cí-ti-co",
    "esclafar": "es-cla-far",
    "esclarea": "es-cla-re-a",
    "esclarecedor": "es-cla-re-ce-dor",
    "esclarecedora": "es-cla-re-ce-do-ra",
    "esclarecer": "es-cla-re-cer",
    "esclarecida": "es-cla-re-ci-da",
    "esclarecidamente": "es-cla-re-ci-da-men-te",
    "esclarecido": "es-cla-re-ci-do",
    "esclarecimiento": "es-cla-re-ci-mien-to",
    "esclava": "es-cla-va",
    "esclavina": "es-cla-vi-na",
    "esclavista": "es-cla-vis-ta",
    "esclavitud": "es-cla-vi-tud",
    "esclavización": "es-cla-vi-za-ción",
    "esclavizar": "es-cla-vi-zar",
    "esclavo": "es-cla-vo",
    "esclavón": "es-cla-vón",
    "esclavona": "es-cla-vo-na",
    "esclavonía": "es-cla-vo-ní-a",
    "esclavonio": "es-cla-vo-nio",
    "esclerénquima": "es-cle-rén-qui-ma",
    "esclerodermia": "es-cle-ro-der-mia",
    "esclerófilo": "es-cle-ró-fi-lo",
    "esclerómetro": "es-cle-ró-me-tro",
    "escleroproteína": "es-cle-ro-pro-te-í-na",
    "esclerosa": "es-cle-ro-sa",
    "esclerosado": "es-cle-ro-sa-do",
    "esclerosar": "es-cle-ro-sar",
    "esclerósica": "es-cle-ró-si-ca",
    "esclerósico": "es-cle-ró-si-co",
    "esclerosis": "es-cle-ro-sis",
    "escleroso": "es-cle-ro-so",
    "esclerótica": "es-cle-ró-ti-ca",
    "esclerótico": "es-cle-ró-ti-co",
    "esclerotización": "es-cle-ro-ti-za-ción",
    "esclerotizar": "es-cle-ro-ti-zar",
    "esclisiada": "es-cli-sia-da",
    "esclisiado": "es-cli-sia-do",
    "esclusa": "es-clu-sa",
    "escoa": "es-co-a",
    "escoba": "es-co-ba",
    "escobada": "es-co-ba-da",
    "escobadera": "es-co-ba-de-ra",
    "escobado": "es-co-ba-do",
    "escobajo": "es-co-ba-jo",
    "escobar": "es-co-bar",
    "escobazar": "es-co-ba-zar",
    "escobazo": "es-co-ba-zo",
    "escobén": "es-co-bén",
    "escobera": "es-co-be-ra",
    "escobero": "es-co-be-ro",
    "escobeta": "es-co-be-ta",
    "escobetear": "es-co-be-te-ar",
    "escobilla": "es-co-bi-lla",
    "escobillado": "es-co-bi-lla-do",
    "escobillar": "es-co-bi-llar",
    "escobilleo": "es-co-bi-lle-o",
    "escobillón": "es-co-bi-llón",
    "escobina": "es-co-bi-na",
    "escobino": "es-co-bi-no",
    "escobio": "es-co-bio",
    "escobizo": "es-co-bi-zo",
    "escobo": "es-co-bo",
    "escobón": "es-co-bón",
    "escocar": "es-co-car",
    "escocedura": "es-co-ce-du-ra",
    "escocer": "es-co-cer",
    "escocés": "es-co-cés",
    "escocesa": "es-co-ce-sa",
    "escocherar": "es-co-che-rar",
    "escocia": "es-co-cia",
    "escociana": "es-co-cia-na",
    "escociano": "es-co-cia-no",
    "escocimiento": "es-co-ci-mien-to",
    "escoda": "es-co-da",
    "escodadero": "es-co-da-de-ro",
    "escodar": "es-co-dar",
    "escofia": "es-co-fia",
    "escofiar": "es-co-fiar",
    "escofieta": "es-co-fie-ta",
    "escofina": "es-co-fi-na",
    "escofinar": "es-co-fi-nar",
    "escofión": "es-co-fión",
    "escogedor": "es-co-ge-dor",
    "escogedora": "es-co-ge-do-ra",
    "escogencia": "es-co-gen-cia",
    "escoger": "es-co-ger",
    "escogida": "es-co-gi-da",
    "escogidamente": "es-co-gi-da-men-te",
    "escogido": "es-co-gi-do",
    "escogimiento": "es-co-gi-mien-to",
    "escolán": "es-co-lán",
    "escolanía": "es-co-la-ní-a",
    "escolano": "es-co-la-no",
    "escolapia": "es-co-la-pia",
    "escolapio": "es-co-la-pio",
    "escolar": "es-co-lar",
    "escolarca": "es-co-lar-ca",
    "escolaridad": "es-co-la-ri-dad",
    "escolariega": "es-co-la-rie-ga",
    "escolariego": "es-co-la-rie-go",
    "escolarina": "es-co-la-ri-na",
    "escolarino": "es-co-la-ri-no",
    "escolarización": "es-co-la-ri-za-ción",
    "escolarizar": "es-co-la-ri-zar",
    "escolástica": "es-co-lás-ti-ca",
    "escolásticamente": "es-co-lás-ti-ca-men-te",
    "escolasticismo": "es-co-las-ti-cis-mo",
    "escolástico": "es-co-lás-ti-co",
    "escoldo": "es-col-do",
    "escoleta": "es-co-le-ta",
    "escólex": "es-có-lex",
    "escoliador": "es-co-lia-dor",
    "escoliadora": "es-co-lia-do-ra",
    "escoliar": "es-co-liar",
    "escoliasta": "es-co-lias-ta",
    "escolimada": "es-co-li-ma-da",
    "escolimado": "es-co-li-ma-do",
    "escolimosa": "es-co-li-mo-sa",
    "escolimoso": "es-co-li-mo-so",
    "escolio": "es-co-lio",
    "escoliosis": "es-co-lio-sis",
    "escollar": "es-co-llar",
    "escollera": "es-co-lle-ra",
    "escollo": "es-co-llo",
    "escolopendra": "es-co-lo-pen-dra",
    "escolta": "es-col-ta",
    "escoltar": "es-col-tar",
    "escomar": "es-co-mar",
    "escombra": "es-com-bra",
    "escombrar": "es-com-brar",
    "escombrera": "es-com-bre-ra",
    "escombrero": "es-com-bre-ro",
    "escómbrido": "es-cóm-bri-do",
    "escombro": "es-com-bro",
    "escomear": "es-co-me-ar",
    "escomearse": "es-co-me-ar-se",
    "escomendrijo": "es-co-men-dri-jo",
    "escomer": "es-co-mer",
    "escomerse": "es-co-mer-se",
    "escomesa": "es-co-me-sa",
    "escón": "es-cón",
    "escoñar": "es-co-ñar",
    "esconce": "es-con-ce",
    "escondecucas": "es-con-de-cu-cas",
    "escondedero": "es-con-de-de-ro",
    "esconder": "es-con-der",
    "escondidamente": "es-con-di-da-men-te",
    "escondidas": "es-con-di-das",
    "escondidijo": "es-con-di-di-jo",
    "escondidillas": "es-con-di-di-llas",
    "escondidizo": "es-con-di-di-zo",
    "escondido": "es-con-di-do",
    "escondijo": "es-con-di-jo",
    "escondimiento": "es-con-di-mien-to",
    "escondite": "es-con-di-te",
    "escondredijo": "es-con-dre-di-jo",
    "escondrijo": "es-con-dri-jo",
    "escoñetar": "es-co-ñe-tar",
    "esconjuro": "es-con-ju-ro",
    "escontra": "es-con-tra",
    "esconzada": "es-con-za-da",
    "esconzado": "es-con-za-do",
    "esconzar": "es-con-zar",
    "escopecina": "es-co-pe-ci-na",
    "escopeta": "es-co-pe-ta",
    "escopetado": "es-co-pe-ta-do",
    "escopetazo": "es-co-pe-ta-zo",
    "escopeteado": "es-co-pe-te-a-do",
    "escopetear": "es-co-pe-te-ar",
    "escopeteo": "es-co-pe-te-o",
    "escopetería": "es-co-pe-te-rí-a",
    "escopetero": "es-co-pe-te-ro",
    "escopetilla": "es-co-pe-ti-lla",
    "escopetón": "es-co-pe-tón",
    "escopladura": "es-co-pla-du-ra",
    "escopleadura": "es-co-ple-a-du-ra",
    "escoplear": "es-co-ple-ar",
    "escoplo": "es-co-plo",
    "escopo": "es-co-po",
    "escora": "es-co-ra",
    "escorar": "es-co-rar",
    "escorbútica": "es-cor-bú-ti-ca",
    "escorbútico": "es-cor-bú-ti-co",
    "escorbuto": "es-cor-bu-to",
    "escorchado": "es-cor-cha-do",
    "escorchador": "es-cor-cha-dor",
    "escorchadora": "es-cor-cha-do-ra",
    "escorchapín": "es-cor-cha-pín",
    "escorchar": "es-cor-char",
    "escorcionera": "es-cor-cio-ne-ra",
    "escordio": "es-cor-dio",
    "escoria": "es-co-ria",
    "escoriación": "es-co-ria-ción",
    "escorial": "es-co-rial",
    "escoriar": "es-co-riar",
    "escornar": "es-cor-nar",
    "escorpena": "es-cor-pe-na",
    "escorpera": "es-cor-pe-ra",
    "escorpiana": "es-cor-pia-na",
    "escorpiano": "es-cor-pia-no",
    "escorpina": "es-cor-pi-na",
    "escorpio": "es-cor-pio",
    "escorpioide": "es-cor-pioi-de",
    "escorpión": "es-cor-pión",
    "escorredero": "es-co-rre-de-ro",
    "escorredor": "es-co-rre-dor",
    "escorrentía": "es-co-rren-tí-a",
    "escorrozo": "es-co-rro-zo",
    "escorzado": "es-cor-za-do",
    "escorzar": "es-cor-zar",
    "escorzo": "es-cor-zo",
    "escorzón": "es-cor-zón",
    "escorzonera": "es-cor-zo-ne-ra",
    "escosa": "es-co-sa",
    "escosar": "es-co-sar",
    "escoscar": "es-cos-car",
    "escota": "es-co-ta",
    "escotada": "es-co-ta-da",
    "escotado": "es-co-ta-do",
    "escotadura": "es-co-ta-du-ra",
    "escotar": "es-co-tar",
    "escote": "es-co-te",
    "escotera": "es-co-te-ra",
    "escotero": "es-co-te-ro",
    "escotilla": "es-co-ti-lla",
    "escotillón": "es-co-ti-llón",
    "escotín": "es-co-tín",
    "escotismo": "es-co-tis-mo",
    "escotista": "es-co-tis-ta",
    "escoto": "es-co-to",
    "escotoma": "es-co-to-ma",
    "escotorrar": "es-co-to-rrar",
    "escoyo": "es-co-yo",
    "escozar": "es-co-zar",
    "escozarse": "es-co-zar-se",
    "escozor": "es-co-zor",
    "escrachar": "es-cra-char",
    "escrache": "es-cra-che",
    "escracho": "es-cra-cho",
    "escrepa": "es-cre-pa",
    "escriba": "es-cri-ba",
    "escribana": "es-cri-ba-na",
    "escribanía": "es-cri-ba-ní-a",
    "escribanil": "es-cri-ba-nil",
    "escribanillo": "es-cri-ba-ni-llo",
    "escribano": "es-cri-ba-no",
    "escribido": "es-cri-bi-do",
    "escribidor": "es-cri-bi-dor",
    "escribidora": "es-cri-bi-do-ra",
    "escribiente": "es-cri-bien-te",
    "escribimiento": "es-cri-bi-mien-to",
    "escribir": "es-cri-bir",
    "escrín": "es-crín",
    "escriño": "es-cri-ño",
    "escripia": "es-cri-pia",
    "escripta": "es-crip-ta",
    "escripto": "es-crip-to",
    "escriptor": "es-crip-tor",
    "escriptora": "es-crip-to-ra",
    "escriptura": "es-crip-tu-ra",
    "escrita": "es-cri-ta",
    "escritilla": "es-cri-ti-lla",
    "escrito": "es-cri-to",
    "escritor": "es-cri-tor",
    "escritora": "es-cri-to-ra",
    "escritorio": "es-cri-to-rio",
    "escritorista": "es-cri-to-ris-ta",
    "escritura": "es-cri-tu-ra",
    "escriturar": "es-cri-tu-rar",
    "escrituraria": "es-cri-tu-ra-ria",
    "escriturario": "es-cri-tu-ra-rio",
    "escriturista": "es-cri-tu-ris-ta",
    "escrocón": "es-cro-cón",
    "escrófula": "es-cró-fu-la",
    "escrofularia": "es-cro-fu-la-ria",
    "escrofulariácea": "es-cro-fu-la-riá-ce-a",
    "escrofulariáceo": "es-cro-fu-la-riá-ce-o",
    "escrofulismo": "es-cro-fu-lis-mo",
    "escrofulosa": "es-cro-fu-lo-sa",
    "escrofuloso": "es-cro-fu-lo-so",
    "escrotal": "es-cro-tal",
    "escroto": "es-cro-to",
    "escrucar": "es-cru-car",
    "escrudiñar": "es-cru-di-ñar",
    "escrupulear": "es-cru-pu-le-ar",
    "escrupulillo": "es-cru-pu-li-llo",
    "escrupulizar": "es-cru-pu-li-zar",
    "escrúpulo": "es-crú-pu-lo",
    "escrupulosa": "es-cru-pu-lo-sa",
    "escrupulosamente": "es-cru-pu-lo-sa-men-te",
    "escrupulosidad": "es-cru-pu-lo-si-dad",
    "escrupuloso": "es-cru-pu-lo-so",
    "escrutador": "es-cru-ta-dor",
    "escrutadora": "es-cru-ta-do-ra",
    "escrutar": "es-cru-tar",
    "escrutiñador": "es-cru-ti-ña-dor",
    "escrutiñadora": "es-cru-ti-ña-do-ra",
    "escrutinio": "es-cru-ti-nio",
    "escuadra": "es-cua-dra",
    "escuadrar": "es-cua-drar",
    "escuadreo": "es-cua-dre-o",
    "escuadría": "es-cua-drí-a",
    "escuadrilla": "es-cua-dri-lla",
    "escuadro": "es-cua-dro",
    "escuadrón": "es-cua-drón",
    "escuadronar": "es-cua-dro-nar",
    "escuálida": "es-cuá-li-da",
    "escualidez": "es-cua-li-dez",
    "escuálido": "es-cuá-li-do",
    "escualo": "es-cua-lo",
    "escualor": "es-cua-lor",
    "escucha": "es-cu-cha",
    "escuchadera": "es-cu-cha-de-ra",
    "escuchador": "es-cu-cha-dor",
    "escuchadora": "es-cu-cha-do-ra",
    "escuchaña": "es-cu-cha-ña",
    "escuchaño": "es-cu-cha-ño",
    "escuchar": "es-cu-char",
    "escuchimizada": "es-cu-chi-mi-za-da",
    "escuchimizado": "es-cu-chi-mi-za-do",
    "escucho": "es-cu-cho",
    "escuchón": "es-cu-chón",
    "escuchona": "es-cu-cho-na",
    "escudado": "es-cu-da-do",
    "escudaño": "es-cu-da-ño",
    "escudar": "es-cu-dar",
    "escudella": "es-cu-de-lla",
    "escudera": "es-cu-de-ra",
    "escuderaje": "es-cu-de-ra-je",
    "escuderear": "es-cu-de-re-ar",
    "escudería": "es-cu-de-rí-a",
    "escuderil": "es-cu-de-ril",
    "escuderilmente": "es-cu-de-ril-men-te",
    "escudero": "es-cu-de-ro",
    "escuderón": "es-cu-de-rón",
    "escudete": "es-cu-de-te",
    "escudilla": "es-cu-di-lla",
    "escudillador": "es-cu-di-lla-dor",
    "escudilladora": "es-cu-di-lla-do-ra",
    "escudillar": "es-cu-di-llar",
    "escudillo": "es-cu-di-llo",
    "escudo": "es-cu-do",
    "escudriñable": "es-cu-dri-ña-ble",
    "escudriñador": "es-cu-dri-ña-dor",
    "escudriñadora": "es-cu-dri-ña-do-ra",
    "escudriñamiento": "es-cu-dri-ña-mien-to",
    "escudriñar": "es-cu-dri-ñar",
    "escudriño": "es-cu-dri-ño",
    "escuela": "es-cue-la",
    "escuerzo": "es-cuer-zo",
    "escueta": "es-cue-ta",
    "escuetamente": "es-cue-ta-men-te",
    "escueto": "es-cue-to",
    "escuincla": "es-cuin-cla",
    "escuincle": "es-cuin-cle",
    "escuintleca": "es-cuin-tle-ca",
    "escuintleco": "es-cuin-tle-co",
    "esculca": "es-cul-ca",
    "esculcar": "es-cul-car",
    "esculco": "es-cul-co",
    "escullador": "es-cu-lla-dor",
    "escullar": "es-cu-llar",
    "escullir": "es-cu-llir",
    "escullón": "es-cu-llón",
    "esculpidor": "es-cul-pi-dor",
    "esculpidura": "es-cul-pi-du-ra",
    "esculpir": "es-cul-pir",
    "escultismo": "es-cul-tis-mo",
    "escultista": "es-cul-tis-ta",
    "escultor": "es-cul-tor",
    "escultora": "es-cul-to-ra",
    "escultórica": "es-cul-tó-ri-ca",
    "escultórico": "es-cul-tó-ri-co",
    "escultura": "es-cul-tu-ra",
    "escultural": "es-cul-tu-ral",
    "escuna": "es-cu-na",
    "escupetina": "es-cu-pe-ti-na",
    "escupida": "es-cu-pi-da",
    "escupidera": "es-cu-pi-de-ra",
    "escupidero": "es-cu-pi-de-ro",
    "escupido": "es-cu-pi-do",
    "escupidor": "es-cu-pi-dor",
    "escupidora": "es-cu-pi-do-ra",
    "escupidura": "es-cu-pi-du-ra",
    "escupiña": "es-cu-pi-ña",
    "escupir": "es-cu-pir",
    "escupitajo": "es-cu-pi-ta-jo",
    "escupitina": "es-cu-pi-ti-na",
    "escupitinajo": "es-cu-pi-ti-na-jo",
    "escupo": "es-cu-po",
    "escura": "es-cu-ra",
    "escurana": "es-cu-ra-na",
    "escurar": "es-cu-rar",
    "escurcar": "es-cur-car",
    "escurecer": "es-cu-re-cer",
    "escurecimiento": "es-cu-re-ci-mien-to",
    "escureta": "es-cu-re-ta",
    "escurialense": "es-cu-ria-len-se",
    "escuridad": "es-cu-ri-dad",
    "escuro": "es-cu-ro",
    "escurra": "es-cu-rra",
    "escurraja": "es-cu-rra-ja",
    "escurreplatos": "es-cu-rre-pla-tos",
    "escurribanda": "es-cu-rri-ban-da",
    "escurrida": "es-cu-rri-da",
    "escurridero": "es-cu-rri-de-ro",
    "escurridiza": "es-cu-rri-di-za",
    "escurridizo": "es-cu-rri-di-zo",
    "escurrido": "es-cu-rri-do",
    "escurridor": "es-cu-rri-dor",
    "escurridura": "es-cu-rri-du-ra",
    "escurriduras": "es-cu-rri-du-ras",
    "escurril": "es-cu-rril",
    "escurrilidad": "es-cu-rri-li-dad",
    "escurrimbres": "es-cu-rrim-bres",
    "escurrimiento": "es-cu-rri-mien-to",
    "escurrir": "es-cu-rrir",
    "escusa": "es-cu-sa",
    "escusabaraja": "es-cu-sa-ba-ra-ja",
    "escusada": "es-cu-sa-da",
    "escusado": "es-cu-sa-do",
    "escusalí": "es-cu-sa-lí",
    "escusaña": "es-cu-sa-ña",
    "escusano": "es-cu-sa-no",
    "escusar": "es-cu-sar",
    "escuso": "es-cu-so",
    "escusón": "es-cu-són",
    "escúter": "es-cú-ter",
    "escutiforme": "es-cu-ti-for-me",
    "escuyer": "es-cu-yer",
    "esdrújula": "es-drú-ju-la",
    "esdrujulismo": "es-dru-ju-lis-mo",
    "esdrujulizar": "es-dru-ju-li-zar",
    "esdrújulo": "es-drú-ju-lo",
    "ese": "e-se",
    "esecilla": "e-se-ci-lla",
    "esencia": "e-sen-cia",
    "esencial": "e-sen-cial",
    "esencialidad": "e-sen-cia-li-dad",
    "esencialismo": "e-sen-cia-lis-mo",
    "esencialista": "e-sen-cia-lis-ta",
    "esencialmente": "e-sen-cial-men-te",
    "esenciar": "e-sen-ciar",
    "esenciarse": "e-sen-ciar-se",
    "esenciero": "e-sen-cie-ro",
    "esenia": "e-se-nia",
    "esenio": "e-se-nio",
    "eser": "e-ser",
    "eseyente": "e-se-yen-te",
    "esfacelar": "es-fa-ce-lar",
    "esfacelarse": "es-fa-ce-lar-se",
    "esfacelo": "es-fa-ce-lo",
    "esfácelo": "es-fá-ce-lo",
    "esfenisciforme": "es-fe-nis-ci-for-me",
    "esfenoidal": "es-fe-noi-dal",
    "esfenoides": "es-fe-noi-des",
    "esfera": "es-fe-ra",
    "esferal": "es-fe-ral",
    "esférica": "es-fé-ri-ca",
    "esfericidad": "es-fe-ri-ci-dad",
    "esférico": "es-fé-ri-co",
    "esferista": "es-fe-ris-ta",
    "esfero": "es-fe-ro",
    "esferográfica": "es-fe-ro-grá-fi-ca",
    "esferográfico": "es-fe-ro-grá-fi-co",
    "esferoidal": "es-fe-roi-dal",
    "esferoide": "es-fe-roi-de",
    "esferómetro": "es-fe-ró-me-tro",
    "esfigmógrafo": "es-fig-mó-gra-fo",
    "esfigmograma": "es-fig-mo-gra-ma",
    "esfigmomanómetro": "es-fig-mo-ma-nó-me-tro",
    "esfigmómetro": "es-fig-mó-me-tro",
    "esfiladiz": "es-fi-la-diz",
    "esfinge": "es-fin-ge",
    "esfíngido": "es-fín-gi-do",
    "esfínter": "es-fín-ter",
    "esfogar": "es-fo-gar",
    "esfolar": "es-fo-lar",
    "esfollar": "es-fo-llar",
    "esfondar": "es-fon-dar",
    "esfornecinar": "es-for-ne-ci-nar",
    "esforrocinar": "es-fo-rro-ci-nar",
    "esforrocino": "es-fo-rro-ci-no",
    "esforzada": "es-for-za-da",
    "esforzadamente": "es-for-za-da-men-te",
    "esforzado": "es-for-za-do",
    "esforzador": "es-for-za-dor",
    "esforzadora": "es-for-za-do-ra",
    "esforzar": "es-for-zar",
    "esfotar": "es-fo-tar",
    "esfoyar": "es-fo-yar",
    "esfoyaza": "es-fo-ya-za",
    "esfriar": "es-friar",
    "esfuerzo": "es-fuer-zo",
    "esfumación": "es-fu-ma-ción",
    "esfumado": "es-fu-ma-do",
    "esfumar": "es-fu-mar",
    "esfuminar": "es-fu-mi-nar",
    "esfumino": "es-fu-mi-no",
    "esgaritar": "es-ga-ri-tar",
    "esgarrar": "es-ga-rrar",
    "esgonzar": "es-gon-zar",
    "esgrafiado": "es-gra-fia-do",
    "esgrafiar": "es-gra-fiar",
    "esgrima": "es-gri-ma",
    "esgrimible": "es-gri-mi-ble",
    "esgrimidor": "es-gri-mi-dor",
    "esgrimidora": "es-gri-mi-do-ra",
    "esgrimidura": "es-gri-mi-du-ra",
    "esgrimir": "es-gri-mir",
    "esgrimista": "es-gri-mis-ta",
    "esguardamillar": "es-guar-da-mi-llar",
    "esguardar": "es-guar-dar",
    "esguarde": "es-guar-de",
    "esguazable": "es-gua-za-ble",
    "esguazar": "es-gua-zar",
    "esguazo": "es-gua-zo",
    "esgucio": "es-gu-cio",
    "esguila": "es-gui-la",
    "esguilar": "es-gui-lar",
    "esguilo": "es-gui-lo",
    "esguín": "es-guín",
    "esguince": "es-guin-ce",
    "esguízara": "es-guí-za-ra",
    "esguízaro": "es-guí-za-ro",
    "eslabón": "es-la-bón",
    "eslabonador": "es-la-bo-na-dor",
    "eslabonadora": "es-la-bo-na-do-ra",
    "eslabonamiento": "es-la-bo-na-mien-to",
    "eslabonar": "es-la-bo-nar",
    "eslalon": "es-la-lon",
    "eslava": "es-la-va",
    "eslavismo": "es-la-vis-mo",
    "eslavista": "es-la-vis-ta",
    "eslavo": "es-la-vo",
    "esleer": "es-le-er",
    "esleír": "es-le-ír",
    "eslinga": "es-lin-ga",
    "eslip": "es-lip",
    "eslizón": "es-li-zón",
    "eslogan": "es-lo-gan",
    "eslora": "es-lo-ra",
    "esloría": "es-lo-rí-a",
    "eslovaca": "es-lo-va-ca",
    "eslovaco": "es-lo-va-co",
    "eslovena": "es-lo-ve-na",
    "esloveno": "es-lo-ve-no",
    "esmachar": "es-ma-char",
    "esmaltado": "es-mal-ta-do",
    "esmaltador": "es-mal-ta-dor",
    "esmaltadora": "es-mal-ta-do-ra",
    "esmaltar": "es-mal-tar",
    "esmalte": "es-mal-te",
    "esmaltín": "es-mal-tín",
    "esmaltina": "es-mal-ti-na",
    "esméctica": "es-méc-ti-ca",
    "esméctico": "es-méc-ti-co",
    "esmedregal": "es-me-dre-gal",
    "esmegma": "es-meg-ma",
    "esmena": "es-me-na",
    "esmerada": "es-me-ra-da",
    "esmeradamente": "es-me-ra-da-men-te",
    "esmerado": "es-me-ra-do",
    "esmerador": "es-me-ra-dor",
    "esmeralda": "es-me-ral-da",
    "esmeraldeña": "es-me-ral-de-ña",
    "esmeraldeño": "es-me-ral-de-ño",
    "esmeraldera": "es-me-ral-de-ra",
    "esmeraldero": "es-me-ral-de-ro",
    "esmeraldina": "es-me-ral-di-na",
    "esmeraldino": "es-me-ral-di-no",
    "esmerar": "es-me-rar",
    "esmerejón": "es-me-re-jón",
    "esmeril": "es-me-ril",
    "esmerilar": "es-me-ri-lar",
    "esmerilazo": "es-me-ri-la-zo",
    "esmero": "es-me-ro",
    "esmilacácea": "es-mi-la-cá-ce-a",
    "esmilacáceas": "es-mi-la-cá-ce-as",
    "esmilacáceo": "es-mi-la-cá-ce-o",
    "esmilácea": "es-mi-lá-ce-a",
    "esmiláceo": "es-mi-lá-ce-o",
    "esmirnio": "es-mir-nio",
    "esmirriada": "es-mi-rria-da",
    "esmirriado": "es-mi-rria-do",
    "esmog": "es-mog",
    "esmola": "es-mo-la",
    "esmoladera": "es-mo-la-de-ra",
    "esmoquin": "es-mo-quin",
    "esmorecer": "es-mo-re-cer",
    "esmorecida": "es-mo-re-ci-da",
    "esmorecido": "es-mo-re-ci-do",
    "esmuir": "es-muir",
    "esmuñir": "es-mu-ñir",
    "esnifada": "es-ni-fa-da",
    "esnifar": "es-ni-far",
    "esnob": "es-nob",
    "esnobismo": "es-no-bis-mo",
    "esnobista": "es-no-bis-ta",
    "eso": "e-so",
    "esofágica": "e-so-fá-gi-ca",
    "esofágico": "e-so-fá-gi-co",
    "esófago": "e-só-fa-go",
    "esópica": "e-só-pi-ca",
    "esópico": "e-só-pi-co",
    "esos": "e-sos",
    "esotérica": "e-so-té-ri-ca",
    "esotérico": "e-so-té-ri-co",
    "esoterismo": "e-so-te-ris-mo",
    "esotra": "e-so-tra",
    "esotro": "e-so-tro",
    "espabilada": "es-pa-bi-la-da",
    "espabiladeras": "es-pa-bi-la-de-ras",
    "espabilado": "es-pa-bi-la-do",
    "espabilar": "es-pa-bi-lar",
    "espachurramiento": "es-pa-chu-rra-mien-to",
    "espachurrar": "es-pa-chu-rrar",
    "espaciadamente": "es-pa-cia-da-men-te",
    "espaciado": "es-pa-cia-do",
    "espaciador": "es-pa-cia-dor",
    "espacial": "es-pa-cial",
    "espaciamiento": "es-pa-cia-mien-to",
    "espaciar": "es-pa-ciar",
    "espácica": "es-pá-ci-ca",
    "espácico": "es-pá-ci-co",
    "espacio": "es-pa-cio",
    "espaciosa": "es-pa-cio-sa",
    "espaciosamente": "es-pa-cio-sa-men-te",
    "espaciosidad": "es-pa-cio-si-dad",
    "espacioso": "es-pa-cio-so",
    "espada": "es-pa-da",
    "espadachín": "es-pa-da-chín",
    "espadada": "es-pa-da-da",
    "espadado": "es-pa-da-do",
    "espadador": "es-pa-da-dor",
    "espadadora": "es-pa-da-do-ra",
    "espadaña": "es-pa-da-ña",
    "espadañada": "es-pa-da-ña-da",
    "espadañal": "es-pa-da-ñal",
    "espadañar": "es-pa-da-ñar",
    "espadar": "es-pa-dar",
    "espadarte": "es-pa-dar-te",
    "espadería": "es-pa-de-rí-a",
    "espadero": "es-pa-de-ro",
    "espádice": "es-pá-di-ce",
    "espadilla": "es-pa-di-lla",
    "espadillado": "es-pa-di-lla-do",
    "espadillar": "es-pa-di-llar",
    "espadillazo": "es-pa-di-lla-zo",
    "espadín": "es-pa-dín",
    "espadista": "es-pa-dis-ta",
    "espadón": "es-pa-dón",
    "espadrapo": "es-pa-dra-po",
    "espagírica": "es-pa-gí-ri-ca",
    "espagírico": "es-pa-gí-ri-co",
    "espagueti": "es-pa-gue-ti",
    "espahí": "es-pa-hí",
    "espaladinar": "es-pa-la-di-nar",
    "espalar": "es-pa-lar",
    "espalda": "es-pal-da",
    "espaldar": "es-pal-dar",
    "espaldarazo": "es-pal-da-ra-zo",
    "espaldarcete": "es-pal-dar-ce-te",
    "espaldarón": "es-pal-da-rón",
    "espaldear": "es-pal-de-ar",
    "espalder": "es-pal-der",
    "espaldera": "es-pal-de-ra",
    "espaldero": "es-pal-de-ro",
    "espaldilla": "es-pal-di-lla",
    "espaldista": "es-pal-dis-ta",
    "espalditendida": "es-pal-di-ten-di-da",
    "espalditendido": "es-pal-di-ten-di-do",
    "espaldón": "es-pal-dón",
    "espaldonar": "es-pal-do-nar",
    "espaldonarse": "es-pal-do-nar-se",
    "espalduda": "es-pal-du-da",
    "espaldudo": "es-pal-du-do",
    "espalera": "es-pa-le-ra",
    "espalmador": "es-pal-ma-dor",
    "espalmadura": "es-pal-ma-du-ra",
    "espalmar": "es-pal-mar",
    "espalto": "es-pal-to",
    "españa": "es-pa-ña",
    "espanglish": "es-pan-glish",
    "español": "es-pa-ñol",
    "española": "es-pa-ño-la",
    "españolada": "es-pa-ño-la-da",
    "españolado": "es-pa-ño-la-do",
    "españolar": "es-pa-ño-lar",
    "españolear": "es-pa-ño-le-ar",
    "españolería": "es-pa-ño-le-rí-a",
    "españoleta": "es-pa-ño-le-ta",
    "españolía": "es-pa-ño-lí-a",
    "españolidad": "es-pa-ño-li-dad",
    "españolismo": "es-pa-ño-lis-mo",
    "españolista": "es-pa-ño-lis-ta",
    "españolización": "es-pa-ño-li-za-ción",
    "españolizar": "es-pa-ño-li-zar",
    "espantable": "es-pan-ta-ble",
    "espantablemente": "es-pan-ta-ble-men-te",
    "espantacaimán": "es-pan-ta-cai-mán",
    "espantada": "es-pan-ta-da",
    "espantadiza": "es-pan-ta-di-za",
    "espantadizo": "es-pan-ta-di-zo",
    "espantador": "es-pan-ta-dor",
    "espantadora": "es-pan-ta-do-ra",
    "espantagustos": "es-pan-ta-gus-tos",
    "espantajo": "es-pan-ta-jo",
    "espantalobos": "es-pan-ta-lo-bos",
    "espantamoscas": "es-pan-ta-mos-cas",
    "espantanublados": "es-pan-ta-nu-bla-dos",
    "espantapájaros": "es-pan-ta-pá-ja-ros",
    "espantar": "es-pan-tar",
    "espantasuegras": "es-pan-ta-sue-gras",
    "espantavillanos": "es-pan-ta-vi-lla-nos",
    "espante": "es-pan-te",
    "espanto": "es-pan-to",
    "espantosa": "es-pan-to-sa",
    "espantosamente": "es-pan-to-sa-men-te",
    "espantosidad": "es-pan-to-si-dad",
    "espantoso": "es-pan-to-so",
    "esparadrapo": "es-pa-ra-dra-po",
    "esparajismo": "es-pa-ra-jis-mo",
    "esparaván": "es-pa-ra-ván",
    "esparavel": "es-pa-ra-vel",
    "esparceta": "es-par-ce-ta",
    "esparciata": "es-par-cia-ta",
    "esparcida": "es-par-ci-da",
    "esparcidamente": "es-par-ci-da-men-te",
    "esparcido": "es-par-ci-do",
    "esparcidor": "es-par-ci-dor",
    "esparcidora": "es-par-ci-do-ra",
    "esparcimiento": "es-par-ci-mien-to",
    "esparcir": "es-par-cir",
    "espárido": "es-pá-ri-do",
    "esparragado": "es-pa-rra-ga-do",
    "esparragador": "es-pa-rra-ga-dor",
    "esparragadora": "es-pa-rra-ga-do-ra",
    "esparragal": "es-pa-rra-gal",
    "esparragamiento": "es-pa-rra-ga-mien-to",
    "esparragar": "es-pa-rra-gar",
    "espárrago": "es-pá-rra-go",
    "esparragón": "es-pa-rra-gón",
    "esparraguera": "es-pa-rra-gue-ra",
    "esparraguero": "es-pa-rra-gue-ro",
    "esparraguina": "es-pa-rra-gui-na",
    "esparramar": "es-pa-rra-mar",
    "esparrancada": "es-pa-rran-ca-da",
    "esparrancado": "es-pa-rran-ca-do",
    "esparrancar": "es-pa-rran-car",
    "esparrancarse": "es-pa-rran-car-se",
    "esparsión": "es-par-sión",
    "espartal": "es-par-tal",
    "espartana": "es-par-ta-na",
    "espartano": "es-par-ta-no",
    "espartaquismo": "es-par-ta-quis-mo",
    "espartaquista": "es-par-ta-quis-ta",
    "espartar": "es-par-tar",
    "esparteína": "es-par-te-í-na",
    "esparteña": "es-par-te-ña",
    "espartera": "es-par-te-ra",
    "espartería": "es-par-te-rí-a",
    "espartero": "es-par-te-ro",
    "espartilla": "es-par-ti-lla",
    "espartillo": "es-par-ti-llo",
    "espartizal": "es-par-ti-zal",
    "esparto": "es-par-to",
    "esparvar": "es-par-var",
    "esparvel": "es-par-vel",
    "esparver": "es-par-ver",
    "espasmar": "es-pas-mar",
    "espasmo": "es-pas-mo",
    "espasmódica": "es-pas-mó-di-ca",
    "espasmódico": "es-pas-mó-di-co",
    "espasticidad": "es-pas-ti-ci-dad",
    "espástico": "es-pás-ti-co",
    "espata": "es-pa-ta",
    "espatarrada": "es-pa-ta-rra-da",
    "espatarrar": "es-pa-ta-rrar",
    "espatarrarse": "es-pa-ta-rrar-se",
    "espática": "es-pá-ti-ca",
    "espático": "es-pá-ti-co",
    "espato": "es-pa-to",
    "espátula": "es-pá-tu-la",
    "espatulomancía": "es-pa-tu-lo-man-cí-a",
    "espatulomancia": "es-pa-tu-lo-man-cia",
    "espaturrar": "es-pa-tu-rrar",
    "espaviento": "es-pa-vien-to",
    "espavorida": "es-pa-vo-ri-da",
    "espavorido": "es-pa-vo-ri-do",
    "espay": "es-pay",
    "especería": "es-pe-ce-rí-a",
    "especia": "es-pe-cia",
    "especial": "es-pe-cial",
    "especialidad": "es-pe-cia-li-dad",
    "especialista": "es-pe-cia-lis-ta",
    "especialización": "es-pe-cia-li-za-ción",
    "especializado": "es-pe-cia-li-za-do",
    "especializar": "es-pe-cia-li-zar",
    "especialmente": "es-pe-cial-men-te",
    "especiar": "es-pe-ciar",
    "especie": "es-pe-cie",
    "especiera": "es-pe-cie-ra",
    "especiería": "es-pe-cie-rí-a",
    "especiero": "es-pe-cie-ro",
    "específica": "es-pe-cí-fi-ca",
    "especificación": "es-pe-ci-fi-ca-ción",
    "especificadamente": "es-pe-ci-fi-ca-da-men-te",
    "específicamente": "es-pe-cí-fi-ca-men-te",
    "especificar": "es-pe-ci-fi-car",
    "especificativa": "es-pe-ci-fi-ca-ti-va",
    "especificativo": "es-pe-ci-fi-ca-ti-vo",
    "especificidad": "es-pe-ci-fi-ci-dad",
    "específico": "es-pe-cí-fi-co",
    "espécimen": "es-pé-ci-men",
    "especiosa": "es-pe-cio-sa",
    "especiosidad": "es-pe-cio-si-dad",
    "especioso": "es-pe-cio-so",
    "especiota": "es-pe-cio-ta",
    "espectable": "es-pec-ta-ble",
    "espectacular": "es-pec-ta-cu-lar",
    "espectacularidad": "es-pec-ta-cu-la-ri-dad",
    "espectáculo": "es-pec-tá-cu-lo",
    "espectador": "es-pec-ta-dor",
    "espectadora": "es-pec-ta-do-ra",
    "espectral": "es-pec-tral",
    "espectro": "es-pec-tro",
    "espectrofotometría": "es-pec-tro-fo-to-me-trí-a",
    "espectrofotómetro": "es-pec-tro-fo-tó-me-tro",
    "espectrografía": "es-pec-tro-gra-fí-a",
    "espectrógrafo": "es-pec-tró-gra-fo",
    "espectrograma": "es-pec-tro-gra-ma",
    "espectroheliógrafo": "es-pec-tro-he-lió-gra-fo",
    "espectrohelioscopio": "es-pec-tro-he-lios-co-pio",
    "espectrometría": "es-pec-tro-me-trí-a",
    "espectrómetro": "es-pec-tró-me-tro",
    "espectroscopia": "es-pec-tros-co-pia",
    "espectroscópica": "es-pec-tros-có-pi-ca",
    "espectroscópico": "es-pec-tros-có-pi-co",
    "espectroscopio": "es-pec-tros-co-pio",
    "especulación": "es-pe-cu-la-ción",
    "especulador": "es-pe-cu-la-dor",
    "especuladora": "es-pe-cu-la-do-ra",
    "especular": "es-pe-cu-lar",
    "especulativa": "es-pe-cu-la-ti-va",
    "especulativamente": "es-pe-cu-la-ti-va-men-te",
    "especulativo": "es-pe-cu-la-ti-vo",
    "espéculo": "es-pé-cu-lo",
    "espedazar": "es-pe-da-zar",
    "espedir": "es-pe-dir",
    "espedirse": "es-pe-dir-se",
    "espedo": "es-pe-do",
    "espejada": "es-pe-ja-da",
    "espejado": "es-pe-ja-do",
    "espejar": "es-pe-jar",
    "espejear": "es-pe-je-ar",
    "espejeo": "es-pe-je-o",
    "espejera": "es-pe-je-ra",
    "espejeras": "es-pe-je-ras",
    "espejería": "es-pe-je-rí-a",
    "espejero": "es-pe-je-ro",
    "espejismo": "es-pe-jis-mo",
    "espejo": "es-pe-jo",
    "espejuela": "es-pe-jue-la",
    "espejuelo": "es-pe-jue-lo",
    "espeleóloga": "es-pe-le-ó-lo-ga",
    "espeleología": "es-pe-le-o-lo-gí-a",
    "espeleológico": "es-pe-le-o-ló-gi-co",
    "espeleólogo": "es-pe-le-ó-lo-go",
    "espelotar": "es-pe-lo-tar",
    "espelta": "es-pel-ta",
    "espéltea": "es-pél-te-a",
    "espélteo": "es-pél-te-o",
    "espelucar": "es-pe-lu-car",
    "espelunca": "es-pe-lun-ca",
    "espeluzar": "es-pe-lu-zar",
    "espeluznamiento": "es-pe-luz-na-mien-to",
    "espeluznante": "es-pe-luz-nan-te",
    "espeluznar": "es-pe-luz-nar",
    "espeluzno": "es-pe-luz-no",
    "espeluzo": "es-pe-lu-zo",
    "espenjador": "es-pen-ja-dor",
    "espeque": "es-pe-que",
    "espera": "es-pe-ra",
    "esperable": "es-pe-ra-ble",
    "esperadamente": "es-pe-ra-da-men-te",
    "esperadero": "es-pe-ra-de-ro",
    "esperador": "es-pe-ra-dor",
    "esperadora": "es-pe-ra-do-ra",
    "esperantista": "es-pe-ran-tis-ta",
    "esperanto": "es-pe-ran-to",
    "esperanza": "es-pe-ran-za",
    "esperanzada": "es-pe-ran-za-da",
    "esperanzado": "es-pe-ran-za-do",
    "esperanzador": "es-pe-ran-za-dor",
    "esperanzar": "es-pe-ran-zar",
    "esperar": "es-pe-rar",
    "espercudir": "es-per-cu-dir",
    "esperdecir": "es-per-de-cir",
    "esperenceja": "es-pe-ren-ce-ja",
    "esperencejo": "es-pe-ren-ce-jo",
    "esperezar": "es-pe-re-zar",
    "esperezarse": "es-pe-re-zar-se",
    "esperezo": "es-pe-re-zo",
    "espergurar": "es-per-gu-rar",
    "esperida": "es-pe-ri-da",
    "esperido": "es-pe-ri-do",
    "esperiega": "es-pe-rie-ga",
    "esperiego": "es-pe-rie-go",
    "esperma": "es-per-ma",
    "espermafita": "es-per-ma-fi-ta",
    "espermafito": "es-per-ma-fi-to",
    "espermática": "es-per-má-ti-ca",
    "espermaticida": "es-per-ma-ti-ci-da",
    "espermático": "es-per-má-ti-co",
    "espermátida": "es-per-má-ti-da",
    "espermatocito": "es-per-ma-to-ci-to",
    "espermatófito": "es-per-ma-tó-fi-to",
    "espermatogénesis": "es-per-ma-to-gé-ne-sis",
    "espermatogonia": "es-per-ma-to-go-nia",
    "espermatorrea": "es-per-ma-to-rre-a",
    "espermatozoario": "es-per-ma-to-zo-a-rio",
    "espermatozoide": "es-per-ma-to-zoi-de",
    "espermatozoo": "es-per-ma-to-zo-o",
    "espermicida": "es-per-mi-ci-da",
    "espermio": "es-per-mio",
    "espermiograma": "es-per-mio-gra-ma",
    "espernada": "es-per-na-da",
    "espernancar": "es-per-nan-car",
    "espernancarse": "es-per-nan-car-se",
    "espernible": "es-per-ni-ble",
    "esperón": "es-pe-rón",
    "esperpéntico": "es-per-pén-ti-co",
    "esperpentismo": "es-per-pen-tis-mo",
    "esperpentizar": "es-per-pen-ti-zar",
    "esperpento": "es-per-pen-to",
    "esperriaca": "es-pe-rria-ca",
    "esperriadero": "es-pe-rria-de-ro",
    "esperriar": "es-pe-rriar",
    "esperteza": "es-per-te-za",
    "espesa": "es-pe-sa",
    "espesamente": "es-pe-sa-men-te",
    "espesamiento": "es-pe-sa-mien-to",
    "espesante": "es-pe-san-te",
    "espesar": "es-pe-sar",
    "espesativa": "es-pe-sa-ti-va",
    "espesativo": "es-pe-sa-ti-vo",
    "espeseza": "es-pe-se-za",
    "espeso": "es-pe-so",
    "espesor": "es-pe-sor",
    "espesura": "es-pe-su-ra",
    "espetado": "es-pe-ta-do",
    "espetaperro": "es-pe-ta-pe-rro",
    "espetar": "es-pe-tar",
    "espetera": "es-pe-te-ra",
    "espeto": "es-pe-to",
    "espetón": "es-pe-tón",
    "espía": "es-pí-a",
    "espiada": "es-pia-da",
    "espiado": "es-pia-do",
    "espiador": "es-pia-dor",
    "espiantar": "es-pian-tar",
    "espiante": "es-pian-te",
    "espiar": "es-piar",
    "espibia": "es-pi-bia",
    "espibio": "es-pi-bio",
    "espibión": "es-pi-bión",
    "espicanardi": "es-pi-ca-nar-di",
    "espicanardo": "es-pi-ca-nar-do",
    "espichar": "es-pi-char",
    "espiche": "es-pi-che",
    "espichón": "es-pi-chón",
    "espiciforme": "es-pi-ci-for-me",
    "espícula": "es-pí-cu-la",
    "espídico": "es-pí-di-co",
    "espiedo": "es-pie-do",
    "espiga": "es-pi-ga",
    "espigada": "es-pi-ga-da",
    "espigadera": "es-pi-ga-de-ra",
    "espigadilla": "es-pi-ga-di-lla",
    "espigado": "es-pi-ga-do",
    "espigador": "es-pi-ga-dor",
    "espigadora": "es-pi-ga-do-ra",
    "espigar": "es-pi-gar",
    "espigo": "es-pi-go",
    "espigón": "es-pi-gón",
    "espigosa": "es-pi-go-sa",
    "espigoso": "es-pi-go-so",
    "espiguear": "es-pi-gue-ar",
    "espigueo": "es-pi-gue-o",
    "espiguilla": "es-pi-gui-lla",
    "espilocho": "es-pi-lo-cho",
    "espín": "es-pín",
    "espina": "es-pi-na",
    "espinablo": "es-pi-na-blo",
    "espinaca": "es-pi-na-ca",
    "espinadura": "es-pi-na-du-ra",
    "espinal": "es-pi-nal",
    "espinapez": "es-pi-na-pez",
    "espinar": "es-pi-nar",
    "espinazo": "es-pi-na-zo",
    "espínea": "es-pí-ne-a",
    "espinel": "es-pi-nel",
    "espinela": "es-pi-ne-la",
    "espíneo": "es-pí-ne-o",
    "espinera": "es-pi-ne-ra",
    "espinescente": "es-pi-nes-cen-te",
    "espineta": "es-pi-ne-ta",
    "espingarda": "es-pin-gar-da",
    "espingardada": "es-pin-gar-da-da",
    "espingardería": "es-pin-gar-de-rí-a",
    "espingardero": "es-pin-gar-de-ro",
    "espinilla": "es-pi-ni-lla",
    "espinillera": "es-pi-ni-lle-ra",
    "espinillo": "es-pi-ni-llo",
    "espinita": "es-pi-ni-ta",
    "espino": "es-pi-no",
    "espinochar": "es-pi-no-char",
    "espinosa": "es-pi-no-sa",
    "espinosiega": "es-pi-no-sie-ga",
    "espinosiego": "es-pi-no-sie-go",
    "espinosismo": "es-pi-no-sis-mo",
    "espinosista": "es-pi-no-sis-ta",
    "espinoso": "es-pi-no-so",
    "espinuda": "es-pi-nu-da",
    "espinudo": "es-pi-nu-do",
    "espiocha": "es-pio-cha",
    "espión": "es-pión",
    "espionaje": "es-pio-na-je",
    "espiote": "es-pio-te",
    "espira": "es-pi-ra",
    "espiración": "es-pi-ra-ción",
    "espiráculo": "es-pi-rá-cu-lo",
    "espirador": "es-pi-ra-dor",
    "espiradora": "es-pi-ra-do-ra",
    "espiral": "es-pi-ral",
    "espirante": "es-pi-ran-te",
    "espirar": "es-pi-rar",
    "espirativa": "es-pi-ra-ti-va",
    "espirativo": "es-pi-ra-ti-vo",
    "espiratoria": "es-pi-ra-to-ria",
    "espiratorio": "es-pi-ra-to-rio",
    "espirilo": "es-pi-ri-lo",
    "espiritada": "es-pi-ri-ta-da",
    "espiritado": "es-pi-ri-ta-do",
    "espirital": "es-pi-ri-tal",
    "espiritar": "es-pi-ri-tar",
    "espiritifláutico": "es-pi-ri-ti-fláu-ti-co",
    "espiritismo": "es-pi-ri-tis-mo",
    "espiritista": "es-pi-ri-tis-ta",
    "espiritosa": "es-pi-ri-to-sa",
    "espiritosamente": "es-pi-ri-to-sa-men-te",
    "espiritoso": "es-pi-ri-to-so",
    "espiritrompa": "es-pi-ri-trom-pa",
    "espíritu": "es-pí-ri-tu",
    "espiritual": "es-pi-ri-tual",
    "espiritualidad": "es-pi-ri-tua-li-dad",
    "espiritualismo": "es-pi-ri-tua-lis-mo",
    "espiritualista": "es-pi-ri-tua-lis-ta",
    "espiritualización": "es-pi-ri-tua-li-za-ción",
    "espiritualizar": "es-pi-ri-tua-li-zar",
    "espiritualmente": "es-pi-ri-tual-men-te",
    "espirituana": "es-pi-ri-tua-na",
    "espirituano": "es-pi-ri-tua-no",
    "espirituosa": "es-pi-ri-tuo-sa",
    "espirituoso": "es-pi-ri-tuo-so",
    "espiritusanto": "es-pi-ri-tu-san-to",
    "espiroidal": "es-pi-roi-dal",
    "espirometría": "es-pi-ro-me-trí-a",
    "espirómetro": "es-pi-ró-me-tro",
    "espiroqueta": "es-pi-ro-que-ta",
    "espiroquetal": "es-pi-ro-que-tal",
    "espiroqueto": "es-pi-ro-que-to",
    "espita": "es-pi-ta",
    "espitar": "es-pi-tar",
    "espito": "es-pi-to",
    "espitoso": "es-pi-to-so",
    "esplendente": "es-plen-den-te",
    "esplender": "es-plen-der",
    "espléndida": "es-plén-di-da",
    "espléndidamente": "es-plén-di-da-men-te",
    "esplendidez": "es-plen-di-dez",
    "espléndido": "es-plén-di-do",
    "esplendor": "es-plen-dor",
    "esplendorosa": "es-plen-do-ro-sa",
    "esplendorosamente": "es-plen-do-ro-sa-men-te",
    "esplendoroso": "es-plen-do-ro-so",
    "esplenectomía": "es-ple-nec-to-mí-a",
    "esplenética": "es-ple-né-ti-ca",
    "esplenético": "es-ple-né-ti-co",
    "esplénica": "es-plé-ni-ca",
    "esplénico": "es-plé-ni-co",
    "esplenio": "es-ple-nio",
    "esplenitis": "es-ple-ni-tis",
    "esplenomegalia": "es-ple-no-me-ga-lia",
    "espliego": "es-plie-go",
    "esplín": "es-plín",
    "esplique": "es-pli-que",
    "espodumena": "es-po-du-me-na",
    "espolada": "es-po-la-da",
    "espolazo": "es-po-la-zo",
    "espoleadura": "es-po-le-a-du-ra",
    "espolear": "es-po-le-ar",
    "espoleta": "es-po-le-ta",
    "espoliación": "es-po-lia-ción",
    "espoliador": "es-po-lia-dor",
    "espoliadora": "es-po-lia-do-ra",
    "espoliar": "es-po-liar",
    "espolín": "es-po-lín",
    "espolinar": "es-po-li-nar",
    "espolio": "es-po-lio",
    "espolique": "es-po-li-que",
    "espolista": "es-po-lis-ta",
    "espolón": "es-po-lón",
    "espolonada": "es-po-lo-na-da",
    "espolonazo": "es-po-lo-na-zo",
    "espolonear": "es-po-lo-ne-ar",
    "espolvorar": "es-pol-vo-rar",
    "espolvorear": "es-pol-vo-re-ar",
    "espolvoreo": "es-pol-vo-re-o",
    "espolvorizar": "es-pol-vo-ri-zar",
    "espondaica": "es-pon-dai-ca",
    "espondaico": "es-pon-dai-co",
    "espondeo": "es-pon-de-o",
    "espóndil": "es-pón-dil",
    "espondilitis": "es-pon-di-li-tis",
    "espóndilo": "es-pón-di-lo",
    "espondilosis": "es-pon-di-lo-sis",
    "espongiario": "es-pon-gia-rio",
    "espongiosa": "es-pon-gio-sa",
    "espongiosidad": "es-pon-gio-si-dad",
    "espongioso": "es-pon-gio-so",
    "esponja": "es-pon-ja",
    "esponjado": "es-pon-ja-do",
    "esponjadura": "es-pon-ja-du-ra",
    "esponjamiento": "es-pon-ja-mien-to",
    "esponjar": "es-pon-jar",
    "esponjera": "es-pon-je-ra",
    "esponjosa": "es-pon-jo-sa",
    "esponjosidad": "es-pon-jo-si-dad",
    "esponjoso": "es-pon-jo-so",
    "esponsales": "es-pon-sa-les",
    "esponsalicia": "es-pon-sa-li-cia",
    "esponsalicio": "es-pon-sa-li-cio",
    "espónsor": "es-pón-sor",
    "esponsorización": "es-pon-so-ri-za-ción",
    "esponsorizar": "es-pon-so-ri-zar",
    "espontánea": "es-pon-tá-ne-a",
    "espontáneamente": "es-pon-tá-ne-a-men-te",
    "espontanear": "es-pon-ta-ne-ar",
    "espontanearse": "es-pon-ta-ne-ar-se",
    "espontaneidad": "es-pon-ta-nei-dad",
    "espontáneo": "es-pon-tá-ne-o",
    "espontón": "es-pon-tón",
    "espontonada": "es-pon-to-na-da",
    "espora": "es-po-ra",
    "esporádica": "es-po-rá-di-ca",
    "esporádico": "es-po-rá-di-co",
    "esporangio": "es-po-ran-gio",
    "esporidio": "es-po-ri-dio",
    "esporífero": "es-po-rí-fe-ro",
    "esporo": "es-po-ro",
    "esporocarpio": "es-po-ro-car-pio",
    "esporofila": "es-po-ro-fi-la",
    "esporofilo": "es-po-ro-fi-lo",
    "esporofito": "es-po-ro-fi-to",
    "esporófito": "es-po-ró-fi-to",
    "esporozoario": "es-po-ro-zo-a-rio",
    "esporozoo": "es-po-ro-zo-o",
    "esportada": "es-por-ta-da",
    "esportear": "es-por-te-ar",
    "esportilla": "es-por-ti-lla",
    "esportillero": "es-por-ti-lle-ro",
    "esportillo": "es-por-ti-llo",
    "esportizo": "es-por-ti-zo",
    "esportón": "es-por-tón",
    "esportonada": "es-por-to-na-da",
    "esporulación": "es-po-ru-la-ción",
    "esporular": "es-po-ru-lar",
    "esposa": "es-po-sa",
    "esposada": "es-po-sa-da",
    "esposado": "es-po-sa-do",
    "esposar": "es-po-sar",
    "esposo": "es-po-so",
    "esprea": "es-pre-a",
    "esprín": "es-prín",
    "esprint": "es-print",
    "esprintar": "es-prin-tar",
    "esprínter": "es-prín-ter",
    "espuela": "es-pue-la",
    "espuenda": "es-puen-da",
    "espuerta": "es-puer-ta",
    "espulgadero": "es-pul-ga-de-ro",
    "espulgador": "es-pul-ga-dor",
    "espulgadora": "es-pul-ga-do-ra",
    "espulgar": "es-pul-gar",
    "espulgo": "es-pul-go",
    "espuma": "es-pu-ma",
    "espumadera": "es-pu-ma-de-ra",
    "espumadero": "es-pu-ma-de-ro",
    "espumador": "es-pu-ma-dor",
    "espumadora": "es-pu-ma-do-ra",
    "espumaje": "es-pu-ma-je",
    "espumajear": "es-pu-ma-je-ar",
    "espumajo": "es-pu-ma-jo",
    "espumajosa": "es-pu-ma-jo-sa",
    "espumajoso": "es-pu-ma-jo-so",
    "espumante": "es-pu-man-te",
    "espumar": "es-pu-mar",
    "espumarajo": "es-pu-ma-ra-jo",
    "espúmea": "es-pú-me-a",
    "espumeante": "es-pu-me-an-te",
    "espumear": "es-pu-me-ar",
    "espúmeo": "es-pú-me-o",
    "espumero": "es-pu-me-ro",
    "espumilla": "es-pu-mi-lla",
    "espumillón": "es-pu-mi-llón",
    "espumosa": "es-pu-mo-sa",
    "espumoso": "es-pu-mo-so",
    "espumuy": "es-pu-muy",
    "espundia": "es-pun-dia",
    "espuria": "es-pu-ria",
    "espurio": "es-pu-rio",
    "espurrear": "es-pu-rre-ar",
    "espurriar": "es-pu-rriar",
    "espurrir": "es-pu-rrir",
    "esputar": "es-pu-tar",
    "esputo": "es-pu-to",
    "esquebrajar": "es-que-bra-jar",
    "esquejar": "es-que-jar",
    "esqueje": "es-que-je",
    "esquela": "es-que-la",
    "esqueletado": "es-que-le-ta-do",
    "esquelética": "es-que-lé-ti-ca",
    "esquelético": "es-que-lé-ti-co",
    "esqueleto": "es-que-le-to",
    "esquema": "es-que-ma",
    "esquemática": "es-que-má-ti-ca",
    "esquemáticamente": "es-que-má-ti-ca-men-te",
    "esquemático": "es-que-má-ti-co",
    "esquematismo": "es-que-ma-tis-mo",
    "esquematización": "es-que-ma-ti-za-ción",
    "esquematizar": "es-que-ma-ti-zar",
    "esquena": "es-que-na",
    "esquenanto": "es-que-nan-to",
    "esquero": "es-que-ro",
    "esquí": "es-quí",
    "esquiador": "es-quia-dor",
    "esquiadora": "es-quia-do-ra",
    "esquiar": "es-quiar",
    "esquiciar": "es-qui-ciar",
    "esquicio": "es-qui-cio",
    "esquifada": "es-qui-fa-da",
    "esquifar": "es-qui-far",
    "esquifazón": "es-qui-fa-zón",
    "esquife": "es-qui-fe",
    "esquijama": "es-qui-ja-ma",
    "esquil": "es-quil",
    "esquila": "es-qui-la",
    "esquilada": "es-qui-la-da",
    "esquilador": "es-qui-la-dor",
    "esquiladora": "es-qui-la-do-ra",
    "esquilar": "es-qui-lar",
    "esquileo": "es-qui-le-o",
    "esquilero": "es-qui-le-ro",
    "esquilfe": "es-quil-fe",
    "esquilimosa": "es-qui-li-mo-sa",
    "esquilimoso": "es-qui-li-mo-so",
    "esquilmar": "es-quil-mar",
    "esquilmo": "es-quil-mo",
    "esquilo": "es-qui-lo",
    "esquilón": "es-qui-lón",
    "esquimal": "es-qui-mal",
    "esquimo": "es-qui-mo",
    "esquina": "es-qui-na",
    "esquinada": "es-qui-na-da",
    "esquinado": "es-qui-na-do",
    "esquinadura": "es-qui-na-du-ra",
    "esquinal": "es-qui-nal",
    "esquinancia": "es-qui-nan-cia",
    "esquinante": "es-qui-nan-te",
    "esquinanto": "es-qui-nan-to",
    "esquinar": "es-qui-nar",
    "esquinazo": "es-qui-na-zo",
    "esquinco": "es-quin-co",
    "esquinela": "es-qui-ne-la",
    "esquinencia": "es-qui-nen-cia",
    "esquinera": "es-qui-ne-ra",
    "esquinero": "es-qui-ne-ro",
    "esquinsuche": "es-quin-su-che",
    "esquinzador": "es-quin-za-dor",
    "esquinzar": "es-quin-zar",
    "esquiraza": "es-qui-ra-za",
    "esquirla": "es-quir-la",
    "esquirol": "es-qui-rol",
    "esquisar": "es-qui-sar",
    "esquisto": "es-quis-to",
    "esquistosa": "es-quis-to-sa",
    "esquistoso": "es-quis-to-so",
    "esquisuche": "es-qui-su-che",
    "esquitar": "es-qui-tar",
    "esquite": "es-qui-te",
    "esquiva": "es-qui-va",
    "esquivar": "es-qui-var",
    "esquivez": "es-qui-vez",
    "esquiveza": "es-qui-ve-za",
    "esquividad": "es-qui-vi-dad",
    "esquivo": "es-qui-vo",
    "esquizada": "es-qui-za-da",
    "esquizado": "es-qui-za-do",
    "esquizofrenia": "es-qui-zo-fre-nia",
    "esquizofrénica": "es-qui-zo-fré-ni-ca",
    "esquizofrénico": "es-qui-zo-fré-ni-co",
    "esquizoide": "es-qui-zoi-de",
    "esta": "es-ta",
    "estabilidad": "es-ta-bi-li-dad",
    "estabilísimo": "es-ta-bi-lí-si-mo",
    "estabilización": "es-ta-bi-li-za-ción",
    "estabilizador": "es-ta-bi-li-za-dor",
    "estabilizadora": "es-ta-bi-li-za-do-ra",
    "estabilizante": "es-ta-bi-li-zan-te",
    "estabilizar": "es-ta-bi-li-zar",
    "estable": "es-ta-ble",
    "establear": "es-ta-ble-ar",
    "establecedor": "es-ta-ble-ce-dor",
    "establecedora": "es-ta-ble-ce-do-ra",
    "establecer": "es-ta-ble-cer",
    "establecido": "es-ta-ble-ci-do",
    "establecimiento": "es-ta-ble-ci-mien-to",
    "establemente": "es-ta-ble-men-te",
    "establero": "es-ta-ble-ro",
    "establía": "es-ta-blí-a",
    "establir": "es-ta-blir",
    "establishment": "es-ta-blish-ment",
    "establo": "es-ta-blo",
    "estabón": "es-ta-bón",
    "estabulación": "es-ta-bu-la-ción",
    "estabular": "es-ta-bu-lar",
    "estaca": "es-ta-ca",
    "estacada": "es-ta-ca-da",
    "estacado": "es-ta-ca-do",
    "estacadura": "es-ta-ca-du-ra",
    "estacar": "es-ta-car",
    "estacazo": "es-ta-ca-zo",
    "estacha": "es-ta-cha",
    "estache": "es-ta-che",
    "estación": "es-ta-ción",
    "estacional": "es-ta-cio-nal",
    "estacionalidad": "es-ta-cio-na-li-dad",
    "estacionamiento": "es-ta-cio-na-mien-to",
    "estacionar": "es-ta-cio-nar",
    "estacionaria": "es-ta-cio-na-ria",
    "estacionario": "es-ta-cio-na-rio",
    "estacionera": "es-ta-cio-ne-ra",
    "estacionero": "es-ta-cio-ne-ro",
    "estacón": "es-ta-cón",
    "estacte": "es-tac-te",
    "estada": "es-ta-da",
    "estadal": "es-ta-dal",
    "estadero": "es-ta-de-ro",
    "estadía": "es-ta-dí-a",
    "estadidad": "es-ta-di-dad",
    "estadificación": "es-ta-di-fi-ca-ción",
    "estadificar": "es-ta-di-fi-car",
    "estadígrafa": "es-ta-dí-gra-fa",
    "estadígrafo": "es-ta-dí-gra-fo",
    "estadillo": "es-ta-di-llo",
    "estadio": "es-ta-dio",
    "estadista": "es-ta-dis-ta",
    "estadística": "es-ta-dís-ti-ca",
    "estadísticamente": "es-ta-dís-ti-ca-men-te",
    "estadístico": "es-ta-dís-ti-co",
    "estadiza": "es-ta-di-za",
    "estadizo": "es-ta-di-zo",
    "estado": "es-ta-do",
    "estadojo": "es-ta-do-jo",
    "estadoño": "es-ta-do-ño",
    "estadounidense": "es-ta-dou-ni-den-se",
    "estadual": "es-ta-dual",
    "estadunidense": "es-ta-du-ni-den-se",
    "estafa": "es-ta-fa",
    "estafador": "es-ta-fa-dor",
    "estafadora": "es-ta-fa-do-ra",
    "estafar": "es-ta-far",
    "estaferia": "es-ta-fe-ria",
    "estafermo": "es-ta-fer-mo",
    "estafero": "es-ta-fe-ro",
    "estafeta": "es-ta-fe-ta",
    "estafetera": "es-ta-fe-te-ra",
    "estafetero": "es-ta-fe-te-ro",
    "estafetil": "es-ta-fe-til",
    "estafiate": "es-ta-fia-te",
    "estafilococia": "es-ta-fi-lo-co-cia",
    "estafilococo": "es-ta-fi-lo-co-co",
    "estafiloma": "es-ta-fi-lo-ma",
    "estafisagria": "es-ta-fi-sa-gria",
    "estagirita": "es-ta-gi-ri-ta",
    "estajanovismo": "es-ta-ja-no-vis-mo",
    "estajanovista": "es-ta-ja-no-vis-ta",
    "estajar": "es-ta-jar",
    "estajero": "es-ta-je-ro",
    "estajista": "es-ta-jis-ta",
    "estajo": "es-ta-jo",
    "estala": "es-ta-la",
    "estalación": "es-ta-la-ción",
    "estalactita": "es-ta-lac-ti-ta",
    "estalagmita": "es-ta-lag-mi-ta",
    "estalaje": "es-ta-la-je",
    "estaliniano": "es-ta-li-nia-no",
    "estalinismo": "es-ta-li-nis-mo",
    "estalinista": "es-ta-li-nis-ta",
    "estallante": "es-ta-llan-te",
    "estallar": "es-ta-llar",
    "estallido": "es-ta-lli-do",
    "estallo": "es-ta-llo",
    "estalo": "es-ta-lo",
    "estambrar": "es-tam-brar",
    "estambre": "es-tam-bre",
    "estameña": "es-ta-me-ña",
    "estameñete": "es-ta-me-ñe-te",
    "estamental": "es-ta-men-tal",
    "estamento": "es-ta-men-to",
    "estamiento": "es-ta-mien-to",
    "estaminal": "es-ta-mi-nal",
    "estamínea": "es-ta-mí-ne-a",
    "estamíneo": "es-ta-mí-ne-o",
    "estaminífera": "es-ta-mi-ní-fe-ra",
    "estaminífero": "es-ta-mi-ní-fe-ro",
    "estampa": "es-tam-pa",
    "estampación": "es-tam-pa-ción",
    "estampada": "es-tam-pa-da",
    "estampado": "es-tam-pa-do",
    "estampador": "es-tam-pa-dor",
    "estampadora": "es-tam-pa-do-ra",
    "estampar": "es-tam-par",
    "estampera": "es-tam-pe-ra",
    "estampería": "es-tam-pe-rí-a",
    "estampero": "es-tam-pe-ro",
    "estampía": "es-tam-pí-a",
    "estampida": "es-tam-pi-da",
    "estampido": "es-tam-pi-do",
    "estampilla": "es-tam-pi-lla",
    "estampillada": "es-tam-pi-lla-da",
    "estampillado": "es-tam-pi-lla-do",
    "estampillar": "es-tam-pi-llar",
    "estampita": "es-tam-pi-ta",
    "estañado": "es-ta-ña-do",
    "estañador": "es-ta-ña-dor",
    "estañadura": "es-ta-ña-du-ra",
    "estañar": "es-ta-ñar",
    "estanca": "es-tan-ca",
    "estancación": "es-tan-ca-ción",
    "estancada": "es-tan-ca-da",
    "estancado": "es-tan-ca-do",
    "estancamiento": "es-tan-ca-mien-to",
    "estancar": "es-tan-car",
    "estancia": "es-tan-cia",
    "estanciera": "es-tan-cie-ra",
    "estanciero": "es-tan-cie-ro",
    "estanco": "es-tan-co",
    "estand": "es-tand",
    "estándar": "es-tán-dar",
    "estandardización": "es-tan-dar-di-za-ción",
    "estandardizar": "es-tan-dar-di-zar",
    "estandarización": "es-tan-da-ri-za-ción",
    "estandarizado": "es-tan-da-ri-za-do",
    "estandarizar": "es-tan-da-ri-zar",
    "estandarte": "es-tan-dar-te",
    "estandorio": "es-tan-do-rio",
    "estañero": "es-ta-ñe-ro",
    "estanflación": "es-tan-fla-ción",
    "estangurria": "es-tan-gu-rria",
    "estannífera": "es-tan-ní-fe-ra",
    "estannífero": "es-tan-ní-fe-ro",
    "estaño": "es-ta-ño",
    "estañón": "es-ta-ñón",
    "estanque": "es-tan-que",
    "estanqueidad": "es-tan-quei-dad",
    "estanquera": "es-tan-que-ra",
    "estanquero": "es-tan-que-ro",
    "estanquidad": "es-tan-qui-dad",
    "estanquillera": "es-tan-qui-lle-ra",
    "estanquillero": "es-tan-qui-lle-ro",
    "estanquillo": "es-tan-qui-llo",
    "estantal": "es-tan-tal",
    "estantalar": "es-tan-ta-lar",
    "estante": "es-tan-te",
    "estantería": "es-tan-te-rí-a",
    "estantía": "es-tan-tí-a",
    "estantigua": "es-tan-ti-gua",
    "estantillo": "es-tan-ti-llo",
    "estantío": "es-tan-tí-o",
    "estanza": "es-tan-za",
    "estaqueadero": "es-ta-que-a-de-ro",
    "estaqueador": "es-ta-que-a-dor",
    "estaquear": "es-ta-que-ar",
    "estaqueo": "es-ta-que-o",
    "estaquero": "es-ta-que-ro",
    "estaquilla": "es-ta-qui-lla",
    "estaquillador": "es-ta-qui-lla-dor",
    "estaquillar": "es-ta-qui-llar",
    "estar": "es-tar",
    "estarcido": "es-tar-ci-do",
    "estarcir": "es-tar-cir",
    "estarna": "es-tar-na",
    "estárter": "es-tár-ter",
    "estasis": "es-ta-sis",
    "estatal": "es-ta-tal",
    "estatalismo": "es-ta-ta-lis-mo",
    "estatalización": "es-ta-ta-li-za-ción",
    "estatalizado": "es-ta-ta-li-za-do",
    "estatalizar": "es-ta-ta-li-zar",
    "estatera": "es-ta-te-ra",
    "estática": "es-tá-ti-ca",
    "estático": "es-tá-ti-co",
    "estatificación": "es-ta-ti-fi-ca-ción",
    "estatificar": "es-ta-ti-fi-car",
    "estatismo": "es-ta-tis-mo",
    "estatista": "es-ta-tis-ta",
    "estativo": "es-ta-ti-vo",
    "estatizar": "es-ta-ti-zar",
    "estatocisto": "es-ta-to-cis-to",
    "estatolito": "es-ta-to-li-to",
    "estátor": "es-tá-tor",
    "estatua": "es-ta-tua",
    "estatuar": "es-ta-tuar",
    "estatuaria": "es-ta-tua-ria",
    "estatuario": "es-ta-tua-rio",
    "estatúder": "es-ta-tú-der",
    "estatuderato": "es-ta-tu-de-ra-to",
    "estatuir": "es-ta-tuir",
    "estatura": "es-ta-tu-ra",
    "estatus": "es-ta-tus",
    "estatutaria": "es-ta-tu-ta-ria",
    "estatutario": "es-ta-tu-ta-rio",
    "estatuto": "es-ta-tu-to",
    "estay": "es-tay",
    "este": "es-te",
    "esteárico": "es-te-á-ri-co",
    "estearina": "es-te-a-ri-na",
    "esteatita": "es-te-a-ti-ta",
    "esteatosis": "es-te-a-to-sis",
    "esteba": "es-te-ba",
    "estebar": "es-te-bar",
    "estefanota": "es-te-fa-no-ta",
    "estefanote": "es-te-fa-no-te",
    "estegomía": "es-te-go-mí-a",
    "estegosaurio": "es-te-go-sau-rio",
    "estela": "es-te-la",
    "estelado": "es-te-la-do",
    "estelar": "es-te-lar",
    "estelaria": "es-te-la-ria",
    "esteliana": "es-te-lia-na",
    "esteliano": "es-te-lia-no",
    "estelífera": "es-te-lí-fe-ra",
    "estelífero": "es-te-lí-fe-ro",
    "esteliforme": "es-te-li-for-me",
    "estelión": "es-te-lión",
    "estelionato": "es-te-lio-na-to",
    "estellés": "es-te-llés",
    "estellesa": "es-te-lle-sa",
    "estelo": "es-te-lo",
    "estelón": "es-te-lón",
    "estema": "es-te-ma",
    "estemple": "es-tem-ple",
    "esteña": "es-te-ña",
    "estendijar": "es-ten-di-jar",
    "estendijarse": "es-ten-di-jar-se",
    "esteño": "es-te-ño",
    "estenocardia": "es-te-no-car-dia",
    "estenógrafa": "es-te-nó-gra-fa",
    "estenografía": "es-te-no-gra-fí-a",
    "estenografiar": "es-te-no-gra-fiar",
    "estenográfica": "es-te-no-grá-fi-ca",
    "estenográficamente": "es-te-no-grá-fi-ca-men-te",
    "estenográfico": "es-te-no-grá-fi-co",
    "estenógrafo": "es-te-nó-gra-fo",
    "estenordeste": "es-te-nor-des-te",
    "estenoreste": "es-te-no-res-te",
    "estenoroeste": "es-te-no-ro-es-te",
    "estenosis": "es-te-no-sis",
    "estenotipia": "es-te-no-ti-pia",
    "estenotipista": "es-te-no-ti-pis-ta",
    "estentórea": "es-ten-tó-re-a",
    "estentóreo": "es-ten-tó-re-o",
    "estepa": "es-te-pa",
    "estepar": "es-te-par",
    "esteparia": "es-te-pa-ria",
    "estepario": "es-te-pa-rio",
    "estepera": "es-te-pe-ra",
    "estepero": "es-te-pe-ro",
    "estepilla": "es-te-pi-lla",
    "ester": "es-ter",
    "éster": "és-ter",
    "estera": "es-te-ra",
    "esteral": "es-te-ral",
    "esterar": "es-te-rar",
    "estercar": "es-ter-car",
    "estercoladura": "es-ter-co-la-du-ra",
    "estercolamiento": "es-ter-co-la-mien-to",
    "estercolar": "es-ter-co-lar",
    "estercolero": "es-ter-co-le-ro",
    "estercoliza": "es-ter-co-li-za",
    "estercolizo": "es-ter-co-li-zo",
    "estercórea": "es-ter-có-re-a",
    "estercóreo": "es-ter-có-re-o",
    "estercuelo": "es-ter-cue-lo",
    "esterculiácea": "es-ter-cu-liá-ce-a",
    "esterculiáceo": "es-ter-cu-liá-ce-o",
    "estéreo": "es-té-re-o",
    "estereocomparador": "es-te-re-o-com-pa-ra-dor",
    "estereofonía": "es-te-re-o-fo-ní-a",
    "estereofónico": "es-te-re-o-fó-ni-co",
    "estereógrafa": "es-te-re-ó-gra-fa",
    "estereografía": "es-te-re-o-gra-fí-a",
    "estereográfica": "es-te-re-o-grá-fi-ca",
    "estereográfico": "es-te-re-o-grá-fi-co",
    "estereógrafo": "es-te-re-ó-gra-fo",
    "estereometría": "es-te-re-o-me-trí-a",
    "estereométrica": "es-te-re-o-mé-tri-ca",
    "estereométrico": "es-te-re-o-mé-tri-co",
    "estereomicroscopio": "es-te-re-o-mi-cros-co-pio",
    "estereoquímica": "es-te-re-o-quí-mi-ca",
    "estereorradián": "es-te-re-o-rra-dián",
    "estereoscopia": "es-te-re-os-co-pia",
    "estereoscópica": "es-te-re-os-có-pi-ca",
    "estereoscópico": "es-te-re-os-có-pi-co",
    "estereoscopio": "es-te-re-os-co-pio",
    "estereotipa": "es-te-re-o-ti-pa",
    "estereotipado": "es-te-re-o-ti-pa-do",
    "estereotipador": "es-te-re-o-ti-pa-dor",
    "estereotipadora": "es-te-re-o-ti-pa-do-ra",
    "estereotipar": "es-te-re-o-ti-par",
    "estereotipia": "es-te-re-o-ti-pia",
    "estereotípica": "es-te-re-o-tí-pi-ca",
    "estereotípico": "es-te-re-o-tí-pi-co",
    "estereotipo": "es-te-re-o-ti-po",
    "estereotomía": "es-te-re-o-to-mí-a",
    "esterera": "es-te-re-ra",
    "esterería": "es-te-re-rí-a",
    "esterero": "es-te-re-ro",
    "esterificación": "es-te-ri-fi-ca-ción",
    "esterificar": "es-te-ri-fi-car",
    "estéril": "es-té-ril",
    "esterilidad": "es-te-ri-li-dad",
    "esterilización": "es-te-ri-li-za-ción",
    "esterilizador": "es-te-ri-li-za-dor",
    "esterilizadora": "es-te-ri-li-za-do-ra",
    "esterilizar": "es-te-ri-li-zar",
    "esterilla": "es-te-ri-lla",
    "estérilmente": "es-té-ril-men-te",
    "esterlín": "es-ter-lín",
    "esterlina": "es-ter-li-na",
    "esternocleidomastoideo": "es-ter-no-clei-do-mas-toi-de-o",
    "esternón": "es-ter-nón",
    "estero": "es-te-ro",
    "esteroide": "es-te-roi-de",
    "esteroideo": "es-te-roi-de-o",
    "esteroídico": "es-te-ro-í-di-co",
    "esterol": "es-te-rol",
    "esterquero": "es-ter-que-ro",
    "esterquilinio": "es-ter-qui-li-nio",
    "estertor": "es-ter-tor",
    "estertóreo": "es-ter-tó-re-o",
    "estertorosa": "es-ter-to-ro-sa",
    "estertoroso": "es-ter-to-ro-so",
    "estesudeste": "es-te-su-des-te",
    "estesudoeste": "es-te-su-do-es-te",
    "estesureste": "es-te-su-res-te",
    "estesuroeste": "es-te-su-ro-es-te",
    "esteta": "es-te-ta",
    "estética": "es-té-ti-ca",
    "estéticamente": "es-té-ti-ca-men-te",
    "esteticismo": "es-te-ti-cis-mo",
    "esteticista": "es-te-ti-cis-ta",
    "estético": "es-té-ti-co",
    "estetoscopia": "es-te-tos-co-pia",
    "estetoscopio": "es-te-tos-co-pio",
    "esteva": "es-te-va",
    "estevada": "es-te-va-da",
    "estevado": "es-te-va-do",
    "estevón": "es-te-vón",
    "estezado": "es-te-za-do",
    "estezar": "es-te-zar",
    "esthéticienne": "es-thé-ti-cien-ne",
    "estiaje": "es-tia-je",
    "estiba": "es-ti-ba",
    "estibación": "es-ti-ba-ción",
    "estibador": "es-ti-ba-dor",
    "estibadora": "es-ti-ba-do-ra",
    "estibar": "es-ti-bar",
    "estibia": "es-ti-bia",
    "estibina": "es-ti-bi-na",
    "estibio": "es-ti-bio",
    "esticomitia": "es-ti-co-mi-tia",
    "esticomítico": "es-ti-co-mí-ti-co",
    "estierco": "es-tier-co",
    "estiércol": "es-tiér-col",
    "estigia": "es-ti-gia",
    "estigio": "es-ti-gio",
    "estigma": "es-tig-ma",
    "estigmatizador": "es-tig-ma-ti-za-dor",
    "estigmatizadora": "es-tig-ma-ti-za-do-ra",
    "estigmatizar": "es-tig-ma-ti-zar",
    "estil": "es-til",
    "estilar": "es-ti-lar",
    "estilete": "es-ti-le-te",
    "estiliano": "es-ti-lia-no",
    "estilicidio": "es-ti-li-ci-dio",
    "estilismo": "es-ti-lis-mo",
    "estilista": "es-ti-lis-ta",
    "estilística": "es-ti-lís-ti-ca",
    "estilístico": "es-ti-lís-ti-co",
    "estilita": "es-ti-li-ta",
    "estilización": "es-ti-li-za-ción",
    "estilizar": "es-ti-li-zar",
    "estilo": "es-ti-lo",
    "estilóbato": "es-ti-ló-ba-to",
    "estilográfica": "es-ti-lo-grá-fi-ca",
    "estilográfico": "es-ti-lo-grá-fi-co",
    "estilógrafo": "es-ti-ló-gra-fo",
    "estiloso": "es-ti-lo-so",
    "estima": "es-ti-ma",
    "estimabilidad": "es-ti-ma-bi-li-dad",
    "estimabilísimo": "es-ti-ma-bi-lí-si-mo",
    "estimable": "es-ti-ma-ble",
    "estimación": "es-ti-ma-ción",
    "estimador": "es-ti-ma-dor",
    "estimadora": "es-ti-ma-do-ra",
    "estimar": "es-ti-mar",
    "estimativa": "es-ti-ma-ti-va",
    "estimativo": "es-ti-ma-ti-vo",
    "estimatoria": "es-ti-ma-to-ria",
    "estimatorio": "es-ti-ma-to-rio",
    "estimulación": "es-ti-mu-la-ción",
    "estimulador": "es-ti-mu-la-dor",
    "estimuladora": "es-ti-mu-la-do-ra",
    "estimulante": "es-ti-mu-lan-te",
    "estimular": "es-ti-mu-lar",
    "estímulo": "es-tí-mu-lo",
    "estimulosa": "es-ti-mu-lo-sa",
    "estimuloso": "es-ti-mu-lo-so",
    "estinco": "es-tin-co",
    "estío": "es-tí-o",
    "estiomenar": "es-tio-me-nar",
    "estiómeno": "es-tió-me-no",
    "estipendial": "es-ti-pen-dial",
    "estipendiar": "es-ti-pen-diar",
    "estipendiario": "es-ti-pen-dia-rio",
    "estipendio": "es-ti-pen-dio",
    "estípite": "es-tí-pi-te",
    "estíptica": "es-típ-ti-ca",
    "estipticar": "es-tip-ti-car",
    "estipticidad": "es-tip-ti-ci-dad",
    "estíptico": "es-típ-ti-co",
    "estiptiquez": "es-tip-ti-quez",
    "estípula": "es-tí-pu-la",
    "estipulación": "es-ti-pu-la-ción",
    "estipulado": "es-ti-pu-la-do",
    "estipular": "es-ti-pu-lar",
    "estique": "es-ti-que",
    "estiquirín": "es-ti-qui-rín",
    "estira": "es-ti-ra",
    "estiracácea": "es-ti-ra-cá-ce-a",
    "estiracáceo": "es-ti-ra-cá-ce-o",
    "estirada": "es-ti-ra-da",
    "estiradamente": "es-ti-ra-da-men-te",
    "estirado": "es-ti-ra-do",
    "estirajar": "es-ti-ra-jar",
    "estirajón": "es-ti-ra-jón",
    "estiramiento": "es-ti-ra-mien-to",
    "estirar": "es-ti-rar",
    "estirazar": "es-ti-ra-zar",
    "estirazo": "es-ti-ra-zo",
    "estireno": "es-ti-re-no",
    "estirón": "es-ti-rón",
    "estirpe": "es-tir-pe",
    "estítica": "es-tí-ti-ca",
    "estítico": "es-tí-ti-co",
    "estitiquez": "es-ti-ti-quez",
    "estiva": "es-ti-va",
    "estivación": "es-ti-va-ción",
    "estivada": "es-ti-va-da",
    "estival": "es-ti-val",
    "estivo": "es-ti-vo",
    "esto": "es-to",
    "estocada": "es-to-ca-da",
    "estocafís": "es-to-ca-fís",
    "estocar": "es-to-car",
    "estocástica": "es-to-cás-ti-ca",
    "estocástico": "es-to-cás-ti-co",
    "estocolmense": "es-to-col-men-se",
    "estoconazo": "es-to-co-na-zo",
    "estofa": "es-to-fa",
    "estofada": "es-to-fa-da",
    "estofado": "es-to-fa-do",
    "estofador": "es-to-fa-dor",
    "estofadora": "es-to-fa-do-ra",
    "estofar": "es-to-far",
    "estofo": "es-to-fo",
    "estofón": "es-to-fón",
    "estoica": "es-toi-ca",
    "estoicamente": "es-toi-ca-men-te",
    "estoicismo": "es-toi-cis-mo",
    "estoico": "es-toi-co",
    "estol": "es-tol",
    "estola": "es-to-la",
    "estólida": "es-tó-li-da",
    "estolidez": "es-to-li-dez",
    "estólido": "es-tó-li-do",
    "estolón": "es-to-lón",
    "estoma": "es-to-ma",
    "estomacal": "es-to-ma-cal",
    "estomagante": "es-to-ma-gan-te",
    "estomagar": "es-to-ma-gar",
    "estómago": "es-tó-ma-go",
    "estomaguero": "es-to-ma-gue-ro",
    "estomática": "es-to-má-ti-ca",
    "estomatical": "es-to-ma-ti-cal",
    "estomático": "es-to-má-ti-co",
    "estomaticón": "es-to-ma-ti-cón",
    "estomatitis": "es-to-ma-ti-tis",
    "estomatóloga": "es-to-ma-tó-lo-ga",
    "estomatología": "es-to-ma-to-lo-gí-a",
    "estomatológico": "es-to-ma-to-ló-gi-co",
    "estomatólogo": "es-to-ma-tó-lo-go",
    "estomatópodo": "es-to-ma-tó-po-do",
    "estonce": "es-ton-ce",
    "estonces": "es-ton-ces",
    "estonia": "es-to-nia",
    "estoniana": "es-to-nia-na",
    "estoniano": "es-to-nia-no",
    "estonio": "es-to-nio",
    "estopa": "es-to-pa",
    "estopada": "es-to-pa-da",
    "estopeña": "es-to-pe-ña",
    "estopeño": "es-to-pe-ño",
    "estoperol": "es-to-pe-rol",
    "estopilla": "es-to-pi-lla",
    "estopín": "es-to-pín",
    "estopón": "es-to-pón",
    "estopor": "es-to-por",
    "estoposa": "es-to-po-sa",
    "estoposo": "es-to-po-so",
    "estoque": "es-to-que",
    "estoqueador": "es-to-que-a-dor",
    "estoqueadora": "es-to-que-a-do-ra",
    "estoquear": "es-to-que-ar",
    "estoqueo": "es-to-que-o",
    "estoquillo": "es-to-qui-llo",
    "estor": "es-tor",
    "estora": "es-to-ra",
    "estoraque": "es-to-ra-que",
    "estorbador": "es-tor-ba-dor",
    "estorbadora": "es-tor-ba-do-ra",
    "estorbar": "es-tor-bar",
    "estorbo": "es-tor-bo",
    "estorbosa": "es-tor-bo-sa",
    "estorboso": "es-tor-bo-so",
    "estorcer": "es-tor-cer",
    "estorcimiento": "es-tor-ci-mien-to",
    "estordida": "es-tor-di-da",
    "estordido": "es-tor-di-do",
    "estórdiga": "es-tór-di-ga",
    "estordir": "es-tor-dir",
    "estornija": "es-tor-ni-ja",
    "estornino": "es-tor-ni-no",
    "estornudar": "es-tor-nu-dar",
    "estornudo": "es-tor-nu-do",
    "estornutatoria": "es-tor-nu-ta-to-ria",
    "estornutatorio": "es-tor-nu-ta-to-rio",
    "estortillar": "es-tor-ti-llar",
    "estos": "es-tos",
    "estotra": "es-to-tra",
    "estotro": "es-to-tro",
    "estovaína": "es-to-va-í-na",
    "estovar": "es-to-var",
    "estozar": "es-to-zar",
    "estozolar": "es-to-zo-lar",
    "estrábica": "es-trá-bi-ca",
    "estrábico": "es-trá-bi-co",
    "estrabismo": "es-tra-bis-mo",
    "estrabón": "es-tra-bón",
    "estracilla": "es-tra-ci-lla",
    "estrada": "es-tra-da",
    "estradiota": "es-tra-dio-ta",
    "estradiote": "es-tra-dio-te",
    "estrado": "es-tra-do",
    "estrafalaria": "es-tra-fa-la-ria",
    "estrafalariamente": "es-tra-fa-la-ria-men-te",
    "estrafalario": "es-tra-fa-la-rio",
    "estragadamente": "es-tra-ga-da-men-te",
    "estragador": "es-tra-ga-dor",
    "estragadora": "es-tra-ga-do-ra",
    "estragal": "es-tra-gal",
    "estragamiento": "es-tra-ga-mien-to",
    "estragar": "es-tra-gar",
    "estrago": "es-tra-go",
    "estragón": "es-tra-gón",
    "estral": "es-tral",
    "estrambólico": "es-tram-bó-li-co",
    "estrambote": "es-tram-bo-te",
    "estrambótica": "es-tram-bó-ti-ca",
    "estrambóticamente": "es-tram-bó-ti-ca-men-te",
    "estrambótico": "es-tram-bó-ti-co",
    "estramonio": "es-tra-mo-nio",
    "estrangol": "es-tran-gol",
    "estranguadera": "es-tran-gua-de-ra",
    "estrangul": "es-tran-gul",
    "estrangulación": "es-tran-gu-la-ción",
    "estrangulador": "es-tran-gu-la-dor",
    "estranguladora": "es-tran-gu-la-do-ra",
    "estrangulamiento": "es-tran-gu-la-mien-to",
    "estrangular": "es-tran-gu-lar",
    "estranguria": "es-tran-gu-ria",
    "estrapada": "es-tra-pa-da",
    "estrapajar": "es-tra-pa-jar",
    "estrapalucio": "es-tra-pa-lu-cio",
    "estraperlear": "es-tra-per-le-ar",
    "estraperlismo": "es-tra-per-lis-mo",
    "estraperlista": "es-tra-per-lis-ta",
    "estraperlo": "es-tra-per-lo",
    "estrapontín": "es-tra-pon-tín",
    "estratagema": "es-tra-ta-ge-ma",
    "estratega": "es-tra-te-ga",
    "estrategia": "es-tra-te-gia",
    "estratégica": "es-tra-té-gi-ca",
    "estratégicamente": "es-tra-té-gi-ca-men-te",
    "estratégico": "es-tra-té-gi-co",
    "estratego": "es-tra-te-go",
    "estratificación": "es-tra-ti-fi-ca-ción",
    "estratificar": "es-tra-ti-fi-car",
    "estratigrafía": "es-tra-ti-gra-fí-a",
    "estratigráfica": "es-tra-ti-grá-fi-ca",
    "estratigráfico": "es-tra-ti-grá-fi-co",
    "estrato": "es-tra-to",
    "estratocúmulo": "es-tra-to-cú-mu-lo",
    "estratonimbo": "es-tra-to-nim-bo",
    "estratopausa": "es-tra-to-pau-sa",
    "estratosfera": "es-tra-tos-fe-ra",
    "estratósfera": "es-tra-tós-fe-ra",
    "estratosférico": "es-tra-tos-fé-ri-co",
    "estrave": "es-tra-ve",
    "estraza": "es-tra-za",
    "estrazar": "es-tra-zar",
    "estrazo": "es-tra-zo",
    "estrecha": "es-tre-cha",
    "estrechadura": "es-tre-cha-du-ra",
    "estrechamente": "es-tre-cha-men-te",
    "estrechamiento": "es-tre-cha-mien-to",
    "estrechar": "es-tre-char",
    "estrechez": "es-tre-chez",
    "estrecheza": "es-tre-che-za",
    "estrecho": "es-tre-cho",
    "estrechón": "es-tre-chón",
    "estrechura": "es-tre-chu-ra",
    "estregadera": "es-tre-ga-de-ra",
    "estregadero": "es-tre-ga-de-ro",
    "estregadura": "es-tre-ga-du-ra",
    "estregamiento": "es-tre-ga-mien-to",
    "estregar": "es-tre-gar",
    "estregón": "es-tre-gón",
    "estrella": "es-tre-lla",
    "estrellada": "es-tre-lla-da",
    "estrelladera": "es-tre-lla-de-ra",
    "estrelladero": "es-tre-lla-de-ro",
    "estrellado": "es-tre-lla-do",
    "estrellamar": "es-tre-lla-mar",
    "estrellamiento": "es-tre-lla-mien-to",
    "estrellar": "es-tre-llar",
    "estrellato": "es-tre-lla-to",
    "estrellera": "es-tre-lle-ra",
    "estrellería": "es-tre-lle-rí-a",
    "estrellero": "es-tre-lle-ro",
    "estrellón": "es-tre-llón",
    "estrelluela": "es-tre-llue-la",
    "estremecedor": "es-tre-me-ce-dor",
    "estremecedora": "es-tre-me-ce-do-ra",
    "estremecer": "es-tre-me-cer",
    "estremecimiento": "es-tre-me-ci-mien-to",
    "estremezón": "es-tre-me-zón",
    "estrena": "es-tre-na",
    "estrenar": "es-tre-nar",
    "estreñida": "es-tre-ñi-da",
    "estreñido": "es-tre-ñi-do",
    "estreñimiento": "es-tre-ñi-mien-to",
    "estreñir": "es-tre-ñir",
    "estrenista": "es-tre-nis-ta",
    "estreno": "es-tre-no",
    "estrenque": "es-tren-que",
    "estrenua": "es-tre-nua",
    "estrenuidad": "es-tre-nui-dad",
    "estrenuo": "es-tre-nuo",
    "estrepa": "es-tre-pa",
    "estrepada": "es-tre-pa-da",
    "estrépito": "es-tré-pi-to",
    "estrepitosa": "es-tre-pi-to-sa",
    "estrepitosamente": "es-tre-pi-to-sa-men-te",
    "estrepitoso": "es-tre-pi-to-so",
    "estreptococia": "es-trep-to-co-cia",
    "estreptocócica": "es-trep-to-có-ci-ca",
    "estreptocócico": "es-trep-to-có-ci-co",
    "estreptococo": "es-trep-to-co-co",
    "estreptomicina": "es-trep-to-mi-ci-na",
    "estrés": "es-trés",
    "estresado": "es-tre-sa-do",
    "estresante": "es-tre-san-te",
    "estresar": "es-tre-sar",
    "estría": "es-trí-a",
    "estriación": "es-tria-ción",
    "estriado": "es-tria-do",
    "estriar": "es-triar",
    "estribación": "es-tri-ba-ción",
    "estribadero": "es-tri-ba-de-ro",
    "estribador": "es-tri-ba-dor",
    "estribadora": "es-tri-ba-do-ra",
    "estribadura": "es-tri-ba-du-ra",
    "estribar": "es-tri-bar",
    "estribera": "es-tri-be-ra",
    "estribería": "es-tri-be-rí-a",
    "estribero": "es-tri-be-ro",
    "estriberón": "es-tri-be-rón",
    "estribillo": "es-tri-bi-llo",
    "estribo": "es-tri-bo",
    "estribor": "es-tri-bor",
    "estribote": "es-tri-bo-te",
    "estricar": "es-tri-car",
    "estricarse": "es-tri-car-se",
    "estricia": "es-tri-cia",
    "estricnina": "es-tric-ni-na",
    "estricote": "es-tri-co-te",
    "estricta": "es-tric-ta",
    "estrictamente": "es-tric-ta-men-te",
    "estrictez": "es-tric-tez",
    "estricto": "es-tric-to",
    "estridencia": "es-tri-den-cia",
    "estridente": "es-tri-den-te",
    "estridor": "es-tri-dor",
    "estridular": "es-tri-du-lar",
    "estriga": "es-tri-ga",
    "estrige": "es-tri-ge",
    "estrigiforme": "es-tri-gi-for-me",
    "estrígil": "es-trí-gil",
    "estriladera": "es-tri-la-de-ra",
    "estrillar": "es-tri-llar",
    "estringa": "es-trin-ga",
    "estrinque": "es-trin-que",
    "estripar": "es-tri-par",
    "estro": "es-tro",
    "estróbilo": "es-tró-bi-lo",
    "estrobo": "es-tro-bo",
    "estroboscópico": "es-tro-bos-có-pi-co",
    "estroboscopio": "es-tro-bos-co-pio",
    "estrofa": "es-tro-fa",
    "estrofanto": "es-tro-fan-to",
    "estrófica": "es-tró-fi-ca",
    "estrófico": "es-tró-fi-co",
    "estrógeno": "es-tró-ge-no",
    "estrolar": "es-tro-lar",
    "estroma": "es-tro-ma",
    "estronciana": "es-tron-cia-na",
    "estroncianita": "es-tron-cia-ni-ta",
    "estroncio": "es-tron-cio",
    "estropajear": "es-tro-pa-je-ar",
    "estropajeo": "es-tro-pa-je-o",
    "estropajo": "es-tro-pa-jo",
    "estropajosa": "es-tro-pa-jo-sa",
    "estropajosamente": "es-tro-pa-jo-sa-men-te",
    "estropajoso": "es-tro-pa-jo-so",
    "estropear": "es-tro-pe-ar",
    "estropeo": "es-tro-pe-o",
    "estropezar": "es-tro-pe-zar",
    "estropezón": "es-tro-pe-zón",
    "estropicio": "es-tro-pi-cio",
    "estropiezo": "es-tro-pie-zo",
    "estrucioniforme": "es-tru-cio-ni-for-me",
    "estructura": "es-truc-tu-ra",
    "estructuración": "es-truc-tu-ra-ción",
    "estructural": "es-truc-tu-ral",
    "estructuralismo": "es-truc-tu-ra-lis-mo",
    "estructuralista": "es-truc-tu-ra-lis-ta",
    "estructurante": "es-truc-tu-ran-te",
    "estructurar": "es-truc-tu-rar",
    "estruendo": "es-truen-do",
    "estruendosa": "es-truen-do-sa",
    "estruendosamente": "es-truen-do-sa-men-te",
    "estruendoso": "es-truen-do-so",
    "estrujador": "es-tru-ja-dor",
    "estrujadora": "es-tru-ja-do-ra",
    "estrujadura": "es-tru-ja-du-ra",
    "estrujamiento": "es-tru-ja-mien-to",
    "estrujar": "es-tru-jar",
    "estrujón": "es-tru-jón",
    "estruma": "es-tru-ma",
    "estrumpido": "es-trum-pi-do",
    "estrumpir": "es-trum-pir",
    "estrupar": "es-tru-par",
    "estrupo": "es-tru-po",
    "estuación": "es-tua-ción",
    "estuante": "es-tuan-te",
    "estuario": "es-tua-rio",
    "estucado": "es-tu-ca-do",
    "estucador": "es-tu-ca-dor",
    "estucadora": "es-tu-ca-do-ra",
    "estucar": "es-tu-car",
    "estuchado": "es-tu-cha-do",
    "estuchar": "es-tu-char",
    "estuche": "es-tu-che",
    "estuchería": "es-tu-che-rí-a",
    "estuchista": "es-tu-chis-ta",
    "estuco": "es-tu-co",
    "estucurú": "es-tu-cu-rú",
    "estudiado": "es-tu-dia-do",
    "estudiador": "es-tu-dia-dor",
    "estudiadora": "es-tu-dia-do-ra",
    "estudiantado": "es-tu-dian-ta-do",
    "estudiante": "es-tu-dian-te",
    "estudiantil": "es-tu-dian-til",
    "estudiantina": "es-tu-dian-ti-na",
    "estudiantino": "es-tu-dian-ti-no",
    "estudiantón": "es-tu-dian-tón",
    "estudiantona": "es-tu-dian-to-na",
    "estudiar": "es-tu-diar",
    "estudio": "es-tu-dio",
    "estudiosa": "es-tu-dio-sa",
    "estudiosamente": "es-tu-dio-sa-men-te",
    "estudiosidad": "es-tu-dio-si-dad",
    "estudioso": "es-tu-dio-so",
    "estufa": "es-tu-fa",
    "estufador": "es-tu-fa-dor",
    "estufar": "es-tu-far",
    "estufera": "es-tu-fe-ra",
    "estufero": "es-tu-fe-ro",
    "estufido": "es-tu-fi-do",
    "estufilla": "es-tu-fi-lla",
    "estufista": "es-tu-fis-ta",
    "estulta": "es-tul-ta",
    "estultamente": "es-tul-ta-men-te",
    "estulticia": "es-tul-ti-cia",
    "estulto": "es-tul-to",
    "estuosa": "es-tuo-sa",
    "estuosidad": "es-tuo-si-dad",
    "estuoso": "es-tuo-so",
    "estupa": "es-tu-pa",
    "estupefacción": "es-tu-pe-fac-ción",
    "estupefaciente": "es-tu-pe-fa-cien-te",
    "estupefacta": "es-tu-pe-fac-ta",
    "estupefactiva": "es-tu-pe-fac-ti-va",
    "estupefactivo": "es-tu-pe-fac-ti-vo",
    "estupefacto": "es-tu-pe-fac-to",
    "estupenda": "es-tu-pen-da",
    "estupendamente": "es-tu-pen-da-men-te",
    "estupendo": "es-tu-pen-do",
    "estúpida": "es-tú-pi-da",
    "estúpidamente": "es-tú-pi-da-men-te",
    "estupidez": "es-tu-pi-dez",
    "estúpido": "es-tú-pi-do",
    "estupor": "es-tu-por",
    "estuprador": "es-tu-pra-dor",
    "estuprar": "es-tu-prar",
    "estupro": "es-tu-pro",
    "estuque": "es-tu-que",
    "estuquería": "es-tu-que-rí-a",
    "estuquista": "es-tu-quis-ta",
    "esturada": "es-tu-ra-da",
    "esturado": "es-tu-ra-do",
    "esturar": "es-tu-rar",
    "esturdir": "es-tur-dir",
    "esturgar": "es-tur-gar",
    "esturión": "es-tu-rión",
    "esturrear": "es-tu-rre-ar",
    "ésula": "é-su-la",
    "esvarar": "es-va-rar",
    "esvarón": "es-va-rón",
    "esvástica": "es-vás-ti-ca",
    "esviaje": "es-via-je",
    "eta": "e-ta",
    "etalaje": "e-ta-la-je",
    "etamina": "e-ta-mi-na",
    "etano": "e-ta-no",
    "etanoico": "e-ta-noi-co",
    "etanol": "e-ta-nol",
    "etapa": "e-ta-pa",
    "etario": "e-ta-rio",
    "etarra": "e-ta-rra",
    "etcétera": "et-cé-te-ra",
    "eteno": "e-te-no",
    "éter": "é-ter",
    "etérea": "e-té-re-a",
    "etéreo": "e-té-re-o",
    "eterio": "e-te-rio",
    "eterismo": "e-te-ris-mo",
    "eterización": "e-te-ri-za-ción",
    "eterizar": "e-te-ri-zar",
    "eterna": "e-ter-na",
    "eternal": "e-ter-nal",
    "eternalmente": "e-ter-nal-men-te",
    "eternamente": "e-ter-na-men-te",
    "eternidad": "e-ter-ni-dad",
    "eternizable": "e-ter-ni-za-ble",
    "eternizar": "e-ter-ni-zar",
    "eterno": "e-ter-no",
    "eteromanía": "e-te-ro-ma-ní-a",
    "etesio": "e-te-sio",
    "ética": "é-ti-ca",
    "eticidad": "e-ti-ci-dad",
    "ético": "é-ti-co",
    "etileno": "e-ti-le-no",
    "etílico": "e-tí-li-co",
    "etilismo": "e-ti-lis-mo",
    "etilo": "e-ti-lo",
    "étimo": "é-ti-mo",
    "etimóloga": "e-ti-mó-lo-ga",
    "etimología": "e-ti-mo-lo-gí-a",
    "etimológica": "e-ti-mo-ló-gi-ca",
    "etimológicamente": "e-ti-mo-ló-gi-ca-men-te",
    "etimológico": "e-ti-mo-ló-gi-co",
    "etimologista": "e-ti-mo-lo-gis-ta",
    "etimologizar": "e-ti-mo-lo-gi-zar",
    "etimólogo": "e-ti-mó-lo-go",
    "etino": "e-ti-no",
    "etiología": "e-tio-lo-gí-a",
    "etiológica": "e-tio-ló-gi-ca",
    "etiológico": "e-tio-ló-gi-co",
    "etíope": "e-tí-o-pe",
    "etiopía": "e-tio-pí-a",
    "etiopia": "e-tio-pia",
    "etiopiana": "e-tio-pia-na",
    "etiopiano": "e-tio-pia-no",
    "etiópica": "e-tió-pi-ca",
    "etiópico": "e-tió-pi-co",
    "etiopio": "e-tio-pio",
    "etiqueta": "e-ti-que-ta",
    "etiquetado": "e-ti-que-ta-do",
    "etiquetaje": "e-ti-que-ta-je",
    "etiquetar": "e-ti-que-tar",
    "etiquetera": "e-ti-que-te-ra",
    "etiquetero": "e-ti-que-te-ro",
    "etiquez": "e-ti-quez",
    "etites": "e-ti-tes",
    "etmoidal": "et-moi-dal",
    "etmoides": "et-moi-des",
    "etnea": "et-ne-a",
    "etneo": "et-ne-o",
    "etnia": "et-nia",
    "étnica": "ét-ni-ca",
    "étnico": "ét-ni-co",
    "etnobotánica": "et-no-bo-tá-ni-ca",
    "etnobotánico": "et-no-bo-tá-ni-co",
    "etnocéntrico": "et-no-cén-tri-co",
    "etnocentrismo": "et-no-cen-tris-mo",
    "etnocida": "et-no-ci-da",
    "etnocidio": "et-no-ci-dio",
    "etnógrafa": "et-nó-gra-fa",
    "etnografía": "et-no-gra-fí-a",
    "etnográfica": "et-no-grá-fi-ca",
    "etnográfico": "et-no-grá-fi-co",
    "etnógrafo": "et-nó-gra-fo",
    "etnolingüística": "et-no-lin-güís-ti-ca",
    "etnóloga": "et-nó-lo-ga",
    "etnología": "et-no-lo-gí-a",
    "etnológica": "et-no-ló-gi-ca",
    "etnológico": "et-no-ló-gi-co",
    "etnólogo": "et-nó-lo-go",
    "etola": "e-to-la",
    "etolia": "e-to-lia",
    "etolio": "e-to-lio",
    "etolo": "e-to-lo",
    "etóloga": "e-tó-lo-ga",
    "etología": "e-to-lo-gí-a",
    "etológico": "e-to-ló-gi-co",
    "etólogo": "e-tó-lo-go",
    "etopeya": "e-to-pe-ya",
    "etrusca": "e-trus-ca",
    "etrusco": "e-trus-co",
    "etusa": "e-tu-sa",
    "eubea": "eu-be-a",
    "eubeo": "eu-be-o",
    "euboica": "eu-boi-ca",
    "euboico": "eu-boi-co",
    "eubolia": "eu-bo-lia",
    "eucaliptal": "eu-ca-lip-tal",
    "eucalipto": "eu-ca-lip-to",
    "eucaliptus": "eu-ca-lip-tus",
    "eucarionte": "eu-ca-rion-te",
    "eucariota": "eu-ca-rio-ta",
    "eucariótico": "eu-ca-rió-ti-co",
    "eucaristía": "eu-ca-ris-tí-a",
    "eucarística": "eu-ca-rís-ti-ca",
    "eucarístico": "eu-ca-rís-ti-co",
    "euclidiana": "eu-cli-dia-na",
    "euclidiano": "eu-cli-dia-no",
    "eucologio": "eu-co-lo-gio",
    "eucrática": "eu-crá-ti-ca",
    "eucrático": "eu-crá-ti-co",
    "eudemonía": "eu-de-mo-ní-a",
    "eudemonismo": "eu-de-mo-nis-mo",
    "eudiometría": "eu-dio-me-trí-a",
    "eudiómetro": "eu-dió-me-tro",
    "eufemismo": "eu-fe-mis-mo",
    "eufemística": "eu-fe-mís-ti-ca",
    "eufemístico": "eu-fe-mís-ti-co",
    "eufonía": "eu-fo-ní-a",
    "eufónica": "eu-fó-ni-ca",
    "eufónico": "eu-fó-ni-co",
    "eufonio": "eu-fo-nio",
    "euforbiácea": "eu-for-biá-ce-a",
    "euforbiáceo": "eu-for-biá-ce-o",
    "euforbio": "eu-for-bio",
    "euforia": "eu-fo-ria",
    "eufórica": "eu-fó-ri-ca",
    "eufórico": "eu-fó-ri-co",
    "euforizante": "eu-fo-ri-zan-te",
    "eufótida": "eu-fó-ti-da",
    "eufrasia": "eu-fra-sia",
    "eugenesia": "eu-ge-ne-sia",
    "eugenésica": "eu-ge-né-si-ca",
    "eugenésico": "eu-ge-né-si-co",
    "eugeosinclinal": "eu-ge-o-sin-cli-nal",
    "eunuco": "eu-nu-co",
    "eupatorio": "eu-pa-to-rio",
    "eupepsia": "eu-pep-sia",
    "eupéptica": "eu-pép-ti-ca",
    "eupéptico": "eu-pép-ti-co",
    "eurasiática": "eu-ra-siá-ti-ca",
    "eurasiático": "eu-ra-siá-ti-co",
    "eureka": "eu-re-ka",
    "euripo": "eu-ri-po",
    "euritmia": "eu-rit-mia",
    "eurítmica": "eu-rít-mi-ca",
    "eurítmico": "eu-rít-mi-co",
    "euro": "eu-ro",
    "euroasiática": "eu-ro-a-siá-ti-ca",
    "euroasiático": "eu-ro-a-siá-ti-co",
    "eurobono": "eu-ro-bo-no",
    "eurocentrismo": "eu-ro-cen-tris-mo",
    "eurocheque": "eu-ro-che-que",
    "eurocomunismo": "eu-ro-co-mu-nis-mo",
    "eurocomunista": "eu-ro-co-mu-nis-ta",
    "euroconector": "eu-ro-co-nec-tor",
    "eurocracia": "eu-ro-cra-cia",
    "eurócrata": "eu-ró-cra-ta",
    "eurodiputada": "eu-ro-di-pu-ta-da",
    "eurodiputado": "eu-ro-di-pu-ta-do",
    "eurodivisa": "eu-ro-di-vi-sa",
    "eurodólar": "eu-ro-dó-lar",
    "euroescéptica": "eu-ro-es-cép-ti-ca",
    "euroescepticismo": "eu-ro-es-cep-ti-cis-mo",
    "euroescéptico": "eu-ro-es-cép-ti-co",
    "europa": "eu-ro-pa",
    "europarlamentaria": "eu-ro-par-la-men-ta-ria",
    "europarlamentario": "eu-ro-par-la-men-ta-rio",
    "europea": "eu-ro-pe-a",
    "europeidad": "eu-ro-pei-dad",
    "europeísmo": "eu-ro-pe-ís-mo",
    "europeísta": "eu-ro-pe-ís-ta",
    "europeización": "eu-ro-pei-za-ción",
    "europeizante": "eu-ro-pei-zan-te",
    "europeizar": "eu-ro-pei-zar",
    "europeo": "eu-ro-pe-o",
    "europio": "eu-ro-pio",
    "eurotúnel": "eu-ro-tú-nel",
    "euroventanilla": "eu-ro-ven-ta-ni-lla",
    "eurovisión": "eu-ro-vi-sión",
    "eurritmia": "eu-rrit-mia",
    "euscaldún": "eus-cal-dún",
    "euscalduna": "eus-cal-du-na",
    "éuscara": "éus-ca-ra",
    "éuscaro": "éus-ca-ro",
    "euskaldún": "eus-kal-dún",
    "euskalduna": "eus-kal-du-na",
    "euskaldunización": "eus-kal-du-ni-za-ción",
    "euskera": "eus-ke-ra",
    "eusquera": "eus-que-ra",
    "eusquérico": "eus-qué-ri-co",
    "eustaquio": "eus-ta-quio",
    "éustilo": "éus-ti-lo",
    "eutanasia": "eu-ta-na-sia",
    "eutanásico": "eu-ta-ná-si-co",
    "eutéctico": "eu-téc-ti-co",
    "euterio": "eu-te-rio",
    "eutiquiana": "eu-ti-quia-na",
    "eutiquianismo": "eu-ti-quia-nis-mo",
    "eutiquiano": "eu-ti-quia-no",
    "eutocia": "eu-to-cia",
    "eutócico": "eu-tó-ci-co",
    "eutrapelia": "eu-tra-pe-lia",
    "eutrapélica": "eu-tra-pé-li-ca",
    "eutrapélico": "eu-tra-pé-li-co",
    "eutrofia": "eu-tro-fia",
    "eutrófico": "eu-tró-fi-co",
    "eutrofización": "eu-tro-fi-za-ción",
    "eutrofizar": "eu-tro-fi-zar",
    "eutropelia": "eu-tro-pe-lia",
    "eutropélica": "eu-tro-pé-li-ca",
    "eutropélico": "eu-tro-pé-li-co",
    "evacuación": "e-va-cua-ción",
    "evacuada": "e-va-cua-da",
    "evacuado": "e-va-cua-do",
    "evacuante": "e-va-cuan-te",
    "evacuar": "e-va-cuar",
    "evacuativa": "e-va-cua-ti-va",
    "evacuativo": "e-va-cua-ti-vo",
    "evacuatoria": "e-va-cua-to-ria",
    "evacuatorio": "e-va-cua-to-rio",
    "evadir": "e-va-dir",
    "evagación": "e-va-ga-ción",
    "evaginación": "e-va-gi-na-ción",
    "evaluación": "e-va-lua-ción",
    "evaluador": "e-va-lua-dor",
    "evaluadora": "e-va-lua-do-ra",
    "evaluar": "e-va-luar",
    "evanecer": "e-va-ne-cer",
    "evanescencia": "e-va-nes-cen-cia",
    "evanescente": "e-va-nes-cen-te",
    "evanescer": "e-va-nes-cer",
    "evangeliario": "e-van-ge-lia-rio",
    "evangélica": "e-van-gé-li-ca",
    "evangélicamente": "e-van-gé-li-ca-men-te",
    "evangélico": "e-van-gé-li-co",
    "evangelio": "e-van-ge-lio",
    "evangelista": "e-van-ge-lis-ta",
    "evangelistero": "e-van-ge-lis-te-ro",
    "evangelización": "e-van-ge-li-za-ción",
    "evangelizador": "e-van-ge-li-za-dor",
    "evangelizadora": "e-van-ge-li-za-do-ra",
    "evangelizar": "e-van-ge-li-zar",
    "evaporable": "e-va-po-ra-ble",
    "evaporación": "e-va-po-ra-ción",
    "evaporado": "e-va-po-ra-do",
    "evaporador": "e-va-po-ra-dor",
    "evaporar": "e-va-po-rar",
    "evaporatoria": "e-va-po-ra-to-ria",
    "evaporatorio": "e-va-po-ra-to-rio",
    "evaporización": "e-va-po-ri-za-ción",
    "evaporizar": "e-va-po-ri-zar",
    "evapotranspiración": "e-va-po-trans-pi-ra-ción",
    "evasión": "e-va-sión",
    "evasiva": "e-va-si-va",
    "evasivo": "e-va-si-vo",
    "evasor": "e-va-sor",
    "evasora": "e-va-so-ra",
    "evección": "e-vec-ción",
    "evento": "e-ven-to",
    "eventración": "e-ven-tra-ción",
    "eventual": "e-ven-tual",
    "eventualidad": "e-ven-tua-li-dad",
    "eventualmente": "e-ven-tual-men-te",
    "eversión": "e-ver-sión",
    "evertir": "e-ver-tir",
    "evicción": "e-vic-ción",
    "evidencia": "e-vi-den-cia",
    "evidenciar": "e-vi-den-ciar",
    "evidente": "e-vi-den-te",
    "evidentemente": "e-vi-den-te-men-te",
    "eviscerar": "e-vis-ce-rar",
    "evitable": "e-vi-ta-ble",
    "evitación": "e-vi-ta-ción",
    "evitar": "e-vi-tar",
    "eviterna": "e-vi-ter-na",
    "eviterno": "e-vi-ter-no",
    "evo": "e-vo",
    "evocable": "e-vo-ca-ble",
    "evocación": "e-vo-ca-ción",
    "evocador": "e-vo-ca-dor",
    "evocadora": "e-vo-ca-do-ra",
    "evocar": "e-vo-car",
    "evocativo": "e-vo-ca-ti-vo",
    "evocatorio": "e-vo-ca-to-rio",
    "evohé": "e-vo-hé",
    "evolución": "e-vo-lu-ción",
    "evolucionar": "e-vo-lu-cio-nar",
    "evolucionismo": "e-vo-lu-cio-nis-mo",
    "evolucionista": "e-vo-lu-cio-nis-ta",
    "evolutiva": "e-vo-lu-ti-va",
    "evolutivo": "e-vo-lu-ti-vo",
    "evónimo": "e-vó-ni-mo",
    "exabrupto": "e-xa-brup-to",
    "exacción": "e-xac-ción",
    "exacerbación": "e-xa-cer-ba-ción",
    "exacerbamiento": "e-xa-cer-ba-mien-to",
    "exacerbar": "e-xa-cer-bar",
    "exacta": "e-xac-ta",
    "exactamente": "e-xac-ta-men-te",
    "exactitud": "e-xac-ti-tud",
    "exacto": "e-xac-to",
    "exactoa": "e-xac-to-a",
    "exactor": "e-xac-tor",
    "exageración": "e-xa-ge-ra-ción",
    "exagerada": "e-xa-ge-ra-da",
    "exageradamente": "e-xa-ge-ra-da-men-te",
    "exagerado": "e-xa-ge-ra-do",
    "exagerador": "e-xa-ge-ra-dor",
    "exageradora": "e-xa-ge-ra-do-ra",
    "exagerar": "e-xa-ge-rar",
    "exagerativa": "e-xa-ge-ra-ti-va",
    "exagerativamente": "e-xa-ge-ra-ti-va-men-te",
    "exagerativo": "e-xa-ge-ra-ti-vo",
    "exagitada": "e-xa-gi-ta-da",
    "exagitado": "e-xa-gi-ta-do",
    "exagonal": "e-xa-go-nal",
    "exágono": "e-xá-go-no",
    "exaltación": "e-xal-ta-ción",
    "exaltada": "e-xal-ta-da",
    "exaltado": "e-xal-ta-do",
    "exaltador": "e-xal-ta-dor",
    "exaltamiento": "e-xal-ta-mien-to",
    "exaltar": "e-xal-tar",
    "examen": "e-xa-men",
    "examinación": "e-xa-mi-na-ción",
    "examinador": "e-xa-mi-na-dor",
    "examinadora": "e-xa-mi-na-do-ra",
    "examinanda": "e-xa-mi-nan-da",
    "examinando": "e-xa-mi-nan-do",
    "examinante": "e-xa-mi-nan-te",
    "examinar": "e-xa-mi-nar",
    "exangüe": "e-xan-güe",
    "exanimación": "e-xa-ni-ma-ción",
    "exánime": "e-xá-ni-me",
    "exantema": "e-xan-te-ma",
    "exantemática": "e-xan-te-má-ti-ca",
    "exantemático": "e-xan-te-má-ti-co",
    "exarca": "e-xar-ca",
    "exarcado": "e-xar-ca-do",
    "exarco": "e-xar-co",
    "exardecer": "e-xar-de-cer",
    "exarico": "e-xa-ri-co",
    "exasperación": "e-xas-pe-ra-ción",
    "exasperante": "e-xas-pe-ran-te",
    "exasperar": "e-xas-pe-rar",
    "exaudible": "e-xau-di-ble",
    "exaudir": "e-xau-dir",
    "excandecencia": "ex-can-de-cen-cia",
    "excandecer": "ex-can-de-cer",
    "excarcelable": "ex-car-ce-la-ble",
    "excarcelación": "ex-car-ce-la-ción",
    "excarcelar": "ex-car-ce-lar",
    "excautiva": "ex-cau-ti-va",
    "excautivo": "ex-cau-ti-vo",
    "excava": "ex-ca-va",
    "excavación": "ex-ca-va-ción",
    "excavador": "ex-ca-va-dor",
    "excavadora": "ex-ca-va-do-ra",
    "excavar": "ex-ca-var",
    "excedencia": "ex-ce-den-cia",
    "excedentario": "ex-ce-den-ta-rio",
    "excedente": "ex-ce-den-te",
    "exceder": "ex-ce-der",
    "excelencia": "ex-ce-len-cia",
    "excelente": "ex-ce-len-te",
    "excelentemente": "ex-ce-len-te-men-te",
    "excelentísima": "ex-ce-len-tí-si-ma",
    "excelentísimo": "ex-ce-len-tí-si-mo",
    "excelsa": "ex-cel-sa",
    "excelsamente": "ex-cel-sa-men-te",
    "excelsitud": "ex-cel-si-tud",
    "excelso": "ex-cel-so",
    "excéntrica": "ex-cén-tri-ca",
    "excéntricamente": "ex-cén-tri-ca-men-te",
    "excentricidad": "ex-cen-tri-ci-dad",
    "excéntrico": "ex-cén-tri-co",
    "excepción": "ex-cep-ción",
    "excepcional": "ex-cep-cio-nal",
    "excepcionalidad": "ex-cep-cio-na-li-dad",
    "excepcionar": "ex-cep-cio-nar",
    "excepta": "ex-cep-ta",
    "exceptador": "ex-cep-ta-dor",
    "exceptadora": "ex-cep-ta-do-ra",
    "exceptar": "ex-cep-tar",
    "exceptiva": "ex-cep-ti-va",
    "exceptivo": "ex-cep-ti-vo",
    "excepto": "ex-cep-to",
    "exceptuación": "ex-cep-tua-ción",
    "exceptuar": "ex-cep-tuar",
    "excerpta": "ex-cerp-ta",
    "excerta": "ex-cer-ta",
    "excesiva": "ex-ce-si-va",
    "excesivamente": "ex-ce-si-va-men-te",
    "excesivo": "ex-ce-si-vo",
    "exceso": "ex-ce-so",
    "excidio": "ex-ci-dio",
    "excipiente": "ex-ci-pien-te",
    "excitabilidad": "ex-ci-ta-bi-li-dad",
    "excitable": "ex-ci-ta-ble",
    "excitación": "ex-ci-ta-ción",
    "excitador": "ex-ci-ta-dor",
    "excitadora": "ex-ci-ta-do-ra",
    "excitante": "ex-ci-tan-te",
    "excitar": "ex-ci-tar",
    "excitativa": "ex-ci-ta-ti-va",
    "excitativo": "ex-ci-ta-ti-vo",
    "excitatriz": "ex-ci-ta-triz",
    "exclamación": "ex-cla-ma-ción",
    "exclamar": "ex-cla-mar",
    "exclamativa": "ex-cla-ma-ti-va",
    "exclamativo": "ex-cla-ma-ti-vo",
    "exclamatoria": "ex-cla-ma-to-ria",
    "exclamatorio": "ex-cla-ma-to-rio",
    "exclaustración": "ex-claus-tra-ción",
    "exclaustrada": "ex-claus-tra-da",
    "exclaustrado": "ex-claus-tra-do",
    "exclaustrar": "ex-claus-trar",
    "excluible": "ex-clui-ble",
    "excluidor": "ex-clui-dor",
    "excluidora": "ex-clui-do-ra",
    "excluir": "ex-cluir",
    "exclusa": "ex-clu-sa",
    "exclusión": "ex-clu-sión",
    "exclusiva": "ex-clu-si-va",
    "exclusivamente": "ex-clu-si-va-men-te",
    "exclusive": "ex-clu-si-ve",
    "exclusividad": "ex-clu-si-vi-dad",
    "exclusivismo": "ex-clu-si-vis-mo",
    "exclusivista": "ex-clu-si-vis-ta",
    "exclusivo": "ex-clu-si-vo",
    "excluso": "ex-clu-so",
    "excluyente": "ex-clu-yen-te",
    "excogitable": "ex-co-gi-ta-ble",
    "excogitación": "ex-co-gi-ta-ción",
    "excogitar": "ex-co-gi-tar",
    "excombatiente": "ex-com-ba-tien-te",
    "excomulgada": "ex-co-mul-ga-da",
    "excomulgado": "ex-co-mul-ga-do",
    "excomulgador": "ex-co-mul-ga-dor",
    "excomulgar": "ex-co-mul-gar",
    "excomunicación": "ex-co-mu-ni-ca-ción",
    "excomunión": "ex-co-mu-nión",
    "excoriación": "ex-co-ria-ción",
    "excoriar": "ex-co-riar",
    "excrecencia": "ex-cre-cen-cia",
    "excreción": "ex-cre-ción",
    "excremental": "ex-cre-men-tal",
    "excrementar": "ex-cre-men-tar",
    "excrementicia": "ex-cre-men-ti-cia",
    "excrementicio": "ex-cre-men-ti-cio",
    "excremento": "ex-cre-men-to",
    "excrementosa": "ex-cre-men-to-sa",
    "excrementoso": "ex-cre-men-to-so",
    "excrescencia": "ex-cres-cen-cia",
    "excreta": "ex-cre-ta",
    "excretar": "ex-cre-tar",
    "excreto": "ex-cre-to",
    "excretor": "ex-cre-tor",
    "excretora": "ex-cre-to-ra",
    "excretoria": "ex-cre-to-ria",
    "excretorio": "ex-cre-to-rio",
    "excullada": "ex-cu-lla-da",
    "excullado": "ex-cu-lla-do",
    "exculpación": "ex-cul-pa-ción",
    "exculpar": "ex-cul-par",
    "exculpatorio": "ex-cul-pa-to-rio",
    "excursión": "ex-cur-sión",
    "excursionismo": "ex-cur-sio-nis-mo",
    "excursionista": "ex-cur-sio-nis-ta",
    "excurso": "ex-cur-so",
    "excusa": "ex-cu-sa",
    "excusabaraja": "ex-cu-sa-ba-ra-ja",
    "excusable": "ex-cu-sa-ble",
    "excusación": "ex-cu-sa-ción",
    "excusada": "ex-cu-sa-da",
    "excusadamente": "ex-cu-sa-da-men-te",
    "excusado": "ex-cu-sa-do",
    "excusador": "ex-cu-sa-dor",
    "excusadora": "ex-cu-sa-do-ra",
    "excusalí": "ex-cu-sa-lí",
    "excusar": "ex-cu-sar",
    "excusión": "ex-cu-sión",
    "excuso": "ex-cu-so",
    "execrable": "e-xe-cra-ble",
    "execración": "e-xe-cra-ción",
    "execrador": "e-xe-cra-dor",
    "execradora": "e-xe-cra-do-ra",
    "execramento": "e-xe-cra-men-to",
    "execranda": "e-xe-cran-da",
    "execrando": "e-xe-cran-do",
    "execrar": "e-xe-crar",
    "execrativa": "e-xe-cra-ti-va",
    "execrativo": "e-xe-cra-ti-vo",
    "execratoria": "e-xe-cra-to-ria",
    "execratorio": "e-xe-cra-to-rio",
    "exedra": "e-xe-dra",
    "exegesis": "e-xe-ge-sis",
    "exégesis": "e-xé-ge-sis",
    "exegeta": "e-xe-ge-ta",
    "exégeta": "e-xé-ge-ta",
    "exegética": "e-xe-gé-ti-ca",
    "exegético": "e-xe-gé-ti-co",
    "exención": "e-xen-ción",
    "exenta": "e-xen-ta",
    "exentamente": "e-xen-ta-men-te",
    "exentar": "e-xen-tar",
    "exento": "e-xen-to",
    "exequátur": "e-xe-quá-tur",
    "exequial": "e-xe-quial",
    "exequias": "e-xe-quias",
    "exequible": "e-xe-qui-ble",
    "exerciva": "e-xer-ci-va",
    "exercivo": "e-xer-ci-vo",
    "exergo": "e-xer-go",
    "exergónico": "e-xer-gó-ni-co",
    "exfoliación": "ex-fo-lia-ción",
    "exfoliador": "ex-fo-lia-dor",
    "exfoliadora": "ex-fo-lia-do-ra",
    "exfoliante": "ex-fo-lian-te",
    "exfoliar": "ex-fo-liar",
    "exfoliativo": "ex-fo-lia-ti-vo",
    "exhalación": "ex-ha-la-ción",
    "exhalador": "ex-ha-la-dor",
    "exhaladora": "ex-ha-la-do-ra",
    "exhalar": "ex-ha-lar",
    "exhausta": "ex-haus-ta",
    "exhaustiva": "ex-haus-ti-va",
    "exhaustividad": "ex-haus-ti-vi-dad",
    "exhaustivo": "ex-haus-ti-vo",
    "exhausto": "ex-haus-to",
    "exhibición": "ex-hi-bi-ción",
    "exhibicionismo": "ex-hi-bi-cio-nis-mo",
    "exhibicionista": "ex-hi-bi-cio-nis-ta",
    "exhibidor": "ex-hi-bi-dor",
    "exhibir": "ex-hi-bir",
    "exhortación": "ex-hor-ta-ción",
    "exhortador": "ex-hor-ta-dor",
    "exhortadora": "ex-hor-ta-do-ra",
    "exhortar": "ex-hor-tar",
    "exhortativa": "ex-hor-ta-ti-va",
    "exhortativo": "ex-hor-ta-ti-vo",
    "exhortatoria": "ex-hor-ta-to-ria",
    "exhortatorio": "ex-hor-ta-to-rio",
    "exhorto": "ex-hor-to",
    "exhumación": "ex-hu-ma-ción",
    "exhumador": "ex-hu-ma-dor",
    "exhumadora": "ex-hu-ma-do-ra",
    "exhumar": "ex-hu-mar",
    "exicial": "e-xi-cial",
    "exida": "e-xi-da",
    "exigencia": "e-xi-gen-cia",
    "exigente": "e-xi-gen-te",
    "exigibilidad": "e-xi-gi-bi-li-dad",
    "exigible": "e-xi-gi-ble",
    "exigidera": "e-xi-gi-de-ra",
    "exigidero": "e-xi-gi-de-ro",
    "exigir": "e-xi-gir",
    "exigua": "e-xi-gua",
    "exigüidad": "e-xi-güi-dad",
    "exiguo": "e-xi-guo",
    "exilada": "e-xi-la-da",
    "exilado": "e-xi-la-do",
    "exilar": "e-xi-lar",
    "exiliada": "e-xi-lia-da",
    "exiliado": "e-xi-lia-do",
    "exiliar": "e-xi-liar",
    "exilio": "e-xi-lio",
    "eximente": "e-xi-men-te",
    "eximio": "e-xi-mio",
    "eximir": "e-xi-mir",
    "exina": "e-xi-na",
    "exinanición": "e-xi-na-ni-ción",
    "exinanida": "e-xi-na-ni-da",
    "exinanido": "e-xi-na-ni-do",
    "exir": "e-xir",
    "existencia": "e-xis-ten-cia",
    "existencial": "e-xis-ten-cial",
    "existencialismo": "e-xis-ten-cia-lis-mo",
    "existencialista": "e-xis-ten-cia-lis-ta",
    "existente": "e-xis-ten-te",
    "existimación": "e-xis-ti-ma-ción",
    "existimar": "e-xis-ti-mar",
    "existimativa": "e-xis-ti-ma-ti-va",
    "existimativo": "e-xis-ti-ma-ti-vo",
    "existir": "e-xis-tir",
    "exitismo": "e-xi-tis-mo",
    "éxito": "é-xi-to",
    "exitosamente": "e-xi-to-sa-men-te",
    "exitoso": "e-xi-to-so",
    "exlibris": "ex-li-bris",
    "exlibrista": "ex-li-bris-ta",
    "exocéntrico": "e-xo-cén-tri-co",
    "exocrina": "e-xo-cri-na",
    "exocrino": "e-xo-cri-no",
    "éxodo": "é-xo-do",
    "exoenergético": "e-xo-e-ner-gé-ti-co",
    "exoesqueleto": "e-xo-es-que-le-to",
    "exoftalmía": "e-xof-tal-mí-a",
    "exoftalmia": "e-xof-tal-mia",
    "exoftálmica": "e-xof-tál-mi-ca",
    "exoftálmico": "e-xof-tál-mi-co",
    "exoftalmos": "e-xof-tal-mos",
    "exogamia": "e-xo-ga-mia",
    "exogámico": "e-xo-gá-mi-co",
    "exógeno": "e-xó-ge-no",
    "exoneración": "e-xo-ne-ra-ción",
    "exonerar": "e-xo-ne-rar",
    "exopodito": "e-xo-po-di-to",
    "exorable": "e-xo-ra-ble",
    "exorar": "e-xo-rar",
    "exorbitancia": "e-xor-bi-tan-cia",
    "exorbitante": "e-xor-bi-tan-te",
    "exorbitantemente": "e-xor-bi-tan-te-men-te",
    "exorbitar": "e-xor-bi-tar",
    "exorcismo": "e-xor-cis-mo",
    "exorcista": "e-xor-cis-ta",
    "exorcistado": "e-xor-cis-ta-do",
    "exorcizar": "e-xor-ci-zar",
    "exordiar": "e-xor-diar",
    "exordio": "e-xor-dio",
    "exordir": "e-xor-dir",
    "exornación": "e-xor-na-ción",
    "exornar": "e-xor-nar",
    "exorno": "e-xor-no",
    "exosfera": "e-xos-fe-ra",
    "exósfera": "e-xós-fe-ra",
    "exósmosis": "e-xós-mo-sis",
    "exotérica": "e-xo-té-ri-ca",
    "exotérico": "e-xo-té-ri-co",
    "exotérmico": "e-xo-tér-mi-co",
    "exótica": "e-xó-ti-ca",
    "exoticidad": "e-xo-ti-ci-dad",
    "exótico": "e-xó-ti-co",
    "exotiquez": "e-xo-ti-quez",
    "exotismo": "e-xo-tis-mo",
    "expandir": "ex-pan-dir",
    "expansibilidad": "ex-pan-si-bi-li-dad",
    "expansible": "ex-pan-si-ble",
    "expansión": "ex-pan-sión",
    "expansionar": "ex-pan-sio-nar",
    "expansionismo": "ex-pan-sio-nis-mo",
    "expansionista": "ex-pan-sio-nis-ta",
    "expansiva": "ex-pan-si-va",
    "expansivo": "ex-pan-si-vo",
    "expatriación": "ex-pa-tria-ción",
    "expatriada": "ex-pa-tria-da",
    "expatriado": "ex-pa-tria-do",
    "expatriar": "ex-pa-triar",
    "expavecer": "ex-pa-ve-cer",
    "expectable": "ex-pec-ta-ble",
    "expectación": "ex-pec-ta-ción",
    "expectante": "ex-pec-tan-te",
    "expectativa": "ex-pec-ta-ti-va",
    "expectoración": "ex-pec-to-ra-ción",
    "expectorante": "ex-pec-to-ran-te",
    "expectorar": "ex-pec-to-rar",
    "expedición": "ex-pe-di-ción",
    "expedicionaria": "ex-pe-di-cio-na-ria",
    "expedicionario": "ex-pe-di-cio-na-rio",
    "expedicionero": "ex-pe-di-cio-ne-ro",
    "expedida": "ex-pe-di-da",
    "expedidamente": "ex-pe-di-da-men-te",
    "expedido": "ex-pe-di-do",
    "expedidor": "ex-pe-di-dor",
    "expedidora": "ex-pe-di-do-ra",
    "expedientar": "ex-pe-dien-tar",
    "expediente": "ex-pe-dien-te",
    "expedienteo": "ex-pe-dien-te-o",
    "expedir": "ex-pe-dir",
    "expedita": "ex-pe-di-ta",
    "expeditamente": "ex-pe-di-ta-men-te",
    "expeditar": "ex-pe-di-tar",
    "expeditiva": "ex-pe-di-ti-va",
    "expeditivo": "ex-pe-di-ti-vo",
    "expedito": "ex-pe-di-to",
    "expeler": "ex-pe-ler",
    "expendedor": "ex-pen-de-dor",
    "expendedora": "ex-pen-de-do-ra",
    "expendeduría": "ex-pen-de-du-rí-a",
    "expender": "ex-pen-der",
    "expendición": "ex-pen-di-ción",
    "expendio": "ex-pen-dio",
    "expensar": "ex-pen-sar",
    "expensas": "ex-pen-sas",
    "experiencia": "ex-pe-rien-cia",
    "experiencial": "ex-pe-rien-cial",
    "experimentación": "ex-pe-ri-men-ta-ción",
    "experimentada": "ex-pe-ri-men-ta-da",
    "experimentado": "ex-pe-ri-men-ta-do",
    "experimentador": "ex-pe-ri-men-ta-dor",
    "experimentadora": "ex-pe-ri-men-ta-do-ra",
    "experimental": "ex-pe-ri-men-tal",
    "experimentalismo": "ex-pe-ri-men-ta-lis-mo",
    "experimentalista": "ex-pe-ri-men-ta-lis-ta",
    "experimentalmente": "ex-pe-ri-men-tal-men-te",
    "experimentar": "ex-pe-ri-men-tar",
    "experimento": "ex-pe-ri-men-to",
    "experta": "ex-per-ta",
    "expertamente": "ex-per-ta-men-te",
    "experticia": "ex-per-ti-cia",
    "experto": "ex-per-to",
    "expiación": "ex-pia-ción",
    "expiar": "ex-piar",
    "expiativa": "ex-pia-ti-va",
    "expiativo": "ex-pia-ti-vo",
    "expiatoria": "ex-pia-to-ria",
    "expiatorio": "ex-pia-to-rio",
    "expilar": "ex-pi-lar",
    "expillo": "ex-pi-llo",
    "expiración": "ex-pi-ra-ción",
    "expirar": "ex-pi-rar",
    "explanación": "ex-pla-na-ción",
    "explanada": "ex-pla-na-da",
    "explanar": "ex-pla-nar",
    "explayada": "ex-pla-ya-da",
    "explayar": "ex-pla-yar",
    "expletiva": "ex-ple-ti-va",
    "expletivo": "ex-ple-ti-vo",
    "explicable": "ex-pli-ca-ble",
    "explicablemente": "ex-pli-ca-ble-men-te",
    "explicación": "ex-pli-ca-ción",
    "explicaderas": "ex-pli-ca-de-ras",
    "explicador": "ex-pli-ca-dor",
    "explicadora": "ex-pli-ca-do-ra",
    "explicar": "ex-pli-car",
    "explicativa": "ex-pli-ca-ti-va",
    "explicativo": "ex-pli-ca-ti-vo",
    "éxplicit": "éx-pli-cit",
    "explícita": "ex-plí-ci-ta",
    "explicitación": "ex-pli-ci-ta-ción",
    "explícitamente": "ex-plí-ci-ta-men-te",
    "explicitar": "ex-pli-ci-tar",
    "explícito": "ex-plí-ci-to",
    "explicitud": "ex-pli-ci-tud",
    "explicotear": "ex-pli-co-te-ar",
    "explicoteo": "ex-pli-co-te-o",
    "explique": "ex-pli-que",
    "explorable": "ex-plo-ra-ble",
    "exploración": "ex-plo-ra-ción",
    "explorador": "ex-plo-ra-dor",
    "exploradora": "ex-plo-ra-do-ra",
    "explorar": "ex-plo-rar",
    "exploratoria": "ex-plo-ra-to-ria",
    "exploratorio": "ex-plo-ra-to-rio",
    "explosímetro": "ex-plo-sí-me-tro",
    "explosión": "ex-plo-sión",
    "explosionar": "ex-plo-sio-nar",
    "explosiva": "ex-plo-si-va",
    "explosivo": "ex-plo-si-vo",
    "explotable": "ex-plo-ta-ble",
    "explotación": "ex-plo-ta-ción",
    "explotador": "ex-plo-ta-dor",
    "explotadora": "ex-plo-ta-do-ra",
    "explotar": "ex-plo-tar",
    "exployada": "ex-plo-ya-da",
    "exployado": "ex-plo-ya-do",
    "expoliación": "ex-po-lia-ción",
    "expoliador": "ex-po-lia-dor",
    "expoliadora": "ex-po-lia-do-ra",
    "expoliar": "ex-po-liar",
    "expolición": "ex-po-li-ción",
    "expolio": "ex-po-lio",
    "exponedor": "ex-po-ne-dor",
    "exponencial": "ex-po-nen-cial",
    "exponente": "ex-po-nen-te",
    "exponer": "ex-po-ner",
    "exportable": "ex-por-ta-ble",
    "exportación": "ex-por-ta-ción",
    "exportador": "ex-por-ta-dor",
    "exportadora": "ex-por-ta-do-ra",
    "exportar": "ex-por-tar",
    "exposición": "ex-po-si-ción",
    "exposímetro": "ex-po-sí-me-tro",
    "expósita": "ex-pó-si-ta",
    "expositiva": "ex-po-si-ti-va",
    "expositivo": "ex-po-si-ti-vo",
    "expósito": "ex-pó-si-to",
    "expositor": "ex-po-si-tor",
    "expositora": "ex-po-si-to-ra",
    "expremijo": "ex-pre-mi-jo",
    "expremir": "ex-pre-mir",
    "exprés": "ex-prés",
    "expresa": "ex-pre-sa",
    "expresable": "ex-pre-sa-ble",
    "expresamente": "ex-pre-sa-men-te",
    "expresar": "ex-pre-sar",
    "expresión": "ex-pre-sión",
    "expresionismo": "ex-pre-sio-nis-mo",
    "expresionista": "ex-pre-sio-nis-ta",
    "expresiva": "ex-pre-si-va",
    "expresivamente": "ex-pre-si-va-men-te",
    "expresividad": "ex-pre-si-vi-dad",
    "expresivo": "ex-pre-si-vo",
    "expreso": "ex-pre-so",
    "exprimidera": "ex-pri-mi-de-ra",
    "exprimidero": "ex-pri-mi-de-ro",
    "exprimidor": "ex-pri-mi-dor",
    "exprimir": "ex-pri-mir",
    "expropiación": "ex-pro-pia-ción",
    "expropiador": "ex-pro-pia-dor",
    "expropiadora": "ex-pro-pia-do-ra",
    "expropiar": "ex-pro-piar",
    "expropiatorio": "ex-pro-pia-to-rio",
    "expuesta": "ex-pues-ta",
    "expuesto": "ex-pues-to",
    "expugnable": "ex-pug-na-ble",
    "expugnación": "ex-pug-na-ción",
    "expugnador": "ex-pug-na-dor",
    "expugnadora": "ex-pug-na-do-ra",
    "expugnar": "ex-pug-nar",
    "expulsa": "ex-pul-sa",
    "expulsar": "ex-pul-sar",
    "expulsión": "ex-pul-sión",
    "expulsiva": "ex-pul-si-va",
    "expulsivo": "ex-pul-si-vo",
    "expulso": "ex-pul-so",
    "expulsor": "ex-pul-sor",
    "expulsora": "ex-pul-so-ra",
    "expurgación": "ex-pur-ga-ción",
    "expurgador": "ex-pur-ga-dor",
    "expurgadora": "ex-pur-ga-do-ra",
    "expurgar": "ex-pur-gar",
    "expurgatoria": "ex-pur-ga-to-ria",
    "expurgatorio": "ex-pur-ga-to-rio",
    "expurgo": "ex-pur-go",
    "exquisita": "ex-qui-si-ta",
    "exquisitamente": "ex-qui-si-ta-men-te",
    "exquisitez": "ex-qui-si-tez",
    "exquisito": "ex-qui-si-to",
    "éxtasi": "éx-ta-si",
    "extasiar": "ex-ta-siar",
    "éxtasis": "éx-ta-sis",
    "extática": "ex-tá-ti-ca",
    "extáticamente": "ex-tá-ti-ca-men-te",
    "extático": "ex-tá-ti-co",
    "extemporal": "ex-tem-po-ral",
    "extemporánea": "ex-tem-po-rá-ne-a",
    "extemporáneamente": "ex-tem-po-rá-ne-a-men-te",
    "extemporaneidad": "ex-tem-po-ra-nei-dad",
    "extemporáneo": "ex-tem-po-rá-ne-o",
    "extender": "ex-ten-der",
    "extendidamente": "ex-ten-di-da-men-te",
    "extendimiento": "ex-ten-di-mien-to",
    "extensa": "ex-ten-sa",
    "extensamente": "ex-ten-sa-men-te",
    "extensible": "ex-ten-si-ble",
    "extensión": "ex-ten-sión",
    "extensiva": "ex-ten-si-va",
    "extensivamente": "ex-ten-si-va-men-te",
    "extensivo": "ex-ten-si-vo",
    "extenso": "ex-ten-so",
    "extensor": "ex-ten-sor",
    "extensora": "ex-ten-so-ra",
    "extenuación": "ex-te-nua-ción",
    "extenuado": "ex-te-nua-do",
    "extenuante": "ex-te-nuan-te",
    "extenuar": "ex-te-nuar",
    "extenuativa": "ex-te-nua-ti-va",
    "extenuativo": "ex-te-nua-ti-vo",
    "exterior": "ex-te-rior",
    "exterioridad": "ex-te-rio-ri-dad",
    "exteriorización": "ex-te-rio-ri-za-ción",
    "exteriorizar": "ex-te-rio-ri-zar",
    "exteriormente": "ex-te-rior-men-te",
    "exterminable": "ex-ter-mi-na-ble",
    "exterminación": "ex-ter-mi-na-ción",
    "exterminador": "ex-ter-mi-na-dor",
    "exterminadora": "ex-ter-mi-na-do-ra",
    "exterminar": "ex-ter-mi-nar",
    "exterminio": "ex-ter-mi-nio",
    "externa": "ex-ter-na",
    "externado": "ex-ter-na-do",
    "externalidad": "ex-ter-na-li-dad",
    "externalización": "ex-ter-na-li-za-ción",
    "externalizar": "ex-ter-na-li-zar",
    "externamente": "ex-ter-na-men-te",
    "externar": "ex-ter-nar",
    "externo": "ex-ter-no",
    "extinción": "ex-tin-ción",
    "extinguible": "ex-tin-gui-ble",
    "extinguidor": "ex-tin-gui-dor",
    "extinguir": "ex-tin-guir",
    "extinta": "ex-tin-ta",
    "extintiva": "ex-tin-ti-va",
    "extintivo": "ex-tin-ti-vo",
    "extinto": "ex-tin-to",
    "extintor": "ex-tin-tor",
    "extintora": "ex-tin-to-ra",
    "extirpable": "ex-tir-pa-ble",
    "extirpación": "ex-tir-pa-ción",
    "extirpador": "ex-tir-pa-dor",
    "extirpadora": "ex-tir-pa-do-ra",
    "extirpar": "ex-tir-par",
    "extornar": "ex-tor-nar",
    "extorno": "ex-tor-no",
    "extorsión": "ex-tor-sión",
    "extorsionador": "ex-tor-sio-na-dor",
    "extorsionar": "ex-tor-sio-nar",
    "extorsionista": "ex-tor-sio-nis-ta",
    "extorsivo": "ex-tor-si-vo",
    "extra": "ex-tra",
    "extracción": "ex-trac-ción",
    "extracomunitario": "ex-tra-co-mu-ni-ta-rio",
    "extracorpóreo": "ex-tra-cor-pó-re-o",
    "extractador": "ex-trac-ta-dor",
    "extractadora": "ex-trac-ta-do-ra",
    "extractar": "ex-trac-tar",
    "extractivo": "ex-trac-ti-vo",
    "extracto": "ex-trac-to",
    "extractor": "ex-trac-tor",
    "extractora": "ex-trac-to-ra",
    "extracurricular": "ex-tra-cu-rri-cu-lar",
    "extradición": "ex-tra-di-ción",
    "extradir": "ex-tra-dir",
    "extraditada": "ex-tra-di-ta-da",
    "extraditado": "ex-tra-di-ta-do",
    "extraditar": "ex-tra-di-tar",
    "extradós": "ex-tra-dós",
    "extraeconómico": "ex-tra-e-co-nó-mi-co",
    "extraembrionario": "ex-tra-em-brio-na-rio",
    "extraer": "ex-tra-er",
    "extraescolar": "ex-tra-es-co-lar",
    "extrafino": "ex-tra-fi-no",
    "extraíble": "ex-tra-í-ble",
    "extrajudicial": "ex-tra-ju-di-cial",
    "extrajudicialmente": "ex-tra-ju-di-cial-men-te",
    "extralimitación": "ex-tra-li-mi-ta-ción",
    "extralimitar": "ex-tra-li-mi-tar",
    "extralimitarse": "ex-tra-li-mi-tar-se",
    "extralingüístico": "ex-tra-lin-güís-ti-co",
    "extramarital": "ex-tra-ma-ri-tal",
    "extramatrimonial": "ex-tra-ma-tri-mo-nial",
    "extramuros": "ex-tra-mu-ros",
    "extraña": "ex-tra-ña",
    "extrañación": "ex-tra-ña-ción",
    "extrañamente": "ex-tra-ña-men-te",
    "extrañamiento": "ex-tra-ña-mien-to",
    "extrañar": "ex-tra-ñar",
    "extranatural": "ex-tra-na-tu-ral",
    "extrañez": "ex-tra-ñez",
    "extrañeza": "ex-tra-ñe-za",
    "extranjera": "ex-tran-je-ra",
    "extranjería": "ex-tran-je-rí-a",
    "extranjerismo": "ex-tran-je-ris-mo",
    "extranjerizante": "ex-tran-je-ri-zan-te",
    "extranjerizar": "ex-tran-je-ri-zar",
    "extranjero": "ex-tran-je-ro",
    "extranjía": "ex-tran-jí-a",
    "extranjis": "ex-tran-jis",
    "extraño": "ex-tra-ño",
    "extraoficial": "ex-tra-o-fi-cial",
    "extraoficialmente": "ex-tra-o-fi-cial-men-te",
    "extraordinaria": "ex-tra-or-di-na-ria",
    "extraordinariamente": "ex-tra-or-di-na-ria-men-te",
    "extraordinario": "ex-tra-or-di-na-rio",
    "extraparlamentario": "ex-tra-par-la-men-ta-rio",
    "extraplano": "ex-tra-pla-no",
    "extrapolable": "ex-tra-po-la-ble",
    "extrapolación": "ex-tra-po-la-ción",
    "extrapolar": "ex-tra-po-lar",
    "extrarradio": "ex-tra-rra-dio",
    "extrasensorial": "ex-tra-sen-so-rial",
    "extrasístole": "ex-tra-sís-to-le",
    "extratémpora": "ex-tra-tém-po-ra",
    "extraterrestre": "ex-tra-te-rres-tre",
    "extraterritorial": "ex-tra-te-rri-to-rial",
    "extraterritorialidad": "ex-tra-te-rri-to-ria-li-dad",
    "extratipo": "ex-tra-ti-po",
    "extrauterino": "ex-trau-te-ri-no",
    "extravagancia": "ex-tra-va-gan-cia",
    "extravagante": "ex-tra-va-gan-te",
    "extravasación": "ex-tra-va-sa-ción",
    "extravasar": "ex-tra-va-sar",
    "extravasarse": "ex-tra-va-sar-se",
    "extravenar": "ex-tra-ve-nar",
    "extraversión": "ex-tra-ver-sión",
    "extravertida": "ex-tra-ver-ti-da",
    "extravertido": "ex-tra-ver-ti-do",
    "extraviada": "ex-tra-via-da",
    "extraviado": "ex-tra-via-do",
    "extraviar": "ex-tra-viar",
    "extravío": "ex-tra-ví-o",
    "extrema": "ex-tre-ma",
    "extremada": "ex-tre-ma-da",
    "extremadamente": "ex-tre-ma-da-men-te",
    "extremadas": "ex-tre-ma-das",
    "extremado": "ex-tre-ma-do",
    "extremamente": "ex-tre-ma-men-te",
    "extremar": "ex-tre-mar",
    "extremaunción": "ex-tre-maun-ción",
    "extremeña": "ex-tre-me-ña",
    "extremeñismo": "ex-tre-me-ñis-mo",
    "extremeño": "ex-tre-me-ño",
    "extremidad": "ex-tre-mi-dad",
    "extremismo": "ex-tre-mis-mo",
    "extremista": "ex-tre-mis-ta",
    "extremo": "ex-tre-mo",
    "extremosa": "ex-tre-mo-sa",
    "extremosidad": "ex-tre-mo-si-dad",
    "extremoso": "ex-tre-mo-so",
    "extrínseca": "ex-trín-se-ca",
    "extrínsecamente": "ex-trín-se-ca-men-te",
    "extrínseco": "ex-trín-se-co",
    "extroversión": "ex-tro-ver-sión",
    "extrovertido": "ex-tro-ver-ti-do",
    "extrudir": "ex-tru-dir",
    "extruir": "ex-truir",
    "extrusión": "ex-tru-sión",
    "extrusor": "ex-tru-sor",
    "extrusora": "ex-tru-so-ra",
    "exturbar": "ex-tur-bar",
    "exuberancia": "e-xu-be-ran-cia",
    "exuberante": "e-xu-be-ran-te",
    "exuberar": "e-xu-be-rar",
    "exudación": "e-xu-da-ción",
    "exudado": "e-xu-da-do",
    "exudar": "e-xu-dar",
    "exudativo": "e-xu-da-ti-vo",
    "exulceración": "e-xul-ce-ra-ción",
    "exulcerar": "e-xul-ce-rar",
    "exultación": "e-xul-ta-ción",
    "exultante": "e-xul-tan-te",
    "exultar": "e-xul-tar",
    "exutorio": "e-xu-to-rio",
    "exvoto": "ex-vo-to",
    "eyaculación": "e-ya-cu-la-ción",
    "eyaculador": "e-ya-cu-la-dor",
    "eyacular": "e-ya-cu-lar",
    "eyaculatoria": "e-ya-cu-la-to-ria",
    "eyaculatorio": "e-ya-cu-la-to-rio",
    "eyección": "e-yec-ción",
    "eyectable": "e-yec-ta-ble",
    "eyectar": "e-yec-tar",
    "eyector": "e-yec-tor",
    "ezquerdear": "ez-quer-de-ar",
    "ezquite": "ez-qui-te",
    "faba": "fa-ba",
    "fabácea": "fa-bá-ce-a",
    "fabáceas": "fa-bá-ce-as",
    "fabáceo": "fa-bá-ce-o",
    "fabada": "fa-ba-da",
    "fabianismo": "fa-bia-nis-mo",
    "fabla": "fa-bla",
    "fablable": "fa-bla-ble",
    "fablar": "fa-blar",
    "fabliella": "fa-blie-lla",
    "fablistanear": "fa-blis-ta-ne-ar",
    "fabo": "fa-bo",
    "fabordón": "fa-bor-dón",
    "fábrica": "fá-bri-ca",
    "fabricación": "fa-bri-ca-ción",
    "fabricadamente": "fa-bri-ca-da-men-te",
    "fabricador": "fa-bri-ca-dor",
    "fabricadora": "fa-bri-ca-do-ra",
    "fabricante": "fa-bri-can-te",
    "fabricar": "fa-bri-car",
    "fabrida": "fa-bri-da",
    "fabrido": "fa-bri-do",
    "fabril": "fa-bril",
    "fabrilmente": "fa-bril-men-te",
    "fabriquero": "fa-bri-que-ro",
    "fabro": "fa-bro",
    "fabuco": "fa-bu-co",
    "fábula": "fá-bu-la",
    "fabulación": "fa-bu-la-ción",
    "fabulador": "fa-bu-la-dor",
    "fabuladora": "fa-bu-la-do-ra",
    "fabular": "fa-bu-lar",
    "fabulario": "fa-bu-la-rio",
    "fabulesco": "fa-bu-les-co",
    "fabulista": "fa-bu-lis-ta",
    "fabulística": "fa-bu-lís-ti-ca",
    "fabulístico": "fa-bu-lís-ti-co",
    "fabulosa": "fa-bu-lo-sa",
    "fabulosamente": "fa-bu-lo-sa-men-te",
    "fabulosidad": "fa-bu-lo-si-dad",
    "fabuloso": "fa-bu-lo-so",
    "faca": "fa-ca",
    "fácata": "fá-ca-ta",
    "facazo": "fa-ca-zo",
    "facción": "fac-ción",
    "faccionar": "fac-cio-nar",
    "faccionaria": "fac-cio-na-ria",
    "faccionario": "fac-cio-na-rio",
    "facciosa": "fac-cio-sa",
    "faccioso": "fac-cio-so",
    "facecia": "fa-ce-cia",
    "facecioso": "fa-ce-cio-so",
    "facedor": "fa-ce-dor",
    "facedora": "fa-ce-do-ra",
    "facer": "fa-cer",
    "facera": "fa-ce-ra",
    "facería": "fa-ce-rí-a",
    "facero": "fa-ce-ro",
    "faceruelo": "fa-ce-rue-lo",
    "faceta": "fa-ce-ta",
    "facetada": "fa-ce-ta-da",
    "faceto": "fa-ce-to",
    "facha": "fa-cha",
    "fachada": "fa-cha-da",
    "fachadismo": "fa-cha-dis-mo",
    "fachado": "fa-cha-do",
    "fachalina": "fa-cha-li-na",
    "fachar": "fa-char",
    "fachear": "fa-che-ar",
    "fachenda": "fa-chen-da",
    "fachendear": "fa-chen-de-ar",
    "fachendista": "fa-chen-dis-ta",
    "fachendón": "fa-chen-dón",
    "fachendona": "fa-chen-do-na",
    "fachendosa": "fa-chen-do-sa",
    "fachendoso": "fa-chen-do-so",
    "fachentada": "fa-chen-ta-da",
    "fachento": "fa-chen-to",
    "fachinal": "fa-chi-nal",
    "facho": "fa-cho",
    "fachosa": "fa-cho-sa",
    "fachoso": "fa-cho-so",
    "fachuda": "fa-chu-da",
    "fachudo": "fa-chu-do",
    "facial": "fa-cial",
    "facialmente": "fa-cial-men-te",
    "facienda": "fa-cien-da",
    "facies": "fa-cies",
    "fácil": "fá-cil",
    "facilidad": "fa-ci-li-dad",
    "facililla": "fa-ci-li-lla",
    "facilillo": "fa-ci-li-llo",
    "facilismo": "fa-ci-lis-mo",
    "facilitación": "fa-ci-li-ta-ción",
    "facilitador": "fa-ci-li-ta-dor",
    "facilitadora": "fa-ci-li-ta-do-ra",
    "facilitar": "fa-ci-li-tar",
    "facilitón": "fa-ci-li-tón",
    "facilitona": "fa-ci-li-to-na",
    "fácilmente": "fá-cil-men-te",
    "facilón": "fa-ci-lón",
    "facilongo": "fa-ci-lon-go",
    "facimiento": "fa-ci-mien-to",
    "facinerosa": "fa-ci-ne-ro-sa",
    "facineroso": "fa-ci-ne-ro-so",
    "facinorosa": "fa-ci-no-ro-sa",
    "facinoroso": "fa-ci-no-ro-so",
    "fación": "fa-ción",
    "facionada": "fa-cio-na-da",
    "facionado": "fa-cio-na-do",
    "facistelo": "fa-cis-te-lo",
    "facistol": "fa-cis-tol",
    "facón": "fa-cón",
    "facsímil": "fac-sí-mil",
    "facsimilar": "fac-si-mi-lar",
    "facsímile": "fac-sí-mi-le",
    "factibilidad": "fac-ti-bi-li-dad",
    "factible": "fac-ti-ble",
    "fácticamente": "fác-ti-ca-men-te",
    "facticia": "fac-ti-cia",
    "facticidad": "fac-ti-ci-dad",
    "facticio": "fac-ti-cio",
    "fáctico": "fác-ti-co",
    "factitivo": "fac-ti-ti-vo",
    "facto": "fac-to",
    "factor": "fac-tor",
    "factora": "fac-to-ra",
    "factoraje": "fac-to-ra-je",
    "factoría": "fac-to-rí-a",
    "factorial": "fac-to-rial",
    "factótum": "fac-tó-tum",
    "factual": "fac-tual",
    "factura": "fac-tu-ra",
    "facturación": "fac-tu-ra-ción",
    "facturar": "fac-tu-rar",
    "fácula": "fá-cu-la",
    "faculta": "fa-cul-ta",
    "facultad": "fa-cul-tad",
    "facultar": "fa-cul-tar",
    "facultativa": "fa-cul-ta-ti-va",
    "facultativamente": "fa-cul-ta-ti-va-men-te",
    "facultativo": "fa-cul-ta-ti-vo",
    "faculto": "fa-cul-to",
    "facultosa": "fa-cul-to-sa",
    "facultoso": "fa-cul-to-so",
    "facunda": "fa-cun-da",
    "facundia": "fa-cun-dia",
    "facundo": "fa-cun-do",
    "fada": "fa-da",
    "fadiga": "fa-di-ga",
    "fado": "fa-do",
    "fadrubada": "fa-dru-ba-da",
    "fadrubado": "fa-dru-ba-do",
    "faena": "fa-e-na",
    "faenar": "fa-e-nar",
    "faenera": "fa-e-ne-ra",
    "faenero": "fa-e-ne-ro",
    "faetón": "fa-e-tón",
    "fafarachero": "fa-fa-ra-che-ro",
    "fagácea": "fa-gá-ce-a",
    "fagáceas": "fa-gá-ce-as",
    "fagáceo": "fa-gá-ce-o",
    "fagales": "fa-ga-les",
    "fago": "fa-go",
    "fagocitar": "fa-go-ci-tar",
    "fagocitario": "fa-go-ci-ta-rio",
    "fagocito": "fa-go-ci-to",
    "fagocitosis": "fa-go-ci-to-sis",
    "fagot": "fa-got",
    "fagote": "fa-go-te",
    "fagotista": "fa-go-tis-ta",
    "fagüeño": "fa-güe-ño",
    "faical": "fai-cal",
    "faina": "fai-na",
    "fainada": "fai-na-da",
    "fainera": "fai-ne-ra",
    "fainería": "fai-ne-rí-a",
    "faino": "fai-no",
    "faique": "fai-que",
    "faisán": "fai-sán",
    "faisana": "fai-sa-na",
    "faisanera": "fai-sa-ne-ra",
    "faisanería": "fai-sa-ne-rí-a",
    "faisanero": "fai-sa-ne-ro",
    "faja": "fa-ja",
    "fajada": "fa-ja-da",
    "fajado": "fa-ja-do",
    "fajador": "fa-ja-dor",
    "fajadora": "fa-ja-do-ra",
    "fajadura": "fa-ja-du-ra",
    "fajamiento": "fa-ja-mien-to",
    "fajana": "fa-ja-na",
    "fajar": "fa-jar",
    "fajardeña": "fa-jar-de-ña",
    "fajardeño": "fa-jar-de-ño",
    "fajardo": "fa-jar-do",
    "fajares": "fa-ja-res",
    "fajazo": "fa-ja-zo",
    "fajazón": "fa-ja-zón",
    "faje": "fa-je",
    "fajeada": "fa-je-a-da",
    "fajeado": "fa-je-a-do",
    "fajear": "fa-je-ar",
    "fajero": "fa-je-ro",
    "fajilla": "fa-ji-lla",
    "fajín": "fa-jín",
    "fajina": "fa-ji-na",
    "fajinada": "fa-ji-na-da",
    "fajinear": "fa-ji-ne-ar",
    "fajo": "fa-jo",
    "fajol": "fa-jol",
    "fajón": "fa-jón",
    "falacia": "fa-la-cia",
    "falafel": "fa-la-fel",
    "falagar": "fa-la-gar",
    "falago": "fa-la-go",
    "falagüeño": "fa-la-güe-ño",
    "falaguera": "fa-la-gue-ra",
    "falaguero": "fa-la-gue-ro",
    "falange": "fa-lan-ge",
    "falangeta": "fa-lan-ge-ta",
    "falangia": "fa-lan-gia",
    "falangiana": "fa-lan-gia-na",
    "falangiano": "fa-lan-gia-no",
    "falangina": "fa-lan-gi-na",
    "falangio": "fa-lan-gio",
    "falangismo": "fa-lan-gis-mo",
    "falangista": "fa-lan-gis-ta",
    "falansterio": "fa-lans-te-rio",
    "falárica": "fa-lá-ri-ca",
    "falaris": "fa-la-ris",
    "falaropo": "fa-la-ro-po",
    "falasha": "fa-las-ha",
    "falaz": "fa-laz",
    "falazmente": "fa-laz-men-te",
    "falbalá": "fal-ba-lá",
    "falca": "fal-ca",
    "falcada": "fal-ca-da",
    "falcado": "fal-ca-do",
    "falcar": "fal-car",
    "falcario": "fal-ca-rio",
    "falcata": "fal-ca-ta",
    "falce": "fal-ce",
    "falcidia": "fal-ci-dia",
    "falciforme": "fal-ci-for-me",
    "falcinelo": "fal-ci-ne-lo",
    "falcino": "fal-ci-no",
    "falcirrostra": "fal-ci-rros-tra",
    "falcirrostro": "fal-ci-rros-tro",
    "falcón": "fal-cón",
    "falconete": "fal-co-ne-te",
    "falconiana": "fal-co-nia-na",
    "falconiano": "fal-co-nia-no",
    "falcónida": "fal-có-ni-da",
    "falcónido": "fal-có-ni-do",
    "falconiforme": "fal-co-ni-for-me",
    "falda": "fal-da",
    "faldamenta": "fal-da-men-ta",
    "faldamento": "fal-da-men-to",
    "faldar": "fal-dar",
    "faldear": "fal-de-ar",
    "faldellín": "fal-de-llín",
    "faldeo": "fal-de-o",
    "faldera": "fal-de-ra",
    "faldero": "fal-de-ro",
    "faldeta": "fal-de-ta",
    "faldicorta": "fal-di-cor-ta",
    "faldicorto": "fal-di-cor-to",
    "faldillas": "fal-di-llas",
    "faldinegra": "fal-di-ne-gra",
    "faldinegro": "fal-di-ne-gro",
    "faldistorio": "fal-dis-to-rio",
    "faldón": "fal-dón",
    "faldriquera": "fal-dri-que-ra",
    "falduda": "fal-du-da",
    "faldudo": "fal-du-do",
    "faldulario": "fal-du-la-rio",
    "falena": "fa-le-na",
    "falencia": "fa-len-cia",
    "falerno": "fa-ler-no",
    "faleucio": "fa-leu-cio",
    "faleuco": "fa-leu-co",
    "falibilidad": "fa-li-bi-li-dad",
    "falible": "fa-li-ble",
    "fálica": "fá-li-ca",
    "fálico": "fá-li-co",
    "falida": "fa-li-da",
    "falidamente": "fa-li-da-men-te",
    "falido": "fa-li-do",
    "falimiento": "fa-li-mien-to",
    "falisco": "fa-lis-co",
    "falla": "fa-lla",
    "fallada": "fa-lla-da",
    "fallado": "fa-lla-do",
    "fallador": "fa-lla-dor",
    "falladora": "fa-lla-do-ra",
    "fallanca": "fa-llan-ca",
    "fallar": "fa-llar",
    "falleba": "fa-lle-ba",
    "fallecedera": "fa-lle-ce-de-ra",
    "fallecedero": "fa-lle-ce-de-ro",
    "fallecer": "fa-lle-cer",
    "fallecida": "fa-lle-ci-da",
    "fallecido": "fa-lle-ci-do",
    "fallecimiento": "fa-lle-ci-mien-to",
    "fallera": "fa-lle-ra",
    "fallero": "fa-lle-ro",
    "fallida": "fa-lli-da",
    "fallidera": "fa-lli-de-ra",
    "fallidero": "fa-lli-de-ro",
    "fallido": "fa-lli-do",
    "fallo": "fa-llo",
    "falluca": "fa-llu-ca",
    "falluquear": "fa-llu-que-ar",
    "falluquera": "fa-llu-que-ra",
    "falluquero": "fa-llu-que-ro",
    "falluta": "fa-llu-ta",
    "fallutada": "fa-llu-ta-da",
    "falluteada": "fa-llu-te-a-da",
    "fallutear": "fa-llu-te-ar",
    "fallutería": "fa-llu-te-rí-a",
    "falluto": "fa-llu-to",
    "falo": "fa-lo",
    "falocracia": "fa-lo-cra-cia",
    "falócrata": "fa-ló-cra-ta",
    "falocrático": "fa-lo-crá-ti-co",
    "falopa": "fa-lo-pa",
    "falopear": "fa-lo-pe-ar",
    "falopera": "fa-lo-pe-ra",
    "falopero": "fa-lo-pe-ro",
    "falopio": "fa-lo-pio",
    "falordia": "fa-lor-dia",
    "faloria": "fa-lo-ria",
    "falquía": "fal-quí-a",
    "falsa": "fal-sa",
    "falsaarmadura": "fal-sa-ar-ma-du-ra",
    "falsabilidad": "fal-sa-bi-li-dad",
    "falsable": "fal-sa-ble",
    "falsabraga": "fal-sa-bra-ga",
    "falsación": "fal-sa-ción",
    "falsacionismo": "fal-sa-cio-nis-mo",
    "falsada": "fal-sa-da",
    "falsamente": "fal-sa-men-te",
    "falsar": "fal-sar",
    "falsaria": "fal-sa-ria",
    "falsario": "fal-sa-rio",
    "falsarregla": "fal-sa-rre-gla",
    "falseador": "fal-se-a-dor",
    "falseadora": "fal-se-a-do-ra",
    "falseamiento": "fal-se-a-mien-to",
    "falsear": "fal-se-ar",
    "falsedad": "fal-se-dad",
    "falseo": "fal-se-o",
    "falseta": "fal-se-ta",
    "falsete": "fal-se-te",
    "falsía": "fal-sí-a",
    "falsificación": "fal-si-fi-ca-ción",
    "falsificador": "fal-si-fi-ca-dor",
    "falsificadora": "fal-si-fi-ca-do-ra",
    "falsificar": "fal-si-fi-car",
    "falsilla": "fal-si-lla",
    "falso": "fal-so",
    "falsopeto": "fal-so-pe-to",
    "falta": "fal-ta",
    "faltante": "fal-tan-te",
    "faltar": "fal-tar",
    "falte": "fal-te",
    "faltista": "fal-tis-ta",
    "falto": "fal-to",
    "faltón": "fal-tón",
    "faltona": "fal-to-na",
    "faltosa": "fal-to-sa",
    "faltoso": "fal-to-so",
    "faltrera": "fal-tre-ra",
    "faltrero": "fal-tre-ro",
    "faltriquera": "fal-tri-que-ra",
    "falúa": "fa-lú-a",
    "faluca": "fa-lu-ca",
    "falucho": "fa-lu-cho",
    "fama": "fa-ma",
    "fambre": "fam-bre",
    "fame": "fa-me",
    "famélica": "fa-mé-li-ca",
    "famélico": "fa-mé-li-co",
    "familia": "fa-mi-lia",
    "familiar": "fa-mi-liar",
    "familiaridad": "fa-mi-lia-ri-dad",
    "familiarizar": "fa-mi-lia-ri-zar",
    "familiarmente": "fa-mi-liar-men-te",
    "familiatura": "fa-mi-lia-tu-ra",
    "familio": "fa-mi-lio",
    "familión": "fa-mi-lión",
    "famillo": "fa-mi-llo",
    "famosa": "fa-mo-sa",
    "famosamente": "fa-mo-sa-men-te",
    "famoso": "fa-mo-so",
    "fámula": "fá-mu-la",
    "famular": "fa-mu-lar",
    "famulato": "fa-mu-la-to",
    "famulicio": "fa-mu-li-cio",
    "fámulo": "fá-mu-lo",
    "fañada": "fa-ña-da",
    "fañado": "fa-ña-do",
    "fanal": "fa-nal",
    "fañar": "fa-ñar",
    "fanática": "fa-ná-ti-ca",
    "fanaticada": "fa-na-ti-ca-da",
    "fanáticamente": "fa-ná-ti-ca-men-te",
    "fanático": "fa-ná-ti-co",
    "fanatismo": "fa-na-tis-mo",
    "fanatizador": "fa-na-ti-za-dor",
    "fanatizadora": "fa-na-ti-za-do-ra",
    "fanatizar": "fa-na-ti-zar",
    "fancine": "fan-ci-ne",
    "fandango": "fan-dan-go",
    "fandanguear": "fan-dan-gue-ar",
    "fandanguera": "fan-dan-gue-ra",
    "fandanguero": "fan-dan-gue-ro",
    "fandanguillo": "fan-dan-gui-llo",
    "fandulario": "fan-du-la-rio",
    "faneca": "fa-ne-ca",
    "fanega": "fa-ne-ga",
    "fanegada": "fa-ne-ga-da",
    "faneguero": "fa-ne-gue-ro",
    "fanerógama": "fa-ne-ró-ga-ma",
    "fanerógamas": "fa-ne-ró-ga-mas",
    "fanerógamo": "fa-ne-ró-ga-mo",
    "fanesca": "fa-nes-ca",
    "fanfarrear": "fan-fa-rre-ar",
    "fanfarria": "fan-fa-rria",
    "fanfarrón": "fan-fa-rrón",
    "fanfarrona": "fan-fa-rro-na",
    "fanfarronada": "fan-fa-rro-na-da",
    "fanfarronamente": "fan-fa-rro-na-men-te",
    "fanfarronear": "fan-fa-rro-ne-ar",
    "fanfarronería": "fan-fa-rro-ne-rí-a",
    "fanfarronesca": "fan-fa-rro-nes-ca",
    "fanfurriña": "fan-fu-rri-ña",
    "fangal": "fan-gal",
    "fangar": "fan-gar",
    "fango": "fan-go",
    "fangosa": "fan-go-sa",
    "fangosidad": "fan-go-si-dad",
    "fangoso": "fan-go-so",
    "fangote": "fan-go-te",
    "fanguero": "fan-gue-ro",
    "fanguito": "fan-gui-to",
    "fano": "fa-no",
    "fañosa": "fa-ño-sa",
    "fañoso": "fa-ño-so",
    "fantaseador": "fan-ta-se-a-dor",
    "fantaseadora": "fan-ta-se-a-do-ra",
    "fantasear": "fan-ta-se-ar",
    "fantaseo": "fan-ta-se-o",
    "fantasía": "fan-ta-sí-a",
    "fantasiosa": "fan-ta-sio-sa",
    "fantasioso": "fan-ta-sio-so",
    "fantasma": "fan-tas-ma",
    "fantasmada": "fan-tas-ma-da",
    "fantasmagoría": "fan-tas-ma-go-rí-a",
    "fantasmagórica": "fan-tas-ma-gó-ri-ca",
    "fantasmagóricamente": "fan-tas-ma-gó-ri-ca-men-te",
    "fantasmagórico": "fan-tas-ma-gó-ri-co",
    "fantasmal": "fan-tas-mal",
    "fantasmalmente": "fan-tas-mal-men-te",
    "fantasmático": "fan-tas-má-ti-co",
    "fantasmear": "fan-tas-me-ar",
    "fantasmón": "fan-tas-món",
    "fantasmona": "fan-tas-mo-na",
    "fantástica": "fan-tás-ti-ca",
    "fantásticamente": "fan-tás-ti-ca-men-te",
    "fantástico": "fan-tás-ti-co",
    "fantesioso": "fan-te-sio-so",
    "fantochada": "fan-to-cha-da",
    "fantoche": "fan-to-che",
    "fanzine": "fan-zi-ne",
    "faquí": "fa-quí",
    "faquín": "fa-quín",
    "faquir": "fa-quir",
    "fara": "fa-ra",
    "farabusteador": "fa-ra-bus-te-a-dor",
    "farabustear": "fa-ra-bus-te-ar",
    "farachar": "fa-ra-char",
    "faracho": "fa-ra-cho",
    "farad": "fa-rad",
    "farádico": "fa-rá-di-co",
    "faradio": "fa-ra-dio",
    "faragua": "fa-ra-gua",
    "faragual": "fa-ra-gual",
    "faralá": "fa-ra-lá",
    "faralao": "fa-ra-la-o",
    "faralla": "fa-ra-lla",
    "farallo": "fa-ra-llo",
    "farallón": "fa-ra-llón",
    "faramalla": "fa-ra-ma-lla",
    "faramallera": "fa-ra-ma-lle-ra",
    "faramallero": "fa-ra-ma-lle-ro",
    "faramallón": "fa-ra-ma-llón",
    "faramallona": "fa-ra-ma-llo-na",
    "farandola": "fa-ran-do-la",
    "farándola": "fa-rán-do-la",
    "farándula": "fa-rán-du-la",
    "farandulear": "fa-ran-du-le-ar",
    "farandulera": "fa-ran-du-le-ra",
    "farandulero": "fa-ran-du-le-ro",
    "farandúlica": "fa-ran-dú-li-ca",
    "farandúlico": "fa-ran-dú-li-co",
    "faranga": "fa-ran-ga",
    "faraón": "fa-ra-ón",
    "faraónica": "fa-ra-ó-ni-ca",
    "faraónico": "fa-ra-ó-ni-co",
    "faraute": "fa-rau-te",
    "farda": "far-da",
    "fardacho": "far-da-cho",
    "fardaje": "far-da-je",
    "fardar": "far-dar",
    "farde": "far-de",
    "fardel": "far-del",
    "fardería": "far-de-rí-a",
    "fardo": "far-do",
    "fardón": "far-dón",
    "farellón": "fa-re-llón",
    "farera": "fa-re-ra",
    "farero": "fa-re-ro",
    "farfalá": "far-fa-lá",
    "farfallón": "far-fa-llón",
    "farfallona": "far-fa-llo-na",
    "farfallosa": "far-fa-llo-sa",
    "farfalloso": "far-fa-llo-so",
    "farfán": "far-fán",
    "farfante": "far-fan-te",
    "farfantón": "far-fan-tón",
    "farfantonada": "far-fan-to-na-da",
    "farfantonería": "far-fan-to-ne-rí-a",
    "fárfara": "fár-fa-ra",
    "farfolla": "far-fo-lla",
    "farfulla": "far-fu-lla",
    "farfulladamente": "far-fu-lla-da-men-te",
    "farfullador": "far-fu-lla-dor",
    "farfulladora": "far-fu-lla-do-ra",
    "farfullar": "far-fu-llar",
    "farfullera": "far-fu-lle-ra",
    "farfullero": "far-fu-lle-ro",
    "fargallón": "far-ga-llón",
    "fargallona": "far-ga-llo-na",
    "faria": "fa-ria",
    "farillón": "fa-ri-llón",
    "farina": "fa-ri-na",
    "fariña": "fa-ri-ña",
    "farinácea": "fa-ri-ná-ce-a",
    "farináceo": "fa-ri-ná-ce-o",
    "farinato": "fa-ri-na-to",
    "fariñera": "fa-ri-ñe-ra",
    "farinetas": "fa-ri-ne-tas",
    "faringe": "fa-rin-ge",
    "faríngea": "fa-rín-ge-a",
    "faríngeo": "fa-rín-ge-o",
    "faringitis": "fa-rin-gi-tis",
    "faringotomía": "fa-rin-go-to-mí-a",
    "fariño": "fa-ri-ño",
    "fario": "fa-rio",
    "farisaica": "fa-ri-sai-ca",
    "farisaicamente": "fa-ri-sai-ca-men-te",
    "farisaico": "fa-ri-sai-co",
    "farisaísmo": "fa-ri-sa-ís-mo",
    "fariseísmo": "fa-ri-se-ís-mo",
    "fariseo": "fa-ri-se-o",
    "farlopa": "far-lo-pa",
    "farmaceuta": "far-ma-ceu-ta",
    "farmacéutica": "far-ma-céu-ti-ca",
    "farmacéutico": "far-ma-céu-ti-co",
    "farmacia": "far-ma-cia",
    "fármaco": "fár-ma-co",
    "farmacocinética": "far-ma-co-ci-né-ti-ca",
    "farmacocinético": "far-ma-co-ci-né-ti-co",
    "farmacodinamia": "far-ma-co-di-na-mia",
    "farmacognosia": "far-ma-cog-no-sia",
    "farmacóloga": "far-ma-có-lo-ga",
    "farmacología": "far-ma-co-lo-gí-a",
    "farmacológica": "far-ma-co-ló-gi-ca",
    "farmacológico": "far-ma-co-ló-gi-co",
    "farmacólogo": "far-ma-có-lo-go",
    "farmacopea": "far-ma-co-pe-a",
    "farmacopola": "far-ma-co-po-la",
    "farmacopólica": "far-ma-co-pó-li-ca",
    "farmacopólico": "far-ma-co-pó-li-co",
    "farmacopsicología": "far-ma-cop-si-co-lo-gí-a",
    "farmacopsiquiatría": "far-ma-cop-si-quia-trí-a",
    "farmacoterapia": "far-ma-co-te-ra-pia",
    "farnaca": "far-na-ca",
    "faro": "fa-ro",
    "farol": "fa-rol",
    "farola": "fa-ro-la",
    "farolazo": "fa-ro-la-zo",
    "farolear": "fa-ro-le-ar",
    "faroleo": "fa-ro-le-o",
    "farolera": "fa-ro-le-ra",
    "farolería": "fa-ro-le-rí-a",
    "farolero": "fa-ro-le-ro",
    "farolillo": "fa-ro-li-llo",
    "farolón": "fa-ro-lón",
    "farolona": "fa-ro-lo-na",
    "farón": "fa-rón",
    "farota": "fa-ro-ta",
    "farotón": "fa-ro-tón",
    "farotona": "fa-ro-to-na",
    "farpa": "far-pa",
    "farpada": "far-pa-da",
    "farpado": "far-pa-do",
    "farra": "fa-rra",
    "farraca": "fa-rra-ca",
    "farrago": "fa-rra-go",
    "fárrago": "fá-rra-go",
    "farragosa": "fa-rra-go-sa",
    "farragoso": "fa-rra-go-so",
    "farraguista": "fa-rra-guis-ta",
    "farrapas": "fa-rra-pas",
    "farrapo": "fa-rra-po",
    "farrear": "fa-rre-ar",
    "farrista": "fa-rris-ta",
    "farro": "fa-rro",
    "farruca": "fa-rru-ca",
    "farruco": "fa-rru-co",
    "farruto": "fa-rru-to",
    "farsa": "far-sa",
    "farsálica": "far-sá-li-ca",
    "farsálico": "far-sá-li-co",
    "farsanta": "far-san-ta",
    "farsante": "far-san-te",
    "farsantear": "far-san-te-ar",
    "farsantería": "far-san-te-rí-a",
    "farsar": "far-sar",
    "farseto": "far-se-to",
    "farsista": "far-sis-ta",
    "fartar": "far-tar",
    "farte": "far-te",
    "faruscas": "fa-rus-cas",
    "fascal": "fas-cal",
    "fasces": "fas-ces",
    "fasciculada": "fas-ci-cu-la-da",
    "fasciculado": "fas-ci-cu-la-do",
    "fascículo": "fas-cí-cu-lo",
    "fascinación": "fas-ci-na-ción",
    "fascinador": "fas-ci-na-dor",
    "fascinadora": "fas-ci-na-do-ra",
    "fascinante": "fas-ci-nan-te",
    "fascinar": "fas-ci-nar",
    "fascismo": "fas-cis-mo",
    "fascista": "fas-cis-ta",
    "fascistizante": "fas-cis-ti-zan-te",
    "fascistoide": "fas-cis-toi-de",
    "fase": "fa-se",
    "faséolo": "fa-sé-o-lo",
    "fasímetro": "fa-sí-me-tro",
    "faso": "fa-so",
    "fásol": "fá-sol",
    "fasquía": "fas-quí-a",
    "fasquiar": "fas-quiar",
    "fasta": "fas-ta",
    "fastial": "fas-tial",
    "fastidiada": "fas-ti-dia-da",
    "fastidiado": "fas-ti-dia-do",
    "fastidiar": "fas-ti-diar",
    "fastidieta": "fas-ti-die-ta",
    "fastidio": "fas-ti-dio",
    "fastidiosa": "fas-ti-dio-sa",
    "fastidiosamente": "fas-ti-dio-sa-men-te",
    "fastidioso": "fas-ti-dio-so",
    "fastigiado": "fas-ti-gia-do",
    "fastigio": "fas-ti-gio",
    "fasto": "fas-to",
    "fastos": "fas-tos",
    "fastosa": "fas-to-sa",
    "fastosamente": "fas-to-sa-men-te",
    "fastoso": "fas-to-so",
    "fastuosa": "fas-tuo-sa",
    "fastuosamente": "fas-tuo-sa-men-te",
    "fastuosidad": "fas-tuo-si-dad",
    "fastuoso": "fas-tuo-so",
    "fata": "fa-ta",
    "fatal": "fa-tal",
    "fatalidad": "fa-ta-li-dad",
    "fatalismo": "fa-ta-lis-mo",
    "fatalista": "fa-ta-lis-ta",
    "fatalizar": "fa-ta-li-zar",
    "fatalmente": "fa-tal-men-te",
    "fatamorgana": "fa-ta-mor-ga-na",
    "fatídica": "fa-tí-di-ca",
    "fatídicamente": "fa-tí-di-ca-men-te",
    "fatídico": "fa-tí-di-co",
    "fatiga": "fa-ti-ga",
    "fatigación": "fa-ti-ga-ción",
    "fatigadamente": "fa-ti-ga-da-men-te",
    "fatigado": "fa-ti-ga-do",
    "fatigador": "fa-ti-ga-dor",
    "fatigadora": "fa-ti-ga-do-ra",
    "fatigante": "fa-ti-gan-te",
    "fatigar": "fa-ti-gar",
    "fatigosa": "fa-ti-go-sa",
    "fatigosamente": "fa-ti-go-sa-men-te",
    "fatigoso": "fa-ti-go-so",
    "fatimí": "fa-ti-mí",
    "fatimita": "fa-ti-mi-ta",
    "fato": "fa-to",
    "fator": "fa-tor",
    "fatoría": "fa-to-rí-a",
    "fatua": "fa-tua",
    "fatuamente": "fa-tua-men-te",
    "fatuería": "fa-tue-rí-a",
    "fatuidad": "fa-tui-dad",
    "fatula": "fa-tu-la",
    "fatulo": "fa-tu-lo",
    "fátum": "fá-tum",
    "fatuo": "fa-tuo",
    "faucal": "fau-cal",
    "fauces": "fau-ces",
    "faulkneriano": "faulk-ne-ria-no",
    "fauna": "fau-na",
    "faunesco": "fau-nes-co",
    "fáunico": "fáu-ni-co",
    "faunístico": "fau-nís-ti-co",
    "fauno": "fau-no",
    "faurestina": "fau-res-ti-na",
    "fausta": "faus-ta",
    "fáustico": "fáus-ti-co",
    "fausto": "faus-to",
    "faustosa": "faus-to-sa",
    "faustoso": "faus-to-so",
    "fautor": "fau-tor",
    "fautora": "fau-to-ra",
    "fautoría": "fau-to-rí-a",
    "fauvismo": "fau-vis-mo",
    "fauvista": "fau-vis-ta",
    "favela": "fa-ve-la",
    "favila": "fa-vi-la",
    "favo": "fa-vo",
    "favonio": "fa-vo-nio",
    "favor": "fa-vor",
    "favorable": "fa-vo-ra-ble",
    "favorablemente": "fa-vo-ra-ble-men-te",
    "favorecedor": "fa-vo-re-ce-dor",
    "favorecedora": "fa-vo-re-ce-do-ra",
    "favorecer": "fa-vo-re-cer",
    "favorida": "fa-vo-ri-da",
    "favorido": "fa-vo-ri-do",
    "favorita": "fa-vo-ri-ta",
    "favoritismo": "fa-vo-ri-tis-mo",
    "favorito": "fa-vo-ri-to",
    "faxear": "fa-xe-ar",
    "faya": "fa-ya",
    "fayado": "fa-ya-do",
    "fayanca": "fa-yan-ca",
    "fayuca": "fa-yu-ca",
    "fayuquear": "fa-yu-que-ar",
    "fayuquera": "fa-yu-que-ra",
    "fayuquero": "fa-yu-que-ro",
    "fazaleja": "fa-za-le-ja",
    "fazaña": "fa-za-ña",
    "fazferir": "faz-fe-rir",
    "fazoleto": "fa-zo-le-to",
    "fea": "fe-a",
    "fealdad": "fe-al-dad",
    "feamente": "fe-a-men-te",
    "febea": "fe-be-a",
    "febeo": "fe-be-o",
    "feblaje": "fe-bla-je",
    "feble": "fe-ble",
    "febledad": "fe-ble-dad",
    "feblemente": "fe-ble-men-te",
    "febrera": "fe-bre-ra",
    "febrerillo": "fe-bre-ri-llo",
    "febrero": "fe-bre-ro",
    "febricitante": "fe-bri-ci-tan-te",
    "febrícula": "fe-brí-cu-la",
    "febrida": "fe-bri-da",
    "febrido": "fe-bri-do",
    "febrífuga": "fe-brí-fu-ga",
    "febrífugo": "fe-brí-fu-go",
    "febril": "fe-bril",
    "febrilidad": "fe-bri-li-dad",
    "febrilmente": "fe-bril-men-te",
    "febroniana": "fe-bro-nia-na",
    "febroniano": "fe-bro-nia-no",
    "fecal": "fe-cal",
    "fecha": "fe-cha",
    "fechador": "fe-cha-dor",
    "fechar": "fe-char",
    "fecho": "fe-cho",
    "fechoría": "fe-cho-rí-a",
    "fechura": "fe-chu-ra",
    "fechuría": "fe-chu-rí-a",
    "fecial": "fe-cial",
    "fécula": "fé-cu-la",
    "feculenta": "fe-cu-len-ta",
    "feculento": "fe-cu-len-to",
    "fecunda": "fe-cun-da",
    "fecundable": "fe-cun-da-ble",
    "fecundación": "fe-cun-da-ción",
    "fecundador": "fe-cun-da-dor",
    "fecundadora": "fe-cun-da-do-ra",
    "fecundamente": "fe-cun-da-men-te",
    "fecundante": "fe-cun-dan-te",
    "fecundar": "fe-cun-dar",
    "fecundativa": "fe-cun-da-ti-va",
    "fecundativo": "fe-cun-da-ti-vo",
    "fecundidad": "fe-cun-di-dad",
    "fecundización": "fe-cun-di-za-ción",
    "fecundizador": "fe-cun-di-za-dor",
    "fecundizadora": "fe-cun-di-za-do-ra",
    "fecundizar": "fe-cun-di-zar",
    "fecundo": "fe-cun-do",
    "fedataria": "fe-da-ta-ria",
    "fedatario": "fe-da-ta-rio",
    "fedayín": "fe-da-yín",
    "fedegar": "fe-de-gar",
    "federación": "fe-de-ra-ción",
    "federal": "fe-de-ral",
    "federalismo": "fe-de-ra-lis-mo",
    "federalista": "fe-de-ra-lis-ta",
    "federalización": "fe-de-ra-li-za-ción",
    "federar": "fe-de-rar",
    "federativa": "fe-de-ra-ti-va",
    "federativo": "fe-de-ra-ti-vo",
    "federica": "fe-de-ri-ca",
    "federico": "fe-de-ri-co",
    "feeling": "fe-e-ling",
    "feérico": "fe-é-ri-co",
    "feeza": "fe-e-za",
    "fefaút": "fe-fa-út",
    "féferes": "fé-fe-res",
    "fehaciente": "fe-ha-cien-te",
    "fehacientemente": "fe-ha-cien-te-men-te",
    "feísmo": "fe-ís-mo",
    "feje": "fe-je",
    "felación": "fe-la-ción",
    "feladiz": "fe-la-diz",
    "felariz": "fe-la-riz",
    "feldespática": "fel-des-pá-ti-ca",
    "feldespático": "fel-des-pá-ti-co",
    "feldespato": "fel-des-pa-to",
    "felibre": "fe-li-bre",
    "felice": "fe-li-ce",
    "felicemente": "fe-li-ce-men-te",
    "feliciana": "fe-li-cia-na",
    "feliciano": "fe-li-cia-no",
    "felicidad": "fe-li-ci-dad",
    "felicitación": "fe-li-ci-ta-ción",
    "felicitar": "fe-li-ci-tar",
    "félido": "fé-li-do",
    "feligrés": "fe-li-grés",
    "feligresa": "fe-li-gre-sa",
    "feligresía": "fe-li-gre-sí-a",
    "felina": "fe-li-na",
    "felino": "fe-li-no",
    "felipe": "fe-li-pe",
    "feliz": "fe-liz",
    "felizmente": "fe-liz-men-te",
    "felógeno": "fe-ló-ge-no",
    "felón": "fe-lón",
    "felona": "fe-lo-na",
    "felonía": "fe-lo-ní-a",
    "felpa": "fel-pa",
    "felpar": "fel-par",
    "felpeada": "fel-pe-a-da",
    "felpear": "fel-pe-ar",
    "felpilla": "fel-pi-lla",
    "felpo": "fel-po",
    "felposa": "fel-po-sa",
    "felposo": "fel-po-so",
    "felpuda": "fel-pu-da",
    "felpudo": "fel-pu-do",
    "felús": "fe-lús",
    "femar": "fe-mar",
    "fembra": "fem-bra",
    "femenil": "fe-me-nil",
    "femenilmente": "fe-me-nil-men-te",
    "femenina": "fe-me-ni-na",
    "femenino": "fe-me-ni-no",
    "fementida": "fe-men-ti-da",
    "fementidamente": "fe-men-ti-da-men-te",
    "fementido": "fe-men-ti-do",
    "femera": "fe-me-ra",
    "fémina": "fé-mi-na",
    "feminal": "fe-mi-nal",
    "femínea": "fe-mí-ne-a",
    "femineidad": "fe-mi-nei-dad",
    "feminela": "fe-mi-ne-la",
    "femíneo": "fe-mí-ne-o",
    "feminidad": "fe-mi-ni-dad",
    "feminismo": "fe-mi-nis-mo",
    "feminista": "fe-mi-nis-ta",
    "feminización": "fe-mi-ni-za-ción",
    "feminizar": "fe-mi-ni-zar",
    "feminoide": "fe-mi-noi-de",
    "femoral": "fe-mo-ral",
    "femtogramo": "fem-to-gra-mo",
    "fémur": "fé-mur",
    "fenal": "fe-nal",
    "fenazo": "fe-na-zo",
    "fenda": "fen-da",
    "fendi": "fen-di",
    "fendiente": "fen-dien-te",
    "fendoz": "fen-doz",
    "fenecer": "fe-ne-cer",
    "fenecimiento": "fe-ne-ci-mien-to",
    "fenestra": "fe-nes-tra",
    "fenestraje": "fe-nes-tra-je",
    "fenianismo": "fe-nia-nis-mo",
    "feniano": "fe-nia-no",
    "fenicada": "fe-ni-ca-da",
    "fenicado": "fe-ni-ca-do",
    "fenicar": "fe-ni-car",
    "fenice": "fe-ni-ce",
    "fenicia": "fe-ni-cia",
    "fenicio": "fe-ni-cio",
    "fénico": "fé-ni-co",
    "fenilalanina": "fe-ni-la-la-ni-na",
    "fenilcetonuria": "fe-nil-ce-to-nu-ria",
    "fénix": "fé-nix",
    "fenogreco": "fe-no-gre-co",
    "fenol": "fe-nol",
    "fenología": "fe-no-lo-gí-a",
    "fenológico": "fe-no-ló-gi-co",
    "fenomenal": "fe-no-me-nal",
    "fenomenalismo": "fe-no-me-na-lis-mo",
    "fenomenalista": "fe-no-me-na-lis-ta",
    "fenoménica": "fe-no-mé-ni-ca",
    "fenoménico": "fe-no-mé-ni-co",
    "fenomenismo": "fe-no-me-nis-mo",
    "fenomenista": "fe-no-me-nis-ta",
    "fenómeno": "fe-nó-me-no",
    "fenomenóloga": "fe-no-me-nó-lo-ga",
    "fenomenología": "fe-no-me-no-lo-gí-a",
    "fenomenológico": "fe-no-me-no-ló-gi-co",
    "fenomenólogo": "fe-no-me-nó-lo-go",
    "fenotípica": "fe-no-tí-pi-ca",
    "fenotípico": "fe-no-tí-pi-co",
    "fenotipo": "fe-no-ti-po",
    "feo": "fe-o",
    "feracidad": "fe-ra-ci-dad",
    "feral": "fe-ral",
    "feraz": "fe-raz",
    "ferecracio": "fe-re-cra-cio",
    "feredad": "fe-re-dad",
    "féretro": "fé-re-tro",
    "feria": "fe-ria",
    "feriado": "fe-ria-do",
    "ferial": "fe-rial",
    "feriante": "fe-rian-te",
    "feriar": "fe-riar",
    "ferida": "fe-ri-da",
    "feridad": "fe-ri-dad",
    "feridor": "fe-ri-dor",
    "feridora": "fe-ri-do-ra",
    "ferina": "fe-ri-na",
    "ferino": "fe-ri-no",
    "ferir": "fe-rir",
    "ferlín": "fer-lín",
    "fermata": "fer-ma-ta",
    "fermentable": "fer-men-ta-ble",
    "fermentación": "fer-men-ta-ción",
    "fermentado": "fer-men-ta-do",
    "fermentador": "fer-men-ta-dor",
    "fermentadora": "fer-men-ta-do-ra",
    "fermentar": "fer-men-tar",
    "fermentativa": "fer-men-ta-ti-va",
    "fermentativo": "fer-men-ta-ti-vo",
    "fermento": "fer-men-to",
    "fermi": "fer-mi",
    "fermio": "fer-mio",
    "fermión": "fer-mión",
    "fermosa": "fer-mo-sa",
    "fermoso": "fer-mo-so",
    "fermosura": "fer-mo-su-ra",
    "fernambuco": "fer-nam-bu-co",
    "fernandense": "fer-nan-den-se",
    "fernandina": "fer-nan-di-na",
    "fernandino": "fer-nan-di-no",
    "ferocidad": "fe-ro-ci-dad",
    "ferodo": "fe-ro-do",
    "feromona": "fe-ro-mo-na",
    "feróstica": "fe-rós-ti-ca",
    "feróstico": "fe-rós-ti-co",
    "feroz": "fe-roz",
    "ferozmente": "fe-roz-men-te",
    "ferra": "fe-rra",
    "ferrada": "fe-rra-da",
    "ferrado": "fe-rra-do",
    "ferrador": "fe-rra-dor",
    "ferradura": "fe-rra-du-ra",
    "ferrallista": "fe-rra-llis-ta",
    "ferrar": "fe-rrar",
    "ferrarés": "fe-rra-rés",
    "ferraresa": "fe-rra-re-sa",
    "ferre": "fe-rre",
    "férrea": "fé-rre-a",
    "ferreal": "fe-rre-al",
    "ferreña": "fe-rre-ña",
    "ferreñafana": "fe-rre-ña-fa-na",
    "ferreñafano": "fe-rre-ña-fa-no",
    "férreo": "fé-rre-o",
    "ferrería": "fe-rre-rí-a",
    "ferrero": "fe-rre-ro",
    "ferreruelo": "fe-rre-rue-lo",
    "ferrete": "fe-rre-te",
    "ferretear": "fe-rre-te-ar",
    "ferretera": "fe-rre-te-ra",
    "ferretería": "fe-rre-te-rí-a",
    "ferretero": "fe-rre-te-ro",
    "ferretreque": "fe-rre-tre-que",
    "férrica": "fé-rri-ca",
    "férrico": "fé-rri-co",
    "ferrificar": "fe-rri-fi-car",
    "ferrificarse": "fe-rri-fi-car-se",
    "ferrita": "fe-rri-ta",
    "ferriza": "fe-rri-za",
    "ferrizo": "fe-rri-zo",
    "ferro": "fe-rro",
    "ferrobús": "fe-rro-bús",
    "ferrocarril": "fe-rro-ca-rril",
    "ferrocarrilera": "fe-rro-ca-rri-le-ra",
    "ferrocarrilero": "fe-rro-ca-rri-le-ro",
    "ferrocianhídrico": "fe-rro-cian-hí-dri-co",
    "ferrocianuro": "fe-rro-cia-nu-ro",
    "ferrolana": "fe-rro-la-na",
    "ferrolano": "fe-rro-la-no",
    "ferromagnético": "fe-rro-mag-né-ti-co",
    "ferromagnetismo": "fe-rro-mag-ne-tis-mo",
    "ferromoza": "fe-rro-mo-za",
    "ferromozo": "fe-rro-mo-zo",
    "ferrón": "fe-rrón",
    "ferropénico": "fe-rro-pé-ni-co",
    "ferroprusiato": "fe-rro-pru-sia-to",
    "ferrosa": "fe-rro-sa",
    "ferroso": "fe-rro-so",
    "ferrovanadio": "fe-rro-va-na-dio",
    "ferrovía": "fe-rro-ví-a",
    "ferrovial": "fe-rro-vial",
    "ferroviaria": "fe-rro-via-ria",
    "ferroviario": "fe-rro-via-rio",
    "ferrugienta": "fe-rru-gien-ta",
    "ferrugiento": "fe-rru-gien-to",
    "ferrugínea": "fe-rru-gí-ne-a",
    "ferrugíneo": "fe-rru-gí-ne-o",
    "ferruginosa": "fe-rru-gi-no-sa",
    "ferruginoso": "fe-rru-gi-no-so",
    "fértil": "fér-til",
    "fertilidad": "fer-ti-li-dad",
    "fertilizable": "fer-ti-li-za-ble",
    "fertilización": "fer-ti-li-za-ción",
    "fertilizador": "fer-ti-li-za-dor",
    "fertilizadora": "fer-ti-li-za-do-ra",
    "fertilizante": "fer-ti-li-zan-te",
    "fertilizar": "fer-ti-li-zar",
    "férula": "fé-ru-la",
    "ferulácea": "fe-ru-lá-ce-a",
    "feruláceo": "fe-ru-lá-ce-o",
    "fervencia": "fer-ven-cia",
    "ferventísima": "fer-ven-tí-si-ma",
    "ferventísimo": "fer-ven-tí-si-mo",
    "férvida": "fér-vi-da",
    "férvido": "fér-vi-do",
    "ferviente": "fer-vien-te",
    "fervientemente": "fer-vien-te-men-te",
    "fervor": "fer-vor",
    "fervorar": "fer-vo-rar",
    "fervorín": "fer-vo-rín",
    "fervorizar": "fer-vo-ri-zar",
    "fervorosa": "fer-vo-ro-sa",
    "fervorosamente": "fer-vo-ro-sa-men-te",
    "fervoroso": "fer-vo-ro-so",
    "fescenina": "fes-ce-ni-na",
    "fescenino": "fes-ce-ni-no",
    "fesoria": "fe-so-ria",
    "festa": "fes-ta",
    "festear": "fes-te-ar",
    "festejador": "fes-te-ja-dor",
    "festejadora": "fes-te-ja-do-ra",
    "festejar": "fes-te-jar",
    "festejo": "fes-te-jo",
    "festera": "fes-te-ra",
    "festero": "fes-te-ro",
    "festichola": "fes-ti-cho-la",
    "festín": "fes-tín",
    "festinación": "fes-ti-na-ción",
    "festinadamente": "fes-ti-na-da-men-te",
    "festinar": "fes-ti-nar",
    "festiva": "fes-ti-va",
    "festival": "fes-ti-val",
    "festivalera": "fes-ti-va-le-ra",
    "festivalero": "fes-ti-va-le-ro",
    "festivamente": "fes-ti-va-men-te",
    "festividad": "fes-ti-vi-dad",
    "festivo": "fes-ti-vo",
    "festón": "fes-tón",
    "festonar": "fes-to-nar",
    "festoneada": "fes-to-ne-a-da",
    "festoneado": "fes-to-ne-a-do",
    "festonear": "fes-to-ne-ar",
    "feta": "fe-ta",
    "fetación": "fe-ta-ción",
    "fetal": "fe-tal",
    "fetén": "fe-tén",
    "fetiche": "fe-ti-che",
    "fetichismo": "fe-ti-chis-mo",
    "fetichista": "fe-ti-chis-ta",
    "feticida": "fe-ti-ci-da",
    "feticidio": "fe-ti-ci-dio",
    "fétida": "fé-ti-da",
    "fetidez": "fe-ti-dez",
    "fétido": "fé-ti-do",
    "feto": "fe-to",
    "fetor": "fe-tor",
    "fettuccini": "fet-tuc-ci-ni",
    "fetua": "fe-tua",
    "fetuchini": "fe-tu-chi-ni",
    "feúca": "fe-ú-ca",
    "feúcha": "fe-ú-cha",
    "feúcho": "fe-ú-cho",
    "feúco": "fe-ú-co",
    "feudal": "feu-dal",
    "feudalidad": "feu-da-li-dad",
    "feudalismo": "feu-da-lis-mo",
    "feudalización": "feu-da-li-za-ción",
    "feudar": "feu-dar",
    "feudataria": "feu-da-ta-ria",
    "feudatario": "feu-da-ta-rio",
    "feudo": "feu-do",
    "feúra": "fe-ú-ra",
    "fía": "fí-a",
    "fiabilidad": "fia-bi-li-dad",
    "fiable": "fia-ble",
    "fiaca": "fia-ca",
    "fiacosa": "fia-co-sa",
    "fiacoso": "fia-co-so",
    "fiada": "fia-da",
    "fiado": "fia-do",
    "fiador": "fia-dor",
    "fiadora": "fia-do-ra",
    "fiadura": "fia-du-ra",
    "fiaduría": "fia-du-rí-a",
    "fiambrar": "fiam-brar",
    "fiambre": "fiam-bre",
    "fiambrera": "fiam-bre-ra",
    "fiambrería": "fiam-bre-rí-a",
    "fiana": "fia-na",
    "fianza": "fian-za",
    "fiasco": "fias-co",
    "fíat": "fí-at",
    "fibra": "fi-bra",
    "fibrilación": "fi-bri-la-ción",
    "fibrilar": "fi-bri-lar",
    "fibrina": "fi-bri-na",
    "fibrinógeno": "fi-bri-nó-ge-no",
    "fibrinolisis": "fi-bri-no-li-sis",
    "fibrocartilaginoso": "fi-bro-car-ti-la-gi-no-so",
    "fibrocartílago": "fi-bro-car-tí-la-go",
    "fibrocemento": "fi-bro-ce-men-to",
    "fibroína": "fi-bro-í-na",
    "fibroma": "fi-bro-ma",
    "fibrosa": "fi-bro-sa",
    "fibrosis": "fi-bro-sis",
    "fibroso": "fi-bro-so",
    "fíbula": "fí-bu-la",
    "ficar": "fi-car",
    "ficción": "fic-ción",
    "ficcional": "fic-cio-nal",
    "fice": "fi-ce",
    "ficha": "fi-cha",
    "fichaje": "fi-cha-je",
    "fichar": "fi-char",
    "fichera": "fi-che-ra",
    "fichero": "fi-che-ro",
    "ficoeritrina": "fi-co-e-ri-tri-na",
    "ficoidea": "fi-coi-de-a",
    "ficoideo": "fi-coi-de-o",
    "ficóloga": "fi-có-lo-ga",
    "ficología": "fi-co-lo-gí-a",
    "ficólogo": "fi-có-lo-go",
    "ficticia": "fic-ti-cia",
    "ficticio": "fic-ti-cio",
    "fictivo": "fic-ti-vo",
    "ficus": "fi-cus",
    "fida": "fi-da",
    "fidalga": "fi-dal-ga",
    "fidalgo": "fi-dal-go",
    "fidecomiso": "fi-de-co-mi-so",
    "fidedigna": "fi-de-dig-na",
    "fidedigno": "fi-de-dig-no",
    "fideera": "fi-de-e-ra",
    "fideero": "fi-de-e-ro",
    "fideicomisaria": "fi-dei-co-mi-sa-ria",
    "fideicomisario": "fi-dei-co-mi-sa-rio",
    "fideicomiso": "fi-dei-co-mi-so",
    "fideicomitente": "fi-dei-co-mi-ten-te",
    "fideísmo": "fi-de-ís-mo",
    "fidelidad": "fi-de-li-dad",
    "fidelísima": "fi-de-lí-si-ma",
    "fidelísimo": "fi-de-lí-si-mo",
    "fidelización": "fi-de-li-za-ción",
    "fidelizar": "fi-de-li-zar",
    "fideo": "fi-de-o",
    "fideuá": "fi-deuá",
    "fido": "fi-do",
    "fiducia": "fi-du-cia",
    "fiduciante": "fi-du-cian-te",
    "fiduciaria": "fi-du-cia-ria",
    "fiduciario": "fi-du-cia-rio",
    "fiebre": "fie-bre",
    "fielato": "fie-la-to",
    "fielazgo": "fie-laz-go",
    "fieldad": "fiel-dad",
    "fielmente": "fiel-men-te",
    "fieltrar": "fiel-trar",
    "fieltro": "fiel-tro",
    "fiemo": "fie-mo",
    "fiera": "fie-ra",
    "fierabrás": "fie-ra-brás",
    "fieramente": "fie-ra-men-te",
    "fiereza": "fie-re-za",
    "fiero": "fie-ro",
    "fieróstico": "fie-rós-ti-co",
    "fierra": "fie-rra",
    "fierrada": "fie-rra-da",
    "fierrazo": "fie-rra-zo",
    "fierro": "fie-rro",
    "fiesta": "fies-ta",
    "fiestear": "fies-te-ar",
    "fiestera": "fies-te-ra",
    "fiesterío": "fies-te-rí-o",
    "fiestero": "fies-te-ro",
    "fiestoca": "fies-to-ca",
    "fifar": "fi-far",
    "fifí": "fi-fí",
    "fifiriche": "fi-fi-ri-che",
    "fígaro": "fí-ga-ro",
    "figle": "fi-gle",
    "figo": "fi-go",
    "figón": "fi-gón",
    "figonera": "fi-go-ne-ra",
    "figonero": "fi-go-ne-ro",
    "figueral": "fi-gue-ral",
    "figuerense": "fi-gue-ren-se",
    "figulina": "fi-gu-li-na",
    "figulino": "fi-gu-li-no",
    "figura": "fi-gu-ra",
    "figurable": "fi-gu-ra-ble",
    "figuración": "fi-gu-ra-ción",
    "figurada": "fi-gu-ra-da",
    "figuradamente": "fi-gu-ra-da-men-te",
    "figurado": "fi-gu-ra-do",
    "figural": "fi-gu-ral",
    "figuranta": "fi-gu-ran-ta",
    "figurante": "fi-gu-ran-te",
    "figurar": "fi-gu-rar",
    "figurativa": "fi-gu-ra-ti-va",
    "figurativamente": "fi-gu-ra-ti-va-men-te",
    "figurativismo": "fi-gu-ra-ti-vis-mo",
    "figurativo": "fi-gu-ra-ti-vo",
    "figurear": "fi-gu-re-ar",
    "figureo": "fi-gu-re-o",
    "figurera": "fi-gu-re-ra",
    "figurería": "fi-gu-re-rí-a",
    "figurero": "fi-gu-re-ro",
    "figurilla": "fi-gu-ri-lla",
    "figurín": "fi-gu-rín",
    "figurinista": "fi-gu-ri-nis-ta",
    "figurita": "fi-gu-ri-ta",
    "figurón": "fi-gu-rón",
    "fija": "fi-ja",
    "fijación": "fi-ja-ción",
    "fijada": "fi-ja-da",
    "fijadalgo": "fi-ja-dal-go",
    "fijado": "fi-ja-do",
    "fijador": "fi-ja-dor",
    "fijadora": "fi-ja-do-ra",
    "fijamente": "fi-ja-men-te",
    "fijante": "fi-jan-te",
    "fijapelo": "fi-ja-pe-lo",
    "fijar": "fi-jar",
    "fijativo": "fi-ja-ti-vo",
    "fijeza": "fi-je-za",
    "fijismo": "fi-jis-mo",
    "fijo": "fi-jo",
    "fijodalgo": "fi-jo-dal-go",
    "fijón": "fi-jón",
    "fijona": "fi-jo-na",
    "fila": "fi-la",
    "filacteria": "fi-lac-te-ria",
    "filadelfa": "fi-la-del-fa",
    "filadelfia": "fi-la-del-fia",
    "filadelfiana": "fi-la-del-fia-na",
    "filadelfiano": "fi-la-del-fia-no",
    "filadelfiense": "fi-la-del-fien-se",
    "filadelfio": "fi-la-del-fio",
    "filadelfo": "fi-la-del-fo",
    "filadiz": "fi-la-diz",
    "filado": "fi-la-do",
    "filamento": "fi-la-men-to",
    "filamentosa": "fi-la-men-to-sa",
    "filamentoso": "fi-la-men-to-so",
    "filamiento": "fi-la-mien-to",
    "filandón": "fi-lan-dón",
    "filandria": "fi-lan-dria",
    "filántropa": "fi-lán-tro-pa",
    "filantropía": "fi-lan-tro-pí-a",
    "filantrópica": "fi-lan-tró-pi-ca",
    "filantrópico": "fi-lan-tró-pi-co",
    "filantropismo": "fi-lan-tro-pis-mo",
    "filántropo": "fi-lán-tro-po",
    "filar": "fi-lar",
    "filarete": "fi-la-re-te",
    "filaria": "fi-la-ria",
    "filariasis": "fi-la-ria-sis",
    "filariosis": "fi-la-rio-sis",
    "filarmonía": "fi-lar-mo-ní-a",
    "filarmónica": "fi-lar-mó-ni-ca",
    "filarmónico": "fi-lar-mó-ni-co",
    "filástica": "fi-lás-ti-ca",
    "filatelia": "fi-la-te-lia",
    "filatélica": "fi-la-té-li-ca",
    "filatélico": "fi-la-té-li-co",
    "filatelista": "fi-la-te-lis-ta",
    "filatera": "fi-la-te-ra",
    "filatería": "fi-la-te-rí-a",
    "filatero": "fi-la-te-ro",
    "filático": "fi-lá-ti-co",
    "filatura": "fi-la-tu-ra",
    "filaucía": "fi-lau-cí-a",
    "filautera": "fi-lau-te-ra",
    "filautero": "fi-lau-te-ro",
    "filautía": "fi-lau-tí-a",
    "filazo": "fi-la-zo",
    "filderretor": "fil-de-rre-tor",
    "filelí": "fi-le-lí",
    "filena": "fi-le-na",
    "fileno": "fi-le-no",
    "filera": "fi-le-ra",
    "filete": "fi-le-te",
    "fileteado": "fi-le-te-a-do",
    "fileteador": "fi-le-te-a-dor",
    "fileteadora": "fi-le-te-a-do-ra",
    "filetear": "fi-le-te-ar",
    "filético": "fi-lé-ti-co",
    "filetón": "fi-le-tón",
    "filfa": "fil-fa",
    "filia": "fi-lia",
    "filiación": "fi-lia-ción",
    "filial": "fi-lial",
    "filialmente": "fi-lial-men-te",
    "filiar": "fi-liar",
    "filibote": "fi-li-bo-te",
    "filibusterismo": "fi-li-bus-te-ris-mo",
    "filibustero": "fi-li-bus-te-ro",
    "filicida": "fi-li-ci-da",
    "filicidio": "fi-li-ci-dio",
    "filicínea": "fi-li-cí-ne-a",
    "filicíneo": "fi-li-cí-ne-o",
    "filiera": "fi-lie-ra",
    "filiforme": "fi-li-for-me",
    "filigrana": "fi-li-gra-na",
    "filigranista": "fi-li-gra-nis-ta",
    "fililí": "fi-li-lí",
    "filin": "fi-lin",
    "filín": "fi-lín",
    "filipéndula": "fi-li-pén-du-la",
    "filipense": "fi-li-pen-se",
    "filípica": "fi-lí-pi-ca",
    "filipichín": "fi-li-pi-chín",
    "filipina": "fi-li-pi-na",
    "filipinismo": "fi-li-pi-nis-mo",
    "filipinista": "fi-li-pi-nis-ta",
    "filipino": "fi-li-pi-no",
    "filis": "fi-lis",
    "filistea": "fi-lis-te-a",
    "filisteo": "fi-lis-te-o",
    "filistrín": "fi-lis-trín",
    "filló": "fi-lló",
    "filloa": "fi-llo-a",
    "filloga": "fi-llo-ga",
    "filmación": "fil-ma-ción",
    "filmador": "fil-ma-dor",
    "filmadora": "fil-ma-do-ra",
    "filmar": "fil-mar",
    "filme": "fil-me",
    "fílmico": "fíl-mi-co",
    "filmina": "fil-mi-na",
    "filmlet": "film-let",
    "filmografía": "fil-mo-gra-fí-a",
    "filmográfico": "fil-mo-grá-fi-co",
    "filmología": "fil-mo-lo-gí-a",
    "filmoteca": "fil-mo-te-ca",
    "filo": "fi-lo",
    "filodendro": "fi-lo-den-dro",
    "filodio": "fi-lo-dio",
    "filófaga": "fi-ló-fa-ga",
    "filófago": "fi-ló-fa-go",
    "filogénesis": "fi-lo-gé-ne-sis",
    "filogenético": "fi-lo-ge-né-ti-co",
    "filogenia": "fi-lo-ge-nia",
    "filogermánica": "fi-lo-ger-má-ni-ca",
    "filogermánico": "fi-lo-ger-má-ni-co",
    "filóloga": "fi-ló-lo-ga",
    "filología": "fi-lo-lo-gí-a",
    "filológica": "fi-lo-ló-gi-ca",
    "filológicamente": "fi-lo-ló-gi-ca-men-te",
    "filológico": "fi-lo-ló-gi-co",
    "filólogo": "fi-ló-lo-go",
    "filomanía": "fi-lo-ma-ní-a",
    "filomática": "fi-lo-má-ti-ca",
    "filomático": "fi-lo-má-ti-co",
    "filomela": "fi-lo-me-la",
    "filomena": "fi-lo-me-na",
    "filón": "fi-lón",
    "filonio": "fi-lo-nio",
    "filopluma": "fi-lo-plu-ma",
    "filopos": "fi-lo-pos",
    "filosa": "fi-lo-sa",
    "filoseda": "fi-lo-se-da",
    "filoso": "fi-lo-so",
    "filósofa": "fi-ló-so-fa",
    "filosofador": "fi-lo-so-fa-dor",
    "filosofadora": "fi-lo-so-fa-do-ra",
    "filosofal": "fi-lo-so-fal",
    "filosofalmente": "fi-lo-so-fal-men-te",
    "filosofante": "fi-lo-so-fan-te",
    "filosofar": "fi-lo-so-far",
    "filosofastro": "fi-lo-so-fas-tro",
    "filosofía": "fi-lo-so-fí-a",
    "filosófica": "fi-lo-só-fi-ca",
    "filosóficamente": "fi-lo-só-fi-ca-men-te",
    "filosófico": "fi-lo-só-fi-co",
    "filosofismo": "fi-lo-so-fis-mo",
    "filósofo": "fi-ló-so-fo",
    "filosoviética": "fi-lo-so-vié-ti-ca",
    "filosoviético": "fi-lo-so-vié-ti-co",
    "filotráquea": "fi-lo-trá-que-a",
    "filoxera": "fi-lo-xe-ra",
    "filoxérica": "fi-lo-xé-ri-ca",
    "filoxérico": "fi-lo-xé-ri-co",
    "filtración": "fil-tra-ción",
    "filtrado": "fil-tra-do",
    "filtrador": "fil-tra-dor",
    "filtradora": "fil-tra-do-ra",
    "filtraje": "fil-tra-je",
    "filtrante": "fil-tran-te",
    "filtrar": "fil-trar",
    "filtro": "fil-tro",
    "filuda": "fi-lu-da",
    "filudo": "fi-lu-do",
    "filustre": "fi-lus-tre",
    "filván": "fil-ván",
    "fimbria": "fim-bria",
    "fimo": "fi-mo",
    "fimosis": "fi-mo-sis",
    "fina": "fi-na",
    "finable": "fi-na-ble",
    "finada": "fi-na-da",
    "finado": "fi-na-do",
    "final": "fi-nal",
    "finalidad": "fi-na-li-dad",
    "finalísima": "fi-na-lí-si-ma",
    "finalista": "fi-na-lis-ta",
    "finalización": "fi-na-li-za-ción",
    "finalizador": "fi-na-li-za-dor",
    "finalizar": "fi-na-li-zar",
    "finalmente": "fi-nal-men-te",
    "finamente": "fi-na-men-te",
    "finamiento": "fi-na-mien-to",
    "fiñana": "fi-ña-na",
    "financiable": "fi-nan-cia-ble",
    "financiación": "fi-nan-cia-ción",
    "financiador": "fi-nan-cia-dor",
    "financiadora": "fi-nan-cia-do-ra",
    "financiamiento": "fi-nan-cia-mien-to",
    "financiar": "fi-nan-ciar",
    "financiera": "fi-nan-cie-ra",
    "financiero": "fi-nan-cie-ro",
    "financista": "fi-nan-cis-ta",
    "finanza": "fi-nan-za",
    "finanzas": "fi-nan-zas",
    "finar": "fi-nar",
    "finca": "fin-ca",
    "fincabilidad": "fin-ca-bi-li-dad",
    "fincable": "fin-ca-ble",
    "fincar": "fin-car",
    "finchada": "fin-cha-da",
    "finchado": "fin-cha-do",
    "finchar": "fin-char",
    "fiñe": "fi-ñe",
    "finés": "fi-nés",
    "finesa": "fi-ne-sa",
    "fineta": "fi-ne-ta",
    "fineza": "fi-ne-za",
    "fingida": "fin-gi-da",
    "fingidamente": "fin-gi-da-men-te",
    "fingido": "fin-gi-do",
    "fingidor": "fin-gi-dor",
    "fingidora": "fin-gi-do-ra",
    "fingimiento": "fin-gi-mien-to",
    "fingir": "fin-gir",
    "finible": "fi-ni-ble",
    "finibusterre": "fi-ni-bus-te-rre",
    "finida": "fi-ni-da",
    "finiestra": "fi-nies-tra",
    "finiquitar": "fi-ni-qui-tar",
    "finiquito": "fi-ni-qui-to",
    "finir": "fi-nir",
    "finisecular": "fi-ni-se-cu-lar",
    "finita": "fi-ni-ta",
    "finítima": "fi-ní-ti-ma",
    "finítimo": "fi-ní-ti-mo",
    "finito": "fi-ni-to",
    "finitud": "fi-ni-tud",
    "finlaísmo": "fin-la-ís-mo",
    "finlaísta": "fin-la-ís-ta",
    "finlandés": "fin-lan-dés",
    "finlandesa": "fin-lan-de-sa",
    "fino": "fi-no",
    "finoli": "fi-no-li",
    "finolis": "fi-no-lis",
    "finoúgrio": "fi-no-ú-grio",
    "finquera": "fin-que-ra",
    "finquero": "fin-que-ro",
    "finta": "fin-ta",
    "fintar": "fin-tar",
    "fintear": "fin-te-ar",
    "finura": "fi-nu-ra",
    "finústica": "fi-nús-ti-ca",
    "finústico": "fi-nús-ti-co",
    "finustiquería": "fi-nus-ti-que-rí-a",
    "fiofío": "fio-fí-o",
    "fiordo": "fior-do",
    "fique": "fi-que",
    "firifira": "fi-ri-fi-ra",
    "firifiro": "fi-ri-fi-ro",
    "firma": "fir-ma",
    "firmal": "fir-mal",
    "firmamento": "fir-ma-men-to",
    "firmán": "fir-mán",
    "firmante": "fir-man-te",
    "firmar": "fir-mar",
    "firme": "fir-me",
    "firmemente": "fir-me-men-te",
    "firmeza": "fir-me-za",
    "firmón": "fir-món",
    "firulete": "fi-ru-le-te",
    "firulo": "fi-ru-lo",
    "fisán": "fi-sán",
    "fisberta": "fis-ber-ta",
    "fiscal": "fis-cal",
    "fiscala": "fis-ca-la",
    "fiscalear": "fis-ca-le-ar",
    "fiscalía": "fis-ca-lí-a",
    "fiscalidad": "fis-ca-li-dad",
    "fiscalizable": "fis-ca-li-za-ble",
    "fiscalización": "fis-ca-li-za-ción",
    "fiscalizador": "fis-ca-li-za-dor",
    "fiscalizadora": "fis-ca-li-za-do-ra",
    "fiscalizar": "fis-ca-li-zar",
    "fiscalmente": "fis-cal-men-te",
    "fisco": "fis-co",
    "fiscorno": "fis-cor-no",
    "fisga": "fis-ga",
    "fisgador": "fis-ga-dor",
    "fisgadora": "fis-ga-do-ra",
    "fisgar": "fis-gar",
    "fisgón": "fis-gón",
    "fisgona": "fis-go-na",
    "fisgonear": "fis-go-ne-ar",
    "fisgoneo": "fis-go-ne-o",
    "fisiatra": "fi-sia-tra",
    "fisiatría": "fi-sia-trí-a",
    "fisiátrico": "fi-siá-tri-co",
    "fisible": "fi-si-ble",
    "física": "fí-si-ca",
    "fisicalismo": "fi-si-ca-lis-mo",
    "físicamente": "fí-si-ca-men-te",
    "físico": "fí-si-co",
    "fisicoculturismo": "fi-si-co-cul-tu-ris-mo",
    "fisicoquímica": "fi-si-co-quí-mi-ca",
    "fisicoquímico": "fi-si-co-quí-mi-co",
    "fisiculturismo": "fi-si-cul-tu-ris-mo",
    "fisio": "fi-sio",
    "fisiocracia": "fi-sio-cra-cia",
    "fisiócrata": "fi-sió-cra-ta",
    "fisioculturismo": "fi-sio-cul-tu-ris-mo",
    "fisiognomía": "fi-siog-no-mí-a",
    "fisiognómica": "fi-siog-nó-mi-ca",
    "fisiognómico": "fi-siog-nó-mi-co",
    "fisiografía": "fi-sio-gra-fí-a",
    "fisiográfico": "fi-sio-grá-fi-co",
    "fisióloga": "fi-sió-lo-ga",
    "fisiología": "fi-sio-lo-gí-a",
    "fisiológica": "fi-sio-ló-gi-ca",
    "fisiológicamente": "fi-sio-ló-gi-ca-men-te",
    "fisiológico": "fi-sio-ló-gi-co",
    "fisiólogo": "fi-sió-lo-go",
    "fisión": "fi-sión",
    "fisionable": "fi-sio-na-ble",
    "fisionar": "fi-sio-nar",
    "fisionomía": "fi-sio-no-mí-a",
    "fisiopatología": "fi-sio-pa-to-lo-gí-a",
    "fisiopatológico": "fi-sio-pa-to-ló-gi-co",
    "fisioterapeuta": "fi-sio-te-ra-peu-ta",
    "fisioterapéutico": "fi-sio-te-ra-péu-ti-co",
    "fisioterapia": "fi-sio-te-ra-pia",
    "fisioterápico": "fi-sio-te-rá-pi-co",
    "fisioterapista": "fi-sio-te-ra-pis-ta",
    "fisiparidad": "fi-si-pa-ri-dad",
    "fisípeda": "fi-sí-pe-da",
    "fisípedo": "fi-sí-pe-do",
    "fisiquear": "fi-si-que-ar",
    "fisirrostra": "fi-si-rros-tra",
    "fisirrostro": "fi-si-rros-tro",
    "fisónoma": "fi-só-no-ma",
    "fisonomía": "fi-so-no-mí-a",
    "fisonómica": "fi-so-nó-mi-ca",
    "fisonómico": "fi-so-nó-mi-co",
    "fisonomista": "fi-so-no-mis-ta",
    "fisónomo": "fi-só-no-mo",
    "fisostigmina": "fi-sos-tig-mi-na",
    "fisóstomo": "fi-sós-to-mo",
    "fisto": "fis-to",
    "fistol": "fis-tol",
    "fístola": "fís-to-la",
    "fistolar": "fis-to-lar",
    "fistra": "fis-tra",
    "fístula": "fís-tu-la",
    "fistulación": "fis-tu-la-ción",
    "fistular": "fis-tu-lar",
    "fistulosa": "fis-tu-lo-sa",
    "fistuloso": "fis-tu-lo-so",
    "fisura": "fi-su-ra",
    "fisurar": "fi-su-rar",
    "fita": "fi-ta",
    "fito": "fi-to",
    "fitocromático": "fi-to-cro-má-ti-co",
    "fitófaga": "fi-tó-fa-ga",
    "fitófago": "fi-tó-fa-go",
    "fitoftirio": "fi-tof-ti-rio",
    "fitógrafa": "fi-tó-gra-fa",
    "fitografía": "fi-to-gra-fí-a",
    "fitográfica": "fi-to-grá-fi-ca",
    "fitográfico": "fi-to-grá-fi-co",
    "fitógrafo": "fi-tó-gra-fo",
    "fitolacácea": "fi-to-la-cá-ce-a",
    "fitolacáceo": "fi-to-la-cá-ce-o",
    "fitología": "fi-to-lo-gí-a",
    "fitonisa": "fi-to-ni-sa",
    "fitopatología": "fi-to-pa-to-lo-gí-a",
    "fitoplancton": "fi-to-planc-ton",
    "fitoquímica": "fi-to-quí-mi-ca",
    "fitosanitario": "fi-to-sa-ni-ta-rio",
    "fitosociología": "fi-to-so-cio-lo-gí-a",
    "fitoterapeuta": "fi-to-te-ra-peu-ta",
    "fitoterapia": "fi-to-te-ra-pia",
    "fitotomía": "fi-to-to-mí-a",
    "fiucia": "fiu-cia",
    "fiyiana": "fi-yia-na",
    "fiyiano": "fi-yia-no",
    "fiyuela": "fi-yue-la",
    "fizar": "fi-zar",
    "fizón": "fi-zón",
    "flabelado": "fla-be-la-do",
    "flabelicornio": "fla-be-li-cor-nio",
    "flabelífera": "fla-be-lí-fe-ra",
    "flabelífero": "fla-be-lí-fe-ro",
    "flabeliforme": "fla-be-li-for-me",
    "flabelo": "fla-be-lo",
    "flaca": "fla-ca",
    "flacamente": "fla-ca-men-te",
    "fláccida": "flác-ci-da",
    "flaccidez": "flac-ci-dez",
    "fláccido": "flác-ci-do",
    "flacidez": "fla-ci-dez",
    "flácido": "flá-ci-do",
    "flaco": "fla-co",
    "flacón": "fla-cón",
    "flacucha": "fla-cu-cha",
    "flacuchento": "fla-cu-chen-to",
    "flacucho": "fla-cu-cho",
    "flacuncho": "fla-cun-cho",
    "flacura": "fla-cu-ra",
    "flagelación": "fla-ge-la-ción",
    "flagelada": "fla-ge-la-da",
    "flagelado": "fla-ge-la-do",
    "flagelador": "fla-ge-la-dor",
    "flageladora": "fla-ge-la-do-ra",
    "flagelante": "fla-ge-lan-te",
    "flagelar": "fla-ge-lar",
    "flagelo": "fla-ge-lo",
    "flageolet": "fla-ge-o-let",
    "flagicio": "fla-gi-cio",
    "flagiciosa": "fla-gi-cio-sa",
    "flagicioso": "fla-gi-cio-so",
    "flagrancia": "fla-gran-cia",
    "flagrante": "fla-gran-te",
    "flagrar": "fla-grar",
    "flama": "fla-ma",
    "flamante": "fla-man-te",
    "flambear": "flam-be-ar",
    "flamboyán": "flam-bo-yán",
    "flamear": "fla-me-ar",
    "flamen": "fla-men",
    "flamenca": "fla-men-ca",
    "flamenco": "fla-men-co",
    "flamencóloga": "fla-men-có-lo-ga",
    "flamencología": "fla-men-co-lo-gí-a",
    "flamencólogo": "fla-men-có-lo-go",
    "flamenquería": "fla-men-que-rí-a",
    "flamenquilla": "fla-men-qui-lla",
    "flamenquismo": "fla-men-quis-mo",
    "flameo": "fla-me-o",
    "flámeo": "flá-me-o",
    "flamero": "fla-me-ro",
    "flamígera": "fla-mí-ge-ra",
    "flamígero": "fla-mí-ge-ro",
    "flámula": "flá-mu-la",
    "flanco": "flan-co",
    "flandes": "flan-des",
    "flanera": "fla-ne-ra",
    "flanero": "fla-ne-ro",
    "flanqueada": "flan-que-a-da",
    "flanqueado": "flan-que-a-do",
    "flanqueador": "flan-que-a-dor",
    "flanqueadora": "flan-que-a-do-ra",
    "flanquear": "flan-que-ar",
    "flanqueo": "flan-que-o",
    "flanquís": "flan-quís",
    "flaón": "fla-ón",
    "flaquear": "fla-que-ar",
    "flaquencia": "fla-quen-cia",
    "flaquera": "fla-que-ra",
    "flaqueza": "fla-que-za",
    "flato": "fla-to",
    "flatosa": "fla-to-sa",
    "flatoso": "fla-to-so",
    "flatulencia": "fla-tu-len-cia",
    "flatulenta": "fla-tu-len-ta",
    "flatulento": "fla-tu-len-to",
    "flatuosa": "fla-tuo-sa",
    "flatuoso": "fla-tuo-so",
    "flaubertiana": "flau-ber-tia-na",
    "flaubertiano": "flau-ber-tia-no",
    "flauta": "flau-ta",
    "flautada": "flau-ta-da",
    "flautado": "flau-ta-do",
    "flauteada": "flau-te-a-da",
    "flauteado": "flau-te-a-do",
    "flautero": "flau-te-ro",
    "flautillo": "flau-ti-llo",
    "flautín": "flau-tín",
    "flautista": "flau-tis-ta",
    "flautos": "flau-tos",
    "flava": "fla-va",
    "flavo": "fla-vo",
    "flébil": "flé-bil",
    "flebítica": "fle-bí-ti-ca",
    "flebítico": "fle-bí-ti-co",
    "flebitis": "fle-bi-tis",
    "flebotomía": "fle-bo-to-mí-a",
    "flebotomiano": "fle-bo-to-mia-no",
    "flecadura": "fle-ca-du-ra",
    "flecha": "fle-cha",
    "flechado": "fle-cha-do",
    "flechador": "fle-cha-dor",
    "flechadura": "fle-cha-du-ra",
    "flechar": "fle-char",
    "flechaste": "fle-chas-te",
    "flechazo": "fle-cha-zo",
    "flechera": "fle-che-ra",
    "flechería": "fle-che-rí-a",
    "flechero": "fle-che-ro",
    "flechilla": "fle-chi-lla",
    "fleco": "fle-co",
    "flectar": "flec-tar",
    "flegma": "fleg-ma",
    "flegmática": "fleg-má-ti-ca",
    "flegmático": "fleg-má-ti-co",
    "flegmonosa": "fleg-mo-no-sa",
    "flegmonoso": "fleg-mo-no-so",
    "fleja": "fle-ja",
    "flejar": "fle-jar",
    "fleje": "fle-je",
    "flema": "fle-ma",
    "flemática": "fle-má-ti-ca",
    "flemático": "fle-má-ti-co",
    "fleme": "fle-me",
    "flemón": "fle-món",
    "flemonosa": "fle-mo-no-sa",
    "flemonoso": "fle-mo-no-so",
    "flemosa": "fle-mo-sa",
    "flemoso": "fle-mo-so",
    "flemuda": "fle-mu-da",
    "flemudo": "fle-mu-do",
    "fleo": "fle-o",
    "flequillo": "fle-qui-llo",
    "fleta": "fle-ta",
    "fletachar": "fle-ta-char",
    "fletación": "fle-ta-ción",
    "fletado": "fle-ta-do",
    "fletador": "fle-ta-dor",
    "fletamento": "fle-ta-men-to",
    "fletán": "fle-tán",
    "fletanero": "fle-ta-ne-ro",
    "fletante": "fle-tan-te",
    "fletar": "fle-tar",
    "flete": "fle-te",
    "fletear": "fle-te-ar",
    "fleteo": "fle-te-o",
    "fletera": "fle-te-ra",
    "fletero": "fle-te-ro",
    "fleto": "fle-to",
    "flexibilidad": "fle-xi-bi-li-dad",
    "flexibilización": "fle-xi-bi-li-za-ción",
    "flexibilizar": "fle-xi-bi-li-zar",
    "flexible": "fle-xi-ble",
    "flexión": "fle-xión",
    "flexional": "fle-xio-nal",
    "flexionar": "fle-xio-nar",
    "flexivo": "fle-xi-vo",
    "flexo": "fle-xo",
    "flexor": "fle-xor",
    "flexora": "fle-xo-ra",
    "flexuosa": "fle-xuo-sa",
    "flexuoso": "fle-xuo-so",
    "flexura": "fle-xu-ra",
    "flictena": "flic-te-na",
    "flipar": "fli-par",
    "flipe": "fli-pe",
    "flipear": "fli-pe-ar",
    "flipera": "fli-pe-ra",
    "flipero": "fli-pe-ro",
    "flirtear": "flir-te-ar",
    "flirteo": "flir-te-o",
    "fliscorno": "flis-cor-no",
    "flocadura": "flo-ca-du-ra",
    "floculación": "flo-cu-la-ción",
    "floculante": "flo-cu-lan-te",
    "flocular": "flo-cu-lar",
    "flóculo": "fló-cu-lo",
    "floema": "flo-e-ma",
    "flogística": "flo-gís-ti-ca",
    "flogístico": "flo-gís-ti-co",
    "flogisto": "flo-gis-to",
    "flogosis": "flo-go-sis",
    "floja": "flo-ja",
    "flojamente": "flo-ja-men-te",
    "flojaza": "flo-ja-za",
    "flojazo": "flo-ja-zo",
    "flojear": "flo-je-ar",
    "flojedad": "flo-je-dad",
    "flojel": "flo-jel",
    "flojera": "flo-je-ra",
    "flojeritis": "flo-je-ri-tis",
    "flojo": "flo-jo",
    "flojuelo": "flo-jue-lo",
    "flojura": "flo-ju-ra",
    "floqueada": "flo-que-a-da",
    "floqueado": "flo-que-a-do",
    "flora": "flo-ra",
    "floración": "flo-ra-ción",
    "florada": "flo-ra-da",
    "floraina": "flo-rai-na",
    "floral": "flo-ral",
    "florar": "flo-rar",
    "flordelisada": "flor-de-li-sa-da",
    "flordelisado": "flor-de-li-sa-do",
    "flordelisar": "flor-de-li-sar",
    "floreado": "flo-re-a-do",
    "floreal": "flo-re-al",
    "florear": "flo-re-ar",
    "florecedor": "flo-re-ce-dor",
    "florecedora": "flo-re-ce-do-ra",
    "florecer": "flo-re-cer",
    "florecido": "flo-re-ci-do",
    "floreciente": "flo-re-cien-te",
    "florecimiento": "flo-re-ci-mien-to",
    "florencia": "flo-ren-cia",
    "florense": "flo-ren-se",
    "florentín": "flo-ren-tín",
    "florentina": "flo-ren-ti-na",
    "florentino": "flo-ren-ti-no",
    "florentísima": "flo-ren-tí-si-ma",
    "florentísimo": "flo-ren-tí-si-mo",
    "floreo": "flo-re-o",
    "florera": "flo-re-ra",
    "florería": "flo-re-rí-a",
    "florero": "flo-re-ro",
    "florescencia": "flo-res-cen-cia",
    "florescer": "flo-res-cer",
    "floresta": "flo-res-ta",
    "florestero": "flo-res-te-ro",
    "floreta": "flo-re-ta",
    "floretada": "flo-re-ta-da",
    "floretazo": "flo-re-ta-zo",
    "florete": "flo-re-te",
    "floretear": "flo-re-te-ar",
    "floreteo": "flo-re-te-o",
    "floretista": "flo-re-tis-ta",
    "floricultor": "flo-ri-cul-tor",
    "floricultora": "flo-ri-cul-to-ra",
    "floricultura": "flo-ri-cul-tu-ra",
    "florida": "flo-ri-da",
    "floridamente": "flo-ri-da-men-te",
    "floridana": "flo-ri-da-na",
    "floridano": "flo-ri-da-no",
    "floridense": "flo-ri-den-se",
    "floridez": "flo-ri-dez",
    "florido": "flo-ri-do",
    "florífera": "flo-rí-fe-ra",
    "florífero": "flo-rí-fe-ro",
    "florígera": "flo-rí-ge-ra",
    "florígero": "flo-rí-ge-ro",
    "florilegio": "flo-ri-le-gio",
    "florín": "flo-rín",
    "floripón": "flo-ri-pón",
    "floripondio": "flo-ri-pon-dio",
    "florista": "flo-ris-ta",
    "floristería": "flo-ris-te-rí-a",
    "florístico": "flo-rís-ti-co",
    "floritura": "flo-ri-tu-ra",
    "florlisar": "flor-li-sar",
    "florón": "flo-rón",
    "flósculo": "flós-cu-lo",
    "flota": "flo-ta",
    "flotabilidad": "flo-ta-bi-li-dad",
    "flotable": "flo-ta-ble",
    "flotación": "flo-ta-ción",
    "flotador": "flo-ta-dor",
    "flotadora": "flo-ta-do-ra",
    "flotadura": "flo-ta-du-ra",
    "flotamiento": "flo-ta-mien-to",
    "flotante": "flo-tan-te",
    "flotar": "flo-tar",
    "flote": "flo-te",
    "flotilla": "flo-ti-lla",
    "fluctuación": "fluc-tua-ción",
    "fluctuante": "fluc-tuan-te",
    "fluctuar": "fluc-tuar",
    "fluctuosa": "fluc-tuo-sa",
    "fluctuoso": "fluc-tuo-so",
    "flueco": "flue-co",
    "fluencia": "fluen-cia",
    "fluente": "fluen-te",
    "fluida": "flui-da",
    "fluidez": "flui-dez",
    "fluidificación": "flui-di-fi-ca-ción",
    "fluidificante": "flui-di-fi-can-te",
    "fluidificar": "flui-di-fi-car",
    "fluidización": "flui-di-za-ción",
    "fluido": "flui-do",
    "flujo": "flu-jo",
    "fluminense": "flu-mi-nen-se",
    "flúor": "flú-or",
    "fluoración": "fluo-ra-ción",
    "fluorado": "fluo-ra-do",
    "fluorar": "fluo-rar",
    "fluorescencia": "fluo-res-cen-cia",
    "fluorescente": "fluo-res-cen-te",
    "fluorhídrico": "fluo-rhí-dri-co",
    "fluorimetría": "fluo-ri-me-trí-a",
    "fluorina": "fluo-ri-na",
    "fluorita": "fluo-ri-ta",
    "fluoruro": "fluo-ru-ro",
    "fluvial": "flu-vial",
    "fluviómetro": "flu-vió-me-tro",
    "fluxibilidad": "flu-xi-bi-li-dad",
    "fluxible": "flu-xi-ble",
    "fluxímetro": "flu-xí-me-tro",
    "fluxión": "flu-xión",
    "fluyente": "flu-yen-te",
    "fobia": "fo-bia",
    "fóbica": "fó-bi-ca",
    "fóbico": "fó-bi-co",
    "foca": "fo-ca",
    "focal": "fo-cal",
    "focalización": "fo-ca-li-za-ción",
    "focalizar": "fo-ca-li-zar",
    "foceifiza": "fo-cei-fi-za",
    "focense": "fo-cen-se",
    "focha": "fo-cha",
    "focia": "fo-cia",
    "focino": "fo-ci-no",
    "focio": "fo-cio",
    "foco": "fo-co",
    "fóculo": "fó-cu-lo",
    "fodolí": "fo-do-lí",
    "fodongo": "fo-don-go",
    "fodonguería": "fo-don-gue-rí-a",
    "foete": "fo-e-te",
    "fofa": "fo-fa",
    "fofo": "fo-fo",
    "fogaje": "fo-ga-je",
    "fogarada": "fo-ga-ra-da",
    "fogarata": "fo-ga-ra-ta",
    "fogarear": "fo-ga-re-ar",
    "fogaril": "fo-ga-ril",
    "fogarín": "fo-ga-rín",
    "fogarizar": "fo-ga-ri-zar",
    "fogata": "fo-ga-ta",
    "fogón": "fo-gón",
    "fogonadura": "fo-go-na-du-ra",
    "fogonazo": "fo-go-na-zo",
    "fogonera": "fo-go-ne-ra",
    "fogonero": "fo-go-ne-ro",
    "fogosa": "fo-go-sa",
    "fogosidad": "fo-go-si-dad",
    "fogoso": "fo-go-so",
    "fogueación": "fo-gue-a-ción",
    "foguear": "fo-gue-ar",
    "fogueo": "fo-gue-o",
    "foguera": "fo-gue-ra",
    "foguerear": "fo-gue-re-ar",
    "foguero": "fo-gue-ro",
    "foisa": "foi-sa",
    "foiso": "foi-so",
    "foja": "fo-ja",
    "folclor": "fol-clor",
    "folclore": "fol-clo-re",
    "folclórica": "fol-cló-ri-ca",
    "folclórico": "fol-cló-ri-co",
    "folclorista": "fol-clo-ris-ta",
    "fólder": "fól-der",
    "folga": "fol-ga",
    "folgada": "fol-ga-da",
    "folgado": "fol-ga-do",
    "folganza": "fol-gan-za",
    "folgar": "fol-gar",
    "folgo": "fol-go",
    "folía": "fo-lí-a",
    "foliácea": "fo-liá-ce-a",
    "foliáceo": "fo-liá-ce-o",
    "foliación": "fo-lia-ción",
    "foliado": "fo-lia-do",
    "foliador": "fo-lia-dor",
    "foliadora": "fo-lia-do-ra",
    "foliar": "fo-liar",
    "foliatura": "fo-lia-tu-ra",
    "folicular": "fo-li-cu-lar",
    "foliculario": "fo-li-cu-la-rio",
    "folículo": "fo-lí-cu-lo",
    "folidoto": "fo-li-do-to",
    "folijones": "fo-li-jo-nes",
    "folio": "fo-lio",
    "folíolo": "fo-lí-o-lo",
    "foliolo": "fo-lio-lo",
    "folión": "fo-lión",
    "folklore": "fol-klo-re",
    "folklórica": "fol-kló-ri-ca",
    "folklórico": "fol-kló-ri-co",
    "folklorista": "fol-klo-ris-ta",
    "folla": "fo-lla",
    "follada": "fo-lla-da",
    "follado": "fo-lla-do",
    "follador": "fo-lla-dor",
    "follaje": "fo-lla-je",
    "follajería": "fo-lla-je-rí-a",
    "follar": "fo-llar",
    "follero": "fo-lle-ro",
    "folleta": "fo-lle-ta",
    "folletero": "fo-lle-te-ro",
    "folletín": "fo-lle-tín",
    "folletinesca": "fo-lle-ti-nes-ca",
    "folletinesco": "fo-lle-ti-nes-co",
    "folletinista": "fo-lle-ti-nis-ta",
    "folletista": "fo-lle-tis-ta",
    "folleto": "fo-lle-to",
    "folletón": "fo-lle-tón",
    "follisca": "fo-llis-ca",
    "follón": "fo-llón",
    "follona": "fo-llo-na",
    "follonera": "fo-llo-ne-ra",
    "follonería": "fo-llo-ne-rí-a",
    "follonero": "fo-llo-ne-ro",
    "follonía": "fo-llo-ní-a",
    "foluz": "fo-luz",
    "fome": "fo-me",
    "fomentación": "fo-men-ta-ción",
    "fomentador": "fo-men-ta-dor",
    "fomentadora": "fo-men-ta-do-ra",
    "fomentar": "fo-men-tar",
    "fomento": "fo-men-to",
    "fomes": "fo-mes",
    "fómite": "fó-mi-te",
    "fona": "fo-na",
    "fonación": "fo-na-ción",
    "fonador": "fo-na-dor",
    "fonazo": "fo-na-zo",
    "foncarralera": "fon-ca-rra-le-ra",
    "foncarralero": "fon-ca-rra-le-ro",
    "fonda": "fon-da",
    "fondable": "fon-da-ble",
    "fondac": "fon-dac",
    "fondada": "fon-da-da",
    "fondado": "fon-da-do",
    "fondeada": "fon-de-a-da",
    "fondeadero": "fon-de-a-de-ro",
    "fondeado": "fon-de-a-do",
    "fondear": "fon-de-ar",
    "fondeo": "fon-de-o",
    "fondera": "fon-de-ra",
    "fondero": "fon-de-ro",
    "fondillo": "fon-di-llo",
    "fondillón": "fon-di-llón",
    "fondista": "fon-dis-ta",
    "fondo": "fon-do",
    "fondón": "fon-dón",
    "fondona": "fon-do-na",
    "fondonga": "fon-don-ga",
    "fondongo": "fon-don-go",
    "fonducho": "fon-du-cho",
    "fondue": "fon-due",
    "fonébol": "fo-né-bol",
    "fonema": "fo-ne-ma",
    "fonemática": "fo-ne-má-ti-ca",
    "fonemático": "fo-ne-má-ti-co",
    "fonendo": "fo-nen-do",
    "fonendoscopio": "fo-nen-dos-co-pio",
    "fonética": "fo-né-ti-ca",
    "fonéticamente": "fo-né-ti-ca-men-te",
    "fonético": "fo-né-ti-co",
    "fonetismo": "fo-ne-tis-mo",
    "fonetista": "fo-ne-tis-ta",
    "foniatra": "fo-nia-tra",
    "foniatría": "fo-nia-trí-a",
    "fónica": "fó-ni-ca",
    "fónico": "fó-ni-co",
    "fonil": "fo-nil",
    "fonio": "fo-nio",
    "fonje": "fon-je",
    "fono": "fo-no",
    "fonocaptor": "fo-no-cap-tor",
    "fonografía": "fo-no-gra-fí-a",
    "fonográfica": "fo-no-grá-fi-ca",
    "fonográfico": "fo-no-grá-fi-co",
    "fonógrafo": "fo-nó-gra-fo",
    "fonograma": "fo-no-gra-ma",
    "fonola": "fo-no-la",
    "fonolita": "fo-no-li-ta",
    "fonóloga": "fo-nó-lo-ga",
    "fonología": "fo-no-lo-gí-a",
    "fonológica": "fo-no-ló-gi-ca",
    "fonológico": "fo-no-ló-gi-co",
    "fonologización": "fo-no-lo-gi-za-ción",
    "fonólogo": "fo-nó-lo-go",
    "fonometría": "fo-no-me-trí-a",
    "fonómetro": "fo-nó-me-tro",
    "fonomímica": "fo-no-mí-mi-ca",
    "fonomímico": "fo-no-mí-mi-co",
    "fonóptico": "fo-nóp-ti-co",
    "fonoteca": "fo-no-te-ca",
    "fonotecnia": "fo-no-tec-nia",
    "fonotécnica": "fo-no-téc-ni-ca",
    "fonotécnico": "fo-no-téc-ni-co",
    "fonsadera": "fon-sa-de-ra",
    "fonsado": "fon-sa-do",
    "fonsario": "fon-sa-rio",
    "fontal": "fon-tal",
    "fontana": "fon-ta-na",
    "fontanal": "fon-ta-nal",
    "fontanar": "fon-ta-nar",
    "fontanela": "fon-ta-ne-la",
    "fontanera": "fon-ta-ne-ra",
    "fontanería": "fon-ta-ne-rí-a",
    "fontanero": "fon-ta-ne-ro",
    "fontano": "fon-ta-no",
    "fontanosa": "fon-ta-no-sa",
    "fontanoso": "fon-ta-no-so",
    "fontegí": "fon-te-gí",
    "fontículo": "fon-tí-cu-lo",
    "foque": "fo-que",
    "forada": "fo-ra-da",
    "forado": "fo-ra-do",
    "foraida": "fo-rai-da",
    "forajida": "fo-ra-ji-da",
    "forajido": "fo-ra-ji-do",
    "foral": "fo-ral",
    "foralismo": "fo-ra-lis-mo",
    "foralmente": "fo-ral-men-te",
    "forambre": "fo-ram-bre",
    "foramen": "fo-ra-men",
    "foraminífero": "fo-ra-mi-ní-fe-ro",
    "foraña": "fo-ra-ña",
    "foránea": "fo-rá-ne-a",
    "foráneo": "fo-rá-ne-o",
    "forano": "fo-ra-no",
    "foraño": "fo-ra-ño",
    "foras": "fo-ras",
    "forastera": "fo-ras-te-ra",
    "forastero": "fo-ras-te-ro",
    "forca": "for-ca",
    "forcate": "for-ca-te",
    "forcatear": "for-ca-te-ar",
    "forcaz": "for-caz",
    "forcejar": "for-ce-jar",
    "forcejear": "for-ce-je-ar",
    "forcejeo": "for-ce-je-o",
    "forcejo": "for-ce-jo",
    "forcejón": "for-ce-jón",
    "forcejuda": "for-ce-ju-da",
    "forcejudo": "for-ce-ju-do",
    "fórceps": "fór-ceps",
    "forchina": "for-chi-na",
    "forcina": "for-ci-na",
    "forcípula": "for-cí-pu-la",
    "forcir": "for-cir",
    "forense": "fo-ren-se",
    "forera": "fo-re-ra",
    "forero": "fo-re-ro",
    "foresta": "fo-res-ta",
    "forestación": "fo-res-ta-ción",
    "forestal": "fo-res-tal",
    "forestar": "fo-res-tar",
    "forfait": "for-fait",
    "fórfolas": "fór-fo-las",
    "forigar": "fo-ri-gar",
    "forillo": "fo-ri-llo",
    "forínseca": "fo-rín-se-ca",
    "forínseco": "fo-rín-se-co",
    "forista": "fo-ris-ta",
    "forja": "for-ja",
    "forjado": "for-ja-do",
    "forjador": "for-ja-dor",
    "forjadora": "for-ja-do-ra",
    "forjadura": "for-ja-du-ra",
    "forjar": "for-jar",
    "forlón": "for-lón",
    "forma": "for-ma",
    "formable": "for-ma-ble",
    "formación": "for-ma-ción",
    "formador": "for-ma-dor",
    "formadora": "for-ma-do-ra",
    "formadura": "for-ma-du-ra",
    "formaje": "for-ma-je",
    "formal": "for-mal",
    "formaldehído": "for-mal-de-hí-do",
    "formaleta": "for-ma-le-ta",
    "formalete": "for-ma-le-te",
    "formalidad": "for-ma-li-dad",
    "formalina": "for-ma-li-na",
    "formalismo": "for-ma-lis-mo",
    "formalista": "for-ma-lis-ta",
    "formalización": "for-ma-li-za-ción",
    "formalizar": "for-ma-li-zar",
    "formalmente": "for-mal-men-te",
    "formalote": "for-ma-lo-te",
    "formante": "for-man-te",
    "formar": "for-mar",
    "formatear": "for-ma-te-ar",
    "formateo": "for-ma-te-o",
    "formativa": "for-ma-ti-va",
    "formativo": "for-ma-ti-vo",
    "formato": "for-ma-to",
    "formatriz": "for-ma-triz",
    "formenterana": "for-men-te-ra-na",
    "formenterano": "for-men-te-ra-no",
    "formenterense": "for-men-te-ren-se",
    "formero": "for-me-ro",
    "formiato": "for-mia-to",
    "formica": "for-mi-ca",
    "formicante": "for-mi-can-te",
    "formícido": "for-mí-ci-do",
    "fórmico": "fór-mi-co",
    "formidable": "for-mi-da-ble",
    "formidar": "for-mi-dar",
    "formidolosa": "for-mi-do-lo-sa",
    "formidoloso": "for-mi-do-lo-so",
    "formol": "for-mol",
    "formón": "for-món",
    "formoseña": "for-mo-se-ña",
    "formoseño": "for-mo-se-ño",
    "fórmula": "fór-mu-la",
    "formulación": "for-mu-la-ción",
    "formular": "for-mu-lar",
    "formularia": "for-mu-la-ria",
    "formulario": "for-mu-la-rio",
    "formulismo": "for-mu-lis-mo",
    "formulista": "for-mu-lis-ta",
    "fornácea": "for-ná-ce-a",
    "fornáceo": "for-ná-ce-o",
    "fornacina": "for-na-ci-na",
    "fornalla": "for-na-lla",
    "fornecer": "for-ne-cer",
    "fornecimiento": "for-ne-ci-mien-to",
    "fornecina": "for-ne-ci-na",
    "fornecino": "for-ne-ci-no",
    "fornel": "for-nel",
    "fornelo": "for-ne-lo",
    "fornicación": "for-ni-ca-ción",
    "fornicador": "for-ni-ca-dor",
    "fornicadora": "for-ni-ca-do-ra",
    "fornicar": "for-ni-car",
    "fornicaria": "for-ni-ca-ria",
    "fornicario": "for-ni-ca-rio",
    "fornicio": "for-ni-cio",
    "fornición": "for-ni-ción",
    "fornida": "for-ni-da",
    "fornido": "for-ni-do",
    "forniguero": "for-ni-gue-ro",
    "fornimento": "for-ni-men-to",
    "fornimiento": "for-ni-mien-to",
    "fornir": "for-nir",
    "fornitura": "for-ni-tu-ra",
    "forno": "for-no",
    "foro": "fo-ro",
    "forofa": "fo-ro-fa",
    "forofo": "fo-ro-fo",
    "forqueta": "for-que-ta",
    "forra": "fo-rra",
    "forración": "fo-rra-ción",
    "forrado": "fo-rra-do",
    "forraje": "fo-rra-je",
    "forrajeador": "fo-rra-je-a-dor",
    "forrajear": "fo-rra-je-ar",
    "forrajera": "fo-rra-je-ra",
    "forrajero": "fo-rra-je-ro",
    "forrar": "fo-rrar",
    "forrazo": "fo-rra-zo",
    "forrear": "fo-rre-ar",
    "forro": "fo-rro",
    "forrocino": "fo-rro-ci-no",
    "forsitia": "for-si-tia",
    "fortacán": "for-ta-cán",
    "fortachón": "for-ta-chón",
    "fortachona": "for-ta-cho-na",
    "fortalecedor": "for-ta-le-ce-dor",
    "fortalecedora": "for-ta-le-ce-do-ra",
    "fortalecer": "for-ta-le-cer",
    "fortalecimiento": "for-ta-le-ci-mien-to",
    "fortaleza": "for-ta-le-za",
    "forte": "for-te",
    "fortepiano": "for-te-pia-no",
    "fortificación": "for-ti-fi-ca-ción",
    "fortificador": "for-ti-fi-ca-dor",
    "fortificadora": "for-ti-fi-ca-do-ra",
    "fortificante": "for-ti-fi-can-te",
    "fortificar": "for-ti-fi-car",
    "fortín": "for-tín",
    "fortísima": "for-tí-si-ma",
    "fortísimo": "for-tí-si-mo",
    "fortissimo": "for-tis-si-mo",
    "fortitud": "for-ti-tud",
    "fortuita": "for-tui-ta",
    "fortuitamente": "for-tui-ta-men-te",
    "fortuito": "for-tui-to",
    "fortuna": "for-tu-na",
    "fortunada": "for-tu-na-da",
    "fortunado": "for-tu-na-do",
    "fortunal": "for-tu-nal",
    "fortunio": "for-tu-nio",
    "fortuno": "for-tu-no",
    "fortunón": "for-tu-nón",
    "fortunosa": "for-tu-no-sa",
    "fortunoso": "for-tu-no-so",
    "fórum": "fó-rum",
    "forúnculo": "fo-rún-cu-lo",
    "forzada": "for-za-da",
    "forzadamente": "for-za-da-men-te",
    "forzado": "for-za-do",
    "forzador": "for-za-dor",
    "forzal": "for-zal",
    "forzamiento": "for-za-mien-to",
    "forzar": "for-zar",
    "forzolento": "for-zo-len-to",
    "forzosa": "for-zo-sa",
    "forzosamente": "for-zo-sa-men-te",
    "forzosidad": "for-zo-si-dad",
    "forzoso": "for-zo-so",
    "forzuda": "for-zu-da",
    "forzudamente": "for-zu-da-men-te",
    "forzudo": "for-zu-do",
    "fosa": "fo-sa",
    "fosada": "fo-sa-da",
    "fosado": "fo-sa-do",
    "fosadura": "fo-sa-du-ra",
    "fosal": "fo-sal",
    "fosar": "fo-sar",
    "fosario": "fo-sa-rio",
    "fosca": "fos-ca",
    "fosco": "fos-co",
    "fosfatada": "fos-fa-ta-da",
    "fosfatado": "fos-fa-ta-do",
    "fosfatar": "fos-fa-tar",
    "fosfática": "fos-fá-ti-ca",
    "fosfático": "fos-fá-ti-co",
    "fosfatina": "fos-fa-ti-na",
    "fosfato": "fos-fa-to",
    "fosfaturia": "fos-fa-tu-ria",
    "fosfeno": "fos-fe-no",
    "fosfito": "fos-fi-to",
    "fosforada": "fos-fo-ra-da",
    "fosforado": "fos-fo-ra-do",
    "fosforecer": "fos-fo-re-cer",
    "fosforera": "fos-fo-re-ra",
    "fosforero": "fos-fo-re-ro",
    "fosforescencia": "fos-fo-res-cen-cia",
    "fosforescente": "fos-fo-res-cen-te",
    "fosforescer": "fos-fo-res-cer",
    "fosfórica": "fos-fó-ri-ca",
    "fosfórico": "fos-fó-ri-co",
    "fosforilar": "fos-fo-ri-lar",
    "fosforita": "fos-fo-ri-ta",
    "fosforito": "fos-fo-ri-to",
    "fósforo": "fós-fo-ro",
    "fosforoscopio": "fos-fo-ros-co-pio",
    "fosforoso": "fos-fo-ro-so",
    "fosfuro": "fos-fu-ro",
    "fosgeno": "fos-ge-no",
    "fósil": "fó-sil",
    "fosilífera": "fo-si-lí-fe-ra",
    "fosilífero": "fo-si-lí-fe-ro",
    "fosilización": "fo-si-li-za-ción",
    "fosilizar": "fo-si-li-zar",
    "fosique": "fo-si-que",
    "foso": "fo-so",
    "fosor": "fo-sor",
    "fosquera": "fos-que-ra",
    "fosura": "fo-su-ra",
    "fotingo": "fo-tin-go",
    "fotiniana": "fo-ti-nia-na",
    "fotiniano": "fo-ti-nia-no",
    "foto": "fo-to",
    "fotoalergia": "fo-to-a-ler-gia",
    "fotoalérgico": "fo-to-a-lér-gi-co",
    "fotobiología": "fo-to-bio-lo-gí-a",
    "fotocatálisis": "fo-to-ca-tá-li-sis",
    "fotocomponedora": "fo-to-com-po-ne-do-ra",
    "fotocomposición": "fo-to-com-po-si-ción",
    "fotoconductividad": "fo-to-con-duc-ti-vi-dad",
    "fotoconductor": "fo-to-con-duc-tor",
    "fotoconductriz": "fo-to-con-duc-triz",
    "fotocopia": "fo-to-co-pia",
    "fotocopiador": "fo-to-co-pia-dor",
    "fotocopiadora": "fo-to-co-pia-do-ra",
    "fotocopiar": "fo-to-co-piar",
    "fotocromático": "fo-to-cro-má-ti-co",
    "fotocromo": "fo-to-cro-mo",
    "fotodegradable": "fo-to-de-gra-da-ble",
    "fotodiodo": "fo-to-dio-do",
    "fotoeléctrica": "fo-to-e-léc-tri-ca",
    "fotoelectricidad": "fo-to-e-lec-tri-ci-dad",
    "fotoeléctrico": "fo-to-e-léc-tri-co",
    "fotoelectrón": "fo-to-e-lec-trón",
    "fotoenvejecimiento": "fo-to-en-ve-je-ci-mien-to",
    "fotófoba": "fo-tó-fo-ba",
    "fotofobia": "fo-to-fo-bia",
    "fotófobo": "fo-tó-fo-bo",
    "fotogénesis": "fo-to-gé-ne-sis",
    "fotogenia": "fo-to-ge-nia",
    "fotogénica": "fo-to-gé-ni-ca",
    "fotogénico": "fo-to-gé-ni-co",
    "fotograbado": "fo-to-gra-ba-do",
    "fotograbador": "fo-to-gra-ba-dor",
    "fotograbadora": "fo-to-gra-ba-do-ra",
    "fotograbar": "fo-to-gra-bar",
    "fotógrafa": "fo-tó-gra-fa",
    "fotografía": "fo-to-gra-fí-a",
    "fotografiar": "fo-to-gra-fiar",
    "fotográfica": "fo-to-grá-fi-ca",
    "fotográficamente": "fo-to-grá-fi-ca-men-te",
    "fotográfico": "fo-to-grá-fi-co",
    "fotógrafo": "fo-tó-gra-fo",
    "fotograma": "fo-to-gra-ma",
    "fotogrametría": "fo-to-gra-me-trí-a",
    "fotolisis": "fo-to-li-sis",
    "fotolito": "fo-to-li-to",
    "fotolitógrafa": "fo-to-li-tó-gra-fa",
    "fotolitografía": "fo-to-li-to-gra-fí-a",
    "fotolitografiar": "fo-to-li-to-gra-fiar",
    "fotolitográfica": "fo-to-li-to-grá-fi-ca",
    "fotolitográficamente": "fo-to-li-to-grá-fi-ca-men-te",
    "fotolitográfico": "fo-to-li-to-grá-fi-co",
    "fotolitografista": "fo-to-li-to-gra-fis-ta",
    "fotolitógrafo": "fo-to-li-tó-gra-fo",
    "fotoluminiscencia": "fo-to-lu-mi-nis-cen-cia",
    "fotomatón": "fo-to-ma-tón",
    "fotomecánica": "fo-to-me-cá-ni-ca",
    "fotomecánico": "fo-to-me-cá-ni-co",
    "fotometría": "fo-to-me-trí-a",
    "fotométrica": "fo-to-mé-tri-ca",
    "fotométrico": "fo-to-mé-tri-co",
    "fotómetro": "fo-tó-me-tro",
    "fotomontaje": "fo-to-mon-ta-je",
    "fotomultiplicador": "fo-to-mul-ti-pli-ca-dor",
    "fotón": "fo-tón",
    "fotónico": "fo-tó-ni-co",
    "fotonovela": "fo-to-no-ve-la",
    "fotoprotector": "fo-to-pro-tec-tor",
    "fotoquímica": "fo-to-quí-mi-ca",
    "fotoquímico": "fo-to-quí-mi-co",
    "fotorresistencia": "fo-to-rre-sis-ten-cia",
    "fotosensibilizador": "fo-to-sen-si-bi-li-za-dor",
    "fotosensible": "fo-to-sen-si-ble",
    "fotosfera": "fo-tos-fe-ra",
    "fotósfera": "fo-tós-fe-ra",
    "fotosíntesis": "fo-to-sín-te-sis",
    "fotosintético": "fo-to-sin-té-ti-co",
    "fotosintetizar": "fo-to-sin-te-ti-zar",
    "fototactismo": "fo-to-tac-tis-mo",
    "fototaxia": "fo-to-ta-xia",
    "fototaxismo": "fo-to-ta-xis-mo",
    "fototeca": "fo-to-te-ca",
    "fototerapia": "fo-to-te-ra-pia",
    "fototipia": "fo-to-ti-pia",
    "fototípica": "fo-to-tí-pi-ca",
    "fototípico": "fo-to-tí-pi-co",
    "fototipografía": "fo-to-ti-po-gra-fí-a",
    "fototipográfica": "fo-to-ti-po-grá-fi-ca",
    "fototipográfico": "fo-to-ti-po-grá-fi-co",
    "fototoxicidad": "fo-to-to-xi-ci-dad",
    "fototóxico": "fo-to-tó-xi-co",
    "fototropismo": "fo-to-tro-pis-mo",
    "fotovoltaico": "fo-to-vol-tai-co",
    "fotutazo": "fo-tu-ta-zo",
    "fotutear": "fo-tu-te-ar",
    "fotuto": "fo-tu-to",
    "foulard": "fou-lard",
    "fóvea": "fó-ve-a",
    "fovismo": "fo-vis-mo",
    "fovista": "fo-vis-ta",
    "foxino": "fo-xi-no",
    "foxterrier": "fox-te-rrier",
    "foxtrot": "fox-trot",
    "foya": "fo-ya",
    "fracasada": "fra-ca-sa-da",
    "fracasado": "fra-ca-sa-do",
    "fracasar": "fra-ca-sar",
    "fracaso": "fra-ca-so",
    "fracatán": "fra-ca-tán",
    "fracción": "frac-ción",
    "fraccionable": "frac-cio-na-ble",
    "fraccionamiento": "frac-cio-na-mien-to",
    "fraccionar": "frac-cio-nar",
    "fraccionaria": "frac-cio-na-ria",
    "fraccionario": "frac-cio-na-rio",
    "fractal": "frac-tal",
    "fractura": "frac-tu-ra",
    "fracturar": "frac-tu-rar",
    "frada": "fra-da",
    "fradar": "fra-dar",
    "frade": "fra-de",
    "fradear": "fra-de-ar",
    "fraga": "fra-ga",
    "fragancia": "fra-gan-cia",
    "fragante": "fra-gan-te",
    "fragaria": "fra-ga-ria",
    "fragata": "fra-ga-ta",
    "frágil": "frá-gil",
    "fragilidad": "fra-gi-li-dad",
    "frágilmente": "frá-gil-men-te",
    "fragmentación": "frag-men-ta-ción",
    "fragmentar": "frag-men-tar",
    "fragmentaria": "frag-men-ta-ria",
    "fragmentario": "frag-men-ta-rio",
    "fragmentarismo": "frag-men-ta-ris-mo",
    "fragmento": "frag-men-to",
    "fragor": "fra-gor",
    "fragorosa": "fra-go-ro-sa",
    "fragoroso": "fra-go-ro-so",
    "fragosa": "fra-go-sa",
    "fragosidad": "fra-go-si-dad",
    "fragoso": "fra-go-so",
    "fragrancia": "fra-gran-cia",
    "fragrante": "fra-gran-te",
    "fragua": "fra-gua",
    "fraguado": "fra-gua-do",
    "fraguador": "fra-gua-dor",
    "fraguadora": "fra-gua-do-ra",
    "fraguar": "fra-guar",
    "fragüín": "fra-güín",
    "fragura": "fra-gu-ra",
    "frailada": "frai-la-da",
    "frailar": "frai-lar",
    "fraile": "frai-le",
    "frailear": "frai-le-ar",
    "frailecillo": "frai-le-ci-llo",
    "frailecito": "frai-le-ci-to",
    "frailega": "frai-le-ga",
    "frailego": "frai-le-go",
    "frailejón": "frai-le-jón",
    "fraileña": "frai-le-ña",
    "frailenga": "frai-len-ga",
    "frailengo": "frai-len-go",
    "fraileño": "frai-le-ño",
    "frailera": "frai-le-ra",
    "frailería": "frai-le-rí-a",
    "frailero": "frai-le-ro",
    "frailesca": "frai-les-ca",
    "frailesco": "frai-les-co",
    "frailía": "frai-lí-a",
    "frailillos": "frai-li-llos",
    "frailuco": "frai-lu-co",
    "frailuna": "frai-lu-na",
    "frailuno": "frai-lu-no",
    "fraire": "frai-re",
    "frajenco": "fra-jen-co",
    "framboyán": "fram-bo-yán",
    "frambuesa": "fram-bue-sa",
    "frambueso": "fram-bue-so",
    "frámea": "frá-me-a",
    "franca": "fran-ca",
    "francachela": "fran-ca-che-la",
    "francalete": "fran-ca-le-te",
    "francamente": "fran-ca-men-te",
    "francés": "fran-cés",
    "francesa": "fran-ce-sa",
    "francesada": "fran-ce-sa-da",
    "francesilla": "fran-ce-si-lla",
    "francesismo": "fran-ce-sis-mo",
    "francesista": "fran-ce-sis-ta",
    "franchipán": "fran-chi-pán",
    "franchota": "fran-cho-ta",
    "franchote": "fran-cho-te",
    "franchuta": "fran-chu-ta",
    "franchute": "fran-chu-te",
    "francia": "fran-cia",
    "francio": "fran-cio",
    "francisca": "fran-cis-ca",
    "franciscana": "fran-cis-ca-na",
    "franciscano": "fran-cis-ca-no",
    "francisco": "fran-cis-co",
    "francmasón": "franc-ma-són",
    "francmasona": "franc-ma-so-na",
    "francmasonería": "franc-ma-so-ne-rí-a",
    "francmasónico": "franc-ma-só-ni-co",
    "franco": "fran-co",
    "francobordo": "fran-co-bor-do",
    "francocanadiense": "fran-co-ca-na-dien-se",
    "francocuartel": "fran-co-cuar-tel",
    "francófila": "fran-có-fi-la",
    "francofilia": "fran-co-fi-lia",
    "francófilo": "fran-có-fi-lo",
    "francófoba": "fran-có-fo-ba",
    "francofobia": "fran-co-fo-bia",
    "francófobo": "fran-có-fo-bo",
    "francófona": "fran-có-fo-na",
    "francofonía": "fran-co-fo-ní-a",
    "francófono": "fran-có-fo-no",
    "francolín": "fran-co-lín",
    "francolina": "fran-co-li-na",
    "francolino": "fran-co-li-no",
    "francomacorisana": "fran-co-ma-co-ri-sa-na",
    "francomacorisano": "fran-co-ma-co-ri-sa-no",
    "francota": "fran-co-ta",
    "francote": "fran-co-te",
    "francotirador": "fran-co-ti-ra-dor",
    "francotiradora": "fran-co-ti-ra-do-ra",
    "franela": "fra-ne-la",
    "franelear": "fra-ne-le-ar",
    "franelera": "fra-ne-le-ra",
    "franelero": "fra-ne-le-ro",
    "franelógrafo": "fra-ne-ló-gra-fo",
    "frañer": "fra-ñer",
    "frange": "fran-ge",
    "frangente": "fran-gen-te",
    "frangible": "fran-gi-ble",
    "frangipani": "fran-gi-pa-ni",
    "frangir": "fran-gir",
    "frangle": "fran-gle",
    "frangollar": "fran-go-llar",
    "frangollero": "fran-go-lle-ro",
    "frangollo": "fran-go-llo",
    "frangollón": "fran-go-llón",
    "frangollona": "fran-go-llo-na",
    "frangote": "fran-go-te",
    "franhueso": "fran-hue-so",
    "franja": "fran-ja",
    "franjar": "fran-jar",
    "franjear": "fran-je-ar",
    "franjón": "fran-jón",
    "frankfurt": "frank-furt",
    "franklin": "fran-klin",
    "franqueable": "fran-que-a-ble",
    "franqueada": "fran-que-a-da",
    "franqueado": "fran-que-a-do",
    "franqueamiento": "fran-que-a-mien-to",
    "franquear": "fran-que-ar",
    "franqueniácea": "fran-que-niá-ce-a",
    "franqueniáceo": "fran-que-niá-ce-o",
    "franqueo": "fran-que-o",
    "franqueza": "fran-que-za",
    "franquía": "fran-quí-a",
    "franquicia": "fran-qui-cia",
    "franquiciada": "fran-qui-cia-da",
    "franquiciado": "fran-qui-cia-do",
    "franquiciar": "fran-qui-ciar",
    "franquismo": "fran-quis-mo",
    "franquista": "fran-quis-ta",
    "frappé": "frap-pé",
    "fraque": "fra-que",
    "frasca": "fras-ca",
    "frasco": "fras-co",
    "frase": "fra-se",
    "frasear": "fra-se-ar",
    "fraseo": "fra-se-o",
    "fraseología": "fra-se-o-lo-gí-a",
    "fraseológica": "fra-se-o-ló-gi-ca",
    "fraseológico": "fra-se-o-ló-gi-co",
    "frasis": "fra-sis",
    "frasquera": "fras-que-ra",
    "frasquerío": "fras-que-rí-o",
    "frasqueta": "fras-que-ta",
    "frasquitera": "fras-qui-te-ra",
    "frasquitero": "fras-qui-te-ro",
    "fratachar": "fra-ta-char",
    "fratacho": "fra-ta-cho",
    "fratás": "fra-tás",
    "fratasar": "fra-ta-sar",
    "fraterna": "fra-ter-na",
    "fraternal": "fra-ter-nal",
    "fraternalmente": "fra-ter-nal-men-te",
    "fraternidad": "fra-ter-ni-dad",
    "fraternizar": "fra-ter-ni-zar",
    "fraterno": "fra-ter-no",
    "fratres": "fra-tres",
    "fratría": "fra-trí-a",
    "fratricida": "fra-tri-ci-da",
    "fratricidio": "fra-tri-ci-dio",
    "fraudador": "frau-da-dor",
    "fraudadora": "frau-da-do-ra",
    "fraudar": "frau-dar",
    "fraude": "frau-de",
    "fraudulencia": "frau-du-len-cia",
    "fraudulenta": "frau-du-len-ta",
    "fraudulentamente": "frau-du-len-ta-men-te",
    "fraudulento": "frau-du-len-to",
    "fraustina": "fraus-ti-na",
    "fraybentina": "fray-ben-ti-na",
    "fraybentino": "fray-ben-ti-no",
    "frazada": "fra-za-da",
    "frazadero": "fra-za-de-ro",
    "freático": "fre-á-ti-co",
    "frecuencia": "fre-cuen-cia",
    "frecuencímetro": "fre-cuen-cí-me-tro",
    "frecuentación": "fre-cuen-ta-ción",
    "frecuentado": "fre-cuen-ta-do",
    "frecuentador": "fre-cuen-ta-dor",
    "frecuentadora": "fre-cuen-ta-do-ra",
    "frecuentar": "fre-cuen-tar",
    "frecuentativo": "fre-cuen-ta-ti-vo",
    "frecuente": "fre-cuen-te",
    "frecuentemente": "fre-cuen-te-men-te",
    "fredo": "fre-do",
    "freesia": "fre-e-sia",
    "fregación": "fre-ga-ción",
    "fregada": "fre-ga-da",
    "fregadazo": "fre-ga-da-zo",
    "fregadera": "fre-ga-de-ra",
    "fregadero": "fre-ga-de-ro",
    "fregado": "fre-ga-do",
    "fregador": "fre-ga-dor",
    "fregadora": "fre-ga-do-ra",
    "fregadura": "fre-ga-du-ra",
    "fregajo": "fre-ga-jo",
    "fregamiento": "fre-ga-mien-to",
    "fregar": "fre-gar",
    "fregata": "fre-ga-ta",
    "fregatina": "fre-ga-ti-na",
    "fregatriz": "fre-ga-triz",
    "fregón": "fre-gón",
    "fregona": "fre-go-na",
    "fregonil": "fre-go-nil",
    "fregotear": "fre-go-te-ar",
    "fregoteo": "fre-go-te-o",
    "freidera": "frei-de-ra",
    "freidor": "frei-dor",
    "freidora": "frei-do-ra",
    "freidura": "frei-du-ra",
    "freiduría": "frei-du-rí-a",
    "freila": "frei-la",
    "freilar": "frei-lar",
    "freile": "frei-le",
    "freír": "fre-ír",
    "freira": "frei-ra",
    "freire": "frei-re",
    "freiría": "frei-rí-a",
    "frejol": "fre-jol",
    "fréjol": "fré-jol",
    "frejón": "fre-jón",
    "fréjul": "fré-jul",
    "frémito": "fré-mi-to",
    "frenada": "fre-na-da",
    "frenado": "fre-na-do",
    "frenar": "fre-nar",
    "frenazo": "fre-na-zo",
    "frenería": "fre-ne-rí-a",
    "frenero": "fre-ne-ro",
    "frenesí": "fre-ne-sí",
    "frenesía": "fre-ne-sí-a",
    "frenética": "fre-né-ti-ca",
    "frenéticamente": "fre-né-ti-ca-men-te",
    "frenético": "fre-né-ti-co",
    "frenetizar": "fre-ne-ti-zar",
    "frénico": "fré-ni-co",
    "frenillar": "fre-ni-llar",
    "frenillo": "fre-ni-llo",
    "freno": "fre-no",
    "frenología": "fre-no-lo-gí-a",
    "frenológica": "fre-no-ló-gi-ca",
    "frenológico": "fre-no-ló-gi-co",
    "frenólogo": "fre-nó-lo-go",
    "frenópata": "fre-nó-pa-ta",
    "frenopatía": "fre-no-pa-tí-a",
    "frenopático": "fre-no-pá-ti-co",
    "frental": "fren-tal",
    "frentazo": "fren-ta-zo",
    "frente": "fren-te",
    "frenteamplista": "fren-te-am-plis-ta",
    "frentero": "fren-te-ro",
    "frentón": "fren-tón",
    "frentona": "fren-to-na",
    "freo": "fre-o",
    "freón": "fre-ón",
    "fresa": "fre-sa",
    "fresada": "fre-sa-da",
    "fresado": "fre-sa-do",
    "fresador": "fre-sa-dor",
    "fresadora": "fre-sa-do-ra",
    "fresal": "fre-sal",
    "fresar": "fre-sar",
    "fresca": "fres-ca",
    "frescachón": "fres-ca-chón",
    "frescachona": "fres-ca-cho-na",
    "frescal": "fres-cal",
    "frescales": "fres-ca-les",
    "frescamente": "fres-ca-men-te",
    "fresco": "fres-co",
    "frescolín": "fres-co-lín",
    "frescor": "fres-cor",
    "frescota": "fres-co-ta",
    "frescote": "fres-co-te",
    "frescura": "fres-cu-ra",
    "fresera": "fre-se-ra",
    "fresero": "fre-se-ro",
    "fresia": "fre-sia",
    "fresnal": "fres-nal",
    "fresneda": "fres-ne-da",
    "fresnillo": "fres-ni-llo",
    "fresno": "fres-no",
    "freso": "fre-so",
    "fresón": "fre-són",
    "fresquedal": "fres-que-dal",
    "fresquera": "fres-que-ra",
    "fresquería": "fres-que-rí-a",
    "fresquero": "fres-que-ro",
    "fresquilla": "fres-qui-lla",
    "fresquista": "fres-quis-ta",
    "fretar": "fre-tar",
    "frete": "fre-te",
    "freudiana": "freu-dia-na",
    "freudiano": "freu-dia-no",
    "freudismo": "freu-dis-mo",
    "freza": "fre-za",
    "frezada": "fre-za-da",
    "frezadero": "fre-za-de-ro",
    "frezador": "fre-za-dor",
    "frezar": "fre-zar",
    "fría": "frí-a",
    "friabilidad": "fria-bi-li-dad",
    "friable": "fria-ble",
    "frialdad": "frial-dad",
    "fríamente": "frí-a-men-te",
    "friática": "friá-ti-ca",
    "friático": "friá-ti-co",
    "fricación": "fri-ca-ción",
    "fricandel": "fri-can-del",
    "fricandó": "fri-can-dó",
    "fricar": "fri-car",
    "fricasé": "fri-ca-sé",
    "fricasea": "fri-ca-se-a",
    "fricativa": "fri-ca-ti-va",
    "fricativo": "fri-ca-ti-vo",
    "fricción": "fric-ción",
    "friccionar": "fric-cio-nar",
    "fridera": "fri-de-ra",
    "friega": "frie-ga",
    "friegaplatos": "frie-ga-pla-tos",
    "friera": "frie-ra",
    "frigente": "fri-gen-te",
    "frigia": "fri-gia",
    "frígida": "frí-gi-da",
    "frigider": "fri-gi-der",
    "frigidez": "fri-gi-dez",
    "frigidísima": "fri-gi-dí-si-ma",
    "frigidísimo": "fri-gi-dí-si-mo",
    "frígido": "frí-gi-do",
    "frigio": "fri-gio",
    "frigoría": "fri-go-rí-a",
    "frigorienta": "fri-go-rien-ta",
    "frigoriento": "fri-go-rien-to",
    "frigorífica": "fri-go-rí-fi-ca",
    "frigorífico": "fri-go-rí-fi-co",
    "frigorista": "fri-go-ris-ta",
    "frijol": "fri-jol",
    "fríjol": "frí-jol",
    "frijolar": "fri-jo-lar",
    "frijolera": "fri-jo-le-ra",
    "frijolero": "fri-jo-le-ro",
    "frijolillo": "fri-jo-li-llo",
    "frijón": "fri-jón",
    "friki": "fri-ki",
    "frimario": "fri-ma-rio",
    "fringilago": "frin-gi-la-go",
    "fringílido": "frin-gí-li-do",
    "frío": "frí-o",
    "friolenta": "frio-len-ta",
    "friolento": "frio-len-to",
    "friolera": "frio-le-ra",
    "friolero": "frio-le-ro",
    "friollega": "frio-lle-ga",
    "friollego": "frio-lle-go",
    "friqui": "fri-qui",
    "frisa": "fri-sa",
    "frisado": "fri-sa-do",
    "frisador": "fri-sa-dor",
    "frisadora": "fri-sa-do-ra",
    "frisadura": "fri-sa-du-ra",
    "frisar": "fri-sar",
    "frisca": "fris-ca",
    "frisia": "fri-sia",
    "frisio": "fri-sio",
    "friso": "fri-so",
    "frísol": "frí-sol",
    "frisolera": "fri-so-le-ra",
    "frisolero": "fri-so-le-ro",
    "frisón": "fri-són",
    "frisona": "fri-so-na",
    "frisuelo": "fri-sue-lo",
    "frita": "fri-ta",
    "fritada": "fri-ta-da",
    "fritadería": "fri-ta-de-rí-a",
    "fritandera": "fri-tan-de-ra",
    "fritanga": "fri-tan-ga",
    "fritanguera": "fri-tan-gue-ra",
    "fritanguería": "fri-tan-gue-rí-a",
    "fritanguero": "fri-tan-gue-ro",
    "fritar": "fri-tar",
    "fritera": "fri-te-ra",
    "fritero": "fri-te-ro",
    "fritillas": "fri-ti-llas",
    "frito": "fri-to",
    "fritura": "fri-tu-ra",
    "friulana": "friu-la-na",
    "friulano": "friu-la-no",
    "friura": "friu-ra",
    "frívola": "frí-vo-la",
    "frívolamente": "frí-vo-la-men-te",
    "frivolidad": "fri-vo-li-dad",
    "frivolización": "fri-vo-li-za-ción",
    "frivolizar": "fri-vo-li-zar",
    "frívolo": "frí-vo-lo",
    "froga": "fro-ga",
    "frogar": "fro-gar",
    "froncia": "fron-cia",
    "fronda": "fron-da",
    "fronde": "fron-de",
    "frondío": "fron-dí-o",
    "frondosa": "fron-do-sa",
    "frondosidad": "fron-do-si-dad",
    "frondoso": "fron-do-so",
    "frontal": "fron-tal",
    "frontalera": "fron-ta-le-ra",
    "frontalero": "fron-ta-le-ro",
    "fronte": "fron-te",
    "frontenis": "fron-te-nis",
    "frontera": "fron-te-ra",
    "fronteriza": "fron-te-ri-za",
    "fronterizo": "fron-te-ri-zo",
    "frontero": "fron-te-ro",
    "frontil": "fron-til",
    "frontina": "fron-ti-na",
    "frontino": "fron-ti-no",
    "frontis": "fron-tis",
    "frontispicio": "fron-tis-pi-cio",
    "frontón": "fron-tón",
    "frontuda": "fron-tu-da",
    "frontudo": "fron-tu-do",
    "frotación": "fro-ta-ción",
    "frotador": "fro-ta-dor",
    "frotadora": "fro-ta-do-ra",
    "frotadura": "fro-ta-du-ra",
    "frotamiento": "fro-ta-mien-to",
    "frotar": "fro-tar",
    "frote": "fro-te",
    "frotis": "fro-tis",
    "fructidor": "fruc-ti-dor",
    "fructífera": "fruc-tí-fe-ra",
    "fructíferamente": "fruc-tí-fe-ra-men-te",
    "fructífero": "fruc-tí-fe-ro",
    "fructificable": "fruc-ti-fi-ca-ble",
    "fructificación": "fruc-ti-fi-ca-ción",
    "fructificador": "fruc-ti-fi-ca-dor",
    "fructificadora": "fruc-ti-fi-ca-do-ra",
    "fructificar": "fruc-ti-fi-car",
    "fructosa": "fruc-to-sa",
    "fructuaria": "fruc-tua-ria",
    "fructuario": "fruc-tua-rio",
    "fructuosa": "fruc-tuo-sa",
    "fructuosamente": "fruc-tuo-sa-men-te",
    "fructuoso": "fruc-tuo-so",
    "frufrú": "fru-frú",
    "frugal": "fru-gal",
    "frugalidad": "fru-ga-li-dad",
    "frugalmente": "fru-gal-men-te",
    "frugífera": "fru-gí-fe-ra",
    "frugífero": "fru-gí-fe-ro",
    "frugívora": "fru-gí-vo-ra",
    "frugívoro": "fru-gí-vo-ro",
    "fruición": "frui-ción",
    "fruitiva": "frui-ti-va",
    "fruitivo": "frui-ti-vo",
    "frumentaria": "fru-men-ta-ria",
    "frumentario": "fru-men-ta-rio",
    "frumenticia": "fru-men-ti-cia",
    "frumenticio": "fru-men-ti-cio",
    "frunce": "frun-ce",
    "fruncia": "frun-cia",
    "fruncida": "frun-ci-da",
    "fruncido": "frun-ci-do",
    "fruncidor": "frun-ci-dor",
    "fruncidora": "frun-ci-do-ra",
    "fruncimiento": "frun-ci-mien-to",
    "fruncir": "frun-cir",
    "fruslera": "frus-le-ra",
    "fruslería": "frus-le-rí-a",
    "fruslero": "frus-le-ro",
    "frustración": "frus-tra-ción",
    "frustrado": "frus-tra-do",
    "frustránea": "frus-trá-ne-a",
    "frustráneo": "frus-trá-ne-o",
    "frustrante": "frus-tran-te",
    "frustrar": "frus-trar",
    "frustratoria": "frus-tra-to-ria",
    "frustratorio": "frus-tra-to-rio",
    "frustre": "frus-tre",
    "fruta": "fru-ta",
    "frutabomba": "fru-ta-bom-ba",
    "frutado": "fru-ta-do",
    "frutaje": "fru-ta-je",
    "frutal": "fru-tal",
    "frutar": "fru-tar",
    "frutear": "fru-te-ar",
    "frutecer": "fru-te-cer",
    "frutera": "fru-te-ra",
    "frutería": "fru-te-rí-a",
    "frutero": "fru-te-ro",
    "frútice": "frú-ti-ce",
    "frutícola": "fru-tí-co-la",
    "fruticosa": "fru-ti-co-sa",
    "fruticoso": "fru-ti-co-so",
    "fruticultura": "fru-ti-cul-tu-ra",
    "frutier": "fru-tier",
    "frutífera": "fru-tí-fe-ra",
    "frutífero": "fru-tí-fe-ro",
    "frutificar": "fru-ti-fi-car",
    "frutilla": "fru-ti-lla",
    "frutillar": "fru-ti-llar",
    "frutillera": "fru-ti-lle-ra",
    "frutillero": "fru-ti-lle-ro",
    "fruto": "fru-to",
    "frutuosa": "fru-tuo-sa",
    "frutuoso": "fru-tuo-so",
    "fuácata": "fuá-ca-ta",
    "fuagrás": "fua-grás",
    "fúcar": "fú-car",
    "fuchi": "fu-chi",
    "fúchila": "fú-chi-la",
    "fuchina": "fu-chi-na",
    "fucia": "fu-cia",
    "fucilar": "fu-ci-lar",
    "fucilazo": "fu-ci-la-zo",
    "fuco": "fu-co",
    "fucsia": "fuc-sia",
    "fucsina": "fuc-si-na",
    "fudre": "fu-dre",
    "fuego": "fue-go",
    "fueguina": "fue-gui-na",
    "fueguino": "fue-gui-no",
    "fuelgo": "fuel-go",
    "fuellar": "fue-llar",
    "fuelle": "fue-lle",
    "fuéllega": "fué-lle-ga",
    "fueloil": "fue-loil",
    "fuelóleo": "fue-ló-le-o",
    "fuentada": "fuen-ta-da",
    "fuente": "fuen-te",
    "fuera": "fue-ra",
    "fueraborda": "fue-ra-bor-da",
    "fuerarropa": "fue-ra-rro-pa",
    "fueras": "fue-ras",
    "fuereña": "fue-re-ña",
    "fuereño": "fue-re-ño",
    "fuerera": "fue-re-ra",
    "fuerero": "fue-re-ro",
    "fuerismo": "fue-ris-mo",
    "fuerista": "fue-ris-ta",
    "fuero": "fue-ro",
    "fuerte": "fuer-te",
    "fuertemente": "fuer-te-men-te",
    "fuerza": "fuer-za",
    "fuesa": "fue-sa",
    "fuetazo": "fue-ta-zo",
    "fuete": "fue-te",
    "fufar": "fu-far",
    "fufo": "fu-fo",
    "fufú": "fu-fú",
    "fufurufa": "fu-fu-ru-fa",
    "fufurufo": "fu-fu-ru-fo",
    "fuga": "fu-ga",
    "fugacidad": "fu-ga-ci-dad",
    "fugada": "fu-ga-da",
    "fugar": "fu-gar",
    "fugaz": "fu-gaz",
    "fugazmente": "fu-gaz-men-te",
    "fugible": "fu-gi-ble",
    "fúgida": "fú-gi-da",
    "fúgido": "fú-gi-do",
    "fugir": "fu-gir",
    "fugitiva": "fu-gi-ti-va",
    "fugitivo": "fu-gi-ti-vo",
    "fuguillas": "fu-gui-llas",
    "fuidiza": "fui-di-za",
    "fuidizo": "fui-di-zo",
    "fuimiento": "fui-mien-to",
    "fuina": "fui-na",
    "fuisca": "fuis-ca",
    "fula": "fu-la",
    "fulana": "fu-la-na",
    "fulano": "fu-la-no",
    "fular": "fu-lar",
    "fulastre": "fu-las-tre",
    "fulastrería": "fu-las-tre-rí-a",
    "fulbito": "ful-bi-to",
    "fulcir": "ful-cir",
    "fulcro": "ful-cro",
    "fulera": "fu-le-ra",
    "fulero": "fu-le-ro",
    "fulgente": "ful-gen-te",
    "fúlgida": "fúl-gi-da",
    "fúlgido": "fúl-gi-do",
    "fulgir": "ful-gir",
    "fulgor": "ful-gor",
    "fulgoroso": "ful-go-ro-so",
    "fulguración": "ful-gu-ra-ción",
    "fulgurante": "ful-gu-ran-te",
    "fulgurar": "ful-gu-rar",
    "fulgúreo": "ful-gú-re-o",
    "fulgurita": "ful-gu-ri-ta",
    "fulgurosa": "ful-gu-ro-sa",
    "fulguroso": "ful-gu-ro-so",
    "fúlica": "fú-li-ca",
    "fuliginosa": "fu-li-gi-no-sa",
    "fuliginosidad": "fu-li-gi-no-si-dad",
    "fuliginoso": "fu-li-gi-no-so",
    "fuligo": "fu-li-go",
    "fulla": "fu-lla",
    "fullera": "fu-lle-ra",
    "fulleresca": "fu-lle-res-ca",
    "fulleresco": "fu-lle-res-co",
    "fullería": "fu-lle-rí-a",
    "fullero": "fu-lle-ro",
    "fullona": "fu-llo-na",
    "fulmar": "ful-mar",
    "fulmicotón": "ful-mi-co-tón",
    "fulminación": "ful-mi-na-ción",
    "fulminador": "ful-mi-na-dor",
    "fulminadora": "ful-mi-na-do-ra",
    "fulminante": "ful-mi-nan-te",
    "fulminar": "ful-mi-nar",
    "fulminato": "ful-mi-na-to",
    "fulminatriz": "ful-mi-na-triz",
    "fúlmine": "fúl-mi-ne",
    "fulmínea": "ful-mí-ne-a",
    "fulmíneo": "ful-mí-ne-o",
    "fulmínico": "ful-mí-ni-co",
    "fulminosa": "ful-mi-no-sa",
    "fulminoso": "ful-mi-no-so",
    "fulo": "fu-lo",
    "fuma": "fu-ma",
    "fumable": "fu-ma-ble",
    "fumada": "fu-ma-da",
    "fumadero": "fu-ma-de-ro",
    "fumado": "fu-ma-do",
    "fumador": "fu-ma-dor",
    "fumadora": "fu-ma-do-ra",
    "fumante": "fu-man-te",
    "fumar": "fu-mar",
    "fumarada": "fu-ma-ra-da",
    "fumarel": "fu-ma-rel",
    "fumaria": "fu-ma-ria",
    "fumarola": "fu-ma-ro-la",
    "fumata": "fu-ma-ta",
    "fumífera": "fu-mí-fe-ra",
    "fumífero": "fu-mí-fe-ro",
    "fumífugo": "fu-mí-fu-go",
    "fumigación": "fu-mi-ga-ción",
    "fumigador": "fu-mi-ga-dor",
    "fumigadora": "fu-mi-ga-do-ra",
    "fumigar": "fu-mi-gar",
    "fumigatoria": "fu-mi-ga-to-ria",
    "fumigatorio": "fu-mi-ga-to-rio",
    "fumígeno": "fu-mí-ge-no",
    "fumista": "fu-mis-ta",
    "fumistería": "fu-mis-te-rí-a",
    "fumívora": "fu-mí-vo-ra",
    "fumívoro": "fu-mí-vo-ro",
    "fumo": "fu-mo",
    "fumón": "fu-món",
    "fumorola": "fu-mo-ro-la",
    "fumosa": "fu-mo-sa",
    "fumosidad": "fu-mo-si-dad",
    "fumoso": "fu-mo-so",
    "funámbula": "fu-nám-bu-la",
    "funambulesco": "fu-nam-bu-les-co",
    "funambulismo": "fu-nam-bu-lis-mo",
    "funámbulo": "fu-nám-bu-lo",
    "fuñar": "fu-ñar",
    "funcar": "fun-car",
    "funche": "fun-che",
    "función": "fun-ción",
    "funcional": "fun-cio-nal",
    "funcionalidad": "fun-cio-na-li-dad",
    "funcionalismo": "fun-cio-na-lis-mo",
    "funcionalista": "fun-cio-na-lis-ta",
    "funcionalmente": "fun-cio-nal-men-te",
    "funcionamiento": "fun-cio-na-mien-to",
    "funcionar": "fun-cio-nar",
    "funcionaria": "fun-cio-na-ria",
    "funcionariado": "fun-cio-na-ria-do",
    "funcionarial": "fun-cio-na-rial",
    "funcionario": "fun-cio-na-rio",
    "funcionarismo": "fun-cio-na-ris-mo",
    "funda": "fun-da",
    "fundación": "fun-da-ción",
    "fundacional": "fun-da-cio-nal",
    "fundadamente": "fun-da-da-men-te",
    "fundador": "fun-da-dor",
    "fundadora": "fun-da-do-ra",
    "fundago": "fun-da-go",
    "fundamentación": "fun-da-men-ta-ción",
    "fundamental": "fun-da-men-tal",
    "fundamentalismo": "fun-da-men-ta-lis-mo",
    "fundamentalista": "fun-da-men-ta-lis-ta",
    "fundamentalmente": "fun-da-men-tal-men-te",
    "fundamentar": "fun-da-men-tar",
    "fundamento": "fun-da-men-to",
    "fundar": "fun-dar",
    "fundente": "fun-den-te",
    "fundería": "fun-de-rí-a",
    "fundible": "fun-di-ble",
    "fundibulario": "fun-di-bu-la-rio",
    "fundíbulo": "fun-dí-bu-lo",
    "fundición": "fun-di-ción",
    "fundida": "fun-di-da",
    "fundido": "fun-di-do",
    "fundidor": "fun-di-dor",
    "fundidora": "fun-di-do-ra",
    "fundillo": "fun-di-llo",
    "fundillón": "fun-di-llón",
    "fundir": "fun-dir",
    "fundo": "fun-do",
    "fúnebre": "fú-ne-bre",
    "fúnebremente": "fú-ne-bre-men-te",
    "funebridad": "fu-ne-bri-dad",
    "funene": "fu-ne-ne",
    "funeral": "fu-ne-ral",
    "funerala": "fu-ne-ra-la",
    "funeraria": "fu-ne-ra-ria",
    "funerario": "fu-ne-ra-rio",
    "funérea": "fu-né-re-a",
    "funéreo": "fu-né-re-o",
    "funesta": "fu-nes-ta",
    "funestamente": "fu-nes-ta-men-te",
    "funestar": "fu-nes-tar",
    "funesto": "fu-nes-to",
    "fungible": "fun-gi-ble",
    "fungicida": "fun-gi-ci-da",
    "fúngico": "fún-gi-co",
    "fungiforme": "fun-gi-for-me",
    "fungir": "fun-gir",
    "fungistático": "fun-gis-tá-ti-co",
    "fungosa": "fun-go-sa",
    "fungosidad": "fun-go-si-dad",
    "fungoso": "fun-go-so",
    "funguicida": "fun-gui-ci-da",
    "fuñicar": "fu-ñi-car",
    "funicular": "fu-ni-cu-lar",
    "funículo": "fu-ní-cu-lo",
    "fuñida": "fu-ñi-da",
    "fuñido": "fu-ñi-do",
    "fuñingue": "fu-ñin-gue",
    "fuñique": "fu-ñi-que",
    "fura": "fu-ra",
    "furcia": "fur-cia",
    "furcio": "fur-cio",
    "fúrcula": "fúr-cu-la",
    "furente": "fu-ren-te",
    "furfurácea": "fur-fu-rá-ce-a",
    "furfuráceo": "fur-fu-rá-ce-o",
    "furgón": "fur-gón",
    "furgoneta": "fur-go-ne-ta",
    "furia": "fu-ria",
    "furibunda": "fu-ri-bun-da",
    "furibundo": "fu-ri-bun-do",
    "fúrico": "fú-ri-co",
    "furiente": "fu-rien-te",
    "furierismo": "fu-rie-ris-mo",
    "furierista": "fu-rie-ris-ta",
    "furiosa": "fu-rio-sa",
    "furiosamente": "fu-rio-sa-men-te",
    "furioso": "fu-rio-so",
    "furlón": "fur-lón",
    "furnia": "fur-nia",
    "furo": "fu-ro",
    "furor": "fu-ror",
    "furriel": "fu-rriel",
    "furriela": "fu-rrie-la",
    "furrier": "fu-rrier",
    "furriera": "fu-rrie-ra",
    "furris": "fu-rris",
    "furruco": "fu-rru-co",
    "furrufalla": "fu-rru-fa-lla",
    "furrumalla": "fu-rru-ma-lla",
    "furrusca": "fu-rrus-ca",
    "furtar": "fur-tar",
    "furtiblemente": "fur-ti-ble-men-te",
    "furtiva": "fur-ti-va",
    "furtivamente": "fur-ti-va-men-te",
    "furtivismo": "fur-ti-vis-mo",
    "furtivo": "fur-ti-vo",
    "furto": "fur-to",
    "furulla": "fu-ru-lla",
    "furuminga": "fu-ru-min-ga",
    "furúnculo": "fu-rún-cu-lo",
    "fusa": "fu-sa",
    "fusada": "fu-sa-da",
    "fusado": "fu-sa-do",
    "fusca": "fus-ca",
    "fuscar": "fus-car",
    "fusco": "fus-co",
    "fuselada": "fu-se-la-da",
    "fuselado": "fu-se-la-do",
    "fuselaje": "fu-se-la-je",
    "fusibilidad": "fu-si-bi-li-dad",
    "fusible": "fu-si-ble",
    "fusiforme": "fu-si-for-me",
    "fusil": "fu-sil",
    "fúsil": "fú-sil",
    "fusilamiento": "fu-si-la-mien-to",
    "fusilar": "fu-si-lar",
    "fusilazo": "fu-si-la-zo",
    "fusilera": "fu-si-le-ra",
    "fusilería": "fu-si-le-rí-a",
    "fusilero": "fu-si-le-ro",
    "fusilico": "fu-si-li-co",
    "fusión": "fu-sión",
    "fusionar": "fu-sio-nar",
    "fusionista": "fu-sio-nis-ta",
    "fusique": "fu-si-que",
    "fuslera": "fus-le-ra",
    "fuslina": "fus-li-na",
    "fuso": "fu-so",
    "fusor": "fu-sor",
    "fusta": "fus-ta",
    "fustada": "fus-ta-da",
    "fustado": "fus-ta-do",
    "fustal": "fus-tal",
    "fustán": "fus-tán",
    "fustanero": "fus-ta-ne-ro",
    "fustaño": "fus-ta-ño",
    "fuste": "fus-te",
    "fustera": "fus-te-ra",
    "fustero": "fus-te-ro",
    "fustete": "fus-te-te",
    "fustigación": "fus-ti-ga-ción",
    "fustigador": "fus-ti-ga-dor",
    "fustigadora": "fus-ti-ga-do-ra",
    "fustigante": "fus-ti-gan-te",
    "fustigar": "fus-ti-gar",
    "fusto": "fus-to",
    "fustumbre": "fus-tum-bre",
    "futbito": "fut-bi-to",
    "futbol": "fut-bol",
    "fútbol": "fút-bol",
    "futbolera": "fut-bo-le-ra",
    "futbolero": "fut-bo-le-ro",
    "futbolín": "fut-bo-lín",
    "futbolista": "fut-bo-lis-ta",
    "futbolística": "fut-bo-lís-ti-ca",
    "futbolístico": "fut-bo-lís-ti-co",
    "futbolito": "fut-bo-li-to",
    "futbolizar": "fut-bo-li-zar",
    "futesa": "fu-te-sa",
    "fútil": "fú-til",
    "futilidad": "fu-ti-li-dad",
    "futón": "fu-tón",
    "futraque": "fu-tra-que",
    "futre": "fu-tre",
    "futura": "fu-tu-ra",
    "futuraria": "fu-tu-ra-ria",
    "futurario": "fu-tu-ra-rio",
    "futurible": "fu-tu-ri-ble",
    "futurición": "fu-tu-ri-ción",
    "futuridad": "fu-tu-ri-dad",
    "futurismo": "fu-tu-ris-mo",
    "futurista": "fu-tu-ris-ta",
    "futurizo": "fu-tu-ri-zo",
    "futuro": "fu-tu-ro",
    "futuróloga": "fu-tu-ró-lo-ga",
    "futurología": "fu-tu-ro-lo-gí-a",
    "futurólogo": "fu-tu-ró-lo-go",
    "fututo": "fu-tu-to",
    "gabacha": "ga-ba-cha",
    "gabachada": "ga-ba-cha-da",
    "gabacho": "ga-ba-cho",
    "gabán": "ga-bán",
    "gabaonita": "ga-ba-o-ni-ta",
    "gabar": "ga-bar",
    "gabarda": "ga-bar-da",
    "gabardina": "ga-bar-di-na",
    "gabarra": "ga-ba-rra",
    "gabarrero": "ga-ba-rre-ro",
    "gabarro": "ga-ba-rro",
    "gabarse": "ga-bar-se",
    "gabasa": "ga-ba-sa",
    "gabata": "ga-ba-ta",
    "gábata": "gá-ba-ta",
    "gabato": "ga-ba-to",
    "gabazo": "ga-ba-zo",
    "gabejo": "ga-be-jo",
    "gabela": "ga-be-la",
    "gabijón": "ga-bi-jón",
    "gábilos": "gá-bi-los",
    "gabina": "ga-bi-na",
    "gabinete": "ga-bi-ne-te",
    "gabita": "ga-bi-ta",
    "gablete": "ga-ble-te",
    "gabonense": "ga-bo-nen-se",
    "gabonés": "ga-bo-nés",
    "gabonesa": "ga-bo-ne-sa",
    "gabote": "ga-bo-te",
    "gabrieles": "ga-brie-les",
    "gabuzo": "ga-bu-zo",
    "gacel": "ga-cel",
    "gacela": "ga-ce-la",
    "gacense": "ga-cen-se",
    "gaceta": "ga-ce-ta",
    "gacetable": "ga-ce-ta-ble",
    "gacetera": "ga-ce-te-ra",
    "gacetero": "ga-ce-te-ro",
    "gacetilla": "ga-ce-ti-lla",
    "gacetillera": "ga-ce-ti-lle-ra",
    "gacetillero": "ga-ce-ti-lle-ro",
    "gacetista": "ga-ce-tis-ta",
    "gacha": "ga-cha",
    "gachapazo": "ga-cha-pa-zo",
    "gachapero": "ga-cha-pe-ro",
    "gachapo": "ga-cha-po",
    "gachasmigas": "ga-chas-mi-gas",
    "gaché": "ga-ché",
    "gacheta": "ga-che-ta",
    "gachí": "ga-chí",
    "gacho": "ga-cho",
    "gachó": "ga-chó",
    "gachón": "ga-chón",
    "gachona": "ga-cho-na",
    "gachonada": "ga-cho-na-da",
    "gachonería": "ga-cho-ne-rí-a",
    "gachumbo": "ga-chum-bo",
    "gachupín": "ga-chu-pín",
    "gachupina": "ga-chu-pi-na",
    "gacilla": "ga-ci-lla",
    "gádido": "gá-di-do",
    "gaditana": "ga-di-ta-na",
    "gaditano": "ga-di-ta-no",
    "gado": "ga-do",
    "gadolinio": "ga-do-li-nio",
    "gaélica": "ga-é-li-ca",
    "gaélico": "ga-é-li-co",
    "gaetana": "ga-e-ta-na",
    "gaetano": "ga-e-ta-no",
    "gafa": "ga-fa",
    "gafar": "ga-far",
    "gafarrón": "ga-fa-rrón",
    "gafe": "ga-fe",
    "gafear": "ga-fe-ar",
    "gafedad": "ga-fe-dad",
    "gafete": "ga-fe-te",
    "gafetí": "ga-fe-tí",
    "gafo": "ga-fo",
    "gafotas": "ga-fo-tas",
    "gafuda": "ga-fu-da",
    "gafudo": "ga-fu-do",
    "gaga": "ga-ga",
    "gagá": "ga-gá",
    "gagate": "ga-ga-te",
    "gagates": "ga-ga-tes",
    "gago": "ga-go",
    "gaguear": "ga-gue-ar",
    "gaguera": "ga-gue-ra",
    "gaibola": "gai-bo-la",
    "gaita": "gai-ta",
    "gaitera": "gai-te-ra",
    "gaitería": "gai-te-rí-a",
    "gaitero": "gai-te-ro",
    "gaje": "ga-je",
    "gajero": "ga-je-ro",
    "gajo": "ga-jo",
    "gajorro": "ga-jo-rro",
    "gajosa": "ga-jo-sa",
    "gajoso": "ga-jo-so",
    "gajuerro": "ga-jue-rro",
    "gala": "ga-la",
    "galaadita": "ga-la-a-di-ta",
    "galabardera": "ga-la-bar-de-ra",
    "galacho": "ga-la-cho",
    "galáctica": "ga-lác-ti-ca",
    "galáctico": "ga-lác-ti-co",
    "galactita": "ga-lac-ti-ta",
    "galactites": "ga-lac-ti-tes",
    "galactocele": "ga-lac-to-ce-le",
    "galactófaga": "ga-lac-tó-fa-ga",
    "galactófago": "ga-lac-tó-fa-go",
    "galactóforo": "ga-lac-tó-fo-ro",
    "galactógeno": "ga-lac-tó-ge-no",
    "galactómetro": "ga-lac-tó-me-tro",
    "galactosa": "ga-lac-to-sa",
    "galafate": "ga-la-fa-te",
    "gálago": "gá-la-go",
    "galaica": "ga-lai-ca",
    "galaico": "ga-lai-co",
    "galaicoportugués": "ga-lai-co-por-tu-gués",
    "galamera": "ga-la-me-ra",
    "galamero": "ga-la-me-ro",
    "galamperna": "ga-lam-per-na",
    "galán": "ga-lán",
    "galana": "ga-la-na",
    "galanamente": "ga-la-na-men-te",
    "galancete": "ga-lan-ce-te",
    "galanga": "ga-lan-ga",
    "galanía": "ga-la-ní-a",
    "galano": "ga-la-no",
    "galante": "ga-lan-te",
    "galanteador": "ga-lan-te-a-dor",
    "galanteadora": "ga-lan-te-a-do-ra",
    "galantear": "ga-lan-te-ar",
    "galantemente": "ga-lan-te-men-te",
    "galanteo": "ga-lan-te-o",
    "galantería": "ga-lan-te-rí-a",
    "galantina": "ga-lan-ti-na",
    "galanura": "ga-la-nu-ra",
    "galapagar": "ga-la-pa-gar",
    "galápago": "ga-lá-pa-go",
    "galapaguense": "ga-la-pa-guen-se",
    "galapaguera": "ga-la-pa-gue-ra",
    "galapatillo": "ga-la-pa-ti-llo",
    "galapero": "ga-la-pe-ro",
    "galapo": "ga-la-po",
    "galar": "ga-lar",
    "galardón": "ga-lar-dón",
    "galardonada": "ga-lar-do-na-da",
    "galardonado": "ga-lar-do-na-do",
    "galardonador": "ga-lar-do-na-dor",
    "galardonadora": "ga-lar-do-na-do-ra",
    "galardonar": "ga-lar-do-nar",
    "galarifo": "ga-la-ri-fo",
    "gálata": "gá-la-ta",
    "galatites": "ga-la-ti-tes",
    "galavardo": "ga-la-var-do",
    "galaxia": "ga-la-xia",
    "galayo": "ga-la-yo",
    "galbana": "gal-ba-na",
    "galbanada": "gal-ba-na-da",
    "galbanado": "gal-ba-na-do",
    "galbanera": "gal-ba-ne-ra",
    "galbanero": "gal-ba-ne-ro",
    "gálbano": "gál-ba-no",
    "galbanosa": "gal-ba-no-sa",
    "galbanoso": "gal-ba-no-so",
    "gálbula": "gál-bu-la",
    "galce": "gal-ce",
    "galdida": "gal-di-da",
    "galdido": "gal-di-do",
    "galdón": "gal-dón",
    "galdosiana": "gal-do-sia-na",
    "galdosiano": "gal-do-sia-no",
    "galdrufa": "gal-dru-fa",
    "galduda": "gal-du-da",
    "galdudo": "gal-du-do",
    "galea": "ga-le-a",
    "gálea": "gá-le-a",
    "galeana": "ga-le-a-na",
    "galeanense": "ga-le-a-nen-se",
    "galeato": "ga-le-a-to",
    "galeaza": "ga-le-a-za",
    "galega": "ga-le-ga",
    "galena": "ga-le-na",
    "galénica": "ga-lé-ni-ca",
    "galénico": "ga-lé-ni-co",
    "galenismo": "ga-le-nis-mo",
    "galenista": "ga-le-nis-ta",
    "galeno": "ga-le-no",
    "gáleo": "gá-le-o",
    "galeón": "ga-le-ón",
    "galeota": "ga-le-o-ta",
    "galeote": "ga-le-o-te",
    "galeoto": "ga-le-o-to",
    "galera": "ga-le-ra",
    "galerada": "ga-le-ra-da",
    "galerero": "ga-le-re-ro",
    "galería": "ga-le-rí-a",
    "galerín": "ga-le-rín",
    "galerista": "ga-le-ris-ta",
    "galerístico": "ga-le-rís-ti-co",
    "galerita": "ga-le-ri-ta",
    "galerna": "ga-ler-na",
    "galerno": "ga-ler-no",
    "galero": "ga-le-ro",
    "galerón": "ga-le-rón",
    "galés": "ga-lés",
    "galesa": "ga-le-sa",
    "galfarro": "gal-fa-rro",
    "galga": "gal-ga",
    "galgo": "gal-go",
    "galguear": "gal-gue-ar",
    "galgueña": "gal-gue-ña",
    "galgueño": "gal-gue-ño",
    "galguería": "gal-gue-rí-a",
    "galguero": "gal-gue-ro",
    "galguesca": "gal-gues-ca",
    "galguesco": "gal-gues-co",
    "gálgulo": "gál-gu-lo",
    "galiana": "ga-lia-na",
    "galianos": "ga-lia-nos",
    "galibar": "ga-li-bar",
    "gálibo": "gá-li-bo",
    "gálica": "gá-li-ca",
    "galicada": "ga-li-ca-da",
    "galicado": "ga-li-ca-do",
    "galicana": "ga-li-ca-na",
    "galicanismo": "ga-li-ca-nis-mo",
    "galicano": "ga-li-ca-no",
    "galiciana": "ga-li-cia-na",
    "galiciano": "ga-li-cia-no",
    "galicinio": "ga-li-ci-nio",
    "galicismo": "ga-li-cis-mo",
    "galicista": "ga-li-cis-ta",
    "gálico": "gá-li-co",
    "galicosa": "ga-li-co-sa",
    "galicoso": "ga-li-co-so",
    "galicursi": "ga-li-cur-si",
    "galilea": "ga-li-le-a",
    "galileo": "ga-li-le-o",
    "galillo": "ga-li-llo",
    "galima": "ga-li-ma",
    "galimar": "ga-li-mar",
    "galimatías": "ga-li-ma-tí-as",
    "galinácea": "ga-li-ná-ce-a",
    "galináceo": "ga-li-ná-ce-o",
    "galinda": "ga-lin-da",
    "galindo": "ga-lin-do",
    "galio": "ga-lio",
    "galiparla": "ga-li-par-la",
    "galiparlante": "ga-li-par-lan-te",
    "galiparlista": "ga-li-par-lis-ta",
    "galipote": "ga-li-po-te",
    "galizabra": "ga-li-za-bra",
    "galla": "ga-lla",
    "gallada": "ga-lla-da",
    "galladura": "ga-lla-du-ra",
    "gallar": "ga-llar",
    "gállara": "gá-lla-ra",
    "gallarda": "ga-llar-da",
    "gallardamente": "ga-llar-da-men-te",
    "gallardear": "ga-llar-de-ar",
    "gallardete": "ga-llar-de-te",
    "gallardetón": "ga-llar-de-tón",
    "gallardía": "ga-llar-dí-a",
    "gallardo": "ga-llar-do",
    "gallareta": "ga-lla-re-ta",
    "gallarín": "ga-lla-rín",
    "gállaro": "gá-lla-ro",
    "gallarofa": "ga-lla-ro-fa",
    "gallarón": "ga-lla-rón",
    "gallaruza": "ga-lla-ru-za",
    "gallear": "ga-lle-ar",
    "gallega": "ga-lle-ga",
    "gallegada": "ga-lle-ga-da",
    "gallego": "ga-lle-go",
    "gallegohablante": "ga-lle-go-ha-blan-te",
    "gallegoparlante": "ga-lle-go-par-lan-te",
    "gallegoportugués": "ga-lle-go-por-tu-gués",
    "gallegoportuguesa": "ga-lle-go-por-tu-gue-sa",
    "galleguense": "ga-lle-guen-se",
    "galleguismo": "ga-lle-guis-mo",
    "galleguista": "ga-lle-guis-ta",
    "galleguizar": "ga-lle-gui-zar",
    "galleo": "ga-lle-o",
    "gallera": "ga-lle-ra",
    "gallería": "ga-lle-rí-a",
    "gallero": "ga-lle-ro",
    "galleta": "ga-lle-ta",
    "gallete": "ga-lle-te",
    "galletear": "ga-lle-te-ar",
    "galletera": "ga-lle-te-ra",
    "galletería": "ga-lle-te-rí-a",
    "galletero": "ga-lle-te-ro",
    "galliforme": "ga-lli-for-me",
    "gallillo": "ga-lli-llo",
    "gallina": "ga-lli-na",
    "gallinácea": "ga-lli-ná-ce-a",
    "gallináceo": "ga-lli-ná-ce-o",
    "gallinaza": "ga-lli-na-za",
    "gallinazo": "ga-lli-na-zo",
    "gallinejas": "ga-lli-ne-jas",
    "gallinera": "ga-lli-ne-ra",
    "gallinería": "ga-lli-ne-rí-a",
    "gallinero": "ga-lli-ne-ro",
    "gallineta": "ga-lli-ne-ta",
    "gallinita": "ga-lli-ni-ta",
    "gallino": "ga-lli-no",
    "gallinuela": "ga-lli-nue-la",
    "gallipato": "ga-lli-pa-to",
    "gallipava": "ga-lli-pa-va",
    "gallipavo": "ga-lli-pa-vo",
    "gallipuente": "ga-lli-puen-te",
    "gallística": "ga-llís-ti-ca",
    "gallístico": "ga-llís-ti-co",
    "gallito": "ga-lli-to",
    "gallo": "ga-llo",
    "gallocresta": "ga-llo-cres-ta",
    "gallofa": "ga-llo-fa",
    "gallofar": "ga-llo-far",
    "gallofear": "ga-llo-fe-ar",
    "gallofera": "ga-llo-fe-ra",
    "gallofero": "ga-llo-fe-ro",
    "gallofo": "ga-llo-fo",
    "gallogallina": "ga-llo-ga-lli-na",
    "gallón": "ga-llón",
    "gallonada": "ga-llo-na-da",
    "gallonado": "ga-llo-na-do",
    "gallopinto": "ga-llo-pin-to",
    "galludo": "ga-llu-do",
    "gallundera": "ga-llun-de-ra",
    "galo": "ga-lo",
    "galocha": "ga-lo-cha",
    "galochero": "ga-lo-che-ro",
    "galocho": "ga-lo-cho",
    "galófila": "ga-ló-fi-la",
    "galófilo": "ga-ló-fi-lo",
    "galófoba": "ga-ló-fo-ba",
    "galofobia": "ga-lo-fo-bia",
    "galófobo": "ga-ló-fo-bo",
    "galolatino": "ga-lo-la-ti-no",
    "galón": "ga-lón",
    "galoneador": "ga-lo-ne-a-dor",
    "galoneadora": "ga-lo-ne-a-do-ra",
    "galoneadura": "ga-lo-ne-a-du-ra",
    "galonear": "ga-lo-ne-ar",
    "galonista": "ga-lo-nis-ta",
    "galop": "ga-lop",
    "galopa": "ga-lo-pa",
    "galopada": "ga-lo-pa-da",
    "galopante": "ga-lo-pan-te",
    "galopar": "ga-lo-par",
    "galope": "ga-lo-pe",
    "galopeada": "ga-lo-pe-a-da",
    "galopeado": "ga-lo-pe-a-do",
    "galopear": "ga-lo-pe-ar",
    "galopeo": "ga-lo-pe-o",
    "galopillo": "ga-lo-pi-llo",
    "galopín": "ga-lo-pín",
    "galopinada": "ga-lo-pi-na-da",
    "galopo": "ga-lo-po",
    "galorromance": "ga-lo-rro-man-ce",
    "galorrománico": "ga-lo-rro-má-ni-co",
    "galorromano": "ga-lo-rro-ma-no",
    "galota": "ga-lo-ta",
    "galpito": "gal-pi-to",
    "galpón": "gal-pón",
    "galponera": "gal-po-ne-ra",
    "galponero": "gal-po-ne-ro",
    "galúa": "ga-lú-a",
    "galucha": "ga-lu-cha",
    "galuchar": "ga-lu-char",
    "galvánica": "gal-vá-ni-ca",
    "galvánico": "gal-vá-ni-co",
    "galvanismo": "gal-va-nis-mo",
    "galvanización": "gal-va-ni-za-ción",
    "galvanizado": "gal-va-ni-za-do",
    "galvanizador": "gal-va-ni-za-dor",
    "galvanizar": "gal-va-ni-zar",
    "galvano": "gal-va-no",
    "galvanométrico": "gal-va-no-mé-tri-co",
    "galvanómetro": "gal-va-nó-me-tro",
    "galvanoplasta": "gal-va-no-plas-ta",
    "galvanoplastia": "gal-va-no-plas-tia",
    "galvanoplástica": "gal-va-no-plás-ti-ca",
    "galvanoplástico": "gal-va-no-plás-ti-co",
    "galvanoscopio": "gal-va-nos-co-pio",
    "galvanostega": "gal-va-nos-te-ga",
    "galvanostegia": "gal-va-nos-te-gia",
    "galvanotipia": "gal-va-no-ti-pia",
    "gama": "ga-ma",
    "gamada": "ga-ma-da",
    "gamado": "ga-ma-do",
    "gamalotal": "ga-ma-lo-tal",
    "gamalote": "ga-ma-lo-te",
    "gamarra": "ga-ma-rra",
    "gamarza": "ga-mar-za",
    "gamba": "gam-ba",
    "gambado": "gam-ba-do",
    "gambaj": "gam-baj",
    "gámbalo": "gám-ba-lo",
    "gambalúa": "gam-ba-lú-a",
    "gámbaro": "gám-ba-ro",
    "gambax": "gam-bax",
    "gamberra": "gam-be-rra",
    "gamberrada": "gam-be-rra-da",
    "gamberrear": "gam-be-rre-ar",
    "gamberrismo": "gam-be-rris-mo",
    "gamberro": "gam-be-rro",
    "gambesina": "gam-be-si-na",
    "gambesón": "gam-be-són",
    "gambeta": "gam-be-ta",
    "gambetear": "gam-be-te-ar",
    "gambeteo": "gam-be-te-o",
    "gambeto": "gam-be-to",
    "gambiana": "gam-bia-na",
    "gambiano": "gam-bia-no",
    "gambito": "gam-bi-to",
    "gamboa": "gam-bo-a",
    "gambocho": "gam-bo-cho",
    "gamboge": "gam-bo-ge",
    "gambota": "gam-bo-ta",
    "gambox": "gam-box",
    "gambucero": "gam-bu-ce-ro",
    "gambuj": "gam-buj",
    "gambujo": "gam-bu-jo",
    "gambusina": "gam-bu-si-na",
    "gambusino": "gam-bu-si-no",
    "gambux": "gam-bux",
    "gambuza": "gam-bu-za",
    "gamelán": "ga-me-lán",
    "gamella": "ga-me-lla",
    "gamellada": "ga-me-lla-da",
    "gamello": "ga-me-llo",
    "gamellón": "ga-me-llón",
    "gamelotal": "ga-me-lo-tal",
    "gamelote": "ga-me-lo-te",
    "gameto": "ga-me-to",
    "gametofito": "ga-me-to-fi-to",
    "gametófito": "ga-me-tó-fi-to",
    "gametogénesis": "ga-me-to-gé-ne-sis",
    "gamezno": "ga-mez-no",
    "gamillón": "ga-mi-llón",
    "gamín": "ga-mín",
    "gamitadera": "ga-mi-ta-de-ra",
    "gamitana": "ga-mi-ta-na",
    "gamitar": "ga-mi-tar",
    "gamitido": "ga-mi-ti-do",
    "gamma": "gam-ma",
    "gammaglobulina": "gam-ma-glo-bu-li-na",
    "gammagrafía": "gam-ma-gra-fí-a",
    "gamo": "ga-mo",
    "gamón": "ga-món",
    "gamonal": "ga-mo-nal",
    "gamonalismo": "ga-mo-na-lis-mo",
    "gamonedo": "ga-mo-ne-do",
    "gamonita": "ga-mo-ni-ta",
    "gamonito": "ga-mo-ni-to",
    "gamonosa": "ga-mo-no-sa",
    "gamonoso": "ga-mo-no-so",
    "gamopétala": "ga-mo-pé-ta-la",
    "gamopétalo": "ga-mo-pé-ta-lo",
    "gamosépala": "ga-mo-sé-pa-la",
    "gamosépalo": "ga-mo-sé-pa-lo",
    "gamuna": "ga-mu-na",
    "gamuno": "ga-mu-no",
    "gamusino": "ga-mu-si-no",
    "gamuza": "ga-mu-za",
    "gamuzada": "ga-mu-za-da",
    "gamuzado": "ga-mu-za-do",
    "gana": "ga-na",
    "ganable": "ga-na-ble",
    "ganada": "ga-na-da",
    "ganadera": "ga-na-de-ra",
    "ganadería": "ga-na-de-rí-a",
    "ganadero": "ga-na-de-ro",
    "ganado": "ga-na-do",
    "ganador": "ga-na-dor",
    "ganadora": "ga-na-do-ra",
    "gañafón": "ga-ña-fón",
    "gañán": "ga-ñán",
    "ganancia": "ga-nan-cia",
    "ganancial": "ga-nan-cial",
    "gananciera": "ga-nan-cie-ra",
    "gananciero": "ga-nan-cie-ro",
    "gananciosa": "ga-nan-cio-sa",
    "ganancioso": "ga-nan-cio-so",
    "gañanía": "ga-ña-ní-a",
    "ganapán": "ga-na-pán",
    "ganapierde": "ga-na-pier-de",
    "ganar": "ga-nar",
    "gancha": "gan-cha",
    "ganchera": "gan-che-ra",
    "ganchero": "gan-che-ro",
    "ganchete": "gan-che-te",
    "ganchillera": "gan-chi-lle-ra",
    "ganchillero": "gan-chi-lle-ro",
    "ganchillo": "gan-chi-llo",
    "ganchito": "gan-chi-to",
    "gancho": "gan-cho",
    "ganchosa": "gan-cho-sa",
    "ganchoso": "gan-cho-so",
    "ganchuda": "gan-chu-da",
    "ganchudo": "gan-chu-do",
    "gandalla": "gan-da-lla",
    "gándara": "gán-da-ra",
    "gandaya": "gan-da-ya",
    "gandida": "gan-di-da",
    "gandido": "gan-di-do",
    "gandiense": "gan-dien-se",
    "gandinga": "gan-din-ga",
    "gandir": "gan-dir",
    "gandola": "gan-do-la",
    "gandolero": "gan-do-le-ro",
    "gandujado": "gan-du-ja-do",
    "gandujar": "gan-du-jar",
    "gandul": "gan-dul",
    "gandula": "gan-du-la",
    "gandulear": "gan-du-le-ar",
    "gandulería": "gan-du-le-rí-a",
    "gandumbas": "gan-dum-bas",
    "ganeta": "ga-ne-ta",
    "ganforra": "gan-fo-rra",
    "ganforro": "gan-fo-rro",
    "ganga": "gan-ga",
    "gangarilla": "gan-ga-ri-lla",
    "gangarria": "gan-ga-rria",
    "ganglio": "gan-glio",
    "ganglionar": "gan-glio-nar",
    "gangocho": "gan-go-cho",
    "gangosa": "gan-go-sa",
    "gangosidad": "gan-go-si-dad",
    "gangoso": "gan-go-so",
    "gangrena": "gan-gre-na",
    "gangrenar": "gan-gre-nar",
    "gangrenarse": "gan-gre-nar-se",
    "gangrénica": "gan-gré-ni-ca",
    "gangrénico": "gan-gré-ni-co",
    "gangrenosa": "gan-gre-no-sa",
    "gangrenoso": "gan-gre-no-so",
    "gángster": "gángs-ter",
    "gangsterismo": "gangs-te-ris-mo",
    "ganguear": "gan-gue-ar",
    "gangueo": "gan-gue-o",
    "ganguera": "gan-gue-ra",
    "ganguero": "gan-gue-ro",
    "gánguil": "gán-guil",
    "gañido": "ga-ñi-do",
    "gañil": "ga-ñil",
    "gañín": "ga-ñín",
    "gañir": "ga-ñir",
    "gañivete": "ga-ñi-ve-te",
    "ganoideo": "ga-noi-de-o",
    "gañón": "ga-ñón",
    "ganona": "ga-no-na",
    "ganosa": "ga-no-sa",
    "ganosamente": "ga-no-sa-men-te",
    "ganoso": "ga-no-so",
    "gañote": "ga-ño-te",
    "gañotudo": "ga-ño-tu-do",
    "gansa": "gan-sa",
    "gansada": "gan-sa-da",
    "gansarón": "gan-sa-rón",
    "gansear": "gan-se-ar",
    "ganso": "gan-so",
    "gánster": "gáns-ter",
    "gansterismo": "gans-te-ris-mo",
    "ganta": "gan-ta",
    "gante": "gan-te",
    "gantés": "gan-tés",
    "gantesa": "gan-te-sa",
    "ganzúa": "gan-zú-a",
    "ganzuar": "gan-zuar",
    "gaollo": "ga-o-llo",
    "gaón": "ga-ón",
    "gaonera": "ga-o-ne-ra",
    "gáraba": "gá-ra-ba",
    "garabasta": "ga-ra-bas-ta",
    "garabatá": "ga-ra-ba-tá",
    "garabatada": "ga-ra-ba-ta-da",
    "garabatal": "ga-ra-ba-tal",
    "garabatear": "ga-ra-ba-te-ar",
    "garabateo": "ga-ra-ba-te-o",
    "garabatera": "ga-ra-ba-te-ra",
    "garabatero": "ga-ra-ba-te-ro",
    "garabato": "ga-ra-ba-to",
    "garabatosa": "ga-ra-ba-to-sa",
    "garabatoso": "ga-ra-ba-to-so",
    "garabito": "ga-ra-bi-to",
    "garaje": "ga-ra-je",
    "garama": "ga-ra-ma",
    "garamanta": "ga-ra-man-ta",
    "garamante": "ga-ra-man-te",
    "garambaina": "ga-ram-bai-na",
    "garambullo": "ga-ram-bu-llo",
    "garandumba": "ga-ran-dum-ba",
    "garañón": "ga-ra-ñón",
    "garante": "ga-ran-te",
    "garantía": "ga-ran-tí-a",
    "garantir": "ga-ran-tir",
    "garantizador": "ga-ran-ti-za-dor",
    "garantizadora": "ga-ran-ti-za-do-ra",
    "garantizar": "ga-ran-ti-zar",
    "garañuela": "ga-ra-ñue-la",
    "garapacho": "ga-ra-pa-cho",
    "garapanda": "ga-ra-pan-da",
    "garapiña": "ga-ra-pi-ña",
    "garapiñar": "ga-ra-pi-ñar",
    "garapiñera": "ga-ra-pi-ñe-ra",
    "garapita": "ga-ra-pi-ta",
    "garapito": "ga-ra-pi-to",
    "garapullo": "ga-ra-pu-llo",
    "garata": "ga-ra-ta",
    "garatera": "ga-ra-te-ra",
    "garatero": "ga-ra-te-ro",
    "garatura": "ga-ra-tu-ra",
    "garatusa": "ga-ra-tu-sa",
    "garay": "ga-ray",
    "garba": "gar-ba",
    "garbanceo": "gar-ban-ce-o",
    "garbancera": "gar-ban-ce-ra",
    "garbancero": "gar-ban-ce-ro",
    "garbancillo": "gar-ban-ci-llo",
    "garbanza": "gar-ban-za",
    "garbanzal": "gar-ban-zal",
    "garbanzo": "gar-ban-zo",
    "garbanzón": "gar-ban-zón",
    "garbanzuelo": "gar-ban-zue-lo",
    "garbar": "gar-bar",
    "garbear": "gar-be-ar",
    "garbeo": "gar-be-o",
    "garbera": "gar-be-ra",
    "garbero": "gar-be-ro",
    "garbías": "gar-bí-as",
    "garbillador": "gar-bi-lla-dor",
    "garbilladora": "gar-bi-lla-do-ra",
    "garbillar": "gar-bi-llar",
    "garbillo": "gar-bi-llo",
    "garbín": "gar-bín",
    "garbino": "gar-bi-no",
    "garbo": "gar-bo",
    "gárboli": "gár-bo-li",
    "garbón": "gar-bón",
    "garbosa": "gar-bo-sa",
    "garbosamente": "gar-bo-sa-men-te",
    "garboso": "gar-bo-so",
    "gárbula": "gár-bu-la",
    "garbullo": "gar-bu-llo",
    "garcero": "gar-ce-ro",
    "garceta": "gar-ce-ta",
    "garchar": "gar-char",
    "garcía": "gar-cí-a",
    "garcilasiano": "gar-ci-la-sia-no",
    "garcilasista": "gar-ci-la-sis-ta",
    "garcilla": "gar-ci-lla",
    "gardacho": "gar-da-cho",
    "gardama": "gar-da-ma",
    "gardenia": "gar-de-nia",
    "gardingo": "gar-din-go",
    "gardubera": "gar-du-be-ra",
    "garduja": "gar-du-ja",
    "garduña": "gar-du-ña",
    "garduño": "gar-du-ño",
    "gareta": "ga-re-ta",
    "garete": "ga-re-te",
    "garfa": "gar-fa",
    "garfada": "gar-fa-da",
    "garfear": "gar-fe-ar",
    "garfiada": "gar-fia-da",
    "garfio": "gar-fio",
    "gargajeada": "gar-ga-je-a-da",
    "gargajear": "gar-ga-je-ar",
    "gargajeo": "gar-ga-je-o",
    "gargajienta": "gar-ga-jien-ta",
    "gargajiento": "gar-ga-jien-to",
    "gargajo": "gar-ga-jo",
    "gargajosa": "gar-ga-jo-sa",
    "gargajoso": "gar-ga-jo-so",
    "gargal": "gar-gal",
    "gargalizar": "gar-ga-li-zar",
    "gargamello": "gar-ga-me-llo",
    "gargamillón": "gar-ga-mi-llón",
    "garganchón": "gar-gan-chón",
    "garganta": "gar-gan-ta",
    "gargantada": "gar-gan-ta-da",
    "gargantear": "gar-gan-te-ar",
    "garganteo": "gar-gan-te-o",
    "gargantera": "gar-gan-te-ra",
    "gargantería": "gar-gan-te-rí-a",
    "gargantero": "gar-gan-te-ro",
    "gargantil": "gar-gan-til",
    "gargantilla": "gar-gan-ti-lla",
    "gargantillo": "gar-gan-ti-llo",
    "gargantón": "gar-gan-tón",
    "gargantona": "gar-gan-to-na",
    "gargantúa": "gar-gan-tú-a",
    "gárgara": "gár-ga-ra",
    "gargarear": "gar-ga-re-ar",
    "gargarismo": "gar-ga-ris-mo",
    "gargarizar": "gar-ga-ri-zar",
    "gárgaro": "gár-ga-ro",
    "gargavero": "gar-ga-ve-ro",
    "gárgol": "gár-gol",
    "gárgola": "gár-go-la",
    "gargolismo": "gar-go-lis-mo",
    "gargozada": "gar-go-za-da",
    "garguero": "gar-gue-ro",
    "gargüero": "gar-güe-ro",
    "garia": "ga-ria",
    "garibaldina": "ga-ri-bal-di-na",
    "garieta": "ga-rie-ta",
    "garifa": "ga-ri-fa",
    "garifo": "ga-ri-fo",
    "garífuna": "ga-rí-fu-na",
    "garigola": "ga-ri-go-la",
    "garigoleado": "ga-ri-go-le-a-do",
    "gario": "ga-rio",
    "gariofilea": "ga-rio-fi-le-a",
    "gariofilo": "ga-rio-fi-lo",
    "garita": "ga-ri-ta",
    "garitera": "ga-ri-te-ra",
    "garitero": "ga-ri-te-ro",
    "garito": "ga-ri-to",
    "garitón": "ga-ri-tón",
    "garla": "gar-la",
    "garlador": "gar-la-dor",
    "garladora": "gar-la-do-ra",
    "garlar": "gar-lar",
    "garlera": "gar-le-ra",
    "garlero": "gar-le-ro",
    "garlido": "gar-li-do",
    "garlito": "gar-li-to",
    "garlo": "gar-lo",
    "garlocha": "gar-lo-cha",
    "garlopa": "gar-lo-pa",
    "garma": "gar-ma",
    "garmasa": "gar-ma-sa",
    "garmejón": "gar-me-jón",
    "garnacha": "gar-na-cha",
    "garnacho": "gar-na-cho",
    "garnatón": "gar-na-tón",
    "garniel": "gar-niel",
    "garnucho": "gar-nu-cho",
    "garo": "ga-ro",
    "garojo": "ga-ro-jo",
    "garosa": "ga-ro-sa",
    "garoso": "ga-ro-so",
    "garpa": "gar-pa",
    "garpar": "gar-par",
    "garra": "ga-rra",
    "garrabera": "ga-rra-be-ra",
    "garrafa": "ga-rra-fa",
    "garrafal": "ga-rra-fal",
    "garrafina": "ga-rra-fi-na",
    "garrafiñar": "ga-rra-fi-ñar",
    "garrafón": "ga-rra-fón",
    "garraleta": "ga-rra-le-ta",
    "garrama": "ga-rra-ma",
    "garramar": "ga-rra-mar",
    "garrampa": "ga-rram-pa",
    "garrancha": "ga-rran-cha",
    "garranchada": "ga-rran-cha-da",
    "garranchazo": "ga-rran-cha-zo",
    "garrancho": "ga-rran-cho",
    "garranchuelo": "ga-rran-chue-lo",
    "garrapata": "ga-rra-pa-ta",
    "garrapatea": "ga-rra-pa-te-a",
    "garrapatear": "ga-rra-pa-te-ar",
    "garrapatero": "ga-rra-pa-te-ro",
    "garrapato": "ga-rra-pa-to",
    "garrapatón": "ga-rra-pa-tón",
    "garrapatosa": "ga-rra-pa-to-sa",
    "garrapatoso": "ga-rra-pa-to-so",
    "garrapiña": "ga-rra-pi-ña",
    "garrapiñada": "ga-rra-pi-ña-da",
    "garrapiñado": "ga-rra-pi-ña-do",
    "garrapiñar": "ga-rra-pi-ñar",
    "garrapo": "ga-rra-po",
    "garrar": "ga-rrar",
    "garrasí": "ga-rra-sí",
    "garrear": "ga-rre-ar",
    "garria": "ga-rria",
    "garrida": "ga-rri-da",
    "garridamente": "ga-rri-da-men-te",
    "garrideza": "ga-rri-de-za",
    "garrido": "ga-rri-do",
    "garridura": "ga-rri-du-ra",
    "garriga": "ga-rri-ga",
    "garrir": "ga-rrir",
    "garroba": "ga-rro-ba",
    "garrobal": "ga-rro-bal",
    "garrobear": "ga-rro-be-ar",
    "garrobera": "ga-rro-be-ra",
    "garrobero": "ga-rro-be-ro",
    "garrobilla": "ga-rro-bi-lla",
    "garrobo": "ga-rro-bo",
    "garrocha": "ga-rro-cha",
    "garrochar": "ga-rro-char",
    "garrochazo": "ga-rro-cha-zo",
    "garrochear": "ga-rro-che-ar",
    "garrochero": "ga-rro-che-ro",
    "garrochista": "ga-rro-chis-ta",
    "garrochón": "ga-rro-chón",
    "garrochona": "ga-rro-cho-na",
    "garrofa": "ga-rro-fa",
    "garrofal": "ga-rro-fal",
    "garrofero": "ga-rro-fe-ro",
    "garrón": "ga-rrón",
    "garronear": "ga-rro-ne-ar",
    "garronera": "ga-rro-ne-ra",
    "garronero": "ga-rro-ne-ro",
    "garronuda": "ga-rro-nu-da",
    "garrota": "ga-rro-ta",
    "garrotal": "ga-rro-tal",
    "garrotazo": "ga-rro-ta-zo",
    "garrote": "ga-rro-te",
    "garrotear": "ga-rro-te-ar",
    "garrotera": "ga-rro-te-ra",
    "garrotero": "ga-rro-te-ro",
    "garrotillo": "ga-rro-ti-llo",
    "garrotín": "ga-rro-tín",
    "garrubia": "ga-rru-bia",
    "garrucha": "ga-rru-cha",
    "garrucho": "ga-rru-cho",
    "garruda": "ga-rru-da",
    "garrudo": "ga-rru-do",
    "garrula": "ga-rru-la",
    "gárrula": "gá-rru-la",
    "garrulador": "ga-rru-la-dor",
    "garruladora": "ga-rru-la-do-ra",
    "garrulería": "ga-rru-le-rí-a",
    "garrulidad": "ga-rru-li-dad",
    "garrulo": "ga-rru-lo",
    "gárrulo": "gá-rru-lo",
    "garúa": "ga-rú-a",
    "garuar": "ga-ruar",
    "garufa": "ga-ru-fa",
    "garujo": "ga-ru-jo",
    "garulla": "ga-ru-lla",
    "garullada": "ga-ru-lla-da",
    "garullo": "ga-ru-llo",
    "garvín": "gar-vín",
    "garza": "gar-za",
    "garzo": "gar-zo",
    "garzón": "gar-zón",
    "garzona": "gar-zo-na",
    "garzonear": "gar-zo-ne-ar",
    "garzonía": "gar-zo-ní-a",
    "garzota": "gar-zo-ta",
    "gasa": "ga-sa",
    "gasajado": "ga-sa-ja-do",
    "gasajar": "ga-sa-jar",
    "gasajo": "ga-sa-jo",
    "gasajosa": "ga-sa-jo-sa",
    "gasajoso": "ga-sa-jo-so",
    "gascón": "gas-cón",
    "gascona": "gas-co-na",
    "gasconés": "gas-co-nés",
    "gasconesa": "gas-co-ne-sa",
    "gasear": "ga-se-ar",
    "gaseiforme": "ga-sei-for-me",
    "gasendismo": "ga-sen-dis-mo",
    "gasendista": "ga-sen-dis-ta",
    "gaseoducto": "ga-se-o-duc-to",
    "gaseosa": "ga-se-o-sa",
    "gaseoso": "ga-se-o-so",
    "gasero": "ga-se-ro",
    "gasfitería": "gas-fi-te-rí-a",
    "gasfitero": "gas-fi-te-ro",
    "gasificación": "ga-si-fi-ca-ción",
    "gasificado": "ga-si-fi-ca-do",
    "gasificar": "ga-si-fi-car",
    "gasista": "ga-sis-ta",
    "gasística": "ga-sís-ti-ca",
    "gasístico": "ga-sís-ti-co",
    "gasmoña": "gas-mo-ña",
    "gasoducto": "ga-so-duc-to",
    "gasógeno": "ga-só-ge-no",
    "gasoil": "ga-soil",
    "gasoleno": "ga-so-le-no",
    "gasóleo": "ga-só-le-o",
    "gasolera": "ga-so-le-ra",
    "gasolero": "ga-so-le-ro",
    "gasolina": "ga-so-li-na",
    "gasolinera": "ga-so-li-ne-ra",
    "gasolinero": "ga-so-li-ne-ro",
    "gasometría": "ga-so-me-trí-a",
    "gasométrico": "ga-so-mé-tri-co",
    "gasómetro": "ga-só-me-tro",
    "gasón": "ga-són",
    "gastable": "gas-ta-ble",
    "gastada": "gas-ta-da",
    "gastadero": "gas-ta-de-ro",
    "gastado": "gas-ta-do",
    "gastador": "gas-ta-dor",
    "gastadora": "gas-ta-do-ra",
    "gastamiento": "gas-ta-mien-to",
    "gastar": "gas-tar",
    "gasterópodo": "gas-te-ró-po-do",
    "gastivo": "gas-ti-vo",
    "gastizo": "gas-ti-zo",
    "gasto": "gas-to",
    "gastosa": "gas-to-sa",
    "gastoso": "gas-to-so",
    "gastralgia": "gas-tral-gia",
    "gastrálgica": "gas-trál-gi-ca",
    "gastrálgico": "gas-trál-gi-co",
    "gastrectomía": "gas-trec-to-mí-a",
    "gástrica": "gás-tri-ca",
    "gástrico": "gás-tri-co",
    "gastrina": "gas-tri-na",
    "gastritis": "gas-tri-tis",
    "gastroduodenal": "gas-tro-duo-de-nal",
    "gastroentérico": "gas-tro-en-té-ri-co",
    "gastroenteritis": "gas-tro-en-te-ri-tis",
    "gastroenteróloga": "gas-tro-en-te-ró-lo-ga",
    "gastroenterología": "gas-tro-en-te-ro-lo-gí-a",
    "gastroenterológico": "gas-tro-en-te-ro-ló-gi-co",
    "gastroenterólogo": "gas-tro-en-te-ró-lo-go",
    "gastroenterostomía": "gas-tro-en-te-ros-to-mí-a",
    "gastrointestinal": "gas-troin-tes-ti-nal",
    "gastrolito": "gas-tro-li-to",
    "gastrónoma": "gas-tró-no-ma",
    "gastronomía": "gas-tro-no-mí-a",
    "gastronómica": "gas-tro-nó-mi-ca",
    "gastronómico": "gas-tro-nó-mi-co",
    "gastrónomo": "gas-tró-no-mo",
    "gastropatía": "gas-tro-pa-tí-a",
    "gastroscopia": "gas-tros-co-pia",
    "gastroscopio": "gas-tros-co-pio",
    "gastrovascular": "gas-tro-vas-cu-lar",
    "gástrula": "gás-tru-la",
    "gastrulación": "gas-tru-la-ción",
    "gata": "ga-ta",
    "gatada": "ga-ta-da",
    "gatallón": "ga-ta-llón",
    "gatallona": "ga-ta-llo-na",
    "gatas": "ga-tas",
    "gatatumba": "ga-ta-tum-ba",
    "gatazo": "ga-ta-zo",
    "gateada": "ga-te-a-da",
    "gateado": "ga-te-a-do",
    "gateamiento": "ga-te-a-mien-to",
    "gatear": "ga-te-ar",
    "gatera": "ga-te-ra",
    "gatería": "ga-te-rí-a",
    "gatero": "ga-te-ro",
    "gatesca": "ga-tes-ca",
    "gatesco": "ga-tes-co",
    "gatillazo": "ga-ti-lla-zo",
    "gatillero": "ga-ti-lle-ro",
    "gatillo": "ga-ti-llo",
    "gato": "ga-to",
    "gatomusa": "ga-to-mu-sa",
    "gatomuso": "ga-to-mu-so",
    "gatopardo": "ga-to-par-do",
    "gatuna": "ga-tu-na",
    "gatuña": "ga-tu-ña",
    "gatunero": "ga-tu-ne-ro",
    "gatuno": "ga-tu-no",
    "gatuperio": "ga-tu-pe-rio",
    "gatuzco": "ga-tuz-co",
    "gaucha": "gau-cha",
    "gauchada": "gau-cha-da",
    "gauchaje": "gau-cha-je",
    "gauchear": "gau-che-ar",
    "gauchesca": "gau-ches-ca",
    "gauchesco": "gau-ches-co",
    "gauchismo": "gau-chis-mo",
    "gaucho": "gau-cho",
    "gaudeamus": "gau-de-a-mus",
    "gaudiniano": "gau-di-nia-no",
    "gaudón": "gau-dón",
    "gaulteria": "gaul-te-ria",
    "gavanza": "ga-van-za",
    "gavanzo": "ga-van-zo",
    "gavera": "ga-ve-ra",
    "gaveta": "ga-ve-ta",
    "gavetero": "ga-ve-te-ro",
    "gavia": "ga-via",
    "gavial": "ga-vial",
    "gaviero": "ga-vie-ro",
    "gavieta": "ga-vie-ta",
    "gaviete": "ga-vie-te",
    "gavilán": "ga-vi-lán",
    "gavilana": "ga-vi-la-na",
    "gavilancillo": "ga-vi-lan-ci-llo",
    "gavilla": "ga-vi-lla",
    "gavillar": "ga-vi-llar",
    "gavillero": "ga-vi-lle-ro",
    "gavina": "ga-vi-na",
    "gavinote": "ga-vi-no-te",
    "gavión": "ga-vión",
    "gaviota": "ga-vio-ta",
    "gavota": "ga-vo-ta",
    "gaya": "ga-ya",
    "gayadura": "ga-ya-du-ra",
    "gayar": "ga-yar",
    "gayata": "ga-ya-ta",
    "gayo": "ga-yo",
    "gayola": "ga-yo-la",
    "gayomba": "ga-yom-ba",
    "gayuba": "ga-yu-ba",
    "gayumbos": "ga-yum-bos",
    "gaza": "ga-za",
    "gazafatón": "ga-za-fa-tón",
    "gazapa": "ga-za-pa",
    "gazapatón": "ga-za-pa-tón",
    "gazapera": "ga-za-pe-ra",
    "gazapina": "ga-za-pi-na",
    "gazapo": "ga-za-po",
    "gazapón": "ga-za-pón",
    "gazgaz": "gaz-gaz",
    "gazmiar": "gaz-miar",
    "gazmol": "gaz-mol",
    "gazmoña": "gaz-mo-ña",
    "gazmoñada": "gaz-mo-ña-da",
    "gazmoñera": "gaz-mo-ñe-ra",
    "gazmoñería": "gaz-mo-ñe-rí-a",
    "gazmoñero": "gaz-mo-ñe-ro",
    "gazmoño": "gaz-mo-ño",
    "gaznápira": "gaz-ná-pi-ra",
    "gaznápiro": "gaz-ná-pi-ro",
    "gaznar": "gaz-nar",
    "gaznatada": "gaz-na-ta-da",
    "gaznatazo": "gaz-na-ta-zo",
    "gaznate": "gaz-na-te",
    "gaznatón": "gaz-na-tón",
    "gaznido": "gaz-ni-do",
    "gazofia": "ga-zo-fia",
    "gazofilacio": "ga-zo-fi-la-cio",
    "gazpachero": "gaz-pa-che-ro",
    "gazpacho": "gaz-pa-cho",
    "gazpachuelo": "gaz-pa-chue-lo",
    "gazuza": "ga-zu-za",
    "gea": "ge-a",
    "geco": "ge-co",
    "gecónido": "ge-có-ni-do",
    "gehena": "ge-he-na",
    "géiser": "géi-ser",
    "geisha": "geis-ha",
    "gejionense": "ge-jio-nen-se",
    "gelado": "ge-la-do",
    "gelamonita": "ge-la-mo-ni-ta",
    "gelar": "ge-lar",
    "gelatina": "ge-la-ti-na",
    "gelatinosa": "ge-la-ti-no-sa",
    "gelatinoso": "ge-la-ti-no-so",
    "geldre": "gel-dre",
    "gelfe": "gel-fe",
    "gélida": "gé-li-da",
    "gelidez": "ge-li-dez",
    "gélido": "gé-li-do",
    "gelignita": "ge-lig-ni-ta",
    "gelivación": "ge-li-va-ción",
    "gema": "ge-ma",
    "gemación": "ge-ma-ción",
    "gemebunda": "ge-me-bun-da",
    "gemebundo": "ge-me-bun-do",
    "gemela": "ge-me-la",
    "gemelar": "ge-me-lar",
    "gemelo": "ge-me-lo",
    "gemido": "ge-mi-do",
    "gemidor": "ge-mi-dor",
    "gemidora": "ge-mi-do-ra",
    "gémina": "gé-mi-na",
    "geminación": "ge-mi-na-ción",
    "geminada": "ge-mi-na-da",
    "geminado": "ge-mi-na-do",
    "geminar": "ge-mi-nar",
    "geminiana": "ge-mi-nia-na",
    "geminiano": "ge-mi-nia-no",
    "géminis": "gé-mi-nis",
    "gémino": "gé-mi-no",
    "gemípara": "ge-mí-pa-ra",
    "gemíparo": "ge-mí-pa-ro",
    "gemiquear": "ge-mi-que-ar",
    "gemiqueo": "ge-mi-que-o",
    "gemir": "ge-mir",
    "gemóloga": "ge-mó-lo-ga",
    "gemología": "ge-mo-lo-gí-a",
    "gemológico": "ge-mo-ló-gi-co",
    "gemólogo": "ge-mó-lo-go",
    "gemonías": "ge-mo-ní-as",
    "gemosa": "ge-mo-sa",
    "gemoso": "ge-mo-so",
    "gemoterapia": "ge-mo-te-ra-pia",
    "gémula": "gé-mu-la",
    "gena": "ge-na",
    "genciana": "gen-cia-na",
    "gencianácea": "gen-cia-ná-ce-a",
    "gencianáceo": "gen-cia-ná-ce-o",
    "gencianea": "gen-cia-ne-a",
    "gencianeo": "gen-cia-ne-o",
    "gendarme": "gen-dar-me",
    "gendarmería": "gen-dar-me-rí-a",
    "gene": "ge-ne",
    "genealogía": "ge-ne-a-lo-gí-a",
    "genealógica": "ge-ne-a-ló-gi-ca",
    "genealógico": "ge-ne-a-ló-gi-co",
    "genealogista": "ge-ne-a-lo-gis-ta",
    "genearca": "ge-ne-ar-ca",
    "geneática": "ge-ne-á-ti-ca",
    "geneático": "ge-ne-á-ti-co",
    "generable": "ge-ne-ra-ble",
    "generación": "ge-ne-ra-ción",
    "generacional": "ge-ne-ra-cio-nal",
    "generador": "ge-ne-ra-dor",
    "generadora": "ge-ne-ra-do-ra",
    "general": "ge-ne-ral",
    "generala": "ge-ne-ra-la",
    "generalato": "ge-ne-ra-la-to",
    "generalidad": "ge-ne-ra-li-dad",
    "generalísima": "ge-ne-ra-lí-si-ma",
    "generalísimo": "ge-ne-ra-lí-si-mo",
    "generalista": "ge-ne-ra-lis-ta",
    "generalizable": "ge-ne-ra-li-za-ble",
    "generalización": "ge-ne-ra-li-za-ción",
    "generalizador": "ge-ne-ra-li-za-dor",
    "generalizadora": "ge-ne-ra-li-za-do-ra",
    "generalizar": "ge-ne-ra-li-zar",
    "generalmente": "ge-ne-ral-men-te",
    "generar": "ge-ne-rar",
    "generativa": "ge-ne-ra-ti-va",
    "generativismo": "ge-ne-ra-ti-vis-mo",
    "generativista": "ge-ne-ra-ti-vis-ta",
    "generativo": "ge-ne-ra-ti-vo",
    "generatriz": "ge-ne-ra-triz",
    "genérica": "ge-né-ri-ca",
    "genéricamente": "ge-né-ri-ca-men-te",
    "genérico": "ge-né-ri-co",
    "género": "gé-ne-ro",
    "generosa": "ge-ne-ro-sa",
    "generosamente": "ge-ne-ro-sa-men-te",
    "generosía": "ge-ne-ro-sí-a",
    "generosidad": "ge-ne-ro-si-dad",
    "generoso": "ge-ne-ro-so",
    "genesiaca": "ge-ne-sia-ca",
    "genesíaco": "ge-ne-sí-a-co",
    "genesiaco": "ge-ne-sia-co",
    "genésica": "ge-né-si-ca",
    "genésico": "ge-né-si-co",
    "génesis": "gé-ne-sis",
    "genesta": "ge-nes-ta",
    "genética": "ge-né-ti-ca",
    "genético": "ge-né-ti-co",
    "genetista": "ge-ne-tis-ta",
    "genetlíaca": "ge-ne-tlí-a-ca",
    "genetliaca": "ge-ne-tlia-ca",
    "genetlíaco": "ge-ne-tlí-a-co",
    "genetliaco": "ge-ne-tlia-co",
    "genial": "ge-nial",
    "genialidad": "ge-nia-li-dad",
    "genialmente": "ge-nial-men-te",
    "geniazo": "ge-nia-zo",
    "génico": "gé-ni-co",
    "genilla": "ge-ni-lla",
    "genio": "ge-nio",
    "genioso": "ge-nio-so",
    "genipa": "ge-ni-pa",
    "genista": "ge-nis-ta",
    "genital": "ge-ni-tal",
    "genitiva": "ge-ni-ti-va",
    "genitivo": "ge-ni-ti-vo",
    "genitor": "ge-ni-tor",
    "genitoria": "ge-ni-to-ria",
    "genitorio": "ge-ni-to-rio",
    "genitourinaria": "ge-ni-tou-ri-na-ria",
    "genitourinario": "ge-ni-tou-ri-na-rio",
    "genitura": "ge-ni-tu-ra",
    "geniuda": "ge-niu-da",
    "geniudo": "ge-niu-do",
    "genízara": "ge-ní-za-ra",
    "genízaro": "ge-ní-za-ro",
    "geno": "ge-no",
    "genocida": "ge-no-ci-da",
    "genocidio": "ge-no-ci-dio",
    "genol": "ge-nol",
    "genolí": "ge-no-lí",
    "genoma": "ge-no-ma",
    "genómica": "ge-nó-mi-ca",
    "genómico": "ge-nó-mi-co",
    "genotípica": "ge-no-tí-pi-ca",
    "genotípico": "ge-no-tí-pi-co",
    "genotipo": "ge-no-ti-po",
    "génova": "gé-no-va",
    "genovés": "ge-no-vés",
    "genovesa": "ge-no-ve-sa",
    "genovisca": "ge-no-vis-ca",
    "genovisco": "ge-no-vis-co",
    "gentalla": "gen-ta-lla",
    "gentarada": "gen-ta-ra-da",
    "gente": "gen-te",
    "gentecilla": "gen-te-ci-lla",
    "gentil": "gen-til",
    "gentileza": "gen-ti-le-za",
    "gentilhombre": "gen-til-hom-bre",
    "gentílica": "gen-tí-li-ca",
    "gentilicia": "gen-ti-li-cia",
    "gentilicio": "gen-ti-li-cio",
    "gentílico": "gen-tí-li-co",
    "gentilidad": "gen-ti-li-dad",
    "gentilismo": "gen-ti-lis-mo",
    "gentilizar": "gen-ti-li-zar",
    "gentillal": "gen-ti-llal",
    "gentilmente": "gen-til-men-te",
    "gentío": "gen-tí-o",
    "gentualla": "gen-tua-lla",
    "gentuza": "gen-tu-za",
    "genuflexión": "ge-nu-fle-xión",
    "genuflexo": "ge-nu-fle-xo",
    "genuina": "ge-nui-na",
    "genuino": "ge-nui-no",
    "genulí": "ge-nu-lí",
    "geo": "ge-o",
    "geobiología": "ge-o-bio-lo-gí-a",
    "geobotánica": "ge-o-bo-tá-ni-ca",
    "geobotánico": "ge-o-bo-tá-ni-co",
    "geocéntrica": "ge-o-cén-tri-ca",
    "geocéntrico": "ge-o-cén-tri-co",
    "geocentrismo": "ge-o-cen-tris-mo",
    "geoda": "ge-o-da",
    "geodesia": "ge-o-de-sia",
    "geodésica": "ge-o-dé-si-ca",
    "geodésico": "ge-o-dé-si-co",
    "geodesta": "ge-o-des-ta",
    "geodinámica": "ge-o-di-ná-mi-ca",
    "geoestacionario": "ge-o-es-ta-cio-na-rio",
    "geoestrategia": "ge-o-es-tra-te-gia",
    "geófaga": "ge-ó-fa-ga",
    "geofagia": "ge-o-fa-gia",
    "geófago": "ge-ó-fa-go",
    "geofísica": "ge-o-fí-si-ca",
    "geofísico": "ge-o-fí-si-co",
    "geogenia": "ge-o-ge-nia",
    "geogénica": "ge-o-gé-ni-ca",
    "geogénico": "ge-o-gé-ni-co",
    "geognosia": "ge-og-no-sia",
    "geognosta": "ge-og-nos-ta",
    "geognóstica": "ge-og-nós-ti-ca",
    "geognóstico": "ge-og-nós-ti-co",
    "geogonía": "ge-o-go-ní-a",
    "geogónica": "ge-o-gó-ni-ca",
    "geogónico": "ge-o-gó-ni-co",
    "geógrafa": "ge-ó-gra-fa",
    "geografía": "ge-o-gra-fí-a",
    "geográfica": "ge-o-grá-fi-ca",
    "geográficamente": "ge-o-grá-fi-ca-men-te",
    "geográfico": "ge-o-grá-fi-co",
    "geógrafo": "ge-ó-gra-fo",
    "geoide": "ge-oi-de",
    "geóloga": "ge-ó-lo-ga",
    "geología": "ge-o-lo-gí-a",
    "geológica": "ge-o-ló-gi-ca",
    "geológico": "ge-o-ló-gi-co",
    "geólogo": "ge-ó-lo-go",
    "geomagnético": "ge-o-mag-né-ti-co",
    "geomagnetismo": "ge-o-mag-ne-tis-mo",
    "geomancía": "ge-o-man-cí-a",
    "geomancia": "ge-o-man-cia",
    "geomántica": "ge-o-mán-ti-ca",
    "geomántico": "ge-o-mán-ti-co",
    "geómetra": "ge-ó-me-tra",
    "geometral": "ge-o-me-tral",
    "geometría": "ge-o-me-trí-a",
    "geométrica": "ge-o-mé-tri-ca",
    "geométricamente": "ge-o-mé-tri-ca-men-te",
    "geométrico": "ge-o-mé-tri-co",
    "geomorfía": "ge-o-mor-fí-a",
    "geomorfología": "ge-o-mor-fo-lo-gí-a",
    "geomorfológico": "ge-o-mor-fo-ló-gi-co",
    "geonomía": "ge-o-no-mí-a",
    "geonómica": "ge-o-nó-mi-ca",
    "geonómico": "ge-o-nó-mi-co",
    "geopolítica": "ge-o-po-lí-ti-ca",
    "geopolíticamente": "ge-o-po-lí-ti-ca-men-te",
    "geopolítico": "ge-o-po-lí-ti-co",
    "geópona": "ge-ó-po-na",
    "geoponía": "ge-o-po-ní-a",
    "geopónica": "ge-o-pó-ni-ca",
    "geopónico": "ge-o-pó-ni-co",
    "geópono": "ge-ó-po-no",
    "geoquímica": "ge-o-quí-mi-ca",
    "geoquímico": "ge-o-quí-mi-co",
    "georama": "ge-o-ra-ma",
    "georgiana": "ge-or-gia-na",
    "georgiano": "ge-or-gia-no",
    "geórgica": "ge-ór-gi-ca",
    "geórgico": "ge-ór-gi-co",
    "geosinclinal": "ge-o-sin-cli-nal",
    "geosinónimo": "ge-o-si-nó-ni-mo",
    "geotecnia": "ge-o-tec-nia",
    "geotécnica": "ge-o-téc-ni-ca",
    "geotécnico": "ge-o-téc-ni-co",
    "geotectónica": "ge-o-tec-tó-ni-ca",
    "geotectónico": "ge-o-tec-tó-ni-co",
    "geotermal": "ge-o-ter-mal",
    "geotermia": "ge-o-ter-mia",
    "geotérmico": "ge-o-tér-mi-co",
    "geótica": "ge-ó-ti-ca",
    "geótico": "ge-ó-ti-co",
    "geotropismo": "ge-o-tro-pis-mo",
    "gépida": "gé-pi-da",
    "gépido": "gé-pi-do",
    "geraniácea": "ge-ra-niá-ce-a",
    "geraniáceo": "ge-ra-niá-ce-o",
    "geranio": "ge-ra-nio",
    "gerbera": "ger-be-ra",
    "gerbo": "ger-bo",
    "gerencia": "ge-ren-cia",
    "gerenciar": "ge-ren-ciar",
    "gerenta": "ge-ren-ta",
    "gerente": "ge-ren-te",
    "geriatra": "ge-ria-tra",
    "geriatría": "ge-ria-trí-a",
    "geriátrico": "ge-riá-tri-co",
    "gerifalte": "ge-ri-fal-te",
    "germán": "ger-mán",
    "germana": "ger-ma-na",
    "germanesca": "ger-ma-nes-ca",
    "germanesco": "ger-ma-nes-co",
    "germanía": "ger-ma-ní-a",
    "germánica": "ger-má-ni-ca",
    "germánico": "ger-má-ni-co",
    "germanio": "ger-ma-nio",
    "germanismo": "ger-ma-nis-mo",
    "germanista": "ger-ma-nis-ta",
    "germanización": "ger-ma-ni-za-ción",
    "germanizar": "ger-ma-ni-zar",
    "germano": "ger-ma-no",
    "germanófila": "ger-ma-nó-fi-la",
    "germanofilia": "ger-ma-no-fi-lia",
    "germanófilo": "ger-ma-nó-fi-lo",
    "germanófoba": "ger-ma-nó-fo-ba",
    "germanofobia": "ger-ma-no-fo-bia",
    "germanófobo": "ger-ma-nó-fo-bo",
    "germen": "ger-men",
    "germicida": "ger-mi-ci-da",
    "germinación": "ger-mi-na-ción",
    "germinador": "ger-mi-na-dor",
    "germinadora": "ger-mi-na-do-ra",
    "germinal": "ger-mi-nal",
    "germinar": "ger-mi-nar",
    "germinativa": "ger-mi-na-ti-va",
    "germinativo": "ger-mi-na-ti-vo",
    "germinicida": "ger-mi-ni-ci-da",
    "gerontocracia": "ge-ron-to-cra-cia",
    "gerontócrata": "ge-ron-tó-cra-ta",
    "gerontóloga": "ge-ron-tó-lo-ga",
    "gerontología": "ge-ron-to-lo-gí-a",
    "gerontológico": "ge-ron-to-ló-gi-co",
    "gerontólogo": "ge-ron-tó-lo-go",
    "geropsiquiatría": "ge-rop-si-quia-trí-a",
    "geropsiquiátrico": "ge-rop-si-quiá-tri-co",
    "gerundense": "ge-run-den-se",
    "gerundiada": "ge-run-dia-da",
    "gerundiana": "ge-run-dia-na",
    "gerundiano": "ge-run-dia-no",
    "gerundio": "ge-run-dio",
    "gerundivo": "ge-run-di-vo",
    "gesneriácea": "ges-ne-riá-ce-a",
    "gesneriáceo": "ges-ne-riá-ce-o",
    "gesolreút": "ge-sol-re-út",
    "gesta": "ges-ta",
    "gestación": "ges-ta-ción",
    "gestadura": "ges-ta-du-ra",
    "gestante": "ges-tan-te",
    "gestar": "ges-tar",
    "gestatoria": "ges-ta-to-ria",
    "gestatorio": "ges-ta-to-rio",
    "gestear": "ges-te-ar",
    "gestera": "ges-te-ra",
    "gestero": "ges-te-ro",
    "gesticulación": "ges-ti-cu-la-ción",
    "gesticulador": "ges-ti-cu-la-dor",
    "gesticulante": "ges-ti-cu-lan-te",
    "gesticular": "ges-ti-cu-lar",
    "gesticulosa": "ges-ti-cu-lo-sa",
    "gesticuloso": "ges-ti-cu-lo-so",
    "gestión": "ges-tión",
    "gestionar": "ges-tio-nar",
    "gesto": "ges-to",
    "gestor": "ges-tor",
    "gestora": "ges-to-ra",
    "gestoría": "ges-to-rí-a",
    "gestual": "ges-tual",
    "gestualidad": "ges-tua-li-dad",
    "gestuda": "ges-tu-da",
    "gestudo": "ges-tu-do",
    "geta": "ge-ta",
    "gética": "gé-ti-ca",
    "gético": "gé-ti-co",
    "gétulo": "gé-tu-lo",
    "ghanés": "gha-nés",
    "ghanesa": "gha-ne-sa",
    "giba": "gi-ba",
    "gibada": "gi-ba-da",
    "gibado": "gi-ba-do",
    "gibao": "gi-ba-o",
    "gibar": "gi-bar",
    "gibelina": "gi-be-li-na",
    "gibelino": "gi-be-li-no",
    "gibón": "gi-bón",
    "gibosa": "gi-bo-sa",
    "gibosidad": "gi-bo-si-dad",
    "giboso": "gi-bo-so",
    "gibraltareña": "gi-bral-ta-re-ña",
    "gibraltareño": "gi-bral-ta-re-ño",
    "giennense": "gien-nen-se",
    "giga": "gi-ga",
    "gigabyte": "gi-gaby-te",
    "giganta": "gi-gan-ta",
    "gigante": "gi-gan-te",
    "gigantea": "gi-gan-te-a",
    "giganteo": "gi-gan-te-o",
    "gigantesca": "gi-gan-tes-ca",
    "gigantesco": "gi-gan-tes-co",
    "gigantez": "gi-gan-tez",
    "gigántica": "gi-gán-ti-ca",
    "gigánticamente": "gi-gán-ti-ca-men-te",
    "gigántico": "gi-gán-ti-co",
    "gigantilla": "gi-gan-ti-lla",
    "gigantillo": "gi-gan-ti-llo",
    "gigantismo": "gi-gan-tis-mo",
    "gigantomaquia": "gi-gan-to-ma-quia",
    "gigantón": "gi-gan-tón",
    "gigantona": "gi-gan-to-na",
    "gigavatio": "gi-ga-va-tio",
    "gigoló": "gi-go-ló",
    "gigote": "gi-go-te",
    "gijonense": "gi-jo-nen-se",
    "gijonés": "gi-jo-nés",
    "gijonesa": "gi-jo-ne-sa",
    "gila": "gi-la",
    "gilada": "gi-la-da",
    "gilastrún": "gi-las-trún",
    "gilí": "gi-lí",
    "gilipolla": "gi-li-po-lla",
    "gilipollada": "gi-li-po-lla-da",
    "gilipollas": "gi-li-po-llas",
    "gilipollez": "gi-li-po-llez",
    "gilipuertas": "gi-li-puer-tas",
    "gilito": "gi-li-to",
    "gillete": "gi-lle-te",
    "gilva": "gil-va",
    "gilvo": "gil-vo",
    "gimnasia": "gim-na-sia",
    "gimnasiada": "gim-na-sia-da",
    "gimnasio": "gim-na-sio",
    "gimnasta": "gim-nas-ta",
    "gimnástica": "gim-nás-ti-ca",
    "gimnástico": "gim-nás-ti-co",
    "gímnica": "gím-ni-ca",
    "gímnico": "gím-ni-co",
    "gimnosofista": "gim-no-so-fis-ta",
    "gimnosperma": "gim-nos-per-ma",
    "gimnospermo": "gim-nos-per-mo",
    "gimnoto": "gim-no-to",
    "gimoteador": "gi-mo-te-a-dor",
    "gimoteadora": "gi-mo-te-a-do-ra",
    "gimotear": "gi-mo-te-ar",
    "gimoteo": "gi-mo-te-o",
    "ginandra": "gi-nan-dra",
    "ginas": "gi-nas",
    "gincana": "gin-ca-na",
    "gindama": "gin-da-ma",
    "ginea": "gi-ne-a",
    "ginebra": "gi-ne-bra",
    "ginebrada": "gi-ne-bra-da",
    "ginebrés": "gi-ne-brés",
    "ginebresa": "gi-ne-bre-sa",
    "ginebrina": "gi-ne-bri-na",
    "ginebrino": "gi-ne-bri-no",
    "gineceo": "gi-ne-ce-o",
    "ginecocracia": "gi-ne-co-cra-cia",
    "ginecóloga": "gi-ne-có-lo-ga",
    "ginecología": "gi-ne-co-lo-gí-a",
    "ginecológica": "gi-ne-co-ló-gi-ca",
    "ginecológico": "gi-ne-co-ló-gi-co",
    "ginecólogo": "gi-ne-có-lo-go",
    "ginecomastia": "gi-ne-co-mas-tia",
    "ginefobia": "gi-ne-fo-bia",
    "ginesta": "gi-nes-ta",
    "gineta": "gi-ne-ta",
    "gingidio": "gin-gi-dio",
    "gingival": "gin-gi-val",
    "gingivitis": "gin-gi-vi-tis",
    "gingko": "ging-ko",
    "ginkgo": "gink-go",
    "ginovés": "gi-no-vés",
    "ginovesa": "gi-no-ve-sa",
    "ginseng": "gin-seng",
    "giobertita": "gio-ber-ti-ta",
    "gira": "gi-ra",
    "girada": "gi-ra-da",
    "giradiscos": "gi-ra-dis-cos",
    "girador": "gi-ra-dor",
    "giradora": "gi-ra-do-ra",
    "giralda": "gi-ral-da",
    "giraldete": "gi-ral-de-te",
    "giraldilla": "gi-ral-di-lla",
    "giramiento": "gi-ra-mien-to",
    "girándula": "gi-rán-du-la",
    "girante": "gi-ran-te",
    "girar": "gi-rar",
    "girasol": "gi-ra-sol",
    "giratoria": "gi-ra-to-ria",
    "giratorio": "gi-ra-to-rio",
    "girifalte": "gi-ri-fal-te",
    "girino": "gi-ri-no",
    "giro": "gi-ro",
    "girocho": "gi-ro-cho",
    "giroflé": "gi-ro-flé",
    "girola": "gi-ro-la",
    "girómetro": "gi-ró-me-tro",
    "girondina": "gi-ron-di-na",
    "girondino": "gi-ron-di-no",
    "gironés": "gi-ro-nés",
    "gironesa": "gi-ro-ne-sa",
    "giroscópica": "gi-ros-có-pi-ca",
    "giroscópico": "gi-ros-có-pi-co",
    "giroscopio": "gi-ros-co-pio",
    "giróscopo": "gi-rós-co-po",
    "girostático": "gi-ros-tá-ti-co",
    "girostato": "gi-ros-ta-to",
    "giróstato": "gi-rós-ta-to",
    "giróvaga": "gi-ró-va-ga",
    "giróvago": "gi-ró-va-go",
    "giste": "gis-te",
    "gitana": "gi-ta-na",
    "gitanada": "gi-ta-na-da",
    "gitanamente": "gi-ta-na-men-te",
    "gitanear": "gi-ta-ne-ar",
    "gitanería": "gi-ta-ne-rí-a",
    "gitanesca": "gi-ta-nes-ca",
    "gitanesco": "gi-ta-nes-co",
    "gitanilla": "gi-ta-ni-lla",
    "gitanismo": "gi-ta-nis-mo",
    "gitano": "gi-ta-no",
    "glabra": "gla-bra",
    "glabro": "gla-bro",
    "glaciación": "gla-cia-ción",
    "glacial": "gla-cial",
    "glacialmente": "gla-cial-men-te",
    "glaciar": "gla-ciar",
    "glaciarismo": "gla-cia-ris-mo",
    "glacióloga": "gla-ció-lo-ga",
    "glaciología": "gla-cio-lo-gí-a",
    "glaciológico": "gla-cio-ló-gi-co",
    "glaciólogo": "gla-ció-lo-go",
    "glacis": "gla-cis",
    "gladiador": "gla-dia-dor",
    "gladiadora": "gla-dia-do-ra",
    "gladiator": "gla-dia-tor",
    "gladiatoria": "gla-dia-to-ria",
    "gladiatorio": "gla-dia-to-rio",
    "gladio": "gla-dio",
    "gladíolo": "gla-dí-o-lo",
    "gladiolo": "gla-dio-lo",
    "glagolítico": "gla-go-lí-ti-co",
    "glamoroso": "gla-mo-ro-so",
    "glamour": "gla-mour",
    "glamouroso": "gla-mou-ro-so",
    "glamuroso": "gla-mu-ro-so",
    "glande": "glan-de",
    "glandífera": "glan-dí-fe-ra",
    "glandífero": "glan-dí-fe-ro",
    "glandígera": "glan-dí-ge-ra",
    "glandígero": "glan-dí-ge-ro",
    "glándula": "glán-du-la",
    "glandular": "glan-du-lar",
    "glandulosa": "glan-du-lo-sa",
    "glanduloso": "glan-du-lo-so",
    "glasé": "gla-sé",
    "glaseada": "gla-se-a-da",
    "glaseado": "gla-se-a-do",
    "glasear": "gla-se-ar",
    "glasto": "glas-to",
    "glauca": "glau-ca",
    "glaucio": "glau-cio",
    "glauco": "glau-co",
    "glaucoma": "glau-co-ma",
    "glaucomatoso": "glau-co-ma-to-so",
    "glayo": "gla-yo",
    "gleba": "gle-ba",
    "glera": "gle-ra",
    "glía": "glí-a",
    "glicemia": "gli-ce-mia",
    "glicérido": "gli-cé-ri-do",
    "glicerina": "gli-ce-ri-na",
    "glicerol": "gli-ce-rol",
    "glicina": "gli-ci-na",
    "glicinia": "gli-ci-nia",
    "glicocola": "gli-co-co-la",
    "glicol": "gli-col",
    "glicólisis": "gli-có-li-sis",
    "gliconio": "gli-co-nio",
    "glicoproteína": "gli-co-pro-te-í-na",
    "glicósido": "gli-có-si-do",
    "glide": "gli-de",
    "glifo": "gli-fo",
    "glioma": "glio-ma",
    "glíptica": "glíp-ti-ca",
    "gliptodonte": "glip-to-don-te",
    "gliptoteca": "glip-to-te-ca",
    "glissando": "glis-san-do",
    "global": "glo-bal",
    "globalidad": "glo-ba-li-dad",
    "globalización": "glo-ba-li-za-ción",
    "globalizador": "glo-ba-li-za-dor",
    "globalizante": "glo-ba-li-zan-te",
    "globalizar": "glo-ba-li-zar",
    "globalmente": "glo-bal-men-te",
    "globera": "glo-be-ra",
    "globero": "glo-be-ro",
    "globo": "glo-bo",
    "globosa": "glo-bo-sa",
    "globoso": "glo-bo-so",
    "globular": "glo-bu-lar",
    "globularia": "glo-bu-la-ria",
    "globulariácea": "glo-bu-la-riá-ce-a",
    "globulariáceo": "glo-bu-la-riá-ce-o",
    "globulina": "glo-bu-li-na",
    "glóbulo": "gló-bu-lo",
    "globulosa": "glo-bu-lo-sa",
    "globuloso": "glo-bu-lo-so",
    "glockenspiel": "gloc-kens-piel",
    "glomérulo": "glo-mé-ru-lo",
    "gloria": "glo-ria",
    "gloriado": "glo-ria-do",
    "gloriapatri": "glo-ria-pa-tri",
    "gloriar": "glo-riar",
    "glorieta": "glo-rie-ta",
    "glorificable": "glo-ri-fi-ca-ble",
    "glorificación": "glo-ri-fi-ca-ción",
    "glorificador": "glo-ri-fi-ca-dor",
    "glorificadora": "glo-ri-fi-ca-do-ra",
    "glorificar": "glo-ri-fi-car",
    "gloriosa": "glo-rio-sa",
    "gloriosamente": "glo-rio-sa-men-te",
    "glorioso": "glo-rio-so",
    "glosa": "glo-sa",
    "glosador": "glo-sa-dor",
    "glosadora": "glo-sa-do-ra",
    "glosar": "glo-sar",
    "glosario": "glo-sa-rio",
    "glose": "glo-se",
    "glosemática": "glo-se-má-ti-ca",
    "glosilla": "glo-si-lla",
    "glosolalia": "glo-so-la-lia",
    "glosopeda": "glo-so-pe-da",
    "glotal": "glo-tal",
    "glótica": "gló-ti-ca",
    "glótico": "gló-ti-co",
    "glotis": "glo-tis",
    "glotología": "glo-to-lo-gí-a",
    "glotón": "glo-tón",
    "glotona": "glo-to-na",
    "glotonamente": "glo-to-na-men-te",
    "glotonear": "glo-to-ne-ar",
    "glotonería": "glo-to-ne-rí-a",
    "glotonía": "glo-to-ní-a",
    "gloxínea": "glo-xí-ne-a",
    "glucagón": "glu-ca-gón",
    "glucemia": "glu-ce-mia",
    "glúcido": "glú-ci-do",
    "glucina": "glu-ci-na",
    "glucinio": "glu-ci-nio",
    "glucógeno": "glu-có-ge-no",
    "glucólisis": "glu-có-li-sis",
    "glucómetro": "glu-có-me-tro",
    "glucosa": "glu-co-sa",
    "glucósido": "glu-có-si-do",
    "glucosuria": "glu-co-su-ria",
    "gluglú": "glu-glú",
    "gluma": "glu-ma",
    "glutamato": "glu-ta-ma-to",
    "glutámico": "glu-tá-mi-co",
    "glútea": "glú-te-a",
    "gluten": "glu-ten",
    "glúteo": "glú-te-o",
    "glutinosa": "glu-ti-no-sa",
    "glutinosidad": "glu-ti-no-si-dad",
    "glutinoso": "glu-ti-no-so",
    "gnatóstomo": "gna-tós-to-mo",
    "gnéisica": "gnéi-si-ca",
    "gnéisico": "gnéi-si-co",
    "gnetácea": "gne-tá-ce-a",
    "gnetáceo": "gne-tá-ce-o",
    "gnocchi": "gnoc-chi",
    "gnómica": "gnó-mi-ca",
    "gnómico": "gnó-mi-co",
    "gnomo": "gno-mo",
    "gnomon": "gno-mon",
    "gnomónica": "gno-mó-ni-ca",
    "gnomónico": "gno-mó-ni-co",
    "gnoseología": "gno-se-o-lo-gí-a",
    "gnoseológico": "gno-se-o-ló-gi-co",
    "gnosis": "gno-sis",
    "gnóstica": "gnós-ti-ca",
    "gnosticismo": "gnos-ti-cis-mo",
    "gnóstico": "gnós-ti-co",
    "goa": "go-a",
    "gobelino": "go-be-li-no",
    "gobén": "go-bén",
    "gobernabilidad": "go-ber-na-bi-li-dad",
    "gobernable": "go-ber-na-ble",
    "gobernación": "go-ber-na-ción",
    "gobernador": "go-ber-na-dor",
    "gobernadora": "go-ber-na-do-ra",
    "gobernadorcillo": "go-ber-na-dor-ci-llo",
    "gobernalle": "go-ber-na-lle",
    "gobernamiento": "go-ber-na-mien-to",
    "gobernanta": "go-ber-nan-ta",
    "gobernante": "go-ber-nan-te",
    "gobernanza": "go-ber-nan-za",
    "gobernar": "go-ber-nar",
    "gobernativa": "go-ber-na-ti-va",
    "gobernativo": "go-ber-na-ti-vo",
    "gobernosa": "go-ber-no-sa",
    "gobernoso": "go-ber-no-so",
    "gobierna": "go-bier-na",
    "gobiernero": "go-bier-ne-ro",
    "gobiernista": "go-bier-nis-ta",
    "gobierno": "go-bier-no",
    "gobio": "go-bio",
    "goce": "go-ce",
    "gocete": "go-ce-te",
    "gocha": "go-cha",
    "gochapeza": "go-cha-pe-za",
    "gocho": "go-cho",
    "gociana": "go-cia-na",
    "gociano": "go-cia-no",
    "goda": "go-da",
    "godeña": "go-de-ña",
    "godeño": "go-de-ño",
    "godeo": "go-de-o",
    "godería": "go-de-rí-a",
    "godesca": "go-des-ca",
    "godesco": "go-des-co",
    "godible": "go-di-ble",
    "godismo": "go-dis-mo",
    "godiza": "go-di-za",
    "godizo": "go-di-zo",
    "godo": "go-do",
    "goetheana": "go-e-the-a-na",
    "goetheano": "go-e-the-a-no",
    "goethiano": "go-e-thia-no",
    "gofa": "go-fa",
    "gofio": "go-fio",
    "gofo": "go-fo",
    "gofrado": "go-fra-do",
    "gofrar": "go-frar",
    "gofre": "go-fre",
    "goja": "go-ja",
    "gola": "go-la",
    "golazo": "go-la-zo",
    "goldre": "gol-dre",
    "goleada": "go-le-a-da",
    "goleador": "go-le-a-dor",
    "goleadora": "go-le-a-do-ra",
    "golear": "go-le-ar",
    "golera": "go-le-ra",
    "golero": "go-le-ro",
    "goles": "go-les",
    "goleta": "go-le-ta",
    "golfa": "gol-fa",
    "golfán": "gol-fán",
    "golfante": "gol-fan-te",
    "golfear": "gol-fe-ar",
    "golfería": "gol-fe-rí-a",
    "golfín": "gol-fín",
    "golfista": "gol-fis-ta",
    "golfístico": "gol-fís-ti-co",
    "golfo": "gol-fo",
    "goliarda": "go-liar-da",
    "goliardesca": "go-liar-des-ca",
    "goliardesco": "go-liar-des-co",
    "goliardo": "go-liar-do",
    "golilla": "go-li-lla",
    "golillera": "go-li-lle-ra",
    "golillero": "go-li-lle-ro",
    "golimbra": "go-lim-bra",
    "golimbro": "go-lim-bro",
    "golimbrón": "go-lim-brón",
    "golimbrona": "go-lim-bro-na",
    "gollería": "go-lle-rí-a",
    "golletazo": "go-lle-ta-zo",
    "gollete": "go-lle-te",
    "golletear": "go-lle-te-ar",
    "golletero": "go-lle-te-ro",
    "gollizno": "go-lliz-no",
    "gollizo": "go-lli-zo",
    "golloría": "go-llo-rí-a",
    "golmaja": "gol-ma-ja",
    "golmajear": "gol-ma-je-ar",
    "golmajería": "gol-ma-je-rí-a",
    "golmajo": "gol-ma-jo",
    "golondrina": "go-lon-dri-na",
    "golondrinera": "go-lon-dri-ne-ra",
    "golondrino": "go-lon-dri-no",
    "golondro": "go-lon-dro",
    "golorito": "go-lo-ri-to",
    "golosa": "go-lo-sa",
    "golosamente": "go-lo-sa-men-te",
    "golosear": "go-lo-se-ar",
    "golosina": "go-lo-si-na",
    "golosinar": "go-lo-si-nar",
    "golosinear": "go-lo-si-ne-ar",
    "golosmear": "go-los-me-ar",
    "goloso": "go-lo-so",
    "golpazo": "gol-pa-zo",
    "golpe": "gol-pe",
    "golpeadero": "gol-pe-a-de-ro",
    "golpeador": "gol-pe-a-dor",
    "golpeadora": "gol-pe-a-do-ra",
    "golpeadura": "gol-pe-a-du-ra",
    "golpear": "gol-pe-ar",
    "golpeo": "gol-pe-o",
    "golpetazo": "gol-pe-ta-zo",
    "golpete": "gol-pe-te",
    "golpetear": "gol-pe-te-ar",
    "golpeteo": "gol-pe-te-o",
    "golpismo": "gol-pis-mo",
    "golpista": "gol-pis-ta",
    "golpiza": "gol-pi-za",
    "goluba": "go-lu-ba",
    "goma": "go-ma",
    "gomaespuma": "go-ma-es-pu-ma",
    "gomar": "go-mar",
    "gomecillo": "go-me-ci-llo",
    "gomel": "go-mel",
    "gómena": "gó-me-na",
    "gomenol": "go-me-nol",
    "gomer": "go-mer",
    "gomera": "go-me-ra",
    "gomería": "go-me-rí-a",
    "gomero": "go-me-ro",
    "gomia": "go-mia",
    "gomina": "go-mi-na",
    "gominola": "go-mi-no-la",
    "gomista": "go-mis-ta",
    "gomita": "go-mi-ta",
    "gomorresina": "go-mo-rre-si-na",
    "gomosa": "go-mo-sa",
    "gomosería": "go-mo-se-rí-a",
    "gomosidad": "go-mo-si-dad",
    "gomoso": "go-mo-so",
    "gónada": "gó-na-da",
    "gonadal": "go-na-dal",
    "gonádico": "go-ná-di-co",
    "gonadotropina": "go-na-do-tro-pi-na",
    "gonce": "gon-ce",
    "goncear": "gon-ce-ar",
    "gonchu": "gon-chu",
    "góndola": "gón-do-la",
    "gondolero": "gon-do-le-ro",
    "gonela": "go-ne-la",
    "gonete": "go-ne-te",
    "gonfalón": "gon-fa-lón",
    "gonfalonero": "gon-fa-lo-ne-ro",
    "gonfalonier": "gon-fa-lo-nier",
    "gonfaloniero": "gon-fa-lo-nie-ro",
    "gongo": "gon-go",
    "gongorina": "gon-go-ri-na",
    "gongorino": "gon-go-ri-no",
    "gongorismo": "gon-go-ris-mo",
    "gongorista": "gon-go-ris-ta",
    "gongorizar": "gon-go-ri-zar",
    "goniómetro": "go-nió-me-tro",
    "gonococia": "go-no-co-cia",
    "gonocócica": "go-no-có-ci-ca",
    "gonocócico": "go-no-có-ci-co",
    "gonococo": "go-no-co-co",
    "gonorrea": "go-no-rre-a",
    "gorbión": "gor-bión",
    "gorbiz": "gor-biz",
    "gorciense": "gor-cien-se",
    "gorda": "gor-da",
    "gordal": "gor-dal",
    "gordana": "gor-da-na",
    "gordeza": "gor-de-za",
    "gordiano": "gor-dia-no",
    "gordiflón": "gor-di-flón",
    "gordiflona": "gor-di-flo-na",
    "gordinflas": "gor-din-flas",
    "gordinflón": "gor-din-flón",
    "gordinflona": "gor-din-flo-na",
    "gordita": "gor-di-ta",
    "gordo": "gor-do",
    "gordolobo": "gor-do-lo-bo",
    "gordor": "gor-dor",
    "gordura": "gor-du-ra",
    "gorga": "gor-ga",
    "gorgojar": "gor-go-jar",
    "gorgojarse": "gor-go-jar-se",
    "gorgojo": "gor-go-jo",
    "gorgojosa": "gor-go-jo-sa",
    "gorgojoso": "gor-go-jo-so",
    "gorgomillera": "gor-go-mi-lle-ra",
    "gorgón": "gor-gón",
    "gorgona": "gor-go-na",
    "gorgónea": "gor-gó-ne-a",
    "gorgóneo": "gor-gó-ne-o",
    "gorgonzola": "gor-gon-zo-la",
    "gorgor": "gor-gor",
    "gorgorán": "gor-go-rán",
    "gorgorear": "gor-go-re-ar",
    "gorgorita": "gor-go-ri-ta",
    "gorgoritear": "gor-go-ri-te-ar",
    "gorgorito": "gor-go-ri-to",
    "górgoro": "gór-go-ro",
    "gorgorotada": "gor-go-ro-ta-da",
    "gorgotear": "gor-go-te-ar",
    "gorgoteo": "gor-go-te-o",
    "gorgotero": "gor-go-te-ro",
    "gorgozada": "gor-go-za-da",
    "gorguera": "gor-gue-ra",
    "gorguerán": "gor-gue-rán",
    "gorguz": "gor-guz",
    "gorigori": "go-ri-go-ri",
    "gorila": "go-ri-la",
    "gorja": "gor-ja",
    "gorjal": "gor-jal",
    "gorjeador": "gor-je-a-dor",
    "gorjeadora": "gor-je-a-do-ra",
    "gorjear": "gor-je-ar",
    "gorjeo": "gor-je-o",
    "gorjería": "gor-je-rí-a",
    "gorlita": "gor-li-ta",
    "gormador": "gor-ma-dor",
    "gormadora": "gor-ma-do-ra",
    "gormar": "gor-mar",
    "gorra": "go-rra",
    "gorrada": "go-rra-da",
    "gorreado": "go-rre-a-do",
    "gorrear": "go-rre-ar",
    "gorrera": "go-rre-ra",
    "gorrería": "go-rre-rí-a",
    "gorrero": "go-rre-ro",
    "gorretada": "go-rre-ta-da",
    "gorriato": "go-rria-to",
    "gorrilla": "go-rri-lla",
    "gorrín": "go-rrín",
    "gorrina": "go-rri-na",
    "gorrinada": "go-rri-na-da",
    "gorrinera": "go-rri-ne-ra",
    "gorrinería": "go-rri-ne-rí-a",
    "gorrino": "go-rri-no",
    "gorrión": "go-rrión",
    "gorriona": "go-rrio-na",
    "gorrionera": "go-rrio-ne-ra",
    "gorrista": "go-rris-ta",
    "gorro": "go-rro",
    "gorrón": "go-rrón",
    "gorrona": "go-rro-na",
    "gorronal": "go-rro-nal",
    "gorronear": "go-rro-ne-ar",
    "gorronería": "go-rro-ne-rí-a",
    "gorruenda": "go-rruen-da",
    "gorruendo": "go-rruen-do",
    "gorullo": "go-ru-llo",
    "gosipina": "go-si-pi-na",
    "gosipino": "go-si-pi-no",
    "gospel": "gos-pel",
    "góspel": "gós-pel",
    "gota": "go-ta",
    "goteado": "go-te-a-do",
    "gotear": "go-te-ar",
    "gotelé": "go-te-lé",
    "goteo": "go-te-o",
    "gotera": "go-te-ra",
    "gotereño": "go-te-re-ño",
    "goterense": "go-te-ren-se",
    "gotero": "go-te-ro",
    "goterón": "go-te-rón",
    "gótica": "gó-ti-ca",
    "gótico": "gó-ti-co",
    "gotón": "go-tón",
    "gotona": "go-to-na",
    "gotosa": "go-to-sa",
    "gotoso": "go-to-so",
    "gouda": "gou-da",
    "gourmet": "gour-met",
    "goya": "go-ya",
    "goyesca": "go-yes-ca",
    "goyesco": "go-yes-co",
    "goyo": "go-yo",
    "gozada": "go-za-da",
    "gozadera": "go-za-de-ra",
    "gozamiento": "go-za-mien-to",
    "gozar": "go-zar",
    "gozne": "goz-ne",
    "gozo": "go-zo",
    "gozón": "go-zón",
    "gozosa": "go-zo-sa",
    "gozosamente": "go-zo-sa-men-te",
    "gozoso": "go-zo-so",
    "gozque": "goz-que",
    "grabación": "gra-ba-ción",
    "grabado": "gra-ba-do",
    "grabador": "gra-ba-dor",
    "grabadora": "gra-ba-do-ra",
    "grabadura": "gra-ba-du-ra",
    "grabar": "gra-bar",
    "grabazón": "gra-ba-zón",
    "gracejada": "gra-ce-ja-da",
    "gracejar": "gra-ce-jar",
    "gracejo": "gra-ce-jo",
    "gracia": "gra-cia",
    "graciable": "gra-cia-ble",
    "graciada": "gra-cia-da",
    "graciadioseño": "gra-cia-dio-se-ño",
    "graciadiosense": "gra-cia-dio-sen-se",
    "graciado": "gra-cia-do",
    "graciana": "gra-cia-na",
    "graciano": "gra-cia-no",
    "grácil": "grá-cil",
    "gracilidad": "gra-ci-li-dad",
    "graciola": "gra-cio-la",
    "graciosa": "gra-cio-sa",
    "graciosamente": "gra-cio-sa-men-te",
    "graciosidad": "gra-cio-si-dad",
    "gracioso": "gra-cio-so",
    "grada": "gra-da",
    "gradación": "gra-da-ción",
    "gradada": "gra-da-da",
    "gradado": "gra-da-do",
    "gradar": "gra-dar",
    "gradecer": "gra-de-cer",
    "gradecilla": "gra-de-ci-lla",
    "gradeo": "gra-de-o",
    "gradería": "gra-de-rí-a",
    "graderío": "gra-de-rí-o",
    "gradiente": "gra-dien-te",
    "gradilla": "gra-di-lla",
    "gradíolo": "gra-dí-o-lo",
    "gradiolo": "gra-dio-lo",
    "grado": "gra-do",
    "gradosa": "gra-do-sa",
    "gradoso": "gra-do-so",
    "graduable": "gra-dua-ble",
    "graduación": "gra-dua-ción",
    "graduada": "gra-dua-da",
    "graduado": "gra-dua-do",
    "graduador": "gra-dua-dor",
    "gradual": "gra-dual",
    "gradualidad": "gra-dua-li-dad",
    "gradualismo": "gra-dua-lis-mo",
    "gradualmente": "gra-dual-men-te",
    "graduanda": "gra-duan-da",
    "graduando": "gra-duan-do",
    "graduar": "gra-duar",
    "grafema": "gra-fe-ma",
    "grafémica": "gra-fé-mi-ca",
    "graffiti": "graf-fi-ti",
    "grafía": "gra-fí-a",
    "grafiar": "gra-fiar",
    "gráfica": "grá-fi-ca",
    "gráficamente": "grá-fi-ca-men-te",
    "graficar": "gra-fi-car",
    "gráfico": "grá-fi-co",
    "grafila": "gra-fi-la",
    "gráfila": "grá-fi-la",
    "grafio": "gra-fio",
    "grafioles": "gra-fio-les",
    "grafismo": "gra-fis-mo",
    "grafista": "gra-fis-ta",
    "grafiti": "gra-fi-ti",
    "grafito": "gra-fi-to",
    "grafo": "gra-fo",
    "grafóloga": "gra-fó-lo-ga",
    "grafología": "gra-fo-lo-gí-a",
    "grafológica": "gra-fo-ló-gi-ca",
    "grafológico": "gra-fo-ló-gi-co",
    "grafólogo": "gra-fó-lo-go",
    "grafómana": "gra-fó-ma-na",
    "grafomanía": "gra-fo-ma-ní-a",
    "grafómano": "gra-fó-ma-no",
    "grafómetro": "gra-fó-me-tro",
    "grafoscopio": "gra-fos-co-pio",
    "gragea": "gra-ge-a",
    "graja": "gra-ja",
    "grajear": "gra-je-ar",
    "grajera": "gra-je-ra",
    "grajero": "gra-je-ro",
    "grajiento": "gra-jien-to",
    "grajilla": "gra-ji-lla",
    "grajo": "gra-jo",
    "grajuna": "gra-ju-na",
    "grajuno": "gra-ju-no",
    "grama": "gra-ma",
    "gramaje": "gra-ma-je",
    "gramal": "gra-mal",
    "gramalla": "gra-ma-lla",
    "gramallera": "gra-ma-lle-ra",
    "gramalote": "gra-ma-lo-te",
    "gramar": "gra-mar",
    "gramática": "gra-má-ti-ca",
    "gramatical": "gra-ma-ti-cal",
    "gramaticalidad": "gra-ma-ti-ca-li-dad",
    "gramaticalización": "gra-ma-ti-ca-li-za-ción",
    "gramaticalizar": "gra-ma-ti-ca-li-zar",
    "gramaticalmente": "gra-ma-ti-cal-men-te",
    "gramático": "gra-má-ti-co",
    "gramatiquear": "gra-ma-ti-que-ar",
    "gramatiquería": "gra-ma-ti-que-rí-a",
    "gramatóloga": "gra-ma-tó-lo-ga",
    "gramatología": "gra-ma-to-lo-gí-a",
    "gramatólogo": "gra-ma-tó-lo-go",
    "gramil": "gra-mil",
    "gramilla": "gra-mi-lla",
    "graminácea": "gra-mi-ná-ce-a",
    "gramináceas": "gra-mi-ná-ce-as",
    "gramináceo": "gra-mi-ná-ce-o",
    "gramínea": "gra-mí-ne-a",
    "gramíneas": "gra-mí-ne-as",
    "gramíneo": "gra-mí-ne-o",
    "gramo": "gra-mo",
    "gramofónico": "gra-mo-fó-ni-co",
    "gramófono": "gra-mó-fo-no",
    "gramola": "gra-mo-la",
    "gramosa": "gra-mo-sa",
    "gramoso": "gra-mo-so",
    "grampa": "gram-pa",
    "grana": "gra-na",
    "granada": "gra-na-da",
    "granadal": "gra-na-dal",
    "granadense": "gra-na-den-se",
    "granadera": "gra-na-de-ra",
    "granadero": "gra-na-de-ro",
    "granadí": "gra-na-dí",
    "granadilla": "gra-na-di-lla",
    "granadillo": "gra-na-di-llo",
    "granadina": "gra-na-di-na",
    "granadino": "gra-na-di-no",
    "granado": "gra-na-do",
    "granaína": "gra-na-í-na",
    "granalla": "gra-na-lla",
    "granallar": "gra-na-llar",
    "granar": "gra-nar",
    "granate": "gra-na-te",
    "granatín": "gra-na-tín",
    "granazón": "gra-na-zón",
    "grancanaria": "gran-ca-na-ria",
    "grancanario": "gran-ca-na-rio",
    "grancé": "gran-cé",
    "grancero": "gran-ce-ro",
    "grancilla": "gran-ci-lla",
    "grancolombiana": "gran-co-lom-bia-na",
    "grancolombiano": "gran-co-lom-bia-no",
    "granda": "gran-da",
    "grandánime": "gran-dá-ni-me",
    "grande": "gran-de",
    "grandemente": "gran-de-men-te",
    "grandevo": "gran-de-vo",
    "grandez": "gran-dez",
    "grandeza": "gran-de-za",
    "grandillón": "gran-di-llón",
    "grandillona": "gran-di-llo-na",
    "grandílocua": "gran-dí-lo-cua",
    "grandilocuencia": "gran-di-lo-cuen-cia",
    "grandilocuente": "gran-di-lo-cuen-te",
    "grandílocuo": "gran-dí-lo-cuo",
    "grandiosa": "gran-dio-sa",
    "grandiosamente": "gran-dio-sa-men-te",
    "grandiosidad": "gran-dio-si-dad",
    "grandioso": "gran-dio-so",
    "grandísona": "gran-dí-so-na",
    "grandisonar": "gran-di-so-nar",
    "grandísono": "gran-dí-so-no",
    "grandón": "gran-dón",
    "grandor": "gran-dor",
    "grandullón": "gran-du-llón",
    "grandullona": "gran-du-llo-na",
    "grandulón": "gran-du-lón",
    "grandulona": "gran-du-lo-na",
    "grandura": "gran-du-ra",
    "graneada": "gra-ne-a-da",
    "graneado": "gra-ne-a-do",
    "graneador": "gra-ne-a-dor",
    "granear": "gra-ne-ar",
    "granel": "gra-nel",
    "granelero": "gra-ne-le-ro",
    "granero": "gra-ne-ro",
    "granévano": "gra-né-va-no",
    "granguardia": "gran-guar-dia",
    "graniento": "gra-nien-to",
    "granífugo": "gra-ní-fu-go",
    "granilla": "gra-ni-lla",
    "granillera": "gra-ni-lle-ra",
    "granillero": "gra-ni-lle-ro",
    "granillo": "gra-ni-llo",
    "granillosa": "gra-ni-llo-sa",
    "granilloso": "gra-ni-llo-so",
    "granítica": "gra-ní-ti-ca",
    "granítico": "gra-ní-ti-co",
    "granito": "gra-ni-to",
    "granívora": "gra-ní-vo-ra",
    "granívoro": "gra-ní-vo-ro",
    "granizada": "gra-ni-za-da",
    "granizado": "gra-ni-za-do",
    "granizar": "gra-ni-zar",
    "granizo": "gra-ni-zo",
    "granja": "gran-ja",
    "granjeable": "gran-je-a-ble",
    "granjear": "gran-je-ar",
    "granjeo": "gran-je-o",
    "granjera": "gran-je-ra",
    "granjería": "gran-je-rí-a",
    "granjero": "gran-je-ro",
    "granmense": "gran-men-se",
    "grano": "gra-no",
    "granollerense": "gra-no-lle-ren-se",
    "grañón": "gra-ñón",
    "granosa": "gra-no-sa",
    "granoso": "gra-no-so",
    "grañuela": "gra-ñue-la",
    "granuja": "gra-nu-ja",
    "granujada": "gra-nu-ja-da",
    "granujado": "gra-nu-ja-do",
    "granujería": "gra-nu-je-rí-a",
    "granujienta": "gra-nu-jien-ta",
    "granujiento": "gra-nu-jien-to",
    "granujo": "gra-nu-jo",
    "granujosa": "gra-nu-jo-sa",
    "granujoso": "gra-nu-jo-so",
    "granulación": "gra-nu-la-ción",
    "granulada": "gra-nu-la-da",
    "granulado": "gra-nu-la-do",
    "granular": "gra-nu-lar",
    "granulia": "gra-nu-lia",
    "gránulo": "grá-nu-lo",
    "granulocito": "gra-nu-lo-ci-to",
    "granulocitosis": "gra-nu-lo-ci-to-sis",
    "granulometría": "gra-nu-lo-me-trí-a",
    "granulométrico": "gra-nu-lo-mé-tri-co",
    "granulosa": "gra-nu-lo-sa",
    "granuloso": "gra-nu-lo-so",
    "granza": "gran-za",
    "granzón": "gran-zón",
    "granzosa": "gran-zo-sa",
    "granzoso": "gran-zo-so",
    "grao": "gra-o",
    "grapa": "gra-pa",
    "grapadora": "gra-pa-do-ra",
    "grapar": "gra-par",
    "grapo": "gra-po",
    "grasa": "gra-sa",
    "grasera": "gra-se-ra",
    "grasería": "gra-se-rí-a",
    "grasero": "gra-se-ro",
    "graseza": "gra-se-za",
    "grasienta": "gra-sien-ta",
    "grasiento": "gra-sien-to",
    "grasilla": "gra-si-lla",
    "graso": "gra-so",
    "grasones": "gra-so-nes",
    "grasor": "gra-sor",
    "grasosa": "gra-so-sa",
    "grasoso": "gra-so-so",
    "graspo": "gras-po",
    "grasura": "gra-su-ra",
    "grata": "gra-ta",
    "gratamente": "gra-ta-men-te",
    "gratar": "gra-tar",
    "gratarola": "gra-ta-ro-la",
    "gratificación": "gra-ti-fi-ca-ción",
    "gratificador": "gra-ti-fi-ca-dor",
    "gratificadora": "gra-ti-fi-ca-do-ra",
    "gratificante": "gra-ti-fi-can-te",
    "gratificar": "gra-ti-fi-car",
    "gratil": "gra-til",
    "grátil": "grá-til",
    "gratinado": "gra-ti-na-do",
    "gratinador": "gra-ti-na-dor",
    "gratiñán": "gra-ti-ñán",
    "gratinar": "gra-ti-nar",
    "gratis": "gra-tis",
    "gratisdata": "gra-tis-da-ta",
    "gratisdato": "gra-tis-da-to",
    "gratitud": "gra-ti-tud",
    "grato": "gra-to",
    "gratonada": "gra-to-na-da",
    "gratuidad": "gra-tui-dad",
    "gratuita": "gra-tui-ta",
    "gratuitamente": "gra-tui-ta-men-te",
    "gratuito": "gra-tui-to",
    "gratulación": "gra-tu-la-ción",
    "gratular": "gra-tu-lar",
    "gratulatoria": "gra-tu-la-to-ria",
    "gratulatorio": "gra-tu-la-to-rio",
    "grauera": "graue-ra",
    "grauero": "graue-ro",
    "grava": "gra-va",
    "gravamen": "gra-va-men",
    "gravar": "gra-var",
    "gravativa": "gra-va-ti-va",
    "gravativo": "gra-va-ti-vo",
    "grave": "gra-ve",
    "gravear": "gra-ve-ar",
    "gravedad": "gra-ve-dad",
    "gravedosa": "gra-ve-do-sa",
    "gravedoso": "gra-ve-do-so",
    "gravedumbre": "gra-ve-dum-bre",
    "gravemente": "gra-ve-men-te",
    "gravera": "gra-ve-ra",
    "gravetiense": "gra-ve-tien-se",
    "graveza": "gra-ve-za",
    "grávida": "grá-vi-da",
    "gravidez": "gra-vi-dez",
    "gravídico": "gra-ví-di-co",
    "grávido": "grá-vi-do",
    "gravilla": "gra-vi-lla",
    "gravimetría": "gra-vi-me-trí-a",
    "gravimétrico": "gra-vi-mé-tri-co",
    "gravímetro": "gra-ví-me-tro",
    "gravitación": "gra-vi-ta-ción",
    "gravitacional": "gra-vi-ta-cio-nal",
    "gravitar": "gra-vi-tar",
    "gravitatorio": "gra-vi-ta-to-rio",
    "gravosa": "gra-vo-sa",
    "gravoso": "gra-vo-so",
    "grazalema": "gra-za-le-ma",
    "graznador": "graz-na-dor",
    "graznadora": "graz-na-do-ra",
    "graznar": "graz-nar",
    "graznido": "graz-ni-do",
    "greba": "gre-ba",
    "greca": "gre-ca",
    "greciana": "gre-cia-na",
    "greciano": "gre-cia-no",
    "grecisca": "gre-cis-ca",
    "grecisco": "gre-cis-co",
    "grecismo": "gre-cis-mo",
    "grecizar": "gre-ci-zar",
    "greco": "gre-co",
    "grecolatina": "gre-co-la-ti-na",
    "grecolatino": "gre-co-la-ti-no",
    "grecorromana": "gre-co-rro-ma-na",
    "grecorromano": "gre-co-rro-ma-no",
    "greda": "gre-da",
    "gredal": "gre-dal",
    "gredosa": "gre-do-sa",
    "gredoso": "gre-do-so",
    "grefier": "gre-fier",
    "gregal": "gre-gal",
    "gregaria": "gre-ga-ria",
    "gregario": "gre-ga-rio",
    "gregarismo": "gre-ga-ris-mo",
    "gregoriana": "gre-go-ria-na",
    "gregoriano": "gre-go-ria-no",
    "gregorillo": "gre-go-ri-llo",
    "greguería": "gre-gue-rí-a",
    "greguescos": "gre-gues-cos",
    "gregüescos": "gre-gües-cos",
    "greguisco": "gre-guis-co",
    "greguizar": "gre-gui-zar",
    "grelo": "gre-lo",
    "gremial": "gre-mial",
    "gremialismo": "gre-mia-lis-mo",
    "gremialista": "gre-mia-lis-ta",
    "gremio": "gre-mio",
    "greña": "gre-ña",
    "grencha": "gren-cha",
    "grenchada": "gren-cha-da",
    "grenchar": "gren-char",
    "grencho": "gren-cho",
    "grenchuda": "gren-chu-da",
    "grenchudo": "gren-chu-do",
    "greno": "gre-no",
    "greñuda": "gre-ñu-da",
    "greñudo": "gre-ñu-do",
    "gresca": "gres-ca",
    "gresite": "gre-si-te",
    "greuge": "greu-ge",
    "grevillo": "gre-vi-llo",
    "grida": "gri-da",
    "gridar": "gri-dar",
    "griega": "grie-ga",
    "griego": "grie-go",
    "griesgo": "gries-go",
    "grieta": "grie-ta",
    "grietada": "grie-ta-da",
    "grietado": "grie-ta-do",
    "grietar": "grie-tar",
    "grietarse": "grie-tar-se",
    "grietear": "grie-te-ar",
    "grietearse": "grie-te-ar-se",
    "grietosa": "grie-to-sa",
    "grietoso": "grie-to-so",
    "grifa": "gri-fa",
    "grifalto": "gri-fal-to",
    "grifar": "gri-far",
    "grifarse": "gri-far-se",
    "grifera": "gri-fe-ra",
    "grifería": "gri-fe-rí-a",
    "grifero": "gri-fe-ro",
    "grifo": "gri-fo",
    "grifón": "gri-fón",
    "grigallo": "gri-ga-llo",
    "grija": "gri-ja",
    "grilla": "gri-lla",
    "grillada": "gri-lla-da",
    "grillado": "gri-lla-do",
    "grillar": "gri-llar",
    "grillarse": "gri-llar-se",
    "grillera": "gri-lle-ra",
    "grillero": "gri-lle-ro",
    "grilleta": "gri-lle-ta",
    "grillete": "gri-lle-te",
    "grillo": "gri-llo",
    "grillos": "gri-llos",
    "grillotalpa": "gri-llo-tal-pa",
    "grima": "gri-ma",
    "grimillón": "gri-mi-llón",
    "grimorio": "gri-mo-rio",
    "grimosa": "gri-mo-sa",
    "grimoso": "gri-mo-so",
    "grímpola": "grím-po-la",
    "grinalde": "gri-nal-de",
    "gringa": "grin-ga",
    "gringada": "grin-ga-da",
    "gringo": "grin-go",
    "gringuele": "grin-gue-le",
    "gringuero": "grin-gue-ro",
    "griñolera": "gri-ño-le-ra",
    "griñón": "gri-ñón",
    "gripa": "gri-pa",
    "gripal": "gri-pal",
    "gripar": "gri-par",
    "gripe": "gri-pe",
    "gripo": "gri-po",
    "griposa": "gri-po-sa",
    "griposo": "gri-po-so",
    "grisa": "gri-sa",
    "grisácea": "gri-sá-ce-a",
    "grisáceo": "gri-sá-ce-o",
    "grisalla": "gri-sa-lla",
    "grisapa": "gri-sa-pa",
    "grísea": "grí-se-a",
    "grisear": "gri-se-ar",
    "gríseo": "grí-se-o",
    "griseta": "gri-se-ta",
    "grisgrís": "gris-grís",
    "grisma": "gris-ma",
    "grisón": "gri-són",
    "grisona": "gri-so-na",
    "grisú": "gri-sú",
    "grisura": "gri-su-ra",
    "grita": "gri-ta",
    "gritadera": "gri-ta-de-ra",
    "gritador": "gri-ta-dor",
    "gritadora": "gri-ta-do-ra",
    "gritar": "gri-tar",
    "gritería": "gri-te-rí-a",
    "griterío": "gri-te-rí-o",
    "grito": "gri-to",
    "gritón": "gri-tón",
    "gritona": "gri-to-na",
    "gritonear": "gri-to-ne-ar",
    "groar": "gro-ar",
    "groenlandés": "gro-en-lan-dés",
    "groenlandesa": "gro-en-lan-de-sa",
    "groera": "gro-e-ra",
    "grogui": "gro-gui",
    "grojo": "gro-jo",
    "gromo": "gro-mo",
    "groncha": "gron-cha",
    "groncho": "gron-cho",
    "gropos": "gro-pos",
    "grosa": "gro-sa",
    "grosca": "gros-ca",
    "grosedad": "gro-se-dad",
    "grosella": "gro-se-lla",
    "grosellero": "gro-se-lle-ro",
    "grosera": "gro-se-ra",
    "groseramente": "gro-se-ra-men-te",
    "grosería": "gro-se-rí-a",
    "grosero": "gro-se-ro",
    "grosez": "gro-sez",
    "groseza": "gro-se-za",
    "grosezuela": "gro-se-zue-la",
    "grosezuelo": "gro-se-zue-lo",
    "grosicie": "gro-si-cie",
    "grosidad": "gro-si-dad",
    "grosísima": "gro-sí-si-ma",
    "grosísimo": "gro-sí-si-mo",
    "groso": "gro-so",
    "grosor": "gro-sor",
    "grosso": "gros-so",
    "grosularia": "gro-su-la-ria",
    "grosulariea": "gro-su-la-rie-a",
    "grosularieo": "gro-su-la-rie-o",
    "grosura": "gro-su-ra",
    "grotesca": "gro-tes-ca",
    "grotescamente": "gro-tes-ca-men-te",
    "grotesco": "gro-tes-co",
    "grúa": "grú-a",
    "gruador": "grua-dor",
    "gruera": "grue-ra",
    "gruero": "grue-ro",
    "gruesa": "grue-sa",
    "gruesamente": "grue-sa-men-te",
    "grueso": "grue-so",
    "gruiforme": "grui-for-me",
    "gruista": "gruis-ta",
    "gruja": "gru-ja",
    "grujidor": "gru-ji-dor",
    "grujir": "gru-jir",
    "grulla": "gru-lla",
    "grullada": "gru-lla-da",
    "grullera": "gru-lle-ra",
    "grullero": "gru-lle-ro",
    "grullo": "gru-llo",
    "grumete": "gru-me-te",
    "grumo": "gru-mo",
    "grumosa": "gru-mo-sa",
    "grumoso": "gru-mo-so",
    "gruñente": "gru-ñen-te",
    "grunge": "grun-ge",
    "gruñido": "gru-ñi-do",
    "gruñidor": "gru-ñi-dor",
    "gruñidora": "gru-ñi-do-ra",
    "gruñimiento": "gru-ñi-mien-to",
    "gruñir": "gru-ñir",
    "gruñón": "gru-ñón",
    "gruñona": "gru-ño-na",
    "grupa": "gru-pa",
    "grupada": "gru-pa-da",
    "grupal": "gru-pal",
    "grupera": "gru-pe-ra",
    "grupeto": "gru-pe-to",
    "grupí": "gru-pí",
    "grupiento": "gru-pien-to",
    "grupo": "gru-po",
    "grupuscular": "gru-pus-cu-lar",
    "grupúsculo": "gru-pús-cu-lo",
    "gruta": "gru-ta",
    "grutesca": "gru-tes-ca",
    "grutesco": "gru-tes-co",
    "gruyer": "gru-yer",
    "guaba": "gua-ba",
    "guabá": "gua-bá",
    "guabairo": "gua-bai-ro",
    "guabán": "gua-bán",
    "guabico": "gua-bi-co",
    "guabina": "gua-bi-na",
    "guabinear": "gua-bi-ne-ar",
    "guabirá": "gua-bi-rá",
    "guabiyú": "gua-bi-yú",
    "guabo": "gua-bo",
    "guabul": "gua-bul",
    "guaca": "gua-ca",
    "guacal": "gua-cal",
    "guácala": "guá-ca-la",
    "guacalada": "gua-ca-la-da",
    "guacalazo": "gua-ca-la-zo",
    "guacalote": "gua-ca-lo-te",
    "guacamaya": "gua-ca-ma-ya",
    "guacamayo": "gua-ca-ma-yo",
    "guacamol": "gua-ca-mol",
    "guacamole": "gua-ca-mo-le",
    "guacamote": "gua-ca-mo-te",
    "guácara": "guá-ca-ra",
    "guacarear": "gua-ca-re-ar",
    "guacha": "gua-cha",
    "guachaca": "gua-cha-ca",
    "guachada": "gua-cha-da",
    "guachafita": "gua-cha-fi-ta",
    "guachafitero": "gua-cha-fi-te-ro",
    "guachaje": "gua-cha-je",
    "guachalomo": "gua-cha-lo-mo",
    "guachapazo": "gua-cha-pa-zo",
    "guachapear": "gua-cha-pe-ar",
    "guachapelí": "gua-cha-pe-lí",
    "guachar": "gua-char",
    "guáchara": "guá-cha-ra",
    "guacharaca": "gua-cha-ra-ca",
    "guacharaco": "gua-cha-ra-co",
    "guácharo": "guá-cha-ro",
    "guacharrada": "gua-cha-rra-da",
    "guacharrazo": "gua-cha-rra-zo",
    "guacharro": "gua-cha-rro",
    "guache": "gua-che",
    "guachi": "gua-chi",
    "guachicón": "gua-chi-cón",
    "guachimán": "gua-chi-mán",
    "guachinanga": "gua-chi-nan-ga",
    "guachinango": "gua-chi-nan-go",
    "guachinear": "gua-chi-ne-ar",
    "guachipelín": "gua-chi-pe-lín",
    "guachipilín": "gua-chi-pi-lín",
    "guacho": "gua-cho",
    "guacia": "gua-cia",
    "guácima": "guá-ci-ma",
    "guácimo": "guá-ci-mo",
    "guaco": "gua-co",
    "guadafiones": "gua-da-fio-nes",
    "guadal": "gua-dal",
    "guadalajareña": "gua-da-la-ja-re-ña",
    "guadalajareño": "gua-da-la-ja-re-ño",
    "guadalajarense": "gua-da-la-ja-ren-se",
    "guadalupana": "gua-da-lu-pa-na",
    "guadalupano": "gua-da-lu-pa-no",
    "guadalupeña": "gua-da-lu-pe-ña",
    "guadalupeño": "gua-da-lu-pe-ño",
    "guadalupense": "gua-da-lu-pen-se",
    "guadamací": "gua-da-ma-cí",
    "guadamacil": "gua-da-ma-cil",
    "guadamacilería": "gua-da-ma-ci-le-rí-a",
    "guadamacilero": "gua-da-ma-ci-le-ro",
    "guadamecí": "gua-da-me-cí",
    "guadamecil": "gua-da-me-cil",
    "guadaña": "gua-da-ña",
    "guadañador": "gua-da-ña-dor",
    "guadañadora": "gua-da-ña-do-ra",
    "guadañar": "gua-da-ñar",
    "guadañero": "gua-da-ñe-ro",
    "guadañeta": "gua-da-ñe-ta",
    "guadañil": "gua-da-ñil",
    "guadaño": "gua-da-ño",
    "guadapero": "gua-da-pe-ro",
    "guadarnés": "gua-dar-nés",
    "guadarrameña": "gua-da-rra-me-ña",
    "guadarrameño": "gua-da-rra-me-ño",
    "guadianés": "gua-dia-nés",
    "guadianesa": "gua-dia-ne-sa",
    "guadianesco": "gua-dia-nes-co",
    "guadijeña": "gua-di-je-ña",
    "guadijeño": "gua-di-je-ño",
    "guado": "gua-do",
    "guadra": "gua-dra",
    "guadramaña": "gua-dra-ma-ña",
    "guadrapear": "gua-dra-pe-ar",
    "guadúa": "gua-dú-a",
    "guadua": "gua-dua",
    "guadual": "gua-dual",
    "guáduba": "guá-du-ba",
    "guafe": "gua-fe",
    "guágara": "guá-ga-ra",
    "guagatear": "gua-ga-te-ar",
    "guagra": "gua-gra",
    "guagua": "gua-gua",
    "guagualón": "gua-gua-lón",
    "guagualona": "gua-gua-lo-na",
    "guaguancó": "gua-guan-có",
    "guaguasí": "gua-gua-sí",
    "guagüita": "gua-güi-ta",
    "guaica": "guai-ca",
    "guaicán": "guai-cán",
    "guaicurú": "guai-cu-rú",
    "guailón": "guai-lón",
    "guailona": "guai-lo-na",
    "guaimí": "guai-mí",
    "guaina": "guai-na",
    "guaiño": "guai-ño",
    "guaipe": "guai-pe",
    "guaiquerí": "guai-que-rí",
    "guaira": "guai-ra",
    "guairabo": "guai-ra-bo",
    "guaireña": "guai-re-ña",
    "guaireño": "guai-re-ño",
    "guairo": "guai-ro",
    "guairuro": "guai-ru-ro",
    "guaita": "guai-ta",
    "guaitar": "guai-tar",
    "guaja": "gua-ja",
    "guajaca": "gua-ja-ca",
    "guajacón": "gua-ja-cón",
    "guájar": "guá-jar",
    "guájara": "guá-ja-ra",
    "guaje": "gua-je",
    "guájete": "guá-je-te",
    "guajiba": "gua-ji-ba",
    "guajibo": "gua-ji-bo",
    "guajira": "gua-ji-ra",
    "guajiro": "gua-ji-ro",
    "guajolote": "gua-jo-lo-te",
    "guala": "gua-la",
    "gualá": "gua-lá",
    "gualaicha": "gua-lai-cha",
    "gualaicho": "gua-lai-cho",
    "gualanday": "gua-lan-day",
    "gualardón": "gua-lar-dón",
    "gualardonar": "gua-lar-do-nar",
    "gualatina": "gua-la-ti-na",
    "gualda": "gual-da",
    "gualdada": "gual-da-da",
    "gualdado": "gual-da-do",
    "gualdera": "gual-de-ra",
    "gualdo": "gual-do",
    "gualdrapa": "gual-dra-pa",
    "gualdrapazo": "gual-dra-pa-zo",
    "gualdrapear": "gual-dra-pe-ar",
    "gualdrapeo": "gual-dra-pe-o",
    "gualdrapero": "gual-dra-pe-ro",
    "gualeta": "gua-le-ta",
    "gualicho": "gua-li-cho",
    "gualiqueme": "gua-li-que-me",
    "gualputa": "gual-pu-ta",
    "gualtata": "gual-ta-ta",
    "gualve": "gual-ve",
    "guama": "gua-ma",
    "guamá": "gua-má",
    "guamazo": "gua-ma-zo",
    "guambia": "guam-bia",
    "guambra": "guam-bra",
    "guame": "gua-me",
    "guamil": "gua-mil",
    "guamo": "gua-mo",
    "guampa": "guam-pa",
    "guampo": "guam-po",
    "guámpora": "guám-po-ra",
    "guampuda": "guam-pu-da",
    "guampudo": "guam-pu-do",
    "guamúchil": "gua-mú-chil",
    "guanabá": "gua-na-bá",
    "guanábana": "gua-ná-ba-na",
    "guanabanada": "gua-na-ba-na-da",
    "guanábano": "gua-ná-ba-no",
    "guanabima": "gua-na-bi-ma",
    "guanacada": "gua-na-ca-da",
    "guanacaste": "gua-na-cas-te",
    "guanacasteca": "gua-na-cas-te-ca",
    "guanacasteco": "gua-na-cas-te-co",
    "guanaco": "gua-na-co",
    "guanaja": "gua-na-ja",
    "guanajada": "gua-na-ja-da",
    "guanajeña": "gua-na-je-ña",
    "guanajeño": "gua-na-je-ño",
    "guanajo": "gua-na-jo",
    "guanajuatense": "gua-na-jua-ten-se",
    "guanana": "gua-na-na",
    "guanaquear": "gua-na-que-ar",
    "guanaquismo": "gua-na-quis-mo",
    "guanareña": "gua-na-re-ña",
    "guanareño": "gua-na-re-ño",
    "guancasco": "guan-cas-co",
    "guanchaca": "guan-cha-ca",
    "guanche": "guan-che",
    "guando": "guan-do",
    "guandoca": "guan-do-ca",
    "guandú": "guan-dú",
    "guanepe": "gua-ne-pe",
    "guanera": "gua-ne-ra",
    "guanero": "gua-ne-ro",
    "guango": "guan-go",
    "guangocha": "guan-go-cha",
    "guangoche": "guan-go-che",
    "guangocho": "guan-go-cho",
    "guangolola": "guan-go-lo-la",
    "guañil": "gua-ñil",
    "guanín": "gua-nín",
    "guanina": "gua-ni-na",
    "guaniquí": "gua-ni-quí",
    "guaniquique": "gua-ni-qui-que",
    "guano": "gua-no",
    "guanota": "gua-no-ta",
    "guanquí": "guan-quí",
    "guanta": "guan-ta",
    "guantada": "guan-ta-da",
    "guantanamera": "guan-ta-na-me-ra",
    "guantanamero": "guan-ta-na-me-ro",
    "guantazo": "guan-ta-zo",
    "guante": "guan-te",
    "guantear": "guan-te-ar",
    "guantelete": "guan-te-le-te",
    "guantera": "guan-te-ra",
    "guantería": "guan-te-rí-a",
    "guantero": "guan-te-ro",
    "guantón": "guan-tón",
    "guao": "gua-o",
    "guapa": "gua-pa",
    "guapamente": "gua-pa-men-te",
    "guape": "gua-pe",
    "guapear": "gua-pe-ar",
    "guaperas": "gua-pe-ras",
    "guapería": "gua-pe-rí-a",
    "guaperío": "gua-pe-rí-o",
    "guapérrimo": "gua-pé-rri-mo",
    "guapetón": "gua-pe-tón",
    "guapetona": "gua-pe-to-na",
    "guapetonería": "gua-pe-to-ne-rí-a",
    "guapeza": "gua-pe-za",
    "guapinol": "gua-pi-nol",
    "guapo": "gua-po",
    "guapomó": "gua-po-mó",
    "guapota": "gua-po-ta",
    "guapote": "gua-po-te",
    "guapura": "gua-pu-ra",
    "guapurú": "gua-pu-rú",
    "guaquear": "gua-que-ar",
    "guaqueña": "gua-que-ña",
    "guaqueño": "gua-que-ño",
    "guaquera": "gua-que-ra",
    "guaquero": "gua-que-ro",
    "guara": "gua-ra",
    "guarabeado": "gua-ra-be-a-do",
    "guaraca": "gua-ra-ca",
    "guaracaro": "gua-ra-ca-ro",
    "guaracha": "gua-ra-cha",
    "guarache": "gua-ra-che",
    "guarachera": "gua-ra-che-ra",
    "guarachero": "gua-ra-che-ro",
    "guarachoso": "gua-ra-cho-so",
    "guarachuda": "gua-ra-chu-da",
    "guarachudo": "gua-ra-chu-do",
    "guaragua": "gua-ra-gua",
    "guaraguao": "gua-ra-gua-o",
    "guaral": "gua-ral",
    "guáramo": "guá-ra-mo",
    "guarán": "gua-rán",
    "guaraná": "gua-ra-ná",
    "guaraña": "gua-ra-ña",
    "guarandeña": "gua-ran-de-ña",
    "guarandeño": "gua-ran-de-ño",
    "guaranga": "gua-ran-ga",
    "guarangada": "gua-ran-ga-da",
    "guarango": "gua-ran-go",
    "guaranguear": "gua-ran-gue-ar",
    "guaranguería": "gua-ran-gue-rí-a",
    "guaraní": "gua-ra-ní",
    "guaranismo": "gua-ra-nis-mo",
    "guaranítico": "gua-ra-ní-ti-co",
    "guarao": "gua-ra-o",
    "guarapazo": "gua-ra-pa-zo",
    "guarapera": "gua-ra-pe-ra",
    "guarapeta": "gua-ra-pe-ta",
    "guarapo": "gua-ra-po",
    "guarapón": "gua-ra-pón",
    "guararey": "gua-ra-rey",
    "guarauna": "gua-rau-na",
    "guaraúno": "gua-ra-ú-no",
    "guarayo": "gua-ra-yo",
    "guarda": "guar-da",
    "guardabanderas": "guar-da-ban-de-ras",
    "guardabarrancos": "guar-da-ba-rran-cos",
    "guardabarrera": "guar-da-ba-rre-ra",
    "guardabarros": "guar-da-ba-rros",
    "guardable": "guar-da-ble",
    "guardabosque": "guar-da-bos-que",
    "guardabosques": "guar-da-bos-ques",
    "guardabrazo": "guar-da-bra-zo",
    "guardabrisa": "guar-da-bri-sa",
    "guardabrisas": "guar-da-bri-sas",
    "guardacabo": "guar-da-ca-bo",
    "guardacabras": "guar-da-ca-bras",
    "guardacalada": "guar-da-ca-la-da",
    "guardacaminos": "guar-da-ca-mi-nos",
    "guardacamisa": "guar-da-ca-mi-sa",
    "guardacantón": "guar-da-can-tón",
    "guardacartuchos": "guar-da-car-tu-chos",
    "guardacoches": "guar-da-co-ches",
    "guardacostas": "guar-da-cos-tas",
    "guardacuños": "guar-da-cu-ños",
    "guardada": "guar-da-da",
    "guardadamas": "guar-da-da-mas",
    "guardado": "guar-da-do",
    "guardador": "guar-da-dor",
    "guardadora": "guar-da-do-ra",
    "guardaespaldas": "guar-da-es-pal-das",
    "guardafango": "guar-da-fan-go",
    "guardafangos": "guar-da-fan-gos",
    "guardafrenos": "guar-da-fre-nos",
    "guardafuego": "guar-da-fue-go",
    "guardaguas": "guar-da-guas",
    "guardagujas": "guar-da-gu-jas",
    "guardahúmo": "guar-da-hú-mo",
    "guardainfante": "guar-dain-fan-te",
    "guardajoyas": "guar-da-jo-yas",
    "guardalado": "guar-da-la-do",
    "guardalmacén": "guar-dal-ma-cén",
    "guardalobo": "guar-da-lo-bo",
    "guardamalleta": "guar-da-ma-lle-ta",
    "guardamangel": "guar-da-man-gel",
    "guardamangier": "guar-da-man-gier",
    "guardamano": "guar-da-ma-no",
    "guardamateriales": "guar-da-ma-te-ria-les",
    "guardameta": "guar-da-me-ta",
    "guardamiento": "guar-da-mien-to",
    "guardamigo": "guar-da-mi-go",
    "guardamonte": "guar-da-mon-te",
    "guardamuebles": "guar-da-mue-bles",
    "guardamujer": "guar-da-mu-jer",
    "guardapapo": "guar-da-pa-po",
    "guardapelo": "guar-da-pe-lo",
    "guardapesca": "guar-da-pes-ca",
    "guardapiés": "guar-da-piés",
    "guardapolvo": "guar-da-pol-vo",
    "guardapolvos": "guar-da-pol-vos",
    "guardapuerta": "guar-da-puer-ta",
    "guardapuntas": "guar-da-pun-tas",
    "guardar": "guar-dar",
    "guardarraíl": "guar-da-rra-íl",
    "guardarraya": "guar-da-rra-ya",
    "guardarrío": "guar-da-rrí-o",
    "guardarropa": "guar-da-rro-pa",
    "guardarropía": "guar-da-rro-pí-a",
    "guardarruedas": "guar-da-rrue-das",
    "guardasellos": "guar-da-se-llos",
    "guardasilla": "guar-da-si-lla",
    "guardasol": "guar-da-sol",
    "guardatimón": "guar-da-ti-món",
    "guardatojo": "guar-da-to-jo",
    "guardavalla": "guar-da-va-lla",
    "guardavecino": "guar-da-ve-ci-no",
    "guardavela": "guar-da-ve-la",
    "guardavía": "guar-da-ví-a",
    "guardavientos": "guar-da-vien-tos",
    "guardería": "guar-de-rí-a",
    "guardés": "guar-dés",
    "guardesa": "guar-de-sa",
    "guardia": "guar-dia",
    "guardiamarina": "guar-dia-ma-ri-na",
    "guardián": "guar-dián",
    "guardiana": "guar-dia-na",
    "guardianía": "guar-dia-ní-a",
    "guardilla": "guar-di-lla",
    "guardillón": "guar-di-llón",
    "guardín": "guar-dín",
    "guardón": "guar-dón",
    "guardona": "guar-do-na",
    "guardosa": "guar-do-sa",
    "guardoso": "guar-do-so",
    "guareao": "gua-re-a-o",
    "guarear": "gua-re-ar",
    "guarecer": "gua-re-cer",
    "guarecimiento": "gua-re-ci-mien-to",
    "guarén": "gua-rén",
    "guareña": "gua-re-ña",
    "guarenticia": "gua-ren-ti-cia",
    "guarenticio": "gua-ren-ti-cio",
    "guares": "gua-res",
    "guargüero": "guar-güe-ro",
    "guaria": "gua-ria",
    "guariao": "gua-ria-o",
    "guaricandilla": "gua-ri-can-di-lla",
    "guaricha": "gua-ri-cha",
    "guarida": "gua-ri-da",
    "guaridera": "gua-ri-de-ra",
    "guaridero": "gua-ri-de-ro",
    "guarimán": "gua-ri-mán",
    "guarimiento": "gua-ri-mien-to",
    "guarín": "gua-rín",
    "guaripola": "gua-ri-po-la",
    "guariqueña": "gua-ri-que-ña",
    "guariqueño": "gua-ri-que-ño",
    "guarir": "gua-rir",
    "guarisapo": "gua-ri-sa-po",
    "guarisma": "gua-ris-ma",
    "guarismo": "gua-ris-mo",
    "guarisnaque": "gua-ris-na-que",
    "guaritoto": "gua-ri-to-to",
    "guarne": "guar-ne",
    "guarnecedor": "guar-ne-ce-dor",
    "guarnecedora": "guar-ne-ce-do-ra",
    "guarnecer": "guar-ne-cer",
    "guarnecido": "guar-ne-ci-do",
    "guarnición": "guar-ni-ción",
    "guarnicionar": "guar-ni-cio-nar",
    "guarnicionera": "guar-ni-cio-ne-ra",
    "guarnicionería": "guar-ni-cio-ne-rí-a",
    "guarnicionero": "guar-ni-cio-ne-ro",
    "guarniel": "guar-niel",
    "guarnimiento": "guar-ni-mien-to",
    "guarnir": "guar-nir",
    "guaro": "gua-ro",
    "guaroso": "gua-ro-so",
    "guarra": "gua-rra",
    "guarrada": "gua-rra-da",
    "guarrazo": "gua-rra-zo",
    "guarrear": "gua-rre-ar",
    "guarrería": "gua-rre-rí-a",
    "guarrero": "gua-rre-ro",
    "guarrido": "gua-rri-do",
    "guarrilla": "gua-rri-lla",
    "guarrindongo": "gua-rrin-don-go",
    "guarro": "gua-rro",
    "guarte": "guar-te",
    "guarumo": "gua-ru-mo",
    "guarura": "gua-ru-ra",
    "guaruso": "gua-ru-so",
    "guasa": "gua-sa",
    "guasábara": "gua-sá-ba-ra",
    "guasabear": "gua-sa-be-ar",
    "guasada": "gua-sa-da",
    "guasamaca": "gua-sa-ma-ca",
    "guasamaco": "gua-sa-ma-co",
    "guasanga": "gua-san-ga",
    "guasasa": "gua-sa-sa",
    "guasaya": "gua-sa-ya",
    "guasca": "guas-ca",
    "guascazo": "guas-ca-zo",
    "guasear": "gua-se-ar",
    "guasearse": "gua-se-ar-se",
    "guasería": "gua-se-rí-a",
    "guashpira": "guash-pi-ra",
    "guásima": "guá-si-ma",
    "guásimo": "guá-si-mo",
    "guaso": "gua-so",
    "guasón": "gua-són",
    "guasona": "gua-so-na",
    "guasontle": "gua-son-tle",
    "guaspirolazo": "guas-pi-ro-la-zo",
    "guastar": "guas-tar",
    "guastatoyana": "guas-ta-to-ya-na",
    "guastatoyano": "guas-ta-to-ya-no",
    "guasto": "guas-to",
    "guata": "gua-ta",
    "guataca": "gua-ta-ca",
    "guatacare": "gua-ta-ca-re",
    "guatacón": "gua-ta-cón",
    "guatacona": "gua-ta-co-na",
    "guatanera": "gua-ta-ne-ra",
    "guatanero": "gua-ta-ne-ro",
    "guataquear": "gua-ta-que-ar",
    "guataquería": "gua-ta-que-rí-a",
    "guatazo": "gua-ta-zo",
    "guate": "gua-te",
    "guateado": "gua-te-a-do",
    "guatear": "gua-te-ar",
    "guatemalense": "gua-te-ma-len-se",
    "guatemalteca": "gua-te-mal-te-ca",
    "guatemalteco": "gua-te-mal-te-co",
    "guatemaltequismo": "gua-te-mal-te-quis-mo",
    "guateque": "gua-te-que",
    "guatero": "gua-te-ro",
    "guatíbere": "gua-tí-be-re",
    "guatíbero": "gua-tí-be-ro",
    "guatita": "gua-ti-ta",
    "guato": "gua-to",
    "guatón": "gua-tón",
    "guatona": "gua-to-na",
    "guatusa": "gua-tu-sa",
    "guatusero": "gua-tu-se-ro",
    "guatuso": "gua-tu-so",
    "guaucho": "guau-cho",
    "guaya": "gua-ya",
    "guayaba": "gua-ya-ba",
    "guayabal": "gua-ya-bal",
    "guayabana": "gua-ya-ba-na",
    "guayabar": "gua-ya-bar",
    "guayabate": "gua-ya-ba-te",
    "guayabazo": "gua-ya-ba-zo",
    "guayabear": "gua-ya-be-ar",
    "guayabera": "gua-ya-be-ra",
    "guayabero": "gua-ya-be-ro",
    "guayabito": "gua-ya-bi-to",
    "guayabo": "gua-ya-bo",
    "guayabón": "gua-ya-bón",
    "guayabuda": "gua-ya-bu-da",
    "guayabudo": "gua-ya-bu-do",
    "guayaca": "gua-ya-ca",
    "guayacán": "gua-ya-cán",
    "guayaco": "gua-ya-co",
    "guayacol": "gua-ya-col",
    "guayacón": "gua-ya-cón",
    "guayada": "gua-ya-da",
    "guayadero": "gua-ya-de-ro",
    "guayado": "gua-ya-do",
    "guayamés": "gua-ya-més",
    "guayamesa": "gua-ya-me-sa",
    "guayanés": "gua-ya-nés",
    "guayanesa": "gua-ya-ne-sa",
    "guayaquil": "gua-ya-quil",
    "guayaquileña": "gua-ya-qui-le-ña",
    "guayaquileño": "gua-ya-qui-le-ño",
    "guayar": "gua-yar",
    "guayas": "gua-yas",
    "guayasense": "gua-ya-sen-se",
    "guayín": "gua-yín",
    "guaymeña": "guay-me-ña",
    "guaymeño": "guay-me-ño",
    "guaymense": "guay-men-se",
    "guayo": "gua-yo",
    "guayola": "gua-yo-la",
    "guayos": "gua-yos",
    "guayuco": "gua-yu-co",
    "guayusa": "gua-yu-sa",
    "guazábara": "gua-zá-ba-ra",
    "guazalo": "gua-za-lo",
    "guazapa": "gua-za-pa",
    "guazubirá": "gua-zu-bi-rá",
    "gubernación": "gu-ber-na-ción",
    "gubernamental": "gu-ber-na-men-tal",
    "gubernamentalista": "gu-ber-na-men-ta-lis-ta",
    "gubernar": "gu-ber-nar",
    "gubernativa": "gu-ber-na-ti-va",
    "gubernativamente": "gu-ber-na-ti-va-men-te",
    "gubernativo": "gu-ber-na-ti-vo",
    "gubia": "gu-bia",
    "gubileta": "gu-bi-le-ta",
    "gubilete": "gu-bi-le-te",
    "gudari": "gu-da-ri",
    "güecho": "güe-cho",
    "güechos": "güe-chos",
    "guedeja": "gue-de-ja",
    "guedejada": "gue-de-ja-da",
    "guedejado": "gue-de-ja-do",
    "guedejón": "gue-de-jón",
    "guedejona": "gue-de-jo-na",
    "guedejosa": "gue-de-jo-sa",
    "guedejoso": "gue-de-jo-so",
    "guedejuda": "gue-de-ju-da",
    "guedejudo": "gue-de-ju-do",
    "güegüecho": "güe-güe-cho",
    "güegüenche": "güe-güen-che",
    "guelaguetza": "gue-la-guet-za",
    "gueldo": "guel-do",
    "güeldrés": "güel-drés",
    "güeldresa": "güel-dre-sa",
    "güelfa": "güel-fa",
    "güelfo": "güel-fo",
    "guelte": "guel-te",
    "gueltre": "guel-tre",
    "güemba": "güem-ba",
    "güemul": "güe-mul",
    "güeña": "güe-ña",
    "guepardo": "gue-par-do",
    "güera": "güe-ra",
    "guercha": "guer-cha",
    "guercho": "guer-cho",
    "güergüero": "güer-güe-ro",
    "güérmeces": "güér-me-ces",
    "guernesey": "guer-ne-sey",
    "güero": "güe-ro",
    "guerra": "gue-rra",
    "guerreador": "gue-rre-a-dor",
    "guerreadora": "gue-rre-a-do-ra",
    "guerrear": "gue-rre-ar",
    "guerrera": "gue-rre-ra",
    "guerreramente": "gue-rre-ra-men-te",
    "guerrerense": "gue-rre-ren-se",
    "guerrería": "gue-rre-rí-a",
    "guerrero": "gue-rre-ro",
    "guerrilla": "gue-rri-lla",
    "guerrillear": "gue-rri-lle-ar",
    "guerrillera": "gue-rri-lle-ra",
    "guerrillerismo": "gue-rri-lle-ris-mo",
    "guerrillero": "gue-rri-lle-ro",
    "guerrillo": "gue-rri-llo",
    "gueto": "gue-to",
    "güevón": "güe-vón",
    "güevona": "güe-vo-na",
    "guía": "guí-a",
    "guiabara": "guia-ba-ra",
    "guiada": "guia-da",
    "guiadera": "guia-de-ra",
    "guiado": "guia-do",
    "guiador": "guia-dor",
    "guiadora": "guia-do-ra",
    "guiaje": "guia-je",
    "guiamiento": "guia-mien-to",
    "guido": "gui-do",
    "guienés": "guie-nés",
    "guienesa": "guie-ne-sa",
    "guifa": "gui-fa",
    "güifa": "güi-fa",
    "guija": "gui-ja",
    "güija": "güi-ja",
    "guijarral": "gui-ja-rral",
    "guijarrazo": "gui-ja-rra-zo",
    "guijarreña": "gui-ja-rre-ña",
    "guijarreño": "gui-ja-rre-ño",
    "guijarro": "gui-ja-rro",
    "guijarrosa": "gui-ja-rro-sa",
    "guijarroso": "gui-ja-rro-so",
    "güije": "güi-je",
    "guijeña": "gui-je-ña",
    "guijeño": "gui-je-ño",
    "guijo": "gui-jo",
    "guijón": "gui-jón",
    "guijosa": "gui-jo-sa",
    "guijoso": "gui-jo-so",
    "güila": "güi-la",
    "guilalo": "gui-la-lo",
    "guileña": "gui-le-ña",
    "guilindajes": "gui-lin-da-jes",
    "guilindajo": "gui-lin-da-jo",
    "guilindujes": "gui-lin-du-jes",
    "guilla": "gui-lla",
    "guillada": "gui-lla-da",
    "guillado": "gui-lla-do",
    "guilladura": "gui-lla-du-ra",
    "guillame": "gui-lla-me",
    "guillar": "gui-llar",
    "guillarse": "gui-llar-se",
    "guillatún": "gui-lla-tún",
    "güillín": "güi-llín",
    "guillomo": "gui-llo-mo",
    "guillote": "gui-llo-te",
    "guillotina": "gui-llo-ti-na",
    "guillotinar": "gui-llo-ti-nar",
    "güilo": "güi-lo",
    "güilota": "güi-lo-ta",
    "güimba": "güim-ba",
    "guimbalete": "guim-ba-le-te",
    "guimbarda": "guim-bar-da",
    "guiñada": "gui-ña-da",
    "guiñador": "gui-ña-dor",
    "guiñadura": "gui-ña-du-ra",
    "guinaldés": "gui-nal-dés",
    "guinaldesa": "gui-nal-de-sa",
    "guiñapienta": "gui-ña-pien-ta",
    "guiñapiento": "gui-ña-pien-to",
    "guiñapo": "gui-ña-po",
    "guiñaposa": "gui-ña-po-sa",
    "guiñaposo": "gui-ña-po-so",
    "guiñar": "gui-ñar",
    "guinchar": "guin-char",
    "guinche": "guin-che",
    "guincho": "guin-cho",
    "guinchón": "guin-chón",
    "guinda": "guin-da",
    "guindada": "guin-da-da",
    "guindado": "guin-da-do",
    "guindajo": "guin-da-jo",
    "guindal": "guin-dal",
    "guindalera": "guin-da-le-ra",
    "guindaleta": "guin-da-le-ta",
    "guindaleza": "guin-da-le-za",
    "guindamaina": "guin-da-mai-na",
    "guindar": "guin-dar",
    "guindaste": "guin-das-te",
    "guindear": "guin-de-ar",
    "guindilla": "guin-di-lla",
    "guindillo": "guin-di-llo",
    "guindo": "guin-do",
    "guindola": "guin-do-la",
    "guinea": "gui-ne-a",
    "guineana": "gui-ne-a-na",
    "guineano": "gui-ne-a-no",
    "guineo": "gui-ne-o",
    "guinga": "guin-ga",
    "guinilla": "gui-ni-lla",
    "guinja": "guin-ja",
    "guinjo": "guin-jo",
    "guínjol": "guín-jol",
    "guinjolero": "guin-jo-le-ro",
    "guiño": "gui-ño",
    "güino": "güi-no",
    "guiñol": "gui-ñol",
    "guiñolesco": "gui-ño-les-co",
    "guiñote": "gui-ño-te",
    "guionaje": "guio-na-je",
    "guionista": "guio-nis-ta",
    "guipar": "gui-par",
    "güipazo": "güi-pa-zo",
    "güipil": "güi-pil",
    "güipipía": "güi-pi-pí-a",
    "guipur": "gui-pur",
    "guipure": "gui-pu-re",
    "guipuzcoana": "gui-puz-co-a-na",
    "guipuzcoano": "gui-puz-co-a-no",
    "güira": "güi-ra",
    "güire": "güi-re",
    "guiri": "gui-ri",
    "guirigay": "gui-ri-gay",
    "güirila": "güi-ri-la",
    "guirindajo": "gui-rin-da-jo",
    "guirindola": "gui-rin-do-la",
    "güirís": "güi-rís",
    "guirisapa": "gui-ri-sa-pa",
    "güirisera": "güi-ri-se-ra",
    "güirisero": "güi-ri-se-ro",
    "guirlache": "guir-la-che",
    "guirlanda": "guir-lan-da",
    "guirnalda": "guir-nal-da",
    "güiro": "güi-ro",
    "guiropa": "gui-ro-pa",
    "guirre": "gui-rre",
    "güirro": "güi-rro",
    "guisa": "gui-sa",
    "guisada": "gui-sa-da",
    "guisadamente": "gui-sa-da-men-te",
    "guisado": "gui-sa-do",
    "guisador": "gui-sa-dor",
    "guisadora": "gui-sa-do-ra",
    "guisamiento": "gui-sa-mien-to",
    "guisandera": "gui-san-de-ra",
    "guisandero": "gui-san-de-ro",
    "guisantal": "gui-san-tal",
    "guisante": "gui-san-te",
    "guisar": "gui-sar",
    "güisaro": "güi-sa-ro",
    "guisaso": "gui-sa-so",
    "guiso": "gui-so",
    "guisopillo": "gui-so-pi-llo",
    "guisopo": "gui-so-po",
    "guisote": "gui-so-te",
    "güisquería": "güis-que-rí-a",
    "güisqui": "güis-qui",
    "güisquil": "güis-quil",
    "güisquilar": "güis-qui-lar",
    "guita": "gui-ta",
    "guitar": "gui-tar",
    "guitarra": "gui-ta-rra",
    "guitarrazo": "gui-ta-rra-zo",
    "guitarreo": "gui-ta-rre-o",
    "guitarrera": "gui-ta-rre-ra",
    "guitarrería": "gui-ta-rre-rí-a",
    "guitarrero": "gui-ta-rre-ro",
    "guitarresca": "gui-ta-rres-ca",
    "guitarresco": "gui-ta-rres-co",
    "guitarrillo": "gui-ta-rri-llo",
    "guitarrista": "gui-ta-rris-ta",
    "guitarro": "gui-ta-rro",
    "guitarrón": "gui-ta-rrón",
    "guitera": "gui-te-ra",
    "guitero": "gui-te-ro",
    "guito": "gui-to",
    "güito": "güi-to",
    "guitón": "gui-tón",
    "guitona": "gui-to-na",
    "guitonear": "gui-to-ne-ar",
    "guitonería": "gui-to-ne-rí-a",
    "guitudo": "gui-tu-do",
    "guiye": "gui-ye",
    "guizacillo": "gui-za-ci-llo",
    "guizazo": "gui-za-zo",
    "guizgar": "guiz-gar",
    "guiznar": "guiz-nar",
    "guizque": "guiz-que",
    "guja": "gu-ja",
    "gula": "gu-la",
    "gulag": "gu-lag",
    "gular": "gu-lar",
    "gulay": "gu-lay",
    "gules": "gu-les",
    "gullán": "gu-llán",
    "gullería": "gu-lle-rí-a",
    "gulloría": "gu-llo-rí-a",
    "gulosa": "gu-lo-sa",
    "gulosidad": "gu-lo-si-dad",
    "guloso": "gu-lo-so",
    "gulusmear": "gu-lus-me-ar",
    "gulusmera": "gu-lus-me-ra",
    "gulusmero": "gu-lus-me-ro",
    "gumamela": "gu-ma-me-la",
    "gúmena": "gú-me-na",
    "gumía": "gu-mí-a",
    "gunnerácea": "gun-ne-rá-ce-a",
    "gunneráceo": "gun-ne-rá-ce-o",
    "gupi": "gu-pi",
    "gura": "gu-ra",
    "gurapas": "gu-ra-pas",
    "gurbia": "gur-bia",
    "gurbio": "gur-bio",
    "gurbión": "gur-bión",
    "gurbionada": "gur-bio-na-da",
    "gurbionado": "gur-bio-na-do",
    "gurda": "gur-da",
    "gurdo": "gur-do",
    "gurí": "gu-rí",
    "guripa": "gu-ri-pa",
    "gurisa": "gu-ri-sa",
    "guro": "gu-ro",
    "gurriata": "gu-rria-ta",
    "gurriato": "gu-rria-to",
    "gurrión": "gu-rrión",
    "gurripato": "gu-rri-pa-to",
    "gurrufero": "gu-rru-fe-ro",
    "gurrumina": "gu-rru-mi-na",
    "gurrumino": "gu-rru-mi-no",
    "gurruñar": "gu-rru-ñar",
    "gurruño": "gu-rru-ño",
    "gurú": "gu-rú",
    "gurullada": "gu-ru-lla-da",
    "gurullo": "gu-ru-llo",
    "gurumelo": "gu-ru-me-lo",
    "gurupa": "gu-ru-pa",
    "gurupera": "gu-ru-pe-ra",
    "gusa": "gu-sa",
    "gusana": "gu-sa-na",
    "gusanear": "gu-sa-ne-ar",
    "gusanera": "gu-sa-ne-ra",
    "gusanería": "gu-sa-ne-rí-a",
    "gusanienta": "gu-sa-nien-ta",
    "gusaniento": "gu-sa-nien-to",
    "gusanillo": "gu-sa-ni-llo",
    "gusano": "gu-sa-no",
    "gusanosa": "gu-sa-no-sa",
    "gusanoso": "gu-sa-no-so",
    "gusarapa": "gu-sa-ra-pa",
    "gusarapienta": "gu-sa-ra-pien-ta",
    "gusarapiento": "gu-sa-ra-pien-to",
    "gusarapo": "gu-sa-ra-po",
    "gustable": "gus-ta-ble",
    "gustación": "gus-ta-ción",
    "gustador": "gus-ta-dor",
    "gustadura": "gus-ta-du-ra",
    "gustar": "gus-tar",
    "gustativa": "gus-ta-ti-va",
    "gustativo": "gus-ta-ti-vo",
    "gustazo": "gus-ta-zo",
    "gustillo": "gus-ti-llo",
    "gusto": "gus-to",
    "gustosa": "gus-to-sa",
    "gustosamente": "gus-to-sa-men-te",
    "gustoso": "gus-to-so",
    "gutagamba": "gu-ta-gam-ba",
    "gutapercha": "gu-ta-per-cha",
    "gutiámbar": "gu-tiám-bar",
    "gutífera": "gu-tí-fe-ra",
    "gutífero": "gu-tí-fe-ro",
    "gutural": "gu-tu-ral",
    "guturalmente": "gu-tu-ral-men-te",
    "guyanés": "gu-ya-nés",
    "guyanesa": "gu-ya-ne-sa",
    "guyot": "gu-yot",
    "guzgo": "guz-go",
    "guzla": "guz-la",
    "guzmán": "guz-mán",
    "guzpátaro": "guz-pá-ta-ro",
    "guzpatarra": "guz-pa-ta-rra",
    "gymkhana": "gym-kha-na",
    "haba": "ha-ba",
    "habada": "ha-ba-da",
    "habado": "ha-ba-do",
    "habana": "ha-ba-na",
    "habanera": "ha-ba-ne-ra",
    "habanero": "ha-ba-ne-ro",
    "habano": "ha-ba-no",
    "habar": "ha-bar",
    "habedera": "ha-be-de-ra",
    "habedero": "ha-be-de-ro",
    "haber": "ha-ber",
    "háber": "há-ber",
    "haberada": "ha-be-ra-da",
    "haberado": "ha-be-ra-do",
    "haberío": "ha-be-rí-o",
    "haberosa": "ha-be-ro-sa",
    "haberoso": "ha-be-ro-so",
    "habichuela": "ha-bi-chue-la",
    "habidera": "ha-bi-de-ra",
    "habidero": "ha-bi-de-ro",
    "habiente": "ha-bien-te",
    "hábil": "há-bil",
    "habilidad": "ha-bi-li-dad",
    "habilidosa": "ha-bi-li-do-sa",
    "habilidoso": "ha-bi-li-do-so",
    "habilindroso": "ha-bi-lin-dro-so",
    "habilitación": "ha-bi-li-ta-ción",
    "habilitada": "ha-bi-li-ta-da",
    "habilitado": "ha-bi-li-ta-do",
    "habilitador": "ha-bi-li-ta-dor",
    "habilitadora": "ha-bi-li-ta-do-ra",
    "habilitar": "ha-bi-li-tar",
    "habillada": "ha-bi-lla-da",
    "habillado": "ha-bi-lla-do",
    "habillamiento": "ha-bi-lla-mien-to",
    "habillo": "ha-bi-llo",
    "hábilmente": "há-bil-men-te",
    "habilosa": "ha-bi-lo-sa",
    "habiloso": "ha-bi-lo-so",
    "habitabilidad": "ha-bi-ta-bi-li-dad",
    "habitable": "ha-bi-ta-ble",
    "habitación": "ha-bi-ta-ción",
    "habitacional": "ha-bi-ta-cio-nal",
    "habitáculo": "ha-bi-tá-cu-lo",
    "habitador": "ha-bi-ta-dor",
    "habitadora": "ha-bi-ta-do-ra",
    "habitanta": "ha-bi-tan-ta",
    "habitante": "ha-bi-tan-te",
    "habitanza": "ha-bi-tan-za",
    "habitar": "ha-bi-tar",
    "hábitat": "há-bi-tat",
    "hábito": "há-bi-to",
    "habituación": "ha-bi-tua-ción",
    "habitual": "ha-bi-tual",
    "habitualidad": "ha-bi-tua-li-dad",
    "habitualmente": "ha-bi-tual-men-te",
    "habituar": "ha-bi-tuar",
    "habitud": "ha-bi-tud",
    "habiz": "ha-biz",
    "habla": "ha-bla",
    "hablachenta": "ha-bla-chen-ta",
    "hablachento": "ha-bla-chen-to",
    "hablada": "ha-bla-da",
    "habladera": "ha-bla-de-ra",
    "hablado": "ha-bla-do",
    "hablador": "ha-bla-dor",
    "habladora": "ha-bla-do-ra",
    "habladuría": "ha-bla-du-rí-a",
    "hablanchín": "ha-blan-chín",
    "hablanchina": "ha-blan-chi-na",
    "hablante": "ha-blan-te",
    "hablantín": "ha-blan-tín",
    "hablantina": "ha-blan-ti-na",
    "hablantinosa": "ha-blan-ti-no-sa",
    "hablantinoso": "ha-blan-ti-no-so",
    "hablapaja": "ha-bla-pa-ja",
    "hablar": "ha-blar",
    "hablilla": "ha-bli-lla",
    "hablista": "ha-blis-ta",
    "hablistán": "ha-blis-tán",
    "habón": "ha-bón",
    "habús": "ha-bús",
    "haca": "ha-ca",
    "hacán": "ha-cán",
    "hacanea": "ha-ca-ne-a",
    "hacecillo": "ha-ce-ci-llo",
    "hacedera": "ha-ce-de-ra",
    "hacedero": "ha-ce-de-ro",
    "hacedor": "ha-ce-dor",
    "hacedora": "ha-ce-do-ra",
    "hacejera": "ha-ce-je-ra",
    "hacejero": "ha-ce-je-ro",
    "hacendada": "ha-cen-da-da",
    "hacendado": "ha-cen-da-do",
    "hacendar": "ha-cen-dar",
    "hacendera": "ha-cen-de-ra",
    "hacendería": "ha-cen-de-rí-a",
    "hacendero": "ha-cen-de-ro",
    "hacendista": "ha-cen-dis-ta",
    "hacendística": "ha-cen-dís-ti-ca",
    "hacendístico": "ha-cen-dís-ti-co",
    "hacendosa": "ha-cen-do-sa",
    "hacendoso": "ha-cen-do-so",
    "hacer": "ha-cer",
    "hacera": "ha-ce-ra",
    "hacha": "ha-cha",
    "hachar": "ha-char",
    "hachazo": "ha-cha-zo",
    "hache": "ha-che",
    "hachear": "ha-che-ar",
    "hachemí": "ha-che-mí",
    "hachemita": "ha-che-mi-ta",
    "hachero": "ha-che-ro",
    "hachís": "ha-chís",
    "hacho": "ha-cho",
    "hachón": "ha-chón",
    "hachote": "ha-cho-te",
    "hachuela": "ha-chue-la",
    "hacia": "ha-cia",
    "hacienda": "ha-cien-da",
    "haciente": "ha-cien-te",
    "hacimiento": "ha-ci-mien-to",
    "hacina": "ha-ci-na",
    "hacinación": "ha-ci-na-ción",
    "hacinador": "ha-ci-na-dor",
    "hacinadora": "ha-ci-na-do-ra",
    "hacinamiento": "ha-ci-na-mien-to",
    "hacinar": "ha-ci-nar",
    "hacino": "ha-ci-no",
    "hacker": "hac-ker",
    "hada": "ha-da",
    "hadada": "ha-da-da",
    "hadado": "ha-da-do",
    "hadador": "ha-da-dor",
    "hadadora": "ha-da-do-ra",
    "hadar": "ha-dar",
    "hadaria": "ha-da-ria",
    "hadario": "ha-da-rio",
    "hado": "ha-do",
    "hadrón": "ha-drón",
    "hadruba": "ha-dru-ba",
    "hadrubado": "ha-dru-ba-do",
    "hafiz": "ha-fiz",
    "hafnio": "haf-nio",
    "hagiógrafa": "ha-gió-gra-fa",
    "hagiografía": "ha-gio-gra-fí-a",
    "hagiográfica": "ha-gio-grá-fi-ca",
    "hagiográfico": "ha-gio-grá-fi-co",
    "hagiógrafo": "ha-gió-gra-fo",
    "hagiónimo": "ha-gió-ni-mo",
    "haiga": "hai-ga",
    "haikai": "hai-kai",
    "haiku": "hai-ku",
    "haikú": "hai-kú",
    "haitiana": "hai-tia-na",
    "haitiano": "hai-tia-no",
    "hala": "ha-la",
    "halacabuyas": "ha-la-ca-bu-yas",
    "halacuerda": "ha-la-cuer-da",
    "halagador": "ha-la-ga-dor",
    "halagadora": "ha-la-ga-do-ra",
    "halagar": "ha-la-gar",
    "halago": "ha-la-go",
    "halagüeña": "ha-la-güe-ña",
    "halagüeñamente": "ha-la-güe-ña-men-te",
    "halagüeño": "ha-la-güe-ño",
    "halaguera": "ha-la-gue-ra",
    "halaguero": "ha-la-gue-ro",
    "halaleva": "ha-la-le-va",
    "halar": "ha-lar",
    "hálara": "há-la-ra",
    "halcón": "hal-cón",
    "halconada": "hal-co-na-da",
    "halconado": "hal-co-na-do",
    "halconear": "hal-co-ne-ar",
    "halconera": "hal-co-ne-ra",
    "halconería": "hal-co-ne-rí-a",
    "halconero": "hal-co-ne-ro",
    "halda": "hal-da",
    "haldada": "hal-da-da",
    "haldear": "hal-de-ar",
    "haldera": "hal-de-ra",
    "haldero": "hal-de-ro",
    "haldeta": "hal-de-ta",
    "haldinegra": "hal-di-ne-gra",
    "haldinegro": "hal-di-ne-gro",
    "halduda": "hal-du-da",
    "haldudo": "hal-du-do",
    "hale": "ha-le",
    "haleche": "ha-le-che",
    "halibut": "ha-li-but",
    "halieto": "ha-lie-to",
    "halifa": "ha-li-fa",
    "halita": "ha-li-ta",
    "hálito": "há-li-to",
    "halitosis": "ha-li-to-sis",
    "hallaca": "ha-lla-ca",
    "hallada": "ha-lla-da",
    "hallado": "ha-lla-do",
    "hallador": "ha-lla-dor",
    "halladora": "ha-lla-do-ra",
    "hallaquita": "ha-lla-qui-ta",
    "hallar": "ha-llar",
    "hallazgo": "ha-llaz-go",
    "hallulla": "ha-llu-lla",
    "hallullera": "ha-llu-lle-ra",
    "hallullero": "ha-llu-lle-ro",
    "hallullo": "ha-llu-llo",
    "halo": "ha-lo",
    "halobacteria": "ha-lo-bac-te-ria",
    "halófila": "ha-ló-fi-la",
    "halófilo": "ha-ló-fi-lo",
    "halófita": "ha-ló-fi-ta",
    "halófito": "ha-ló-fi-to",
    "halógena": "ha-ló-ge-na",
    "halogenado": "ha-lo-ge-na-do",
    "halógeno": "ha-ló-ge-no",
    "halogenuro": "ha-lo-ge-nu-ro",
    "haloidea": "ha-loi-de-a",
    "haloideo": "ha-loi-de-o",
    "halón": "ha-lón",
    "haloque": "ha-lo-que",
    "halotecnia": "ha-lo-tec-nia",
    "haloza": "ha-lo-za",
    "haltera": "hal-te-ra",
    "halterófila": "hal-te-ró-fi-la",
    "halterofilia": "hal-te-ro-fi-lia",
    "halterófilo": "hal-te-ró-fi-lo",
    "haluro": "ha-lu-ro",
    "hamaca": "ha-ma-ca",
    "hamacar": "ha-ma-car",
    "hamada": "ha-ma-da",
    "hamadría": "ha-ma-drí-a",
    "hamadriada": "ha-ma-dria-da",
    "hamadríade": "ha-ma-drí-a-de",
    "hámago": "há-ma-go",
    "hamamelidácea": "ha-ma-me-li-dá-ce-a",
    "hamamelidáceo": "ha-ma-me-li-dá-ce-o",
    "hamaquear": "ha-ma-que-ar",
    "hamaquera": "ha-ma-que-ra",
    "hamaquero": "ha-ma-que-ro",
    "hamartoma": "ha-mar-to-ma",
    "hambrazón": "ham-bra-zón",
    "hambre": "ham-bre",
    "hambreada": "ham-bre-a-da",
    "hambrear": "ham-bre-ar",
    "hambría": "ham-brí-a",
    "hambrienta": "ham-brien-ta",
    "hambriento": "ham-brien-to",
    "hambrina": "ham-bri-na",
    "hambrío": "ham-brí-o",
    "hambrón": "ham-brón",
    "hambrona": "ham-bro-na",
    "hambruna": "ham-bru-na",
    "hambrusia": "ham-bru-sia",
    "hamburgués": "ham-bur-gués",
    "hamburguesa": "ham-bur-gue-sa",
    "hamburguesería": "ham-bur-gue-se-rí-a",
    "hamez": "ha-mez",
    "hamo": "ha-mo",
    "hampa": "ham-pa",
    "hampesca": "ham-pes-ca",
    "hampesco": "ham-pes-co",
    "hampo": "ham-po",
    "hampoducto": "ham-po-duc-to",
    "hampón": "ham-pón",
    "hampona": "ham-po-na",
    "hamponil": "ham-po-nil",
    "hámster": "háms-ter",
    "hamudí": "ha-mu-dí",
    "hándicap": "hán-di-cap",
    "hanega": "ha-ne-ga",
    "hanegada": "ha-ne-ga-da",
    "hangar": "han-gar",
    "hannoveriana": "han-no-ve-ria-na",
    "hannoveriano": "han-no-ve-ria-no",
    "hansa": "han-sa",
    "hanseática": "han-se-á-ti-ca",
    "hanseático": "han-se-á-ti-co",
    "hanzo": "han-zo",
    "hao": "ha-o",
    "hapálido": "ha-pá-li-do",
    "hápax": "há-pax",
    "haploclamídeo": "ha-plo-cla-mí-de-o",
    "haplofase": "ha-plo-fa-se",
    "haplografía": "ha-plo-gra-fí-a",
    "haploide": "ha-ploi-de",
    "haploidía": "ha-ploi-dí-a",
    "haplología": "ha-plo-lo-gí-a",
    "happening": "hap-pe-ning",
    "haptonomía": "hap-to-no-mí-a",
    "haquitía": "ha-qui-tí-a",
    "haragán": "ha-ra-gán",
    "haragana": "ha-ra-ga-na",
    "haraganamente": "ha-ra-ga-na-men-te",
    "haraganear": "ha-ra-ga-ne-ar",
    "haraganería": "ha-ra-ga-ne-rí-a",
    "haraganía": "ha-ra-ga-ní-a",
    "haraganosa": "ha-ra-ga-no-sa",
    "haraganoso": "ha-ra-ga-no-so",
    "harakiri": "ha-ra-ki-ri",
    "harambel": "ha-ram-bel",
    "harapienta": "ha-ra-pien-ta",
    "harapiento": "ha-ra-pien-to",
    "harapo": "ha-ra-po",
    "haraposa": "ha-ra-po-sa",
    "haraposo": "ha-ra-po-so",
    "haraquiri": "ha-ra-qui-ri",
    "haras": "ha-ras",
    "haraute": "ha-rau-te",
    "haravico": "ha-ra-vi-co",
    "harbar": "har-bar",
    "harbullar": "har-bu-llar",
    "harbullista": "har-bu-llis-ta",
    "harca": "har-ca",
    "harda": "har-da",
    "hardcore": "hard-co-re",
    "hardido": "har-di-do",
    "harem": "ha-rem",
    "harén": "ha-rén",
    "harense": "ha-ren-se",
    "harija": "ha-ri-ja",
    "harina": "ha-ri-na",
    "harinado": "ha-ri-na-do",
    "harinear": "ha-ri-ne-ar",
    "harinera": "ha-ri-ne-ra",
    "harinero": "ha-ri-ne-ro",
    "harinosa": "ha-ri-no-sa",
    "harinoso": "ha-ri-no-so",
    "harinudo": "ha-ri-nu-do",
    "harma": "har-ma",
    "harmonía": "har-mo-ní-a",
    "harmónica": "har-mó-ni-ca",
    "harmónicamente": "har-mó-ni-ca-men-te",
    "harmónico": "har-mó-ni-co",
    "harmonio": "har-mo-nio",
    "harmoniosa": "har-mo-nio-sa",
    "harmoniosamente": "har-mo-nio-sa-men-te",
    "harmonioso": "har-mo-nio-so",
    "harmonizable": "har-mo-ni-za-ble",
    "harmonización": "har-mo-ni-za-ción",
    "harmonizar": "har-mo-ni-zar",
    "harnal": "har-nal",
    "harneadura": "har-ne-a-du-ra",
    "harnear": "har-ne-ar",
    "harnerero": "har-ne-re-ro",
    "harnero": "har-ne-ro",
    "harneruelo": "har-ne-rue-lo",
    "harón": "ha-rón",
    "harona": "ha-ro-na",
    "haronear": "ha-ro-ne-ar",
    "haronía": "ha-ro-ní-a",
    "harpa": "har-pa",
    "harpada": "har-pa-da",
    "harpado": "har-pa-do",
    "harpía": "har-pí-a",
    "harpillera": "har-pi-lle-ra",
    "harqueño": "har-que-ño",
    "harrado": "ha-rra-do",
    "harrapo": "ha-rra-po",
    "harre": "ha-rre",
    "harrear": "ha-rre-ar",
    "harria": "ha-rria",
    "harriería": "ha-rrie-rí-a",
    "harriero": "ha-rrie-ro",
    "harropea": "ha-rro-pe-a",
    "harta": "har-ta",
    "hartada": "har-ta-da",
    "hartadera": "har-ta-de-ra",
    "hartamente": "har-ta-men-te",
    "hartar": "har-tar",
    "hartazga": "har-taz-ga",
    "hartazgo": "har-taz-go",
    "hartazón": "har-ta-zón",
    "hartera": "har-te-ra",
    "harto": "har-to",
    "hartón": "har-tón",
    "hartona": "har-to-na",
    "hartura": "har-tu-ra",
    "hasaní": "ha-sa-ní",
    "hassio": "has-sio",
    "hasta": "has-ta",
    "hastial": "has-tial",
    "hastiar": "has-tiar",
    "hastío": "has-tí-o",
    "hastiosa": "has-tio-sa",
    "hastiosamente": "has-tio-sa-men-te",
    "hastioso": "has-tio-so",
    "hataca": "ha-ta-ca",
    "hatada": "ha-ta-da",
    "hatajo": "ha-ta-jo",
    "hatear": "ha-te-ar",
    "hatera": "ha-te-ra",
    "hatería": "ha-te-rí-a",
    "hatero": "ha-te-ro",
    "hatijo": "ha-ti-jo",
    "hatillo": "ha-ti-llo",
    "hato": "ha-to",
    "hatomayorense": "ha-to-ma-yo-ren-se",
    "haustorio": "haus-to-rio",
    "haute": "hau-te",
    "havar": "ha-var",
    "havara": "ha-va-ra",
    "havo": "ha-vo",
    "hawaiana": "ha-waia-na",
    "hawaianas": "ha-waia-nas",
    "hawaiano": "ha-waia-no",
    "haya": "ha-ya",
    "hayaca": "ha-ya-ca",
    "hayal": "ha-yal",
    "hayedo": "ha-ye-do",
    "hayena": "ha-ye-na",
    "hayeno": "ha-ye-no",
    "hayo": "ha-yo",
    "hayuco": "ha-yu-co",
    "haza": "ha-za",
    "hazaleja": "ha-za-le-ja",
    "hazana": "ha-za-na",
    "hazaña": "ha-za-ña",
    "hazañar": "ha-za-ñar",
    "hazañera": "ha-za-ñe-ra",
    "hazañería": "ha-za-ñe-rí-a",
    "hazañero": "ha-za-ñe-ro",
    "hazañosa": "ha-za-ño-sa",
    "hazañosamente": "ha-za-ño-sa-men-te",
    "hazañoso": "ha-za-ño-so",
    "hazmerreír": "haz-me-rre-ír",
    "heavy": "he-avy",
    "hebdómada": "heb-dó-ma-da",
    "hebdomadaria": "heb-do-ma-da-ria",
    "hebdomadariamente": "heb-do-ma-da-ria-men-te",
    "hebdomadario": "heb-do-ma-da-rio",
    "hebén": "he-bén",
    "hebetar": "he-be-tar",
    "hebijón": "he-bi-jón",
    "hebilla": "he-bi-lla",
    "hebillaje": "he-bi-lla-je",
    "hebillar": "he-bi-llar",
    "hebillera": "he-bi-lle-ra",
    "hebillero": "he-bi-lle-ro",
    "hebilleta": "he-bi-lle-ta",
    "hebillón": "he-bi-llón",
    "hebra": "he-bra",
    "hebraica": "he-brai-ca",
    "hebraico": "he-brai-co",
    "hebraísmo": "he-bra-ís-mo",
    "hebraísta": "he-bra-ís-ta",
    "hebraizante": "he-brai-zan-te",
    "hebraizar": "he-brai-zar",
    "hebrea": "he-bre-a",
    "hebreo": "he-bre-o",
    "hebrero": "he-bre-ro",
    "hebrosa": "he-bro-sa",
    "hebroso": "he-bro-so",
    "hebruda": "he-bru-da",
    "hebrudo": "he-bru-do",
    "hecatombe": "he-ca-tom-be",
    "hecha": "he-cha",
    "hechicera": "he-chi-ce-ra",
    "hechiceresca": "he-chi-ce-res-ca",
    "hechiceresco": "he-chi-ce-res-co",
    "hechicería": "he-chi-ce-rí-a",
    "hechicero": "he-chi-ce-ro",
    "hechiza": "he-chi-za",
    "hechizar": "he-chi-zar",
    "hechizo": "he-chi-zo",
    "hecho": "he-cho",
    "hechor": "he-chor",
    "hechora": "he-cho-ra",
    "hechura": "he-chu-ra",
    "hecienta": "he-cien-ta",
    "heciento": "he-cien-to",
    "hectárea": "hec-tá-re-a",
    "héctica": "héc-ti-ca",
    "héctico": "héc-ti-co",
    "hectiquez": "hec-ti-quez",
    "hecto": "hec-to",
    "hectógrafo": "hec-tó-gra-fo",
    "hectogramo": "hec-to-gra-mo",
    "hectolitro": "hec-to-li-tro",
    "hectómetro": "hec-tó-me-tro",
    "hectórea": "hec-tó-re-a",
    "hectóreo": "hec-tó-re-o",
    "hectovatio": "hec-to-va-tio",
    "hedentina": "he-den-ti-na",
    "hedentino": "he-den-ti-no",
    "hedentinosa": "he-den-ti-no-sa",
    "hedentinoso": "he-den-ti-no-so",
    "heder": "he-der",
    "hedienta": "he-dien-ta",
    "hediento": "he-dien-to",
    "hedionda": "he-dion-da",
    "hediondamente": "he-dion-da-men-te",
    "hediondez": "he-dion-dez",
    "hediondo": "he-dion-do",
    "hedónico": "he-dó-ni-co",
    "hedonismo": "he-do-nis-mo",
    "hedonista": "he-do-nis-ta",
    "hedonístico": "he-do-nís-ti-co",
    "hedor": "he-dor",
    "hegeliana": "he-ge-lia-na",
    "hegelianismo": "he-ge-lia-nis-mo",
    "hegeliano": "he-ge-lia-no",
    "hegemonía": "he-ge-mo-ní-a",
    "hegemónica": "he-ge-mó-ni-ca",
    "hegemónico": "he-ge-mó-ni-co",
    "hégira": "hé-gi-ra",
    "héjira": "hé-ji-ra",
    "helable": "he-la-ble",
    "helada": "he-la-da",
    "heladera": "he-la-de-ra",
    "heladería": "he-la-de-rí-a",
    "heladero": "he-la-de-ro",
    "heladiza": "he-la-di-za",
    "heladizo": "he-la-di-zo",
    "helado": "he-la-do",
    "helador": "he-la-dor",
    "heladora": "he-la-do-ra",
    "heladura": "he-la-du-ra",
    "helaje": "he-la-je",
    "helamiento": "he-la-mien-to",
    "helar": "he-lar",
    "helear": "he-le-ar",
    "helechal": "he-le-chal",
    "helecho": "he-le-cho",
    "helena": "he-le-na",
    "helénica": "he-lé-ni-ca",
    "helénico": "he-lé-ni-co",
    "helenio": "he-le-nio",
    "helenismo": "he-le-nis-mo",
    "helenista": "he-le-nis-ta",
    "helenística": "he-le-nís-ti-ca",
    "helenístico": "he-le-nís-ti-co",
    "helenización": "he-le-ni-za-ción",
    "helenizante": "he-le-ni-zan-te",
    "helenizar": "he-le-ni-zar",
    "heleno": "he-le-no",
    "helera": "he-le-ra",
    "helero": "he-le-ro",
    "helespontiaca": "he-les-pon-tia-ca",
    "helespontíaco": "he-les-pon-tí-a-co",
    "helespontiaco": "he-les-pon-tia-co",
    "helespóntica": "he-les-pón-ti-ca",
    "helespóntico": "he-les-pón-ti-co",
    "helgada": "hel-ga-da",
    "helgado": "hel-ga-do",
    "helgadura": "hel-ga-du-ra",
    "heliaca": "he-lia-ca",
    "helíaco": "he-lí-a-co",
    "heliaco": "he-lia-co",
    "heliasta": "he-lias-ta",
    "hélice": "hé-li-ce",
    "helicoidal": "he-li-coi-dal",
    "helicoide": "he-li-coi-de",
    "helicón": "he-li-cón",
    "helicona": "he-li-co-na",
    "heliconia": "he-li-co-nia",
    "helicónides": "he-li-có-ni-des",
    "heliconio": "he-li-co-nio",
    "helicóptero": "he-li-cóp-te-ro",
    "helio": "he-lio",
    "heliocéntrica": "he-lio-cén-tri-ca",
    "heliocéntrico": "he-lio-cén-tri-co",
    "heliocentrismo": "he-lio-cen-tris-mo",
    "heliófilo": "he-lió-fi-lo",
    "heliofísica": "he-lio-fí-si-ca",
    "heliofísico": "he-lio-fí-si-co",
    "heliogábalo": "he-lio-gá-ba-lo",
    "heliograbado": "he-lio-gra-ba-do",
    "heliografía": "he-lio-gra-fí-a",
    "heliográfica": "he-lio-grá-fi-ca",
    "heliográfico": "he-lio-grá-fi-co",
    "heliógrafo": "he-lió-gra-fo",
    "heliograma": "he-lio-gra-ma",
    "heliómetro": "he-lió-me-tro",
    "heliomotor": "he-lio-mo-tor",
    "helión": "he-lión",
    "helioscopio": "he-lios-co-pio",
    "heliosis": "he-lio-sis",
    "heliostático": "he-lios-tá-ti-co",
    "heliostato": "he-lios-ta-to",
    "helióstato": "he-liós-ta-to",
    "heliotecnia": "he-lio-tec-nia",
    "heliotelegrafía": "he-lio-te-le-gra-fí-a",
    "helioterapia": "he-lio-te-ra-pia",
    "heliotropio": "he-lio-tro-pio",
    "heliotropismo": "he-lio-tro-pis-mo",
    "heliotropo": "he-lio-tro-po",
    "helipuerto": "he-li-puer-to",
    "helitransportado": "he-li-trans-por-ta-do",
    "helmántica": "hel-mán-ti-ca",
    "helmántico": "hel-mán-ti-co",
    "helmintiasis": "hel-min-tia-sis",
    "helmíntica": "hel-mín-ti-ca",
    "helmíntico": "hel-mín-ti-co",
    "helminto": "hel-min-to",
    "helmintología": "hel-min-to-lo-gí-a",
    "helmintológica": "hel-min-to-ló-gi-ca",
    "helmintológico": "hel-min-to-ló-gi-co",
    "helor": "he-lor",
    "helvecia": "hel-ve-cia",
    "helvecio": "hel-ve-cio",
    "helvética": "hel-vé-ti-ca",
    "helvético": "hel-vé-ti-co",
    "hemacrimo": "he-ma-cri-mo",
    "hemal": "he-mal",
    "hemangioma": "he-man-gio-ma",
    "hematemesis": "he-ma-te-me-sis",
    "hematermo": "he-ma-ter-mo",
    "hemático": "he-má-ti-co",
    "hematíe": "he-ma-tí-e",
    "hematites": "he-ma-ti-tes",
    "hematocrito": "he-ma-to-cri-to",
    "hematófaga": "he-ma-tó-fa-ga",
    "hematófago": "he-ma-tó-fa-go",
    "hematógeno": "he-ma-tó-ge-no",
    "hematóloga": "he-ma-tó-lo-ga",
    "hematología": "he-ma-to-lo-gí-a",
    "hematológico": "he-ma-to-ló-gi-co",
    "hematólogo": "he-ma-tó-lo-go",
    "hematoma": "he-ma-to-ma",
    "hematopoyesis": "he-ma-to-po-ye-sis",
    "hematopoyético": "he-ma-to-po-yé-ti-co",
    "hematosis": "he-ma-to-sis",
    "hematoxilina": "he-ma-to-xi-li-na",
    "hematozoario": "he-ma-to-zo-a-rio",
    "hematuria": "he-ma-tu-ria",
    "hembra": "hem-bra",
    "hembraje": "hem-bra-je",
    "hembrear": "hem-bre-ar",
    "hembrilla": "hem-bri-lla",
    "hembrón": "hem-brón",
    "hembruna": "hem-bru-na",
    "hembruno": "hem-bru-no",
    "hemencia": "he-men-cia",
    "hemenciar": "he-men-ciar",
    "hemenciosa": "he-men-cio-sa",
    "hemencioso": "he-men-cio-so",
    "hemerálope": "he-me-rá-lo-pe",
    "hemeralopía": "he-me-ra-lo-pí-a",
    "hemeroteca": "he-me-ro-te-ca",
    "hemianopsia": "he-mia-nop-sia",
    "hemiatrofia": "he-mia-tro-fia",
    "hemiciclo": "he-mi-ci-clo",
    "hemicordado": "he-mi-cor-da-do",
    "hemicránea": "he-mi-crá-ne-a",
    "hemina": "he-mi-na",
    "hemión": "he-mión",
    "hemíono": "he-mí-o-no",
    "hemiparásito": "he-mi-pa-rá-si-to",
    "hemiplejía": "he-mi-ple-jí-a",
    "hemiplejia": "he-mi-ple-jia",
    "hemipléjica": "he-mi-plé-ji-ca",
    "hemipléjico": "he-mi-plé-ji-co",
    "hemíptero": "he-míp-te-ro",
    "hemisférica": "he-mis-fé-ri-ca",
    "hemisférico": "he-mis-fé-ri-co",
    "hemisferio": "he-mis-fe-rio",
    "hemisfero": "he-mis-fe-ro",
    "hemistiquio": "he-mis-ti-quio",
    "hemoaglutinación": "he-mo-a-glu-ti-na-ción",
    "hemocianina": "he-mo-cia-ni-na",
    "hemocromatosis": "he-mo-cro-ma-to-sis",
    "hemocultivo": "he-mo-cul-ti-vo",
    "hemoderivado": "he-mo-de-ri-va-do",
    "hemodiálisis": "he-mo-diá-li-sis",
    "hemodializador": "he-mo-dia-li-za-dor",
    "hemodinámica": "he-mo-di-ná-mi-ca",
    "hemodonación": "he-mo-do-na-ción",
    "hemofilia": "he-mo-fi-lia",
    "hemofílica": "he-mo-fí-li-ca",
    "hemofílico": "he-mo-fí-li-co",
    "hemoglobina": "he-mo-glo-bi-na",
    "hemoglobinuria": "he-mo-glo-bi-nu-ria",
    "hemograma": "he-mo-gra-ma",
    "hemolinfa": "he-mo-lin-fa",
    "hemolisina": "he-mo-li-si-na",
    "hemolisis": "he-mo-li-sis",
    "hemolítico": "he-mo-lí-ti-co",
    "hemolizar": "he-mo-li-zar",
    "hemología": "he-mo-lo-gí-a",
    "hemopatía": "he-mo-pa-tí-a",
    "hemoptísica": "he-mop-tí-si-ca",
    "hemoptísico": "he-mop-tí-si-co",
    "hemoptisis": "he-mop-ti-sis",
    "hemoptoico": "he-mop-toi-co",
    "hemorragia": "he-mo-rra-gia",
    "hemorrágico": "he-mo-rrá-gi-co",
    "hemorroida": "he-mo-rroi-da",
    "hemorroidal": "he-mo-rroi-dal",
    "hemorroide": "he-mo-rroi-de",
    "hemorroísa": "he-mo-rro-í-sa",
    "hemorroisa": "he-mo-rroi-sa",
    "hemorroo": "he-mo-rro-o",
    "hemostasia": "he-mos-ta-sia",
    "hemostasis": "he-mos-ta-sis",
    "hemostática": "he-mos-tá-ti-ca",
    "hemostático": "he-mos-tá-ti-co",
    "hemoterapia": "he-mo-te-ra-pia",
    "hemotórax": "he-mo-tó-rax",
    "hemotóxico": "he-mo-tó-xi-co",
    "henal": "he-nal",
    "henar": "he-nar",
    "henasco": "he-nas-co",
    "henazo": "he-na-zo",
    "henchidor": "hen-chi-dor",
    "henchidora": "hen-chi-do-ra",
    "henchidura": "hen-chi-du-ra",
    "henchimiento": "hen-chi-mien-to",
    "henchir": "hen-chir",
    "hendedor": "hen-de-dor",
    "hendedora": "hen-de-do-ra",
    "hendedura": "hen-de-du-ra",
    "hender": "hen-der",
    "hendíadis": "hen-dí-a-dis",
    "hendible": "hen-di-ble",
    "hendido": "hen-di-do",
    "hendidura": "hen-di-du-ra",
    "hendiente": "hen-dien-te",
    "hendija": "hen-di-ja",
    "hendimiento": "hen-di-mien-to",
    "hendir": "hen-dir",
    "hendrija": "hen-dri-ja",
    "henequén": "he-ne-quén",
    "henequenera": "he-ne-que-ne-ra",
    "henequenero": "he-ne-que-ne-ro",
    "henequera": "he-ne-que-ra",
    "henequero": "he-ne-que-ro",
    "hénide": "hé-ni-de",
    "henificar": "he-ni-fi-car",
    "henil": "he-nil",
    "heñir": "he-ñir",
    "heno": "he-no",
    "henojil": "he-no-jil",
    "henoteísmo": "he-no-te-ís-mo",
    "henrio": "hen-rio",
    "heparina": "he-pa-ri-na",
    "heparinización": "he-pa-ri-ni-za-ción",
    "heparinizar": "he-pa-ri-ni-zar",
    "hepatalgia": "he-pa-tal-gia",
    "hepática": "he-pá-ti-ca",
    "hepático": "he-pá-ti-co",
    "hepatitis": "he-pa-ti-tis",
    "hepatización": "he-pa-ti-za-ción",
    "hepatocito": "he-pa-to-ci-to",
    "hepatograma": "he-pa-to-gra-ma",
    "hepatóloga": "he-pa-tó-lo-ga",
    "hepatología": "he-pa-to-lo-gí-a",
    "hepatológico": "he-pa-to-ló-gi-co",
    "hepatólogo": "he-pa-tó-lo-go",
    "hepatomegalia": "he-pa-to-me-ga-lia",
    "hepatopáncreas": "he-pa-to-pán-cre-as",
    "heptacordio": "hep-ta-cor-dio",
    "heptacordo": "hep-ta-cor-do",
    "heptaedro": "hep-ta-e-dro",
    "heptágona": "hep-tá-go-na",
    "heptagonal": "hep-ta-go-nal",
    "heptágono": "hep-tá-go-no",
    "heptámetro": "hep-tá-me-tro",
    "heptarquía": "hep-tar-quí-a",
    "heptasílaba": "hep-ta-sí-la-ba",
    "heptasilábica": "hep-ta-si-lá-bi-ca",
    "heptasilábico": "hep-ta-si-lá-bi-co",
    "heptasílabo": "hep-ta-sí-la-bo",
    "heptatlón": "hep-ta-tlón",
    "heracleo": "he-ra-cle-o",
    "heraclida": "he-ra-cli-da",
    "heracliteísmo": "he-ra-cli-te-ís-mo",
    "heráldica": "he-rál-di-ca",
    "heráldico": "he-rál-di-co",
    "heraldista": "he-ral-dis-ta",
    "heraldo": "he-ral-do",
    "heraute": "he-rau-te",
    "herbácea": "her-bá-ce-a",
    "herbáceo": "her-bá-ce-o",
    "herbada": "her-ba-da",
    "herbajar": "her-ba-jar",
    "herbaje": "her-ba-je",
    "herbajear": "her-ba-je-ar",
    "herbajero": "her-ba-je-ro",
    "herbal": "her-bal",
    "herbar": "her-bar",
    "herbaria": "her-ba-ria",
    "herbario": "her-ba-rio",
    "herbato": "her-ba-to",
    "herbazal": "her-ba-zal",
    "herbecer": "her-be-cer",
    "herbera": "her-be-ra",
    "herbero": "her-be-ro",
    "herbicida": "her-bi-ci-da",
    "herbívora": "her-bí-vo-ra",
    "herbívoro": "her-bí-vo-ro",
    "herbodietética": "her-bo-die-té-ti-ca",
    "herbolar": "her-bo-lar",
    "herbolaria": "her-bo-la-ria",
    "herbolario": "her-bo-la-rio",
    "herbolecer": "her-bo-le-cer",
    "herbología": "her-bo-lo-gí-a",
    "herborista": "her-bo-ris-ta",
    "herboristería": "her-bo-ris-te-rí-a",
    "herborización": "her-bo-ri-za-ción",
    "herborizador": "her-bo-ri-za-dor",
    "herborizadora": "her-bo-ri-za-do-ra",
    "herborizar": "her-bo-ri-zar",
    "herbosa": "her-bo-sa",
    "herboso": "her-bo-so",
    "herciano": "her-cia-no",
    "herciniano": "her-ci-nia-no",
    "hercio": "her-cio",
    "herculana": "her-cu-la-na",
    "herculano": "her-cu-la-no",
    "hercúlea": "her-cú-le-a",
    "hercúleo": "her-cú-le-o",
    "hércules": "hér-cu-les",
    "herculina": "her-cu-li-na",
    "herculino": "her-cu-li-no",
    "heredable": "he-re-da-ble",
    "heredad": "he-re-dad",
    "heredada": "he-re-da-da",
    "heredado": "he-re-da-do",
    "heredamiento": "he-re-da-mien-to",
    "heredanza": "he-re-dan-za",
    "heredar": "he-re-dar",
    "heredera": "he-re-de-ra",
    "heredero": "he-re-de-ro",
    "herediana": "he-re-dia-na",
    "herediano": "he-re-dia-no",
    "heredípeta": "he-re-dí-pe-ta",
    "hereditaria": "he-re-di-ta-ria",
    "hereditario": "he-re-di-ta-rio",
    "hereja": "he-re-ja",
    "hereje": "he-re-je",
    "herejía": "he-re-jí-a",
    "herencia": "he-ren-cia",
    "herepo": "he-re-po",
    "heresiarca": "he-re-siar-ca",
    "herética": "he-ré-ti-ca",
    "heretical": "he-re-ti-cal",
    "hereticar": "he-re-ti-car",
    "herético": "he-ré-ti-co",
    "heria": "he-ria",
    "herida": "he-ri-da",
    "herido": "he-ri-do",
    "heridor": "he-ri-dor",
    "heridora": "he-ri-do-ra",
    "heril": "he-ril",
    "herimiento": "he-ri-mien-to",
    "herir": "he-rir",
    "herma": "her-ma",
    "hermafrodismo": "her-ma-fro-dis-mo",
    "hermafrodita": "her-ma-fro-di-ta",
    "hermafroditismo": "her-ma-fro-di-tis-mo",
    "hermafrodito": "her-ma-fro-di-to",
    "hermana": "her-ma-na",
    "hermanable": "her-ma-na-ble",
    "hermanablemente": "her-ma-na-ble-men-te",
    "hermanada": "her-ma-na-da",
    "hermanado": "her-ma-na-do",
    "hermanal": "her-ma-nal",
    "hermanamiento": "her-ma-na-mien-to",
    "hermanar": "her-ma-nar",
    "hermanastra": "her-ma-nas-tra",
    "hermanastro": "her-ma-nas-tro",
    "hermanazgo": "her-ma-naz-go",
    "hermandad": "her-man-dad",
    "hermandar": "her-man-dar",
    "hermandarse": "her-man-dar-se",
    "hermandino": "her-man-di-no",
    "hermanear": "her-ma-ne-ar",
    "hermanecer": "her-ma-ne-cer",
    "hermano": "her-ma-no",
    "hermanuco": "her-ma-nu-co",
    "hermeneuta": "her-me-neu-ta",
    "hermenéutica": "her-me-néu-ti-ca",
    "hermenéutico": "her-me-néu-ti-co",
    "hermética": "her-mé-ti-ca",
    "herméticamente": "her-mé-ti-ca-men-te",
    "hermeticidad": "her-me-ti-ci-dad",
    "hermético": "her-mé-ti-co",
    "hermetismo": "her-me-tis-mo",
    "hermetizar": "her-me-ti-zar",
    "hermodátil": "her-mo-dá-til",
    "hermosa": "her-mo-sa",
    "hermosamente": "her-mo-sa-men-te",
    "hermoseador": "her-mo-se-a-dor",
    "hermoseadora": "her-mo-se-a-do-ra",
    "hermoseamiento": "her-mo-se-a-mien-to",
    "hermosear": "her-mo-se-ar",
    "hermoseo": "her-mo-se-o",
    "hermosilla": "her-mo-si-lla",
    "hermosillense": "her-mo-si-llen-se",
    "hermoso": "her-mo-so",
    "hermosura": "her-mo-su-ra",
    "hernia": "her-nia",
    "herniación": "her-nia-ción",
    "herniada": "her-nia-da",
    "herniado": "her-nia-do",
    "herniar": "her-niar",
    "herniaria": "her-nia-ria",
    "herniario": "her-nia-rio",
    "hérnica": "hér-ni-ca",
    "hérnico": "hér-ni-co",
    "herniosa": "her-nio-sa",
    "hernioso": "her-nio-so",
    "hernista": "her-nis-ta",
    "herodes": "he-ro-des",
    "herodiana": "he-ro-dia-na",
    "herodiano": "he-ro-dia-no",
    "héroe": "hé-ro-e",
    "heroica": "he-roi-ca",
    "heroicamente": "he-roi-ca-men-te",
    "heroicidad": "he-roi-ci-dad",
    "heroico": "he-roi-co",
    "heroida": "he-roi-da",
    "heroína": "he-ro-í-na",
    "heroinómana": "he-roi-nó-ma-na",
    "heroinómano": "he-roi-nó-ma-no",
    "heroísmo": "he-ro-ís-mo",
    "heroísta": "he-ro-ís-ta",
    "herpe": "her-pe",
    "herpes": "her-pes",
    "herpética": "her-pé-ti-ca",
    "herpético": "her-pé-ti-co",
    "herpetismo": "her-pe-tis-mo",
    "herpetóloga": "her-pe-tó-lo-ga",
    "herpetología": "her-pe-to-lo-gí-a",
    "herpetólogo": "her-pe-tó-lo-go",
    "herpil": "her-pil",
    "herrada": "he-rra-da",
    "herradero": "he-rra-de-ro",
    "herrado": "he-rra-do",
    "herrador": "he-rra-dor",
    "herradora": "he-rra-do-ra",
    "herradura": "he-rra-du-ra",
    "herraj": "he-rraj",
    "herraje": "he-rra-je",
    "herramental": "he-rra-men-tal",
    "herramienta": "he-rra-mien-ta",
    "herrar": "he-rrar",
    "herrén": "he-rrén",
    "herreña": "he-rre-ña",
    "herrenal": "he-rre-nal",
    "herreñal": "he-rre-ñal",
    "herrenar": "he-rre-nar",
    "herreño": "he-rre-ño",
    "herrera": "he-rre-ra",
    "herrerana": "he-rre-ra-na",
    "herrerano": "he-rre-ra-no",
    "herrería": "he-rre-rí-a",
    "herreriano": "he-rre-ria-no",
    "herrerillo": "he-rre-ri-llo",
    "herrerismo": "he-rre-ris-mo",
    "herrerista": "he-rre-ris-ta",
    "herrero": "he-rre-ro",
    "herrerón": "he-rre-rón",
    "herreruelo": "he-rre-rue-lo",
    "herrete": "he-rre-te",
    "herretear": "he-rre-te-ar",
    "herrezuelo": "he-rre-zue-lo",
    "herrial": "he-rrial",
    "herrín": "he-rrín",
    "herriza": "he-rri-za",
    "herrojo": "he-rro-jo",
    "herrón": "he-rrón",
    "herronada": "he-rro-na-da",
    "herropea": "he-rro-pe-a",
    "herropeada": "he-rro-pe-a-da",
    "herropeado": "he-rro-pe-a-do",
    "herrugenta": "he-rru-gen-ta",
    "herrugento": "he-rru-gen-to",
    "herrumbrado": "he-rrum-bra-do",
    "herrumbrar": "he-rrum-brar",
    "herrumbre": "he-rrum-bre",
    "herrumbrosa": "he-rrum-bro-sa",
    "herrumbroso": "he-rrum-bro-so",
    "herrusca": "he-rrus-ca",
    "hertziana": "hert-zia-na",
    "hertziano": "hert-zia-no",
    "hérula": "hé-ru-la",
    "hérulo": "hé-ru-lo",
    "hervencia": "her-ven-cia",
    "herventar": "her-ven-tar",
    "herver": "her-ver",
    "hervidero": "her-vi-de-ro",
    "hervido": "her-vi-do",
    "hervidor": "her-vi-dor",
    "hervidura": "her-vi-du-ra",
    "hervimiento": "her-vi-mien-to",
    "hervir": "her-vir",
    "hervor": "her-vor",
    "hervorizar": "her-vo-ri-zar",
    "hervorizarse": "her-vo-ri-zar-se",
    "hervorosa": "her-vo-ro-sa",
    "hervoroso": "her-vo-ro-so",
    "hesitación": "he-si-ta-ción",
    "hesitar": "he-si-tar",
    "héspera": "hés-pe-ra",
    "hesperia": "hes-pe-ria",
    "hespérica": "hes-pé-ri-ca",
    "hespérico": "hes-pé-ri-co",
    "hespéride": "hes-pé-ri-de",
    "hespérides": "hes-pé-ri-des",
    "hesperidio": "hes-pe-ri-dio",
    "hespérido": "hes-pé-ri-do",
    "hesperio": "hes-pe-rio",
    "héspero": "hés-pe-ro",
    "hespir": "hes-pir",
    "hessonita": "hes-so-ni-ta",
    "hetaira": "he-tai-ra",
    "hetea": "he-te-a",
    "heteo": "he-te-o",
    "hetera": "he-te-ra",
    "heterocerca": "he-te-ro-cer-ca",
    "heterocerco": "he-te-ro-cer-co",
    "heterocíclico": "he-te-ro-cí-cli-co",
    "heterociclo": "he-te-ro-ci-clo",
    "heterocigótico": "he-te-ro-ci-gó-ti-co",
    "heterocigoto": "he-te-ro-ci-go-to",
    "heteroclamídeo": "he-te-ro-cla-mí-de-o",
    "heteroclisis": "he-te-ro-cli-sis",
    "heteróclita": "he-te-ró-cli-ta",
    "heteróclito": "he-te-ró-cli-to",
    "heterodino": "he-te-ro-di-no",
    "heterodonto": "he-te-ro-don-to",
    "heterodoxa": "he-te-ro-do-xa",
    "heterodoxia": "he-te-ro-do-xia",
    "heterodoxo": "he-te-ro-do-xo",
    "heterogénea": "he-te-ro-gé-ne-a",
    "heterogeneidad": "he-te-ro-ge-nei-dad",
    "heterogéneo": "he-te-ro-gé-ne-o",
    "heteromancía": "he-te-ro-man-cí-a",
    "heteromancia": "he-te-ro-man-cia",
    "heterómero": "he-te-ró-me-ro",
    "heteronimia": "he-te-ro-ni-mia",
    "heterónimo": "he-te-ró-ni-mo",
    "heterónoma": "he-te-ró-no-ma",
    "heteronomía": "he-te-ro-no-mí-a",
    "heterónomo": "he-te-ró-no-mo",
    "heteroplastia": "he-te-ro-plas-tia",
    "heterópsida": "he-te-róp-si-da",
    "heterópsido": "he-te-róp-si-do",
    "heteróptero": "he-te-róp-te-ro",
    "heteroscia": "he-te-ros-cia",
    "heteroscio": "he-te-ros-cio",
    "heterosexual": "he-te-ro-se-xual",
    "heterosexualidad": "he-te-ro-se-xua-li-dad",
    "heterosfera": "he-te-ros-fe-ra",
    "heterósfera": "he-te-rós-fe-ra",
    "heterosugestión": "he-te-ro-su-ges-tión",
    "heterotrófico": "he-te-ro-tró-fi-co",
    "heterótrofo": "he-te-ró-tro-fo",
    "heterozigótico": "he-te-ro-zi-gó-ti-co",
    "heterozigoto": "he-te-ro-zi-go-to",
    "hética": "hé-ti-ca",
    "hético": "hé-ti-co",
    "hetiquez": "he-ti-quez",
    "hetita": "he-ti-ta",
    "hetría": "he-trí-a",
    "heurística": "heu-rís-ti-ca",
    "heurístico": "heu-rís-ti-co",
    "hevea": "he-ve-a",
    "hevicultivo": "he-vi-cul-ti-vo",
    "hevicultor": "he-vi-cul-tor",
    "hevicultora": "he-vi-cul-to-ra",
    "hexacoralario": "he-xa-co-ra-la-rio",
    "hexacordo": "he-xa-cor-do",
    "hexadecimal": "he-xa-de-ci-mal",
    "hexaedro": "he-xa-e-dro",
    "hexágona": "he-xá-go-na",
    "hexagonal": "he-xa-go-nal",
    "hexágono": "he-xá-go-no",
    "hexagrama": "he-xa-gra-ma",
    "hexalite": "he-xa-li-te",
    "hexámetro": "he-xá-me-tro",
    "hexángula": "he-xán-gu-la",
    "hexángulo": "he-xán-gu-lo",
    "hexápeda": "he-xá-pe-da",
    "hexápodo": "he-xá-po-do",
    "hexasílaba": "he-xa-sí-la-ba",
    "hexasílabo": "he-xa-sí-la-bo",
    "hexástilo": "he-xás-ti-lo",
    "hialina": "hia-li-na",
    "hialino": "hia-li-no",
    "hialoideo": "hia-loi-de-o",
    "hialoplasma": "hia-lo-plas-ma",
    "hiante": "hian-te",
    "hiato": "hia-to",
    "hibernación": "hi-ber-na-ción",
    "hibernal": "hi-ber-nal",
    "hibernar": "hi-ber-nar",
    "hibernés": "hi-ber-nés",
    "hibernesa": "hi-ber-ne-sa",
    "hibérnica": "hi-bér-ni-ca",
    "hibérnico": "hi-bér-ni-co",
    "hiberniza": "hi-ber-ni-za",
    "hibernizo": "hi-ber-ni-zo",
    "hibierno": "hi-bier-no",
    "hibisco": "hi-bis-co",
    "hiblea": "hi-ble-a",
    "hibleo": "hi-ble-o",
    "híbrida": "hí-bri-da",
    "hibridación": "hi-bri-da-ción",
    "hibridar": "hi-bri-dar",
    "hibridez": "hi-bri-dez",
    "hibridismo": "hi-bri-dis-mo",
    "híbrido": "hí-bri-do",
    "hibridoma": "hi-bri-do-ma",
    "hibuerense": "hi-bue-ren-se",
    "hibuero": "hi-bue-ro",
    "hicaco": "hi-ca-co",
    "hicadura": "hi-ca-du-ra",
    "hico": "hi-co",
    "hicotea": "hi-co-te-a",
    "hidalga": "hi-dal-ga",
    "hidalgamente": "hi-dal-ga-men-te",
    "hidalgo": "hi-dal-go",
    "hidalguense": "hi-dal-guen-se",
    "hidalguez": "hi-dal-guez",
    "hidalguía": "hi-dal-guí-a",
    "hidátide": "hi-dá-ti-de",
    "hidatídica": "hi-da-tí-di-ca",
    "hidatídico": "hi-da-tí-di-co",
    "hidatidosis": "hi-da-ti-do-sis",
    "hiddenita": "hid-de-ni-ta",
    "hideputa": "hi-de-pu-ta",
    "hidionda": "hi-dion-da",
    "hidiondo": "hi-dion-do",
    "hidra": "hi-dra",
    "hidracida": "hi-dra-ci-da",
    "hidrácido": "hi-drá-ci-do",
    "hidracina": "hi-dra-ci-na",
    "hidractivo": "hi-drac-ti-vo",
    "hidragogía": "hi-dra-go-gí-a",
    "hidrante": "hi-dran-te",
    "hidrargirio": "hi-drar-gi-rio",
    "hidrargirismo": "hi-drar-gi-ris-mo",
    "hidrargiro": "hi-drar-gi-ro",
    "hidrartrosis": "hi-drar-tro-sis",
    "hidratación": "hi-dra-ta-ción",
    "hidratante": "hi-dra-tan-te",
    "hidratar": "hi-dra-tar",
    "hidrato": "hi-dra-to",
    "hidráulica": "hi-dráu-li-ca",
    "hidráulico": "hi-dráu-li-co",
    "hidria": "hi-dria",
    "hídrico": "hí-dri-co",
    "hidroala": "hi-dro-a-la",
    "hidroavión": "hi-dro-a-vión",
    "hidrobiología": "hi-dro-bio-lo-gí-a",
    "hidrocálido": "hi-dro-cá-li-do",
    "hidrocarburo": "hi-dro-car-bu-ro",
    "hidrocéfala": "hi-dro-cé-fa-la",
    "hidrocefalia": "hi-dro-ce-fa-lia",
    "hidrocefálico": "hi-dro-ce-fá-li-co",
    "hidrocéfalo": "hi-dro-cé-fa-lo",
    "hidrocele": "hi-dro-ce-le",
    "hidroclorato": "hi-dro-clo-ra-to",
    "hidroclórica": "hi-dro-cló-ri-ca",
    "hidroclórico": "hi-dro-cló-ri-co",
    "hidrocloruro": "hi-dro-clo-ru-ro",
    "hidrodinámica": "hi-dro-di-ná-mi-ca",
    "hidrodinámico": "hi-dro-di-ná-mi-co",
    "hidroeléctrica": "hi-dro-e-léc-tri-ca",
    "hidroelectricidad": "hi-dro-e-lec-tri-ci-dad",
    "hidroeléctrico": "hi-dro-e-léc-tri-co",
    "hidroestable": "hi-dro-es-ta-ble",
    "hidrófana": "hi-dró-fa-na",
    "hidrófila": "hi-dró-fi-la",
    "hidrofilacio": "hi-dro-fi-la-cio",
    "hidrofilia": "hi-dro-fi-lia",
    "hidrófilo": "hi-dró-fi-lo",
    "hidrófoba": "hi-dró-fo-ba",
    "hidrofobia": "hi-dro-fo-bia",
    "hidrófobo": "hi-dró-fo-bo",
    "hidrófono": "hi-dró-fo-no",
    "hidrófuga": "hi-dró-fu-ga",
    "hidrófugo": "hi-dró-fu-go",
    "hidrogenación": "hi-dro-ge-na-ción",
    "hidrogenar": "hi-dro-ge-nar",
    "hidrógeno": "hi-dró-ge-no",
    "hidrogenocarbonato": "hi-dro-ge-no-car-bo-na-to",
    "hidrogenosulfuro": "hi-dro-ge-no-sul-fu-ro",
    "hidrogeóloga": "hi-dro-ge-ó-lo-ga",
    "hidrogeología": "hi-dro-ge-o-lo-gí-a",
    "hidrogeológico": "hi-dro-ge-o-ló-gi-co",
    "hidrogeólogo": "hi-dro-ge-ó-lo-go",
    "hidrognosia": "hi-drog-no-sia",
    "hidrógrafa": "hi-dró-gra-fa",
    "hidrografía": "hi-dro-gra-fí-a",
    "hidrográfica": "hi-dro-grá-fi-ca",
    "hidrográfico": "hi-dro-grá-fi-co",
    "hidrógrafo": "hi-dró-gra-fo",
    "hidrojardinera": "hi-dro-jar-di-ne-ra",
    "hidrojet": "hi-dro-jet",
    "hidrólisis": "hi-dró-li-sis",
    "hidrolítico": "hi-dro-lí-ti-co",
    "hidrolizado": "hi-dro-li-za-do",
    "hidrolizar": "hi-dro-li-zar",
    "hidróloga": "hi-dró-lo-ga",
    "hidrología": "hi-dro-lo-gí-a",
    "hidrológica": "hi-dro-ló-gi-ca",
    "hidrológico": "hi-dro-ló-gi-co",
    "hidrólogo": "hi-dró-lo-go",
    "hidroma": "hi-dro-ma",
    "hidromancía": "hi-dro-man-cí-a",
    "hidromancia": "hi-dro-man-cia",
    "hidromántica": "hi-dro-mán-ti-ca",
    "hidromántico": "hi-dro-mán-ti-co",
    "hidromasaje": "hi-dro-ma-sa-je",
    "hidromecánico": "hi-dro-me-cá-ni-co",
    "hidromel": "hi-dro-mel",
    "hidrometeoro": "hi-dro-me-te-o-ro",
    "hidrómetra": "hi-dró-me-tra",
    "hidrometría": "hi-dro-me-trí-a",
    "hidrométrica": "hi-dro-mé-tri-ca",
    "hidrométrico": "hi-dro-mé-tri-co",
    "hidrómetro": "hi-dró-me-tro",
    "hidromiel": "hi-dro-miel",
    "hidromineral": "hi-dro-mi-ne-ral",
    "hidromodelismo": "hi-dro-mo-de-lis-mo",
    "hidroneumático": "hi-dro-neu-má-ti-co",
    "hidronimia": "hi-dro-ni-mia",
    "hidronímico": "hi-dro-ní-mi-co",
    "hidrónimo": "hi-dró-ni-mo",
    "hidronio": "hi-dro-nio",
    "hidrópata": "hi-dró-pa-ta",
    "hidropatía": "hi-dro-pa-tí-a",
    "hidropática": "hi-dro-pá-ti-ca",
    "hidropático": "hi-dro-pá-ti-co",
    "hidropesía": "hi-dro-pe-sí-a",
    "hidrópica": "hi-dró-pi-ca",
    "hidrópico": "hi-dró-pi-co",
    "hidroplano": "hi-dro-pla-no",
    "hidroponía": "hi-dro-po-ní-a",
    "hidropónica": "hi-dro-pó-ni-ca",
    "hidropónico": "hi-dro-pó-ni-co",
    "hidropterínea": "hi-drop-te-rí-ne-a",
    "hidropteríneo": "hi-drop-te-rí-ne-o",
    "hidroquinona": "hi-dro-qui-no-na",
    "hidroscopia": "hi-dros-co-pia",
    "hidroscopio": "hi-dros-co-pio",
    "hidrosfera": "hi-dros-fe-ra",
    "hidrósfera": "hi-drós-fe-ra",
    "hidrosilicato": "hi-dro-si-li-ca-to",
    "hidrosol": "hi-dro-sol",
    "hidrosoluble": "hi-dro-so-lu-ble",
    "hidrostática": "hi-dros-tá-ti-ca",
    "hidrostáticamente": "hi-dros-tá-ti-ca-men-te",
    "hidrostático": "hi-dros-tá-ti-co",
    "hidrotecnia": "hi-dro-tec-nia",
    "hidroterapia": "hi-dro-te-ra-pia",
    "hidroterápica": "hi-dro-te-rá-pi-ca",
    "hidroterápico": "hi-dro-te-rá-pi-co",
    "hidrotermal": "hi-dro-ter-mal",
    "hidrotimetría": "hi-dro-ti-me-trí-a",
    "hidrotimétrico": "hi-dro-ti-mé-tri-co",
    "hidrotórax": "hi-dro-tó-rax",
    "hidrotropismo": "hi-dro-tro-pis-mo",
    "hidróxido": "hi-dró-xi-do",
    "hidroxilar": "hi-dro-xi-lar",
    "hidroxilo": "hi-dro-xi-lo",
    "hidrozoo": "hi-dro-zo-o",
    "hidruro": "hi-dru-ro",
    "hiebre": "hie-bre",
    "hiedra": "hie-dra",
    "hielera": "hie-le-ra",
    "hielo": "hie-lo",
    "hieltro": "hiel-tro",
    "hiemal": "hie-mal",
    "hiena": "hie-na",
    "hienda": "hien-da",
    "hiera": "hie-ra",
    "hierarquía": "hie-rar-quí-a",
    "hierática": "hie-rá-ti-ca",
    "hierático": "hie-rá-ti-co",
    "hieratismo": "hie-ra-tis-mo",
    "hierba": "hier-ba",
    "hierbabuena": "hier-ba-bue-na",
    "hierbajo": "hier-ba-jo",
    "hierbal": "hier-bal",
    "hierbaluisa": "hier-ba-lui-sa",
    "hierbatera": "hier-ba-te-ra",
    "hierbatero": "hier-ba-te-ro",
    "hierbazal": "hier-ba-zal",
    "hierbera": "hier-be-ra",
    "hierbería": "hier-be-rí-a",
    "hierbero": "hier-be-ro",
    "hiero": "hie-ro",
    "hieródula": "hie-ró-du-la",
    "hieródulo": "hie-ró-du-lo",
    "hierofanta": "hie-ro-fan-ta",
    "hierofante": "hie-ro-fan-te",
    "hieroglífica": "hie-ro-glí-fi-ca",
    "hieroglífico": "hie-ro-glí-fi-co",
    "hieroscopia": "hie-ros-co-pia",
    "hierosolimitana": "hie-ro-so-li-mi-ta-na",
    "hierosolimitano": "hie-ro-so-li-mi-ta-no",
    "hierra": "hie-rra",
    "hierro": "hie-rro",
    "hifa": "hi-fa",
    "higa": "hi-ga",
    "higadilla": "hi-ga-di-lla",
    "higadillo": "hi-ga-di-llo",
    "hígado": "hí-ga-do",
    "higaja": "hi-ga-ja",
    "higate": "hi-ga-te",
    "higiene": "hi-gie-ne",
    "higiénica": "hi-gié-ni-ca",
    "higiénico": "hi-gié-ni-co",
    "higienista": "hi-gie-nis-ta",
    "higienización": "hi-gie-ni-za-ción",
    "higienizar": "hi-gie-ni-zar",
    "higo": "hi-go",
    "higrófilo": "hi-gró-fi-lo",
    "higrófugo": "hi-gró-fu-go",
    "higroma": "hi-gro-ma",
    "higrometría": "hi-gro-me-trí-a",
    "higrométrica": "hi-gro-mé-tri-ca",
    "higrométrico": "hi-gro-mé-tri-co",
    "higrómetro": "hi-gró-me-tro",
    "higroscopia": "hi-gros-co-pia",
    "higroscópica": "hi-gros-có-pi-ca",
    "higroscopicidad": "hi-gros-co-pi-ci-dad",
    "higroscópico": "hi-gros-có-pi-co",
    "higroscopio": "hi-gros-co-pio",
    "higuana": "hi-gua-na",
    "higuela": "hi-gue-la",
    "higüela": "hi-güe-la",
    "higuera": "hi-gue-ra",
    "higueral": "hi-gue-ral",
    "higuereta": "hi-gue-re-ta",
    "higuerilla": "hi-gue-ri-lla",
    "higüero": "hi-güe-ro",
    "higuerón": "hi-gue-rón",
    "higuerote": "hi-gue-ro-te",
    "higueruela": "hi-gue-rue-la",
    "higüeyana": "hi-güe-ya-na",
    "higüeyano": "hi-güe-ya-no",
    "higuí": "hi-guí",
    "higuillo": "hi-gui-llo",
    "hija": "hi-ja",
    "hijadalgo": "hi-ja-dal-go",
    "hijastra": "hi-jas-tra",
    "hijastro": "hi-jas-tro",
    "hijato": "hi-ja-to",
    "hijear": "hi-je-ar",
    "hijo": "hi-jo",
    "hijodalgo": "hi-jo-dal-go",
    "híjole": "hí-jo-le",
    "hijuela": "hi-jue-la",
    "hijuelar": "hi-jue-lar",
    "hijuelero": "hi-jue-le-ro",
    "hijuelo": "hi-jue-lo",
    "hila": "hi-la",
    "hilacha": "hi-la-cha",
    "hilachento": "hi-la-chen-to",
    "hilacho": "hi-la-cho",
    "hilachosa": "hi-la-cho-sa",
    "hilachoso": "hi-la-cho-so",
    "hilachudo": "hi-la-chu-do",
    "hilada": "hi-la-da",
    "hiladillo": "hi-la-di-llo",
    "hiladiza": "hi-la-di-za",
    "hiladizo": "hi-la-di-zo",
    "hilado": "hi-la-do",
    "hilador": "hi-la-dor",
    "hiladora": "hi-la-do-ra",
    "hilandera": "hi-lan-de-ra",
    "hilandería": "hi-lan-de-rí-a",
    "hilandero": "hi-lan-de-ro",
    "hilanza": "hi-lan-za",
    "hilar": "hi-lar",
    "hilaracha": "hi-la-ra-cha",
    "hilarante": "hi-la-ran-te",
    "hilaridad": "hi-la-ri-dad",
    "hilatura": "hi-la-tu-ra",
    "hilaza": "hi-la-za",
    "hilemorfismo": "hi-le-mor-fis-mo",
    "hilemorfista": "hi-le-mor-fis-ta",
    "hileña": "hi-le-ña",
    "hilera": "hi-le-ra",
    "hilero": "hi-le-ro",
    "hilio": "hi-lio",
    "hilo": "hi-lo",
    "hilomorfismo": "hi-lo-mor-fis-mo",
    "hilorio": "hi-lo-rio",
    "hilozoísmo": "hi-lo-zo-ís-mo",
    "hilván": "hil-ván",
    "hilvanado": "hil-va-na-do",
    "hilvanar": "hil-va-nar",
    "himen": "hi-men",
    "himeneo": "hi-me-ne-o",
    "himenóptero": "hi-me-nóp-te-ro",
    "himnario": "him-na-rio",
    "himno": "him-no",
    "himnodia": "him-no-dia",
    "himpar": "him-par",
    "himplar": "him-plar",
    "hincadura": "hin-ca-du-ra",
    "hincapié": "hin-ca-pié",
    "hincar": "hin-car",
    "hincha": "hin-cha",
    "hinchable": "hin-cha-ble",
    "hinchabolas": "hin-cha-bo-las",
    "hinchada": "hin-cha-da",
    "hinchadamente": "hin-cha-da-men-te",
    "hinchado": "hin-cha-do",
    "hinchahuevos": "hin-cha-hue-vos",
    "hinchamiento": "hin-cha-mien-to",
    "hinchapelotas": "hin-cha-pe-lo-tas",
    "hinchar": "hin-char",
    "hinchazón": "hin-cha-zón",
    "hinchimiento": "hin-chi-mien-to",
    "hinchir": "hin-chir",
    "hinco": "hin-co",
    "hincón": "hin-cón",
    "hindi": "hin-di",
    "hindú": "hin-dú",
    "hinduismo": "hin-duis-mo",
    "hinduista": "hin-duis-ta",
    "hiniesta": "hi-nies-ta",
    "hiniestra": "hi-nies-tra",
    "hiñir": "hi-ñir",
    "hinnible": "hin-ni-ble",
    "hinojal": "hi-no-jal",
    "hinojar": "hi-no-jar",
    "hinojo": "hi-no-jo",
    "hinojosa": "hi-no-jo-sa",
    "hinque": "hin-que",
    "hintero": "hin-te-ro",
    "hioglosa": "hio-glo-sa",
    "hiogloso": "hio-glo-so",
    "hioidea": "hioi-de-a",
    "hioideo": "hioi-de-o",
    "hioides": "hioi-des",
    "hipálage": "hi-pá-la-ge",
    "hipar": "hi-par",
    "hipear": "hi-pe-ar",
    "hiper": "hi-per",
    "híper": "hí-per",
    "hiperactiva": "hi-pe-rac-ti-va",
    "hiperactividad": "hi-pe-rac-ti-vi-dad",
    "hiperactivo": "hi-pe-rac-ti-vo",
    "hiperacusia": "hi-pe-ra-cu-sia",
    "hiperbárico": "hi-per-bá-ri-co",
    "hiperbática": "hi-per-bá-ti-ca",
    "hiperbático": "hi-per-bá-ti-co",
    "hipérbato": "hi-pér-ba-to",
    "hipérbaton": "hi-pér-ba-ton",
    "hipérbola": "hi-pér-bo-la",
    "hipérbole": "hi-pér-bo-le",
    "hiperbólica": "hi-per-bó-li-ca",
    "hiperbólicamente": "hi-per-bó-li-ca-men-te",
    "hiperbólico": "hi-per-bó-li-co",
    "hiperbolizar": "hi-per-bo-li-zar",
    "hiperboloide": "hi-per-bo-loi-de",
    "hiperbórea": "hi-per-bó-re-a",
    "hiperbóreo": "hi-per-bó-re-o",
    "hipercalcemia": "hi-per-cal-ce-mia",
    "hipercaracterización": "hi-per-ca-rac-te-ri-za-ción",
    "hipercinesia": "hi-per-ci-ne-sia",
    "hiperclorhidria": "hi-per-clo-rhi-dria",
    "hiperclorhídrica": "hi-per-clo-rhí-dri-ca",
    "hiperclorhídrico": "hi-per-clo-rhí-dri-co",
    "hipercolesterinemia": "hi-per-co-les-te-ri-ne-mia",
    "hipercolesterolemia": "hi-per-co-les-te-ro-le-mia",
    "hipercrisis": "hi-per-cri-sis",
    "hipercrítica": "hi-per-crí-ti-ca",
    "hipercrítico": "hi-per-crí-ti-co",
    "hiperdulía": "hi-per-du-lí-a",
    "hiperémesis": "hi-pe-ré-me-sis",
    "hiperemia": "hi-pe-re-mia",
    "hiperespacio": "hi-pe-res-pa-cio",
    "hiperestático": "hi-pe-res-tá-ti-co",
    "hiperestesia": "hi-pe-res-te-sia",
    "hiperestesiar": "hi-pe-res-te-siar",
    "hiperestésica": "hi-pe-res-té-si-ca",
    "hiperestésico": "hi-pe-res-té-si-co",
    "hiperfunción": "hi-per-fun-ción",
    "hiperglucemia": "hi-per-glu-ce-mia",
    "hiperglucémica": "hi-per-glu-cé-mi-ca",
    "hiperglucémico": "hi-per-glu-cé-mi-co",
    "hiperhidrosis": "hi-pe-rhi-dro-sis",
    "hipericínea": "hi-pe-ri-cí-ne-a",
    "hipericíneo": "hi-pe-ri-cí-ne-o",
    "hipérico": "hi-pé-ri-co",
    "hiperinflación": "hi-pe-rin-fla-ción",
    "hiperlipemia": "hi-per-li-pe-mia",
    "hiperlipidemia": "hi-per-li-pi-de-mia",
    "hipermenorrea": "hi-per-me-no-rre-a",
    "hipermercado": "hi-per-mer-ca-do",
    "hipermetamorfosis": "hi-per-me-ta-mor-fo-sis",
    "hipermetría": "hi-per-me-trí-a",
    "hipermétrope": "hi-per-mé-tro-pe",
    "hipermetropía": "hi-per-me-tro-pí-a",
    "hiperonimia": "hi-pe-ro-ni-mia",
    "hiperónimo": "hi-pe-ró-ni-mo",
    "hiperoxia": "hi-pe-ro-xia",
    "hiperparásito": "hi-per-pa-rá-si-to",
    "hiperplasia": "hi-per-pla-sia",
    "hiperrealismo": "hi-pe-rre-a-lis-mo",
    "hiperrealista": "hi-pe-rre-a-lis-ta",
    "hipersensibilidad": "hi-per-sen-si-bi-li-dad",
    "hipersensible": "hi-per-sen-si-ble",
    "hipersomnia": "hi-per-som-nia",
    "hipersónico": "hi-per-só-ni-co",
    "hiperstena": "hi-pers-te-na",
    "hipersteno": "hi-pers-te-no",
    "hipersustentación": "hi-per-sus-ten-ta-ción",
    "hipersustentador": "hi-per-sus-ten-ta-dor",
    "hipertensa": "hi-per-ten-sa",
    "hipertensión": "hi-per-ten-sión",
    "hipertensivo": "hi-per-ten-si-vo",
    "hipertenso": "hi-per-ten-so",
    "hipertermia": "hi-per-ter-mia",
    "hipertexto": "hi-per-tex-to",
    "hipertextual": "hi-per-tex-tual",
    "hipertiroidea": "hi-per-ti-roi-de-a",
    "hipertiroideo": "hi-per-ti-roi-de-o",
    "hipertiroidismo": "hi-per-ti-roi-dis-mo",
    "hipertonía": "hi-per-to-ní-a",
    "hipertónico": "hi-per-tó-ni-co",
    "hipertrofia": "hi-per-tro-fia",
    "hipertrofiar": "hi-per-tro-fiar",
    "hipertrofiarse": "hi-per-tro-fiar-se",
    "hipertrófica": "hi-per-tró-fi-ca",
    "hipertrófico": "hi-per-tró-fi-co",
    "hiperuricemia": "hi-pe-ru-ri-ce-mia",
    "hiperventilación": "hi-per-ven-ti-la-ción",
    "hiperventilar": "hi-per-ven-ti-lar",
    "hipervitaminosis": "hi-per-vi-ta-mi-no-sis",
    "hípetro": "hí-pe-tro",
    "hípica": "hí-pi-ca",
    "hípico": "hí-pi-co",
    "hipido": "hi-pi-do",
    "hipil": "hi-pil",
    "hipismo": "hi-pis-mo",
    "hipnal": "hip-nal",
    "hipnosis": "hip-no-sis",
    "hipnoterapia": "hip-no-te-ra-pia",
    "hipnótica": "hip-nó-ti-ca",
    "hipnótico": "hip-nó-ti-co",
    "hipnotismo": "hip-no-tis-mo",
    "hipnotización": "hip-no-ti-za-ción",
    "hipnotizador": "hip-no-ti-za-dor",
    "hipnotizadora": "hip-no-ti-za-do-ra",
    "hipnotizante": "hip-no-ti-zan-te",
    "hipnotizar": "hip-no-ti-zar",
    "hipo": "hi-po",
    "hipoacusia": "hi-po-a-cu-sia",
    "hipoalergénico": "hi-po-a-ler-gé-ni-co",
    "hipoalérgico": "hi-po-a-lér-gi-co",
    "hipocalcemia": "hi-po-cal-ce-mia",
    "hipocalórico": "hi-po-ca-ló-ri-co",
    "hipocampo": "hi-po-cam-po",
    "hipocastanácea": "hi-po-cas-ta-ná-ce-a",
    "hipocastanáceo": "hi-po-cas-ta-ná-ce-o",
    "hipocastánea": "hi-po-cas-tá-ne-a",
    "hipocastáneo": "hi-po-cas-tá-ne-o",
    "hipocausto": "hi-po-caus-to",
    "hipocentauro": "hi-po-cen-tau-ro",
    "hipocentro": "hi-po-cen-tro",
    "hipocicloide": "hi-po-ci-cloi-de",
    "hipocinesia": "hi-po-ci-ne-sia",
    "hipocinético": "hi-po-ci-né-ti-co",
    "hipocístide": "hi-po-cís-ti-de",
    "hipoclorhidria": "hi-po-clo-rhi-dria",
    "hipoclorhídrica": "hi-po-clo-rhí-dri-ca",
    "hipoclorhídrico": "hi-po-clo-rhí-dri-co",
    "hipocondría": "hi-po-con-drí-a",
    "hipocondríaca": "hi-po-con-drí-a-ca",
    "hipocondriaca": "hi-po-con-dria-ca",
    "hipocondríaco": "hi-po-con-drí-a-co",
    "hipocondriaco": "hi-po-con-dria-co",
    "hipocóndrica": "hi-po-cón-dri-ca",
    "hipocóndrico": "hi-po-cón-dri-co",
    "hipocondrio": "hi-po-con-drio",
    "hipocorística": "hi-po-co-rís-ti-ca",
    "hipocorístico": "hi-po-co-rís-ti-co",
    "hipocrás": "hi-po-crás",
    "hipocrática": "hi-po-crá-ti-ca",
    "hipocrático": "hi-po-crá-ti-co",
    "hipocratismo": "hi-po-cra-tis-mo",
    "hipocrénides": "hi-po-cré-ni-des",
    "hipocresía": "hi-po-cre-sí-a",
    "hipócrita": "hi-pó-cri-ta",
    "hipócritamente": "hi-pó-cri-ta-men-te",
    "hipodérmica": "hi-po-dér-mi-ca",
    "hipodérmico": "hi-po-dér-mi-co",
    "hipodermis": "hi-po-der-mis",
    "hipódromo": "hi-pó-dro-mo",
    "hipófisis": "hi-pó-fi-sis",
    "hipofosfito": "hi-po-fos-fi-to",
    "hipofosforoso": "hi-po-fos-fo-ro-so",
    "hipofunción": "hi-po-fun-ción",
    "hipogástrica": "hi-po-gás-tri-ca",
    "hipogástrico": "hi-po-gás-tri-co",
    "hipogastrio": "hi-po-gas-trio",
    "hipogénica": "hi-po-gé-ni-ca",
    "hipogénico": "hi-po-gé-ni-co",
    "hipogeo": "hi-po-ge-o",
    "hipoglosa": "hi-po-glo-sa",
    "hipogloso": "hi-po-glo-so",
    "hipoglucemia": "hi-po-glu-ce-mia",
    "hipoglucémica": "hi-po-glu-cé-mi-ca",
    "hipoglucémico": "hi-po-glu-cé-mi-co",
    "hipogonadismo": "hi-po-go-na-dis-mo",
    "hipogrifo": "hi-po-gri-fo",
    "hipóloga": "hi-pó-lo-ga",
    "hipología": "hi-po-lo-gí-a",
    "hipólogo": "hi-pó-lo-go",
    "hipómanes": "hi-pó-ma-nes",
    "hipomanía": "hi-po-ma-ní-a",
    "hipomaníaca": "hi-po-ma-ní-a-ca",
    "hipomaníaco": "hi-po-ma-ní-a-co",
    "hipomenorrea": "hi-po-me-no-rre-a",
    "hipomoclio": "hi-po-mo-clio",
    "hipomoclion": "hi-po-mo-clion",
    "hiponimia": "hi-po-ni-mia",
    "hipónimo": "hi-pó-ni-mo",
    "hipopótamo": "hi-po-pó-ta-mo",
    "hiposa": "hi-po-sa",
    "hiposo": "hi-po-so",
    "hipospadias": "hi-pos-pa-dias",
    "hipóstasis": "hi-pós-ta-sis",
    "hipostática": "hi-pos-tá-ti-ca",
    "hipostáticamente": "hi-pos-tá-ti-ca-men-te",
    "hipostático": "hi-pos-tá-ti-co",
    "hipóstilo": "hi-pós-ti-lo",
    "hiposulfito": "hi-po-sul-fi-to",
    "hiposulfuroso": "hi-po-sul-fu-ro-so",
    "hipotáctico": "hi-po-tác-ti-co",
    "hipotálamo": "hi-po-tá-la-mo",
    "hipotaxis": "hi-po-ta-xis",
    "hipoteca": "hi-po-te-ca",
    "hipotecable": "hi-po-te-ca-ble",
    "hipotecar": "hi-po-te-car",
    "hipotecaria": "hi-po-te-ca-ria",
    "hipotecario": "hi-po-te-ca-rio",
    "hipotecnia": "hi-po-tec-nia",
    "hipotensa": "hi-po-ten-sa",
    "hipotensión": "hi-po-ten-sión",
    "hipotenso": "hi-po-ten-so",
    "hipotenusa": "hi-po-te-nu-sa",
    "hipotermia": "hi-po-ter-mia",
    "hipotérmico": "hi-po-tér-mi-co",
    "hipótesi": "hi-pó-te-si",
    "hipótesis": "hi-pó-te-sis",
    "hipotética": "hi-po-té-ti-ca",
    "hipotéticamente": "hi-po-té-ti-ca-men-te",
    "hipotético": "hi-po-té-ti-co",
    "hipotiposis": "hi-po-ti-po-sis",
    "hipotiroidea": "hi-po-ti-roi-de-a",
    "hipotiroideo": "hi-po-ti-roi-de-o",
    "hipotiroidismo": "hi-po-ti-roi-dis-mo",
    "hipotonía": "hi-po-to-ní-a",
    "hipotónica": "hi-po-tó-ni-ca",
    "hipotónico": "hi-po-tó-ni-co",
    "hipovitaminosis": "hi-po-vi-ta-mi-no-sis",
    "hipovolemia": "hi-po-vo-le-mia",
    "hipovolémico": "hi-po-vo-lé-mi-co",
    "hipoxia": "hi-po-xia",
    "hippioso": "hip-pio-so",
    "hipsometría": "hip-so-me-trí-a",
    "hipsométrica": "hip-so-mé-tri-ca",
    "hipsométrico": "hip-so-mé-tri-co",
    "hipsómetro": "hip-só-me-tro",
    "hiracoideo": "hi-ra-coi-de-o",
    "hircana": "hir-ca-na",
    "hircano": "hir-ca-no",
    "hirco": "hir-co",
    "hircocervo": "hir-co-cer-vo",
    "hiriente": "hi-rien-te",
    "hirma": "hir-ma",
    "hirmar": "hir-mar",
    "hirsuta": "hir-su-ta",
    "hirsutismo": "hir-su-tis-mo",
    "hirsuto": "hir-su-to",
    "hirudíneo": "hi-ru-dí-ne-o",
    "hirundinaria": "hi-run-di-na-ria",
    "hirviente": "hir-vien-te",
    "hisca": "his-ca",
    "hiscal": "his-cal",
    "hisopada": "hi-so-pa-da",
    "hisopadura": "hi-so-pa-du-ra",
    "hisopar": "hi-so-par",
    "hisopazo": "hi-so-pa-zo",
    "hisopear": "hi-so-pe-ar",
    "hisopillo": "hi-so-pi-llo",
    "hisopo": "hi-so-po",
    "hispalense": "his-pa-len-se",
    "hispalia": "his-pa-lia",
    "hispalio": "his-pa-lio",
    "hispana": "his-pa-na",
    "hispanense": "his-pa-nen-se",
    "hispánica": "his-pá-ni-ca",
    "hispánico": "his-pá-ni-co",
    "hispanidad": "his-pa-ni-dad",
    "hispanismo": "his-pa-nis-mo",
    "hispanista": "his-pa-nis-ta",
    "hispanización": "his-pa-ni-za-ción",
    "hispanizante": "his-pa-ni-zan-te",
    "hispanizar": "his-pa-ni-zar",
    "hispano": "his-pa-no",
    "hispanoamericana": "his-pa-no-a-me-ri-ca-na",
    "hispanoamericanismo": "his-pa-no-a-me-ri-ca-nis-mo",
    "hispanoamericano": "his-pa-no-a-me-ri-ca-no",
    "hispanoárabe": "his-pa-no-á-ra-be",
    "hispanófila": "his-pa-nó-fi-la",
    "hispanofilia": "his-pa-no-fi-lia",
    "hispanófilo": "his-pa-nó-fi-lo",
    "hispanófoba": "his-pa-nó-fo-ba",
    "hispanofobia": "his-pa-no-fo-bia",
    "hispanófobo": "his-pa-nó-fo-bo",
    "hispanofrancés": "his-pa-no-fran-cés",
    "hispanohablante": "his-pa-no-ha-blan-te",
    "hispanojudío": "his-pa-no-ju-dí-o",
    "hispanomusulmán": "his-pa-no-mu-sul-mán",
    "hispanomusulmana": "his-pa-no-mu-sul-ma-na",
    "hispanoparlante": "his-pa-no-par-lan-te",
    "hispanorromana": "his-pa-no-rro-ma-na",
    "hispanorromano": "his-pa-no-rro-ma-no",
    "híspida": "hís-pi-da",
    "híspido": "hís-pi-do",
    "hispir": "his-pir",
    "histamina": "his-ta-mi-na",
    "histamínico": "his-ta-mí-ni-co",
    "histeralgia": "his-te-ral-gia",
    "histerectomía": "his-te-rec-to-mí-a",
    "histéresis": "his-té-re-sis",
    "histeria": "his-te-ria",
    "histérica": "his-té-ri-ca",
    "histérico": "his-té-ri-co",
    "histerismo": "his-te-ris-mo",
    "histerizar": "his-te-ri-zar",
    "histerología": "his-te-ro-lo-gí-a",
    "hístico": "hís-ti-co",
    "histocompatibilidad": "his-to-com-pa-ti-bi-li-dad",
    "histograma": "his-to-gra-ma",
    "históloga": "his-tó-lo-ga",
    "histología": "his-to-lo-gí-a",
    "histológica": "his-to-ló-gi-ca",
    "histológico": "his-to-ló-gi-co",
    "histólogo": "his-tó-lo-go",
    "histopatología": "his-to-pa-to-lo-gí-a",
    "histopatológico": "his-to-pa-to-ló-gi-co",
    "historia": "his-to-ria",
    "historiable": "his-to-ria-ble",
    "historiada": "his-to-ria-da",
    "historiado": "his-to-ria-do",
    "historiador": "his-to-ria-dor",
    "historiadora": "his-to-ria-do-ra",
    "historial": "his-to-rial",
    "historialmente": "his-to-rial-men-te",
    "historiar": "his-to-riar",
    "histórica": "his-tó-ri-ca",
    "históricamente": "his-tó-ri-ca-men-te",
    "historicidad": "his-to-ri-ci-dad",
    "historicismo": "his-to-ri-cis-mo",
    "historicista": "his-to-ri-cis-ta",
    "histórico": "his-tó-ri-co",
    "historieta": "his-to-rie-ta",
    "historietista": "his-to-rie-tis-ta",
    "historiógrafa": "his-to-rió-gra-fa",
    "historiografía": "his-to-rio-gra-fí-a",
    "historiográfica": "his-to-rio-grá-fi-ca",
    "historiográfico": "his-to-rio-grá-fi-co",
    "historiógrafo": "his-to-rió-gra-fo",
    "historiología": "his-to-rio-lo-gí-a",
    "historismo": "his-to-ris-mo",
    "historizar": "his-to-ri-zar",
    "histrión": "his-trión",
    "histriónica": "his-trió-ni-ca",
    "histriónico": "his-trió-ni-co",
    "histrionisa": "his-trio-ni-sa",
    "histrionismo": "his-trio-nis-mo",
    "hita": "hi-ta",
    "hitación": "hi-ta-ción",
    "hitamente": "hi-ta-men-te",
    "hitar": "hi-tar",
    "hitita": "hi-ti-ta",
    "hitleriana": "hi-tle-ria-na",
    "hitleriano": "hi-tle-ria-no",
    "hitlerismo": "hi-tle-ris-mo",
    "hito": "hi-to",
    "hitón": "hi-tón",
    "hoatzin": "ho-at-zin",
    "hobacha": "ho-ba-cha",
    "hobacho": "ho-ba-cho",
    "hobachón": "ho-ba-chón",
    "hobachona": "ho-ba-cho-na",
    "hobachonería": "ho-ba-cho-ne-rí-a",
    "hobo": "ho-bo",
    "hoce": "ho-ce",
    "hocera": "ho-ce-ra",
    "hocero": "ho-ce-ro",
    "hocete": "ho-ce-te",
    "hochío": "ho-chí-o",
    "hocicada": "ho-ci-ca-da",
    "hocicar": "ho-ci-car",
    "hocico": "ho-ci-co",
    "hocicón": "ho-ci-cón",
    "hocicona": "ho-ci-co-na",
    "hociconear": "ho-ci-co-ne-ar",
    "hocicuda": "ho-ci-cu-da",
    "hocicudo": "ho-ci-cu-do",
    "hocino": "ho-ci-no",
    "hociquear": "ho-ci-que-ar",
    "hockey": "hoc-key",
    "hoco": "ho-co",
    "hodierno": "ho-dier-no",
    "hodómetro": "ho-dó-me-tro",
    "hogañazo": "ho-ga-ña-zo",
    "hogaño": "ho-ga-ño",
    "hogar": "ho-gar",
    "hogareña": "ho-ga-re-ña",
    "hogareño": "ho-ga-re-ño",
    "hogaril": "ho-ga-ril",
    "hogaza": "ho-ga-za",
    "hogo": "ho-go",
    "hoguera": "ho-gue-ra",
    "hoja": "ho-ja",
    "hojalata": "ho-ja-la-ta",
    "hojalatear": "ho-ja-la-te-ar",
    "hojalatería": "ho-ja-la-te-rí-a",
    "hojalatero": "ho-ja-la-te-ro",
    "hojalde": "ho-jal-de",
    "hojaldra": "ho-jal-dra",
    "hojaldrada": "ho-jal-dra-da",
    "hojaldrado": "ho-jal-dra-do",
    "hojaldrar": "ho-jal-drar",
    "hojaldre": "ho-jal-dre",
    "hojaldrera": "ho-jal-dre-ra",
    "hojaldrero": "ho-jal-dre-ro",
    "hojaldrista": "ho-jal-dris-ta",
    "hojarasca": "ho-ja-ras-ca",
    "hojasanta": "ho-ja-san-ta",
    "hojear": "ho-je-ar",
    "hojecer": "ho-je-cer",
    "hojilla": "ho-ji-lla",
    "hojosa": "ho-jo-sa",
    "hojoso": "ho-jo-so",
    "hojuda": "ho-ju-da",
    "hojudo": "ho-ju-do",
    "hojuela": "ho-jue-la",
    "hola": "ho-la",
    "holán": "ho-lán",
    "holanda": "ho-lan-da",
    "holandés": "ho-lan-dés",
    "holandesa": "ho-lan-de-sa",
    "holandeta": "ho-lan-de-ta",
    "holandilla": "ho-lan-di-lla",
    "holco": "hol-co",
    "holding": "hol-ding",
    "holear": "ho-le-ar",
    "holgachón": "hol-ga-chón",
    "holgachona": "hol-ga-cho-na",
    "holgada": "hol-ga-da",
    "holgadamente": "hol-ga-da-men-te",
    "holgadero": "hol-ga-de-ro",
    "holgado": "hol-ga-do",
    "holganza": "hol-gan-za",
    "holgar": "hol-gar",
    "holgazán": "hol-ga-zán",
    "holgazana": "hol-ga-za-na",
    "holgazanear": "hol-ga-za-ne-ar",
    "holgazanería": "hol-ga-za-ne-rí-a",
    "holgón": "hol-gón",
    "holgona": "hol-go-na",
    "holgorio": "hol-go-rio",
    "holgueta": "hol-gue-ta",
    "holguinera": "hol-gui-ne-ra",
    "holguinero": "hol-gui-ne-ro",
    "holgura": "hol-gu-ra",
    "holismo": "ho-lis-mo",
    "holístico": "ho-lís-ti-co",
    "holladera": "ho-lla-de-ra",
    "holladero": "ho-lla-de-ro",
    "holladura": "ho-lla-du-ra",
    "hollar": "ho-llar",
    "holleca": "ho-lle-ca",
    "holleja": "ho-lle-ja",
    "hollejo": "ho-lle-jo",
    "hollejuda": "ho-lle-ju-da",
    "hollejudo": "ho-lle-ju-do",
    "hollín": "ho-llín",
    "hollinienta": "ho-lli-nien-ta",
    "holliniento": "ho-lli-nien-to",
    "holmio": "hol-mio",
    "holocausto": "ho-lo-caus-to",
    "holoceno": "ho-lo-ce-no",
    "holoédrico": "ho-lo-é-dri-co",
    "holoedro": "ho-lo-e-dro",
    "hológrafa": "ho-ló-gra-fa",
    "holografía": "ho-lo-gra-fí-a",
    "holográfico": "ho-lo-grá-fi-co",
    "hológrafo": "ho-ló-gra-fo",
    "holograma": "ho-lo-gra-ma",
    "holómetro": "ho-ló-me-tro",
    "holosérica": "ho-lo-sé-ri-ca",
    "holosérico": "ho-lo-sé-ri-co",
    "holostérico": "ho-los-té-ri-co",
    "holoturia": "ho-lo-tu-ria",
    "holotúrido": "ho-lo-tú-ri-do",
    "holoturoideo": "ho-lo-tu-roi-de-o",
    "homarrache": "ho-ma-rra-che",
    "hombracho": "hom-bra-cho",
    "hombrada": "hom-bra-da",
    "hombradía": "hom-bra-dí-a",
    "hombre": "hom-bre",
    "hombrear": "hom-bre-ar",
    "hombrecillo": "hom-bre-ci-llo",
    "hombredad": "hom-bre-dad",
    "hombrera": "hom-bre-ra",
    "hombretón": "hom-bre-tón",
    "hombría": "hom-brí-a",
    "hombrillo": "hom-bri-llo",
    "hombro": "hom-bro",
    "hombrón": "hom-brón",
    "hombruna": "hom-bru-na",
    "hombruno": "hom-bru-no",
    "home": "ho-me",
    "homecillo": "ho-me-ci-llo",
    "homeless": "ho-me-less",
    "homenaje": "ho-me-na-je",
    "homenajeada": "ho-me-na-je-a-da",
    "homenajeado": "ho-me-na-je-a-do",
    "homenajear": "ho-me-na-je-ar",
    "homeópata": "ho-me-ó-pa-ta",
    "homeopatía": "ho-me-o-pa-tí-a",
    "homeopática": "ho-me-o-pá-ti-ca",
    "homeopáticamente": "ho-me-o-pá-ti-ca-men-te",
    "homeopático": "ho-me-o-pá-ti-co",
    "homeostasia": "ho-me-os-ta-sia",
    "homeostasis": "ho-me-os-ta-sis",
    "homeostático": "ho-me-os-tá-ti-co",
    "homeoterma": "ho-me-o-ter-ma",
    "homeotermia": "ho-me-o-ter-mia",
    "homeotérmico": "ho-me-o-tér-mi-co",
    "homeotermo": "ho-me-o-ter-mo",
    "homérica": "ho-mé-ri-ca",
    "homérico": "ho-mé-ri-co",
    "homero": "ho-me-ro",
    "homiciano": "ho-mi-cia-no",
    "homiciar": "ho-mi-ciar",
    "homiciarse": "ho-mi-ciar-se",
    "homicida": "ho-mi-ci-da",
    "homicidio": "ho-mi-ci-dio",
    "homiciero": "ho-mi-cie-ro",
    "homicillo": "ho-mi-ci-llo",
    "homilía": "ho-mi-lí-a",
    "homiliario": "ho-mi-lia-rio",
    "hominal": "ho-mi-nal",
    "hominicaco": "ho-mi-ni-ca-co",
    "homínido": "ho-mí-ni-do",
    "homo": "ho-mo",
    "homocerca": "ho-mo-cer-ca",
    "homocerco": "ho-mo-cer-co",
    "homocigótico": "ho-mo-ci-gó-ti-co",
    "homocigoto": "ho-mo-ci-go-to",
    "homoclamídeo": "ho-mo-cla-mí-de-o",
    "homodonto": "ho-mo-don-to",
    "homofobia": "ho-mo-fo-bia",
    "homofóbico": "ho-mo-fó-bi-co",
    "homófona": "ho-mó-fo-na",
    "homofonía": "ho-mo-fo-ní-a",
    "homofónico": "ho-mo-fó-ni-co",
    "homófono": "ho-mó-fo-no",
    "homogénea": "ho-mo-gé-ne-a",
    "homogéneamente": "ho-mo-gé-ne-a-men-te",
    "homogeneidad": "ho-mo-ge-nei-dad",
    "homogeneización": "ho-mo-ge-nei-za-ción",
    "homogeneizador": "ho-mo-ge-nei-za-dor",
    "homogeneizar": "ho-mo-ge-nei-zar",
    "homogéneo": "ho-mo-gé-ne-o",
    "homógrafa": "ho-mó-gra-fa",
    "homografía": "ho-mo-gra-fí-a",
    "homógrafo": "ho-mó-gra-fo",
    "homóloga": "ho-mó-lo-ga",
    "homologable": "ho-mo-lo-ga-ble",
    "homologación": "ho-mo-lo-ga-ción",
    "homologar": "ho-mo-lo-gar",
    "homología": "ho-mo-lo-gí-a",
    "homólogo": "ho-mó-lo-go",
    "homomorfismo": "ho-mo-mor-fis-mo",
    "homónima": "ho-mó-ni-ma",
    "homonimia": "ho-mo-ni-mia",
    "homónimo": "ho-mó-ni-mo",
    "homoplastia": "ho-mo-plas-tia",
    "homóptero": "ho-móp-te-ro",
    "homosexual": "ho-mo-se-xual",
    "homosexualidad": "ho-mo-se-xua-li-dad",
    "homosexualismo": "ho-mo-se-xua-lis-mo",
    "homosfera": "ho-mos-fe-ra",
    "homozigótico": "ho-mo-zi-gó-ti-co",
    "homozigoto": "ho-mo-zi-go-to",
    "homúnculo": "ho-mún-cu-lo",
    "honcejo": "hon-ce-jo",
    "honda": "hon-da",
    "hondable": "hon-da-ble",
    "hondada": "hon-da-da",
    "hondamente": "hon-da-men-te",
    "hondarras": "hon-da-rras",
    "hondazo": "hon-da-zo",
    "hondear": "hon-de-ar",
    "hondero": "hon-de-ro",
    "hondijo": "hon-di-jo",
    "hondilla": "hon-di-lla",
    "hondillos": "hon-di-llos",
    "hondo": "hon-do",
    "hondón": "hon-dón",
    "hondonada": "hon-do-na-da",
    "hondonal": "hon-do-nal",
    "hondura": "hon-du-ra",
    "hondureña": "hon-du-re-ña",
    "hondureñismo": "hon-du-re-ñis-mo",
    "hondureñizar": "hon-du-re-ñi-zar",
    "hondureño": "hon-du-re-ño",
    "hondurense": "hon-du-ren-se",
    "honesta": "ho-nes-ta",
    "honestad": "ho-nes-tad",
    "honestamente": "ho-nes-ta-men-te",
    "honestar": "ho-nes-tar",
    "honestidad": "ho-nes-ti-dad",
    "honesto": "ho-nes-to",
    "hongarina": "hon-ga-ri-na",
    "hongkonés": "hong-ko-nés",
    "hongkonesa": "hong-ko-ne-sa",
    "hongo": "hon-go",
    "hongosa": "hon-go-sa",
    "hongoso": "hon-go-so",
    "honkonguense": "hon-kon-guen-se",
    "honor": "ho-nor",
    "honorabilidad": "ho-no-ra-bi-li-dad",
    "honorable": "ho-no-ra-ble",
    "honorablemente": "ho-no-ra-ble-men-te",
    "honoración": "ho-no-ra-ción",
    "honorar": "ho-no-rar",
    "honoraria": "ho-no-ra-ria",
    "honorario": "ho-no-ra-rio",
    "honorífica": "ho-no-rí-fi-ca",
    "honorificación": "ho-no-ri-fi-ca-ción",
    "honorificadamente": "ho-no-ri-fi-ca-da-men-te",
    "honoríficamente": "ho-no-rí-fi-ca-men-te",
    "honorificar": "ho-no-ri-fi-car",
    "honorificencia": "ho-no-ri-fi-cen-cia",
    "honorífico": "ho-no-rí-fi-co",
    "honorosa": "ho-no-ro-sa",
    "honoroso": "ho-no-ro-so",
    "honra": "hon-ra",
    "honrable": "hon-ra-ble",
    "honrada": "hon-ra-da",
    "honradamente": "hon-ra-da-men-te",
    "honradera": "hon-ra-de-ra",
    "honradero": "hon-ra-de-ro",
    "honradez": "hon-ra-dez",
    "honrado": "hon-ra-do",
    "honrador": "hon-ra-dor",
    "honradora": "hon-ra-do-ra",
    "honramiento": "hon-ra-mien-to",
    "honrar": "hon-rar",
    "honrilla": "hon-ri-lla",
    "honrosa": "hon-ro-sa",
    "honrosamente": "hon-ro-sa-men-te",
    "honroso": "hon-ro-so",
    "hontana": "hon-ta-na",
    "hontanal": "hon-ta-nal",
    "hontanar": "hon-ta-nar",
    "hopa": "ho-pa",
    "hopalanda": "ho-pa-lan-da",
    "hopar": "ho-par",
    "hopear": "ho-pe-ar",
    "hopeo": "ho-pe-o",
    "hoplita": "ho-pli-ta",
    "hoploteca": "ho-plo-te-ca",
    "hopo": "ho-po",
    "hoque": "ho-que",
    "hora": "ho-ra",
    "horacar": "ho-ra-car",
    "horaciana": "ho-ra-cia-na",
    "horaciano": "ho-ra-cia-no",
    "horaco": "ho-ra-co",
    "horadable": "ho-ra-da-ble",
    "horadación": "ho-ra-da-ción",
    "horadado": "ho-ra-da-do",
    "horadador": "ho-ra-da-dor",
    "horadadora": "ho-ra-da-do-ra",
    "horadar": "ho-ra-dar",
    "horado": "ho-ra-do",
    "horambre": "ho-ram-bre",
    "horaria": "ho-ra-ria",
    "horario": "ho-ra-rio",
    "horca": "hor-ca",
    "horcada": "hor-ca-da",
    "horcado": "hor-ca-do",
    "horcadura": "hor-ca-du-ra",
    "horcajadas": "hor-ca-ja-das",
    "horcajadillas": "hor-ca-ja-di-llas",
    "horcajadura": "hor-ca-ja-du-ra",
    "horcajo": "hor-ca-jo",
    "horcar": "hor-car",
    "horcate": "hor-ca-te",
    "horchata": "hor-cha-ta",
    "horchatera": "hor-cha-te-ra",
    "horchatería": "hor-cha-te-rí-a",
    "horchatero": "hor-cha-te-ro",
    "horco": "hor-co",
    "horcón": "hor-cón",
    "horconada": "hor-co-na-da",
    "horconadura": "hor-co-na-du-ra",
    "horda": "hor-da",
    "hordiate": "hor-dia-te",
    "hordio": "hor-dio",
    "horita": "ho-ri-ta",
    "horitita": "ho-ri-ti-ta",
    "horizontal": "ho-ri-zon-tal",
    "horizontalidad": "ho-ri-zon-ta-li-dad",
    "horizontalmente": "ho-ri-zon-tal-men-te",
    "horizonte": "ho-ri-zon-te",
    "horma": "hor-ma",
    "hormadoras": "hor-ma-do-ras",
    "hormaza": "hor-ma-za",
    "hormazo": "hor-ma-zo",
    "hormento": "hor-men-to",
    "hormero": "hor-me-ro",
    "hormiga": "hor-mi-ga",
    "hormigante": "hor-mi-gan-te",
    "hormigo": "hor-mi-go",
    "hormigón": "hor-mi-gón",
    "hormigonar": "hor-mi-go-nar",
    "hormigonera": "hor-mi-go-ne-ra",
    "hormigosa": "hor-mi-go-sa",
    "hormigoso": "hor-mi-go-so",
    "hormigueamiento": "hor-mi-gue-a-mien-to",
    "hormiguear": "hor-mi-gue-ar",
    "hormigueo": "hor-mi-gue-o",
    "hormiguera": "hor-mi-gue-ra",
    "hormiguero": "hor-mi-gue-ro",
    "hormiguesca": "hor-mi-gues-ca",
    "hormiguesco": "hor-mi-gues-co",
    "hormiguilla": "hor-mi-gui-lla",
    "hormiguillar": "hor-mi-gui-llar",
    "hormiguillo": "hor-mi-gui-llo",
    "hormiguita": "hor-mi-gui-ta",
    "hormilla": "hor-mi-lla",
    "hormona": "hor-mo-na",
    "hormonal": "hor-mo-nal",
    "hormonar": "hor-mo-nar",
    "hormonoterapia": "hor-mo-no-te-ra-pia",
    "hornabeque": "hor-na-be-que",
    "hornablenda": "hor-na-blen-da",
    "hornacero": "hor-na-ce-ro",
    "hornacho": "hor-na-cho",
    "hornachuela": "hor-na-chue-la",
    "hornacina": "hor-na-ci-na",
    "hornada": "hor-na-da",
    "hornado": "hor-na-do",
    "hornaguear": "hor-na-gue-ar",
    "hornagueo": "hor-na-gue-o",
    "hornaguera": "hor-na-gue-ra",
    "hornaguero": "hor-na-gue-ro",
    "hornalla": "hor-na-lla",
    "hornar": "hor-nar",
    "hornaza": "hor-na-za",
    "hornazo": "hor-na-zo",
    "hornblenda": "horn-blen-da",
    "horneada": "hor-ne-a-da",
    "horneado": "hor-ne-a-do",
    "hornear": "hor-ne-ar",
    "hornecina": "hor-ne-ci-na",
    "hornecino": "hor-ne-ci-no",
    "hornera": "hor-ne-ra",
    "hornería": "hor-ne-rí-a",
    "hornero": "hor-ne-ro",
    "hornía": "hor-ní-a",
    "hornija": "hor-ni-ja",
    "hornijera": "hor-ni-je-ra",
    "hornijero": "hor-ni-je-ro",
    "hornilla": "hor-ni-lla",
    "hornillo": "hor-ni-llo",
    "horno": "hor-no",
    "horópter": "ho-róp-ter",
    "horoptérica": "ho-rop-té-ri-ca",
    "horoptérico": "ho-rop-té-ri-co",
    "horóptero": "ho-róp-te-ro",
    "horóscopo": "ho-rós-co-po",
    "horqueta": "hor-que-ta",
    "horquetear": "hor-que-te-ar",
    "horquetilla": "hor-que-ti-lla",
    "horquilla": "hor-qui-lla",
    "horquillada": "hor-qui-lla-da",
    "horquillado": "hor-qui-lla-do",
    "horquillar": "hor-qui-llar",
    "horra": "ho-rra",
    "horrar": "ho-rrar",
    "horre": "ho-rre",
    "horrenda": "ho-rren-da",
    "horrendamente": "ho-rren-da-men-te",
    "horrendo": "ho-rren-do",
    "hórreo": "hó-rre-o",
    "horrero": "ho-rre-ro",
    "horribilidad": "ho-rri-bi-li-dad",
    "horribilísimo": "ho-rri-bi-lí-si-mo",
    "horrible": "ho-rri-ble",
    "horriblemente": "ho-rri-ble-men-te",
    "hórrida": "hó-rri-da",
    "horridez": "ho-rri-dez",
    "hórrido": "hó-rri-do",
    "horrífica": "ho-rrí-fi-ca",
    "horrífico": "ho-rrí-fi-co",
    "horripilación": "ho-rri-pi-la-ción",
    "horripilante": "ho-rri-pi-lan-te",
    "horripilar": "ho-rri-pi-lar",
    "horripilativa": "ho-rri-pi-la-ti-va",
    "horripilativo": "ho-rri-pi-la-ti-vo",
    "horrísona": "ho-rrí-so-na",
    "horrisonante": "ho-rri-so-nan-te",
    "horrísono": "ho-rrí-so-no",
    "horro": "ho-rro",
    "horror": "ho-rror",
    "horrorizar": "ho-rro-ri-zar",
    "horrorosa": "ho-rro-ro-sa",
    "horrorosamente": "ho-rro-ro-sa-men-te",
    "horroroso": "ho-rro-ro-so",
    "horrura": "ho-rru-ra",
    "hortal": "hor-tal",
    "hortaliza": "hor-ta-li-za",
    "hortatoria": "hor-ta-to-ria",
    "hortatorio": "hor-ta-to-rio",
    "hortelana": "hor-te-la-na",
    "hortelano": "hor-te-la-no",
    "hortense": "hor-ten-se",
    "hortensia": "hor-ten-sia",
    "hortera": "hor-te-ra",
    "horterada": "hor-te-ra-da",
    "hortícola": "hor-tí-co-la",
    "horticultor": "hor-ti-cul-tor",
    "horticultora": "hor-ti-cul-to-ra",
    "horticultura": "hor-ti-cul-tu-ra",
    "hortofrutícola": "hor-to-fru-tí-co-la",
    "hortofruticultura": "hor-to-fru-ti-cul-tu-ra",
    "hortolano": "hor-to-la-no",
    "horuelo": "ho-rue-lo",
    "hosanna": "ho-san-na",
    "hosca": "hos-ca",
    "hosco": "hos-co",
    "hoscosa": "hos-co-sa",
    "hoscoso": "hos-co-so",
    "hospa": "hos-pa",
    "hospedable": "hos-pe-da-ble",
    "hospedador": "hos-pe-da-dor",
    "hospedadora": "hos-pe-da-do-ra",
    "hospedaje": "hos-pe-da-je",
    "hospedamiento": "hos-pe-da-mien-to",
    "hospedante": "hos-pe-dan-te",
    "hospedar": "hos-pe-dar",
    "hospedera": "hos-pe-de-ra",
    "hospedería": "hos-pe-de-rí-a",
    "hospedero": "hos-pe-de-ro",
    "hospiciana": "hos-pi-cia-na",
    "hospiciano": "hos-pi-cia-no",
    "hospicio": "hos-pi-cio",
    "hospital": "hos-pi-tal",
    "hospitalaria": "hos-pi-ta-la-ria",
    "hospitalariamente": "hos-pi-ta-la-ria-men-te",
    "hospitalario": "hos-pi-ta-la-rio",
    "hospitalera": "hos-pi-ta-le-ra",
    "hospitalero": "hos-pi-ta-le-ro",
    "hospitalicia": "hos-pi-ta-li-cia",
    "hospitalicio": "hos-pi-ta-li-cio",
    "hospitalidad": "hos-pi-ta-li-dad",
    "hospitalización": "hos-pi-ta-li-za-ción",
    "hospitalizar": "hos-pi-ta-li-zar",
    "hospitalmente": "hos-pi-tal-men-te",
    "hospodar": "hos-po-dar",
    "hosquedad": "hos-que-dad",
    "hosta": "hos-ta",
    "hostaje": "hos-ta-je",
    "hostal": "hos-tal",
    "hostalero": "hos-ta-le-ro",
    "hoste": "hos-te",
    "hostelaje": "hos-te-la-je",
    "hostelera": "hos-te-le-ra",
    "hostelería": "hos-te-le-rí-a",
    "hostelero": "hos-te-le-ro",
    "hosterero": "hos-te-re-ro",
    "hostería": "hos-te-rí-a",
    "hostia": "hos-tia",
    "hostiar": "hos-tiar",
    "hostiario": "hos-tia-rio",
    "hostiera": "hos-tie-ra",
    "hostiero": "hos-tie-ro",
    "hostigador": "hos-ti-ga-dor",
    "hostigadora": "hos-ti-ga-do-ra",
    "hostigamiento": "hos-ti-ga-mien-to",
    "hostigar": "hos-ti-gar",
    "hostigo": "hos-ti-go",
    "hostigosa": "hos-ti-go-sa",
    "hostigoso": "hos-ti-go-so",
    "hostil": "hos-til",
    "hostilidad": "hos-ti-li-dad",
    "hostilizar": "hos-ti-li-zar",
    "hostilmente": "hos-til-men-te",
    "hotel": "ho-tel",
    "hotelera": "ho-te-le-ra",
    "hotelería": "ho-te-le-rí-a",
    "hotelero": "ho-te-le-ro",
    "hotentota": "ho-ten-to-ta",
    "hotentote": "ho-ten-to-te",
    "hoto": "ho-to",
    "house": "hou-se",
    "hove": "ho-ve",
    "hovera": "ho-ve-ra",
    "hovercraft": "ho-ver-craft",
    "hovero": "ho-ve-ro",
    "hoya": "ho-ya",
    "hoyada": "ho-ya-da",
    "hoyanca": "ho-yan-ca",
    "hoyanco": "ho-yan-co",
    "hoyar": "ho-yar",
    "hoyita": "ho-yi-ta",
    "hoyo": "ho-yo",
    "hoyosa": "ho-yo-sa",
    "hoyoso": "ho-yo-so",
    "hoyuela": "ho-yue-la",
    "hoyuelo": "ho-yue-lo",
    "hozada": "ho-za-da",
    "hozadero": "ho-za-de-ro",
    "hozador": "ho-za-dor",
    "hozadora": "ho-za-do-ra",
    "hozadura": "ho-za-du-ra",
    "hozar": "ho-zar",
    "huaca": "hua-ca",
    "huacal": "hua-cal",
    "huácala": "huá-ca-la",
    "huacalón": "hua-ca-lón",
    "huacatay": "hua-ca-tay",
    "huacha": "hua-cha",
    "huachache": "hua-cha-che",
    "huachafa": "hua-cha-fa",
    "huachafería": "hua-cha-fe-rí-a",
    "huachafo": "hua-cha-fo",
    "huachafosa": "hua-cha-fo-sa",
    "huachafoso": "hua-cha-fo-so",
    "huachalomo": "hua-cha-lo-mo",
    "huachana": "hua-cha-na",
    "huachano": "hua-cha-no",
    "huachar": "hua-char",
    "huachinango": "hua-chi-nan-go",
    "huacho": "hua-cho",
    "huaco": "hua-co",
    "huaico": "huai-co",
    "huailina": "huai-li-na",
    "huailino": "huai-li-no",
    "huaino": "huai-no",
    "huairuro": "huai-ru-ro",
    "huaje": "hua-je",
    "hualo": "hua-lo",
    "huamachuquina": "hua-ma-chu-qui-na",
    "huamachuquino": "hua-ma-chu-qui-no",
    "huamalina": "hua-ma-li-na",
    "huamalino": "hua-ma-li-no",
    "huamanguina": "hua-man-gui-na",
    "huamanguino": "hua-man-gui-no",
    "huambisa": "huam-bi-sa",
    "huamúchil": "hua-mú-chil",
    "huancaina": "huan-cai-na",
    "huancaíno": "huan-ca-í-no",
    "huancaneña": "huan-ca-ne-ña",
    "huancaneño": "huan-ca-ne-ño",
    "huancara": "huan-ca-ra",
    "huancavelicana": "huan-ca-ve-li-ca-na",
    "huancavelicano": "huan-ca-ve-li-ca-no",
    "huancavilca": "huan-ca-vil-ca",
    "huango": "huan-go",
    "huangudo": "huan-gu-do",
    "huantina": "huan-ti-na",
    "huantino": "huan-ti-no",
    "huanunense": "hua-nu-nen-se",
    "huanuqueña": "hua-nu-que-ña",
    "huanuqueño": "hua-nu-que-ño",
    "huao": "hua-o",
    "huaorani": "hua-o-ra-ni",
    "huapango": "hua-pan-go",
    "huapanguera": "hua-pan-gue-ra",
    "huapanguero": "hua-pan-gue-ro",
    "huaquear": "hua-que-ar",
    "huaquera": "hua-que-ra",
    "huaquero": "hua-que-ro",
    "huarache": "hua-ra-che",
    "huarachudo": "hua-ra-chu-do",
    "huaracina": "hua-ra-ci-na",
    "huaracino": "hua-ra-ci-no",
    "huaralina": "hua-ra-li-na",
    "huaralino": "hua-ra-li-no",
    "huarapeta": "hua-ra-pe-ta",
    "huarique": "hua-ri-que",
    "huarochirana": "hua-ro-chi-ra-na",
    "huarochirano": "hua-ro-chi-ra-no",
    "huarpe": "huar-pe",
    "huasca": "huas-ca",
    "huascar": "huas-car",
    "huasipungo": "hua-si-pun-go",
    "huaso": "hua-so",
    "huasquina": "huas-qui-na",
    "huasquino": "huas-qui-no",
    "huasquiri": "huas-qui-ri",
    "huasteca": "huas-te-ca",
    "huasteco": "huas-te-co",
    "huateque": "hua-te-que",
    "huatia": "hua-tia",
    "huato": "hua-to",
    "huauchinango": "huau-chi-nan-go",
    "huautli": "huau-tli",
    "huauzontle": "huau-zon-tle",
    "huave": "hua-ve",
    "huayco": "huay-co",
    "huayno": "huay-no",
    "huazontle": "hua-zon-tle",
    "hucha": "hu-cha",
    "huchear": "hu-che-ar",
    "hucho": "hu-cho",
    "huchohó": "hu-cho-hó",
    "hucia": "hu-cia",
    "huebra": "hue-bra",
    "huebrero": "hue-bre-ro",
    "hueca": "hue-ca",
    "hueco": "hue-co",
    "huecograbado": "hue-co-gra-ba-do",
    "huecú": "hue-cú",
    "huego": "hue-go",
    "huehuenche": "hue-huen-che",
    "huehueteca": "hue-hue-te-ca",
    "huehueteco": "hue-hue-te-co",
    "hueledenoche": "hue-le-de-no-che",
    "huelepega": "hue-le-pe-ga",
    "huélfago": "huél-fa-go",
    "huelga": "huel-ga",
    "huelgo": "huel-go",
    "huelguista": "huel-guis-ta",
    "huelguística": "huel-guís-ti-ca",
    "huelguístico": "huel-guís-ti-co",
    "huella": "hue-lla",
    "huélliga": "hué-lli-ga",
    "huello": "hue-llo",
    "huelveña": "huel-ve-ña",
    "huelveño": "huel-ve-ño",
    "huemul": "hue-mul",
    "huera": "hue-ra",
    "huerca": "huer-ca",
    "huerco": "huer-co",
    "huérfago": "huér-fa-go",
    "huérfana": "huér-fa-na",
    "huerfanidad": "huer-fa-ni-dad",
    "huerfanito": "huer-fa-ni-to",
    "huérfano": "huér-fa-no",
    "huero": "hue-ro",
    "huerta": "huer-ta",
    "huertana": "huer-ta-na",
    "huertano": "huer-ta-no",
    "huertera": "huer-te-ra",
    "huertero": "huer-te-ro",
    "huerto": "huer-to",
    "huesa": "hue-sa",
    "huesera": "hue-se-ra",
    "huesero": "hue-se-ro",
    "huesillo": "hue-si-llo",
    "hueso": "hue-so",
    "huesosa": "hue-so-sa",
    "huesoso": "hue-so-so",
    "huésped": "hués-ped",
    "huéspeda": "hués-pe-da",
    "huesque": "hues-que",
    "hueste": "hues-te",
    "huesteadora": "hues-te-a-do-ra",
    "huestear": "hues-te-ar",
    "huesuda": "hue-su-da",
    "huesudo": "hue-su-do",
    "huetar": "hue-tar",
    "hueteña": "hue-te-ña",
    "hueteño": "hue-te-ño",
    "hueva": "hue-va",
    "huevada": "hue-va-da",
    "huevar": "hue-var",
    "huevas": "hue-vas",
    "huevazos": "hue-va-zos",
    "huevear": "hue-ve-ar",
    "huevera": "hue-ve-ra",
    "huevería": "hue-ve-rí-a",
    "huevero": "hue-ve-ro",
    "huévil": "hué-vil",
    "huevo": "hue-vo",
    "huevón": "hue-vón",
    "huevona": "hue-vo-na",
    "huevonada": "hue-vo-na-da",
    "huevonear": "hue-vo-ne-ar",
    "hugonota": "hu-go-no-ta",
    "hugonote": "hu-go-no-te",
    "huiche": "hui-che",
    "huichó": "hui-chó",
    "huichola": "hui-cho-la",
    "huiclacoche": "hui-cla-co-che",
    "huida": "hui-da",
    "huidera": "hui-de-ra",
    "huidero": "hui-de-ro",
    "huidiza": "hui-di-za",
    "huidizo": "hui-di-zo",
    "huido": "hui-do",
    "huidor": "hui-dor",
    "huidora": "hui-do-ra",
    "huifa": "hui-fa",
    "huila": "hui-la",
    "huilense": "hui-len-se",
    "huilienta": "hui-lien-ta",
    "huiliento": "hui-lien-to",
    "huilliche": "hui-lli-che",
    "huillín": "hui-llín",
    "huilo": "hui-lo",
    "huilota": "hui-lo-ta",
    "huilte": "huil-te",
    "huiltota": "huil-to-ta",
    "huincha": "huin-cha",
    "huingán": "huin-gán",
    "huipil": "hui-pil",
    "huira": "hui-ra",
    "huiriche": "hui-ri-che",
    "huiro": "hui-ro",
    "huisache": "hui-sa-che",
    "huisachear": "hui-sa-che-ar",
    "huisachera": "hui-sa-che-ra",
    "huisachero": "hui-sa-che-ro",
    "huisquil": "huis-quil",
    "huisquilar": "huis-qui-lar",
    "huisquilete": "huis-qui-le-te",
    "huitlacoche": "hui-tla-co-che",
    "huitoró": "hui-to-ró",
    "huitrín": "hui-trín",
    "huizache": "hui-za-che",
    "hujier": "hu-jier",
    "hulana": "hu-la-na",
    "hulano": "hu-la-no",
    "hular": "hu-lar",
    "hule": "hu-le",
    "hulear": "hu-le-ar",
    "hulera": "hu-le-ra",
    "hulero": "hu-le-ro",
    "hulla": "hu-lla",
    "hullera": "hu-lle-ra",
    "hullero": "hu-lle-ro",
    "hulte": "hul-te",
    "humacaeña": "hu-ma-ca-e-ña",
    "humacaeño": "hu-ma-ca-e-ño",
    "humacera": "hu-ma-ce-ra",
    "humada": "hu-ma-da",
    "humahuaca": "hu-ma-hua-ca",
    "humaina": "hu-mai-na",
    "humana": "hu-ma-na",
    "humanal": "hu-ma-nal",
    "humanamente": "hu-ma-na-men-te",
    "humanar": "hu-ma-nar",
    "humanidad": "hu-ma-ni-dad",
    "humanismo": "hu-ma-nis-mo",
    "humanista": "hu-ma-nis-ta",
    "humanística": "hu-ma-nís-ti-ca",
    "humanístico": "hu-ma-nís-ti-co",
    "humanitaria": "hu-ma-ni-ta-ria",
    "humanitario": "hu-ma-ni-ta-rio",
    "humanitarismo": "hu-ma-ni-ta-ris-mo",
    "humanización": "hu-ma-ni-za-ción",
    "humanizador": "hu-ma-ni-za-dor",
    "humanizar": "hu-ma-ni-zar",
    "humano": "hu-ma-no",
    "humanoide": "hu-ma-noi-de",
    "humar": "hu-mar",
    "humarada": "hu-ma-ra-da",
    "humarascal": "hu-ma-ras-cal",
    "humarasco": "hu-ma-ras-co",
    "humarazo": "hu-ma-ra-zo",
    "humareda": "hu-ma-re-da",
    "humasera": "hu-ma-se-ra",
    "humaza": "hu-ma-za",
    "humazga": "hu-maz-ga",
    "humazo": "hu-ma-zo",
    "humazón": "hu-ma-zón",
    "humeante": "hu-me-an-te",
    "humear": "hu-me-ar",
    "humectación": "hu-mec-ta-ción",
    "humectante": "hu-mec-tan-te",
    "humectar": "hu-mec-tar",
    "humectativa": "hu-mec-ta-ti-va",
    "humectativo": "hu-mec-ta-ti-vo",
    "húmeda": "hú-me-da",
    "humedad": "hu-me-dad",
    "humedal": "hu-me-dal",
    "humedecer": "hu-me-de-cer",
    "húmedo": "hú-me-do",
    "humera": "hu-me-ra",
    "humeral": "hu-me-ral",
    "humero": "hu-me-ro",
    "húmero": "hú-me-ro",
    "húmico": "hú-mi-co",
    "húmida": "hú-mi-da",
    "humidad": "hu-mi-dad",
    "humidificación": "hu-mi-di-fi-ca-ción",
    "humidificador": "hu-mi-di-fi-ca-dor",
    "humidificar": "hu-mi-di-fi-car",
    "húmido": "hú-mi-do",
    "humienta": "hu-mien-ta",
    "humiento": "hu-mien-to",
    "humificación": "hu-mi-fi-ca-ción",
    "humil": "hu-mil",
    "húmil": "hú-mil",
    "humildad": "hu-mil-dad",
    "humilde": "hu-mil-de",
    "humildemente": "hu-mil-de-men-te",
    "humildosa": "hu-mil-do-sa",
    "humildosamente": "hu-mil-do-sa-men-te",
    "humildoso": "hu-mil-do-so",
    "humiliación": "hu-mi-lia-ción",
    "humillación": "hu-mi-lla-ción",
    "humilladamente": "hu-mi-lla-da-men-te",
    "humilladero": "hu-mi-lla-de-ro",
    "humillador": "hu-mi-lla-dor",
    "humilladora": "hu-mi-lla-do-ra",
    "humillante": "hu-mi-llan-te",
    "humillar": "hu-mi-llar",
    "humillo": "hu-mi-llo",
    "humilmente": "hu-mil-men-te",
    "húmilmente": "hú-mil-men-te",
    "humita": "hu-mi-ta",
    "humitera": "hu-mi-te-ra",
    "humitero": "hu-mi-te-ro",
    "humo": "hu-mo",
    "humor": "hu-mor",
    "humorada": "hu-mo-ra-da",
    "humorado": "hu-mo-ra-do",
    "humoral": "hu-mo-ral",
    "humoralismo": "hu-mo-ra-lis-mo",
    "humoralista": "hu-mo-ra-lis-ta",
    "humorismo": "hu-mo-ris-mo",
    "humorista": "hu-mo-ris-ta",
    "humorística": "hu-mo-rís-ti-ca",
    "humorísticamente": "hu-mo-rís-ti-ca-men-te",
    "humorístico": "hu-mo-rís-ti-co",
    "humorosa": "hu-mo-ro-sa",
    "humorosidad": "hu-mo-ro-si-dad",
    "humoroso": "hu-mo-ro-so",
    "humosa": "hu-mo-sa",
    "humosidad": "hu-mo-si-dad",
    "humoso": "hu-mo-so",
    "humus": "hu-mus",
    "huna": "hu-na",
    "hunche": "hun-che",
    "hunco": "hun-co",
    "hundible": "hun-di-ble",
    "hundidor": "hun-di-dor",
    "hundimiento": "hun-di-mien-to",
    "hundir": "hun-dir",
    "húngara": "hún-ga-ra",
    "hungarina": "hun-ga-ri-na",
    "húngaro": "hún-ga-ro",
    "huno": "hu-no",
    "hupe": "hu-pe",
    "hura": "hu-ra",
    "huracán": "hu-ra-cán",
    "huracanada": "hu-ra-ca-na-da",
    "huracanado": "hu-ra-ca-na-do",
    "huracanar": "hu-ra-ca-nar",
    "huraco": "hu-ra-co",
    "huraña": "hu-ra-ña",
    "hurañamente": "hu-ra-ña-men-te",
    "hurañía": "hu-ra-ñí-a",
    "huraño": "hu-ra-ño",
    "hurdana": "hur-da-na",
    "hurdano": "hur-da-no",
    "hure": "hu-re",
    "hurera": "hu-re-ra",
    "hurgador": "hur-ga-dor",
    "hurgadora": "hur-ga-do-ra",
    "hurgamandera": "hur-ga-man-de-ra",
    "hurgamiento": "hur-ga-mien-to",
    "hurgar": "hur-gar",
    "hurgón": "hur-gón",
    "hurgonada": "hur-go-na-da",
    "hurgonazo": "hur-go-na-zo",
    "hurgonear": "hur-go-ne-ar",
    "hurgonero": "hur-go-ne-ro",
    "hurguete": "hur-gue-te",
    "hurguetear": "hur-gue-te-ar",
    "hurguillas": "hur-gui-llas",
    "hurí": "hu-rí",
    "hurmiento": "hur-mien-to",
    "hurón": "hu-rón",
    "hurona": "hu-ro-na",
    "huronear": "hu-ro-ne-ar",
    "huroneo": "hu-ro-ne-o",
    "huronera": "hu-ro-ne-ra",
    "huronero": "hu-ro-ne-ro",
    "hurra": "hu-rra",
    "hurraca": "hu-rra-ca",
    "hurraco": "hu-rra-co",
    "hurta": "hur-ta",
    "hurtadamente": "hur-ta-da-men-te",
    "hurtadillas": "hur-ta-di-llas",
    "hurtadineros": "hur-ta-di-ne-ros",
    "hurtado": "hur-ta-do",
    "hurtador": "hur-ta-dor",
    "hurtadora": "hur-ta-do-ra",
    "hurtagua": "hur-ta-gua",
    "hurtar": "hur-tar",
    "hurtas": "hur-tas",
    "hurtiblemente": "hur-ti-ble-men-te",
    "hurto": "hur-to",
    "husada": "hu-sa-da",
    "húsar": "hú-sar",
    "husera": "hu-se-ra",
    "husero": "hu-se-ro",
    "husillero": "hu-si-lle-ro",
    "husillo": "hu-si-llo",
    "husita": "hu-si-ta",
    "husma": "hus-ma",
    "husmar": "hus-mar",
    "husmeador": "hus-me-a-dor",
    "husmeadora": "hus-me-a-do-ra",
    "husmear": "hus-me-ar",
    "husmeo": "hus-me-o",
    "husmo": "hus-mo",
    "huso": "hu-so",
    "huta": "hu-ta",
    "hutía": "hu-tí-a",
    "huyuya": "hu-yu-ya",
    "huyuyo": "hu-yu-yo",
    "iatrogénico": "ia-tro-gé-ni-co",
    "ibaguereña": "i-ba-gue-re-ña",
    "ibaguereño": "i-ba-gue-re-ño",
    "ibapoí": "i-ba-po-í",
    "ibarreña": "i-ba-rre-ña",
    "ibarreño": "i-ba-rre-ño",
    "ibera": "i-be-ra",
    "íbera": "í-be-ra",
    "iberia": "i-be-ria",
    "ibérica": "i-bé-ri-ca",
    "ibérico": "i-bé-ri-co",
    "iberio": "i-be-rio",
    "iberismo": "i-be-ris-mo",
    "iberista": "i-be-ris-ta",
    "ibero": "i-be-ro",
    "íbero": "í-be-ro",
    "iberoamericana": "i-be-ro-a-me-ri-ca-na",
    "iberoamericano": "i-be-ro-a-me-ri-ca-no",
    "iberorromance": "i-be-ro-rro-man-ce",
    "iberorrománico": "i-be-ro-rro-má-ni-co",
    "íbice": "í-bi-ce",
    "ibicenca": "i-bi-cen-ca",
    "ibicenco": "i-bi-cen-co",
    "ibídem": "i-bí-dem",
    "ibis": "i-bis",
    "ibón": "i-bón",
    "icaco": "i-ca-co",
    "icárea": "i-cá-re-a",
    "icáreo": "i-cá-re-o",
    "icaria": "i-ca-ria",
    "icario": "i-ca-rio",
    "icástico": "i-cás-ti-co",
    "iceberg": "i-ce-berg",
    "ichal": "i-chal",
    "icho": "i-cho",
    "icipó": "i-ci-pó",
    "icneumón": "ic-neu-món",
    "icnografía": "ic-no-gra-fí-a",
    "icnográfica": "ic-no-grá-fi-ca",
    "icnográfico": "ic-no-grá-fi-co",
    "icnología": "ic-no-lo-gí-a",
    "iconicidad": "i-co-ni-ci-dad",
    "icónico": "i-có-ni-co",
    "icono": "i-co-no",
    "ícono": "í-co-no",
    "iconoclasia": "i-co-no-cla-sia",
    "iconoclasta": "i-co-no-clas-ta",
    "iconografía": "i-co-no-gra-fí-a",
    "iconográfica": "i-co-no-grá-fi-ca",
    "iconográfico": "i-co-no-grá-fi-co",
    "iconolatría": "i-co-no-la-trí-a",
    "iconología": "i-co-no-lo-gí-a",
    "iconológica": "i-co-no-ló-gi-ca",
    "iconológico": "i-co-no-ló-gi-co",
    "iconómaco": "i-co-nó-ma-co",
    "iconoscopio": "i-co-nos-co-pio",
    "iconostasio": "i-co-nos-ta-sio",
    "icor": "i-cor",
    "icorosa": "i-co-ro-sa",
    "icoroso": "i-co-ro-so",
    "icosaedro": "i-co-sa-e-dro",
    "ictérica": "ic-té-ri-ca",
    "ictericia": "ic-te-ri-cia",
    "ictericiada": "ic-te-ri-cia-da",
    "ictericiado": "ic-te-ri-cia-do",
    "ictérico": "ic-té-ri-co",
    "ictérido": "ic-té-ri-do",
    "icterodes": "ic-te-ro-des",
    "ictíneo": "ic-tí-ne-o",
    "ictiófaga": "ic-tió-fa-ga",
    "ictiofagia": "ic-tio-fa-gia",
    "ictiófago": "ic-tió-fa-go",
    "ictiofauna": "ic-tio-fau-na",
    "ictiografía": "ic-tio-gra-fí-a",
    "ictiol": "ic-tiol",
    "ictióloga": "ic-tió-lo-ga",
    "ictiología": "ic-tio-lo-gí-a",
    "ictiológica": "ic-tio-ló-gi-ca",
    "ictiológico": "ic-tio-ló-gi-co",
    "ictiólogo": "ic-tió-lo-go",
    "ictiosaurio": "ic-tio-sau-rio",
    "ictiosauro": "ic-tio-sau-ro",
    "ictiosis": "ic-tio-sis",
    "ictus": "ic-tus",
    "ida": "i-da",
    "idalia": "i-da-lia",
    "idalio": "i-da-lio",
    "idea": "i-de-a",
    "ideación": "i-de-a-ción",
    "ideal": "i-de-al",
    "idealidad": "i-de-a-li-dad",
    "idealismo": "i-de-a-lis-mo",
    "idealista": "i-de-a-lis-ta",
    "idealización": "i-de-a-li-za-ción",
    "idealizador": "i-de-a-li-za-dor",
    "idealizadora": "i-de-a-li-za-do-ra",
    "idealizar": "i-de-a-li-zar",
    "idealmente": "i-de-al-men-te",
    "idear": "i-de-ar",
    "ideario": "i-de-a-rio",
    "ideática": "i-de-á-ti-ca",
    "ideático": "i-de-á-ti-co",
    "ideay": "i-de-ay",
    "ídem": "í-dem",
    "idempotencia": "i-dem-po-ten-cia",
    "idempotente": "i-dem-po-ten-te",
    "idéntica": "i-dén-ti-ca",
    "idénticamente": "i-dén-ti-ca-men-te",
    "idéntico": "i-dén-ti-co",
    "identidad": "i-den-ti-dad",
    "identificable": "i-den-ti-fi-ca-ble",
    "identificación": "i-den-ti-fi-ca-ción",
    "identificador": "i-den-ti-fi-ca-dor",
    "identificadora": "i-den-ti-fi-ca-do-ra",
    "identificar": "i-den-ti-fi-car",
    "identificativo": "i-den-ti-fi-ca-ti-vo",
    "identificatorio": "i-den-ti-fi-ca-to-rio",
    "identikit": "i-den-ti-kit",
    "ideo": "i-de-o",
    "ideografía": "i-de-o-gra-fí-a",
    "ideográfica": "i-de-o-grá-fi-ca",
    "ideográfico": "i-de-o-grá-fi-co",
    "ideograma": "i-de-o-gra-ma",
    "ideóloga": "i-de-ó-lo-ga",
    "ideología": "i-de-o-lo-gí-a",
    "ideológica": "i-de-o-ló-gi-ca",
    "ideológicamente": "i-de-o-ló-gi-ca-men-te",
    "ideológico": "i-de-o-ló-gi-co",
    "ideologización": "i-de-o-lo-gi-za-ción",
    "ideologizado": "i-de-o-lo-gi-za-do",
    "ideologizar": "i-de-o-lo-gi-zar",
    "ideólogo": "i-de-ó-lo-go",
    "ideosa": "i-de-o-sa",
    "ideoso": "i-de-o-so",
    "idílica": "i-dí-li-ca",
    "idílico": "i-dí-li-co",
    "idilio": "i-di-lio",
    "idiocia": "i-dio-cia",
    "idiófono": "i-dió-fo-no",
    "idiolecto": "i-dio-lec-to",
    "idioma": "i-dio-ma",
    "idiomática": "i-dio-má-ti-ca",
    "idiomático": "i-dio-má-ti-co",
    "idiosincrasia": "i-dio-sin-cra-sia",
    "idiosincrásica": "i-dio-sin-crá-si-ca",
    "idiosincrásico": "i-dio-sin-crá-si-co",
    "idiota": "i-dio-ta",
    "idiotada": "i-dio-ta-da",
    "idiotez": "i-dio-tez",
    "idiotipo": "i-dio-ti-po",
    "idiotismo": "i-dio-tis-mo",
    "idiotizar": "i-dio-ti-zar",
    "ido": "i-do",
    "idólatra": "i-dó-la-tra",
    "idolatrar": "i-do-la-trar",
    "idolatría": "i-do-la-trí-a",
    "idolátrica": "i-do-lá-tri-ca",
    "idolátrico": "i-do-lá-tri-co",
    "ídolo": "í-do-lo",
    "idolología": "i-do-lo-lo-gí-a",
    "idolopeya": "i-do-lo-pe-ya",
    "idónea": "i-dó-ne-a",
    "idoneidad": "i-do-nei-dad",
    "idóneo": "i-dó-ne-o",
    "idos": "i-dos",
    "idumea": "i-du-me-a",
    "idumeo": "i-du-me-o",
    "idus": "i-dus",
    "iglesia": "i-gle-sia",
    "iglesiario": "i-gle-sia-rio",
    "iglesiera": "i-gle-sie-ra",
    "iglesiero": "i-gle-sie-ro",
    "iglú": "i-glú",
    "ignaciana": "ig-na-cia-na",
    "ignaciano": "ig-na-cia-no",
    "ignacias": "ig-na-cias",
    "ignara": "ig-na-ra",
    "ignaro": "ig-na-ro",
    "ignava": "ig-na-va",
    "ignavia": "ig-na-via",
    "ignavo": "ig-na-vo",
    "ígnea": "íg-ne-a",
    "ígneo": "íg-ne-o",
    "ignición": "ig-ni-ción",
    "ignícola": "ig-ní-co-la",
    "ignífera": "ig-ní-fe-ra",
    "ignífero": "ig-ní-fe-ro",
    "ignífuga": "ig-ní-fu-ga",
    "ignífugo": "ig-ní-fu-go",
    "ignipotente": "ig-ni-po-ten-te",
    "ignita": "ig-ni-ta",
    "ignito": "ig-ni-to",
    "ignívoma": "ig-ní-vo-ma",
    "ignívomo": "ig-ní-vo-mo",
    "ignobilidad": "ig-no-bi-li-dad",
    "ignoble": "ig-no-ble",
    "ignografía": "ig-no-gra-fí-a",
    "ignominia": "ig-no-mi-nia",
    "ignominiosa": "ig-no-mi-nio-sa",
    "ignominiosamente": "ig-no-mi-nio-sa-men-te",
    "ignominioso": "ig-no-mi-nio-so",
    "ignoración": "ig-no-ra-ción",
    "ignorancia": "ig-no-ran-cia",
    "ignorante": "ig-no-ran-te",
    "ignorantemente": "ig-no-ran-te-men-te",
    "ignorar": "ig-no-rar",
    "ignota": "ig-no-ta",
    "ignoto": "ig-no-to",
    "igorote": "i-go-ro-te",
    "igreja": "i-gre-ja",
    "iguada": "i-gua-da",
    "iguado": "i-gua-do",
    "igual": "i-gual",
    "iguala": "i-gua-la",
    "igualación": "i-gua-la-ción",
    "igualada": "i-gua-la-da",
    "igualadina": "i-gua-la-di-na",
    "igualadino": "i-gua-la-di-no",
    "igualado": "i-gua-la-do",
    "igualador": "i-gua-la-dor",
    "igualadora": "i-gua-la-do-ra",
    "igualamiento": "i-gua-la-mien-to",
    "igualanza": "i-gua-lan-za",
    "igualar": "i-gua-lar",
    "igualatorio": "i-gua-la-to-rio",
    "igualdad": "i-gual-dad",
    "igualeza": "i-gua-le-za",
    "igualitaria": "i-gua-li-ta-ria",
    "igualitario": "i-gua-li-ta-rio",
    "igualitarismo": "i-gua-li-ta-ris-mo",
    "igualmente": "i-gual-men-te",
    "igualón": "i-gua-lón",
    "igualona": "i-gua-lo-na",
    "iguana": "i-gua-na",
    "iguanal": "i-gua-nal",
    "iguanero": "i-gua-ne-ro",
    "iguánido": "i-guá-ni-do",
    "iguanodonte": "i-gua-no-don-te",
    "iguar": "i-guar",
    "iguaria": "i-gua-ria",
    "igüedo": "i-güe-do",
    "ijada": "i-ja-da",
    "ijadear": "i-ja-de-ar",
    "ijar": "i-jar",
    "ijillo": "i-ji-llo",
    "ijiyo": "i-ji-yo",
    "ijujú": "i-ju-jú",
    "ikastola": "i-kas-to-la",
    "ikebana": "i-ke-ba-na",
    "ikurriña": "i-ku-rri-ña",
    "ilación": "i-la-ción",
    "ilapso": "i-lap-so",
    "ilativa": "i-la-ti-va",
    "ilativo": "i-la-ti-vo",
    "ilécebra": "i-lé-ce-bra",
    "ilegal": "i-le-gal",
    "ilegalidad": "i-le-ga-li-dad",
    "ilegalización": "i-le-ga-li-za-ción",
    "ilegalizar": "i-le-ga-li-zar",
    "ilegalmente": "i-le-gal-men-te",
    "ilegibilidad": "i-le-gi-bi-li-dad",
    "ilegible": "i-le-gi-ble",
    "ilegislable": "i-le-gis-la-ble",
    "ilegítima": "i-le-gí-ti-ma",
    "ilegítimamente": "i-le-gí-ti-ma-men-te",
    "ilegitimar": "i-le-gi-ti-mar",
    "ilegitimidad": "i-le-gi-ti-mi-dad",
    "ilegítimo": "i-le-gí-ti-mo",
    "íleo": "í-le-o",
    "ileocecal": "i-le-o-ce-cal",
    "íleon": "í-le-on",
    "ilercaón": "i-ler-ca-ón",
    "ilercaona": "i-ler-ca-o-na",
    "ilercavón": "i-ler-ca-vón",
    "ilercavona": "i-ler-ca-vo-na",
    "ilerdense": "i-ler-den-se",
    "ilergete": "i-ler-ge-te",
    "ilesa": "i-le-sa",
    "ileso": "i-le-so",
    "iletrada": "i-le-tra-da",
    "iletrado": "i-le-tra-do",
    "ilíaca": "i-lí-a-ca",
    "iliaca": "i-lia-ca",
    "ilíaco": "i-lí-a-co",
    "iliaco": "i-lia-co",
    "iliberal": "i-li-be-ral",
    "iliberitana": "i-li-be-ri-ta-na",
    "iliberitano": "i-li-be-ri-ta-no",
    "iliberritana": "i-li-be-rri-ta-na",
    "iliberritano": "i-li-be-rri-ta-no",
    "ilicínea": "i-li-cí-ne-a",
    "ilicíneo": "i-li-cí-ne-o",
    "ilícita": "i-lí-ci-ta",
    "ilícitamente": "i-lí-ci-ta-men-te",
    "ilicitana": "i-li-ci-ta-na",
    "ilicitano": "i-li-ci-ta-no",
    "ilícito": "i-lí-ci-to",
    "ilicitud": "i-li-ci-tud",
    "iliense": "i-lien-se",
    "ilimitable": "i-li-mi-ta-ble",
    "ilimitación": "i-li-mi-ta-ción",
    "ilimitada": "i-li-mi-ta-da",
    "ilimitadamente": "i-li-mi-ta-da-men-te",
    "ilimitado": "i-li-mi-ta-do",
    "ilion": "i-lion",
    "ilipulense": "i-li-pu-len-se",
    "ilíquida": "i-lí-qui-da",
    "ilíquido": "i-lí-qui-do",
    "iliria": "i-li-ria",
    "ilírica": "i-lí-ri-ca",
    "ilírico": "i-lí-ri-co",
    "ilirio": "i-li-rio",
    "ilistle": "i-lis-tle",
    "iliterario": "i-li-te-ra-rio",
    "iliterata": "i-li-te-ra-ta",
    "iliterato": "i-li-te-ra-to",
    "iliturgitana": "i-li-tur-gi-ta-na",
    "iliturgitano": "i-li-tur-gi-ta-no",
    "illa": "i-lla",
    "illapelina": "i-lla-pe-li-na",
    "illapelino": "i-lla-pe-li-no",
    "ilocalizable": "i-lo-ca-li-za-ble",
    "ilógica": "i-ló-gi-ca",
    "ilógico": "i-ló-gi-co",
    "ilota": "i-lo-ta",
    "ilotismo": "i-lo-tis-mo",
    "iludir": "i-lu-dir",
    "iluminación": "i-lu-mi-na-ción",
    "iluminada": "i-lu-mi-na-da",
    "iluminado": "i-lu-mi-na-do",
    "iluminador": "i-lu-mi-na-dor",
    "iluminadora": "i-lu-mi-na-do-ra",
    "iluminancia": "i-lu-mi-nan-cia",
    "iluminante": "i-lu-mi-nan-te",
    "iluminar": "i-lu-mi-nar",
    "iluminaria": "i-lu-mi-na-ria",
    "iluminativa": "i-lu-mi-na-ti-va",
    "iluminativo": "i-lu-mi-na-ti-vo",
    "iluminismo": "i-lu-mi-nis-mo",
    "iluminista": "i-lu-mi-nis-ta",
    "ilusa": "i-lu-sa",
    "ilusamente": "i-lu-sa-men-te",
    "ilusión": "i-lu-sión",
    "ilusionante": "i-lu-sio-nan-te",
    "ilusionar": "i-lu-sio-nar",
    "ilusionismo": "i-lu-sio-nis-mo",
    "ilusionista": "i-lu-sio-nis-ta",
    "ilusiva": "i-lu-si-va",
    "ilusivo": "i-lu-si-vo",
    "iluso": "i-lu-so",
    "ilusoria": "i-lu-so-ria",
    "ilusorio": "i-lu-so-rio",
    "ilustración": "i-lus-tra-ción",
    "ilustrada": "i-lus-tra-da",
    "ilustrado": "i-lus-tra-do",
    "ilustrador": "i-lus-tra-dor",
    "ilustradora": "i-lus-tra-do-ra",
    "ilustrar": "i-lus-trar",
    "ilustrativa": "i-lus-tra-ti-va",
    "ilustrativo": "i-lus-tra-ti-vo",
    "ilustre": "i-lus-tre",
    "ilustremente": "i-lus-tre-men-te",
    "ilustreza": "i-lus-tre-za",
    "ilustrísima": "i-lus-trí-si-ma",
    "ilustrísimo": "i-lus-trí-si-mo",
    "imada": "i-ma-da",
    "imagen": "i-ma-gen",
    "imagenería": "i-ma-ge-ne-rí-a",
    "imaginable": "i-ma-gi-na-ble",
    "imaginación": "i-ma-gi-na-ción",
    "imaginamiento": "i-ma-gi-na-mien-to",
    "imaginar": "i-ma-gi-nar",
    "imaginaria": "i-ma-gi-na-ria",
    "imaginariamente": "i-ma-gi-na-ria-men-te",
    "imaginario": "i-ma-gi-na-rio",
    "imaginativa": "i-ma-gi-na-ti-va",
    "imaginativo": "i-ma-gi-na-ti-vo",
    "imaginería": "i-ma-gi-ne-rí-a",
    "imaginero": "i-ma-gi-ne-ro",
    "imaginología": "i-ma-gi-no-lo-gí-a",
    "imago": "i-ma-go",
    "imam": "i-mam",
    "imán": "i-mán",
    "imanación": "i-ma-na-ción",
    "imanador": "i-ma-na-dor",
    "imanadora": "i-ma-na-do-ra",
    "imanar": "i-ma-nar",
    "imantación": "i-man-ta-ción",
    "imantar": "i-man-tar",
    "imbabureña": "im-ba-bu-re-ña",
    "imbabureño": "im-ba-bu-re-ño",
    "imbancable": "im-ban-ca-ble",
    "imbatibilidad": "im-ba-ti-bi-li-dad",
    "imbatible": "im-ba-ti-ble",
    "imbatido": "im-ba-ti-do",
    "imbebible": "im-be-bi-ble",
    "imbécil": "im-bé-cil",
    "imbecilidad": "im-be-ci-li-dad",
    "imbécilmente": "im-bé-cil-men-te",
    "imbele": "im-be-le",
    "imberbe": "im-ber-be",
    "imbiar": "im-biar",
    "imbibición": "im-bi-bi-ción",
    "imbornal": "im-bor-nal",
    "imborrable": "im-bo-rra-ble",
    "imbricación": "im-bri-ca-ción",
    "imbricada": "im-bri-ca-da",
    "imbricado": "im-bri-ca-do",
    "imbricar": "im-bri-car",
    "imbuir": "im-buir",
    "imbunchar": "im-bun-char",
    "imbunche": "im-bun-che",
    "imela": "i-me-la",
    "imitable": "i-mi-ta-ble",
    "imitación": "i-mi-ta-ción",
    "imitador": "i-mi-ta-dor",
    "imitadora": "i-mi-ta-do-ra",
    "imitamonas": "i-mi-ta-mo-nas",
    "imitar": "i-mi-tar",
    "imitativa": "i-mi-ta-ti-va",
    "imitativo": "i-mi-ta-ti-vo",
    "imitatoria": "i-mi-ta-to-ria",
    "imitatorio": "i-mi-ta-to-rio",
    "imoscapo": "i-mos-ca-po",
    "impaciencia": "im-pa-cien-cia",
    "impacientar": "im-pa-cien-tar",
    "impaciente": "im-pa-cien-te",
    "impacientemente": "im-pa-cien-te-men-te",
    "impactante": "im-pac-tan-te",
    "impactar": "im-pac-tar",
    "impacto": "im-pac-to",
    "impagable": "im-pa-ga-ble",
    "impagado": "im-pa-ga-do",
    "impago": "im-pa-go",
    "impajaritable": "im-pa-ja-ri-ta-ble",
    "impala": "im-pa-la",
    "impalpable": "im-pal-pa-ble",
    "impar": "im-par",
    "imparable": "im-pa-ra-ble",
    "imparcial": "im-par-cial",
    "imparcialidad": "im-par-cia-li-dad",
    "imparcialmente": "im-par-cial-men-te",
    "imparisílaba": "im-pa-ri-sí-la-ba",
    "imparisílabo": "im-pa-ri-sí-la-bo",
    "impartible": "im-par-ti-ble",
    "impartición": "im-par-ti-ción",
    "impartir": "im-par-tir",
    "impasibilidad": "im-pa-si-bi-li-dad",
    "impasible": "im-pa-si-ble",
    "impasiblemente": "im-pa-si-ble-men-te",
    "impasse": "im-pas-se",
    "impávida": "im-pá-vi-da",
    "impávidamente": "im-pá-vi-da-men-te",
    "impavidez": "im-pa-vi-dez",
    "impávido": "im-pá-vi-do",
    "impecabilidad": "im-pe-ca-bi-li-dad",
    "impecable": "im-pe-ca-ble",
    "impecune": "im-pe-cu-ne",
    "impedancia": "im-pe-dan-cia",
    "impedida": "im-pe-di-da",
    "impedido": "im-pe-di-do",
    "impedidor": "im-pe-di-dor",
    "impedidora": "im-pe-di-do-ra",
    "impediencia": "im-pe-dien-cia",
    "impediente": "im-pe-dien-te",
    "impedimenta": "im-pe-di-men-ta",
    "impedimento": "im-pe-di-men-to",
    "impedir": "im-pe-dir",
    "impeditiva": "im-pe-di-ti-va",
    "impeditivo": "im-pe-di-ti-vo",
    "impelente": "im-pe-len-te",
    "impeler": "im-pe-ler",
    "impender": "im-pen-der",
    "impenetrabilidad": "im-pe-ne-tra-bi-li-dad",
    "impenetrable": "im-pe-ne-tra-ble",
    "impenitencia": "im-pe-ni-ten-cia",
    "impenitente": "im-pe-ni-ten-te",
    "impensa": "im-pen-sa",
    "impensable": "im-pen-sa-ble",
    "impensada": "im-pen-sa-da",
    "impensadamente": "im-pen-sa-da-men-te",
    "impensado": "im-pen-sa-do",
    "impepinable": "im-pe-pi-na-ble",
    "impeque": "im-pe-que",
    "imperador": "im-pe-ra-dor",
    "imperadora": "im-pe-ra-do-ra",
    "imperante": "im-pe-ran-te",
    "imperar": "im-pe-rar",
    "imperativa": "im-pe-ra-ti-va",
    "imperativamente": "im-pe-ra-ti-va-men-te",
    "imperativo": "im-pe-ra-ti-vo",
    "imperatoria": "im-pe-ra-to-ria",
    "imperatorio": "im-pe-ra-to-rio",
    "imperceptibilidad": "im-per-cep-ti-bi-li-dad",
    "imperceptible": "im-per-cep-ti-ble",
    "imperceptiblemente": "im-per-cep-ti-ble-men-te",
    "imperdible": "im-per-di-ble",
    "imperdonable": "im-per-do-na-ble",
    "imperdonablemente": "im-per-do-na-ble-men-te",
    "imperecedera": "im-pe-re-ce-de-ra",
    "imperecedero": "im-pe-re-ce-de-ro",
    "imperfección": "im-per-fec-ción",
    "imperfecta": "im-per-fec-ta",
    "imperfectamente": "im-per-fec-ta-men-te",
    "imperfectible": "im-per-fec-ti-ble",
    "imperfectivo": "im-per-fec-ti-vo",
    "imperfecto": "im-per-fec-to",
    "imperfeta": "im-per-fe-ta",
    "imperfeto": "im-per-fe-to",
    "imperforación": "im-per-fo-ra-ción",
    "imperial": "im-pe-rial",
    "imperialismo": "im-pe-ria-lis-mo",
    "imperialista": "im-pe-ria-lis-ta",
    "impericia": "im-pe-ri-cia",
    "imperio": "im-pe-rio",
    "imperiosa": "im-pe-rio-sa",
    "imperiosamente": "im-pe-rio-sa-men-te",
    "imperiosidad": "im-pe-rio-si-dad",
    "imperioso": "im-pe-rio-so",
    "imperita": "im-pe-ri-ta",
    "imperitamente": "im-pe-ri-ta-men-te",
    "imperito": "im-pe-ri-to",
    "impermeabilidad": "im-per-me-a-bi-li-dad",
    "impermeabilización": "im-per-me-a-bi-li-za-ción",
    "impermeabilizante": "im-per-me-a-bi-li-zan-te",
    "impermeabilizar": "im-per-me-a-bi-li-zar",
    "impermeable": "im-per-me-a-ble",
    "impermisible": "im-per-mi-si-ble",
    "impermutabilidad": "im-per-mu-ta-bi-li-dad",
    "impermutable": "im-per-mu-ta-ble",
    "imperscrutable": "im-pers-cru-ta-ble",
    "impersonal": "im-per-so-nal",
    "impersonalidad": "im-per-so-na-li-dad",
    "impersonalizar": "im-per-so-na-li-zar",
    "impersonalmente": "im-per-so-nal-men-te",
    "impersuasible": "im-per-sua-si-ble",
    "impertérrita": "im-per-té-rri-ta",
    "impertérrito": "im-per-té-rri-to",
    "impertinencia": "im-per-ti-nen-cia",
    "impertinente": "im-per-ti-nen-te",
    "impertinentemente": "im-per-ti-nen-te-men-te",
    "impertir": "im-per-tir",
    "imperturbabilidad": "im-per-tur-ba-bi-li-dad",
    "imperturbable": "im-per-tur-ba-ble",
    "imperturbablemente": "im-per-tur-ba-ble-men-te",
    "impétigo": "im-pé-ti-go",
    "ímpeto": "ím-pe-to",
    "impetra": "im-pe-tra",
    "impetración": "im-pe-tra-ción",
    "impetrador": "im-pe-tra-dor",
    "impetradora": "im-pe-tra-do-ra",
    "impetrar": "im-pe-trar",
    "impetratoria": "im-pe-tra-to-ria",
    "impetratorio": "im-pe-tra-to-rio",
    "ímpetu": "ím-pe-tu",
    "impetuosa": "im-pe-tuo-sa",
    "impetuosamente": "im-pe-tuo-sa-men-te",
    "impetuosidad": "im-pe-tuo-si-dad",
    "impetuoso": "im-pe-tuo-so",
    "impía": "im-pí-a",
    "impiadosa": "im-pia-do-sa",
    "impiadoso": "im-pia-do-so",
    "impíamente": "im-pí-a-men-te",
    "impiedad": "im-pie-dad",
    "impiedosa": "im-pie-do-sa",
    "impiedoso": "im-pie-do-so",
    "impingar": "im-pin-gar",
    "impío": "im-pí-o",
    "impírea": "im-pí-re-a",
    "impíreo": "im-pí-re-o",
    "impla": "im-pla",
    "implacabilidad": "im-pla-ca-bi-li-dad",
    "implacable": "im-pla-ca-ble",
    "implacablemente": "im-pla-ca-ble-men-te",
    "implantación": "im-plan-ta-ción",
    "implantador": "im-plan-ta-dor",
    "implantadora": "im-plan-ta-do-ra",
    "implantar": "im-plan-tar",
    "implante": "im-plan-te",
    "implar": "im-plar",
    "implaticable": "im-pla-ti-ca-ble",
    "implementación": "im-ple-men-ta-ción",
    "implementar": "im-ple-men-tar",
    "implemento": "im-ple-men-to",
    "implicación": "im-pli-ca-ción",
    "implicancia": "im-pli-can-cia",
    "implicar": "im-pli-car",
    "implicatoria": "im-pli-ca-to-ria",
    "implicatorio": "im-pli-ca-to-rio",
    "implícita": "im-plí-ci-ta",
    "implícitamente": "im-plí-ci-ta-men-te",
    "implícito": "im-plí-ci-to",
    "imploración": "im-plo-ra-ción",
    "implorador": "im-plo-ra-dor",
    "imploradora": "im-plo-ra-do-ra",
    "implorante": "im-plo-ran-te",
    "implorar": "im-plo-rar",
    "implosión": "im-plo-sión",
    "implosiva": "im-plo-si-va",
    "implosivo": "im-plo-si-vo",
    "implume": "im-plu-me",
    "impluvio": "im-plu-vio",
    "impolítica": "im-po-lí-ti-ca",
    "impolíticamente": "im-po-lí-ti-ca-men-te",
    "impolítico": "im-po-lí-ti-co",
    "impoluta": "im-po-lu-ta",
    "impoluto": "im-po-lu-to",
    "imponderabilidad": "im-pon-de-ra-bi-li-dad",
    "imponderable": "im-pon-de-ra-ble",
    "imponderablemente": "im-pon-de-ra-ble-men-te",
    "imponedor": "im-po-ne-dor",
    "imponedora": "im-po-ne-do-ra",
    "imponencia": "im-po-nen-cia",
    "imponente": "im-po-nen-te",
    "imponer": "im-po-ner",
    "imponible": "im-po-ni-ble",
    "impopular": "im-po-pu-lar",
    "impopularidad": "im-po-pu-la-ri-dad",
    "importable": "im-por-ta-ble",
    "importación": "im-por-ta-ción",
    "importador": "im-por-ta-dor",
    "importadora": "im-por-ta-do-ra",
    "importancia": "im-por-tan-cia",
    "importante": "im-por-tan-te",
    "importantemente": "im-por-tan-te-men-te",
    "importar": "im-por-tar",
    "importe": "im-por-te",
    "importuna": "im-por-tu-na",
    "importunación": "im-por-tu-na-ción",
    "importunadamente": "im-por-tu-na-da-men-te",
    "importunamente": "im-por-tu-na-men-te",
    "importunar": "im-por-tu-nar",
    "importunidad": "im-por-tu-ni-dad",
    "importuno": "im-por-tu-no",
    "imposibilidad": "im-po-si-bi-li-dad",
    "imposibilitada": "im-po-si-bi-li-ta-da",
    "imposibilitado": "im-po-si-bi-li-ta-do",
    "imposibilitar": "im-po-si-bi-li-tar",
    "imposible": "im-po-si-ble",
    "imposiblemente": "im-po-si-ble-men-te",
    "imposición": "im-po-si-ción",
    "impositivo": "im-po-si-ti-vo",
    "impositor": "im-po-si-tor",
    "impositora": "im-po-si-to-ra",
    "imposta": "im-pos-ta",
    "impostación": "im-pos-ta-ción",
    "impostado": "im-pos-ta-do",
    "impostar": "im-pos-tar",
    "impostergable": "im-pos-ter-ga-ble",
    "impostor": "im-pos-tor",
    "impostora": "im-pos-to-ra",
    "impostura": "im-pos-tu-ra",
    "impotable": "im-po-ta-ble",
    "impotencia": "im-po-ten-cia",
    "impotente": "im-po-ten-te",
    "impracticabilidad": "im-prac-ti-ca-bi-li-dad",
    "impracticable": "im-prac-ti-ca-ble",
    "imprecación": "im-pre-ca-ción",
    "imprecar": "im-pre-car",
    "imprecatoria": "im-pre-ca-to-ria",
    "imprecatorio": "im-pre-ca-to-rio",
    "imprecisa": "im-pre-ci-sa",
    "imprecisión": "im-pre-ci-sión",
    "impreciso": "im-pre-ci-so",
    "impredecibilidad": "im-pre-de-ci-bi-li-dad",
    "impredecible": "im-pre-de-ci-ble",
    "impredictibilidad": "im-pre-dic-ti-bi-li-dad",
    "impregnable": "im-preg-na-ble",
    "impregnación": "im-preg-na-ción",
    "impregnar": "im-preg-nar",
    "impremeditación": "im-pre-me-di-ta-ción",
    "impremeditada": "im-pre-me-di-ta-da",
    "impremeditado": "im-pre-me-di-ta-do",
    "impremir": "im-pre-mir",
    "imprenta": "im-pren-ta",
    "imprentar": "im-pren-tar",
    "imprentera": "im-pren-te-ra",
    "imprentero": "im-pren-te-ro",
    "impresa": "im-pre-sa",
    "impresario": "im-pre-sa-rio",
    "imprescindible": "im-pres-cin-di-ble",
    "imprescriptibilidad": "im-pres-crip-ti-bi-li-dad",
    "imprescriptible": "im-pres-crip-ti-ble",
    "impresentable": "im-pre-sen-ta-ble",
    "impresión": "im-pre-sión",
    "impresionabilidad": "im-pre-sio-na-bi-li-dad",
    "impresionable": "im-pre-sio-na-ble",
    "impresionante": "im-pre-sio-nan-te",
    "impresionar": "im-pre-sio-nar",
    "impresionismo": "im-pre-sio-nis-mo",
    "impresionista": "im-pre-sio-nis-ta",
    "impresivo": "im-pre-si-vo",
    "impreso": "im-pre-so",
    "impresor": "im-pre-sor",
    "impresora": "im-pre-so-ra",
    "imprestable": "im-pres-ta-ble",
    "imprevisibilidad": "im-pre-vi-si-bi-li-dad",
    "imprevisible": "im-pre-vi-si-ble",
    "imprevisión": "im-pre-vi-sión",
    "imprevisor": "im-pre-vi-sor",
    "imprevisora": "im-pre-vi-so-ra",
    "imprevista": "im-pre-vis-ta",
    "imprevisto": "im-pre-vis-to",
    "imprimación": "im-pri-ma-ción",
    "imprimadera": "im-pri-ma-de-ra",
    "imprimador": "im-pri-ma-dor",
    "imprimadora": "im-pri-ma-do-ra",
    "imprimante": "im-pri-man-te",
    "imprimar": "im-pri-mar",
    "imprimátur": "im-pri-má-tur",
    "imprimidor": "im-pri-mi-dor",
    "imprimir": "im-pri-mir",
    "improbabilidad": "im-pro-ba-bi-li-dad",
    "improbable": "im-pro-ba-ble",
    "improbablemente": "im-pro-ba-ble-men-te",
    "improbar": "im-pro-bar",
    "improbidad": "im-pro-bi-dad",
    "ímprobo": "ím-pro-bo",
    "improcedencia": "im-pro-ce-den-cia",
    "improcedente": "im-pro-ce-den-te",
    "improductiva": "im-pro-duc-ti-va",
    "improductividad": "im-pro-duc-ti-vi-dad",
    "improductivo": "im-pro-duc-ti-vo",
    "improfanable": "im-pro-fa-na-ble",
    "improlija": "im-pro-li-ja",
    "improlijo": "im-pro-li-jo",
    "improlongable": "im-pro-lon-ga-ble",
    "impromptu": "im-promp-tu",
    "impronta": "im-pron-ta",
    "impronunciable": "im-pro-nun-cia-ble",
    "improperar": "im-pro-pe-rar",
    "improperio": "im-pro-pe-rio",
    "impropia": "im-pro-pia",
    "impropiamente": "im-pro-pia-men-te",
    "impropiar": "im-pro-piar",
    "impropiedad": "im-pro-pie-dad",
    "impropio": "im-pro-pio",
    "improporción": "im-pro-por-ción",
    "improporcionada": "im-pro-por-cio-na-da",
    "improporcionado": "im-pro-por-cio-na-do",
    "impropria": "im-pro-pria",
    "impropriamente": "im-pro-pria-men-te",
    "impropriedad": "im-pro-prie-dad",
    "improprio": "im-pro-prio",
    "improrrogable": "im-pro-rro-ga-ble",
    "impróspera": "im-prós-pe-ra",
    "impróspero": "im-prós-pe-ro",
    "improsulta": "im-pro-sul-ta",
    "improsulto": "im-pro-sul-to",
    "impróvida": "im-pró-vi-da",
    "impróvidamente": "im-pró-vi-da-men-te",
    "improvidencia": "im-pro-vi-den-cia",
    "impróvido": "im-pró-vi-do",
    "improvisa": "im-pro-vi-sa",
    "improvisación": "im-pro-vi-sa-ción",
    "improvisadamente": "im-pro-vi-sa-da-men-te",
    "improvisador": "im-pro-vi-sa-dor",
    "improvisadora": "im-pro-vi-sa-do-ra",
    "improvisamente": "im-pro-vi-sa-men-te",
    "improvisar": "im-pro-vi-sar",
    "improvisatorio": "im-pro-vi-sa-to-rio",
    "improviso": "im-pro-vi-so",
    "improvista": "im-pro-vis-ta",
    "improvisto": "im-pro-vis-to",
    "imprudencia": "im-pru-den-cia",
    "imprudente": "im-pru-den-te",
    "imprudentemente": "im-pru-den-te-men-te",
    "impúber": "im-pú-ber",
    "impúbera": "im-pú-be-ra",
    "impúbero": "im-pú-be-ro",
    "impublicable": "im-pu-bli-ca-ble",
    "impudencia": "im-pu-den-cia",
    "impudente": "im-pu-den-te",
    "impúdica": "im-pú-di-ca",
    "impúdicamente": "im-pú-di-ca-men-te",
    "impudicia": "im-pu-di-cia",
    "impudicicia": "im-pu-di-ci-cia",
    "impúdico": "im-pú-di-co",
    "impudor": "im-pu-dor",
    "impuesta": "im-pues-ta",
    "impuesto": "im-pues-to",
    "impugnable": "im-pug-na-ble",
    "impugnación": "im-pug-na-ción",
    "impugnador": "im-pug-na-dor",
    "impugnadora": "im-pug-na-do-ra",
    "impugnar": "im-pug-nar",
    "impugnativa": "im-pug-na-ti-va",
    "impugnativo": "im-pug-na-ti-vo",
    "impulsar": "im-pul-sar",
    "impulsión": "im-pul-sión",
    "impulsiva": "im-pul-si-va",
    "impulsividad": "im-pul-si-vi-dad",
    "impulsivo": "im-pul-si-vo",
    "impulso": "im-pul-so",
    "impulsor": "im-pul-sor",
    "impulsora": "im-pul-so-ra",
    "impune": "im-pu-ne",
    "impunemente": "im-pu-ne-men-te",
    "impunida": "im-pu-ni-da",
    "impunidad": "im-pu-ni-dad",
    "impunido": "im-pu-ni-do",
    "impuntual": "im-pun-tual",
    "impuntualidad": "im-pun-tua-li-dad",
    "impura": "im-pu-ra",
    "impuramente": "im-pu-ra-men-te",
    "impureza": "im-pu-re-za",
    "impuridad": "im-pu-ri-dad",
    "impurificación": "im-pu-ri-fi-ca-ción",
    "impurificar": "im-pu-ri-fi-car",
    "impuro": "im-pu-ro",
    "imputabilidad": "im-pu-ta-bi-li-dad",
    "imputable": "im-pu-ta-ble",
    "imputación": "im-pu-ta-ción",
    "imputada": "im-pu-ta-da",
    "imputado": "im-pu-ta-do",
    "imputador": "im-pu-ta-dor",
    "imputadora": "im-pu-ta-do-ra",
    "imputar": "im-pu-tar",
    "imputrescible": "im-pu-tres-ci-ble",
    "imputrible": "im-pu-tri-ble",
    "inabarcable": "i-na-bar-ca-ble",
    "inabordable": "i-na-bor-da-ble",
    "inacabable": "i-na-ca-ba-ble",
    "inacabado": "i-na-ca-ba-do",
    "inaccesa": "i-nac-ce-sa",
    "inaccesibilidad": "i-nac-ce-si-bi-li-dad",
    "inaccesible": "i-nac-ce-si-ble",
    "inaccesiblemente": "i-nac-ce-si-ble-men-te",
    "inacceso": "i-nac-ce-so",
    "inacción": "i-nac-ción",
    "inacentuada": "i-na-cen-tua-da",
    "inacentuado": "i-na-cen-tua-do",
    "inaceptable": "i-na-cep-ta-ble",
    "inactiva": "i-nac-ti-va",
    "inactividad": "i-nac-ti-vi-dad",
    "inactivo": "i-nac-ti-vo",
    "inactual": "i-nac-tual",
    "inadaptabilidad": "i-na-dap-ta-bi-li-dad",
    "inadaptable": "i-na-dap-ta-ble",
    "inadaptación": "i-na-dap-ta-ción",
    "inadaptada": "i-na-dap-ta-da",
    "inadaptado": "i-na-dap-ta-do",
    "inadecuación": "i-na-de-cua-ción",
    "inadecuada": "i-na-de-cua-da",
    "inadecuado": "i-na-de-cua-do",
    "inadmisible": "i-nad-mi-si-ble",
    "inadmitir": "i-nad-mi-tir",
    "inadoptable": "i-na-dop-ta-ble",
    "inadvertencia": "i-nad-ver-ten-cia",
    "inadvertida": "i-nad-ver-ti-da",
    "inadvertidamente": "i-nad-ver-ti-da-men-te",
    "inadvertido": "i-nad-ver-ti-do",
    "inafectada": "i-na-fec-ta-da",
    "inafectado": "i-na-fec-ta-do",
    "inagotable": "i-na-go-ta-ble",
    "inaguantable": "i-na-guan-ta-ble",
    "inalámbrica": "i-na-lám-bri-ca",
    "inalámbrico": "i-na-lám-bri-co",
    "inalcanzable": "i-nal-can-za-ble",
    "inalienabilidad": "i-na-lie-na-bi-li-dad",
    "inalienable": "i-na-lie-na-ble",
    "inalterabilidad": "i-nal-te-ra-bi-li-dad",
    "inalterable": "i-nal-te-ra-ble",
    "inalterablemente": "i-nal-te-ra-ble-men-te",
    "inalterada": "i-nal-te-ra-da",
    "inalterado": "i-nal-te-ra-do",
    "inamena": "i-na-me-na",
    "inameno": "i-na-me-no",
    "inamisible": "i-na-mi-si-ble",
    "inamistoso": "i-na-mis-to-so",
    "inamovible": "i-na-mo-vi-ble",
    "inamovilidad": "i-na-mo-vi-li-dad",
    "inanalizable": "i-na-na-li-za-ble",
    "inane": "i-na-ne",
    "inanición": "i-na-ni-ción",
    "inanidad": "i-na-ni-dad",
    "inanimada": "i-na-ni-ma-da",
    "inanimado": "i-na-ni-ma-do",
    "inánime": "i-ná-ni-me",
    "inapagable": "i-na-pa-ga-ble",
    "inapeable": "i-na-pe-a-ble",
    "inapelable": "i-na-pe-la-ble",
    "inapetencia": "i-na-pe-ten-cia",
    "inapetente": "i-na-pe-ten-te",
    "inaplazable": "i-na-pla-za-ble",
    "inaplicable": "i-na-pli-ca-ble",
    "inaplicación": "i-na-pli-ca-ción",
    "inaplicada": "i-na-pli-ca-da",
    "inaplicado": "i-na-pli-ca-do",
    "inapreciable": "i-na-pre-cia-ble",
    "inaprehensible": "i-na-pre-hen-si-ble",
    "inaprensible": "i-na-pren-si-ble",
    "inaprensiva": "i-na-pren-si-va",
    "inaprensivo": "i-na-pren-si-vo",
    "inapresable": "i-na-pre-sa-ble",
    "inapropiable": "i-na-pro-pia-ble",
    "inapropiado": "i-na-pro-pia-do",
    "inaprovechada": "i-na-pro-ve-cha-da",
    "inaprovechado": "i-na-pro-ve-cha-do",
    "inarmónica": "i-nar-mó-ni-ca",
    "inarmónico": "i-nar-mó-ni-co",
    "inarrugable": "i-na-rru-ga-ble",
    "inarticulable": "i-nar-ti-cu-la-ble",
    "inarticulada": "i-nar-ti-cu-la-da",
    "inarticulado": "i-nar-ti-cu-la-do",
    "inartificiosa": "i-nar-ti-fi-cio-sa",
    "inartificioso": "i-nar-ti-fi-cio-so",
    "inasequible": "i-na-se-qui-ble",
    "inasible": "i-na-si-ble",
    "inasistencia": "i-na-sis-ten-cia",
    "inasistente": "i-na-sis-ten-te",
    "inastillable": "i-nas-ti-lla-ble",
    "inasumible": "i-na-su-mi-ble",
    "inatacable": "i-na-ta-ca-ble",
    "inatención": "i-na-ten-ción",
    "inatenta": "i-na-ten-ta",
    "inatento": "i-na-ten-to",
    "inaudible": "i-nau-di-ble",
    "inaudita": "i-nau-di-ta",
    "inaudito": "i-nau-di-to",
    "inauguración": "i-nau-gu-ra-ción",
    "inaugurador": "i-nau-gu-ra-dor",
    "inauguradora": "i-nau-gu-ra-do-ra",
    "inaugural": "i-nau-gu-ral",
    "inaugurar": "i-nau-gu-rar",
    "inaveriguable": "i-na-ve-ri-gua-ble",
    "inaveriguada": "i-na-ve-ri-gua-da",
    "inaveriguado": "i-na-ve-ri-gua-do",
    "inca": "in-ca",
    "incachable": "in-ca-cha-ble",
    "incaica": "in-cai-ca",
    "incaico": "in-cai-co",
    "incalculable": "in-cal-cu-la-ble",
    "incaler": "in-ca-ler",
    "incalificable": "in-ca-li-fi-ca-ble",
    "incalmable": "in-cal-ma-ble",
    "incalumniable": "in-ca-lum-nia-ble",
    "incanato": "in-ca-na-to",
    "incandescencia": "in-can-des-cen-cia",
    "incandescente": "in-can-des-cen-te",
    "incansable": "in-can-sa-ble",
    "incansablemente": "in-can-sa-ble-men-te",
    "incantable": "in-can-ta-ble",
    "incantación": "in-can-ta-ción",
    "incapacidad": "in-ca-pa-ci-dad",
    "incapacitación": "in-ca-pa-ci-ta-ción",
    "incapacitada": "in-ca-pa-ci-ta-da",
    "incapacitado": "in-ca-pa-ci-ta-do",
    "incapacitar": "in-ca-pa-ci-tar",
    "incapaz": "in-ca-paz",
    "incardinación": "in-car-di-na-ción",
    "incardinar": "in-car-di-nar",
    "incario": "in-ca-rio",
    "incasable": "in-ca-sa-ble",
    "incásico": "in-cá-si-co",
    "incasta": "in-cas-ta",
    "incasto": "in-cas-to",
    "incausto": "in-caus-to",
    "incauta": "in-cau-ta",
    "incautación": "in-cau-ta-ción",
    "incautamente": "in-cau-ta-men-te",
    "incautar": "in-cau-tar",
    "incautarse": "in-cau-tar-se",
    "incauto": "in-cau-to",
    "incendaja": "in-cen-da-ja",
    "incendiar": "in-cen-diar",
    "incendiaria": "in-cen-dia-ria",
    "incendiario": "in-cen-dia-rio",
    "incendio": "in-cen-dio",
    "incensación": "in-cen-sa-ción",
    "incensada": "in-cen-sa-da",
    "incensar": "in-cen-sar",
    "incensario": "in-cen-sa-rio",
    "incensiva": "in-cen-si-va",
    "incensivo": "in-cen-si-vo",
    "incenso": "in-cen-so",
    "incensurable": "in-cen-su-ra-ble",
    "incentiva": "in-cen-ti-va",
    "incentivación": "in-cen-ti-va-ción",
    "incentivar": "in-cen-ti-var",
    "incentivo": "in-cen-ti-vo",
    "incentro": "in-cen-tro",
    "inceptor": "in-cep-tor",
    "incerteza": "in-cer-te-za",
    "incertidumbre": "in-cer-ti-dum-bre",
    "incertinidad": "in-cer-ti-ni-dad",
    "incertísima": "in-cer-tí-si-ma",
    "incertísimo": "in-cer-tí-si-mo",
    "incertitud": "in-cer-ti-tud",
    "incesable": "in-ce-sa-ble",
    "incesablemente": "in-ce-sa-ble-men-te",
    "incesante": "in-ce-san-te",
    "incesantemente": "in-ce-san-te-men-te",
    "incestar": "in-ces-tar",
    "incesto": "in-ces-to",
    "incestuosa": "in-ces-tuo-sa",
    "incestuosamente": "in-ces-tuo-sa-men-te",
    "incestuoso": "in-ces-tuo-so",
    "incidencia": "in-ci-den-cia",
    "incidental": "in-ci-den-tal",
    "incidentalmente": "in-ci-den-tal-men-te",
    "incidente": "in-ci-den-te",
    "incidentemente": "in-ci-den-te-men-te",
    "incidir": "in-ci-dir",
    "incienso": "in-cien-so",
    "inciente": "in-cien-te",
    "incierta": "in-cier-ta",
    "inciertamente": "in-cier-ta-men-te",
    "incierto": "in-cier-to",
    "incinerable": "in-ci-ne-ra-ble",
    "incineración": "in-ci-ne-ra-ción",
    "incinerador": "in-ci-ne-ra-dor",
    "incineradora": "in-ci-ne-ra-do-ra",
    "incinerar": "in-ci-ne-rar",
    "incipiente": "in-ci-pien-te",
    "íncipit": "ín-ci-pit",
    "incircuncisa": "in-cir-cun-ci-sa",
    "incircunciso": "in-cir-cun-ci-so",
    "incircunscripta": "in-cir-cuns-crip-ta",
    "incircunscripto": "in-cir-cuns-crip-to",
    "incircunscrito": "in-cir-cuns-cri-to",
    "incisa": "in-ci-sa",
    "incisión": "in-ci-sión",
    "incisiva": "in-ci-si-va",
    "incisivamente": "in-ci-si-va-men-te",
    "incisivo": "in-ci-si-vo",
    "inciso": "in-ci-so",
    "incisoria": "in-ci-so-ria",
    "incisorio": "in-ci-so-rio",
    "incisura": "in-ci-su-ra",
    "incitación": "in-ci-ta-ción",
    "incitador": "in-ci-ta-dor",
    "incitadora": "in-ci-ta-do-ra",
    "incitamento": "in-ci-ta-men-to",
    "incitamiento": "in-ci-ta-mien-to",
    "incitante": "in-ci-tan-te",
    "incitantemente": "in-ci-tan-te-men-te",
    "incitar": "in-ci-tar",
    "incitativa": "in-ci-ta-ti-va",
    "incitativo": "in-ci-ta-ti-vo",
    "incívica": "in-cí-vi-ca",
    "incívico": "in-cí-vi-co",
    "incivil": "in-ci-vil",
    "incivilidad": "in-ci-vi-li-dad",
    "incivilizada": "in-ci-vi-li-za-da",
    "incivilizado": "in-ci-vi-li-za-do",
    "incivilmente": "in-ci-vil-men-te",
    "incivismo": "in-ci-vis-mo",
    "inclasificable": "in-cla-si-fi-ca-ble",
    "inclaustración": "in-claus-tra-ción",
    "inclaustrar": "in-claus-trar",
    "inclemencia": "in-cle-men-cia",
    "inclemente": "in-cle-men-te",
    "inclín": "in-clín",
    "inclinación": "in-cli-na-ción",
    "inclinado": "in-cli-na-do",
    "inclinador": "in-cli-na-dor",
    "inclinadora": "in-cli-na-do-ra",
    "inclinar": "in-cli-nar",
    "inclinativa": "in-cli-na-ti-va",
    "inclinativo": "in-cli-na-ti-vo",
    "inclinómetro": "in-cli-nó-me-tro",
    "ínclita": "ín-cli-ta",
    "ínclito": "ín-cli-to",
    "incluir": "in-cluir",
    "inclusa": "in-clu-sa",
    "inclusera": "in-clu-se-ra",
    "inclusero": "in-clu-se-ro",
    "inclusión": "in-clu-sión",
    "inclusiva": "in-clu-si-va",
    "inclusivamente": "in-clu-si-va-men-te",
    "inclusive": "in-clu-si-ve",
    "inclusivo": "in-clu-si-vo",
    "incluso": "in-clu-so",
    "incluyente": "in-clu-yen-te",
    "incoación": "in-co-a-ción",
    "incoar": "in-co-ar",
    "incoativa": "in-co-a-ti-va",
    "incoativo": "in-co-a-ti-vo",
    "incobrable": "in-co-bra-ble",
    "incoercible": "in-co-er-ci-ble",
    "incogitada": "in-co-gi-ta-da",
    "incogitado": "in-co-gi-ta-do",
    "incógnita": "in-cóg-ni-ta",
    "incógnito": "in-cóg-ni-to",
    "incognoscible": "in-cog-nos-ci-ble",
    "incoherencia": "in-co-he-ren-cia",
    "incoherente": "in-co-he-ren-te",
    "incoherentemente": "in-co-he-ren-te-men-te",
    "íncola": "ín-co-la",
    "incolora": "in-co-lo-ra",
    "incoloro": "in-co-lo-ro",
    "incólume": "in-có-lu-me",
    "incolumidad": "in-co-lu-mi-dad",
    "incombinable": "in-com-bi-na-ble",
    "incombusta": "in-com-bus-ta",
    "incombustibilidad": "in-com-bus-ti-bi-li-dad",
    "incombustible": "in-com-bus-ti-ble",
    "incombusto": "in-com-bus-to",
    "incomerciable": "in-co-mer-cia-ble",
    "incomestible": "in-co-mes-ti-ble",
    "incomible": "in-co-mi-ble",
    "incómoda": "in-có-mo-da",
    "incomodador": "in-co-mo-da-dor",
    "incomodadora": "in-co-mo-da-do-ra",
    "incómodamente": "in-có-mo-da-men-te",
    "incomodar": "in-co-mo-dar",
    "incomodidad": "in-co-mo-di-dad",
    "incomodo": "in-co-mo-do",
    "incómodo": "in-có-mo-do",
    "incomparable": "in-com-pa-ra-ble",
    "incomparablemente": "in-com-pa-ra-ble-men-te",
    "incomparada": "in-com-pa-ra-da",
    "incomparado": "in-com-pa-ra-do",
    "incomparecencia": "in-com-pa-re-cen-cia",
    "incompartible": "in-com-par-ti-ble",
    "incompasible": "in-com-pa-si-ble",
    "incompasiva": "in-com-pa-si-va",
    "incompasivo": "in-com-pa-si-vo",
    "incompatibilidad": "in-com-pa-ti-bi-li-dad",
    "incompatible": "in-com-pa-ti-ble",
    "incompensable": "in-com-pen-sa-ble",
    "incompetencia": "in-com-pe-ten-cia",
    "incompetente": "in-com-pe-ten-te",
    "incompleja": "in-com-ple-ja",
    "incomplejo": "in-com-ple-jo",
    "incompleta": "in-com-ple-ta",
    "incompletamente": "in-com-ple-ta-men-te",
    "incompleto": "in-com-ple-to",
    "incomplexa": "in-com-ple-xa",
    "incomplexo": "in-com-ple-xo",
    "incomponible": "in-com-po-ni-ble",
    "incomportable": "in-com-por-ta-ble",
    "incomposibilidad": "in-com-po-si-bi-li-dad",
    "incomposible": "in-com-po-si-ble",
    "incomposición": "in-com-po-si-ción",
    "incomprehensibilidad": "in-com-pre-hen-si-bi-li-dad",
    "incomprehensible": "in-com-pre-hen-si-ble",
    "incomprendida": "in-com-pren-di-da",
    "incomprendido": "in-com-pren-di-do",
    "incomprensibilidad": "in-com-pren-si-bi-li-dad",
    "incomprensible": "in-com-pren-si-ble",
    "incomprensiblemente": "in-com-pren-si-ble-men-te",
    "incomprensión": "in-com-pren-sión",
    "incomprensivo": "in-com-pren-si-vo",
    "incompresibilidad": "in-com-pre-si-bi-li-dad",
    "incompresible": "in-com-pre-si-ble",
    "incompuesta": "in-com-pues-ta",
    "incompuestamente": "in-com-pues-ta-men-te",
    "incompuesto": "in-com-pues-to",
    "incomunicabilidad": "in-co-mu-ni-ca-bi-li-dad",
    "incomunicable": "in-co-mu-ni-ca-ble",
    "incomunicación": "in-co-mu-ni-ca-ción",
    "incomunicada": "in-co-mu-ni-ca-da",
    "incomunicado": "in-co-mu-ni-ca-do",
    "incomunicar": "in-co-mu-ni-car",
    "inconar": "in-co-nar",
    "inconcebible": "in-con-ce-bi-ble",
    "inconciliable": "in-con-ci-lia-ble",
    "inconcina": "in-con-ci-na",
    "inconcino": "in-con-ci-no",
    "inconclusión": "in-con-clu-sión",
    "inconcluso": "in-con-clu-so",
    "inconcreción": "in-con-cre-ción",
    "inconcreto": "in-con-cre-to",
    "inconcusa": "in-con-cu-sa",
    "inconcusamente": "in-con-cu-sa-men-te",
    "inconcuso": "in-con-cu-so",
    "incondicionado": "in-con-di-cio-na-do",
    "incondicional": "in-con-di-cio-nal",
    "incondicionalmente": "in-con-di-cio-nal-men-te",
    "inconducente": "in-con-du-cen-te",
    "inconducta": "in-con-duc-ta",
    "inconexa": "in-co-ne-xa",
    "inconexión": "in-co-ne-xión",
    "inconexo": "in-co-ne-xo",
    "inconfesa": "in-con-fe-sa",
    "inconfesable": "in-con-fe-sa-ble",
    "inconfesadamente": "in-con-fe-sa-da-men-te",
    "inconfesado": "in-con-fe-sa-do",
    "inconfeso": "in-con-fe-so",
    "inconfidencia": "in-con-fi-den-cia",
    "inconfidente": "in-con-fi-den-te",
    "inconformar": "in-con-for-mar",
    "inconforme": "in-con-for-me",
    "inconformidad": "in-con-for-mi-dad",
    "inconformismo": "in-con-for-mis-mo",
    "inconformista": "in-con-for-mis-ta",
    "inconfortable": "in-con-for-ta-ble",
    "inconfundible": "in-con-fun-di-ble",
    "incongrua": "in-con-grua",
    "incongruamente": "in-con-grua-men-te",
    "incongruencia": "in-con-gruen-cia",
    "incongruente": "in-con-gruen-te",
    "incongruentemente": "in-con-gruen-te-men-te",
    "incongruidad": "in-con-grui-dad",
    "incongruo": "in-con-gruo",
    "inconmensurabilidad": "in-con-men-su-ra-bi-li-dad",
    "inconmensurable": "in-con-men-su-ra-ble",
    "inconmovible": "in-con-mo-vi-ble",
    "inconmutabilidad": "in-con-mu-ta-bi-li-dad",
    "inconmutable": "in-con-mu-ta-ble",
    "inconocible": "in-co-no-ci-ble",
    "inconquistable": "in-con-quis-ta-ble",
    "inconsciencia": "in-cons-cien-cia",
    "inconsciente": "in-cons-cien-te",
    "inconscientemente": "in-cons-cien-te-men-te",
    "inconsecuencia": "in-con-se-cuen-cia",
    "inconsecuente": "in-con-se-cuen-te",
    "inconsideración": "in-con-si-de-ra-ción",
    "inconsiderada": "in-con-si-de-ra-da",
    "inconsideradamente": "in-con-si-de-ra-da-men-te",
    "inconsiderado": "in-con-si-de-ra-do",
    "inconsiguiente": "in-con-si-guien-te",
    "inconsistencia": "in-con-sis-ten-cia",
    "inconsistente": "in-con-sis-ten-te",
    "inconsolable": "in-con-so-la-ble",
    "inconsolablemente": "in-con-so-la-ble-men-te",
    "inconstancia": "in-cons-tan-cia",
    "inconstante": "in-cons-tan-te",
    "inconstantemente": "in-cons-tan-te-men-te",
    "inconstitucional": "in-cons-ti-tu-cio-nal",
    "inconstitucionalidad": "in-cons-ti-tu-cio-na-li-dad",
    "inconstruible": "in-cons-trui-ble",
    "inconsulta": "in-con-sul-ta",
    "inconsultamente": "in-con-sul-ta-men-te",
    "inconsulto": "in-con-sul-to",
    "inconsútil": "in-con-sú-til",
    "incontable": "in-con-ta-ble",
    "incontaminada": "in-con-ta-mi-na-da",
    "incontaminado": "in-con-ta-mi-na-do",
    "incontenible": "in-con-te-ni-ble",
    "inconteniblemente": "in-con-te-ni-ble-men-te",
    "incontestabilidad": "in-con-tes-ta-bi-li-dad",
    "incontestable": "in-con-tes-ta-ble",
    "incontinencia": "in-con-ti-nen-cia",
    "incontinente": "in-con-ti-nen-te",
    "incontinentemente": "in-con-ti-nen-te-men-te",
    "incontinenti": "in-con-ti-nen-ti",
    "incontinua": "in-con-ti-nua",
    "incontinuo": "in-con-ti-nuo",
    "incontrarrestable": "in-con-tra-rres-ta-ble",
    "incontrastable": "in-con-tras-ta-ble",
    "incontrastablemente": "in-con-tras-ta-ble-men-te",
    "incontratable": "in-con-tra-ta-ble",
    "incontrita": "in-con-tri-ta",
    "incontrito": "in-con-tri-to",
    "incontrolable": "in-con-tro-la-ble",
    "incontrolada": "in-con-tro-la-da",
    "incontroladamente": "in-con-tro-la-da-men-te",
    "incontrolado": "in-con-tro-la-do",
    "incontrovertible": "in-con-tro-ver-ti-ble",
    "inconvencible": "in-con-ven-ci-ble",
    "inconvenible": "in-con-ve-ni-ble",
    "inconveniencia": "in-con-ve-nien-cia",
    "inconveniente": "in-con-ve-nien-te",
    "inconversable": "in-con-ver-sa-ble",
    "inconvertible": "in-con-ver-ti-ble",
    "incoordinación": "in-co-or-di-na-ción",
    "incordia": "in-cor-dia",
    "incordiar": "in-cor-diar",
    "incordio": "in-cor-dio",
    "incorporable": "in-cor-po-ra-ble",
    "incorporación": "in-cor-po-ra-ción",
    "incorporal": "in-cor-po-ral",
    "incorporalmente": "in-cor-po-ral-men-te",
    "incorporar": "in-cor-po-rar",
    "incorporeidad": "in-cor-po-rei-dad",
    "incorpóreo": "in-cor-pó-re-o",
    "incorporo": "in-cor-po-ro",
    "incorrección": "in-co-rrec-ción",
    "incorrecta": "in-co-rrec-ta",
    "incorrectamente": "in-co-rrec-ta-men-te",
    "incorrecto": "in-co-rrec-to",
    "incorregibilidad": "in-co-rre-gi-bi-li-dad",
    "incorregible": "in-co-rre-gi-ble",
    "incorregiblemente": "in-co-rre-gi-ble-men-te",
    "incorrupción": "in-co-rrup-ción",
    "incorrupta": "in-co-rrup-ta",
    "incorruptamente": "in-co-rrup-ta-men-te",
    "incorruptibilidad": "in-co-rrup-ti-bi-li-dad",
    "incorruptible": "in-co-rrup-ti-ble",
    "incorrupto": "in-co-rrup-to",
    "incrasar": "in-cra-sar",
    "increada": "in-cre-a-da",
    "increado": "in-cre-a-do",
    "incredibilidad": "in-cre-di-bi-li-dad",
    "incrédula": "in-cré-du-la",
    "incrédulamente": "in-cré-du-la-men-te",
    "incredulidad": "in-cre-du-li-dad",
    "incrédulo": "in-cré-du-lo",
    "increíble": "in-cre-í-ble",
    "increíblemente": "in-cre-í-ble-men-te",
    "incrementar": "in-cre-men-tar",
    "incremento": "in-cre-men-to",
    "increpación": "in-cre-pa-ción",
    "increpador": "in-cre-pa-dor",
    "increpadora": "in-cre-pa-do-ra",
    "increpar": "in-cre-par",
    "incriminación": "in-cri-mi-na-ción",
    "incriminar": "in-cri-mi-nar",
    "incristalizable": "in-cris-ta-li-za-ble",
    "incruenta": "in-cruen-ta",
    "incruentamente": "in-cruen-ta-men-te",
    "incruento": "in-cruen-to",
    "incrustación": "in-crus-ta-ción",
    "incrustante": "in-crus-tan-te",
    "incrustar": "in-crus-tar",
    "incubación": "in-cu-ba-ción",
    "incubadora": "in-cu-ba-do-ra",
    "incubar": "in-cu-bar",
    "íncubo": "ín-cu-bo",
    "incuestionable": "in-cues-tio-na-ble",
    "inculcación": "in-cul-ca-ción",
    "inculcador": "in-cul-ca-dor",
    "inculcadora": "in-cul-ca-do-ra",
    "inculcar": "in-cul-car",
    "inculpabilidad": "in-cul-pa-bi-li-dad",
    "inculpable": "in-cul-pa-ble",
    "inculpablemente": "in-cul-pa-ble-men-te",
    "inculpación": "in-cul-pa-ción",
    "inculpada": "in-cul-pa-da",
    "inculpadamente": "in-cul-pa-da-men-te",
    "inculpado": "in-cul-pa-do",
    "inculpar": "in-cul-par",
    "inculpatorio": "in-cul-pa-to-rio",
    "inculta": "in-cul-ta",
    "incultamente": "in-cul-ta-men-te",
    "incultivable": "in-cul-ti-va-ble",
    "incultivada": "in-cul-ti-va-da",
    "incultivado": "in-cul-ti-va-do",
    "inculto": "in-cul-to",
    "incultura": "in-cul-tu-ra",
    "incumbencia": "in-cum-ben-cia",
    "incumbir": "in-cum-bir",
    "incumplido": "in-cum-pli-do",
    "incumplimiento": "in-cum-pli-mien-to",
    "incumplir": "in-cum-plir",
    "incunable": "in-cu-na-ble",
    "incurabilidad": "in-cu-ra-bi-li-dad",
    "incurable": "in-cu-ra-ble",
    "incuria": "in-cu-ria",
    "incuriosa": "in-cu-rio-sa",
    "incurioso": "in-cu-rio-so",
    "incurrimiento": "in-cu-rri-mien-to",
    "incurrir": "in-cu-rrir",
    "incursión": "in-cur-sión",
    "incursionar": "in-cur-sio-nar",
    "incurso": "in-cur-so",
    "incurvar": "in-cur-var",
    "incusa": "in-cu-sa",
    "incusar": "in-cu-sar",
    "incuso": "in-cu-so",
    "inda": "in-da",
    "indagación": "in-da-ga-ción",
    "indagador": "in-da-ga-dor",
    "indagadora": "in-da-ga-do-ra",
    "indagar": "in-da-gar",
    "indagatoria": "in-da-ga-to-ria",
    "indagatorio": "in-da-ga-to-rio",
    "indalo": "in-da-lo",
    "indebida": "in-de-bi-da",
    "indebidamente": "in-de-bi-da-men-te",
    "indebido": "in-de-bi-do",
    "indecencia": "in-de-cen-cia",
    "indecente": "in-de-cen-te",
    "indecentemente": "in-de-cen-te-men-te",
    "indecible": "in-de-ci-ble",
    "indeciblemente": "in-de-ci-ble-men-te",
    "indecidible": "in-de-ci-di-ble",
    "indecisa": "in-de-ci-sa",
    "indecisamente": "in-de-ci-sa-men-te",
    "indecisión": "in-de-ci-sión",
    "indeciso": "in-de-ci-so",
    "indecisorio": "in-de-ci-so-rio",
    "indeclarable": "in-de-cla-ra-ble",
    "indeclinable": "in-de-cli-na-ble",
    "indecora": "in-de-co-ra",
    "indecoro": "in-de-co-ro",
    "indecorosa": "in-de-co-ro-sa",
    "indecorosamente": "in-de-co-ro-sa-men-te",
    "indecoroso": "in-de-co-ro-so",
    "indefectibilidad": "in-de-fec-ti-bi-li-dad",
    "indefectible": "in-de-fec-ti-ble",
    "indefectiblemente": "in-de-fec-ti-ble-men-te",
    "indefendible": "in-de-fen-di-ble",
    "indefensa": "in-de-fen-sa",
    "indefensable": "in-de-fen-sa-ble",
    "indefensible": "in-de-fen-si-ble",
    "indefensión": "in-de-fen-sión",
    "indefenso": "in-de-fen-so",
    "indeficiente": "in-de-fi-cien-te",
    "indefinible": "in-de-fi-ni-ble",
    "indefinición": "in-de-fi-ni-ción",
    "indefinida": "in-de-fi-ni-da",
    "indefinidamente": "in-de-fi-ni-da-men-te",
    "indefinido": "in-de-fi-ni-do",
    "indeformable": "in-de-for-ma-ble",
    "indehiscente": "in-dehis-cen-te",
    "indeleble": "in-de-le-ble",
    "indeleblemente": "in-de-le-ble-men-te",
    "indelegable": "in-de-le-ga-ble",
    "indeliberación": "in-de-li-be-ra-ción",
    "indeliberada": "in-de-li-be-ra-da",
    "indeliberadamente": "in-de-li-be-ra-da-men-te",
    "indeliberado": "in-de-li-be-ra-do",
    "indelicada": "in-de-li-ca-da",
    "indelicadeza": "in-de-li-ca-de-za",
    "indelicado": "in-de-li-ca-do",
    "indemne": "in-dem-ne",
    "indemnidad": "in-dem-ni-dad",
    "indemnización": "in-dem-ni-za-ción",
    "indemnizar": "in-dem-ni-zar",
    "indemnizatorio": "in-dem-ni-za-to-rio",
    "indemorable": "in-de-mo-ra-ble",
    "indemostrable": "in-de-mos-tra-ble",
    "independencia": "in-de-pen-den-cia",
    "independente": "in-de-pen-den-te",
    "independentismo": "in-de-pen-den-tis-mo",
    "independentista": "in-de-pen-den-tis-ta",
    "independiente": "in-de-pen-dien-te",
    "independientemente": "in-de-pen-dien-te-men-te",
    "independización": "in-de-pen-di-za-ción",
    "independizar": "in-de-pen-di-zar",
    "inderogabilidad": "in-de-ro-ga-bi-li-dad",
    "inderogable": "in-de-ro-ga-ble",
    "indescifrable": "in-des-ci-fra-ble",
    "indescriptible": "in-des-crip-ti-ble",
    "indeseable": "in-de-se-a-ble",
    "indeseado": "in-de-se-a-do",
    "indesignable": "in-de-sig-na-ble",
    "indesmallable": "in-des-ma-lla-ble",
    "indesmayable": "in-des-ma-ya-ble",
    "indestructibilidad": "in-des-truc-ti-bi-li-dad",
    "indestructible": "in-des-truc-ti-ble",
    "indetectable": "in-de-tec-ta-ble",
    "indeterminable": "in-de-ter-mi-na-ble",
    "indeterminación": "in-de-ter-mi-na-ción",
    "indeterminada": "in-de-ter-mi-na-da",
    "indeterminadamente": "in-de-ter-mi-na-da-men-te",
    "indeterminado": "in-de-ter-mi-na-do",
    "indeterminismo": "in-de-ter-mi-nis-mo",
    "indeterminista": "in-de-ter-mi-nis-ta",
    "indevoción": "in-de-vo-ción",
    "indevota": "in-de-vo-ta",
    "indevoto": "in-de-vo-to",
    "índex": "ín-dex",
    "indexación": "in-de-xa-ción",
    "indexar": "in-de-xar",
    "indezuela": "in-de-zue-la",
    "indezuelo": "in-de-zue-lo",
    "india": "in-dia",
    "india": "in-dia",
    "indiada": "in-dia-da",
    "indiana": "in-dia-na",
    "indianés": "in-dia-nés",
    "indianesa": "in-dia-ne-sa",
    "indianismo": "in-dia-nis-mo",
    "indianista": "in-dia-nis-ta",
    "indiano": "in-dia-no",
    "índica": "ín-di-ca",
    "indicación": "in-di-ca-ción",
    "indicador": "in-di-ca-dor",
    "indicadora": "in-di-ca-do-ra",
    "indicante": "in-di-can-te",
    "indicar": "in-di-car",
    "indicativa": "in-di-ca-ti-va",
    "indicativo": "in-di-ca-ti-vo",
    "indicción": "in-dic-ción",
    "índice": "ín-di-ce",
    "indiciada": "in-di-cia-da",
    "indiciado": "in-di-cia-do",
    "indiciador": "in-di-cia-dor",
    "indiciadora": "in-di-cia-do-ra",
    "indiciar": "in-di-ciar",
    "indiciaria": "in-di-cia-ria",
    "indiciario": "in-di-cia-rio",
    "indicio": "in-di-cio",
    "indiciosa": "in-di-cio-sa",
    "indicioso": "in-di-cio-so",
    "índico": "ín-di-co",
    "indiestra": "in-dies-tra",
    "indiestro": "in-dies-tro",
    "indiferencia": "in-di-fe-ren-cia",
    "indiferenciación": "in-di-fe-ren-cia-ción",
    "indiferenciado": "in-di-fe-ren-cia-do",
    "indiferente": "in-di-fe-ren-te",
    "indiferentemente": "in-di-fe-ren-te-men-te",
    "indiferentismo": "in-di-fe-ren-tis-mo",
    "indígena": "in-dí-ge-na",
    "indigenado": "in-di-ge-na-do",
    "indigencia": "in-di-gen-cia",
    "indigenismo": "in-di-ge-nis-mo",
    "indigenista": "in-di-ge-nis-ta",
    "indigente": "in-di-gen-te",
    "indigerible": "in-di-ge-ri-ble",
    "indigerida": "in-di-ge-ri-da",
    "indigerido": "in-di-ge-ri-do",
    "indigesta": "in-di-ges-ta",
    "indigestar": "in-di-ges-tar",
    "indigestarse": "in-di-ges-tar-se",
    "indigestible": "in-di-ges-ti-ble",
    "indigestión": "in-di-ges-tión",
    "indigesto": "in-di-ges-to",
    "indigna": "in-dig-na",
    "indignación": "in-dig-na-ción",
    "indignamente": "in-dig-na-men-te",
    "indignante": "in-dig-nan-te",
    "indignar": "in-dig-nar",
    "indignidad": "in-dig-ni-dad",
    "indigno": "in-dig-no",
    "índigo": "ín-di-go",
    "indijada": "in-di-ja-da",
    "indijado": "in-di-ja-do",
    "indilgar": "in-dil-gar",
    "indiligencia": "in-di-li-gen-cia",
    "indina": "in-di-na",
    "indinar": "in-di-nar",
    "indino": "in-di-no",
    "indio": "in-dio",
    "indiófilo": "in-dió-fi-lo",
    "indirecta": "in-di-rec-ta",
    "indirectamente": "in-di-rec-ta-men-te",
    "indirecte": "in-di-rec-te",
    "indirecto": "in-di-rec-to",
    "indiscernible": "in-dis-cer-ni-ble",
    "indisciplina": "in-dis-ci-pli-na",
    "indisciplinable": "in-dis-ci-pli-na-ble",
    "indisciplinada": "in-dis-ci-pli-na-da",
    "indisciplinado": "in-dis-ci-pli-na-do",
    "indisciplinar": "in-dis-ci-pli-nar",
    "indisciplinarse": "in-dis-ci-pli-nar-se",
    "indiscreción": "in-dis-cre-ción",
    "indiscreta": "in-dis-cre-ta",
    "indiscretamente": "in-dis-cre-ta-men-te",
    "indiscreto": "in-dis-cre-to",
    "indiscriminadamente": "in-dis-cri-mi-na-da-men-te",
    "indiscriminado": "in-dis-cri-mi-na-do",
    "indisculpable": "in-dis-cul-pa-ble",
    "indiscutible": "in-dis-cu-ti-ble",
    "indiscutiblemente": "in-dis-cu-ti-ble-men-te",
    "indiscutido": "in-dis-cu-ti-do",
    "indisimuladamente": "in-di-si-mu-la-da-men-te",
    "indisimulado": "in-di-si-mu-la-do",
    "indisociable": "in-di-so-cia-ble",
    "indisolubilidad": "in-di-so-lu-bi-li-dad",
    "indisoluble": "in-di-so-lu-ble",
    "indisolublemente": "in-di-so-lu-ble-men-te",
    "indispensabilidad": "in-dis-pen-sa-bi-li-dad",
    "indispensable": "in-dis-pen-sa-ble",
    "indispensablemente": "in-dis-pen-sa-ble-men-te",
    "indisponer": "in-dis-po-ner",
    "indisposición": "in-dis-po-si-ción",
    "indispuesta": "in-dis-pues-ta",
    "indispuesto": "in-dis-pues-to",
    "indisputable": "in-dis-pu-ta-ble",
    "indisputablemente": "in-dis-pu-ta-ble-men-te",
    "indistinción": "in-dis-tin-ción",
    "indistinguible": "in-dis-tin-gui-ble",
    "indistinta": "in-dis-tin-ta",
    "indistintamente": "in-dis-tin-ta-men-te",
    "indistinto": "in-dis-tin-to",
    "individua": "in-di-vi-dua",
    "individuación": "in-di-vi-dua-ción",
    "individual": "in-di-vi-dual",
    "individualidad": "in-di-vi-dua-li-dad",
    "individualismo": "in-di-vi-dua-lis-mo",
    "individualista": "in-di-vi-dua-lis-ta",
    "individualización": "in-di-vi-dua-li-za-ción",
    "individualizar": "in-di-vi-dua-li-zar",
    "individualmente": "in-di-vi-dual-men-te",
    "individuamente": "in-di-vi-dua-men-te",
    "individuar": "in-di-vi-duar",
    "individuidad": "in-di-vi-dui-dad",
    "individuo": "in-di-vi-duo",
    "indivisa": "in-di-vi-sa",
    "indivisamente": "in-di-vi-sa-men-te",
    "indivisibilidad": "in-di-vi-si-bi-li-dad",
    "indivisible": "in-di-vi-si-ble",
    "indivisiblemente": "in-di-vi-si-ble-men-te",
    "indivisión": "in-di-vi-sión",
    "indiviso": "in-di-vi-so",
    "indiyudicable": "in-di-yu-di-ca-ble",
    "indización": "in-di-za-ción",
    "indizar": "in-di-zar",
    "indo": "in-do",
    "indoamericano": "in-do-a-me-ri-ca-no",
    "indoantillana": "in-do-an-ti-lla-na",
    "indoantillano": "in-do-an-ti-lla-no",
    "indoario": "in-do-a-rio",
    "indoblegable": "in-do-ble-ga-ble",
    "indochina": "in-do-chi-na",
    "indochino": "in-do-chi-no",
    "indócil": "in-dó-cil",
    "indocilidad": "in-do-ci-li-dad",
    "indocta": "in-doc-ta",
    "indoctamente": "in-doc-ta-men-te",
    "indocto": "in-doc-to",
    "indoctrinada": "in-doc-tri-na-da",
    "indoctrinado": "in-doc-tri-na-do",
    "indoctrinar": "in-doc-tri-nar",
    "indocubana": "in-do-cu-ba-na",
    "indocubano": "in-do-cu-ba-no",
    "indocumentada": "in-do-cu-men-ta-da",
    "indocumentado": "in-do-cu-men-ta-do",
    "indoeuropea": "in-do-eu-ro-pe-a",
    "indoeuropeo": "in-do-eu-ro-pe-o",
    "indogermánica": "in-do-ger-má-ni-ca",
    "indogermánico": "in-do-ger-má-ni-co",
    "indoiranio": "in-doi-ra-nio",
    "índole": "ín-do-le",
    "indolencia": "in-do-len-cia",
    "indolente": "in-do-len-te",
    "indolentemente": "in-do-len-te-men-te",
    "indolora": "in-do-lo-ra",
    "indoloro": "in-do-lo-ro",
    "indomabilidad": "in-do-ma-bi-li-dad",
    "indomable": "in-do-ma-ble",
    "indomada": "in-do-ma-da",
    "indomado": "in-do-ma-do",
    "indomeñable": "in-do-me-ña-ble",
    "indoméstica": "in-do-més-ti-ca",
    "indomesticable": "in-do-mes-ti-ca-ble",
    "indomesticada": "in-do-mes-ti-ca-da",
    "indomesticado": "in-do-mes-ti-ca-do",
    "indoméstico": "in-do-més-ti-co",
    "indómita": "in-dó-mi-ta",
    "indómito": "in-dó-mi-to",
    "indonesia": "in-do-ne-sia",
    "indonésica": "in-do-né-si-ca",
    "indonésico": "in-do-né-si-co",
    "indonesio": "in-do-ne-sio",
    "indormia": "in-dor-mia",
    "indostana": "in-dos-ta-na",
    "indostanés": "in-dos-ta-nés",
    "indostanesa": "in-dos-ta-ne-sa",
    "indostaní": "in-dos-ta-ní",
    "indostánica": "in-dos-tá-ni-ca",
    "indostánico": "in-dos-tá-ni-co",
    "indostano": "in-dos-ta-no",
    "indotación": "in-do-ta-ción",
    "indotada": "in-do-ta-da",
    "indotado": "in-do-ta-do",
    "indrí": "in-drí",
    "indubitable": "in-du-bi-ta-ble",
    "indubitablemente": "in-du-bi-ta-ble-men-te",
    "indubitada": "in-du-bi-ta-da",
    "indubitadamente": "in-du-bi-ta-da-men-te",
    "indubitado": "in-du-bi-ta-do",
    "inducción": "in-duc-ción",
    "inducia": "in-du-cia",
    "inducido": "in-du-ci-do",
    "inducidor": "in-du-ci-dor",
    "inducidora": "in-du-ci-do-ra",
    "inducimiento": "in-du-ci-mien-to",
    "inducir": "in-du-cir",
    "inductancia": "in-duc-tan-cia",
    "inductiva": "in-duc-ti-va",
    "inductivo": "in-duc-ti-vo",
    "inductor": "in-duc-tor",
    "inductora": "in-duc-to-ra",
    "indudable": "in-du-da-ble",
    "indudablemente": "in-du-da-ble-men-te",
    "indulgencia": "in-dul-gen-cia",
    "indulgente": "in-dul-gen-te",
    "indulgentemente": "in-dul-gen-te-men-te",
    "indultar": "in-dul-tar",
    "indultario": "in-dul-ta-rio",
    "indulto": "in-dul-to",
    "indumentaria": "in-du-men-ta-ria",
    "indumentario": "in-du-men-ta-rio",
    "indumento": "in-du-men-to",
    "induración": "in-du-ra-ción",
    "industria": "in-dus-tria",
    "industrial": "in-dus-trial",
    "industrialismo": "in-dus-tria-lis-mo",
    "industrialista": "in-dus-tria-lis-ta",
    "industrialización": "in-dus-tria-li-za-ción",
    "industrializador": "in-dus-tria-li-za-dor",
    "industrializar": "in-dus-tria-li-zar",
    "industrialmente": "in-dus-trial-men-te",
    "industriar": "in-dus-triar",
    "industriosa": "in-dus-trio-sa",
    "industriosamente": "in-dus-trio-sa-men-te",
    "industrioso": "in-dus-trio-so",
    "inebriar": "i-ne-briar",
    "inecuación": "i-ne-cua-ción",
    "inedia": "i-ne-dia",
    "inédita": "i-né-di-ta",
    "inédito": "i-né-di-to",
    "ineducación": "i-ne-du-ca-ción",
    "ineducada": "i-ne-du-ca-da",
    "ineducado": "i-ne-du-ca-do",
    "inefabilidad": "i-ne-fa-bi-li-dad",
    "inefable": "i-ne-fa-ble",
    "inefablemente": "i-ne-fa-ble-men-te",
    "inefectividad": "i-ne-fec-ti-vi-dad",
    "inefectivo": "i-ne-fec-ti-vo",
    "ineficacia": "i-ne-fi-ca-cia",
    "ineficaz": "i-ne-fi-caz",
    "ineficazmente": "i-ne-fi-caz-men-te",
    "ineficiencia": "i-ne-fi-cien-cia",
    "ineficiente": "i-ne-fi-cien-te",
    "inejecución": "i-ne-je-cu-ción",
    "inelegancia": "i-ne-le-gan-cia",
    "inelegante": "i-ne-le-gan-te",
    "inelegantemente": "i-ne-le-gan-te-men-te",
    "inelegible": "i-ne-le-gi-ble",
    "ineluctable": "i-ne-luc-ta-ble",
    "ineluctablemente": "i-ne-luc-ta-ble-men-te",
    "ineludible": "i-ne-lu-di-ble",
    "ineludiblemente": "i-ne-lu-di-ble-men-te",
    "inembargable": "i-nem-bar-ga-ble",
    "inenarrable": "i-ne-na-rra-ble",
    "inencontrable": "i-nen-con-tra-ble",
    "inepcia": "i-nep-cia",
    "inepta": "i-nep-ta",
    "ineptamente": "i-nep-ta-men-te",
    "ineptitud": "i-nep-ti-tud",
    "inepto": "i-nep-to",
    "inequívoca": "i-ne-quí-vo-ca",
    "inequívocamente": "i-ne-quí-vo-ca-men-te",
    "inequívoco": "i-ne-quí-vo-co",
    "inercia": "i-ner-cia",
    "inercial": "i-ner-cial",
    "inercialmente": "i-ner-cial-men-te",
    "inerme": "i-ner-me",
    "inerrable": "i-ne-rra-ble",
    "inerrancia": "i-ne-rran-cia",
    "inerrante": "i-ne-rran-te",
    "inerte": "i-ner-te",
    "inervación": "i-ner-va-ción",
    "inervador": "i-ner-va-dor",
    "inervadora": "i-ner-va-do-ra",
    "inervar": "i-ner-var",
    "inescrupuloso": "i-nes-cru-pu-lo-so",
    "inescrutable": "i-nes-cru-ta-ble",
    "inescudriñable": "i-nes-cu-dri-ña-ble",
    "inesencial": "i-ne-sen-cial",
    "inesperable": "i-nes-pe-ra-ble",
    "inesperada": "i-nes-pe-ra-da",
    "inesperadamente": "i-nes-pe-ra-da-men-te",
    "inesperado": "i-nes-pe-ra-do",
    "inestabilidad": "i-nes-ta-bi-li-dad",
    "inestable": "i-nes-ta-ble",
    "inestancable": "i-nes-tan-ca-ble",
    "inestimabilidad": "i-nes-ti-ma-bi-li-dad",
    "inestimable": "i-nes-ti-ma-ble",
    "inestimada": "i-nes-ti-ma-da",
    "inestimado": "i-nes-ti-ma-do",
    "inevitabilidad": "i-ne-vi-ta-bi-li-dad",
    "inevitable": "i-ne-vi-ta-ble",
    "inevitablemente": "i-ne-vi-ta-ble-men-te",
    "inexacta": "i-ne-xac-ta",
    "inexactamente": "i-ne-xac-ta-men-te",
    "inexactitud": "i-ne-xac-ti-tud",
    "inexacto": "i-ne-xac-to",
    "inexcogitable": "i-nex-co-gi-ta-ble",
    "inexcusable": "i-nex-cu-sa-ble",
    "inexcusablemente": "i-nex-cu-sa-ble-men-te",
    "inexequible": "i-ne-xe-qui-ble",
    "inexhausta": "i-nex-haus-ta",
    "inexhaustible": "i-nex-haus-ti-ble",
    "inexhausto": "i-nex-haus-to",
    "inexistencia": "i-ne-xis-ten-cia",
    "inexistente": "i-ne-xis-ten-te",
    "inexorabilidad": "i-ne-xo-ra-bi-li-dad",
    "inexorable": "i-ne-xo-ra-ble",
    "inexorablemente": "i-ne-xo-ra-ble-men-te",
    "inexperiencia": "i-nex-pe-rien-cia",
    "inexperiente": "i-nex-pe-rien-te",
    "inexperta": "i-nex-per-ta",
    "inexperto": "i-nex-per-to",
    "inexpiable": "i-nex-pia-ble",
    "inexplicable": "i-nex-pli-ca-ble",
    "inexplicablemente": "i-nex-pli-ca-ble-men-te",
    "inexplicada": "i-nex-pli-ca-da",
    "inexplicado": "i-nex-pli-ca-do",
    "inexplorada": "i-nex-plo-ra-da",
    "inexplorado": "i-nex-plo-ra-do",
    "inexpresable": "i-nex-pre-sa-ble",
    "inexpresado": "i-nex-pre-sa-do",
    "inexpresiva": "i-nex-pre-si-va",
    "inexpresividad": "i-nex-pre-si-vi-dad",
    "inexpresivo": "i-nex-pre-si-vo",
    "inexpreso": "i-nex-pre-so",
    "inexpugnable": "i-nex-pug-na-ble",
    "inextensa": "i-nex-ten-sa",
    "inextensible": "i-nex-ten-si-ble",
    "inextenso": "i-nex-ten-so",
    "inextinguible": "i-nex-tin-gui-ble",
    "inextinguiblemente": "i-nex-tin-gui-ble-men-te",
    "inextricable": "i-nex-tri-ca-ble",
    "infacunda": "in-fa-cun-da",
    "infacundo": "in-fa-cun-do",
    "infalibilidad": "in-fa-li-bi-li-dad",
    "infalible": "in-fa-li-ble",
    "infaliblemente": "in-fa-li-ble-men-te",
    "infalsificable": "in-fal-si-fi-ca-ble",
    "infamación": "in-fa-ma-ción",
    "infamadamente": "in-fa-ma-da-men-te",
    "infamador": "in-fa-ma-dor",
    "infamadora": "in-fa-ma-do-ra",
    "infamante": "in-fa-man-te",
    "infamar": "in-fa-mar",
    "infamativa": "in-fa-ma-ti-va",
    "infamativo": "in-fa-ma-ti-vo",
    "infamatoria": "in-fa-ma-to-ria",
    "infamatorio": "in-fa-ma-to-rio",
    "infame": "in-fa-me",
    "infamemente": "in-fa-me-men-te",
    "infamia": "in-fa-mia",
    "infamosa": "in-fa-mo-sa",
    "infamoso": "in-fa-mo-so",
    "infancia": "in-fan-cia",
    "infanda": "in-fan-da",
    "infando": "in-fan-do",
    "infanta": "in-fan-ta",
    "infantado": "in-fan-ta-do",
    "infantazgo": "in-fan-taz-go",
    "infante": "in-fan-te",
    "infantejo": "in-fan-te-jo",
    "infantería": "in-fan-te-rí-a",
    "infantesa": "in-fan-te-sa",
    "infanticida": "in-fan-ti-ci-da",
    "infanticidio": "in-fan-ti-ci-dio",
    "infantil": "in-fan-til",
    "infantilidad": "in-fan-ti-li-dad",
    "infantilismo": "in-fan-ti-lis-mo",
    "infantilización": "in-fan-ti-li-za-ción",
    "infantilizar": "in-fan-ti-li-zar",
    "infantillo": "in-fan-ti-llo",
    "infantilmente": "in-fan-til-men-te",
    "infantiloide": "in-fan-ti-loi-de",
    "infantina": "in-fan-ti-na",
    "infantino": "in-fan-ti-no",
    "infantojuvenil": "in-fan-to-ju-ve-nil",
    "infanzón": "in-fan-zón",
    "infanzona": "in-fan-zo-na",
    "infanzonada": "in-fan-zo-na-da",
    "infanzonado": "in-fan-zo-na-do",
    "infanzonazgo": "in-fan-zo-naz-go",
    "infanzonía": "in-fan-zo-ní-a",
    "infartado": "in-far-ta-do",
    "infartar": "in-far-tar",
    "infarto": "in-far-to",
    "infatigable": "in-fa-ti-ga-ble",
    "infatigablemente": "in-fa-ti-ga-ble-men-te",
    "infatuación": "in-fa-tua-ción",
    "infatuar": "in-fa-tuar",
    "infausta": "in-faus-ta",
    "infaustamente": "in-faus-ta-men-te",
    "infausto": "in-faus-to",
    "infebril": "in-fe-bril",
    "infección": "in-fec-ción",
    "infeccionar": "in-fec-cio-nar",
    "infecciosa": "in-fec-cio-sa",
    "infeccioso": "in-fec-cio-so",
    "infecciosos": "in-fec-cio-sos",
    "infecir": "in-fe-cir",
    "infecta": "in-fec-ta",
    "infectado": "in-fec-ta-do",
    "infectar": "in-fec-tar",
    "infectiva": "in-fec-ti-va",
    "infectivo": "in-fec-ti-vo",
    "infecto": "in-fec-to",
    "infecunda": "in-fe-cun-da",
    "infecundar": "in-fe-cun-dar",
    "infecundarse": "in-fe-cun-dar-se",
    "infecundidad": "in-fe-cun-di-dad",
    "infecundo": "in-fe-cun-do",
    "infelice": "in-fe-li-ce",
    "infelicemente": "in-fe-li-ce-men-te",
    "infelicidad": "in-fe-li-ci-dad",
    "infeliz": "in-fe-liz",
    "infelizmente": "in-fe-liz-men-te",
    "inferencia": "in-fe-ren-cia",
    "inferior": "in-fe-rior",
    "inferioridad": "in-fe-rio-ri-dad",
    "inferir": "in-fe-rir",
    "inferna": "in-fer-na",
    "infernáculo": "in-fer-ná-cu-lo",
    "infernal": "in-fer-nal",
    "infernar": "in-fer-nar",
    "infernillo": "in-fer-ni-llo",
    "inferno": "in-fer-no",
    "ínfero": "ín-fe-ro",
    "infértil": "in-fér-til",
    "infertilidad": "in-fer-ti-li-dad",
    "infesta": "in-fes-ta",
    "infestación": "in-fes-ta-ción",
    "infestar": "in-fes-tar",
    "infesto": "in-fes-to",
    "infeudación": "in-feu-da-ción",
    "infeudar": "in-feu-dar",
    "infibulación": "in-fi-bu-la-ción",
    "infibular": "in-fi-bu-lar",
    "infición": "in-fi-ción",
    "inficionar": "in-fi-cio-nar",
    "infida": "in-fi-da",
    "infidelidad": "in-fi-de-li-dad",
    "infidelísima": "in-fi-de-lí-si-ma",
    "infidelísimo": "in-fi-de-lí-si-mo",
    "infidencia": "in-fi-den-cia",
    "infidente": "in-fi-den-te",
    "infido": "in-fi-do",
    "infiel": "in-fiel",
    "infielmente": "in-fiel-men-te",
    "infiernillo": "in-fier-ni-llo",
    "infiernito": "in-fier-ni-to",
    "infierno": "in-fier-no",
    "infigurable": "in-fi-gu-ra-ble",
    "infijo": "in-fi-jo",
    "infiltración": "in-fil-tra-ción",
    "infiltrada": "in-fil-tra-da",
    "infiltrado": "in-fil-tra-do",
    "infiltrar": "in-fil-trar",
    "ínfima": "ín-fi-ma",
    "ínfimo": "ín-fi-mo",
    "infinible": "in-fi-ni-ble",
    "infinida": "in-fi-ni-da",
    "infinidad": "in-fi-ni-dad",
    "infinido": "in-fi-ni-do",
    "infinitamente": "in-fi-ni-ta-men-te",
    "infinitesimal": "in-fi-ni-te-si-mal",
    "infinitivo": "in-fi-ni-ti-vo",
    "infinito": "in-fi-ni-to",
    "infinitud": "in-fi-ni-tud",
    "infinta": "in-fin-ta",
    "infintosa": "in-fin-to-sa",
    "infintosamente": "in-fin-to-sa-men-te",
    "infintoso": "in-fin-to-so",
    "infirmar": "in-fir-mar",
    "infistiútico": "in-fis-tiú-ti-co",
    "inflable": "in-fla-ble",
    "inflación": "in-fla-ción",
    "inflacionario": "in-fla-cio-na-rio",
    "inflacionismo": "in-fla-cio-nis-mo",
    "inflacionista": "in-fla-cio-nis-ta",
    "inflador": "in-fla-dor",
    "inflagaitas": "in-fla-gai-tas",
    "inflamable": "in-fla-ma-ble",
    "inflamación": "in-fla-ma-ción",
    "inflamador": "in-fla-ma-dor",
    "inflamadora": "in-fla-ma-do-ra",
    "inflamamiento": "in-fla-ma-mien-to",
    "inflamar": "in-fla-mar",
    "inflamatoria": "in-fla-ma-to-ria",
    "inflamatorio": "in-fla-ma-to-rio",
    "inflamiento": "in-fla-mien-to",
    "inflar": "in-flar",
    "inflativa": "in-fla-ti-va",
    "inflativo": "in-fla-ti-vo",
    "inflexibilidad": "in-fle-xi-bi-li-dad",
    "inflexible": "in-fle-xi-ble",
    "inflexiblemente": "in-fle-xi-ble-men-te",
    "inflexión": "in-fle-xión",
    "infligir": "in-fli-gir",
    "inflorescencia": "in-flo-res-cen-cia",
    "influencia": "in-fluen-cia",
    "influenciable": "in-fluen-cia-ble",
    "influenciar": "in-fluen-ciar",
    "influente": "in-fluen-te",
    "influenza": "in-fluen-za",
    "influir": "in-fluir",
    "influjo": "in-flu-jo",
    "influyente": "in-flu-yen-te",
    "infografía": "in-fo-gra-fí-a",
    "infográfico": "in-fo-grá-fi-co",
    "infolio": "in-fo-lio",
    "infopista": "in-fo-pis-ta",
    "información": "in-for-ma-ción",
    "informado": "in-for-ma-do",
    "informador": "in-for-ma-dor",
    "informadora": "in-for-ma-do-ra",
    "informal": "in-for-mal",
    "informalidad": "in-for-ma-li-dad",
    "informalismo": "in-for-ma-lis-mo",
    "informalista": "in-for-ma-lis-ta",
    "informalmente": "in-for-mal-men-te",
    "informante": "in-for-man-te",
    "informar": "in-for-mar",
    "informática": "in-for-má-ti-ca",
    "informático": "in-for-má-ti-co",
    "informativa": "in-for-ma-ti-va",
    "informativista": "in-for-ma-ti-vis-ta",
    "informativo": "in-for-ma-ti-vo",
    "informatización": "in-for-ma-ti-za-ción",
    "informatizar": "in-for-ma-ti-zar",
    "informe": "in-for-me",
    "informidad": "in-for-mi-dad",
    "informulable": "in-for-mu-la-ble",
    "infortificable": "in-for-ti-fi-ca-ble",
    "infortuna": "in-for-tu-na",
    "infortunada": "in-for-tu-na-da",
    "infortunadamente": "in-for-tu-na-da-men-te",
    "infortunado": "in-for-tu-na-do",
    "infortunio": "in-for-tu-nio",
    "infortuno": "in-for-tu-no",
    "infosura": "in-fo-su-ra",
    "infracción": "in-frac-ción",
    "infraccionar": "in-frac-cio-nar",
    "infraclase": "in-fra-cla-se",
    "infracta": "in-frac-ta",
    "infracto": "in-frac-to",
    "infractor": "in-frac-tor",
    "infractora": "in-frac-to-ra",
    "infradotada": "in-fra-do-ta-da",
    "infradotado": "in-fra-do-ta-do",
    "infraestructura": "in-fra-es-truc-tu-ra",
    "infraestructural": "in-fra-es-truc-tu-ral",
    "infraganti": "in-fra-gan-ti",
    "infrahumano": "in-frahu-ma-no",
    "inframundo": "in-fra-mun-do",
    "infrangible": "in-fran-gi-ble",
    "infranqueable": "in-fran-que-a-ble",
    "infraoctava": "in-fra-oc-ta-va",
    "infraoctavo": "in-fra-oc-ta-vo",
    "infraorbitaria": "in-fra-or-bi-ta-ria",
    "infraorbitario": "in-fra-or-bi-ta-rio",
    "infrarrojo": "in-fra-rro-jo",
    "infrascripta": "in-fras-crip-ta",
    "infrascripto": "in-fras-crip-to",
    "infrascrita": "in-fras-cri-ta",
    "infrascrito": "in-fras-cri-to",
    "infraseguro": "in-fra-se-gu-ro",
    "infrasónico": "in-fra-só-ni-co",
    "infrasonido": "in-fra-so-ni-do",
    "infrasonoro": "in-fra-so-no-ro",
    "infrautilización": "in-frau-ti-li-za-ción",
    "infrautilizar": "in-frau-ti-li-zar",
    "infravaloración": "in-fra-va-lo-ra-ción",
    "infravalorar": "in-fra-va-lo-rar",
    "infravivienda": "in-fra-vi-vien-da",
    "infrecuencia": "in-fre-cuen-cia",
    "infrecuente": "in-fre-cuen-te",
    "infrigidación": "in-fri-gi-da-ción",
    "infringir": "in-frin-gir",
    "infructífera": "in-fruc-tí-fe-ra",
    "infructífero": "in-fruc-tí-fe-ro",
    "infructuosa": "in-fruc-tuo-sa",
    "infructuosamente": "in-fruc-tuo-sa-men-te",
    "infructuosidad": "in-fruc-tuo-si-dad",
    "infructuoso": "in-fruc-tuo-so",
    "infrugífera": "in-fru-gí-fe-ra",
    "infrugífero": "in-fru-gí-fe-ro",
    "infrutescencia": "in-fru-tes-cen-cia",
    "ínfula": "ín-fu-la",
    "ínfulas": "ín-fu-las",
    "infumable": "in-fu-ma-ble",
    "infundada": "in-fun-da-da",
    "infundadamente": "in-fun-da-da-men-te",
    "infundado": "in-fun-da-do",
    "infundibuliforme": "in-fun-di-bu-li-for-me",
    "infundíbulo": "in-fun-dí-bu-lo",
    "infundio": "in-fun-dio",
    "infundiosa": "in-fun-dio-sa",
    "infundioso": "in-fun-dio-so",
    "infundir": "in-fun-dir",
    "infurción": "in-fur-ción",
    "infurcioniega": "in-fur-cio-nie-ga",
    "infurcioniego": "in-fur-cio-nie-go",
    "infurtir": "in-fur-tir",
    "infusa": "in-fu-sa",
    "infuscar": "in-fus-car",
    "infusibilidad": "in-fu-si-bi-li-dad",
    "infusible": "in-fu-si-ble",
    "infusión": "in-fu-sión",
    "infuso": "in-fu-so",
    "infusorio": "in-fu-so-rio",
    "inga": "in-ga",
    "ingenerable": "in-ge-ne-ra-ble",
    "ingeniar": "in-ge-niar",
    "ingeniatura": "in-ge-nia-tu-ra",
    "ingeniera": "in-ge-nie-ra",
    "ingeniería": "in-ge-nie-rí-a",
    "ingenieril": "in-ge-nie-ril",
    "ingeniero": "in-ge-nie-ro",
    "ingenio": "in-ge-nio",
    "ingeniosa": "in-ge-nio-sa",
    "ingeniosamente": "in-ge-nio-sa-men-te",
    "ingeniosidad": "in-ge-nio-si-dad",
    "ingenioso": "in-ge-nio-so",
    "ingénita": "in-gé-ni-ta",
    "ingénito": "in-gé-ni-to",
    "ingente": "in-gen-te",
    "ingenua": "in-ge-nua",
    "ingenuamente": "in-ge-nua-men-te",
    "ingenuidad": "in-ge-nui-dad",
    "ingenuo": "in-ge-nuo",
    "ingerir": "in-ge-rir",
    "ingesta": "in-ges-ta",
    "ingestión": "in-ges-tión",
    "ingle": "in-gle",
    "inglés": "in-glés",
    "inglesa": "in-gle-sa",
    "inglesismo": "in-gle-sis-mo",
    "inglete": "in-gle-te",
    "ingletear": "in-gle-te-ar",
    "inglosable": "in-glo-sa-ble",
    "ingobernabilidad": "in-go-ber-na-bi-li-dad",
    "ingobernable": "in-go-ber-na-ble",
    "ingón": "in-gón",
    "ingrata": "in-gra-ta",
    "ingratamente": "in-gra-ta-men-te",
    "ingratitud": "in-gra-ti-tud",
    "ingrato": "in-gra-to",
    "ingrávida": "in-grá-vi-da",
    "ingravidez": "in-gra-vi-dez",
    "ingrávido": "in-grá-vi-do",
    "ingre": "in-gre",
    "ingrediente": "in-gre-dien-te",
    "ingresar": "in-gre-sar",
    "ingresivo": "in-gre-si-vo",
    "ingreso": "in-gre-so",
    "ingrido": "in-gri-do",
    "íngrimo": "ín-gri-mo",
    "inguinal": "in-gui-nal",
    "inguinaria": "in-gui-na-ria",
    "inguinario": "in-gui-na-rio",
    "ingurgitación": "in-gur-gi-ta-ción",
    "ingurgitar": "in-gur-gi-tar",
    "ingustable": "in-gus-ta-ble",
    "inhábil": "in-há-bil",
    "inhabilidad": "in-ha-bi-li-dad",
    "inhabilitación": "in-ha-bi-li-ta-ción",
    "inhabilitar": "in-ha-bi-li-tar",
    "inhabitable": "in-ha-bi-ta-ble",
    "inhabitada": "in-ha-bi-ta-da",
    "inhabitado": "in-ha-bi-ta-do",
    "inhabitual": "in-ha-bi-tual",
    "inhacedera": "in-ha-ce-de-ra",
    "inhacedero": "in-ha-ce-de-ro",
    "inhalación": "in-ha-la-ción",
    "inhalador": "in-ha-la-dor",
    "inhalar": "in-ha-lar",
    "inhallable": "in-ha-lla-ble",
    "inherencia": "in-he-ren-cia",
    "inherente": "in-he-ren-te",
    "inhesión": "in-he-sión",
    "inhestar": "in-hes-tar",
    "inhibición": "in-hi-bi-ción",
    "inhibidor": "in-hi-bi-dor",
    "inhibir": "in-hi-bir",
    "inhibitoria": "in-hi-bi-to-ria",
    "inhibitorio": "in-hi-bi-to-rio",
    "inhiesta": "in-hies-ta",
    "inhiesto": "in-hies-to",
    "inhonesta": "in-ho-nes-ta",
    "inhonestable": "in-ho-nes-ta-ble",
    "inhonestamente": "in-ho-nes-ta-men-te",
    "inhonestidad": "in-ho-nes-ti-dad",
    "inhonesto": "in-ho-nes-to",
    "inhospedable": "in-hos-pe-da-ble",
    "inhóspita": "in-hós-pi-ta",
    "inhospitable": "in-hos-pi-ta-ble",
    "inhospital": "in-hos-pi-tal",
    "inhospitalaria": "in-hos-pi-ta-la-ria",
    "inhospitalario": "in-hos-pi-ta-la-rio",
    "inhospitalidad": "in-hos-pi-ta-li-dad",
    "inhóspito": "in-hós-pi-to",
    "inhumación": "in-hu-ma-ción",
    "inhumanamente": "in-hu-ma-na-men-te",
    "inhumanidad": "in-hu-ma-ni-dad",
    "inhumano": "in-hu-ma-no",
    "inhumar": "in-hu-mar",
    "iniciación": "i-ni-cia-ción",
    "iniciada": "i-ni-cia-da",
    "iniciado": "i-ni-cia-do",
    "iniciador": "i-ni-cia-dor",
    "iniciadora": "i-ni-cia-do-ra",
    "inicial": "i-ni-cial",
    "inicialar": "i-ni-cia-lar",
    "inicializar": "i-ni-cia-li-zar",
    "inicialmente": "i-ni-cial-men-te",
    "iniciar": "i-ni-ciar",
    "iniciático": "i-ni-ciá-ti-co",
    "iniciativa": "i-ni-cia-ti-va",
    "iniciativo": "i-ni-cia-ti-vo",
    "inicio": "i-ni-cio",
    "inicua": "i-ni-cua",
    "inicuamente": "i-ni-cua-men-te",
    "inicuo": "i-ni-cuo",
    "inidentificable": "i-ni-den-ti-fi-ca-ble",
    "iniesta": "i-nies-ta",
    "inigualable": "i-ni-gua-la-ble",
    "inigualada": "i-ni-gua-la-da",
    "inigualado": "i-ni-gua-la-do",
    "inigualdad": "i-ni-gual-dad",
    "iñiguista": "i-ñi-guis-ta",
    "inimaginable": "i-ni-ma-gi-na-ble",
    "inimicicia": "i-ni-mi-ci-cia",
    "inimicísima": "i-ni-mi-cí-si-ma",
    "inimicísimo": "i-ni-mi-cí-si-mo",
    "inimitable": "i-ni-mi-ta-ble",
    "inimitablemente": "i-ni-mi-ta-ble-men-te",
    "inimputabilidad": "i-nim-pu-ta-bi-li-dad",
    "inimputable": "i-nim-pu-ta-ble",
    "ininflamable": "i-nin-fla-ma-ble",
    "ininteligibilidad": "i-nin-te-li-gi-bi-li-dad",
    "ininteligible": "i-nin-te-li-gi-ble",
    "ininterrumpida": "i-nin-te-rrum-pi-da",
    "ininterrumpido": "i-nin-te-rrum-pi-do",
    "iniquidad": "i-ni-qui-dad",
    "iniquísimo": "i-ni-quí-si-mo",
    "injerencia": "in-je-ren-cia",
    "injeridura": "in-je-ri-du-ra",
    "injerir": "in-je-rir",
    "injerta": "in-jer-ta",
    "injertable": "in-jer-ta-ble",
    "injertador": "in-jer-ta-dor",
    "injertadora": "in-jer-ta-do-ra",
    "injertar": "in-jer-tar",
    "injertera": "in-jer-te-ra",
    "injerto": "in-jer-to",
    "injundia": "in-jun-dia",
    "injuria": "in-ju-ria",
    "injuriado": "in-ju-ria-do",
    "injuriador": "in-ju-ria-dor",
    "injuriadora": "in-ju-ria-do-ra",
    "injuriamiento": "in-ju-ria-mien-to",
    "injuriante": "in-ju-rian-te",
    "injuriar": "in-ju-riar",
    "injuriosa": "in-ju-rio-sa",
    "injuriosamente": "in-ju-rio-sa-men-te",
    "injurioso": "in-ju-rio-so",
    "injusta": "in-jus-ta",
    "injustamente": "in-jus-ta-men-te",
    "injusticia": "in-jus-ti-cia",
    "injustificable": "in-jus-ti-fi-ca-ble",
    "injustificada": "in-jus-ti-fi-ca-da",
    "injustificadamente": "in-jus-ti-fi-ca-da-men-te",
    "injustificado": "in-jus-ti-fi-ca-do",
    "injusto": "in-jus-to",
    "inlandsis": "in-land-sis",
    "inllevable": "in-lle-va-ble",
    "inmaculada": "in-ma-cu-la-da",
    "inmaculadamente": "in-ma-cu-la-da-men-te",
    "inmaculado": "in-ma-cu-la-do",
    "inmadura": "in-ma-du-ra",
    "inmadurez": "in-ma-du-rez",
    "inmaduro": "in-ma-du-ro",
    "inmamable": "in-ma-ma-ble",
    "inmancable": "in-man-ca-ble",
    "inmanejable": "in-ma-ne-ja-ble",
    "inmanencia": "in-ma-nen-cia",
    "inmanente": "in-ma-nen-te",
    "inmanentismo": "in-ma-nen-tis-mo",
    "inmarcesible": "in-mar-ce-si-ble",
    "inmarchitable": "in-mar-chi-ta-ble",
    "inmaterial": "in-ma-te-rial",
    "inmaterialidad": "in-ma-te-ria-li-dad",
    "inmaterialismo": "in-ma-te-ria-lis-mo",
    "inmatura": "in-ma-tu-ra",
    "inmaturo": "in-ma-tu-ro",
    "inmediación": "in-me-dia-ción",
    "inmediata": "in-me-dia-ta",
    "inmediatamente": "in-me-dia-ta-men-te",
    "inmediatez": "in-me-dia-tez",
    "inmediato": "in-me-dia-to",
    "inmedicable": "in-me-di-ca-ble",
    "inmejorable": "in-me-jo-ra-ble",
    "inmejorablemente": "in-me-jo-ra-ble-men-te",
    "inmemorable": "in-me-mo-ra-ble",
    "inmemorablemente": "in-me-mo-ra-ble-men-te",
    "inmemorial": "in-me-mo-rial",
    "inmensa": "in-men-sa",
    "inmensamente": "in-men-sa-men-te",
    "inmensidad": "in-men-si-dad",
    "inmenso": "in-men-so",
    "inmensurable": "in-men-su-ra-ble",
    "inmerecida": "in-me-re-ci-da",
    "inmerecidamente": "in-me-re-ci-da-men-te",
    "inmerecido": "in-me-re-ci-do",
    "inmérita": "in-mé-ri-ta",
    "inméritamente": "in-mé-ri-ta-men-te",
    "inmérito": "in-mé-ri-to",
    "inmeritoria": "in-me-ri-to-ria",
    "inmeritorio": "in-me-ri-to-rio",
    "inmersa": "in-mer-sa",
    "inmersión": "in-mer-sión",
    "inmerso": "in-mer-so",
    "inmigración": "in-mi-gra-ción",
    "inmigrada": "in-mi-gra-da",
    "inmigrado": "in-mi-gra-do",
    "inmigrante": "in-mi-gran-te",
    "inmigrar": "in-mi-grar",
    "inmigratoria": "in-mi-gra-to-ria",
    "inmigratorio": "in-mi-gra-to-rio",
    "inminencia": "in-mi-nen-cia",
    "inminente": "in-mi-nen-te",
    "inmisario": "in-mi-sa-rio",
    "inmiscible": "in-mis-ci-ble",
    "inmiscuir": "in-mis-cuir",
    "inmisericorde": "in-mi-se-ri-cor-de",
    "inmisión": "in-mi-sión",
    "inmobiliaria": "in-mo-bi-lia-ria",
    "inmobiliario": "in-mo-bi-lia-rio",
    "inmoble": "in-mo-ble",
    "inmoderación": "in-mo-de-ra-ción",
    "inmoderada": "in-mo-de-ra-da",
    "inmoderadamente": "in-mo-de-ra-da-men-te",
    "inmoderado": "in-mo-de-ra-do",
    "inmodesta": "in-mo-des-ta",
    "inmodestamente": "in-mo-des-ta-men-te",
    "inmodestia": "in-mo-des-tia",
    "inmodesto": "in-mo-des-to",
    "inmódica": "in-mó-di-ca",
    "inmódico": "in-mó-di-co",
    "inmodificable": "in-mo-di-fi-ca-ble",
    "inmolación": "in-mo-la-ción",
    "inmolador": "in-mo-la-dor",
    "inmoladora": "in-mo-la-do-ra",
    "inmolar": "in-mo-lar",
    "inmoral": "in-mo-ral",
    "inmoralidad": "in-mo-ra-li-dad",
    "inmortal": "in-mor-tal",
    "inmortalidad": "in-mor-ta-li-dad",
    "inmortalizar": "in-mor-ta-li-zar",
    "inmortalmente": "in-mor-tal-men-te",
    "inmortificación": "in-mor-ti-fi-ca-ción",
    "inmortificada": "in-mor-ti-fi-ca-da",
    "inmortificado": "in-mor-ti-fi-ca-do",
    "inmota": "in-mo-ta",
    "inmotivada": "in-mo-ti-va-da",
    "inmotivadamente": "in-mo-ti-va-da-men-te",
    "inmotivado": "in-mo-ti-va-do",
    "inmoto": "in-mo-to",
    "inmovible": "in-mo-vi-ble",
    "inmóvil": "in-mó-vil",
    "inmovilidad": "in-mo-vi-li-dad",
    "inmovilismo": "in-mo-vi-lis-mo",
    "inmovilista": "in-mo-vi-lis-ta",
    "inmovilización": "in-mo-vi-li-za-ción",
    "inmovilizado": "in-mo-vi-li-za-do",
    "inmovilizar": "in-mo-vi-li-zar",
    "inmudable": "in-mu-da-ble",
    "inmueble": "in-mue-ble",
    "inmunda": "in-mun-da",
    "inmundicia": "in-mun-di-cia",
    "inmundo": "in-mun-do",
    "inmune": "in-mu-ne",
    "inmunidad": "in-mu-ni-dad",
    "inmunitario": "in-mu-ni-ta-rio",
    "inmunización": "in-mu-ni-za-ción",
    "inmunizador": "in-mu-ni-za-dor",
    "inmunizadora": "in-mu-ni-za-do-ra",
    "inmunizante": "in-mu-ni-zan-te",
    "inmunizar": "in-mu-ni-zar",
    "inmunodeficiencia": "in-mu-no-de-fi-cien-cia",
    "inmunodeficiente": "in-mu-no-de-fi-cien-te",
    "inmunodepresión": "in-mu-no-de-pre-sión",
    "inmunodepresor": "in-mu-no-de-pre-sor",
    "inmunodeprimido": "in-mu-no-de-pri-mi-do",
    "inmunoglobulina": "in-mu-no-glo-bu-li-na",
    "inmunóloga": "in-mu-nó-lo-ga",
    "inmunología": "in-mu-no-lo-gí-a",
    "inmunológico": "in-mu-no-ló-gi-co",
    "inmunólogo": "in-mu-nó-lo-go",
    "inmunosupresión": "in-mu-no-su-pre-sión",
    "inmunosupresor": "in-mu-no-su-pre-sor",
    "inmunosuprimido": "in-mu-no-su-pri-mi-do",
    "inmunoterapia": "in-mu-no-te-ra-pia",
    "inmutabilidad": "in-mu-ta-bi-li-dad",
    "inmutable": "in-mu-ta-ble",
    "inmutablemente": "in-mu-ta-ble-men-te",
    "inmutación": "in-mu-ta-ción",
    "inmutar": "in-mu-tar",
    "inmutativa": "in-mu-ta-ti-va",
    "inmutativo": "in-mu-ta-ti-vo",
    "innacible": "in-na-ci-ble",
    "innata": "in-na-ta",
    "innatamente": "in-na-ta-men-te",
    "innatismo": "in-na-tis-mo",
    "innato": "in-na-to",
    "innatural": "in-na-tu-ral",
    "innavegable": "in-na-ve-ga-ble",
    "innecesaria": "in-ne-ce-sa-ria",
    "innecesariamente": "in-ne-ce-sa-ria-men-te",
    "innecesario": "in-ne-ce-sa-rio",
    "innegable": "in-ne-ga-ble",
    "innegablemente": "in-ne-ga-ble-men-te",
    "innegociable": "in-ne-go-cia-ble",
    "innoble": "in-no-ble",
    "innocencia": "in-no-cen-cia",
    "innocente": "in-no-cen-te",
    "innocua": "in-no-cua",
    "innocuidad": "in-no-cui-dad",
    "innocuo": "in-no-cuo",
    "innombrable": "in-nom-bra-ble",
    "innominable": "in-no-mi-na-ble",
    "innominada": "in-no-mi-na-da",
    "innominado": "in-no-mi-na-do",
    "innota": "in-no-ta",
    "innoto": "in-no-to",
    "innovación": "in-no-va-ción",
    "innovador": "in-no-va-dor",
    "innovadora": "in-no-va-do-ra",
    "innovamiento": "in-no-va-mien-to",
    "innovar": "in-no-var",
    "innúmera": "in-nú-me-ra",
    "innumerabilidad": "in-nu-me-ra-bi-li-dad",
    "innumerable": "in-nu-me-ra-ble",
    "innumerablemente": "in-nu-me-ra-ble-men-te",
    "innumeridad": "in-nu-me-ri-dad",
    "innúmero": "in-nú-me-ro",
    "inobediencia": "i-no-be-dien-cia",
    "inobediente": "i-no-be-dien-te",
    "inobjetable": "i-nob-je-ta-ble",
    "inobservable": "i-nob-ser-va-ble",
    "inobservancia": "i-nob-ser-van-cia",
    "inobservante": "i-nob-ser-van-te",
    "inocencia": "i-no-cen-cia",
    "inocentada": "i-no-cen-ta-da",
    "inocente": "i-no-cen-te",
    "inocentemente": "i-no-cen-te-men-te",
    "inocentón": "i-no-cen-tón",
    "inocentona": "i-no-cen-to-na",
    "inocua": "i-no-cua",
    "inocuidad": "i-no-cui-dad",
    "inoculación": "i-no-cu-la-ción",
    "inoculador": "i-no-cu-la-dor",
    "inoculadora": "i-no-cu-la-do-ra",
    "inocular": "i-no-cu-lar",
    "inóculo": "i-nó-cu-lo",
    "inocultable": "i-no-cul-ta-ble",
    "inocuo": "i-no-cuo",
    "inodora": "i-no-do-ra",
    "inodoro": "i-no-do-ro",
    "inofensa": "i-no-fen-sa",
    "inofensiva": "i-no-fen-si-va",
    "inofensivo": "i-no-fen-si-vo",
    "inofenso": "i-no-fen-so",
    "inoficiosa": "i-no-fi-cio-sa",
    "inoficioso": "i-no-fi-cio-so",
    "inolvidable": "i-nol-vi-da-ble",
    "inope": "i-no-pe",
    "inoperable": "i-no-pe-ra-ble",
    "inoperancia": "i-no-pe-ran-cia",
    "inoperante": "i-no-pe-ran-te",
    "inoperatividad": "i-no-pe-ra-ti-vi-dad",
    "inoperativo": "i-no-pe-ra-ti-vo",
    "inopia": "i-no-pia",
    "inopinable": "i-no-pi-na-ble",
    "inopinada": "i-no-pi-na-da",
    "inopinadamente": "i-no-pi-na-da-men-te",
    "inopinado": "i-no-pi-na-do",
    "inoportuna": "i-no-por-tu-na",
    "inoportunamente": "i-no-por-tu-na-men-te",
    "inoportunidad": "i-no-por-tu-ni-dad",
    "inoportuno": "i-no-por-tu-no",
    "inordenada": "i-nor-de-na-da",
    "inordenadamente": "i-nor-de-na-da-men-te",
    "inordenado": "i-nor-de-na-do",
    "inordinada": "i-nor-di-na-da",
    "inordinado": "i-nor-di-na-do",
    "inorgánica": "i-nor-gá-ni-ca",
    "inorgánico": "i-nor-gá-ni-co",
    "inoxidable": "i-no-xi-da-ble",
    "input": "in-put",
    "inquebrantable": "in-que-bran-ta-ble",
    "inquerir": "in-que-rir",
    "inquieta": "in-quie-ta",
    "inquietación": "in-quie-ta-ción",
    "inquietador": "in-quie-ta-dor",
    "inquietadora": "in-quie-ta-do-ra",
    "inquietamente": "in-quie-ta-men-te",
    "inquietante": "in-quie-tan-te",
    "inquietar": "in-quie-tar",
    "inquieto": "in-quie-to",
    "inquietud": "in-quie-tud",
    "inquilina": "in-qui-li-na",
    "inquilinaje": "in-qui-li-na-je",
    "inquilinato": "in-qui-li-na-to",
    "inquilinismo": "in-qui-li-nis-mo",
    "inquilino": "in-qui-li-no",
    "inquina": "in-qui-na",
    "inquinamento": "in-qui-na-men-to",
    "inquinar": "in-qui-nar",
    "inquiridor": "in-qui-ri-dor",
    "inquiridora": "in-qui-ri-do-ra",
    "inquirir": "in-qui-rir",
    "inquirriado": "in-qui-rria-do",
    "inquisición": "in-qui-si-ción",
    "inquisidor": "in-qui-si-dor",
    "inquisidora": "in-qui-si-do-ra",
    "inquisitiva": "in-qui-si-ti-va",
    "inquisitivo": "in-qui-si-ti-vo",
    "inquisitoria": "in-qui-si-to-ria",
    "inquisitorial": "in-qui-si-to-rial",
    "inquisitorio": "in-qui-si-to-rio",
    "inri": "in-ri",
    "insabible": "in-sa-bi-ble",
    "insaciabilidad": "in-sa-cia-bi-li-dad",
    "insaciable": "in-sa-cia-ble",
    "insaciablemente": "in-sa-cia-ble-men-te",
    "insaculación": "in-sa-cu-la-ción",
    "insaculador": "in-sa-cu-la-dor",
    "insacular": "in-sa-cu-lar",
    "insalivación": "in-sa-li-va-ción",
    "insalivar": "in-sa-li-var",
    "insalubre": "in-sa-lu-bre",
    "insalubridad": "in-sa-lu-bri-dad",
    "insalvable": "in-sal-va-ble",
    "insana": "in-sa-na",
    "insanable": "in-sa-na-ble",
    "insania": "in-sa-nia",
    "insano": "in-sa-no",
    "insatisfacción": "in-sa-tis-fac-ción",
    "insatisfactoriamente": "in-sa-tis-fac-to-ria-men-te",
    "insatisfactorio": "in-sa-tis-fac-to-rio",
    "insatisfecha": "in-sa-tis-fe-cha",
    "insatisfecho": "in-sa-tis-fe-cho",
    "insaturado": "in-sa-tu-ra-do",
    "inscribible": "ins-cri-bi-ble",
    "inscribir": "ins-cri-bir",
    "inscripción": "ins-crip-ción",
    "inscripta": "ins-crip-ta",
    "inscripto": "ins-crip-to",
    "inscrito": "ins-cri-to",
    "inscrutable": "ins-cru-ta-ble",
    "insculpir": "ins-cul-pir",
    "insecable": "in-se-ca-ble",
    "insectario": "in-sec-ta-rio",
    "insecticida": "in-sec-ti-ci-da",
    "insectil": "in-sec-til",
    "insectívora": "in-sec-tí-vo-ra",
    "insectívoro": "in-sec-tí-vo-ro",
    "insecto": "in-sec-to",
    "insegura": "in-se-gu-ra",
    "inseguramente": "in-se-gu-ra-men-te",
    "inseguridad": "in-se-gu-ri-dad",
    "inseguro": "in-se-gu-ro",
    "inseminación": "in-se-mi-na-ción",
    "inseminar": "in-se-mi-nar",
    "insenescencia": "in-se-nes-cen-cia",
    "insensata": "in-sen-sa-ta",
    "insensatamente": "in-sen-sa-ta-men-te",
    "insensatez": "in-sen-sa-tez",
    "insensato": "in-sen-sa-to",
    "insensibilidad": "in-sen-si-bi-li-dad",
    "insensibilización": "in-sen-si-bi-li-za-ción",
    "insensibilizar": "in-sen-si-bi-li-zar",
    "insensible": "in-sen-si-ble",
    "insensiblemente": "in-sen-si-ble-men-te",
    "inseparabilidad": "in-se-pa-ra-bi-li-dad",
    "inseparable": "in-se-pa-ra-ble",
    "inseparablemente": "in-se-pa-ra-ble-men-te",
    "insepulta": "in-se-pul-ta",
    "insepultada": "in-se-pul-ta-da",
    "insepultado": "in-se-pul-ta-do",
    "insepulto": "in-se-pul-to",
    "inserción": "in-ser-ción",
    "inserir": "in-se-rir",
    "insertada": "in-ser-ta-da",
    "insertado": "in-ser-ta-do",
    "insertar": "in-ser-tar",
    "inserto": "in-ser-to",
    "inservible": "in-ser-vi-ble",
    "insidia": "in-si-dia",
    "insidiador": "in-si-dia-dor",
    "insidiadora": "in-si-dia-do-ra",
    "insidiar": "in-si-diar",
    "insidiosa": "in-si-dio-sa",
    "insidiosamente": "in-si-dio-sa-men-te",
    "insidioso": "in-si-dio-so",
    "insigne": "in-sig-ne",
    "insignemente": "in-sig-ne-men-te",
    "insignia": "in-sig-nia",
    "insignida": "in-sig-ni-da",
    "insignido": "in-sig-ni-do",
    "insignificancia": "in-sig-ni-fi-can-cia",
    "insignificante": "in-sig-ni-fi-can-te",
    "insimular": "in-si-mu-lar",
    "insincera": "in-sin-ce-ra",
    "insinceramente": "in-sin-ce-ra-men-te",
    "insinceridad": "in-sin-ce-ri-dad",
    "insincero": "in-sin-ce-ro",
    "insinia": "in-si-nia",
    "insinuación": "in-si-nua-ción",
    "insinuador": "in-si-nua-dor",
    "insinuadora": "in-si-nua-do-ra",
    "insinuante": "in-si-nuan-te",
    "insinuar": "in-si-nuar",
    "insinuativa": "in-si-nua-ti-va",
    "insinuativo": "in-si-nua-ti-vo",
    "insípida": "in-sí-pi-da",
    "insípidamente": "in-sí-pi-da-men-te",
    "insipidez": "in-si-pi-dez",
    "insípido": "in-sí-pi-do",
    "insipiencia": "in-si-pien-cia",
    "insipiente": "in-si-pien-te",
    "insistencia": "in-sis-ten-cia",
    "insistente": "in-sis-ten-te",
    "insistentemente": "in-sis-ten-te-men-te",
    "insistir": "in-sis-tir",
    "ínsita": "ín-si-ta",
    "ínsito": "ín-si-to",
    "insobornable": "in-so-bor-na-ble",
    "insociabilidad": "in-so-cia-bi-li-dad",
    "insociable": "in-so-cia-ble",
    "insocial": "in-so-cial",
    "insolación": "in-so-la-ción",
    "insolar": "in-so-lar",
    "insoldable": "in-sol-da-ble",
    "insolencia": "in-so-len-cia",
    "insolentar": "in-so-len-tar",
    "insolente": "in-so-len-te",
    "insolentemente": "in-so-len-te-men-te",
    "insolidaria": "in-so-li-da-ria",
    "insolidariamente": "in-so-li-da-ria-men-te",
    "insolidaridad": "in-so-li-da-ri-dad",
    "insolidario": "in-so-li-da-rio",
    "insólita": "in-só-li-ta",
    "insólito": "in-só-li-to",
    "insolubilidad": "in-so-lu-bi-li-dad",
    "insoluble": "in-so-lu-ble",
    "insoluta": "in-so-lu-ta",
    "insoluto": "in-so-lu-to",
    "insolvencia": "in-sol-ven-cia",
    "insolvente": "in-sol-ven-te",
    "insomne": "in-som-ne",
    "insomnio": "in-som-nio",
    "insondable": "in-son-da-ble",
    "insonora": "in-so-no-ra",
    "insonoridad": "in-so-no-ri-dad",
    "insonorización": "in-so-no-ri-za-ción",
    "insonorizar": "in-so-no-ri-zar",
    "insonoro": "in-so-no-ro",
    "insoportable": "in-so-por-ta-ble",
    "insoportablemente": "in-so-por-ta-ble-men-te",
    "insoria": "in-so-ria",
    "insoslayable": "in-sos-la-ya-ble",
    "insospechable": "in-sos-pe-cha-ble",
    "insospechada": "in-sos-pe-cha-da",
    "insospechadamente": "in-sos-pe-cha-da-men-te",
    "insospechado": "in-sos-pe-cha-do",
    "insostenible": "in-sos-te-ni-ble",
    "inspección": "ins-pec-ción",
    "inspeccionar": "ins-pec-cio-nar",
    "inspector": "ins-pec-tor",
    "inspectora": "ins-pec-to-ra",
    "inspectoría": "ins-pec-to-rí-a",
    "inspiración": "ins-pi-ra-ción",
    "inspiradamente": "ins-pi-ra-da-men-te",
    "inspirador": "ins-pi-ra-dor",
    "inspiradora": "ins-pi-ra-do-ra",
    "inspirar": "ins-pi-rar",
    "inspirativa": "ins-pi-ra-ti-va",
    "inspirativo": "ins-pi-ra-ti-vo",
    "inspiratorio": "ins-pi-ra-to-rio",
    "inspirómetro": "ins-pi-ró-me-tro",
    "instabilidad": "ins-ta-bi-li-dad",
    "instable": "ins-ta-ble",
    "instalación": "ins-ta-la-ción",
    "instalador": "ins-ta-la-dor",
    "instaladora": "ins-ta-la-do-ra",
    "instalar": "ins-ta-lar",
    "instancia": "ins-tan-cia",
    "instantánea": "ins-tan-tá-ne-a",
    "instantáneamente": "ins-tan-tá-ne-a-men-te",
    "instantaneidad": "ins-tan-ta-nei-dad",
    "instantáneo": "ins-tan-tá-ne-o",
    "instante": "ins-tan-te",
    "instantemente": "ins-tan-te-men-te",
    "instar": "ins-tar",
    "instauración": "ins-tau-ra-ción",
    "instaurador": "ins-tau-ra-dor",
    "instauradora": "ins-tau-ra-do-ra",
    "instaurar": "ins-tau-rar",
    "instaurativa": "ins-tau-ra-ti-va",
    "instaurativo": "ins-tau-ra-ti-vo",
    "instigación": "ins-ti-ga-ción",
    "instigador": "ins-ti-ga-dor",
    "instigadora": "ins-ti-ga-do-ra",
    "instigar": "ins-ti-gar",
    "instilación": "ins-ti-la-ción",
    "instilar": "ins-ti-lar",
    "instimular": "ins-ti-mu-lar",
    "instímulo": "ins-tí-mu-lo",
    "instintiva": "ins-tin-ti-va",
    "instintivamente": "ins-tin-ti-va-men-te",
    "instintivo": "ins-tin-ti-vo",
    "instinto": "ins-tin-to",
    "institor": "ins-ti-tor",
    "institución": "ins-ti-tu-ción",
    "institucional": "ins-ti-tu-cio-nal",
    "institucionalidad": "ins-ti-tu-cio-na-li-dad",
    "institucionalización": "ins-ti-tu-cio-na-li-za-ción",
    "institucionalizar": "ins-ti-tu-cio-na-li-zar",
    "institucionalmente": "ins-ti-tu-cio-nal-men-te",
    "institucionista": "ins-ti-tu-cio-nis-ta",
    "instituidor": "ins-ti-tui-dor",
    "instituidora": "ins-ti-tui-do-ra",
    "instituir": "ins-ti-tuir",
    "instituta": "ins-ti-tu-ta",
    "instituto": "ins-ti-tu-to",
    "institutor": "ins-ti-tu-tor",
    "institutora": "ins-ti-tu-to-ra",
    "institutriz": "ins-ti-tu-triz",
    "instridente": "ins-tri-den-te",
    "instrucción": "ins-truc-ción",
    "instructiva": "ins-truc-ti-va",
    "instructivamente": "ins-truc-ti-va-men-te",
    "instructivo": "ins-truc-ti-vo",
    "instructor": "ins-truc-tor",
    "instructora": "ins-truc-to-ra",
    "instruida": "ins-trui-da",
    "instruido": "ins-trui-do",
    "instruir": "ins-truir",
    "instrumentación": "ins-tru-men-ta-ción",
    "instrumental": "ins-tru-men-tal",
    "instrumentalización": "ins-tru-men-ta-li-za-ción",
    "instrumentalizar": "ins-tru-men-ta-li-zar",
    "instrumentalmente": "ins-tru-men-tal-men-te",
    "instrumentar": "ins-tru-men-tar",
    "instrumentista": "ins-tru-men-tis-ta",
    "instrumento": "ins-tru-men-to",
    "insuave": "in-sua-ve",
    "insuavidad": "in-sua-vi-dad",
    "insubordinación": "in-su-bor-di-na-ción",
    "insubordinada": "in-su-bor-di-na-da",
    "insubordinado": "in-su-bor-di-na-do",
    "insubordinar": "in-su-bor-di-nar",
    "insubsanable": "in-sub-sa-na-ble",
    "insubsistencia": "in-sub-sis-ten-cia",
    "insubsistente": "in-sub-sis-ten-te",
    "insubstancial": "in-subs-tan-cial",
    "insubstancialidad": "in-subs-tan-cia-li-dad",
    "insubstancialmente": "in-subs-tan-cial-men-te",
    "insubstituible": "in-subs-ti-tui-ble",
    "insudar": "in-su-dar",
    "insuficiencia": "in-su-fi-cien-cia",
    "insuficiente": "in-su-fi-cien-te",
    "insuflación": "in-su-fla-ción",
    "insuflador": "in-su-fla-dor",
    "insuflar": "in-su-flar",
    "insufrible": "in-su-fri-ble",
    "insufriblemente": "in-su-fri-ble-men-te",
    "insufridera": "in-su-fri-de-ra",
    "insufridero": "in-su-fri-de-ro",
    "ínsula": "ín-su-la",
    "insulana": "in-su-la-na",
    "insulano": "in-su-la-no",
    "insular": "in-su-lar",
    "insularidad": "in-su-la-ri-dad",
    "insulina": "in-su-li-na",
    "insulinodependiente": "in-su-li-no-de-pen-dien-te",
    "insulinoma": "in-su-li-no-ma",
    "insulsa": "in-sul-sa",
    "insulsamente": "in-sul-sa-men-te",
    "insulsez": "in-sul-sez",
    "insulso": "in-sul-so",
    "insultada": "in-sul-ta-da",
    "insultador": "in-sul-ta-dor",
    "insultadora": "in-sul-ta-do-ra",
    "insultante": "in-sul-tan-te",
    "insultar": "in-sul-tar",
    "insulto": "in-sul-to",
    "insumable": "in-su-ma-ble",
    "insumergible": "in-su-mer-gi-ble",
    "insumir": "in-su-mir",
    "insumisa": "in-su-mi-sa",
    "insumisión": "in-su-mi-sión",
    "insumiso": "in-su-mi-so",
    "insumo": "in-su-mo",
    "insuperable": "in-su-pe-ra-ble",
    "insuperablemente": "in-su-pe-ra-ble-men-te",
    "insupurable": "in-su-pu-ra-ble",
    "insurgencia": "in-sur-gen-cia",
    "insurgente": "in-sur-gen-te",
    "insurgir": "in-sur-gir",
    "insurrección": "in-su-rrec-ción",
    "insurreccional": "in-su-rrec-cio-nal",
    "insurreccionar": "in-su-rrec-cio-nar",
    "insurrecta": "in-su-rrec-ta",
    "insurrecto": "in-su-rrec-to",
    "insustancial": "in-sus-tan-cial",
    "insustancialidad": "in-sus-tan-cia-li-dad",
    "insustancialmente": "in-sus-tan-cial-men-te",
    "insustituible": "in-sus-ti-tui-ble",
    "intachable": "in-ta-cha-ble",
    "intacta": "in-tac-ta",
    "intacto": "in-tac-to",
    "intangibilidad": "in-tan-gi-bi-li-dad",
    "intangible": "in-tan-gi-ble",
    "integérrima": "in-te-gé-rri-ma",
    "integérrimo": "in-te-gé-rri-mo",
    "íntegra": "ín-te-gra",
    "integrable": "in-te-gra-ble",
    "integración": "in-te-gra-ción",
    "integracionista": "in-te-gra-cio-nis-ta",
    "integrado": "in-te-gra-do",
    "integrador": "in-te-gra-dor",
    "integral": "in-te-gral",
    "integralmente": "in-te-gral-men-te",
    "íntegramente": "ín-te-gra-men-te",
    "integrante": "in-te-gran-te",
    "integrar": "in-te-grar",
    "integridad": "in-te-gri-dad",
    "integrismo": "in-te-gris-mo",
    "integrista": "in-te-gris-ta",
    "íntegro": "ín-te-gro",
    "integumento": "in-te-gu-men-to",
    "intelección": "in-te-lec-ción",
    "intelectiva": "in-te-lec-ti-va",
    "intelectivamente": "in-te-lec-ti-va-men-te",
    "intelectivo": "in-te-lec-ti-vo",
    "intelecto": "in-te-lec-to",
    "intelectual": "in-te-lec-tual",
    "intelectualidad": "in-te-lec-tua-li-dad",
    "intelectualismo": "in-te-lec-tua-lis-mo",
    "intelectualista": "in-te-lec-tua-lis-ta",
    "intelectualización": "in-te-lec-tua-li-za-ción",
    "intelectualizar": "in-te-lec-tua-li-zar",
    "intelectualmente": "in-te-lec-tual-men-te",
    "intelectualoide": "in-te-lec-tua-loi-de",
    "inteleto": "in-te-le-to",
    "inteligencia": "in-te-li-gen-cia",
    "inteligenciada": "in-te-li-gen-cia-da",
    "inteligenciado": "in-te-li-gen-cia-do",
    "inteligenciar": "in-te-li-gen-ciar",
    "inteligente": "in-te-li-gen-te",
    "inteligibilidad": "in-te-li-gi-bi-li-dad",
    "inteligible": "in-te-li-gi-ble",
    "inteligiblemente": "in-te-li-gi-ble-men-te",
    "intemerata": "in-te-me-ra-ta",
    "intemperada": "in-tem-pe-ra-da",
    "intemperadamente": "in-tem-pe-ra-da-men-te",
    "intemperado": "in-tem-pe-ra-do",
    "intemperancia": "in-tem-pe-ran-cia",
    "intemperante": "in-tem-pe-ran-te",
    "intemperatura": "in-tem-pe-ra-tu-ra",
    "intemperie": "in-tem-pe-rie",
    "intempesta": "in-tem-pes-ta",
    "intempestiva": "in-tem-pes-ti-va",
    "intempestivamente": "in-tem-pes-ti-va-men-te",
    "intempestivo": "in-tem-pes-ti-vo",
    "intemporal": "in-tem-po-ral",
    "intemporalidad": "in-tem-po-ra-li-dad",
    "intención": "in-ten-ción",
    "intencionada": "in-ten-cio-na-da",
    "intencionadamente": "in-ten-cio-na-da-men-te",
    "intencionado": "in-ten-cio-na-do",
    "intencional": "in-ten-cio-nal",
    "intencionalidad": "in-ten-cio-na-li-dad",
    "intencionalmente": "in-ten-cio-nal-men-te",
    "intendencia": "in-ten-den-cia",
    "intendenta": "in-ten-den-ta",
    "intendente": "in-ten-den-te",
    "intender": "in-ten-der",
    "intensa": "in-ten-sa",
    "intensamente": "in-ten-sa-men-te",
    "intensar": "in-ten-sar",
    "intensidad": "in-ten-si-dad",
    "intensificación": "in-ten-si-fi-ca-ción",
    "intensificador": "in-ten-si-fi-ca-dor",
    "intensificar": "in-ten-si-fi-car",
    "intensión": "in-ten-sión",
    "intensiva": "in-ten-si-va",
    "intensivamente": "in-ten-si-va-men-te",
    "intensivista": "in-ten-si-vis-ta",
    "intensivo": "in-ten-si-vo",
    "intenso": "in-ten-so",
    "intenta": "in-ten-ta",
    "intentar": "in-ten-tar",
    "intento": "in-ten-to",
    "intentona": "in-ten-to-na",
    "ínter": "ín-ter",
    "interacción": "in-te-rac-ción",
    "interaccionar": "in-te-rac-cio-nar",
    "interactividad": "in-te-rac-ti-vi-dad",
    "interactivo": "in-te-rac-ti-vo",
    "interactuar": "in-te-rac-tuar",
    "interaliado": "in-te-ra-lia-do",
    "interamericano": "in-te-ra-me-ri-ca-no",
    "interandina": "in-te-ran-di-na",
    "interandino": "in-te-ran-di-no",
    "interanual": "in-te-ra-nual",
    "interarticular": "in-te-rar-ti-cu-lar",
    "interbancario": "in-ter-ban-ca-rio",
    "intercadencia": "in-ter-ca-den-cia",
    "intercadente": "in-ter-ca-den-te",
    "intercadentemente": "in-ter-ca-den-te-men-te",
    "intercalación": "in-ter-ca-la-ción",
    "intercalado": "in-ter-ca-la-do",
    "intercaladura": "in-ter-ca-la-du-ra",
    "intercalar": "in-ter-ca-lar",
    "intercambiable": "in-ter-cam-bia-ble",
    "intercambiador": "in-ter-cam-bia-dor",
    "intercambiar": "in-ter-cam-biar",
    "intercambio": "in-ter-cam-bio",
    "interceder": "in-ter-ce-der",
    "intercelular": "in-ter-ce-lu-lar",
    "intercepción": "in-ter-cep-ción",
    "interceptación": "in-ter-cep-ta-ción",
    "interceptar": "in-ter-cep-tar",
    "interceptor": "in-ter-cep-tor",
    "interceptora": "in-ter-cep-to-ra",
    "intercesión": "in-ter-ce-sión",
    "intercesor": "in-ter-ce-sor",
    "intercesora": "in-ter-ce-so-ra",
    "intercesoriamente": "in-ter-ce-so-ria-men-te",
    "interciso": "in-ter-ci-so",
    "interclasista": "in-ter-cla-sis-ta",
    "interclusión": "in-ter-clu-sión",
    "intercolumnio": "in-ter-co-lum-nio",
    "intercolunio": "in-ter-co-lu-nio",
    "intercomunicación": "in-ter-co-mu-ni-ca-ción",
    "intercomunicador": "in-ter-co-mu-ni-ca-dor",
    "intercomunicar": "in-ter-co-mu-ni-car",
    "intercomunitario": "in-ter-co-mu-ni-ta-rio",
    "interconectado": "in-ter-co-nec-ta-do",
    "interconectar": "in-ter-co-nec-tar",
    "interconexión": "in-ter-co-ne-xión",
    "intercontinental": "in-ter-con-ti-nen-tal",
    "intercostal": "in-ter-cos-tal",
    "intercultural": "in-ter-cul-tu-ral",
    "intercurrente": "in-ter-cu-rren-te",
    "intercutánea": "in-ter-cu-tá-ne-a",
    "intercutáneo": "in-ter-cu-tá-ne-o",
    "interdecir": "in-ter-de-cir",
    "interdental": "in-ter-den-tal",
    "interdepartamental": "in-ter-de-par-ta-men-tal",
    "interdependencia": "in-ter-de-pen-den-cia",
    "interdependiente": "in-ter-de-pen-dien-te",
    "interdicción": "in-ter-dic-ción",
    "interdicto": "in-ter-dic-to",
    "interdigital": "in-ter-di-gi-tal",
    "interdisciplinar": "in-ter-dis-ci-pli-nar",
    "interdisciplinaridad": "in-ter-dis-ci-pli-na-ri-dad",
    "interdisciplinariedad": "in-ter-dis-ci-pli-na-rie-dad",
    "interdisciplinario": "in-ter-dis-ci-pli-na-rio",
    "interés": "in-te-rés",
    "interesable": "in-te-re-sa-ble",
    "interesada": "in-te-re-sa-da",
    "interesadamente": "in-te-re-sa-da-men-te",
    "interesado": "in-te-re-sa-do",
    "interesal": "in-te-re-sal",
    "interesante": "in-te-re-san-te",
    "interesar": "in-te-re-sar",
    "interese": "in-te-re-se",
    "interestatal": "in-te-res-ta-tal",
    "interestelar": "in-te-res-te-lar",
    "interétnico": "in-te-rét-ni-co",
    "interface": "in-ter-fa-ce",
    "interfase": "in-ter-fa-se",
    "interfaz": "in-ter-faz",
    "interfecta": "in-ter-fec-ta",
    "interfecto": "in-ter-fec-to",
    "interferencia": "in-ter-fe-ren-cia",
    "interferencial": "in-ter-fe-ren-cial",
    "interferir": "in-ter-fe-rir",
    "interferómetro": "in-ter-fe-ró-me-tro",
    "interferón": "in-ter-fe-rón",
    "interfijo": "in-ter-fi-jo",
    "interfoliar": "in-ter-fo-liar",
    "interfono": "in-ter-fo-no",
    "intergaláctico": "in-ter-ga-lác-ti-co",
    "interglaciar": "in-ter-gla-ciar",
    "intergubernamental": "in-ter-gu-ber-na-men-tal",
    "intergular": "in-ter-gu-lar",
    "interhumano": "in-te-rhu-ma-no",
    "interiana": "in-te-ria-na",
    "interiano": "in-te-ria-no",
    "ínterin": "ín-te-rin",
    "interina": "in-te-ri-na",
    "interinamente": "in-te-ri-na-men-te",
    "interinar": "in-te-ri-nar",
    "interinaria": "in-te-ri-na-ria",
    "interinario": "in-te-ri-na-rio",
    "interinato": "in-te-ri-na-to",
    "interindividual": "in-te-rin-di-vi-dual",
    "interinidad": "in-te-ri-ni-dad",
    "interino": "in-te-ri-no",
    "interinstitucional": "in-te-rins-ti-tu-cio-nal",
    "interinsular": "in-te-rin-su-lar",
    "interior": "in-te-rior",
    "interiorana": "in-te-rio-ra-na",
    "interiorano": "in-te-rio-ra-no",
    "interioridad": "in-te-rio-ri-dad",
    "interiorismo": "in-te-rio-ris-mo",
    "interiorista": "in-te-rio-ris-ta",
    "interiorización": "in-te-rio-ri-za-ción",
    "interiorizado": "in-te-rio-ri-za-do",
    "interiorizar": "in-te-rio-ri-zar",
    "interiormente": "in-te-rior-men-te",
    "interjección": "in-ter-jec-ción",
    "interjectiva": "in-ter-jec-ti-va",
    "interjectivamente": "in-ter-jec-ti-va-men-te",
    "interjectivo": "in-ter-jec-ti-vo",
    "interlínea": "in-ter-lí-ne-a",
    "interlineación": "in-ter-li-ne-a-ción",
    "interlineado": "in-ter-li-ne-a-do",
    "interlineal": "in-ter-li-ne-al",
    "interlinear": "in-ter-li-ne-ar",
    "interlocución": "in-ter-lo-cu-ción",
    "interlocutor": "in-ter-lo-cu-tor",
    "interlocutora": "in-ter-lo-cu-to-ra",
    "interlocutoria": "in-ter-lo-cu-to-ria",
    "interlocutoriamente": "in-ter-lo-cu-to-ria-men-te",
    "interlocutorio": "in-ter-lo-cu-to-rio",
    "intérlope": "in-tér-lo-pe",
    "interludio": "in-ter-lu-dio",
    "interlunio": "in-ter-lu-nio",
    "intermareal": "in-ter-ma-re-al",
    "intermaxilar": "in-ter-ma-xi-lar",
    "intermedia": "in-ter-me-dia",
    "intermediación": "in-ter-me-dia-ción",
    "intermediada": "in-ter-me-dia-da",
    "intermediado": "in-ter-me-dia-do",
    "intermediador": "in-ter-me-dia-dor",
    "intermediadora": "in-ter-me-dia-do-ra",
    "intermediar": "in-ter-me-diar",
    "intermediaria": "in-ter-me-dia-ria",
    "intermediario": "in-ter-me-dia-rio",
    "intermedio": "in-ter-me-dio",
    "intermezzo": "in-ter-mez-zo",
    "interminable": "in-ter-mi-na-ble",
    "interminación": "in-ter-mi-na-ción",
    "interministerial": "in-ter-mi-nis-te-rial",
    "intermisión": "in-ter-mi-sión",
    "intermitencia": "in-ter-mi-ten-cia",
    "intermitente": "in-ter-mi-ten-te",
    "intermitir": "in-ter-mi-tir",
    "intermodal": "in-ter-mo-dal",
    "intermuscular": "in-ter-mus-cu-lar",
    "interna": "in-ter-na",
    "internación": "in-ter-na-ción",
    "internacional": "in-ter-na-cio-nal",
    "internacionalidad": "in-ter-na-cio-na-li-dad",
    "internacionalismo": "in-ter-na-cio-na-lis-mo",
    "internacionalista": "in-ter-na-cio-na-lis-ta",
    "internacionalización": "in-ter-na-cio-na-li-za-ción",
    "internacionalizar": "in-ter-na-cio-na-li-zar",
    "internacionalmente": "in-ter-na-cio-nal-men-te",
    "internada": "in-ter-na-da",
    "internado": "in-ter-na-do",
    "internalización": "in-ter-na-li-za-ción",
    "internalizar": "in-ter-na-li-zar",
    "internamente": "in-ter-na-men-te",
    "internamiento": "in-ter-na-mien-to",
    "internar": "in-ter-nar",
    "internauta": "in-ter-nau-ta",
    "internet": "in-ter-net",
    "internista": "in-ter-nis-ta",
    "interno": "in-ter-no",
    "internodio": "in-ter-no-dio",
    "internuncio": "in-ter-nun-cio",
    "interoceánica": "in-te-ro-ce-á-ni-ca",
    "interoceánico": "in-te-ro-ce-á-ni-co",
    "interóseo": "in-te-ró-se-o",
    "interpaginar": "in-ter-pa-gi-nar",
    "interparlamentaria": "in-ter-par-la-men-ta-ria",
    "interparlamentario": "in-ter-par-la-men-ta-rio",
    "interpelación": "in-ter-pe-la-ción",
    "interpelante": "in-ter-pe-lan-te",
    "interpelar": "in-ter-pe-lar",
    "interpenetración": "in-ter-pe-ne-tra-ción",
    "interpersonal": "in-ter-per-so-nal",
    "interplanetaria": "in-ter-pla-ne-ta-ria",
    "interplanetario": "in-ter-pla-ne-ta-rio",
    "interpolación": "in-ter-po-la-ción",
    "interpoladamente": "in-ter-po-la-da-men-te",
    "interpolador": "in-ter-po-la-dor",
    "interpoladora": "in-ter-po-la-do-ra",
    "interpolar": "in-ter-po-lar",
    "interponer": "in-ter-po-ner",
    "interposición": "in-ter-po-si-ción",
    "interprender": "in-ter-pren-der",
    "interpresa": "in-ter-pre-sa",
    "interpretable": "in-ter-pre-ta-ble",
    "interpretación": "in-ter-pre-ta-ción",
    "interpretador": "in-ter-pre-ta-dor",
    "interpretadora": "in-ter-pre-ta-do-ra",
    "interpretar": "in-ter-pre-tar",
    "interpretariado": "in-ter-pre-ta-ria-do",
    "interpretativa": "in-ter-pre-ta-ti-va",
    "interpretativamente": "in-ter-pre-ta-ti-va-men-te",
    "interpretativo": "in-ter-pre-ta-ti-vo",
    "intérprete": "in-tér-pre-te",
    "interprofesional": "in-ter-pro-fe-sio-nal",
    "interprovincial": "in-ter-pro-vin-cial",
    "interpuesta": "in-ter-pues-ta",
    "interpuesto": "in-ter-pues-to",
    "interracial": "in-te-rra-cial",
    "interregional": "in-te-rre-gio-nal",
    "interregno": "in-te-rreg-no",
    "interrelación": "in-te-rre-la-ción",
    "interrelacionar": "in-te-rre-la-cio-nar",
    "interrogación": "in-te-rro-ga-ción",
    "interrogador": "in-te-rro-ga-dor",
    "interrogadora": "in-te-rro-ga-do-ra",
    "interrogante": "in-te-rro-gan-te",
    "interrogar": "in-te-rro-gar",
    "interrogativa": "in-te-rro-ga-ti-va",
    "interrogativamente": "in-te-rro-ga-ti-va-men-te",
    "interrogativo": "in-te-rro-ga-ti-vo",
    "interrogatorio": "in-te-rro-ga-to-rio",
    "interromper": "in-te-rrom-per",
    "interrumpidamente": "in-te-rrum-pi-da-men-te",
    "interrumpir": "in-te-rrum-pir",
    "interrupción": "in-te-rrup-ción",
    "interruptor": "in-te-rrup-tor",
    "interruptora": "in-te-rrup-to-ra",
    "intersecar": "in-ter-se-car",
    "intersecarse": "in-ter-se-car-se",
    "intersección": "in-ter-sec-ción",
    "interserir": "in-ter-se-rir",
    "intersexual": "in-ter-se-xual",
    "intersexualidad": "in-ter-se-xua-li-dad",
    "intersideral": "in-ter-si-de-ral",
    "intersindical": "in-ter-sin-di-cal",
    "intersticial": "in-ters-ti-cial",
    "intersticio": "in-ters-ti-cio",
    "intersubjetividad": "in-ter-sub-je-ti-vi-dad",
    "intersubjetivo": "in-ter-sub-je-ti-vo",
    "interterritorial": "in-ter-te-rri-to-rial",
    "intertextual": "in-ter-tex-tual",
    "intertextualidad": "in-ter-tex-tua-li-dad",
    "intertrigo": "in-ter-tri-go",
    "intertropical": "in-ter-tro-pi-cal",
    "interurbana": "in-te-rur-ba-na",
    "interurbano": "in-te-rur-ba-no",
    "intervalo": "in-ter-va-lo",
    "intervención": "in-ter-ven-ción",
    "intervencionismo": "in-ter-ven-cio-nis-mo",
    "intervencionista": "in-ter-ven-cio-nis-ta",
    "intervenidor": "in-ter-ve-ni-dor",
    "intervenidora": "in-ter-ve-ni-do-ra",
    "intervenir": "in-ter-ve-nir",
    "interventor": "in-ter-ven-tor",
    "interventora": "in-ter-ven-to-ra",
    "intervertebral": "in-ter-ver-te-bral",
    "interviniente": "in-ter-vi-nien-te",
    "interviú": "in-ter-viú",
    "intervocálica": "in-ter-vo-cá-li-ca",
    "intervocálico": "in-ter-vo-cá-li-co",
    "interyacente": "in-ter-ya-cen-te",
    "intestada": "in-tes-ta-da",
    "intestado": "in-tes-ta-do",
    "intestar": "in-tes-tar",
    "intestina": "in-tes-ti-na",
    "intestinal": "in-tes-ti-nal",
    "intestino": "in-tes-ti-no",
    "inti": "in-ti",
    "intibucana": "in-ti-bu-ca-na",
    "intibucano": "in-ti-bu-ca-no",
    "intifada": "in-ti-fa-da",
    "intima": "in-ti-ma",
    "íntima": "ín-ti-ma",
    "intimación": "in-ti-ma-ción",
    "íntimamente": "ín-ti-ma-men-te",
    "intimar": "in-ti-mar",
    "intimatorio": "in-ti-ma-to-rio",
    "intimidación": "in-ti-mi-da-ción",
    "intimidad": "in-ti-mi-dad",
    "intimidante": "in-ti-mi-dan-te",
    "intimidar": "in-ti-mi-dar",
    "intimidatorio": "in-ti-mi-da-to-rio",
    "intimismo": "in-ti-mis-mo",
    "intimista": "in-ti-mis-ta",
    "íntimo": "ín-ti-mo",
    "intina": "in-ti-na",
    "intitulación": "in-ti-tu-la-ción",
    "intitular": "in-ti-tu-lar",
    "intocable": "in-to-ca-ble",
    "intocado": "in-to-ca-do",
    "intolerabilidad": "in-to-le-ra-bi-li-dad",
    "intolerable": "in-to-le-ra-ble",
    "intolerancia": "in-to-le-ran-cia",
    "intolerante": "in-to-le-ran-te",
    "intonsa": "in-ton-sa",
    "intonso": "in-ton-so",
    "intoxicación": "in-to-xi-ca-ción",
    "intoxicar": "in-to-xi-car",
    "intracardíaco": "in-tra-car-dí-a-co",
    "intracelular": "in-tra-ce-lu-lar",
    "intradérmico": "in-tra-dér-mi-co",
    "intradós": "in-tra-dós",
    "intraducibilidad": "in-tra-du-ci-bi-li-dad",
    "intraducible": "in-tra-du-ci-ble",
    "intrahistoria": "in-trahis-to-ria",
    "intrahistórico": "in-trahis-tó-ri-co",
    "intramuros": "in-tra-mu-ros",
    "intramuscular": "in-tra-mus-cu-lar",
    "intránea": "in-trá-ne-a",
    "intráneo": "in-trá-ne-o",
    "intranquila": "in-tran-qui-la",
    "intranquilidad": "in-tran-qui-li-dad",
    "intranquilizador": "in-tran-qui-li-za-dor",
    "intranquilizadora": "in-tran-qui-li-za-do-ra",
    "intranquilizar": "in-tran-qui-li-zar",
    "intranquilo": "in-tran-qui-lo",
    "intranscendencia": "in-trans-cen-den-cia",
    "intranscendente": "in-trans-cen-den-te",
    "intransferible": "in-trans-fe-ri-ble",
    "intransigencia": "in-tran-si-gen-cia",
    "intransigente": "in-tran-si-gen-te",
    "intransitable": "in-tran-si-ta-ble",
    "intransitividad": "in-tran-si-ti-vi-dad",
    "intransitivo": "in-tran-si-ti-vo",
    "intransmisible": "in-trans-mi-si-ble",
    "intransmutabilidad": "in-trans-mu-ta-bi-li-dad",
    "intransmutable": "in-trans-mu-ta-ble",
    "intraocular": "in-tra-o-cu-lar",
    "intrascendencia": "in-tras-cen-den-cia",
    "intrascendental": "in-tras-cen-den-tal",
    "intrascendente": "in-tras-cen-den-te",
    "intrasmisible": "in-tras-mi-si-ble",
    "intratabilidad": "in-tra-ta-bi-li-dad",
    "intratable": "in-tra-ta-ble",
    "intratar": "in-tra-tar",
    "intrauterino": "in-trau-te-ri-no",
    "intravenoso": "in-tra-ve-no-so",
    "intrépida": "in-tré-pi-da",
    "intrépidamente": "in-tré-pi-da-men-te",
    "intrepidez": "in-tre-pi-dez",
    "intrépido": "in-tré-pi-do",
    "intributar": "in-tri-bu-tar",
    "intricable": "in-tri-ca-ble",
    "intricación": "in-tri-ca-ción",
    "intricadamente": "in-tri-ca-da-men-te",
    "intricado": "in-tri-ca-do",
    "intricar": "in-tri-car",
    "intriga": "in-tri-ga",
    "intrigante": "in-tri-gan-te",
    "intrigar": "in-tri-gar",
    "intrincable": "in-trin-ca-ble",
    "intrincación": "in-trin-ca-ción",
    "intrincada": "in-trin-ca-da",
    "intrincadamente": "in-trin-ca-da-men-te",
    "intrincado": "in-trin-ca-do",
    "intrincamiento": "in-trin-ca-mien-to",
    "intrincar": "in-trin-car",
    "intríngulis": "in-trín-gu-lis",
    "intrínseca": "in-trín-se-ca",
    "intrínsecamente": "in-trín-se-ca-men-te",
    "intrínseco": "in-trín-se-co",
    "intrinsiqueza": "in-trin-si-que-za",
    "introducción": "in-tro-duc-ción",
    "introducidor": "in-tro-du-ci-dor",
    "introducidora": "in-tro-du-ci-do-ra",
    "introducir": "in-tro-du-cir",
    "introducta": "in-tro-duc-ta",
    "introducto": "in-tro-duc-to",
    "introductor": "in-tro-duc-tor",
    "introductora": "in-tro-duc-to-ra",
    "introductoria": "in-tro-duc-to-ria",
    "introductorio": "in-tro-duc-to-rio",
    "introito": "in-troi-to",
    "intromisión": "in-tro-mi-sión",
    "introspección": "in-tros-pec-ción",
    "introspectiva": "in-tros-pec-ti-va",
    "introspectivo": "in-tros-pec-ti-vo",
    "introversa": "in-tro-ver-sa",
    "introversión": "in-tro-ver-sión",
    "introverso": "in-tro-ver-so",
    "introvertida": "in-tro-ver-ti-da",
    "introvertido": "in-tro-ver-ti-do",
    "intrusa": "in-tru-sa",
    "intrusamente": "in-tru-sa-men-te",
    "intrusar": "in-tru-sar",
    "intrusarse": "in-tru-sar-se",
    "intrusear": "in-tru-se-ar",
    "intrusete": "in-tru-se-te",
    "intrusión": "in-tru-sión",
    "intrusismo": "in-tru-sis-mo",
    "intrusivo": "in-tru-si-vo",
    "intruso": "in-tru-so",
    "intubación": "in-tu-ba-ción",
    "intubar": "in-tu-bar",
    "intuición": "in-tui-ción",
    "intuicionismo": "in-tui-cio-nis-mo",
    "intuicionista": "in-tui-cio-nis-ta",
    "intuir": "in-tuir",
    "intuitiva": "in-tui-ti-va",
    "intuitivamente": "in-tui-ti-va-men-te",
    "intuitivo": "in-tui-ti-vo",
    "intuito": "in-tui-to",
    "intumescencia": "in-tu-mes-cen-cia",
    "intumescente": "in-tu-mes-cen-te",
    "intususcepción": "in-tu-sus-cep-ción",
    "inulta": "i-nul-ta",
    "inulto": "i-nul-to",
    "inundación": "i-nun-da-ción",
    "inundado": "i-nun-da-do",
    "inundar": "i-nun-dar",
    "inurbana": "i-nur-ba-na",
    "inurbanamente": "i-nur-ba-na-men-te",
    "inurbanidad": "i-nur-ba-ni-dad",
    "inurbano": "i-nur-ba-no",
    "inusada": "i-nu-sa-da",
    "inusado": "i-nu-sa-do",
    "inusitada": "i-nu-si-ta-da",
    "inusitadamente": "i-nu-si-ta-da-men-te",
    "inusitado": "i-nu-si-ta-do",
    "inusual": "i-nu-sual",
    "inusualmente": "i-nu-sual-men-te",
    "inútil": "i-nú-til",
    "inutilidad": "i-nu-ti-li-dad",
    "inutilizable": "i-nu-ti-li-za-ble",
    "inutilización": "i-nu-ti-li-za-ción",
    "inutilizado": "i-nu-ti-li-za-do",
    "inutilizar": "i-nu-ti-li-zar",
    "inútilmente": "i-nú-til-men-te",
    "invadeable": "in-va-de-a-ble",
    "invadir": "in-va-dir",
    "invaginación": "in-va-gi-na-ción",
    "invaginar": "in-va-gi-nar",
    "inválida": "in-vá-li-da",
    "invalidación": "in-va-li-da-ción",
    "invalidad": "in-va-li-dad",
    "inválidamente": "in-vá-li-da-men-te",
    "invalidar": "in-va-li-dar",
    "invalidez": "in-va-li-dez",
    "inválido": "in-vá-li-do",
    "invalorable": "in-va-lo-ra-ble",
    "invaluable": "in-va-lua-ble",
    "invar": "in-var",
    "invariabilidad": "in-va-ria-bi-li-dad",
    "invariable": "in-va-ria-ble",
    "invariablemente": "in-va-ria-ble-men-te",
    "invariación": "in-va-ria-ción",
    "invariada": "in-va-ria-da",
    "invariadamente": "in-va-ria-da-men-te",
    "invariado": "in-va-ria-do",
    "invariancia": "in-va-rian-cia",
    "invariante": "in-va-rian-te",
    "invasión": "in-va-sión",
    "invasivo": "in-va-si-vo",
    "invasor": "in-va-sor",
    "invasora": "in-va-so-ra",
    "invectiva": "in-vec-ti-va",
    "invehír": "in-ve-hír",
    "invencibilidad": "in-ven-ci-bi-li-dad",
    "invencible": "in-ven-ci-ble",
    "invenciblemente": "in-ven-ci-ble-men-te",
    "invención": "in-ven-ción",
    "invencionera": "in-ven-cio-ne-ra",
    "invencionero": "in-ven-cio-ne-ro",
    "invendible": "in-ven-di-ble",
    "invenible": "in-ve-ni-ble",
    "invenir": "in-ve-nir",
    "inventación": "in-ven-ta-ción",
    "inventador": "in-ven-ta-dor",
    "inventadora": "in-ven-ta-do-ra",
    "inventar": "in-ven-tar",
    "inventariar": "in-ven-ta-riar",
    "inventario": "in-ven-ta-rio",
    "inventiva": "in-ven-ti-va",
    "inventivo": "in-ven-ti-vo",
    "invento": "in-ven-to",
    "inventor": "in-ven-tor",
    "inventora": "in-ven-to-ra",
    "inverecunda": "in-ve-re-cun-da",
    "inverecundia": "in-ve-re-cun-dia",
    "inverecundo": "in-ve-re-cun-do",
    "inverisímil": "in-ve-ri-sí-mil",
    "inverisimilitud": "in-ve-ri-si-mi-li-tud",
    "inverna": "in-ver-na",
    "invernáculo": "in-ver-ná-cu-lo",
    "invernada": "in-ver-na-da",
    "invernadero": "in-ver-na-de-ro",
    "invernal": "in-ver-nal",
    "invernar": "in-ver-nar",
    "invernazo": "in-ver-na-zo",
    "inverniza": "in-ver-ni-za",
    "invernizo": "in-ver-ni-zo",
    "inverosímil": "in-ve-ro-sí-mil",
    "inverosimilitud": "in-ve-ro-si-mi-li-tud",
    "inverosímilmente": "in-ve-ro-sí-mil-men-te",
    "inversa": "in-ver-sa",
    "inversamente": "in-ver-sa-men-te",
    "inversión": "in-ver-sión",
    "inversionista": "in-ver-sio-nis-ta",
    "inverso": "in-ver-so",
    "inversor": "in-ver-sor",
    "inversora": "in-ver-so-ra",
    "invertebración": "in-ver-te-bra-ción",
    "invertebrada": "in-ver-te-bra-da",
    "invertebrado": "in-ver-te-bra-do",
    "invertible": "in-ver-ti-ble",
    "invertida": "in-ver-ti-da",
    "invertido": "in-ver-ti-do",
    "invertir": "in-ver-tir",
    "investidura": "in-ves-ti-du-ra",
    "investigable": "in-ves-ti-ga-ble",
    "investigación": "in-ves-ti-ga-ción",
    "investigador": "in-ves-ti-ga-dor",
    "investigadora": "in-ves-ti-ga-do-ra",
    "investigar": "in-ves-ti-gar",
    "investir": "in-ves-tir",
    "inveterada": "in-ve-te-ra-da",
    "inveteradamente": "in-ve-te-ra-da-men-te",
    "inveterado": "in-ve-te-ra-do",
    "inveterar": "in-ve-te-rar",
    "inveterarse": "in-ve-te-rar-se",
    "inviabilidad": "in-via-bi-li-dad",
    "inviable": "in-via-ble",
    "inviar": "in-viar",
    "invicta": "in-vic-ta",
    "invictamente": "in-vic-ta-men-te",
    "invicto": "in-vic-to",
    "ínvida": "ín-vi-da",
    "invidencia": "in-vi-den-cia",
    "invidente": "in-vi-den-te",
    "invidia": "in-vi-dia",
    "invidiar": "in-vi-diar",
    "invidiosa": "in-vi-dio-sa",
    "invidioso": "in-vi-dio-so",
    "ínvido": "ín-vi-do",
    "invierno": "in-vier-no",
    "invigilar": "in-vi-gi-lar",
    "inviolabilidad": "in-vio-la-bi-li-dad",
    "inviolable": "in-vio-la-ble",
    "inviolablemente": "in-vio-la-ble-men-te",
    "inviolada": "in-vio-la-da",
    "inviolado": "in-vio-la-do",
    "invirtud": "in-vir-tud",
    "invirtuosa": "in-vir-tuo-sa",
    "invirtuosamente": "in-vir-tuo-sa-men-te",
    "invirtuoso": "in-vir-tuo-so",
    "invisibilidad": "in-vi-si-bi-li-dad",
    "invisible": "in-vi-si-ble",
    "invisiblemente": "in-vi-si-ble-men-te",
    "invita": "in-vi-ta",
    "invitación": "in-vi-ta-ción",
    "invitada": "in-vi-ta-da",
    "invitado": "in-vi-ta-do",
    "invitador": "in-vi-ta-dor",
    "invitadora": "in-vi-ta-do-ra",
    "invitar": "in-vi-tar",
    "invitatorio": "in-vi-ta-to-rio",
    "invite": "in-vi-te",
    "invito": "in-vi-to",
    "invivible": "in-vi-vi-ble",
    "invocación": "in-vo-ca-ción",
    "invocador": "in-vo-ca-dor",
    "invocadora": "in-vo-ca-do-ra",
    "invocar": "in-vo-car",
    "invocatoria": "in-vo-ca-to-ria",
    "invocatorio": "in-vo-ca-to-rio",
    "involución": "in-vo-lu-ción",
    "involucionar": "in-vo-lu-cio-nar",
    "involucionismo": "in-vo-lu-cio-nis-mo",
    "involucionista": "in-vo-lu-cio-nis-ta",
    "involucración": "in-vo-lu-cra-ción",
    "involucrar": "in-vo-lu-crar",
    "involucro": "in-vo-lu-cro",
    "involuntaria": "in-vo-lun-ta-ria",
    "involuntariamente": "in-vo-lun-ta-ria-men-te",
    "involuntariedad": "in-vo-lun-ta-rie-dad",
    "involuntario": "in-vo-lun-ta-rio",
    "involutivo": "in-vo-lu-ti-vo",
    "involuto": "in-vo-lu-to",
    "invulnerabilidad": "in-vul-ne-ra-bi-li-dad",
    "invulnerable": "in-vul-ne-ra-ble",
    "inyección": "in-yec-ción",
    "inyectable": "in-yec-ta-ble",
    "inyectador": "in-yec-ta-dor",
    "inyectadora": "in-yec-ta-do-ra",
    "inyectar": "in-yec-tar",
    "inyectivo": "in-yec-ti-vo",
    "inyector": "in-yec-tor",
    "inyungir": "in-yun-gir",
    "iodo": "io-do",
    "ioduro": "io-du-ro",
    "iónico": "ió-ni-co",
    "ionización": "io-ni-za-ción",
    "ionizador": "io-ni-za-dor",
    "ionizante": "io-ni-zan-te",
    "ionizar": "io-ni-zar",
    "ionoforesis": "io-no-fo-re-sis",
    "ionosfera": "io-nos-fe-ra",
    "ionósfera": "io-nós-fe-ra",
    "iontoforesis": "ion-to-fo-re-sis",
    "iota": "io-ta",
    "iotización": "io-ti-za-ción",
    "ipecacuana": "i-pe-ca-cua-na",
    "ipegüe": "i-pe-güe",
    "iperita": "i-pe-ri-ta",
    "ipil": "i-pil",
    "ipseidad": "ip-sei-dad",
    "ipsi": "ip-si",
    "ípsilon": "íp-si-lon",
    "iqueña": "i-que-ña",
    "iqueño": "i-que-ño",
    "iquiqueña": "i-qui-que-ña",
    "iquiqueño": "i-qui-que-ño",
    "iquiteña": "i-qui-te-ña",
    "iquiteño": "i-qui-te-ño",
    "ira": "i-ra",
    "iraca": "i-ra-ca",
    "iracal": "i-ra-cal",
    "iracunda": "i-ra-cun-da",
    "iracundamente": "i-ra-cun-da-men-te",
    "iracundia": "i-ra-cun-dia",
    "iracundo": "i-ra-cun-do",
    "irada": "i-ra-da",
    "irado": "i-ra-do",
    "iraní": "i-ra-ní",
    "irania": "i-ra-nia",
    "iranio": "i-ra-nio",
    "iraqués": "i-ra-qués",
    "iraquesa": "i-ra-que-sa",
    "iraquí": "i-ra-quí",
    "irascibilidad": "i-ras-ci-bi-li-dad",
    "irascible": "i-ras-ci-ble",
    "irasco": "i-ras-co",
    "irenarca": "i-re-nar-ca",
    "irenismo": "i-re-nis-mo",
    "iridácea": "i-ri-dá-ce-a",
    "iridáceas": "i-ri-dá-ce-as",
    "iridáceo": "i-ri-dá-ce-o",
    "íride": "í-ri-de",
    "irídea": "i-rí-de-a",
    "irídeas": "i-rí-de-as",
    "irídeo": "i-rí-de-o",
    "iridiado": "i-ri-dia-do",
    "iridio": "i-ri-dio",
    "iridiscencia": "i-ri-dis-cen-cia",
    "iridiscente": "i-ri-dis-cen-te",
    "iridóloga": "i-ri-dó-lo-ga",
    "iridología": "i-ri-do-lo-gí-a",
    "iridólogo": "i-ri-dó-lo-go",
    "iriense": "i-rien-se",
    "iril": "i-ril",
    "irire": "i-ri-re",
    "irirear": "i-ri-re-ar",
    "iris": "i-ris",
    "irisación": "i-ri-sa-ción",
    "irisado": "i-ri-sa-do",
    "irisar": "i-ri-sar",
    "iritis": "i-ri-tis",
    "irlanda": "ir-lan-da",
    "irlandés": "ir-lan-dés",
    "irlandesa": "ir-lan-de-sa",
    "irlandesca": "ir-lan-des-ca",
    "irlandesco": "ir-lan-des-co",
    "ironía": "i-ro-ní-a",
    "irónica": "i-ró-ni-ca",
    "irónicamente": "i-ró-ni-ca-men-te",
    "irónico": "i-ró-ni-co",
    "ironista": "i-ro-nis-ta",
    "ironizar": "i-ro-ni-zar",
    "iroqués": "i-ro-qués",
    "iroquesa": "i-ro-que-sa",
    "irracionabilidad": "i-rra-cio-na-bi-li-dad",
    "irracionable": "i-rra-cio-na-ble",
    "irracionablemente": "i-rra-cio-na-ble-men-te",
    "irracional": "i-rra-cio-nal",
    "irracionalidad": "i-rra-cio-na-li-dad",
    "irracionalismo": "i-rra-cio-na-lis-mo",
    "irracionalista": "i-rra-cio-na-lis-ta",
    "irracionalmente": "i-rra-cio-nal-men-te",
    "irradiación": "i-rra-dia-ción",
    "irradiador": "i-rra-dia-dor",
    "irradiar": "i-rra-diar",
    "irrazonable": "i-rra-zo-na-ble",
    "irrazonablemente": "i-rra-zo-na-ble-men-te",
    "irreal": "i-rre-al",
    "irrealidad": "i-rre-a-li-dad",
    "irrealizable": "i-rre-a-li-za-ble",
    "irrebatible": "i-rre-ba-ti-ble",
    "irreconciliable": "i-rre-con-ci-lia-ble",
    "irreconocible": "i-rre-co-no-ci-ble",
    "irrecordable": "i-rre-cor-da-ble",
    "irrecuperable": "i-rre-cu-pe-ra-ble",
    "irrecusable": "i-rre-cu-sa-ble",
    "irredenta": "i-rre-den-ta",
    "irredentismo": "i-rre-den-tis-mo",
    "irredentista": "i-rre-den-tis-ta",
    "irredento": "i-rre-den-to",
    "irredimible": "i-rre-di-mi-ble",
    "irreducible": "i-rre-du-ci-ble",
    "irreductibilidad": "i-rre-duc-ti-bi-li-dad",
    "irreductible": "i-rre-duc-ti-ble",
    "irreductiblemente": "i-rre-duc-ti-ble-men-te",
    "irreemplazable": "i-rre-em-pla-za-ble",
    "irreflexión": "i-rre-fle-xión",
    "irreflexiva": "i-rre-fle-xi-va",
    "irreflexivamente": "i-rre-fle-xi-va-men-te",
    "irreflexivo": "i-rre-fle-xi-vo",
    "irreformable": "i-rre-for-ma-ble",
    "irrefragable": "i-rre-fra-ga-ble",
    "irrefragablemente": "i-rre-fra-ga-ble-men-te",
    "irrefrenable": "i-rre-fre-na-ble",
    "irrefutable": "i-rre-fu-ta-ble",
    "irreglamentable": "i-rre-gla-men-ta-ble",
    "irregular": "i-rre-gu-lar",
    "irregularidad": "i-rre-gu-la-ri-dad",
    "irregularmente": "i-rre-gu-lar-men-te",
    "irreivindicable": "i-rrei-vin-di-ca-ble",
    "irrelevancia": "i-rre-le-van-cia",
    "irrelevante": "i-rre-le-van-te",
    "irreligión": "i-rre-li-gión",
    "irreligiosa": "i-rre-li-gio-sa",
    "irreligiosamente": "i-rre-li-gio-sa-men-te",
    "irreligiosidad": "i-rre-li-gio-si-dad",
    "irreligioso": "i-rre-li-gio-so",
    "irremediable": "i-rre-me-dia-ble",
    "irremediablemente": "i-rre-me-dia-ble-men-te",
    "irremisible": "i-rre-mi-si-ble",
    "irremisiblemente": "i-rre-mi-si-ble-men-te",
    "irremplazable": "i-rrem-pla-za-ble",
    "irremunerada": "i-rre-mu-ne-ra-da",
    "irremunerado": "i-rre-mu-ne-ra-do",
    "irrenunciable": "i-rre-nun-cia-ble",
    "irreparable": "i-rre-pa-ra-ble",
    "irreparablemente": "i-rre-pa-ra-ble-men-te",
    "irrepetible": "i-rre-pe-ti-ble",
    "irreprehensible": "i-rre-pre-hen-si-ble",
    "irreprensible": "i-rre-pren-si-ble",
    "irreprensiblemente": "i-rre-pren-si-ble-men-te",
    "irrepresentable": "i-rre-pre-sen-ta-ble",
    "irreprimible": "i-rre-pri-mi-ble",
    "irreprochabilidad": "i-rre-pro-cha-bi-li-dad",
    "irreprochable": "i-rre-pro-cha-ble",
    "irrequieta": "i-rre-quie-ta",
    "irrequieto": "i-rre-quie-to",
    "irrescindible": "i-rres-cin-di-ble",
    "irresistible": "i-rre-sis-ti-ble",
    "irresistiblemente": "i-rre-sis-ti-ble-men-te",
    "irresoluble": "i-rre-so-lu-ble",
    "irresolución": "i-rre-so-lu-ción",
    "irresoluta": "i-rre-so-lu-ta",
    "irresoluto": "i-rre-so-lu-to",
    "irrespetar": "i-rres-pe-tar",
    "irrespeto": "i-rres-pe-to",
    "irrespetuosa": "i-rres-pe-tuo-sa",
    "irrespetuosamente": "i-rres-pe-tuo-sa-men-te",
    "irrespetuosidad": "i-rres-pe-tuo-si-dad",
    "irrespetuoso": "i-rres-pe-tuo-so",
    "irrespirable": "i-rres-pi-ra-ble",
    "irresponsabilidad": "i-rres-pon-sa-bi-li-dad",
    "irresponsable": "i-rres-pon-sa-ble",
    "irrestañable": "i-rres-ta-ña-ble",
    "irrestricto": "i-rres-tric-to",
    "irresuelta": "i-rre-suel-ta",
    "irresuelto": "i-rre-suel-to",
    "irretractable": "i-rre-trac-ta-ble",
    "irretroactividad": "i-rre-tro-ac-ti-vi-dad",
    "irreverencia": "i-rre-ve-ren-cia",
    "irreverenciar": "i-rre-ve-ren-ciar",
    "irreverente": "i-rre-ve-ren-te",
    "irreverentemente": "i-rre-ve-ren-te-men-te",
    "irreversibilidad": "i-rre-ver-si-bi-li-dad",
    "irreversible": "i-rre-ver-si-ble",
    "irrevocabilidad": "i-rre-vo-ca-bi-li-dad",
    "irrevocable": "i-rre-vo-ca-ble",
    "irrevocablemente": "i-rre-vo-ca-ble-men-te",
    "irrigación": "i-rri-ga-ción",
    "irrigador": "i-rri-ga-dor",
    "irrigar": "i-rri-gar",
    "irrisible": "i-rri-si-ble",
    "irrisión": "i-rri-sión",
    "irrisoria": "i-rri-so-ria",
    "irrisoriamente": "i-rri-so-ria-men-te",
    "irrisorio": "i-rri-so-rio",
    "írrita": "í-rri-ta",
    "irritabilidad": "i-rri-ta-bi-li-dad",
    "irritable": "i-rri-ta-ble",
    "irritación": "i-rri-ta-ción",
    "irritador": "i-rri-ta-dor",
    "irritadora": "i-rri-ta-do-ra",
    "írritamente": "í-rri-ta-men-te",
    "irritamiento": "i-rri-ta-mien-to",
    "irritante": "i-rri-tan-te",
    "irritar": "i-rri-tar",
    "irritativo": "i-rri-ta-ti-vo",
    "írrito": "í-rri-to",
    "irrogación": "i-rro-ga-ción",
    "irrogar": "i-rro-gar",
    "irrompible": "i-rrom-pi-ble",
    "irruir": "i-rruir",
    "irrumpir": "i-rrum-pir",
    "irrupción": "i-rrup-ción",
    "irruptor": "i-rrup-tor",
    "irunés": "i-ru-nés",
    "irunesa": "i-ru-ne-sa",
    "irupaneña": "i-ru-pa-ne-ña",
    "irupaneño": "i-ru-pa-ne-ño",
    "irupé": "i-ru-pé",
    "isa": "i-sa",
    "isabelina": "i-sa-be-li-na",
    "isabelino": "i-sa-be-li-no",
    "isabelo": "i-sa-be-lo",
    "isagoge": "i-sa-go-ge",
    "isagógico": "i-sa-gó-gi-co",
    "isalóbara": "i-sa-ló-ba-ra",
    "isaloterma": "i-sa-lo-ter-ma",
    "ísatis": "í-sa-tis",
    "isba": "is-ba",
    "isiaca": "i-sia-ca",
    "isiaco": "i-sia-co",
    "isidoriana": "i-si-do-ria-na",
    "isidoriano": "i-si-do-ria-no",
    "isidra": "i-si-dra",
    "isidrada": "i-si-dra-da",
    "isidril": "i-si-dril",
    "isidro": "i-si-dro",
    "isiga": "i-si-ga",
    "isipó": "i-si-pó",
    "isípula": "i-sí-pu-la",
    "isla": "is-la",
    "islam": "is-lam",
    "islámica": "is-lá-mi-ca",
    "islámico": "is-lá-mi-co",
    "islamismo": "is-la-mis-mo",
    "islamista": "is-la-mis-ta",
    "islamita": "is-la-mi-ta",
    "islamización": "is-la-mi-za-ción",
    "islamizar": "is-la-mi-zar",
    "islamóloga": "is-la-mó-lo-ga",
    "islamólogo": "is-la-mó-lo-go",
    "islán": "is-lán",
    "islandés": "is-lan-dés",
    "islandesa": "is-lan-de-sa",
    "islandia": "is-lan-dia",
    "islándica": "is-lán-di-ca",
    "islándico": "is-lán-di-co",
    "islario": "is-la-rio",
    "isleña": "is-le-ña",
    "isleño": "is-le-ño",
    "isleo": "is-le-o",
    "isleta": "is-le-ta",
    "islilla": "is-li-lla",
    "islote": "is-lo-te",
    "ismael": "is-ma-el",
    "ismaelita": "is-ma-e-li-ta",
    "ismo": "is-mo",
    "isobara": "i-so-ba-ra",
    "isóbara": "i-só-ba-ra",
    "isobárica": "i-so-bá-ri-ca",
    "isobárico": "i-so-bá-ri-co",
    "isobaro": "i-so-ba-ro",
    "isóbata": "i-só-ba-ta",
    "isobática": "i-so-bá-ti-ca",
    "isobático": "i-so-bá-ti-co",
    "isoca": "i-so-ca",
    "isoclina": "i-so-cli-na",
    "isoclino": "i-so-cli-no",
    "isocromático": "i-so-cro-má-ti-co",
    "isócrona": "i-só-cro-na",
    "isocronía": "i-so-cro-ní-a",
    "isocronismo": "i-so-cro-nis-mo",
    "isócrono": "i-só-cro-no",
    "isodáctilo": "i-so-dác-ti-lo",
    "isodínama": "i-so-dí-na-ma",
    "isodinámico": "i-so-di-ná-mi-co",
    "isoédrico": "i-so-é-dri-co",
    "isoentrópico": "i-so-en-tró-pi-co",
    "isófago": "i-só-fa-go",
    "isofena": "i-so-fe-na",
    "isofilo": "i-so-fi-lo",
    "isofonía": "i-so-fo-ní-a",
    "isofónico": "i-so-fó-ni-co",
    "isófono": "i-só-fo-no",
    "isogeoterma": "i-so-ge-o-ter-ma",
    "isoglosa": "i-so-glo-sa",
    "isógona": "i-só-go-na",
    "isógono": "i-só-go-no",
    "isómera": "i-só-me-ra",
    "isomería": "i-so-me-rí-a",
    "isómero": "i-só-me-ro",
    "isometría": "i-so-me-trí-a",
    "isométrico": "i-so-mé-tri-co",
    "isomorfa": "i-so-mor-fa",
    "isomorfismo": "i-so-mor-fis-mo",
    "isomorfo": "i-so-mor-fo",
    "isonefa": "i-so-ne-fa",
    "isoperímetra": "i-so-pe-rí-me-tra",
    "isoperímetro": "i-so-pe-rí-me-tro",
    "isópodo": "i-só-po-do",
    "isóptero": "i-sóp-te-ro",
    "isoquimena": "i-so-qui-me-na",
    "isoquímena": "i-so-quí-me-na",
    "isósceles": "i-sós-ce-les",
    "isosilábico": "i-so-si-lá-bi-co",
    "isosilabismo": "i-so-si-la-bis-mo",
    "isostasia": "i-sos-ta-sia",
    "isótera": "i-só-te-ra",
    "isoterma": "i-so-ter-ma",
    "isotérmico": "i-so-tér-mi-co",
    "isotermo": "i-so-ter-mo",
    "isotónica": "i-so-tó-ni-ca",
    "isotónico": "i-so-tó-ni-co",
    "isotópico": "i-so-tó-pi-co",
    "isotopo": "i-so-to-po",
    "isótopo": "i-só-to-po",
    "isotropía": "i-so-tro-pí-a",
    "isótropo": "i-só-tro-po",
    "isoyeta": "i-so-ye-ta",
    "isquemia": "is-que-mia",
    "isquémico": "is-qué-mi-co",
    "isquiática": "is-quiá-ti-ca",
    "isquiático": "is-quiá-ti-co",
    "isquion": "is-quion",
    "israelí": "is-ra-e-lí",
    "israelita": "is-ra-e-li-ta",
    "israelítica": "is-ra-e-lí-ti-ca",
    "israelítico": "is-ra-e-lí-ti-co",
    "istapacle": "is-ta-pa-cle",
    "istmeña": "ist-me-ña",
    "istmeño": "ist-me-ño",
    "ístmica": "íst-mi-ca",
    "ístmico": "íst-mi-co",
    "istmo": "ist-mo",
    "istulte": "is-tul-te",
    "ita": "i-ta",
    "itacate": "i-ta-ca-te",
    "ítala": "í-ta-la",
    "italiana": "i-ta-lia-na",
    "italianismo": "i-ta-lia-nis-mo",
    "italianista": "i-ta-lia-nis-ta",
    "italianizante": "i-ta-lia-ni-zan-te",
    "italianizar": "i-ta-lia-ni-zar",
    "italiano": "i-ta-lia-no",
    "italianófila": "i-ta-lia-nó-fi-la",
    "italianófilo": "i-ta-lia-nó-fi-lo",
    "itálica": "i-tá-li-ca",
    "italicense": "i-ta-li-cen-se",
    "itálico": "i-tá-li-co",
    "ítalo": "í-ta-lo",
    "italoamericano": "i-ta-lo-a-me-ri-ca-no",
    "italorromance": "i-ta-lo-rro-man-ce",
    "italorrománico": "i-ta-lo-rro-má-ni-co",
    "itapuense": "i-ta-puen-se",
    "ítem": "í-tem",
    "iterable": "i-te-ra-ble",
    "iteración": "i-te-ra-ción",
    "iterar": "i-te-rar",
    "iterativa": "i-te-ra-ti-va",
    "iterativo": "i-te-ra-ti-vo",
    "iterbio": "i-ter-bio",
    "itericia": "i-te-ri-cia",
    "itifálico": "i-ti-fá-li-co",
    "itinerante": "i-ti-ne-ran-te",
    "itineraria": "i-ti-ne-ra-ria",
    "itinerario": "i-ti-ne-ra-rio",
    "itria": "i-tria",
    "itrio": "i-trio",
    "itzaj": "it-zaj",
    "iva": "i-va",
    "ivernar": "i-ver-nar",
    "ivierno": "i-vier-no",
    "ixil": "i-xil",
    "ixtle": "ix-tle",
    "iza": "i-za",
    "izada": "i-za-da",
    "izado": "i-za-do",
    "izaga": "i-za-ga",
    "izamiento": "i-za-mien-to",
    "izar": "i-zar",
    "izgonce": "iz-gon-ce",
    "izgonzar": "iz-gon-zar",
    "izote": "i-zo-te",
    "izquierda": "iz-quier-da",
    "izquierdazo": "iz-quier-da-zo",
    "izquierdear": "iz-quier-de-ar",
    "izquierdismo": "iz-quier-dis-mo",
    "izquierdista": "iz-quier-dis-ta",
    "izquierdo": "iz-quier-do",
    "izquierdoso": "iz-quier-do-so",
    "jaba": "ja-ba",
    "jabada": "ja-ba-da",
    "jabado": "ja-ba-do",
    "jabalcón": "ja-bal-cón",
    "jabalconar": "ja-bal-co-nar",
    "jabalí": "ja-ba-lí",
    "jabalín": "ja-ba-lín",
    "jabalina": "ja-ba-li-na",
    "jabalinera": "ja-ba-li-ne-ra",
    "jabalinero": "ja-ba-li-ne-ro",
    "jabalón": "ja-ba-lón",
    "jabalonar": "ja-ba-lo-nar",
    "jabaluna": "ja-ba-lu-na",
    "jabardear": "ja-bar-de-ar",
    "jabardillo": "ja-bar-di-llo",
    "jabardo": "ja-bar-do",
    "jabata": "ja-ba-ta",
    "jabato": "ja-ba-to",
    "jabear": "ja-be-ar",
    "jabeba": "ja-be-ba",
    "jabeca": "ja-be-ca",
    "jábeca": "já-be-ca",
    "jabega": "ja-be-ga",
    "jábega": "já-be-ga",
    "jabegote": "ja-be-go-te",
    "jabeguera": "ja-be-gue-ra",
    "jabeguero": "ja-be-gue-ro",
    "jabelgar": "ja-bel-gar",
    "jabeque": "ja-be-que",
    "jabera": "ja-be-ra",
    "jabí": "ja-bí",
    "jabilla": "ja-bi-lla",
    "jabillo": "ja-bi-llo",
    "jabino": "ja-bi-no",
    "jable": "ja-ble",
    "jabón": "ja-bón",
    "jabonada": "ja-bo-na-da",
    "jabonado": "ja-bo-na-do",
    "jabonador": "ja-bo-na-dor",
    "jabonadora": "ja-bo-na-do-ra",
    "jabonadura": "ja-bo-na-du-ra",
    "jabonallo": "ja-bo-na-llo",
    "jabonar": "ja-bo-nar",
    "jaboncillo": "ja-bon-ci-llo",
    "jabonear": "ja-bo-ne-ar",
    "jabonera": "ja-bo-ne-ra",
    "jabonería": "ja-bo-ne-rí-a",
    "jabonero": "ja-bo-ne-ro",
    "jaboneta": "ja-bo-ne-ta",
    "jabonete": "ja-bo-ne-te",
    "jabonosa": "ja-bo-no-sa",
    "jabonoso": "ja-bo-no-so",
    "jaborandi": "ja-bo-ran-di",
    "jabotí": "ja-bo-tí",
    "jabrir": "ja-brir",
    "jabuco": "ja-bu-co",
    "jabugo": "ja-bu-go",
    "jabutí": "ja-bu-tí",
    "jaca": "ja-ca",
    "jacal": "ja-cal",
    "jacalasúchil": "ja-ca-la-sú-chil",
    "jacalear": "ja-ca-le-ar",
    "jacalera": "ja-ca-le-ra",
    "jacalerío": "ja-ca-le-rí-o",
    "jacalero": "ja-ca-le-ro",
    "jacalón": "ja-ca-lón",
    "jacalosúchil": "ja-ca-lo-sú-chil",
    "jacalteca": "ja-cal-te-ca",
    "jacapa": "ja-ca-pa",
    "jacapucayo": "ja-ca-pu-ca-yo",
    "jácara": "já-ca-ra",
    "jacaranda": "ja-ca-ran-da",
    "jacarandá": "ja-ca-ran-dá",
    "jacarandaina": "ja-ca-ran-dai-na",
    "jacarandana": "ja-ca-ran-da-na",
    "jacarandina": "ja-ca-ran-di-na",
    "jacarandino": "ja-ca-ran-di-no",
    "jacarando": "ja-ca-ran-do",
    "jacarandosa": "ja-ca-ran-do-sa",
    "jacarandoso": "ja-ca-ran-do-so",
    "jacarear": "ja-ca-re-ar",
    "jacarera": "ja-ca-re-ra",
    "jacarero": "ja-ca-re-ro",
    "jacarista": "ja-ca-ris-ta",
    "jácaro": "já-ca-ro",
    "jácena": "já-ce-na",
    "jacer": "ja-cer",
    "jacerina": "ja-ce-ri-na",
    "jacerino": "ja-ce-ri-no",
    "jacetana": "ja-ce-ta-na",
    "jacetano": "ja-ce-ta-no",
    "jacha": "ja-cha",
    "jachado": "ja-cha-do",
    "jachalí": "ja-cha-lí",
    "jachamenta": "ja-cha-men-ta",
    "jache": "ja-che",
    "jachón": "ja-chón",
    "jachudo": "ja-chu-do",
    "jacilla": "ja-ci-lla",
    "jacintina": "ja-cin-ti-na",
    "jacintino": "ja-cin-ti-no",
    "jacinto": "ja-cin-to",
    "jaco": "ja-co",
    "jacobea": "ja-co-be-a",
    "jacobeo": "ja-co-be-o",
    "jacobina": "ja-co-bi-na",
    "jacobinismo": "ja-co-bi-nis-mo",
    "jacobino": "ja-co-bi-no",
    "jacobita": "ja-co-bi-ta",
    "jacoiba": "ja-coi-ba",
    "jacoibo": "ja-coi-bo",
    "jaconta": "ja-con-ta",
    "jactancia": "jac-tan-cia",
    "jactanciosa": "jac-tan-cio-sa",
    "jactanciosamente": "jac-tan-cio-sa-men-te",
    "jactancioso": "jac-tan-cio-so",
    "jactar": "jac-tar",
    "jactura": "jac-tu-ra",
    "jacuaré": "ja-cua-ré",
    "jaculatoria": "ja-cu-la-to-ria",
    "jaculatorio": "ja-cu-la-to-rio",
    "jáculo": "já-cu-lo",
    "jada": "ja-da",
    "jade": "ja-de",
    "jadeante": "ja-de-an-te",
    "jadear": "ja-de-ar",
    "jadeíta": "ja-de-í-ta",
    "jadeo": "ja-de-o",
    "jadiar": "ja-diar",
    "jadraque": "ja-dra-que",
    "jaecera": "ja-e-ce-ra",
    "jaecero": "ja-e-ce-ro",
    "jaén": "ja-én",
    "jaenera": "ja-e-ne-ra",
    "jaenero": "ja-e-ne-ro",
    "jaenés": "ja-e-nés",
    "jaenesa": "ja-e-ne-sa",
    "jaez": "ja-ez",
    "jaezar": "ja-e-zar",
    "jafética": "ja-fé-ti-ca",
    "jafético": "ja-fé-ti-co",
    "jagua": "ja-gua",
    "jaguar": "ja-guar",
    "jaguareté": "ja-gua-re-té",
    "jaguarundí": "ja-gua-run-dí",
    "jaguarzo": "ja-guar-zo",
    "jagüel": "ja-güel",
    "jagüey": "ja-güey",
    "jagüilla": "ja-güi-lla",
    "jaharí": "ja-ha-rí",
    "jaharrar": "ja-ha-rrar",
    "jaharro": "ja-ha-rro",
    "jaiba": "jai-ba",
    "jaibería": "jai-be-rí-a",
    "jaibol": "jai-bol",
    "jailoso": "jai-lo-so",
    "jaima": "jai-ma",
    "jaimitada": "jai-mi-ta-da",
    "jaimito": "jai-mi-to",
    "jainismo": "jai-nis-mo",
    "jainista": "jai-nis-ta",
    "jaique": "jai-que",
    "jajajear": "ja-ja-je-ar",
    "jajay": "ja-jay",
    "jala": "ja-la",
    "jalacate": "ja-la-ca-te",
    "jalada": "ja-la-da",
    "jaladera": "ja-la-de-ra",
    "jalado": "ja-la-do",
    "jalador": "ja-la-dor",
    "jaladora": "ja-la-do-ra",
    "jalapa": "ja-la-pa",
    "jalapaneca": "ja-la-pa-ne-ca",
    "jalapaneco": "ja-la-pa-ne-co",
    "jalapeña": "ja-la-pe-ña",
    "jalapeño": "ja-la-pe-ño",
    "jalar": "ja-lar",
    "jalbegador": "jal-be-ga-dor",
    "jalbegadora": "jal-be-ga-do-ra",
    "jalbegar": "jal-be-gar",
    "jalbegue": "jal-be-gue",
    "jalca": "jal-ca",
    "jalda": "jal-da",
    "jaldada": "jal-da-da",
    "jaldado": "jal-da-do",
    "jalde": "jal-de",
    "jaldeta": "jal-de-ta",
    "jaldo": "jal-do",
    "jaldre": "jal-dre",
    "jale": "ja-le",
    "jalea": "ja-le-a",
    "jaleador": "ja-le-a-dor",
    "jaleadora": "ja-le-a-do-ra",
    "jalear": "ja-le-ar",
    "jaleco": "ja-le-co",
    "jalencia": "ja-len-cia",
    "jaleo": "ja-le-o",
    "jaletina": "ja-le-ti-na",
    "jalifa": "ja-li-fa",
    "jalifato": "ja-li-fa-to",
    "jalifiana": "ja-li-fia-na",
    "jalifiano": "ja-li-fia-no",
    "jalisciense": "ja-lis-cien-se",
    "jalisco": "ja-lis-co",
    "jalma": "jal-ma",
    "jalmería": "jal-me-rí-a",
    "jalmero": "jal-me-ro",
    "jalón": "ja-lón",
    "jalona": "ja-lo-na",
    "jalonamiento": "ja-lo-na-mien-to",
    "jalonar": "ja-lo-nar",
    "jalonazo": "ja-lo-na-zo",
    "jalonear": "ja-lo-ne-ar",
    "jaloneo": "ja-lo-ne-o",
    "jaloque": "ja-lo-que",
    "jama": "ja-ma",
    "jamacuco": "ja-ma-cu-co",
    "jamaica": "ja-mai-ca",
    "jamaicana": "ja-mai-ca-na",
    "jamaicano": "ja-mai-ca-no",
    "jamaiquina": "ja-mai-qui-na",
    "jamaiquino": "ja-mai-qui-no",
    "jamaliche": "ja-ma-li-che",
    "jamaquear": "ja-ma-que-ar",
    "jamaqueo": "ja-ma-que-o",
    "jamaqueón": "ja-ma-que-ón",
    "jamaquión": "ja-ma-quión",
    "jamar": "ja-mar",
    "jamás": "ja-más",
    "jamba": "jam-ba",
    "jambado": "jam-ba-do",
    "jambaje": "jam-ba-je",
    "jambar": "jam-bar",
    "jámbico": "jám-bi-co",
    "jambo": "jam-bo",
    "jambrar": "jam-brar",
    "jamelgo": "ja-mel-go",
    "jameo": "ja-me-o",
    "jamerdana": "ja-mer-da-na",
    "jamerdar": "ja-mer-dar",
    "jamete": "ja-me-te",
    "jámila": "já-mi-la",
    "jamo": "ja-mo",
    "jamón": "ja-món",
    "jamona": "ja-mo-na",
    "jamoncillo": "ja-mon-ci-llo",
    "jamonería": "ja-mo-ne-rí-a",
    "jamonero": "ja-mo-ne-ro",
    "jamúas": "ja-mú-as",
    "jamuga": "ja-mu-ga",
    "jamugas": "ja-mu-gas",
    "jamurar": "ja-mu-rar",
    "jamuscar": "ja-mus-car",
    "jaña": "ja-ña",
    "janana": "ja-na-na",
    "janano": "ja-na-no",
    "jándala": "ján-da-la",
    "jándalo": "ján-da-lo",
    "jangada": "jan-ga-da",
    "jangua": "jan-gua",
    "janiche": "ja-ni-che",
    "janicho": "ja-ni-cho",
    "jaño": "ja-ño",
    "jansenismo": "jan-se-nis-mo",
    "jansenista": "jan-se-nis-ta",
    "januche": "ja-nu-che",
    "japón": "ja-pón",
    "japona": "ja-po-na",
    "japonense": "ja-po-nen-se",
    "japonés": "ja-po-nés",
    "japonesa": "ja-po-ne-sa",
    "japónica": "ja-pó-ni-ca",
    "japuta": "ja-pu-ta",
    "japutamo": "ja-pu-ta-mo",
    "jaque": "ja-que",
    "jaquear": "ja-que-ar",
    "jaqueca": "ja-que-ca",
    "jaquecosa": "ja-que-co-sa",
    "jaquecoso": "ja-que-co-so",
    "jaquel": "ja-quel",
    "jaquelada": "ja-que-la-da",
    "jaquelado": "ja-que-la-do",
    "jaquero": "ja-que-ro",
    "jaqués": "ja-qués",
    "jaquesa": "ja-que-sa",
    "jaqueta": "ja-que-ta",
    "jaquetilla": "ja-que-ti-lla",
    "jaquetón": "ja-que-tón",
    "jaquetonería": "ja-que-to-ne-rí-a",
    "jáquima": "já-qui-ma",
    "jaquimazo": "ja-qui-ma-zo",
    "jaquimero": "ja-qui-me-ro",
    "jaquinicuil": "ja-qui-ni-cuil",
    "jaquir": "ja-quir",
    "jara": "ja-ra",
    "jarabe": "ja-ra-be",
    "jarabear": "ja-ra-be-ar",
    "jarabugo": "ja-ra-bu-go",
    "jaracalla": "ja-ra-ca-lla",
    "jaracatal": "ja-ra-ca-tal",
    "jaraíz": "ja-ra-íz",
    "jaral": "ja-ral",
    "jaramago": "ja-ra-ma-go",
    "jarameña": "ja-ra-me-ña",
    "jarameño": "ja-ra-me-ño",
    "jaramugo": "ja-ra-mu-go",
    "jarana": "ja-ra-na",
    "jarandina": "ja-ran-di-na",
    "jaranear": "ja-ra-ne-ar",
    "jaranera": "ja-ra-ne-ra",
    "jaranero": "ja-ra-ne-ro",
    "jaranista": "ja-ra-nis-ta",
    "jarano": "ja-ra-no",
    "jarapa": "ja-ra-pa",
    "jarazo": "ja-ra-zo",
    "jarbar": "jar-bar",
    "jarca": "jar-ca",
    "jarcería": "jar-ce-rí-a",
    "jarcha": "jar-cha",
    "jarcia": "jar-cia",
    "jarciar": "jar-ciar",
    "jarciera": "jar-cie-ra",
    "jarciería": "jar-cie-rí-a",
    "jarciero": "jar-cie-ro",
    "jarcio": "jar-cio",
    "jarda": "jar-da",
    "jardazo": "jar-da-zo",
    "jardín": "jar-dín",
    "jardinear": "jar-di-ne-ar",
    "jardinera": "jar-di-ne-ra",
    "jardinería": "jar-di-ne-rí-a",
    "jardinero": "jar-di-ne-ro",
    "jarear": "ja-re-ar",
    "jareta": "ja-re-ta",
    "jaretera": "ja-re-te-ra",
    "jaretón": "ja-re-tón",
    "jargonza": "jar-gon-za",
    "jaricar": "ja-ri-car",
    "jarichi": "ja-ri-chi",
    "jarico": "ja-ri-co",
    "jarifa": "ja-ri-fa",
    "jarife": "ja-ri-fe",
    "jarifiana": "ja-ri-fia-na",
    "jarifiano": "ja-ri-fia-no",
    "jarifo": "ja-ri-fo",
    "jarilla": "ja-ri-lla",
    "jarillo": "ja-ri-llo",
    "jaripeada": "ja-ri-pe-a-da",
    "jaripear": "ja-ri-pe-ar",
    "jaripeo": "ja-ri-pe-o",
    "jarique": "ja-ri-que",
    "járjara": "jár-ja-ra",
    "jaro": "ja-ro",
    "jarocha": "ja-ro-cha",
    "jarocho": "ja-ro-cho",
    "jaropar": "ja-ro-par",
    "jarope": "ja-ro-pe",
    "jaropear": "ja-ro-pe-ar",
    "jaropeo": "ja-ro-pe-o",
    "jarosa": "ja-ro-sa",
    "jaroso": "ja-ro-so",
    "jarquía": "jar-quí-a",
    "jarra": "ja-rra",
    "jarrar": "ja-rrar",
    "jarrazo": "ja-rra-zo",
    "jarrear": "ja-rre-ar",
    "jarrer": "ja-rrer",
    "jarrera": "ja-rre-ra",
    "jarrero": "ja-rre-ro",
    "jarretar": "ja-rre-tar",
    "jarrete": "ja-rre-te",
    "jarretera": "ja-rre-te-ra",
    "jarretuda": "ja-rre-tu-da",
    "jarretudo": "ja-rre-tu-do",
    "jarrita": "ja-rri-ta",
    "jarro": "ja-rro",
    "jarrón": "ja-rrón",
    "jarropa": "ja-rro-pa",
    "jartera": "jar-te-ra",
    "jarto": "jar-to",
    "jarusca": "ja-rus-ca",
    "jasa": "ja-sa",
    "jasador": "ja-sa-dor",
    "jasadura": "ja-sa-du-ra",
    "jasar": "ja-sar",
    "jaspe": "jas-pe",
    "jaspeada": "jas-pe-a-da",
    "jaspeado": "jas-pe-a-do",
    "jaspear": "jas-pe-ar",
    "jaspón": "jas-pón",
    "jata": "ja-ta",
    "jatata": "ja-ta-ta",
    "jatear": "ja-te-ar",
    "jateo": "ja-te-o",
    "jatib": "ja-tib",
    "jatibés": "ja-ti-bés",
    "jatibesa": "ja-ti-be-sa",
    "jativés": "ja-ti-vés",
    "jativesa": "ja-ti-ve-sa",
    "jato": "ja-to",
    "jauda": "jau-da",
    "jaudo": "jau-do",
    "jauja": "jau-ja",
    "jaujina": "jau-ji-na",
    "jaujino": "jau-ji-no",
    "jaúl": "ja-úl",
    "jaula": "jau-la",
    "jaulera": "jau-le-ra",
    "jaulero": "jau-le-ro",
    "jaulilla": "jau-li-lla",
    "jauría": "jau-rí-a",
    "jauta": "jau-ta",
    "jauto": "jau-to",
    "java": "ja-va",
    "javanés": "ja-va-nés",
    "javanesa": "ja-va-ne-sa",
    "javera": "ja-ve-ra",
    "javiereña": "ja-vie-re-ña",
    "javiereño": "ja-vie-re-ño",
    "javo": "ja-vo",
    "jayán": "ja-yán",
    "jayana": "ja-ya-na",
    "jayanada": "ja-ya-na-da",
    "jayanear": "ja-ya-ne-ar",
    "jayao": "ja-ya-o",
    "jazarán": "ja-za-rán",
    "jazarina": "ja-za-ri-na",
    "jazarino": "ja-za-ri-no",
    "jazmín": "jaz-mín",
    "jazmínea": "jaz-mí-ne-a",
    "jazmíneo": "jaz-mí-ne-o",
    "jazminero": "jaz-mi-ne-ro",
    "jazzista": "jaz-zis-ta",
    "jazzístico": "jaz-zís-ti-co",
    "jea": "je-a",
    "jeans": "je-ans",
    "jeba": "je-ba",
    "jebe": "je-be",
    "jebusea": "je-bu-se-a",
    "jebuseo": "je-bu-se-o",
    "jeda": "je-da",
    "jedar": "je-dar",
    "jedentina": "je-den-ti-na",
    "jediondo": "je-dion-do",
    "jedive": "je-di-ve",
    "jedrea": "je-dre-a",
    "jefa": "je-fa",
    "jefatura": "je-fa-tu-ra",
    "jefaza": "je-fa-za",
    "jefazo": "je-fa-zo",
    "jefe": "je-fe",
    "jegüite": "je-güi-te",
    "jehová": "je-ho-vá",
    "jeito": "jei-to",
    "jején": "je-jén",
    "jelengue": "je-len-gue",
    "jelepate": "je-le-pa-te",
    "jeliz": "je-liz",
    "jemal": "je-mal",
    "jeme": "je-me",
    "jemer": "je-mer",
    "jemesía": "je-me-sí-a",
    "jena": "je-na",
    "jenabe": "je-na-be",
    "jenable": "je-na-ble",
    "jenchicero": "jen-chi-ce-ro",
    "jengibre": "jen-gi-bre",
    "jeniquén": "je-ni-quén",
    "jenízara": "je-ní-za-ra",
    "jenízaro": "je-ní-za-ro",
    "jeque": "je-que",
    "jera": "je-ra",
    "jerapellina": "je-ra-pe-lli-na",
    "jerarca": "je-rar-ca",
    "jerarquía": "je-rar-quí-a",
    "jerárquica": "je-rár-qui-ca",
    "jerárquicamente": "je-rár-qui-ca-men-te",
    "jerárquico": "je-rár-qui-co",
    "jerarquización": "je-rar-qui-za-ción",
    "jerarquizar": "je-rar-qui-zar",
    "jerbo": "jer-bo",
    "jeremíaca": "je-re-mí-a-ca",
    "jeremiaca": "je-re-mia-ca",
    "jeremíaco": "je-re-mí-a-co",
    "jeremiada": "je-re-mia-da",
    "jeremías": "je-re-mí-as",
    "jeremiquear": "je-re-mi-que-ar",
    "jerez": "je-rez",
    "jerezana": "je-re-za-na",
    "jerezano": "je-re-za-no",
    "jerga": "jer-ga",
    "jergal": "jer-gal",
    "jergón": "jer-gón",
    "jerguilla": "jer-gui-lla",
    "jeribeque": "je-ri-be-que",
    "jericalla": "je-ri-ca-lla",
    "jericaya": "je-ri-ca-ya",
    "jericó": "je-ri-có",
    "jericoplear": "je-ri-co-ple-ar",
    "jerife": "je-ri-fe",
    "jerifiana": "je-ri-fia-na",
    "jerifiano": "je-ri-fia-no",
    "jerigonza": "je-ri-gon-za",
    "jerigonzar": "je-ri-gon-zar",
    "jeringa": "je-rin-ga",
    "jeringación": "je-rin-ga-ción",
    "jeringador": "je-rin-ga-dor",
    "jeringadora": "je-rin-ga-do-ra",
    "jeringar": "je-rin-gar",
    "jeringatorio": "je-rin-ga-to-rio",
    "jeringazo": "je-rin-ga-zo",
    "jeringón": "je-rin-gón",
    "jeringonza": "je-rin-gon-za",
    "jeringuear": "je-rin-gue-ar",
    "jeringuilla": "je-rin-gui-lla",
    "jeroglífica": "je-ro-glí-fi-ca",
    "jeroglífico": "je-ro-glí-fi-co",
    "jerónima": "je-ró-ni-ma",
    "jeronimiana": "je-ro-ni-mia-na",
    "jeronimiano": "je-ro-ni-mia-no",
    "jerónimo": "je-ró-ni-mo",
    "jerosolimitana": "je-ro-so-li-mi-ta-na",
    "jerosolimitano": "je-ro-so-li-mi-ta-no",
    "jerpa": "jer-pa",
    "jerricote": "je-rri-co-te",
    "jersey": "jer-sey",
    "jeruga": "je-ru-ga",
    "jerusalén": "je-ru-sa-lén",
    "jeruza": "je-ru-za",
    "jervilla": "jer-vi-lla",
    "jesé": "je-sé",
    "jesnata": "jes-na-ta",
    "jesnato": "jes-na-to",
    "jesucristo": "je-su-cris-to",
    "jesuita": "je-sui-ta",
    "jesuítica": "je-suí-ti-ca",
    "jesuítico": "je-suí-ti-co",
    "jesuitina": "je-sui-ti-na",
    "jesuitismo": "je-sui-tis-mo",
    "jesús": "je-sús",
    "jesusear": "je-su-se-ar",
    "jeta": "je-ta",
    "jetar": "je-tar",
    "jetazo": "je-ta-zo",
    "jetear": "je-te-ar",
    "jeto": "je-to",
    "jetón": "je-tón",
    "jetona": "je-to-na",
    "jetonada": "je-to-na-da",
    "jetonear": "je-to-ne-ar",
    "jetudo": "je-tu-do",
    "jeva": "je-va",
    "jíbara": "jí-ba-ra",
    "jíbaro": "jí-ba-ro",
    "jibe": "ji-be",
    "jibia": "ji-bia",
    "jibión": "ji-bión",
    "jibraltareña": "ji-bral-ta-re-ña",
    "jibraltareño": "ji-bral-ta-re-ño",
    "jícama": "jí-ca-ma",
    "jicaque": "ji-ca-que",
    "jícara": "jí-ca-ra",
    "jicaral": "ji-ca-ral",
    "jicarazo": "ji-ca-ra-zo",
    "jicarera": "ji-ca-re-ra",
    "jicarería": "ji-ca-re-rí-a",
    "jicarero": "ji-ca-re-ro",
    "jícaro": "jí-ca-ro",
    "jicarudo": "ji-ca-ru-do",
    "jichi": "ji-chi",
    "jico": "ji-co",
    "jicota": "ji-co-ta",
    "jicote": "ji-co-te",
    "jicotea": "ji-co-te-a",
    "jicotear": "ji-co-te-ar",
    "jicotera": "ji-co-te-ra",
    "jienense": "jie-nen-se",
    "jiennense": "jien-nen-se",
    "jifa": "ji-fa",
    "jifera": "ji-fe-ra",
    "jiferada": "ji-fe-ra-da",
    "jifería": "ji-fe-rí-a",
    "jifero": "ji-fe-ro",
    "jifia": "ji-fia",
    "jiga": "ji-ga",
    "jigo": "ji-go",
    "jigote": "ji-go-te",
    "jigüe": "ji-güe",
    "jiguilete": "ji-gui-le-te",
    "jiguillo": "ji-gui-llo",
    "jija": "ji-ja",
    "jijallar": "ji-ja-llar",
    "jijallo": "ji-ja-llo",
    "jijas": "ji-jas",
    "jijear": "ji-je-ar",
    "jijeo": "ji-je-o",
    "jijo": "ji-jo",
    "jijona": "ji-jo-na",
    "jijonenca": "ji-jo-nen-ca",
    "jijonenco": "ji-jo-nen-co",
    "jileco": "ji-le-co",
    "jilguera": "jil-gue-ra",
    "jilguero": "jil-gue-ro",
    "jilibioso": "ji-li-bio-so",
    "jilmaestre": "jil-ma-es-tre",
    "jilote": "ji-lo-te",
    "jilotear": "ji-lo-te-ar",
    "jimagua": "ji-ma-gua",
    "jimar": "ji-mar",
    "jimelga": "ji-mel-ga",
    "jimerito": "ji-me-ri-to",
    "jimia": "ji-mia",
    "jimio": "ji-mio",
    "jimplar": "jim-plar",
    "jiña": "ji-ña",
    "jiñar": "ji-ñar",
    "jincho": "jin-cho",
    "jinda": "jin-da",
    "jindama": "jin-da-ma",
    "jiné": "ji-né",
    "jinebro": "ji-ne-bro",
    "jinestada": "ji-nes-ta-da",
    "jineta": "ji-ne-ta",
    "jinetada": "ji-ne-ta-da",
    "jinete": "ji-ne-te",
    "jineteada": "ji-ne-te-a-da",
    "jinetear": "ji-ne-te-ar",
    "jinetera": "ji-ne-te-ra",
    "jinetero": "ji-ne-te-ro",
    "jinglar": "jin-glar",
    "jingoísmo": "jin-go-ís-mo",
    "jingoísta": "jin-go-ís-ta",
    "jinicuite": "ji-ni-cui-te",
    "jínjol": "jín-jol",
    "jinjolero": "jin-jo-le-ro",
    "jiñocuabo": "ji-ño-cua-bo",
    "jinojo": "ji-no-jo",
    "jinotegana": "ji-no-te-ga-na",
    "jinotegano": "ji-no-te-ga-no",
    "jiote": "jio-te",
    "jiotosa": "jio-to-sa",
    "jiotoso": "jio-to-so",
    "jiotuda": "jio-tu-da",
    "jiotudo": "jio-tu-do",
    "jipa": "ji-pa",
    "jipato": "ji-pa-to",
    "jipi": "ji-pi",
    "jipiar": "ji-piar",
    "jipido": "ji-pi-do",
    "jipijapa": "ji-pi-ja-pa",
    "jipío": "ji-pí-o",
    "jipioso": "ji-pio-so",
    "jipismo": "ji-pis-mo",
    "jíquera": "jí-que-ra",
    "jiquilete": "ji-qui-le-te",
    "jiquilite": "ji-qui-li-te",
    "jiquinicuil": "ji-qui-ni-cuil",
    "jira": "ji-ra",
    "jirafa": "ji-ra-fa",
    "jirahara": "ji-ra-ha-ra",
    "jirapliega": "ji-ra-plie-ga",
    "jirasal": "ji-ra-sal",
    "jirel": "ji-rel",
    "jiricaya": "ji-ri-ca-ya",
    "jíride": "jí-ri-de",
    "jirimiquear": "ji-ri-mi-que-ar",
    "jirocho": "ji-ro-cho",
    "jirofina": "ji-ro-fi-na",
    "jiroflé": "ji-ro-flé",
    "jirón": "ji-rón",
    "jironada": "ji-ro-na-da",
    "jironado": "ji-ro-na-do",
    "jirpear": "jir-pe-ar",
    "jisca": "jis-ca",
    "jismera": "jis-me-ra",
    "jismero": "jis-me-ro",
    "jitanjáfora": "ji-tan-já-fo-ra",
    "jitar": "ji-tar",
    "jitazo": "ji-ta-zo",
    "jitomatal": "ji-to-ma-tal",
    "jitomate": "ji-to-ma-te",
    "jitomatera": "ji-to-ma-te-ra",
    "jitomatero": "ji-to-ma-te-ro",
    "jobada": "jo-ba-da",
    "jobar": "jo-bar",
    "jobero": "jo-be-ro",
    "jobillo": "jo-bi-llo",
    "jobo": "jo-bo",
    "jochar": "jo-char",
    "jochatero": "jo-cha-te-ro",
    "joche": "jo-che",
    "jochear": "jo-che-ar",
    "jockey": "joc-key",
    "jocó": "jo-có",
    "jocón": "jo-cón",
    "joconostle": "jo-co-nos-tle",
    "jocoque": "jo-co-que",
    "jocoqui": "jo-co-qui",
    "jocosa": "jo-co-sa",
    "jocosamente": "jo-co-sa-men-te",
    "jocoseria": "jo-co-se-ria",
    "jocoserio": "jo-co-se-rio",
    "jocosidad": "jo-co-si-dad",
    "jocoso": "jo-co-so",
    "jocotal": "jo-co-tal",
    "jocote": "jo-co-te",
    "jocotear": "jo-co-te-ar",
    "jocoyote": "jo-co-yo-te",
    "jocunda": "jo-cun-da",
    "jocundidad": "jo-cun-di-dad",
    "jocundo": "jo-cun-do",
    "joda": "jo-da",
    "jodarria": "jo-da-rria",
    "jodedera": "jo-de-de-ra",
    "jodedor": "jo-de-dor",
    "joder": "jo-der",
    "jodido": "jo-di-do",
    "jodienda": "jo-dien-da",
    "jodión": "jo-dión",
    "jodón": "jo-dón",
    "jodona": "jo-do-na",
    "jofaina": "jo-fai-na",
    "jofor": "jo-for",
    "joglar": "jo-glar",
    "joglería": "jo-gle-rí-a",
    "joguer": "jo-guer",
    "jojana": "jo-ja-na",
    "jojoba": "jo-jo-ba",
    "jojoto": "jo-jo-to",
    "jolgorio": "jol-go-rio",
    "jolín": "jo-lín",
    "jolina": "jo-li-na",
    "jolines": "jo-li-nes",
    "jolino": "jo-li-no",
    "jolito": "jo-li-to",
    "jollín": "jo-llín",
    "joloana": "jo-lo-a-na",
    "joloano": "jo-lo-a-no",
    "jolongo": "jo-lon-go",
    "jolote": "jo-lo-te",
    "jomeinista": "jo-mei-nis-ta",
    "jomete": "jo-me-te",
    "jonia": "jo-nia",
    "jónica": "jó-ni-ca",
    "jónico": "jó-ni-co",
    "jonio": "jo-nio",
    "jonjabar": "jon-ja-bar",
    "jonjolí": "jon-jo-lí",
    "jonrón": "jon-rón",
    "jonronear": "jon-ro-ne-ar",
    "jonronera": "jon-ro-ne-ra",
    "jonronero": "jon-ro-ne-ro",
    "jonuco": "jo-nu-co",
    "jopar": "jo-par",
    "joparse": "jo-par-se",
    "jope": "jo-pe",
    "jopé": "jo-pé",
    "jopear": "jo-pe-ar",
    "jopeo": "jo-pe-o",
    "jopo": "jo-po",
    "jora": "jo-ra",
    "jorco": "jor-co",
    "jordán": "jor-dán",
    "jordana": "jor-da-na",
    "jordano": "jor-da-no",
    "jorfe": "jor-fe",
    "jorga": "jor-ga",
    "jorge": "jor-ge",
    "jorguín": "jor-guín",
    "jorguina": "jor-gui-na",
    "jorguinería": "jor-gui-ne-rí-a",
    "jornada": "jor-na-da",
    "jornal": "jor-nal",
    "jornalar": "jor-na-lar",
    "jornalear": "jor-na-le-ar",
    "jornalera": "jor-na-le-ra",
    "jornalero": "jor-na-le-ro",
    "joroba": "jo-ro-ba",
    "jorobada": "jo-ro-ba-da",
    "jorobado": "jo-ro-ba-do",
    "jorobadura": "jo-ro-ba-du-ra",
    "jorobar": "jo-ro-bar",
    "jorobeta": "jo-ro-be-ta",
    "jorobón": "jo-ro-bón",
    "jorobona": "jo-ro-bo-na",
    "jorongo": "jo-ron-go",
    "joropear": "jo-ro-pe-ar",
    "joropo": "jo-ro-po",
    "jorrar": "jo-rrar",
    "jorro": "jo-rro",
    "josa": "jo-sa",
    "josco": "jos-co",
    "josefina": "jo-se-fi-na",
    "josefinismo": "jo-se-fi-nis-mo",
    "josefino": "jo-se-fi-no",
    "josefismo": "jo-se-fis-mo",
    "jostra": "jos-tra",
    "jostrada": "jos-tra-da",
    "jostrado": "jos-tra-do",
    "jota": "jo-ta",
    "jote": "jo-te",
    "jotera": "jo-te-ra",
    "jotero": "jo-te-ro",
    "joto": "jo-to",
    "joule": "jou-le",
    "jovata": "jo-va-ta",
    "jovato": "jo-va-to",
    "joven": "jo-ven",
    "jovenado": "jo-ve-na-do",
    "jovenazo": "jo-ve-na-zo",
    "jovenete": "jo-ve-ne-te",
    "jovenzuela": "jo-ven-zue-la",
    "jovenzuelo": "jo-ven-zue-lo",
    "jovial": "jo-vial",
    "jovialidad": "jo-via-li-dad",
    "jovialmente": "jo-vial-men-te",
    "joya": "jo-ya",
    "joyante": "jo-yan-te",
    "joyel": "jo-yel",
    "joyelero": "jo-ye-le-ro",
    "joyera": "jo-ye-ra",
    "joyería": "jo-ye-rí-a",
    "joyero": "jo-ye-ro",
    "joyo": "jo-yo",
    "joyolina": "jo-yo-li-na",
    "joyón": "jo-yón",
    "joyosa": "jo-yo-sa",
    "joystick": "joys-tick",
    "juácata": "juá-ca-ta",
    "juagarzo": "jua-gar-zo",
    "juagaza": "jua-ga-za",
    "juana": "jua-na",
    "juanacastle": "jua-na-cas-tle",
    "juanelo": "jua-ne-lo",
    "juanete": "jua-ne-te",
    "juanetero": "jua-ne-te-ro",
    "juanetuda": "jua-ne-tu-da",
    "juanetudo": "jua-ne-tu-do",
    "juanilama": "jua-ni-la-ma",
    "juanillo": "jua-ni-llo",
    "juanramoniano": "juan-ra-mo-nia-no",
    "juarda": "juar-da",
    "juardosa": "juar-do-sa",
    "juardoso": "juar-do-so",
    "juarista": "jua-ris-ta",
    "juba": "ju-ba",
    "jubada": "ju-ba-da",
    "jubete": "ju-be-te",
    "jubetería": "ju-be-te-rí-a",
    "jubetero": "ju-be-te-ro",
    "jubilación": "ju-bi-la-ción",
    "jubilada": "ju-bi-la-da",
    "jubilado": "ju-bi-la-do",
    "jubilar": "ju-bi-lar",
    "jubileo": "ju-bi-le-o",
    "jubillo": "ju-bi-llo",
    "jubilo": "ju-bi-lo",
    "júbilo": "jú-bi-lo",
    "jubilosa": "ju-bi-lo-sa",
    "jubilosamente": "ju-bi-lo-sa-men-te",
    "jubiloso": "ju-bi-lo-so",
    "jubo": "ju-bo",
    "jubón": "ju-bón",
    "jubonero": "ju-bo-ne-ro",
    "jubre": "ju-bre",
    "júcaro": "jú-ca-ro",
    "juco": "ju-co",
    "judaica": "ju-dai-ca",
    "judaico": "ju-dai-co",
    "judaísmo": "ju-da-ís-mo",
    "judaización": "ju-dai-za-ción",
    "judaizante": "ju-dai-zan-te",
    "judaizar": "ju-dai-zar",
    "judas": "ju-das",
    "judea": "ju-de-a",
    "judeoconversa": "ju-de-o-con-ver-sa",
    "judeoconverso": "ju-de-o-con-ver-so",
    "judeocristianismo": "ju-de-o-cris-tia-nis-mo",
    "judeocristiano": "ju-de-o-cris-tia-no",
    "judeoespañol": "ju-de-o-es-pa-ñol",
    "judeoespañola": "ju-de-o-es-pa-ño-la",
    "judería": "ju-de-rí-a",
    "judgador": "jud-ga-dor",
    "judgar": "jud-gar",
    "judía": "ju-dí-a",
    "judiada": "ju-dia-da",
    "judiar": "ju-diar",
    "judicante": "ju-di-can-te",
    "judicar": "ju-di-car",
    "judicativa": "ju-di-ca-ti-va",
    "judicativo": "ju-di-ca-ti-vo",
    "judicatura": "ju-di-ca-tu-ra",
    "judicial": "ju-di-cial",
    "judicialización": "ju-di-cia-li-za-ción",
    "judicializar": "ju-di-cia-li-zar",
    "judicialmente": "ju-di-cial-men-te",
    "judiciaria": "ju-di-cia-ria",
    "judiciario": "ju-di-cia-rio",
    "judicio": "ju-di-cio",
    "judiciosa": "ju-di-cio-sa",
    "judicioso": "ju-di-cio-so",
    "judiega": "ju-die-ga",
    "judiego": "ju-die-go",
    "judío": "ju-dí-o",
    "judión": "ju-dión",
    "judo": "ju-do",
    "judoca": "ju-do-ca",
    "judoka": "ju-do-ka",
    "jueceo": "jue-ce-o",
    "juego": "jue-go",
    "juera": "jue-ra",
    "juerga": "juer-ga",
    "juerguear": "juer-gue-ar",
    "juerguista": "juer-guis-ta",
    "jueves": "jue-ves",
    "jueza": "jue-za",
    "jugada": "ju-ga-da",
    "jugadera": "ju-ga-de-ra",
    "jugado": "ju-ga-do",
    "jugador": "ju-ga-dor",
    "jugadora": "ju-ga-do-ra",
    "jugar": "ju-gar",
    "jugarreta": "ju-ga-rre-ta",
    "juglándeo": "ju-glán-de-o",
    "juglar": "ju-glar",
    "juglara": "ju-gla-ra",
    "juglarería": "ju-gla-re-rí-a",
    "juglaresa": "ju-gla-re-sa",
    "juglaresca": "ju-gla-res-ca",
    "juglaresco": "ju-gla-res-co",
    "juglaría": "ju-gla-rí-a",
    "juglería": "ju-gle-rí-a",
    "jugo": "ju-go",
    "jugosa": "ju-go-sa",
    "jugosidad": "ju-go-si-dad",
    "jugoso": "ju-go-so",
    "juguera": "ju-gue-ra",
    "juguería": "ju-gue-rí-a",
    "juguete": "ju-gue-te",
    "juguetear": "ju-gue-te-ar",
    "jugueteo": "ju-gue-te-o",
    "juguetera": "ju-gue-te-ra",
    "juguetería": "ju-gue-te-rí-a",
    "juguetero": "ju-gue-te-ro",
    "juguetón": "ju-gue-tón",
    "juguetona": "ju-gue-to-na",
    "juiciero": "jui-cie-ro",
    "juicio": "jui-cio",
    "juiciosa": "jui-cio-sa",
    "juiciosamente": "jui-cio-sa-men-te",
    "juicioso": "jui-cio-so",
    "juico": "jui-co",
    "juigalpina": "jui-gal-pi-na",
    "juigalpino": "jui-gal-pi-no",
    "juilín": "jui-lín",
    "juilón": "jui-lón",
    "jujear": "ju-je-ar",
    "jujeña": "ju-je-ña",
    "jujeño": "ju-je-ño",
    "jujeo": "ju-je-o",
    "jula": "ju-la",
    "julandrón": "ju-lan-drón",
    "julango": "ju-lan-go",
    "julepe": "ju-le-pe",
    "julepear": "ju-le-pe-ar",
    "julia": "ju-lia",
    "juliana": "ju-lia-na",
    "juliano": "ju-lia-no",
    "juliaqueña": "ju-lia-que-ña",
    "juliaqueño": "ju-lia-que-ño",
    "julio": "ju-lio",
    "julo": "ju-lo",
    "juma": "ju-ma",
    "jumar": "ju-mar",
    "jumareda": "ju-ma-re-da",
    "jumarse": "ju-mar-se",
    "jumas": "ju-mas",
    "jumbo": "jum-bo",
    "jumear": "ju-me-ar",
    "jumenta": "ju-men-ta",
    "jumental": "ju-men-tal",
    "jumentil": "ju-men-til",
    "jumentizar": "ju-men-ti-zar",
    "jumento": "ju-men-to",
    "jumera": "ju-me-ra",
    "jumetrear": "ju-me-tre-ar",
    "jumil": "ju-mil",
    "jumilla": "ju-mi-lla",
    "jumo": "ju-mo",
    "jumper": "jum-per",
    "junar": "ju-nar",
    "juncácea": "jun-cá-ce-a",
    "juncáceas": "jun-cá-ce-as",
    "juncáceo": "jun-cá-ce-o",
    "juncada": "jun-ca-da",
    "juncal": "jun-cal",
    "juncar": "jun-car",
    "júncea": "jún-ce-a",
    "júnceo": "jún-ce-o",
    "juncia": "jun-cia",
    "juncial": "jun-cial",
    "junciana": "jun-cia-na",
    "junciera": "jun-cie-ra",
    "juncina": "jun-ci-na",
    "juncino": "jun-ci-no",
    "juncir": "jun-cir",
    "junco": "jun-co",
    "juncosa": "jun-co-sa",
    "juncoso": "jun-co-so",
    "junene": "ju-ne-ne",
    "jungla": "jun-gla",
    "junglada": "jun-gla-da",
    "juniapa": "ju-nia-pa",
    "juniche": "ju-ni-che",
    "juninense": "ju-ni-nen-se",
    "junio": "ju-nio",
    "junior": "ju-nior",
    "júnior": "jú-nior",
    "juniora": "ju-nio-ra",
    "juniorado": "ju-nio-ra-do",
    "junípero": "ju-ní-pe-ro",
    "juñir": "ju-ñir",
    "junquera": "jun-que-ra",
    "junqueral": "jun-que-ral",
    "junquillo": "jun-qui-llo",
    "junta": "jun-ta",
    "juntador": "jun-ta-dor",
    "juntadora": "jun-ta-do-ra",
    "juntamente": "jun-ta-men-te",
    "juntamiento": "jun-ta-mien-to",
    "juntapapeles": "jun-ta-pa-pe-les",
    "juntapuchos": "jun-ta-pu-chos",
    "juntar": "jun-tar",
    "juntera": "jun-te-ra",
    "junterilla": "jun-te-ri-lla",
    "juntero": "jun-te-ro",
    "junto": "jun-to",
    "juntorio": "jun-to-rio",
    "juntucha": "jun-tu-cha",
    "juntura": "jun-tu-ra",
    "junza": "jun-za",
    "jupa": "ju-pa",
    "jupear": "ju-pe-ar",
    "jupia": "ju-pia",
    "jupiar": "ju-piar",
    "júpiter": "jú-pi-ter",
    "jupiterina": "ju-pi-te-ri-na",
    "jupiterino": "ju-pi-te-ri-no",
    "jupón": "ju-pón",
    "jupona": "ju-po-na",
    "juque": "ju-que",
    "juquear": "ju-que-ar",
    "juquencia": "ju-quen-cia",
    "jura": "ju-ra",
    "juraco": "ju-ra-co",
    "jurada": "ju-ra-da",
    "juradera": "ju-ra-de-ra",
    "juradería": "ju-ra-de-rí-a",
    "jurado": "ju-ra-do",
    "jurador": "ju-ra-dor",
    "juradora": "ju-ra-do-ra",
    "juraduría": "ju-ra-du-rí-a",
    "juramentar": "ju-ra-men-tar",
    "juramento": "ju-ra-men-to",
    "juramiento": "ju-ra-mien-to",
    "jurar": "ju-rar",
    "jurásica": "ju-rá-si-ca",
    "jurásico": "ju-rá-si-co",
    "juratoria": "ju-ra-to-ria",
    "juratorio": "ju-ra-to-rio",
    "jurco": "jur-co",
    "jurdana": "jur-da-na",
    "jurdano": "jur-da-no",
    "jurdía": "jur-dí-a",
    "jurel": "ju-rel",
    "jurera": "ju-re-ra",
    "jurero": "ju-re-ro",
    "jurguina": "jur-gui-na",
    "jurídica": "ju-rí-di-ca",
    "jurídicamente": "ju-rí-di-ca-men-te",
    "juridicidad": "ju-ri-di-ci-dad",
    "jurídico": "ju-rí-di-co",
    "juridificación": "ju-ri-di-fi-ca-ción",
    "juridificar": "ju-ri-di-fi-car",
    "jurisconsulta": "ju-ris-con-sul-ta",
    "jurisconsulto": "ju-ris-con-sul-to",
    "jurisdicción": "ju-ris-dic-ción",
    "jurisdiccional": "ju-ris-dic-cio-nal",
    "jurispericia": "ju-ris-pe-ri-cia",
    "jurisperita": "ju-ris-pe-ri-ta",
    "jurisperito": "ju-ris-pe-ri-to",
    "jurisprudencia": "ju-ris-pru-den-cia",
    "jurisprudente": "ju-ris-pru-den-te",
    "jurista": "ju-ris-ta",
    "juro": "ju-ro",
    "jurquero": "jur-que-ro",
    "jurunera": "ju-ru-ne-ra",
    "jurungar": "ju-run-gar",
    "jurutungo": "ju-ru-tun-go",
    "jusbarba": "jus-bar-ba",
    "jusello": "ju-se-llo",
    "jusente": "ju-sen-te",
    "jusi": "ju-si",
    "justa": "jus-ta",
    "justador": "jus-ta-dor",
    "justamente": "jus-ta-men-te",
    "justar": "jus-tar",
    "justedad": "jus-te-dad",
    "justeque": "jus-te-que",
    "justeza": "jus-te-za",
    "justicia": "jus-ti-cia",
    "justiciable": "jus-ti-cia-ble",
    "justiciador": "jus-ti-cia-dor",
    "justicialismo": "jus-ti-cia-lis-mo",
    "justicialista": "jus-ti-cia-lis-ta",
    "justiciar": "jus-ti-ciar",
    "justiciazgo": "jus-ti-ciaz-go",
    "justiciera": "jus-ti-cie-ra",
    "justiciero": "jus-ti-cie-ro",
    "justificable": "jus-ti-fi-ca-ble",
    "justificación": "jus-ti-fi-ca-ción",
    "justificada": "jus-ti-fi-ca-da",
    "justificadamente": "jus-ti-fi-ca-da-men-te",
    "justificado": "jus-ti-fi-ca-do",
    "justificador": "jus-ti-fi-ca-dor",
    "justificadora": "jus-ti-fi-ca-do-ra",
    "justificante": "jus-ti-fi-can-te",
    "justificar": "jus-ti-fi-car",
    "justificativa": "jus-ti-fi-ca-ti-va",
    "justificativo": "jus-ti-fi-ca-ti-vo",
    "justillo": "jus-ti-llo",
    "justinianea": "jus-ti-nia-ne-a",
    "justinianeo": "jus-ti-nia-ne-o",
    "justipreciación": "jus-ti-pre-cia-ción",
    "justipreciar": "jus-ti-pre-ciar",
    "justiprecio": "jus-ti-pre-cio",
    "justo": "jus-to",
    "juta": "ju-ta",
    "jutía": "ju-tí-a",
    "jutiapaneca": "ju-tia-pa-ne-ca",
    "jutiapaneco": "ju-tia-pa-ne-co",
    "juticalpense": "ju-ti-cal-pen-se",
    "juvenal": "ju-ve-nal",
    "juvenca": "ju-ven-ca",
    "juvenco": "ju-ven-co",
    "juvenecer": "ju-ve-ne-cer",
    "juvenil": "ju-ve-nil",
    "juventud": "ju-ven-tud",
    "juvia": "ju-via",
    "juyaca": "ju-ya-ca",
    "juyunga": "ju-yun-ga",
    "juyungo": "ju-yun-go",
    "juyuya": "ju-yu-ya",
    "juyuyo": "ju-yu-yo",
    "juzgado": "juz-ga-do",
    "juzgador": "juz-ga-dor",
    "juzgadora": "juz-ga-do-ra",
    "juzgaduría": "juz-ga-du-rí-a",
    "juzgamiento": "juz-ga-mien-to",
    "juzgamundos": "juz-ga-mun-dos",
    "juzgar": "juz-gar",
    "kaaguaseña": "ka-a-gua-se-ña",
    "kaaguaseño": "ka-a-gua-se-ño",
    "kaakupeña": "ka-a-ku-pe-ña",
    "kaakupeño": "ka-a-ku-pe-ño",
    "kaasapeña": "ka-a-sa-pe-ña",
    "kaasapeño": "ka-a-sa-pe-ño",
    "kabuki": "ka-bu-ki",
    "kafkiano": "kaf-kia-no",
    "káiser": "kái-ser",
    "kaki": "ka-ki",
    "kamikaze": "ka-mi-ka-ze",
    "kanindeyuense": "ka-nin-de-yuen-se",
    "kanjobal": "kan-jo-bal",
    "kantiana": "kan-tia-na",
    "kantiano": "kan-tia-no",
    "kantismo": "kan-tis-mo",
    "kantista": "kan-tis-ta",
    "kappa": "kap-pa",
    "kaputt": "ka-putt",
    "karakul": "ka-ra-kul",
    "karaoke": "ka-ra-o-ke",
    "karate": "ka-ra-te",
    "kárate": "ká-ra-te",
    "karateca": "ka-ra-te-ca",
    "karateka": "ka-ra-te-ka",
    "karma": "kar-ma",
    "kárstico": "kárs-ti-co",
    "karting": "kar-ting",
    "kastila": "kas-ti-la",
    "katiuska": "ka-tius-ka",
    "kavakava": "ka-va-ka-va",
    "kayak": "ka-yak",
    "kazaka": "ka-za-ka",
    "kazako": "ka-za-ko",
    "kea": "ke-a",
    "kebab": "ke-bab",
    "kéfir": "ké-fir",
    "kelvin": "kel-vin",
    "kelvinio": "kel-vi-nio",
    "kendo": "ken-do",
    "keniana": "ke-nia-na",
    "keniano": "ke-nia-no",
    "keniata": "ke-nia-ta",
    "kepí": "ke-pí",
    "kepis": "ke-pis",
    "kerigma": "ke-rig-ma",
    "kermes": "ker-mes",
    "kermés": "ker-més",
    "kerosén": "ke-ro-sén",
    "kerosene": "ke-ro-se-ne",
    "keroseno": "ke-ro-se-no",
    "kétchup": "két-chup",
    "khoisánida": "khoi-sá-ni-da",
    "kibbutz": "kib-butz",
    "kibutz": "ki-butz",
    "kiko": "ki-ko",
    "kili": "ki-li",
    "kiliárea": "ki-liá-re-a",
    "kilim": "ki-lim",
    "kílim": "kí-lim",
    "kilo": "ki-lo",
    "kilobyte": "ki-loby-te",
    "kilocaloría": "ki-lo-ca-lo-rí-a",
    "kilociclo": "ki-lo-ci-clo",
    "kilográmetro": "ki-lo-grá-me-tro",
    "kilogramo": "ki-lo-gra-mo",
    "kilohercio": "ki-lo-her-cio",
    "kilohertz": "ki-lo-hertz",
    "kilolitro": "ki-lo-li-tro",
    "kilometraje": "ki-lo-me-tra-je",
    "kilometrar": "ki-lo-me-trar",
    "kilométrica": "ki-lo-mé-tri-ca",
    "kilométrico": "ki-lo-mé-tri-co",
    "kilómetro": "ki-ló-me-tro",
    "kilopondio": "ki-lo-pon-dio",
    "kilotex": "ki-lo-tex",
    "kilotón": "ki-lo-tón",
    "kilovatio": "ki-lo-va-tio",
    "kilovoltio": "ki-lo-vol-tio",
    "kilowatt": "ki-lo-watt",
    "kimono": "ki-mo-no",
    "kínder": "kín-der",
    "kindergarten": "kin-der-gar-ten",
    "kinésica": "ki-né-si-ca",
    "kinésico": "ki-né-si-co",
    "kinesióloga": "ki-ne-sió-lo-ga",
    "kinesiología": "ki-ne-sio-lo-gí-a",
    "kinesiólogo": "ki-ne-sió-lo-go",
    "kinesioterapia": "ki-ne-sio-te-ra-pia",
    "kinesioterápico": "ki-ne-sio-te-rá-pi-co",
    "kinesiterapia": "ki-ne-si-te-ra-pia",
    "kinesiterápico": "ki-ne-si-te-rá-pi-co",
    "kiosco": "kios-co",
    "kioskera": "kios-ke-ra",
    "kioskero": "kios-ke-ro",
    "kiosquera": "kios-que-ra",
    "kiosquero": "kios-que-ro",
    "kipá": "ki-pá",
    "kirguís": "kir-guís",
    "kirguiza": "kir-gui-za",
    "kirguizo": "kir-gui-zo",
    "kiribatiana": "ki-ri-ba-tia-na",
    "kiribatiano": "ki-ri-ba-tia-no",
    "kirie": "ki-rie",
    "kirieleisón": "ki-rie-lei-són",
    "kitchenette": "kit-che-net-te",
    "kivi": "ki-vi",
    "kiwi": "ki-wi",
    "kleenex": "kle-e-nex",
    "koala": "ko-a-la",
    "kodzito": "kod-zi-to",
    "kohol": "ko-hol",
    "koiné": "koi-né",
    "koljoz": "kol-joz",
    "kopek": "ko-pek",
    "kosovar": "ko-so-var",
    "kostka": "kost-ka",
    "krakatoano": "kra-ka-to-a-no",
    "krausismo": "krau-sis-mo",
    "krausista": "krau-sis-ta",
    "kremlin": "krem-lin",
    "kremlinóloga": "krem-li-nó-lo-ga",
    "kremlinología": "krem-li-no-lo-gí-a",
    "kremlinólogo": "krem-li-nó-lo-go",
    "kriptón": "krip-tón",
    "kufía": "ku-fí-a",
    "kunzita": "kun-zi-ta",
    "kurchatovio": "kur-cha-to-vio",
    "kurda": "kur-da",
    "kurdo": "kur-do",
    "kuriliana": "ku-ri-lia-na",
    "kuriliano": "ku-ri-lia-no",
    "kuriliense": "ku-ri-lien-se",
    "kuwaití": "ku-wai-tí",
    "lábaro": "lá-ba-ro",
    "labe": "la-be",
    "labeo": "la-be-o",
    "laberíntica": "la-be-rín-ti-ca",
    "laberíntico": "la-be-rín-ti-co",
    "laberinto": "la-be-rin-to",
    "labia": "la-bia",
    "labiada": "la-bia-da",
    "labiadas": "la-bia-das",
    "labiado": "la-bia-do",
    "labial": "la-bial",
    "labialización": "la-bia-li-za-ción",
    "labializar": "la-bia-li-zar",
    "labiarriscada": "la-bia-rris-ca-da",
    "labiarriscado": "la-bia-rris-ca-do",
    "labiérnago": "la-biér-na-go",
    "labihendida": "la-bihen-di-da",
    "labihendido": "la-bihen-di-do",
    "lábil": "lá-bil",
    "labilidad": "la-bi-li-dad",
    "labio": "la-bio",
    "labiodental": "la-bio-den-tal",
    "labiosa": "la-bio-sa",
    "labioso": "la-bio-so",
    "labiovelar": "la-bio-ve-lar",
    "labirinto": "la-bi-rin-to",
    "labor": "la-bor",
    "laborable": "la-bo-ra-ble",
    "laborador": "la-bo-ra-dor",
    "laboral": "la-bo-ral",
    "laboralista": "la-bo-ra-lis-ta",
    "laborante": "la-bo-ran-te",
    "laborar": "la-bo-rar",
    "laboratorio": "la-bo-ra-to-rio",
    "laboratorista": "la-bo-ra-to-ris-ta",
    "laborear": "la-bo-re-ar",
    "laboreo": "la-bo-re-o",
    "laborera": "la-bo-re-ra",
    "laborero": "la-bo-re-ro",
    "laborío": "la-bo-rí-o",
    "laboriosa": "la-bo-rio-sa",
    "laboriosamente": "la-bo-rio-sa-men-te",
    "laboriosidad": "la-bo-rio-si-dad",
    "laborioso": "la-bo-rio-so",
    "laborismo": "la-bo-ris-mo",
    "laborista": "la-bo-ris-ta",
    "laborosa": "la-bo-ro-sa",
    "laboroso": "la-bo-ro-so",
    "labortano": "la-bor-ta-no",
    "laborterapia": "la-bor-te-ra-pia",
    "labra": "la-bra",
    "labrada": "la-bra-da",
    "labradera": "la-bra-de-ra",
    "labradero": "la-bra-de-ro",
    "labradía": "la-bra-dí-a",
    "labradío": "la-bra-dí-o",
    "labrado": "la-bra-do",
    "labrador": "la-bra-dor",
    "labradora": "la-bra-do-ra",
    "labradoresca": "la-bra-do-res-ca",
    "labradoresco": "la-bra-do-res-co",
    "labradoril": "la-bra-do-ril",
    "labradorita": "la-bra-do-ri-ta",
    "labrandera": "la-bran-de-ra",
    "labrante": "la-bran-te",
    "labrantía": "la-bran-tí-a",
    "labrantín": "la-bran-tín",
    "labrantío": "la-bran-tí-o",
    "labranza": "la-bran-za",
    "labrapuntas": "la-bra-pun-tas",
    "labrar": "la-brar",
    "labrera": "la-bre-ra",
    "labrero": "la-bre-ro",
    "lábrido": "lá-bri-do",
    "labriega": "la-brie-ga",
    "labriego": "la-brie-go",
    "labrio": "la-brio",
    "labro": "la-bro",
    "labrusca": "la-brus-ca",
    "laburador": "la-bu-ra-dor",
    "laburadora": "la-bu-ra-do-ra",
    "laburanta": "la-bu-ran-ta",
    "laburante": "la-bu-ran-te",
    "laburar": "la-bu-rar",
    "laburo": "la-bu-ro",
    "laca": "la-ca",
    "lacado": "la-ca-do",
    "lacandón": "la-can-dón",
    "lacandona": "la-can-do-na",
    "lacar": "la-car",
    "lacaya": "la-ca-ya",
    "lacayil": "la-ca-yil",
    "lacayo": "la-ca-yo",
    "lacayuna": "la-ca-yu-na",
    "lacayuno": "la-ca-yu-no",
    "laceada": "la-ce-a-da",
    "laceador": "la-ce-a-dor",
    "laceadora": "la-ce-a-do-ra",
    "lacear": "la-ce-ar",
    "lacedemón": "la-ce-de-món",
    "lacedemonia": "la-ce-de-mo-nia",
    "lacedemonio": "la-ce-de-mo-nio",
    "lacena": "la-ce-na",
    "lacera": "la-ce-ra",
    "laceración": "la-ce-ra-ción",
    "lacerada": "la-ce-ra-da",
    "lacerado": "la-ce-ra-do",
    "lacerador": "la-ce-ra-dor",
    "lacerante": "la-ce-ran-te",
    "lacerar": "la-ce-rar",
    "lacería": "la-ce-rí-a",
    "laceria": "la-ce-ria",
    "laceriosa": "la-ce-rio-sa",
    "lacerioso": "la-ce-rio-so",
    "lacero": "la-ce-ro",
    "lacértido": "la-cér-ti-do",
    "lacerto": "la-cer-to",
    "lacertosa": "la-cer-to-sa",
    "lacertoso": "la-cer-to-so",
    "lacetana": "la-ce-ta-na",
    "lacetano": "la-ce-ta-no",
    "lacha": "la-cha",
    "lachear": "la-che-ar",
    "lacho": "la-cho",
    "lacia": "la-cia",
    "lacinia": "la-ci-nia",
    "laciniada": "la-ci-nia-da",
    "laciniado": "la-ci-nia-do",
    "lacio": "la-cio",
    "laciva": "la-ci-va",
    "lacivo": "la-ci-vo",
    "lacolito": "la-co-li-to",
    "lacón": "la-cón",
    "laconia": "la-co-nia",
    "lacónica": "la-có-ni-ca",
    "lacónicamente": "la-có-ni-ca-men-te",
    "lacónico": "la-có-ni-co",
    "laconio": "la-co-nio",
    "laconismo": "la-co-nis-mo",
    "lacra": "la-cra",
    "lacrar": "la-crar",
    "lacre": "la-cre",
    "lacrimable": "la-cri-ma-ble",
    "lacrimación": "la-cri-ma-ción",
    "lacrimal": "la-cri-mal",
    "lacrimar": "la-cri-mar",
    "lacrimatorio": "la-cri-ma-to-rio",
    "lacrimógena": "la-cri-mó-ge-na",
    "lacrimógeno": "la-cri-mó-ge-no",
    "lacrimosa": "la-cri-mo-sa",
    "lacrimosamente": "la-cri-mo-sa-men-te",
    "lacrimoso": "la-cri-mo-so",
    "lactación": "lac-ta-ción",
    "lactancia": "lac-tan-cia",
    "lactante": "lac-tan-te",
    "lactar": "lac-tar",
    "lactaria": "lac-ta-ria",
    "lactario": "lac-ta-rio",
    "lactasa": "lac-ta-sa",
    "lactato": "lac-ta-to",
    "láctea": "lác-te-a",
    "lacteada": "lac-te-a-da",
    "lacteado": "lac-te-a-do",
    "lácteo": "lác-te-o",
    "lactescencia": "lac-tes-cen-cia",
    "lactescente": "lac-tes-cen-te",
    "lacticínea": "lac-ti-cí-ne-a",
    "lacticíneo": "lac-ti-cí-ne-o",
    "lacticinio": "lac-ti-ci-nio",
    "lacticinosa": "lac-ti-ci-no-sa",
    "lacticinoso": "lac-ti-ci-no-so",
    "láctico": "lác-ti-co",
    "lactífera": "lac-tí-fe-ra",
    "lactífero": "lac-tí-fe-ro",
    "lactómetro": "lac-tó-me-tro",
    "lactosa": "lac-to-sa",
    "lactosuero": "lac-to-sue-ro",
    "lactucario": "lac-tu-ca-rio",
    "lactumen": "lac-tu-men",
    "lacunario": "la-cu-na-rio",
    "lacustre": "la-cus-tre",
    "lada": "la-da",
    "ládano": "lá-da-no",
    "ladeada": "la-de-a-da",
    "ladeado": "la-de-a-do",
    "ladeamiento": "la-de-a-mien-to",
    "ladear": "la-de-ar",
    "ladeo": "la-de-o",
    "ladera": "la-de-ra",
    "ladería": "la-de-rí-a",
    "ladero": "la-de-ro",
    "laderoso": "la-de-ro-so",
    "ladierno": "la-dier-no",
    "ladilla": "la-di-lla",
    "ladillar": "la-di-llar",
    "ladillo": "la-di-llo",
    "ladilloso": "la-di-llo-so",
    "ladina": "la-di-na",
    "ladinamente": "la-di-na-men-te",
    "ladinización": "la-di-ni-za-ción",
    "ladinizar": "la-di-ni-zar",
    "ladino": "la-di-no",
    "lado": "la-do",
    "ladón": "la-dón",
    "ladra": "la-dra",
    "ladrador": "la-dra-dor",
    "ladradora": "la-dra-do-ra",
    "ladradura": "la-dra-du-ra",
    "ladrar": "la-drar",
    "ladrería": "la-dre-rí-a",
    "ladrerío": "la-dre-rí-o",
    "ladrido": "la-dri-do",
    "ladriello": "la-drie-llo",
    "ladrillado": "la-dri-lla-do",
    "ladrillador": "la-dri-lla-dor",
    "ladrillar": "la-dri-llar",
    "ladrillazo": "la-dri-lla-zo",
    "ladrillejo": "la-dri-lle-jo",
    "ladrillera": "la-dri-lle-ra",
    "ladrillero": "la-dri-lle-ro",
    "ladrillo": "la-dri-llo",
    "ladrillosa": "la-dri-llo-sa",
    "ladrilloso": "la-dri-llo-so",
    "ladrocinio": "la-dro-ci-nio",
    "ladrón": "la-drón",
    "ladrona": "la-dro-na",
    "ladronamente": "la-dro-na-men-te",
    "ladronear": "la-dro-ne-ar",
    "ladronera": "la-dro-ne-ra",
    "ladronería": "la-dro-ne-rí-a",
    "ladronesca": "la-dro-nes-ca",
    "ladronesco": "la-dro-nes-co",
    "ladronicio": "la-dro-ni-cio",
    "ladronzuela": "la-dron-zue-la",
    "ladronzuelo": "la-dron-zue-lo",
    "lagaña": "la-ga-ña",
    "lagañosa": "la-ga-ño-sa",
    "lagañoso": "la-ga-ño-so",
    "lagar": "la-gar",
    "lagarear": "la-ga-re-ar",
    "lagarearse": "la-ga-re-ar-se",
    "lagarejo": "la-ga-re-jo",
    "lagarero": "la-ga-re-ro",
    "lagareta": "la-ga-re-ta",
    "lagarta": "la-gar-ta",
    "lagartada": "la-gar-ta-da",
    "lagartado": "la-gar-ta-do",
    "lagartear": "la-gar-te-ar",
    "lagartera": "la-gar-te-ra",
    "lagarterana": "la-gar-te-ra-na",
    "lagarterano": "la-gar-te-ra-no",
    "lagartero": "la-gar-te-ro",
    "lagartezna": "la-gar-tez-na",
    "lagartija": "la-gar-ti-ja",
    "lagartijera": "la-gar-ti-je-ra",
    "lagartijero": "la-gar-ti-je-ro",
    "lagarto": "la-gar-to",
    "lagartón": "la-gar-tón",
    "lagartona": "la-gar-to-na",
    "lago": "la-go",
    "lagomorfo": "la-go-mor-fo",
    "lagopo": "la-go-po",
    "lagosta": "la-gos-ta",
    "lagostín": "la-gos-tín",
    "lagotear": "la-go-te-ar",
    "lagotera": "la-go-te-ra",
    "lagotería": "la-go-te-rí-a",
    "lagotero": "la-go-te-ro",
    "lágrima": "lá-gri-ma",
    "lagrimable": "la-gri-ma-ble",
    "lagrimal": "la-gri-mal",
    "lagrimar": "la-gri-mar",
    "lagrimear": "la-gri-me-ar",
    "lagrimeo": "la-gri-me-o",
    "lagrimón": "la-gri-món",
    "lagrimona": "la-gri-mo-na",
    "lagrimosa": "la-gri-mo-sa",
    "lagrimoso": "la-gri-mo-so",
    "lagua": "la-gua",
    "laguna": "la-gu-na",
    "lagunajo": "la-gu-na-jo",
    "lagunar": "la-gu-nar",
    "lagunato": "la-gu-na-to",
    "lagunazo": "la-gu-na-zo",
    "lagunear": "la-gu-ne-ar",
    "lagunera": "la-gu-ne-ra",
    "lagunerío": "la-gu-ne-rí-o",
    "lagunero": "la-gu-ne-ro",
    "lagunés": "la-gu-nés",
    "lagunesa": "la-gu-ne-sa",
    "lagunosa": "la-gu-no-sa",
    "lagunoso": "la-gu-no-so",
    "laica": "lai-ca",
    "laicado": "lai-ca-do",
    "laical": "lai-cal",
    "laicho": "lai-cho",
    "laicidad": "lai-ci-dad",
    "laicismo": "lai-cis-mo",
    "laicista": "lai-cis-ta",
    "laicización": "lai-ci-za-ción",
    "laicizar": "lai-ci-zar",
    "laico": "lai-co",
    "laida": "lai-da",
    "laidamente": "lai-da-men-te",
    "laido": "lai-do",
    "laika": "lai-ka",
    "lailán": "lai-lán",
    "lairén": "lai-rén",
    "laísmo": "la-ís-mo",
    "laísta": "la-ís-ta",
    "laja": "la-ja",
    "lajazo": "la-ja-zo",
    "lama": "la-ma",
    "lamaísmo": "la-ma-ís-mo",
    "lamaísta": "la-ma-ís-ta",
    "lamasería": "la-ma-se-rí-a",
    "lambada": "lam-ba-da",
    "lambarera": "lam-ba-re-ra",
    "lambarero": "lam-ba-re-ro",
    "lambayecana": "lam-ba-ye-ca-na",
    "lambayecano": "lam-ba-ye-ca-no",
    "lambda": "lamb-da",
    "lambeculo": "lam-be-cu-lo",
    "lambeculos": "lam-be-cu-los",
    "lambedero": "lam-be-de-ro",
    "lambel": "lam-bel",
    "lambeo": "lam-be-o",
    "lambeojos": "lam-be-o-jos",
    "lambeplatos": "lam-be-pla-tos",
    "lamber": "lam-ber",
    "lambeta": "lam-be-ta",
    "lambetada": "lam-be-ta-da",
    "lambetazo": "lam-be-ta-zo",
    "lambetear": "lam-be-te-ar",
    "lambicar": "lam-bi-car",
    "lambiche": "lam-bi-che",
    "lambida": "lam-bi-da",
    "lambión": "lam-bión",
    "lambiotón": "lam-bio-tón",
    "lambiscar": "lam-bis-car",
    "lambiscón": "lam-bis-cón",
    "lambiscona": "lam-bis-co-na",
    "lambisconear": "lam-bis-co-ne-ar",
    "lambisconería": "lam-bis-co-ne-rí-a",
    "lambisquear": "lam-bis-que-ar",
    "lambistón": "lam-bis-tón",
    "lambistona": "lam-bis-to-na",
    "lambón": "lam-bón",
    "lambona": "lam-bo-na",
    "lambonería": "lam-bo-ne-rí-a",
    "lambrequín": "lam-bre-quín",
    "lambrija": "lam-bri-ja",
    "lambrón": "lam-brón",
    "lambrucear": "lam-bru-ce-ar",
    "lambrucia": "lam-bru-cia",
    "lambrucio": "lam-bru-cio",
    "lambucear": "lam-bu-ce-ar",
    "lambucera": "lam-bu-ce-ra",
    "lambucero": "lam-bu-ce-ro",
    "lambucia": "lam-bu-cia",
    "lambucio": "lam-bu-cio",
    "lambuzo": "lam-bu-zo",
    "lamé": "la-mé",
    "lameculos": "la-me-cu-los",
    "lamedal": "la-me-dal",
    "lamedor": "la-me-dor",
    "lamedora": "la-me-do-ra",
    "lamedura": "la-me-du-ra",
    "lamelibranquio": "la-me-li-bran-quio",
    "lamelirrostro": "la-me-li-rros-tro",
    "lamentable": "la-men-ta-ble",
    "lamentablemente": "la-men-ta-ble-men-te",
    "lamentación": "la-men-ta-ción",
    "lamentador": "la-men-ta-dor",
    "lamentadora": "la-men-ta-do-ra",
    "lamentar": "la-men-tar",
    "lamento": "la-men-to",
    "lamentosa": "la-men-to-sa",
    "lamentoso": "la-men-to-so",
    "lameojos": "la-me-o-jos",
    "lameplatos": "la-me-pla-tos",
    "lamer": "la-mer",
    "lamerón": "la-me-rón",
    "lamerona": "la-me-ro-na",
    "lametada": "la-me-ta-da",
    "lametazo": "la-me-ta-zo",
    "lametear": "la-me-te-ar",
    "lameteo": "la-me-te-o",
    "lametón": "la-me-tón",
    "lamia": "la-mia",
    "lamida": "la-mi-da",
    "lamido": "la-mi-do",
    "lamín": "la-mín",
    "lámina": "lá-mi-na",
    "laminación": "la-mi-na-ción",
    "laminada": "la-mi-na-da",
    "laminado": "la-mi-na-do",
    "laminador": "la-mi-na-dor",
    "laminadora": "la-mi-na-do-ra",
    "laminar": "la-mi-nar",
    "laminaria": "la-mi-na-ria",
    "laminera": "la-mi-ne-ra",
    "laminero": "la-mi-ne-ro",
    "laminosa": "la-mi-no-sa",
    "laminoso": "la-mi-no-so",
    "lamiscar": "la-mis-car",
    "lamista": "la-mis-ta",
    "lamosa": "la-mo-sa",
    "lamoso": "la-mo-so",
    "lampa": "lam-pa",
    "lampacear": "lam-pa-ce-ar",
    "lampaceo": "lam-pa-ce-o",
    "lampada": "lam-pa-da",
    "lámpada": "lám-pa-da",
    "lampadario": "lam-pa-da-rio",
    "lampalagua": "lam-pa-la-gua",
    "lampalla": "lam-pa-lla",
    "lampallo": "lam-pa-llo",
    "lampante": "lam-pan-te",
    "lampar": "lam-par",
    "lámpara": "lám-pa-ra",
    "lamparazo": "lam-pa-ra-zo",
    "lamparear": "lam-pa-re-ar",
    "lamparera": "lam-pa-re-ra",
    "lamparería": "lam-pa-re-rí-a",
    "lamparero": "lam-pa-re-ro",
    "lamparilla": "lam-pa-ri-lla",
    "lamparín": "lam-pa-rín",
    "lamparista": "lam-pa-ris-ta",
    "lamparita": "lam-pa-ri-ta",
    "lámparo": "lám-pa-ro",
    "lamparón": "lam-pa-rón",
    "lamparoso": "lam-pa-ro-so",
    "lampasear": "lam-pa-se-ar",
    "lampatán": "lam-pa-tán",
    "lampazo": "lam-pa-zo",
    "lampear": "lam-pe-ar",
    "lampeña": "lam-pe-ña",
    "lampeño": "lam-pe-ño",
    "lampeón": "lam-pe-ón",
    "lampiña": "lam-pi-ña",
    "lampiño": "lam-pi-ño",
    "lampión": "lam-pión",
    "lampista": "lam-pis-ta",
    "lampistera": "lam-pis-te-ra",
    "lampistería": "lam-pis-te-rí-a",
    "lampistero": "lam-pis-te-ro",
    "lampo": "lam-po",
    "lamprea": "lam-pre-a",
    "lampreada": "lam-pre-a-da",
    "lamprear": "lam-pre-ar",
    "lampreazo": "lam-pre-a-zo",
    "lamprehuela": "lam-pre-hue-la",
    "lampreílla": "lam-pre-í-lla",
    "lampuga": "lam-pu-ga",
    "lampuguera": "lam-pu-gue-ra",
    "lampuso": "lam-pu-so",
    "lana": "la-na",
    "laña": "la-ña",
    "lanada": "la-na-da",
    "lanado": "la-na-do",
    "lañador": "la-ña-dor",
    "lanar": "la-nar",
    "lañar": "la-ñar",
    "lanaria": "la-na-ria",
    "lancán": "lan-cán",
    "lance": "lan-ce",
    "lanceada": "lan-ce-a-da",
    "lanceado": "lan-ce-a-do",
    "lancear": "lan-ce-ar",
    "lancéola": "lan-cé-o-la",
    "lanceolada": "lan-ce-o-la-da",
    "lanceolado": "lan-ce-o-la-do",
    "lancera": "lan-ce-ra",
    "lancería": "lan-ce-rí-a",
    "lancero": "lan-ce-ro",
    "lanceta": "lan-ce-ta",
    "lancetada": "lan-ce-ta-da",
    "lancetazo": "lan-ce-ta-zo",
    "lancetero": "lan-ce-te-ro",
    "lancha": "lan-cha",
    "lanchada": "lan-cha-da",
    "lanchaje": "lan-cha-je",
    "lanchar": "lan-char",
    "lanchazo": "lan-cha-zo",
    "lanchero": "lan-che-ro",
    "lancho": "lan-cho",
    "lanchón": "lan-chón",
    "lancilla": "lan-ci-lla",
    "lancinante": "lan-ci-nan-te",
    "lancinar": "lan-ci-nar",
    "lancurdia": "lan-cur-dia",
    "landa": "lan-da",
    "lande": "lan-de",
    "landgrave": "land-gra-ve",
    "landgraviato": "land-gra-via-to",
    "landó": "lan-dó",
    "landra": "lan-dra",
    "landre": "lan-dre",
    "landrecilla": "lan-dre-ci-lla",
    "landrera": "lan-dre-ra",
    "landrero": "lan-dre-ro",
    "landrilla": "lan-dri-lla",
    "lanera": "la-ne-ra",
    "lanería": "la-ne-rí-a",
    "lanero": "la-ne-ro",
    "langa": "lan-ga",
    "langanazo": "lan-ga-na-zo",
    "lángara": "lán-ga-ra",
    "langaro": "lan-ga-ro",
    "langarote": "lan-ga-ro-te",
    "langaruta": "lan-ga-ru-ta",
    "langaruto": "lan-ga-ru-to",
    "langor": "lan-gor",
    "langosta": "lan-gos-ta",
    "langostera": "lan-gos-te-ra",
    "langostero": "lan-gos-te-ro",
    "langostín": "lan-gos-tín",
    "langostino": "lan-gos-ti-no",
    "langostón": "lan-gos-tón",
    "languarico": "lan-gua-ri-co",
    "languceta": "lan-gu-ce-ta",
    "languedociana": "lan-gue-do-cia-na",
    "languedociano": "lan-gue-do-cia-no",
    "langüetear": "lan-güe-te-ar",
    "lánguida": "lán-gui-da",
    "lánguidamente": "lán-gui-da-men-te",
    "languidecer": "lan-gui-de-cer",
    "languidez": "lan-gui-dez",
    "languideza": "lan-gui-de-za",
    "lánguido": "lán-gui-do",
    "languor": "lan-guor",
    "lanía": "la-ní-a",
    "lanífera": "la-ní-fe-ra",
    "lanífero": "la-ní-fe-ro",
    "lanificación": "la-ni-fi-ca-ción",
    "lanificio": "la-ni-fi-cio",
    "lanilla": "la-ni-lla",
    "lanío": "la-ní-o",
    "lanolina": "la-no-li-na",
    "lanosa": "la-no-sa",
    "lanosidad": "la-no-si-dad",
    "lanoso": "la-no-so",
    "lansquenete": "lans-que-ne-te",
    "lantaca": "lan-ta-ca",
    "lantánido": "lan-tá-ni-do",
    "lantano": "lan-ta-no",
    "lanteja": "lan-te-ja",
    "lantejuela": "lan-te-jue-la",
    "lantén": "lan-tén",
    "lanterna": "lan-ter-na",
    "lanterno": "lan-ter-no",
    "lantisco": "lan-tis-co",
    "lanuda": "la-nu-da",
    "lanudo": "la-nu-do",
    "lanuginosa": "la-nu-gi-no-sa",
    "lanuginoso": "la-nu-gi-no-so",
    "lanugo": "la-nu-go",
    "lanuza": "la-nu-za",
    "lanza": "lan-za",
    "lanzacabos": "lan-za-ca-bos",
    "lanzacargas": "lan-za-car-gas",
    "lanzacohetes": "lan-za-co-he-tes",
    "lanzada": "lan-za-da",
    "lanzadera": "lan-za-de-ra",
    "lanzado": "lan-za-do",
    "lanzador": "lan-za-dor",
    "lanzadora": "lan-za-do-ra",
    "lanzafuego": "lan-za-fue-go",
    "lanzagranadas": "lan-za-gra-na-das",
    "lanzagua": "lan-za-gua",
    "lanzallamas": "lan-za-lla-mas",
    "lanzamiento": "lan-za-mien-to",
    "lanzamisiles": "lan-za-mi-si-les",
    "lanzaplatos": "lan-za-pla-tos",
    "lanzar": "lan-zar",
    "lanzaroteña": "lan-za-ro-te-ña",
    "lanzaroteño": "lan-za-ro-te-ño",
    "lanzatorpedos": "lan-za-tor-pe-dos",
    "lanzazo": "lan-za-zo",
    "lanzón": "lan-zón",
    "lanzuela": "lan-zue-la",
    "laocia": "la-o-cia",
    "laocio": "la-o-cio",
    "laodicense": "la-o-di-cen-se",
    "laosiana": "la-o-sia-na",
    "laosiano": "la-o-sia-no",
    "lapa": "la-pa",
    "lapacha": "la-pa-cha",
    "lapachar": "la-pa-char",
    "lapachero": "la-pa-che-ro",
    "lapacho": "la-pa-cho",
    "lapalapa": "la-pa-la-pa",
    "laparoscopia": "la-pa-ros-co-pia",
    "laparoscopio": "la-pa-ros-co-pio",
    "laparotomía": "la-pa-ro-to-mí-a",
    "lape": "la-pe",
    "lapiaz": "la-piaz",
    "lapicera": "la-pi-ce-ra",
    "lapicero": "la-pi-ce-ro",
    "lápida": "lá-pi-da",
    "lapidación": "la-pi-da-ción",
    "lapidar": "la-pi-dar",
    "lapidaria": "la-pi-da-ria",
    "lapidario": "la-pi-da-rio",
    "lapídea": "la-pí-de-a",
    "lapídeo": "la-pí-de-o",
    "lapidífica": "la-pi-dí-fi-ca",
    "lapidificación": "la-pi-di-fi-ca-ción",
    "lapidificar": "la-pi-di-fi-car",
    "lapidífico": "la-pi-dí-fi-co",
    "lapidosa": "la-pi-do-sa",
    "lapidoso": "la-pi-do-so",
    "lapilla": "la-pi-lla",
    "lapilli": "la-pi-lli",
    "lapislázuli": "la-pis-lá-zu-li",
    "lapita": "la-pi-ta",
    "lápiz": "lá-piz",
    "lapizar": "la-pi-zar",
    "lapo": "la-po",
    "lapón": "la-pón",
    "lapona": "la-po-na",
    "lapsa": "lap-sa",
    "lapso": "lap-so",
    "lapsus": "lap-sus",
    "laque": "la-que",
    "laqueada": "la-que-a-da",
    "laqueado": "la-que-a-do",
    "laquear": "la-que-ar",
    "laquista": "la-quis-ta",
    "larario": "la-ra-rio",
    "larda": "lar-da",
    "lardáceo": "lar-dá-ce-o",
    "lardar": "lar-dar",
    "lardear": "lar-de-ar",
    "lardera": "lar-de-ra",
    "lardero": "lar-de-ro",
    "lardo": "lar-do",
    "lardón": "lar-dón",
    "lardosa": "lar-do-sa",
    "lardoso": "lar-do-so",
    "lareña": "la-re-ña",
    "lareño": "la-re-ño",
    "larense": "la-ren-se",
    "larga": "lar-ga",
    "largada": "lar-ga-da",
    "largado": "lar-ga-do",
    "largamente": "lar-ga-men-te",
    "largar": "lar-gar",
    "largaria": "lar-ga-ria",
    "largavista": "lar-ga-vis-ta",
    "largición": "lar-gi-ción",
    "largo": "lar-go",
    "largometraje": "lar-go-me-tra-je",
    "largomira": "lar-go-mi-ra",
    "largona": "lar-go-na",
    "largor": "lar-gor",
    "largueada": "lar-gue-a-da",
    "largueado": "lar-gue-a-do",
    "larguera": "lar-gue-ra",
    "larguero": "lar-gue-ro",
    "largueza": "lar-gue-za",
    "larguicha": "lar-gui-cha",
    "larguicho": "lar-gui-cho",
    "larguirucha": "lar-gui-ru-cha",
    "larguirucho": "lar-gui-ru-cho",
    "larguncha": "lar-gun-cha",
    "larguncho": "lar-gun-cho",
    "largura": "lar-gu-ra",
    "largurucha": "lar-gu-ru-cha",
    "largurucho": "lar-gu-ru-cho",
    "lárice": "lá-ri-ce",
    "laricina": "la-ri-ci-na",
    "laricino": "la-ri-ci-no",
    "lariforme": "la-ri-for-me",
    "larije": "la-ri-je",
    "laringal": "la-rin-gal",
    "laringe": "la-rin-ge",
    "laríngea": "la-rín-ge-a",
    "laríngeo": "la-rín-ge-o",
    "laringitis": "la-rin-gi-tis",
    "laringófono": "la-rin-gó-fo-no",
    "laringóloga": "la-rin-gó-lo-ga",
    "laringología": "la-rin-go-lo-gí-a",
    "laringológico": "la-rin-go-ló-gi-co",
    "laringólogo": "la-rin-gó-lo-go",
    "laringoscopia": "la-rin-gos-co-pia",
    "laringoscopio": "la-rin-gos-co-pio",
    "laringotomía": "la-rin-go-to-mí-a",
    "larra": "la-rra",
    "larva": "lar-va",
    "larvada": "lar-va-da",
    "larvado": "lar-va-do",
    "larval": "lar-val",
    "larvario": "lar-va-rio",
    "larvicida": "lar-vi-ci-da",
    "lasa": "la-sa",
    "lasaña": "la-sa-ña",
    "lasar": "la-sar",
    "lasarse": "la-sar-se",
    "lasca": "las-ca",
    "lascar": "las-car",
    "lasciva": "las-ci-va",
    "lascivamente": "las-ci-va-men-te",
    "lascivia": "las-ci-via",
    "lascivo": "las-ci-vo",
    "láser": "lá-ser",
    "laserpicio": "la-ser-pi-cio",
    "laserterapia": "la-ser-te-ra-pia",
    "lasitud": "la-si-tud",
    "laso": "la-so",
    "lastar": "las-tar",
    "lástima": "lás-ti-ma",
    "lastimada": "las-ti-ma-da",
    "lastimado": "las-ti-ma-do",
    "lastimador": "las-ti-ma-dor",
    "lastimadora": "las-ti-ma-do-ra",
    "lastimadura": "las-ti-ma-du-ra",
    "lastimar": "las-ti-mar",
    "lastimeramente": "las-ti-me-ra-men-te",
    "lastimero": "las-ti-me-ro",
    "lastimosa": "las-ti-mo-sa",
    "lastimosamente": "las-ti-mo-sa-men-te",
    "lastimoso": "las-ti-mo-so",
    "lasto": "las-to",
    "lastón": "las-tón",
    "lastra": "las-tra",
    "lastrar": "las-trar",
    "lastre": "las-tre",
    "lastrear": "las-tre-ar",
    "lasún": "la-sún",
    "lata": "la-ta",
    "latacungueña": "la-ta-cun-gue-ña",
    "latacungueño": "la-ta-cun-gue-ño",
    "latamente": "la-ta-men-te",
    "latania": "la-ta-nia",
    "latastro": "la-tas-tro",
    "lataz": "la-taz",
    "latazo": "la-ta-zo",
    "lateada": "la-te-a-da",
    "lateado": "la-te-a-do",
    "latear": "la-te-ar",
    "latebra": "la-te-bra",
    "latebrosa": "la-te-bro-sa",
    "latebroso": "la-te-bro-so",
    "latencia": "la-ten-cia",
    "latente": "la-ten-te",
    "latera": "la-te-ra",
    "lateral": "la-te-ral",
    "lateralidad": "la-te-ra-li-dad",
    "lateralización": "la-te-ra-li-za-ción",
    "lateralizar": "la-te-ra-li-zar",
    "lateralmente": "la-te-ral-men-te",
    "lateranense": "la-te-ra-nen-se",
    "latería": "la-te-rí-a",
    "laterío": "la-te-rí-o",
    "latero": "la-te-ro",
    "látex": "lá-tex",
    "laticífero": "la-ti-cí-fe-ro",
    "latido": "la-ti-do",
    "latifundio": "la-ti-fun-dio",
    "latifundismo": "la-ti-fun-dis-mo",
    "latifundista": "la-ti-fun-dis-ta",
    "latigadera": "la-ti-ga-de-ra",
    "latigazo": "la-ti-ga-zo",
    "látigo": "lá-ti-go",
    "latiguda": "la-ti-gu-da",
    "latigudo": "la-ti-gu-do",
    "latiguear": "la-ti-gue-ar",
    "latigueo": "la-ti-gue-o",
    "latiguera": "la-ti-gue-ra",
    "latiguero": "la-ti-gue-ro",
    "latiguillo": "la-ti-gui-llo",
    "latín": "la-tín",
    "latina": "la-ti-na",
    "latinado": "la-ti-na-do",
    "latinajo": "la-ti-na-jo",
    "latinamente": "la-ti-na-men-te",
    "latinar": "la-ti-nar",
    "latinazgo": "la-ti-naz-go",
    "latinear": "la-ti-ne-ar",
    "latinidad": "la-ti-ni-dad",
    "latiniparla": "la-ti-ni-par-la",
    "latinismo": "la-ti-nis-mo",
    "latinista": "la-ti-nis-ta",
    "latinización": "la-ti-ni-za-ción",
    "latinizador": "la-ti-ni-za-dor",
    "latinizadora": "la-ti-ni-za-do-ra",
    "latinizante": "la-ti-ni-zan-te",
    "latinizar": "la-ti-ni-zar",
    "latino": "la-ti-no",
    "latinoamericana": "la-ti-no-a-me-ri-ca-na",
    "latinoamericano": "la-ti-no-a-me-ri-ca-no",
    "latir": "la-tir",
    "latirismo": "la-ti-ris-mo",
    "latísimamente": "la-tí-si-ma-men-te",
    "latisueldo": "la-ti-suel-do",
    "latitar": "la-ti-tar",
    "latitud": "la-ti-tud",
    "latitudinal": "la-ti-tu-di-nal",
    "latitudinaria": "la-ti-tu-di-na-ria",
    "latitudinario": "la-ti-tu-di-na-rio",
    "latitudinarismo": "la-ti-tu-di-na-ris-mo",
    "lativo": "la-ti-vo",
    "lato": "la-to",
    "latón": "la-tón",
    "latonera": "la-to-ne-ra",
    "latonería": "la-to-ne-rí-a",
    "latonero": "la-to-ne-ro",
    "latosa": "la-to-sa",
    "latoso": "la-to-so",
    "latréutica": "la-tréu-ti-ca",
    "latréutico": "la-tréu-ti-co",
    "latría": "la-trí-a",
    "latrina": "la-tri-na",
    "latrocinar": "la-tro-ci-nar",
    "latrocinio": "la-tro-ci-nio",
    "latvia": "lat-via",
    "latvio": "lat-vio",
    "lauca": "lau-ca",
    "laucha": "lau-cha",
    "lauchear": "lau-che-ar",
    "lauchera": "lau-che-ra",
    "lauchero": "lau-che-ro",
    "laúd": "la-úd",
    "lauda": "lau-da",
    "laudable": "lau-da-ble",
    "laudablemente": "lau-da-ble-men-te",
    "láudano": "láu-da-no",
    "laudar": "lau-dar",
    "laudativamente": "lau-da-ti-va-men-te",
    "laudatoria": "lau-da-to-ria",
    "laudatorio": "lau-da-to-rio",
    "laude": "lau-de",
    "laudemio": "lau-de-mio",
    "laudes": "lau-des",
    "laudista": "lau-dis-ta",
    "laudo": "lau-do",
    "launa": "lau-na",
    "laurácea": "lau-rá-ce-a",
    "lauráceas": "lau-rá-ce-as",
    "lauráceo": "lau-rá-ce-o",
    "láurea": "láu-re-a",
    "laureada": "lau-re-a-da",
    "laureado": "lau-re-a-do",
    "laureando": "lau-re-an-do",
    "laurear": "lau-re-ar",
    "lauredal": "lau-re-dal",
    "laurel": "lau-rel",
    "laurencio": "lau-ren-cio",
    "laurente": "lau-ren-te",
    "láureo": "láu-re-o",
    "laureola": "lau-re-o-la",
    "lauréola": "lau-ré-o-la",
    "lauretana": "lau-re-ta-na",
    "lauretano": "lau-re-ta-no",
    "laurífera": "lau-rí-fe-ra",
    "laurífero": "lau-rí-fe-ro",
    "laurina": "lau-ri-na",
    "laurínea": "lau-rí-ne-a",
    "lauríneo": "lau-rí-ne-o",
    "laurino": "lau-ri-no",
    "laurisilva": "lau-ri-sil-va",
    "lauro": "lau-ro",
    "lauroceraso": "lau-ro-ce-ra-so",
    "lause": "lau-se",
    "lauta": "lau-ta",
    "lautamente": "lau-ta-men-te",
    "lauto": "lau-to",
    "lava": "la-va",
    "lavable": "la-va-ble",
    "lavabo": "la-va-bo",
    "lavacara": "la-va-ca-ra",
    "lavacaras": "la-va-ca-ras",
    "lavación": "la-va-ción",
    "lavacoches": "la-va-co-ches",
    "lavacro": "la-va-cro",
    "lavada": "la-va-da",
    "lavadedos": "la-va-de-dos",
    "lavadero": "la-va-de-ro",
    "lavadientes": "la-va-dien-tes",
    "lavado": "la-va-do",
    "lavador": "la-va-dor",
    "lavadora": "la-va-do-ra",
    "lavadura": "la-va-du-ra",
    "lavafrutas": "la-va-fru-tas",
    "lavagallos": "la-va-ga-llos",
    "lavahuesos": "la-va-hue-sos",
    "lavaje": "la-va-je",
    "lavajo": "la-va-jo",
    "lavaloza": "la-va-lo-za",
    "lavalozas": "la-va-lo-zas",
    "lavamanos": "la-va-ma-nos",
    "lavamiento": "la-va-mien-to",
    "lavanco": "la-van-co",
    "lavanda": "la-van-da",
    "lavandera": "la-van-de-ra",
    "lavandería": "la-van-de-rí-a",
    "lavandero": "la-van-de-ro",
    "lavandina": "la-van-di-na",
    "lavándula": "la-ván-du-la",
    "lavaojos": "la-va-o-jos",
    "lavaplatos": "la-va-pla-tos",
    "lavar": "la-var",
    "lavarropa": "la-va-rro-pa",
    "lavarropas": "la-va-rro-pas",
    "lavaseco": "la-va-se-co",
    "lavativa": "la-va-ti-va",
    "lavativo": "la-va-ti-vo",
    "lavatorio": "la-va-to-rio",
    "lavatrastos": "la-va-tras-tos",
    "lavavajilla": "la-va-va-ji-lla",
    "lavavajillas": "la-va-va-ji-llas",
    "lavazas": "la-va-zas",
    "lave": "la-ve",
    "lavija": "la-vi-ja",
    "lavotear": "la-vo-te-ar",
    "lavoteo": "la-vo-te-o",
    "lawrencio": "law-ren-cio",
    "laxa": "la-xa",
    "laxación": "la-xa-ción",
    "laxamiento": "la-xa-mien-to",
    "laxante": "la-xan-te",
    "laxar": "la-xar",
    "laxativa": "la-xa-ti-va",
    "laxativo": "la-xa-ti-vo",
    "laxidad": "la-xi-dad",
    "laxismo": "la-xis-mo",
    "laxista": "la-xis-ta",
    "laxitud": "la-xi-tud",
    "laxo": "la-xo",
    "laya": "la-ya",
    "layador": "la-ya-dor",
    "layadora": "la-ya-do-ra",
    "layar": "la-yar",
    "layetana": "la-ye-ta-na",
    "layetano": "la-ye-ta-no",
    "lazada": "la-za-da",
    "lazar": "la-zar",
    "lazareto": "la-za-re-to",
    "lazarillo": "la-za-ri-llo",
    "lazarina": "la-za-ri-na",
    "lazarino": "la-za-ri-no",
    "lazarista": "la-za-ris-ta",
    "lázaro": "lá-za-ro",
    "lazarosa": "la-za-ro-sa",
    "lazaroso": "la-za-ro-so",
    "lazdrar": "laz-drar",
    "lazo": "la-zo",
    "lazradamente": "laz-ra-da-men-te",
    "lazrador": "laz-ra-dor",
    "lazrar": "laz-rar",
    "lazulita": "la-zu-li-ta",
    "leal": "le-al",
    "lealdad": "le-al-dad",
    "lealmente": "le-al-men-te",
    "lealtad": "le-al-tad",
    "leandra": "le-an-dra",
    "lebaniega": "le-ba-nie-ga",
    "lebaniego": "le-ba-nie-go",
    "lebeche": "le-be-che",
    "lebení": "le-be-ní",
    "leberquisa": "le-ber-qui-sa",
    "lebisa": "le-bi-sa",
    "lebrada": "le-bra-da",
    "lebrancho": "le-bran-cho",
    "lebrasta": "le-bras-ta",
    "lebrastón": "le-bras-tón",
    "lebrato": "le-bra-to",
    "lebratón": "le-bra-tón",
    "lebrel": "le-brel",
    "lebrela": "le-bre-la",
    "lebrera": "le-bre-ra",
    "lebrero": "le-bre-ro",
    "lebrijana": "le-bri-ja-na",
    "lebrijano": "le-bri-ja-no",
    "lebrillo": "le-bri-llo",
    "lebrón": "le-brón",
    "lebrona": "le-bro-na",
    "lebroncillo": "le-bron-ci-llo",
    "lebruna": "le-bru-na",
    "lebruno": "le-bru-no",
    "lebulensa": "le-bu-len-sa",
    "lebulense": "le-bu-len-se",
    "lecanomancía": "le-ca-no-man-cí-a",
    "lecanomancia": "le-ca-no-man-cia",
    "lección": "lec-ción",
    "leccionario": "lec-cio-na-rio",
    "leccionista": "lec-cio-nis-ta",
    "lecha": "le-cha",
    "lechada": "le-cha-da",
    "lechal": "le-chal",
    "lechar": "le-char",
    "lechaza": "le-cha-za",
    "lechazo": "le-cha-zo",
    "leche": "le-che",
    "lechecillas": "le-che-ci-llas",
    "lechera": "le-che-ra",
    "lechería": "le-che-rí-a",
    "lecherina": "le-che-ri-na",
    "lechero": "le-che-ro",
    "lecherón": "le-che-rón",
    "lechetrezna": "le-che-trez-na",
    "lechiga": "le-chi-ga",
    "lechigada": "le-chi-ga-da",
    "lechigado": "le-chi-ga-do",
    "lechiguana": "le-chi-gua-na",
    "lechín": "le-chín",
    "lechina": "le-chi-na",
    "lechino": "le-chi-no",
    "lecho": "le-cho",
    "lechón": "le-chón",
    "lechona": "le-cho-na",
    "lechosa": "le-cho-sa",
    "lechoso": "le-cho-so",
    "lechucear": "le-chu-ce-ar",
    "lechucera": "le-chu-ce-ra",
    "lechucero": "le-chu-ce-ro",
    "lechuda": "le-chu-da",
    "lechudo": "le-chu-do",
    "lechuga": "le-chu-ga",
    "lechugada": "le-chu-ga-da",
    "lechugado": "le-chu-ga-do",
    "lechugín": "le-chu-gín",
    "lechuguera": "le-chu-gue-ra",
    "lechuguero": "le-chu-gue-ro",
    "lechuguilla": "le-chu-gui-lla",
    "lechuguina": "le-chu-gui-na",
    "lechuguino": "le-chu-gui-no",
    "lechuza": "le-chu-za",
    "lechuzo": "le-chu-zo",
    "lecitina": "le-ci-ti-na",
    "leco": "le-co",
    "lectisternio": "lec-tis-ter-nio",
    "lectiva": "lec-ti-va",
    "lectivo": "lec-ti-vo",
    "lectoescritura": "lec-to-es-cri-tu-ra",
    "lector": "lec-tor",
    "lectora": "lec-to-ra",
    "lectorado": "lec-to-ra-do",
    "lectoral": "lec-to-ral",
    "lectoralía": "lec-to-ra-lí-a",
    "lectoría": "lec-to-rí-a",
    "lectuario": "lec-tua-rio",
    "lectura": "lec-tu-ra",
    "leda": "le-da",
    "ledamente": "le-da-men-te",
    "ledanía": "le-da-ní-a",
    "ledo": "le-do",
    "ledón": "le-dón",
    "leedor": "le-e-dor",
    "leedora": "le-e-do-ra",
    "leer": "le-er",
    "lega": "le-ga",
    "legacía": "le-ga-cí-a",
    "legación": "le-ga-ción",
    "legado": "le-ga-do",
    "legador": "le-ga-dor",
    "legadura": "le-ga-du-ra",
    "legajo": "le-ga-jo",
    "legal": "le-gal",
    "legalidad": "le-ga-li-dad",
    "legalismo": "le-ga-lis-mo",
    "legalista": "le-ga-lis-ta",
    "legalizable": "le-ga-li-za-ble",
    "legalización": "le-ga-li-za-ción",
    "legalizar": "le-ga-li-zar",
    "legalmente": "le-gal-men-te",
    "legamente": "le-ga-men-te",
    "légamo": "lé-ga-mo",
    "legamosa": "le-ga-mo-sa",
    "legamoso": "le-ga-mo-so",
    "legaña": "le-ga-ña",
    "leganal": "le-ga-nal",
    "legañil": "le-ga-ñil",
    "légano": "lé-ga-no",
    "legañosa": "le-ga-ño-sa",
    "leganoso": "le-ga-no-so",
    "legañoso": "le-ga-ño-so",
    "legar": "le-gar",
    "legataria": "le-ga-ta-ria",
    "legatario": "le-ga-ta-rio",
    "legato": "le-ga-to",
    "legenda": "le-gen-da",
    "legendaria": "le-gen-da-ria",
    "legendario": "le-gen-da-rio",
    "legging": "leg-ging",
    "legibilidad": "le-gi-bi-li-dad",
    "legible": "le-gi-ble",
    "legión": "le-gión",
    "legionaria": "le-gio-na-ria",
    "legionario": "le-gio-na-rio",
    "legionela": "le-gio-ne-la",
    "legionella": "le-gio-ne-lla",
    "legionelosis": "le-gio-ne-lo-sis",
    "legionense": "le-gio-nen-se",
    "legislable": "le-gis-la-ble",
    "legislación": "le-gis-la-ción",
    "legislador": "le-gis-la-dor",
    "legisladora": "le-gis-la-do-ra",
    "legislar": "le-gis-lar",
    "legislativa": "le-gis-la-ti-va",
    "legislativo": "le-gis-la-ti-vo",
    "legislatura": "le-gis-la-tu-ra",
    "legisperito": "le-gis-pe-ri-to",
    "legista": "le-gis-ta",
    "legítima": "le-gí-ti-ma",
    "legitimación": "le-gi-ti-ma-ción",
    "legitimado": "le-gi-ti-ma-do",
    "legitimador": "le-gi-ti-ma-dor",
    "legitimadora": "le-gi-ti-ma-do-ra",
    "legítimamente": "le-gí-ti-ma-men-te",
    "legitimar": "le-gi-ti-mar",
    "legitimaria": "le-gi-ti-ma-ria",
    "legitimario": "le-gi-ti-ma-rio",
    "legitimidad": "le-gi-ti-mi-dad",
    "legitimismo": "le-gi-ti-mis-mo",
    "legitimista": "le-gi-ti-mis-ta",
    "legítimo": "le-gí-ti-mo",
    "lego": "le-go",
    "legón": "le-gón",
    "legra": "le-gra",
    "legrado": "le-gra-do",
    "legradura": "le-gra-du-ra",
    "legrar": "le-grar",
    "légrimo": "lé-gri-mo",
    "legrón": "le-grón",
    "legua": "le-gua",
    "leguaria": "le-gua-ria",
    "leguario": "le-gua-rio",
    "legui": "le-gui",
    "leguleya": "le-gu-le-ya",
    "leguleyo": "le-gu-le-yo",
    "legumbre": "le-gum-bre",
    "legúmina": "le-gú-mi-na",
    "leguminosa": "le-gu-mi-no-sa",
    "leguminosas": "le-gu-mi-no-sas",
    "leguminoso": "le-gu-mi-no-so",
    "lehendakari": "le-hen-da-ka-ri",
    "leíble": "le-í-ble",
    "leída": "le-í-da",
    "leiden": "lei-den",
    "leído": "le-í-do",
    "leila": "lei-la",
    "leima": "lei-ma",
    "leísmo": "le-ís-mo",
    "leísta": "le-ís-ta",
    "leixaprén": "lei-xa-prén",
    "leja": "le-ja",
    "lejana": "le-ja-na",
    "lejanamente": "le-ja-na-men-te",
    "lejanía": "le-ja-ní-a",
    "lejano": "le-ja-no",
    "lejas": "le-jas",
    "lejazo": "le-ja-zo",
    "lejecitos": "le-je-ci-tos",
    "lejía": "le-jí-a",
    "lejío": "le-jí-o",
    "lejísimo": "le-jí-si-mo",
    "lejísimos": "le-jí-si-mos",
    "lejitos": "le-ji-tos",
    "lejos": "le-jos",
    "lejote": "le-jo-te",
    "lejura": "le-ju-ra",
    "lela": "le-la",
    "lele": "le-le",
    "lelera": "le-le-ra",
    "lelilí": "le-li-lí",
    "lelo": "le-lo",
    "lema": "le-ma",
    "lemán": "le-mán",
    "lemanaje": "le-ma-na-je",
    "lemanita": "le-ma-ni-ta",
    "lemario": "le-ma-rio",
    "lematización": "le-ma-ti-za-ción",
    "lematizar": "le-ma-ti-zar",
    "lembario": "lem-ba-rio",
    "lembo": "lem-bo",
    "lembrar": "lem-brar",
    "leme": "le-me",
    "lemming": "lem-ming",
    "lemnácea": "lem-ná-ce-a",
    "lemnáceas": "lem-ná-ce-as",
    "lemnáceo": "lem-ná-ce-o",
    "lemnia": "lem-nia",
    "lemnícola": "lem-ní-co-la",
    "lemnio": "lem-nio",
    "lemniscata": "lem-nis-ca-ta",
    "lemnisco": "lem-nis-co",
    "lemosín": "le-mo-sín",
    "lemosina": "le-mo-si-na",
    "lempira": "lem-pi-ra",
    "lempireño": "lem-pi-re-ño",
    "lempirense": "lem-pi-ren-se",
    "lempo": "lem-po",
    "lémur": "lé-mur",
    "lemurias": "le-mu-rias",
    "lena": "le-na",
    "leña": "le-ña",
    "leñador": "le-ña-dor",
    "leñadora": "le-ña-do-ra",
    "leñame": "le-ña-me",
    "leñar": "le-ñar",
    "leñatear": "le-ña-te-ar",
    "leñatera": "le-ña-te-ra",
    "leñatero": "le-ña-te-ro",
    "leñazo": "le-ña-zo",
    "lenca": "len-ca",
    "lencera": "len-ce-ra",
    "lencería": "len-ce-rí-a",
    "lencero": "len-ce-ro",
    "lenco": "len-co",
    "lendakari": "len-da-ka-ri",
    "lendel": "len-del",
    "lendrera": "len-dre-ra",
    "lendrero": "len-dre-ro",
    "lendrosa": "len-dro-sa",
    "lendroso": "len-dro-so",
    "lene": "le-ne",
    "leñe": "le-ñe",
    "leneas": "le-ne-as",
    "leñera": "le-ñe-ra",
    "leñero": "le-ñe-ro",
    "lengón": "len-gón",
    "lengona": "len-go-na",
    "lengua": "len-gua",
    "lenguadeta": "len-gua-de-ta",
    "lenguado": "len-gua-do",
    "lenguaje": "len-gua-je",
    "lenguarada": "len-gua-ra-da",
    "lenguaraz": "len-gua-raz",
    "lenguatón": "len-gua-tón",
    "lenguatona": "len-gua-to-na",
    "lenguaz": "len-guaz",
    "lenguaza": "len-gua-za",
    "lenguda": "len-gu-da",
    "lengudo": "len-gu-do",
    "lengüear": "len-güe-ar",
    "lengüeta": "len-güe-ta",
    "lengüetada": "len-güe-ta-da",
    "lengüetazo": "len-güe-ta-zo",
    "lengüeteada": "len-güe-te-a-da",
    "lengüetear": "len-güe-te-ar",
    "lengüetera": "len-güe-te-ra",
    "lengüetería": "len-güe-te-rí-a",
    "lengüetero": "len-güe-te-ro",
    "lengüicorta": "len-güi-cor-ta",
    "lengüicorto": "len-güi-cor-to",
    "lengüilarga": "len-güi-lar-ga",
    "lengüilargo": "len-güi-lar-go",
    "lenguón": "len-guón",
    "lenguona": "len-guo-na",
    "lenidad": "le-ni-dad",
    "lenificación": "le-ni-fi-ca-ción",
    "lenificar": "le-ni-fi-car",
    "lenificativa": "le-ni-fi-ca-ti-va",
    "lenificativo": "le-ni-fi-ca-ti-vo",
    "leninismo": "le-ni-nis-mo",
    "leninista": "le-ni-nis-ta",
    "lenitiva": "le-ni-ti-va",
    "lenitivo": "le-ni-ti-vo",
    "lenizar": "le-ni-zar",
    "leño": "le-ño",
    "lenocinio": "le-no-ci-nio",
    "lenón": "le-nón",
    "leñosa": "le-ño-sa",
    "leñoso": "le-ño-so",
    "lenta": "len-ta",
    "lentamente": "len-ta-men-te",
    "lente": "len-te",
    "lentecer": "len-te-cer",
    "lenteja": "len-te-ja",
    "lentejar": "len-te-jar",
    "lentejuela": "len-te-jue-la",
    "lentejuelar": "len-te-jue-lar",
    "lenteza": "len-te-za",
    "lenticular": "len-ti-cu-lar",
    "lentificación": "len-ti-fi-ca-ción",
    "lentificar": "len-ti-fi-car",
    "lentigo": "len-ti-go",
    "lentilla": "len-ti-lla",
    "lentiscal": "len-tis-cal",
    "lentiscina": "len-tis-ci-na",
    "lentisco": "len-tis-co",
    "lentitud": "len-ti-tud",
    "lento": "len-to",
    "lentor": "len-tor",
    "lentura": "len-tu-ra",
    "lenzal": "len-zal",
    "lenzuelo": "len-zue-lo",
    "leo": "le-o",
    "león": "le-ón",
    "leona": "le-o-na",
    "leonada": "le-o-na-da",
    "leonado": "le-o-na-do",
    "leonera": "le-o-ne-ra",
    "leonería": "le-o-ne-rí-a",
    "leonero": "le-o-ne-ro",
    "leonés": "le-o-nés",
    "leonesa": "le-o-ne-sa",
    "leonesismo": "le-o-ne-sis-mo",
    "leónica": "le-ó-ni-ca",
    "leonina": "le-o-ni-na",
    "leonino": "le-o-ni-no",
    "leontina": "le-on-ti-na",
    "leopardo": "le-o-par-do",
    "leopoldina": "le-o-pol-di-na",
    "leotardo": "le-o-tar-do",
    "lepasil": "le-pa-sil",
    "lepe": "le-pe",
    "lépera": "lé-pe-ra",
    "leperada": "le-pe-ra-da",
    "lépero": "lé-pe-ro",
    "leperuza": "le-pe-ru-za",
    "lepidio": "le-pi-dio",
    "lepidóptero": "le-pi-dóp-te-ro",
    "lepiota": "le-pio-ta",
    "lepisma": "le-pis-ma",
    "lepórido": "le-pó-ri-do",
    "leporina": "le-po-ri-na",
    "leporino": "le-po-ri-no",
    "lepra": "le-pra",
    "leprocomio": "le-pro-co-mio",
    "leprosa": "le-pro-sa",
    "leprosario": "le-pro-sa-rio",
    "leprosera": "le-pro-se-ra",
    "leprosería": "le-pro-se-rí-a",
    "leprosero": "le-pro-se-ro",
    "leproso": "le-pro-so",
    "leprosorio": "le-pro-so-rio",
    "leptón": "lep-tón",
    "leptorrina": "lep-to-rri-na",
    "leptorrino": "lep-to-rri-no",
    "lera": "le-ra",
    "lercha": "ler-cha",
    "lerda": "ler-da",
    "lerdamente": "ler-da-men-te",
    "lerdear": "ler-de-ar",
    "lerdera": "ler-de-ra",
    "lerdez": "ler-dez",
    "lerdo": "ler-do",
    "lerdón": "ler-dón",
    "lerense": "le-ren-se",
    "leridana": "le-ri-da-na",
    "leridano": "le-ri-da-no",
    "lernea": "ler-ne-a",
    "lerneo": "ler-ne-o",
    "lero": "le-ro",
    "lesa": "le-sa",
    "lesbia": "les-bia",
    "lesbiana": "les-bia-na",
    "lesbianismo": "les-bia-nis-mo",
    "lesbiano": "les-bia-no",
    "lésbico": "lés-bi-co",
    "lesbio": "les-bio",
    "lesear": "le-se-ar",
    "leseo": "le-se-o",
    "lesera": "le-se-ra",
    "lesión": "le-sión",
    "lesionado": "le-sio-na-do",
    "lesionador": "le-sio-na-dor",
    "lesionadora": "le-sio-na-do-ra",
    "lesionar": "le-sio-nar",
    "lesiva": "le-si-va",
    "lesivo": "le-si-vo",
    "lesna": "les-na",
    "lesnordeste": "les-nor-des-te",
    "leso": "le-so",
    "lesothense": "le-so-then-se",
    "lessueste": "les-sues-te",
    "leste": "les-te",
    "lestrigón": "les-tri-gón",
    "lesueste": "le-sues-te",
    "letal": "le-tal",
    "letalidad": "le-ta-li-dad",
    "letame": "le-ta-me",
    "letanía": "le-ta-ní-a",
    "letargia": "le-tar-gia",
    "letárgica": "le-tár-gi-ca",
    "letárgico": "le-tár-gi-co",
    "letargo": "le-tar-go",
    "letargosa": "le-tar-go-sa",
    "letargoso": "le-tar-go-so",
    "letea": "le-te-a",
    "leteo": "le-te-o",
    "leticia": "le-ti-cia",
    "leticiana": "le-ti-cia-na",
    "leticiano": "le-ti-cia-no",
    "letífica": "le-tí-fi-ca",
    "letificante": "le-ti-fi-can-te",
    "letificar": "le-ti-fi-car",
    "letífico": "le-tí-fi-co",
    "letigio": "le-ti-gio",
    "letijo": "le-ti-jo",
    "letón": "le-tón",
    "letona": "le-to-na",
    "letra": "le-tra",
    "letrada": "le-tra-da",
    "letrado": "le-tra-do",
    "letradura": "le-tra-du-ra",
    "letraduría": "le-tra-du-rí-a",
    "letraset": "le-tra-set",
    "letrear": "le-tre-ar",
    "letrera": "le-tre-ra",
    "letrero": "le-tre-ro",
    "letrilla": "le-tri-lla",
    "letrina": "le-tri-na",
    "letrista": "le-tris-ta",
    "letrones": "le-tro-nes",
    "letruda": "le-tru-da",
    "letrudo": "le-tru-do",
    "letuario": "le-tua-rio",
    "letura": "le-tu-ra",
    "leucemia": "leu-ce-mia",
    "leucémica": "leu-cé-mi-ca",
    "leucémico": "leu-cé-mi-co",
    "leucisco": "leu-cis-co",
    "leuco": "leu-co",
    "leucocito": "leu-co-ci-to",
    "leucocitosis": "leu-co-ci-to-sis",
    "leucofea": "leu-co-fe-a",
    "leucofeo": "leu-co-fe-o",
    "leucoma": "leu-co-ma",
    "leucopenia": "leu-co-pe-nia",
    "leucoplaquia": "leu-co-pla-quia",
    "leucoplasia": "leu-co-pla-sia",
    "leucorrea": "leu-co-rre-a",
    "leuda": "leu-da",
    "leudante": "leu-dan-te",
    "leudar": "leu-dar",
    "leude": "leu-de",
    "leudo": "leu-do",
    "leva": "le-va",
    "levada": "le-va-da",
    "levadera": "le-va-de-ra",
    "levadero": "le-va-de-ro",
    "levadiza": "le-va-di-za",
    "levadizo": "le-va-di-zo",
    "levador": "le-va-dor",
    "levadura": "le-va-du-ra",
    "levamiento": "le-va-mien-to",
    "levantada": "le-van-ta-da",
    "levantadamente": "le-van-ta-da-men-te",
    "levantado": "le-van-ta-do",
    "levantador": "le-van-ta-dor",
    "levantadora": "le-van-ta-do-ra",
    "levantamiento": "le-van-ta-mien-to",
    "levantar": "le-van-tar",
    "levantavidrios": "le-van-ta-vi-drios",
    "levante": "le-van-te",
    "levantina": "le-van-ti-na",
    "levantino": "le-van-ti-no",
    "levantisca": "le-van-tis-ca",
    "levantisco": "le-van-tis-co",
    "levar": "le-var",
    "leve": "le-ve",
    "levedad": "le-ve-dad",
    "levemente": "le-ve-men-te",
    "levente": "le-ven-te",
    "leviatán": "le-via-tán",
    "levidad": "le-vi-dad",
    "levigación": "le-vi-ga-ción",
    "levigar": "le-vi-gar",
    "levirato": "le-vi-ra-to",
    "levisa": "le-vi-sa",
    "levita": "le-vi-ta",
    "levitación": "le-vi-ta-ción",
    "levitar": "le-vi-tar",
    "levítica": "le-ví-ti-ca",
    "levítico": "le-ví-ti-co",
    "levitín": "le-vi-tín",
    "levitón": "le-vi-tón",
    "levógira": "le-vó-gi-ra",
    "levógiro": "le-vó-gi-ro",
    "levosa": "le-vo-sa",
    "levudo": "le-vu-do",
    "levulosa": "le-vu-lo-sa",
    "lexema": "le-xe-ma",
    "lexiarca": "le-xiar-ca",
    "léxica": "lé-xi-ca",
    "lexical": "le-xi-cal",
    "lexicalización": "le-xi-ca-li-za-ción",
    "lexicalizar": "le-xi-ca-li-zar",
    "léxico": "lé-xi-co",
    "lexicógrafa": "le-xi-có-gra-fa",
    "lexicografía": "le-xi-co-gra-fí-a",
    "lexicográfica": "le-xi-co-grá-fi-ca",
    "lexicográfico": "le-xi-co-grá-fi-co",
    "lexicógrafo": "le-xi-có-gra-fo",
    "lexicóloga": "le-xi-có-lo-ga",
    "lexicología": "le-xi-co-lo-gí-a",
    "lexicológica": "le-xi-co-ló-gi-ca",
    "lexicológico": "le-xi-co-ló-gi-co",
    "lexicólogo": "le-xi-có-lo-go",
    "lexicón": "le-xi-cón",
    "leyenda": "le-yen-da",
    "leyendaria": "le-yen-da-ria",
    "leyendario": "le-yen-da-rio",
    "lezda": "lez-da",
    "lezdero": "lez-de-ro",
    "lezna": "lez-na",
    "lezne": "lez-ne",
    "lía": "lí-a",
    "liado": "lia-do",
    "liana": "lia-na",
    "lianta": "lian-ta",
    "liante": "lian-te",
    "liara": "lia-ra",
    "liásica": "liá-si-ca",
    "liásico": "liá-si-co",
    "liatón": "lia-tón",
    "liaza": "lia-za",
    "libación": "li-ba-ción",
    "libamen": "li-ba-men",
    "libamiento": "li-ba-mien-to",
    "libán": "li-bán",
    "libanés": "li-ba-nés",
    "libanesa": "li-ba-ne-sa",
    "libar": "li-bar",
    "libatorio": "li-ba-to-rio",
    "libela": "li-be-la",
    "libelar": "li-be-lar",
    "libelática": "li-be-lá-ti-ca",
    "libelático": "li-be-lá-ti-co",
    "libelista": "li-be-lis-ta",
    "libelo": "li-be-lo",
    "libélula": "li-bé-lu-la",
    "líber": "lí-ber",
    "líbera": "lí-be-ra",
    "liberación": "li-be-ra-ción",
    "liberada": "li-be-ra-da",
    "liberado": "li-be-ra-do",
    "liberador": "li-be-ra-dor",
    "liberadora": "li-be-ra-do-ra",
    "liberal": "li-be-ral",
    "liberalidad": "li-be-ra-li-dad",
    "liberalismo": "li-be-ra-lis-mo",
    "liberalista": "li-be-ra-lis-ta",
    "liberalización": "li-be-ra-li-za-ción",
    "liberalizador": "li-be-ra-li-za-dor",
    "liberalizar": "li-be-ra-li-zar",
    "liberalmente": "li-be-ral-men-te",
    "líberamente": "lí-be-ra-men-te",
    "liberar": "li-be-rar",
    "liberatoria": "li-be-ra-to-ria",
    "liberatorio": "li-be-ra-to-rio",
    "liberiana": "li-be-ria-na",
    "liberiano": "li-be-ria-no",
    "líbero": "lí-be-ro",
    "libérrima": "li-bé-rri-ma",
    "libérrimo": "li-bé-rri-mo",
    "liberta": "li-ber-ta",
    "libertad": "li-ber-tad",
    "libertada": "li-ber-ta-da",
    "libertadamente": "li-ber-ta-da-men-te",
    "libertadense": "li-ber-ta-den-se",
    "libertado": "li-ber-ta-do",
    "libertador": "li-ber-ta-dor",
    "libertadora": "li-ber-ta-do-ra",
    "libertar": "li-ber-tar",
    "libertaria": "li-ber-ta-ria",
    "libertario": "li-ber-ta-rio",
    "libertarismo": "li-ber-ta-ris-mo",
    "liberteña": "li-ber-te-ña",
    "liberteño": "li-ber-te-ño",
    "liberticida": "li-ber-ti-ci-da",
    "libertina": "li-ber-ti-na",
    "libertinaje": "li-ber-ti-na-je",
    "libertino": "li-ber-ti-no",
    "liberto": "li-ber-to",
    "libia": "li-bia",
    "líbica": "lí-bi-ca",
    "líbico": "lí-bi-co",
    "libidinal": "li-bi-di-nal",
    "libídine": "li-bí-di-ne",
    "libidinosa": "li-bi-di-no-sa",
    "libidinosamente": "li-bi-di-no-sa-men-te",
    "libidinosidad": "li-bi-di-no-si-dad",
    "libidinoso": "li-bi-di-no-so",
    "libido": "li-bi-do",
    "libio": "li-bio",
    "libón": "li-bón",
    "libra": "li-bra",
    "libracho": "li-bra-cho",
    "libración": "li-bra-ción",
    "libraco": "li-bra-co",
    "librada": "li-bra-da",
    "librado": "li-bra-do",
    "librador": "li-bra-dor",
    "libradora": "li-bra-do-ra",
    "libramiento": "li-bra-mien-to",
    "librana": "li-bra-na",
    "librancista": "li-bran-cis-ta",
    "librano": "li-bra-no",
    "libranza": "li-bran-za",
    "librar": "li-brar",
    "libratorio": "li-bra-to-rio",
    "librazo": "li-bra-zo",
    "libre": "li-bre",
    "librea": "li-bre-a",
    "librear": "li-bre-ar",
    "librecambio": "li-bre-cam-bio",
    "librecambismo": "li-bre-cam-bis-mo",
    "librecambista": "li-bre-cam-bis-ta",
    "librejo": "li-bre-jo",
    "libremente": "li-bre-men-te",
    "librepensador": "li-bre-pen-sa-dor",
    "librepensadora": "li-bre-pen-sa-do-ra",
    "librepensamiento": "li-bre-pen-sa-mien-to",
    "librera": "li-bre-ra",
    "librería": "li-bre-rí-a",
    "libreril": "li-bre-ril",
    "librero": "li-bre-ro",
    "libresca": "li-bres-ca",
    "libresco": "li-bres-co",
    "libreta": "li-bre-ta",
    "libretazo": "li-bre-ta-zo",
    "librete": "li-bre-te",
    "libretear": "li-bre-te-ar",
    "libretera": "li-bre-te-ra",
    "libretero": "li-bre-te-ro",
    "libretista": "li-bre-tis-ta",
    "libreto": "li-bre-to",
    "libriano": "li-bria-no",
    "librillo": "li-bri-llo",
    "libro": "li-bro",
    "licantropía": "li-can-tro-pí-a",
    "licantrópico": "li-can-tró-pi-co",
    "licántropo": "li-cán-tro-po",
    "licaón": "li-ca-ón",
    "liceísta": "li-ce-ís-ta",
    "licencia": "li-cen-cia",
    "licenciada": "li-cen-cia-da",
    "licenciadillo": "li-cen-cia-di-llo",
    "licenciado": "li-cen-cia-do",
    "licenciador": "li-cen-cia-dor",
    "licenciadora": "li-cen-cia-do-ra",
    "licenciamiento": "li-cen-cia-mien-to",
    "licenciar": "li-cen-ciar",
    "licenciataria": "li-cen-cia-ta-ria",
    "licenciatario": "li-cen-cia-ta-rio",
    "licenciatura": "li-cen-cia-tu-ra",
    "licenciosa": "li-cen-cio-sa",
    "licenciosamente": "li-cen-cio-sa-men-te",
    "licencioso": "li-cen-cio-so",
    "liceo": "li-ce-o",
    "lichera": "li-che-ra",
    "lichi": "li-chi",
    "lichiguera": "li-chi-gue-ra",
    "lichiguero": "li-chi-gue-ro",
    "licia": "li-cia",
    "licio": "li-cio",
    "lícita": "lí-ci-ta",
    "licitación": "li-ci-ta-ción",
    "licitador": "li-ci-ta-dor",
    "licitadora": "li-ci-ta-do-ra",
    "lícitamente": "lí-ci-ta-men-te",
    "licitante": "li-ci-tan-te",
    "licitar": "li-ci-tar",
    "lícito": "lí-ci-to",
    "licitud": "li-ci-tud",
    "licnobia": "lic-no-bia",
    "licnobio": "lic-no-bio",
    "licopeno": "li-co-pe-no",
    "licopodínea": "li-co-po-dí-ne-a",
    "licopodíneo": "li-co-po-dí-ne-o",
    "licopodio": "li-co-po-dio",
    "licor": "li-cor",
    "licorera": "li-co-re-ra",
    "licorería": "li-co-re-rí-a",
    "licorero": "li-co-re-ro",
    "licorista": "li-co-ris-ta",
    "licorosa": "li-co-ro-sa",
    "licoroso": "li-co-ro-so",
    "licra": "li-cra",
    "lictor": "lic-tor",
    "licuable": "li-cua-ble",
    "licuación": "li-cua-ción",
    "licuado": "li-cua-do",
    "licuadora": "li-cua-do-ra",
    "licuar": "li-cuar",
    "licuecer": "li-cue-cer",
    "licuefacción": "li-cue-fac-ción",
    "licuefacer": "li-cue-fa-cer",
    "licuefactible": "li-cue-fac-ti-ble",
    "licuefactiva": "li-cue-fac-ti-va",
    "licuefactivo": "li-cue-fac-ti-vo",
    "licuor": "li-cuor",
    "licurga": "li-cur-ga",
    "licurgo": "li-cur-go",
    "líder": "lí-der",
    "liderar": "li-de-rar",
    "liderato": "li-de-ra-to",
    "liderazgo": "li-de-raz-go",
    "lideresa": "li-de-re-sa",
    "liderizar": "li-de-ri-zar",
    "lidia": "li-dia",
    "lidiadera": "li-dia-de-ra",
    "lidiadero": "li-dia-de-ro",
    "lidiador": "li-dia-dor",
    "lidiadora": "li-dia-do-ra",
    "lidiar": "li-diar",
    "lidio": "li-dio",
    "lidioso": "li-dio-so",
    "lidón": "li-dón",
    "lidonero": "li-do-ne-ro",
    "liebrastón": "lie-bras-tón",
    "liebratico": "lie-bra-ti-co",
    "liebratón": "lie-bra-tón",
    "liebre": "lie-bre",
    "liebrecilla": "lie-bre-ci-lla",
    "liechtensteiniana": "liech-tens-tei-nia-na",
    "liechtensteiniano": "liech-tens-tei-nia-no",
    "liega": "lie-ga",
    "liego": "lie-go",
    "liencillo": "lien-ci-llo",
    "liendra": "lien-dra",
    "liendre": "lien-dre",
    "lienta": "lien-ta",
    "lientera": "lien-te-ra",
    "lientería": "lien-te-rí-a",
    "lientérica": "lien-té-ri-ca",
    "lientérico": "lien-té-ri-co",
    "liento": "lien-to",
    "lienza": "lien-za",
    "lienzo": "lien-zo",
    "liera": "lie-ra",
    "liero": "lie-ro",
    "lieva": "lie-va",
    "lievar": "lie-var",
    "lieve": "lie-ve",
    "lifara": "li-fa-ra",
    "liftado": "lif-ta-do",
    "liftar": "lif-tar",
    "lifting": "lif-ting",
    "liga": "li-ga",
    "ligación": "li-ga-ción",
    "ligada": "li-ga-da",
    "ligado": "li-ga-do",
    "ligador": "li-ga-dor",
    "ligadura": "li-ga-du-ra",
    "ligagamba": "li-ga-gam-ba",
    "ligamaza": "li-ga-ma-za",
    "ligamen": "li-ga-men",
    "ligamento": "li-ga-men-to",
    "ligamentosa": "li-ga-men-to-sa",
    "ligamentoso": "li-ga-men-to-so",
    "ligamiento": "li-ga-mien-to",
    "ligapierna": "li-ga-pier-na",
    "ligar": "li-gar",
    "ligarza": "li-gar-za",
    "ligaterna": "li-ga-ter-na",
    "ligatura": "li-ga-tu-ra",
    "ligazón": "li-ga-zón",
    "ligera": "li-ge-ra",
    "ligeramente": "li-ge-ra-men-te",
    "ligerear": "li-ge-re-ar",
    "ligerez": "li-ge-rez",
    "ligereza": "li-ge-re-za",
    "ligero": "li-ge-ro",
    "ligeruela": "li-ge-rue-la",
    "ligio": "li-gio",
    "lignáloe": "lig-ná-lo-e",
    "lignaria": "lig-na-ria",
    "lignario": "lig-na-rio",
    "lignificación": "lig-ni-fi-ca-ción",
    "lignificar": "lig-ni-fi-car",
    "lignina": "lig-ni-na",
    "lignito": "lig-ni-to",
    "lignívoro": "lig-ní-vo-ro",
    "ligón": "li-gón",
    "ligona": "li-go-na",
    "ligotear": "li-go-te-ar",
    "ligoteo": "li-go-te-o",
    "lígrime": "lí-gri-me",
    "lígrimo": "lí-gri-mo",
    "liguana": "li-gua-na",
    "liguano": "li-gua-no",
    "ligue": "li-gue",
    "liguero": "li-gue-ro",
    "liguilla": "li-gui-lla",
    "lígula": "lí-gu-la",
    "ligur": "li-gur",
    "ligurina": "li-gu-ri-na",
    "ligurino": "li-gu-ri-no",
    "ligústico": "li-gús-ti-co",
    "ligustre": "li-gus-tre",
    "ligustrina": "li-gus-tri-na",
    "ligustrino": "li-gus-tri-no",
    "ligustro": "li-gus-tro",
    "lija": "li-ja",
    "lijado": "li-ja-do",
    "lijadora": "li-ja-do-ra",
    "lijadura": "li-ja-du-ra",
    "lijar": "li-jar",
    "lijo": "li-jo",
    "lijosa": "li-jo-sa",
    "lijosamente": "li-jo-sa-men-te",
    "lijoso": "li-jo-so",
    "lijuana": "li-jua-na",
    "lila": "li-la",
    "lilac": "li-lac",
    "lilaila": "li-lai-la",
    "lilao": "li-la-o",
    "lile": "li-le",
    "lilequear": "li-le-que-ar",
    "liliácea": "li-liá-ce-a",
    "liliáceas": "li-liá-ce-as",
    "liliáceo": "li-liá-ce-o",
    "lililí": "li-li-lí",
    "lilio": "li-lio",
    "liliputiense": "li-li-pu-tien-se",
    "lilo": "li-lo",
    "lima": "li-ma",
    "limaco": "li-ma-co",
    "limado": "li-ma-do",
    "limador": "li-ma-dor",
    "limadura": "li-ma-du-ra",
    "limalla": "li-ma-lla",
    "limanda": "li-man-da",
    "limar": "li-mar",
    "limarina": "li-ma-ri-na",
    "limarino": "li-ma-ri-no",
    "limatón": "li-ma-tón",
    "limaza": "li-ma-za",
    "limazo": "li-ma-zo",
    "limbo": "lim-bo",
    "limen": "li-men",
    "limeña": "li-me-ña",
    "limeño": "li-me-ño",
    "limera": "li-me-ra",
    "limero": "li-me-ro",
    "limeta": "li-me-ta",
    "limícola": "li-mí-co-la",
    "liminal": "li-mi-nal",
    "liminar": "li-mi-nar",
    "limiste": "li-mis-te",
    "limitable": "li-mi-ta-ble",
    "limitación": "li-mi-ta-ción",
    "limitada": "li-mi-ta-da",
    "limitadamente": "li-mi-ta-da-men-te",
    "limitado": "li-mi-ta-do",
    "limitador": "li-mi-ta-dor",
    "limitánea": "li-mi-tá-ne-a",
    "limitáneo": "li-mi-tá-ne-o",
    "limitante": "li-mi-tan-te",
    "limitar": "li-mi-tar",
    "limitativa": "li-mi-ta-ti-va",
    "limitativo": "li-mi-ta-ti-vo",
    "límite": "lí-mi-te",
    "limítrofe": "li-mí-tro-fe",
    "limnología": "lim-no-lo-gí-a",
    "limo": "li-mo",
    "limón": "li-món",
    "limonada": "li-mo-na-da",
    "limonado": "li-mo-na-do",
    "limonar": "li-mo-nar",
    "limonaria": "li-mo-na-ria",
    "limonario": "li-mo-na-rio",
    "limoncillo": "li-mon-ci-llo",
    "limoncito": "li-mon-ci-to",
    "limonense": "li-mo-nen-se",
    "limonera": "li-mo-ne-ra",
    "limonero": "li-mo-ne-ro",
    "limonita": "li-mo-ni-ta",
    "limosa": "li-mo-sa",
    "limosidad": "li-mo-si-dad",
    "limosín": "li-mo-sín",
    "limosna": "li-mos-na",
    "limosnadera": "li-mos-na-de-ra",
    "limosnadero": "li-mos-na-de-ro",
    "limosnador": "li-mos-na-dor",
    "limosnadora": "li-mos-na-do-ra",
    "limosnear": "li-mos-ne-ar",
    "limosneo": "li-mos-ne-o",
    "limosnera": "li-mos-ne-ra",
    "limosnero": "li-mos-ne-ro",
    "limoso": "li-mo-so",
    "limousine": "li-mou-si-ne",
    "limpia": "lim-pia",
    "limpiabarros": "lim-pia-ba-rros",
    "limpiabotas": "lim-pia-bo-tas",
    "limpiachimeneas": "lim-pia-chi-me-ne-as",
    "limpiacoches": "lim-pia-co-ches",
    "limpiacristales": "lim-pia-cris-ta-les",
    "limpiada": "lim-pia-da",
    "limpiadera": "lim-pia-de-ra",
    "limpiadientes": "lim-pia-dien-tes",
    "limpiador": "lim-pia-dor",
    "limpiadora": "lim-pia-do-ra",
    "limpiadura": "lim-pia-du-ra",
    "limpiamente": "lim-pia-men-te",
    "limpiamiento": "lim-pia-mien-to",
    "limpiaparabrisas": "lim-pia-pa-ra-bri-sas",
    "limpiapiés": "lim-pia-piés",
    "limpiaplumas": "lim-pia-plu-mas",
    "limpiar": "lim-piar",
    "limpiaúñas": "lim-pia-ú-ñas",
    "limpiavidrios": "lim-pia-vi-drios",
    "limpidez": "lim-pi-dez",
    "límpido": "lím-pi-do",
    "limpieza": "lim-pie-za",
    "limpio": "lim-pio",
    "limpión": "lim-pión",
    "limusina": "li-mu-si-na",
    "liña": "li-ña",
    "linácea": "li-ná-ce-a",
    "lináceas": "li-ná-ce-as",
    "lináceo": "li-ná-ce-o",
    "linaje": "li-na-je",
    "linajista": "li-na-jis-ta",
    "linajuda": "li-na-ju-da",
    "linajudo": "li-na-ju-do",
    "lináloe": "li-ná-lo-e",
    "linamen": "li-na-men",
    "linao": "li-na-o",
    "linar": "li-nar",
    "linarense": "li-na-ren-se",
    "linaria": "li-na-ria",
    "linaza": "li-na-za",
    "lince": "lin-ce",
    "lincea": "lin-ce-a",
    "lincear": "lin-ce-ar",
    "linceo": "lin-ce-o",
    "linchaco": "lin-cha-co",
    "linchamiento": "lin-cha-mien-to",
    "linchar": "lin-char",
    "lincurio": "lin-cu-rio",
    "linda": "lin-da",
    "lindamente": "lin-da-men-te",
    "lindante": "lin-dan-te",
    "lindar": "lin-dar",
    "lindazo": "lin-da-zo",
    "linde": "lin-de",
    "lindel": "lin-del",
    "lindera": "lin-de-ra",
    "lindería": "lin-de-rí-a",
    "lindero": "lin-de-ro",
    "lindeza": "lin-de-za",
    "lindo": "lin-do",
    "lindón": "lin-dón",
    "lindura": "lin-du-ra",
    "línea": "lí-ne-a",
    "lineal": "li-ne-al",
    "linealidad": "li-ne-a-li-dad",
    "lineamento": "li-ne-a-men-to",
    "lineamiento": "li-ne-a-mien-to",
    "linear": "li-ne-ar",
    "linense": "li-nen-se",
    "líneo": "lí-ne-o",
    "linera": "li-ne-ra",
    "linero": "li-ne-ro",
    "linfa": "lin-fa",
    "linfangitis": "lin-fan-gi-tis",
    "linfática": "lin-fá-ti-ca",
    "linfático": "lin-fá-ti-co",
    "linfatismo": "lin-fa-tis-mo",
    "linfocito": "lin-fo-ci-to",
    "linfocitosis": "lin-fo-ci-to-sis",
    "linfoide": "lin-foi-de",
    "linfoma": "lin-fo-ma",
    "linfopenia": "lin-fo-pe-nia",
    "lingo": "lin-go",
    "lingotazo": "lin-go-ta-zo",
    "lingote": "lin-go-te",
    "lingotera": "lin-go-te-ra",
    "lingual": "lin-gual",
    "lingue": "lin-gue",
    "linguete": "lin-gue-te",
    "lingüista": "lin-güis-ta",
    "lingüística": "lin-güís-ti-ca",
    "lingüístico": "lin-güís-ti-co",
    "linier": "li-nier",
    "liniera": "li-nie-ra",
    "liniero": "li-nie-ro",
    "linimento": "li-ni-men-to",
    "linimiento": "li-ni-mien-to",
    "linio": "li-nio",
    "linjavera": "lin-ja-ve-ra",
    "lino": "li-no",
    "liño": "li-ño",
    "linografía": "li-no-gra-fí-a",
    "linóleo": "li-nó-le-o",
    "linóleum": "li-nó-leum",
    "linón": "li-nón",
    "linotipia": "li-no-ti-pia",
    "linotipista": "li-no-ti-pis-ta",
    "linotipo": "li-no-ti-po",
    "lintel": "lin-tel",
    "linterna": "lin-ter-na",
    "linternazo": "lin-ter-na-zo",
    "linternear": "lin-ter-ne-ar",
    "linternera": "lin-ter-ne-ra",
    "linternero": "lin-ter-ne-ro",
    "linternón": "lin-ter-nón",
    "linudo": "li-nu-do",
    "liñuelo": "li-ñue-lo",
    "linuezo": "li-nue-zo",
    "linyera": "lin-ye-ra",
    "lío": "lí-o",
    "liofilización": "lio-fi-li-za-ción",
    "liofilizador": "lio-fi-li-za-dor",
    "liofilizadora": "lio-fi-li-za-do-ra",
    "liofilizar": "lio-fi-li-zar",
    "lionés": "lio-nés",
    "lionesa": "lio-ne-sa",
    "liorna": "lior-na",
    "liosa": "lio-sa",
    "lioso": "lio-so",
    "lipa": "li-pa",
    "lipasa": "li-pa-sa",
    "lipemanía": "li-pe-ma-ní-a",
    "lipemaniaca": "li-pe-ma-nia-ca",
    "lipemaniaco": "li-pe-ma-nia-co",
    "lipemia": "li-pe-mia",
    "lipendi": "li-pen-di",
    "lipes": "li-pes",
    "lipidia": "li-pi-dia",
    "lipidiar": "li-pi-diar",
    "lipídico": "li-pí-di-co",
    "lipidiosa": "li-pi-dio-sa",
    "lipidioso": "li-pi-dio-so",
    "lípido": "lí-pi-do",
    "lipiria": "li-pi-ria",
    "lipis": "li-pis",
    "lipodistrofia": "li-po-dis-tro-fia",
    "lipodistrófico": "li-po-dis-tró-fi-co",
    "lipoescultura": "li-po-es-cul-tu-ra",
    "lipograma": "li-po-gra-ma",
    "lipoidea": "li-poi-de-a",
    "lipoideo": "li-poi-de-o",
    "lipoma": "li-po-ma",
    "lipón": "li-pón",
    "lipoproteína": "li-po-pro-te-í-na",
    "liposoluble": "li-po-so-lu-ble",
    "liposoma": "li-po-so-ma",
    "liposucción": "li-po-suc-ción",
    "lipotimia": "li-po-ti-mia",
    "lipudo": "li-pu-do",
    "liquen": "li-quen",
    "líquida": "lí-qui-da",
    "liquidable": "li-qui-da-ble",
    "liquidación": "li-qui-da-ción",
    "liquidador": "li-qui-da-dor",
    "liquidadora": "li-qui-da-do-ra",
    "liquidámbar": "li-qui-dám-bar",
    "liquidambo": "li-qui-dam-bo",
    "líquidamente": "lí-qui-da-men-te",
    "liquidar": "li-qui-dar",
    "liquidativo": "li-qui-da-ti-vo",
    "liquidez": "li-qui-dez",
    "líquido": "lí-qui-do",
    "liquiligue": "li-qui-li-gue",
    "liquilique": "li-qui-li-que",
    "liquiliqui": "li-qui-li-qui",
    "lira": "li-ra",
    "lirada": "li-ra-da",
    "lirado": "li-ra-do",
    "liria": "li-ria",
    "lírica": "lí-ri-ca",
    "liricidad": "li-ri-ci-dad",
    "lírico": "lí-ri-co",
    "lirio": "li-rio",
    "lirismo": "li-ris-mo",
    "liróforo": "li-ró-fo-ro",
    "lirón": "li-rón",
    "lironero": "li-ro-ne-ro",
    "lisa": "li-sa",
    "lisamente": "li-sa-men-te",
    "lisboeta": "lis-bo-e-ta",
    "lisbonense": "lis-bo-nen-se",
    "lisbonés": "lis-bo-nés",
    "lisbonesa": "lis-bo-ne-sa",
    "lisera": "li-se-ra",
    "lisérgico": "li-sér-gi-co",
    "lisiada": "li-sia-da",
    "lisiado": "li-sia-do",
    "lisiadura": "li-sia-du-ra",
    "lisiar": "li-siar",
    "lisimaquia": "li-si-ma-quia",
    "lisina": "li-si-na",
    "lisión": "li-sión",
    "lisis": "li-sis",
    "lislique": "lis-li-que",
    "liso": "li-so",
    "lisol": "li-sol",
    "lisonja": "li-son-ja",
    "lisonjar": "li-son-jar",
    "lisonjeador": "li-son-je-a-dor",
    "lisonjeadora": "li-son-je-a-do-ra",
    "lisonjear": "li-son-je-ar",
    "lisonjera": "li-son-je-ra",
    "lisonjeramente": "li-son-je-ra-men-te",
    "lisonjería": "li-son-je-rí-a",
    "lisonjero": "li-son-je-ro",
    "lisosoma": "li-so-so-ma",
    "lisota": "li-so-ta",
    "lisote": "li-so-te",
    "lista": "lis-ta",
    "listada": "lis-ta-da",
    "listado": "lis-ta-do",
    "listar": "lis-tar",
    "listeada": "lis-te-a-da",
    "listeado": "lis-te-a-do",
    "listel": "lis-tel",
    "listera": "lis-te-ra",
    "listero": "lis-te-ro",
    "listeza": "lis-te-za",
    "listilla": "lis-ti-lla",
    "listillo": "lis-ti-llo",
    "listín": "lis-tín",
    "listo": "lis-to",
    "listoco": "lis-to-co",
    "listón": "lis-tón",
    "listonado": "lis-to-na-do",
    "listonar": "lis-to-nar",
    "listonera": "lis-to-ne-ra",
    "listonería": "lis-to-ne-rí-a",
    "listonero": "lis-to-ne-ro",
    "listura": "lis-tu-ra",
    "lisura": "li-su-ra",
    "lita": "li-ta",
    "litación": "li-ta-ción",
    "litar": "li-tar",
    "litarge": "li-tar-ge",
    "litargia": "li-tar-gia",
    "litargirio": "li-tar-gi-rio",
    "lite": "li-te",
    "litera": "li-te-ra",
    "literal": "li-te-ral",
    "literalidad": "li-te-ra-li-dad",
    "literalmente": "li-te-ral-men-te",
    "literaria": "li-te-ra-ria",
    "literariamente": "li-te-ra-ria-men-te",
    "literario": "li-te-ra-rio",
    "literata": "li-te-ra-ta",
    "literato": "li-te-ra-to",
    "literatura": "li-te-ra-tu-ra",
    "literaturización": "li-te-ra-tu-ri-za-ción",
    "literaturizar": "li-te-ra-tu-ri-zar",
    "literero": "li-te-re-ro",
    "litería": "li-te-rí-a",
    "litiásico": "li-tiá-si-co",
    "litiasis": "li-tia-sis",
    "lítica": "lí-ti-ca",
    "lítico": "lí-ti-co",
    "litificación": "li-ti-fi-ca-ción",
    "litigación": "li-ti-ga-ción",
    "litigante": "li-ti-gan-te",
    "litigar": "li-ti-gar",
    "litigio": "li-ti-gio",
    "litigiosa": "li-ti-gio-sa",
    "litigiosidad": "li-ti-gio-si-dad",
    "litigioso": "li-ti-gio-so",
    "litina": "li-ti-na",
    "litio": "li-tio",
    "litis": "li-tis",
    "litisconsorte": "li-tis-con-sor-te",
    "litisexpensas": "li-ti-sex-pen-sas",
    "litispendencia": "li-tis-pen-den-cia",
    "litocálamo": "li-to-cá-la-mo",
    "litoclasa": "li-to-cla-sa",
    "litocola": "li-to-co-la",
    "litófaga": "li-tó-fa-ga",
    "litófago": "li-tó-fa-go",
    "litofanía": "li-to-fa-ní-a",
    "litofotografía": "li-to-fo-to-gra-fí-a",
    "litofotografiar": "li-to-fo-to-gra-fiar",
    "litofotográficamente": "li-to-fo-to-grá-fi-ca-men-te",
    "litogenesia": "li-to-ge-ne-sia",
    "litogénesis": "li-to-gé-ne-sis",
    "litógrafa": "li-tó-gra-fa",
    "litografía": "li-to-gra-fí-a",
    "litografiar": "li-to-gra-fiar",
    "litográfica": "li-to-grá-fi-ca",
    "litográfico": "li-to-grá-fi-co",
    "litógrafo": "li-tó-gra-fo",
    "litóloga": "li-tó-lo-ga",
    "litología": "li-to-lo-gí-a",
    "litológica": "li-to-ló-gi-ca",
    "litológico": "li-to-ló-gi-co",
    "litólogo": "li-tó-lo-go",
    "litonero": "li-to-ne-ro",
    "litoral": "li-to-ral",
    "litosfera": "li-tos-fe-ra",
    "litósfera": "li-tós-fe-ra",
    "litote": "li-to-te",
    "lítotes": "lí-to-tes",
    "litotomía": "li-to-to-mí-a",
    "litotricia": "li-to-tri-cia",
    "litrácea": "li-trá-ce-a",
    "litráceo": "li-trá-ce-o",
    "litrariea": "li-tra-rie-a",
    "litrarieo": "li-tra-rie-o",
    "litre": "li-tre",
    "litreado": "li-tre-a-do",
    "litro": "li-tro",
    "litrona": "li-tro-na",
    "lituana": "li-tua-na",
    "lituano": "li-tua-no",
    "lituo": "li-tuo",
    "liturgia": "li-tur-gia",
    "litúrgica": "li-túr-gi-ca",
    "litúrgico": "li-túr-gi-co",
    "liturgista": "li-tur-gis-ta",
    "liuda": "liu-da",
    "liudar": "liu-dar",
    "liudo": "liu-do",
    "liviana": "li-via-na",
    "livianamente": "li-via-na-men-te",
    "liviandad": "li-vian-dad",
    "livianeza": "li-via-ne-za",
    "liviano": "li-via-no",
    "lívida": "lí-vi-da",
    "lividecer": "li-vi-de-cer",
    "lividez": "li-vi-dez",
    "lívido": "lí-vi-do",
    "living": "li-ving",
    "livonia": "li-vo-nia",
    "livonio": "li-vo-nio",
    "livor": "li-vor",
    "lixiviación": "li-xi-via-ción",
    "lixiviar": "li-xi-viar",
    "liza": "li-za",
    "lizo": "li-zo",
    "llábana": "llá-ba-na",
    "llaca": "lla-ca",
    "llaga": "lla-ga",
    "llagador": "lla-ga-dor",
    "llagadora": "lla-ga-do-ra",
    "llagamiento": "lla-ga-mien-to",
    "llagar": "lla-gar",
    "llagosa": "lla-go-sa",
    "llagoso": "lla-go-so",
    "llalla": "lla-lla",
    "llama": "lla-ma",
    "llamada": "lla-ma-da",
    "llamadera": "lla-ma-de-ra",
    "llamado": "lla-ma-do",
    "llamador": "lla-ma-dor",
    "llamadora": "lla-ma-do-ra",
    "llamamiento": "lla-ma-mien-to",
    "llamar": "lla-mar",
    "llamarada": "lla-ma-ra-da",
    "llamarón": "lla-ma-rón",
    "llamativa": "lla-ma-ti-va",
    "llamativo": "lla-ma-ti-vo",
    "llambo": "llam-bo",
    "llambria": "llam-bria",
    "llame": "lla-me",
    "llameante": "lla-me-an-te",
    "llamear": "lla-me-ar",
    "llamerada": "lla-me-ra-da",
    "llamingo": "lla-min-go",
    "llamo": "lla-mo",
    "llampo": "llam-po",
    "llana": "lla-na",
    "llanada": "lla-na-da",
    "llanamente": "lla-na-men-te",
    "llanca": "llan-ca",
    "llande": "llan-de",
    "llaneador": "lla-ne-a-dor",
    "llaneadora": "lla-ne-a-do-ra",
    "llanear": "lla-ne-ar",
    "llanera": "lla-ne-ra",
    "llanero": "lla-ne-ro",
    "llaneza": "lla-ne-za",
    "llanisca": "lla-nis-ca",
    "llanisco": "lla-nis-co",
    "llanita": "lla-ni-ta",
    "llanito": "lla-ni-to",
    "llano": "lla-no",
    "llanque": "llan-que",
    "llanquihuana": "llan-qui-hua-na",
    "llanquihuano": "llan-qui-hua-no",
    "llanta": "llan-ta",
    "llantear": "llan-te-ar",
    "llantén": "llan-tén",
    "llantera": "llan-te-ra",
    "llantería": "llan-te-rí-a",
    "llanterío": "llan-te-rí-o",
    "llantero": "llan-te-ro",
    "llantina": "llan-ti-na",
    "llanto": "llan-to",
    "llanura": "lla-nu-ra",
    "llapa": "lla-pa",
    "llapar": "lla-par",
    "llapingacho": "lla-pin-ga-cho",
    "llares": "lla-res",
    "llareta": "lla-re-ta",
    "llaucana": "llau-ca-na",
    "llauquear": "llau-que-ar",
    "llave": "lla-ve",
    "llavear": "lla-ve-ar",
    "llavera": "lla-ve-ra",
    "llaverizo": "lla-ve-ri-zo",
    "llavero": "lla-ve-ro",
    "llavín": "lla-vín",
    "lleca": "lle-ca",
    "lleco": "lle-co",
    "llega": "lle-ga",
    "llegada": "lle-ga-da",
    "llegado": "lle-ga-do",
    "llegador": "lle-ga-dor",
    "llegadora": "lle-ga-do-ra",
    "llegamiento": "lle-ga-mien-to",
    "llegar": "lle-gar",
    "llegue": "lle-gue",
    "lleivún": "llei-vún",
    "llena": "lle-na",
    "llenado": "lle-na-do",
    "llenador": "lle-na-dor",
    "llenadora": "lle-na-do-ra",
    "llenamente": "lle-na-men-te",
    "llenar": "lle-nar",
    "llenazo": "lle-na-zo",
    "llenazón": "lle-na-zón",
    "llenera": "lle-ne-ra",
    "lleneramente": "lle-ne-ra-men-te",
    "llenero": "lle-ne-ro",
    "llenez": "lle-nez",
    "lleneza": "lle-ne-za",
    "lleno": "lle-no",
    "llenura": "lle-nu-ra",
    "llera": "lle-ra",
    "lleudar": "lleu-dar",
    "lleva": "lle-va",
    "llevada": "lle-va-da",
    "llevadera": "lle-va-de-ra",
    "llevadero": "lle-va-de-ro",
    "llevado": "lle-va-do",
    "llevador": "lle-va-dor",
    "llevadora": "lle-va-do-ra",
    "llevaitrae": "lle-vai-tra-e",
    "llevanza": "lle-van-za",
    "llevar": "lle-var",
    "lleve": "lle-ve",
    "lliclla": "llic-lla",
    "llicta": "llic-ta",
    "lligues": "lli-gues",
    "llocántaro": "llo-cán-ta-ro",
    "llocura": "llo-cu-ra",
    "lloica": "lloi-ca",
    "lloradera": "llo-ra-de-ra",
    "llorador": "llo-ra-dor",
    "lloradora": "llo-ra-do-ra",
    "lloraduelos": "llo-ra-due-los",
    "llorar": "llo-rar",
    "lloredo": "llo-re-do",
    "llorera": "llo-re-ra",
    "lloreta": "llo-re-ta",
    "llorica": "llo-ri-ca",
    "llorido": "llo-ri-do",
    "lloriquear": "llo-ri-que-ar",
    "lloriqueo": "llo-ri-que-o",
    "llorisquear": "llo-ris-que-ar",
    "lloro": "llo-ro",
    "llorón": "llo-rón",
    "llorona": "llo-ro-na",
    "lloronas": "llo-ro-nas",
    "llorosa": "llo-ro-sa",
    "llorosamente": "llo-ro-sa-men-te",
    "lloroso": "llo-ro-so",
    "llosa": "llo-sa",
    "llotrar": "llo-trar",
    "llovedera": "llo-ve-de-ra",
    "llovediza": "llo-ve-di-za",
    "llovedizo": "llo-ve-di-zo",
    "llover": "llo-ver",
    "llovida": "llo-vi-da",
    "llovido": "llo-vi-do",
    "lloviosa": "llo-vio-sa",
    "llovioso": "llo-vio-so",
    "llovizna": "llo-viz-na",
    "lloviznar": "llo-viz-nar",
    "lloviznoso": "llo-viz-no-so",
    "llubina": "llu-bi-na",
    "llucho": "llu-cho",
    "llueca": "llue-ca",
    "lluvia": "llu-via",
    "lluvial": "llu-vial",
    "lluviana": "llu-via-na",
    "lluviano": "llu-via-no",
    "lluviosa": "llu-vio-sa",
    "lluvioso": "llu-vio-so",
    "loa": "lo-a",
    "loable": "lo-a-ble",
    "loablemente": "lo-a-ble-men-te",
    "loador": "lo-a-dor",
    "loadora": "lo-a-do-ra",
    "loanda": "lo-an-da",
    "loanza": "lo-an-za",
    "loar": "lo-ar",
    "loba": "lo-ba",
    "lobada": "lo-ba-da",
    "lobado": "lo-ba-do",
    "lobagante": "lo-ba-gan-te",
    "lobanillo": "lo-ba-ni-llo",
    "lobarro": "lo-ba-rro",
    "lobato": "lo-ba-to",
    "lobatón": "lo-ba-tón",
    "lobear": "lo-be-ar",
    "lobectomía": "lo-bec-to-mí-a",
    "lobelia": "lo-be-lia",
    "lobeliácea": "lo-be-liá-ce-a",
    "lobeliáceo": "lo-be-liá-ce-o",
    "lobera": "lo-be-ra",
    "lobería": "lo-be-rí-a",
    "lobero": "lo-be-ro",
    "lobezno": "lo-bez-no",
    "lobina": "lo-bi-na",
    "lobisón": "lo-bi-són",
    "lobizón": "lo-bi-zón",
    "lobo": "lo-bo",
    "lobosa": "lo-bo-sa",
    "loboso": "lo-bo-so",
    "lobotomía": "lo-bo-to-mí-a",
    "lóbrega": "ló-bre-ga",
    "lóbrego": "ló-bre-go",
    "lobreguecer": "lo-bre-gue-cer",
    "lobreguez": "lo-bre-guez",
    "lobregura": "lo-bre-gu-ra",
    "lóbriga": "ló-bri-ga",
    "lóbrigo": "ló-bri-go",
    "lobulada": "lo-bu-la-da",
    "lobulado": "lo-bu-la-do",
    "lobular": "lo-bu-lar",
    "lóbulo": "ló-bu-lo",
    "lobuna": "lo-bu-na",
    "lobuno": "lo-bu-no",
    "loca": "lo-ca",
    "locación": "lo-ca-ción",
    "local": "lo-cal",
    "localidad": "lo-ca-li-dad",
    "localismo": "lo-ca-lis-mo",
    "localista": "lo-ca-lis-ta",
    "localizable": "lo-ca-li-za-ble",
    "localización": "lo-ca-li-za-ción",
    "localizador": "lo-ca-li-za-dor",
    "localizar": "lo-ca-li-zar",
    "locamente": "lo-ca-men-te",
    "locata": "lo-ca-ta",
    "locataria": "lo-ca-ta-ria",
    "locatario": "lo-ca-ta-rio",
    "locateli": "lo-ca-te-li",
    "locatis": "lo-ca-tis",
    "locativa": "lo-ca-ti-va",
    "locativo": "lo-ca-ti-vo",
    "locato": "lo-ca-to",
    "locear": "lo-ce-ar",
    "locera": "lo-ce-ra",
    "locería": "lo-ce-rí-a",
    "locero": "lo-ce-ro",
    "locha": "lo-cha",
    "loche": "lo-che",
    "loción": "lo-ción",
    "lockout": "loc-kout",
    "loco": "lo-co",
    "locomoción": "lo-co-mo-ción",
    "locomotor": "lo-co-mo-tor",
    "locomotora": "lo-co-mo-to-ra",
    "locomotriz": "lo-co-mo-triz",
    "locomovible": "lo-co-mo-vi-ble",
    "locomóvil": "lo-co-mó-vil",
    "locrio": "lo-crio",
    "locro": "lo-cro",
    "locuacidad": "lo-cua-ci-dad",
    "locuaz": "lo-cuaz",
    "locución": "lo-cu-ción",
    "locuela": "lo-cue-la",
    "locuelo": "lo-cue-lo",
    "locumbeta": "lo-cum-be-ta",
    "locura": "lo-cu-ra",
    "locutar": "lo-cu-tar",
    "locutor": "lo-cu-tor",
    "locutora": "lo-cu-to-ra",
    "locutorio": "lo-cu-to-rio",
    "lodacera": "lo-da-ce-ra",
    "lodachar": "lo-da-char",
    "lodazal": "lo-da-zal",
    "lodazar": "lo-da-zar",
    "lodera": "lo-de-ra",
    "lodienta": "lo-dien-ta",
    "lodiento": "lo-dien-to",
    "lodo": "lo-do",
    "lodón": "lo-dón",
    "lodoñero": "lo-do-ñe-ro",
    "lodoño": "lo-do-ño",
    "lodosa": "lo-do-sa",
    "lodoso": "lo-do-so",
    "lodra": "lo-dra",
    "loess": "lo-ess",
    "lofobranquio": "lo-fo-bran-quio",
    "logadero": "lo-ga-de-ro",
    "loganiácea": "lo-ga-niá-ce-a",
    "loganiáceo": "lo-ga-niá-ce-o",
    "logar": "lo-gar",
    "logarítmica": "lo-ga-rít-mi-ca",
    "logarítmico": "lo-ga-rít-mi-co",
    "logaritmo": "lo-ga-rit-mo",
    "logia": "lo-gia",
    "lógica": "ló-gi-ca",
    "logical": "lo-gi-cal",
    "lógicamente": "ló-gi-ca-men-te",
    "logicismo": "lo-gi-cis-mo",
    "lógico": "ló-gi-co",
    "logis": "lo-gis",
    "logista": "lo-gis-ta",
    "logística": "lo-gís-ti-ca",
    "logístico": "lo-gís-ti-co",
    "logo": "lo-go",
    "logogrífica": "lo-go-grí-fi-ca",
    "logogrífico": "lo-go-grí-fi-co",
    "logogrifo": "lo-go-gri-fo",
    "logomaquia": "lo-go-ma-quia",
    "logopeda": "lo-go-pe-da",
    "logopedia": "lo-go-pe-dia",
    "logos": "lo-gos",
    "logotipo": "lo-go-ti-po",
    "logrado": "lo-gra-do",
    "lograr": "lo-grar",
    "logrear": "lo-gre-ar",
    "logrera": "lo-gre-ra",
    "logrería": "lo-gre-rí-a",
    "logrero": "lo-gre-ro",
    "logro": "lo-gro",
    "logroñés": "lo-gro-ñés",
    "logroñesa": "lo-gro-ñe-sa",
    "loguer": "lo-guer",
    "loguero": "lo-gue-ro",
    "loica": "loi-ca",
    "loina": "loi-na",
    "loíno": "lo-í-no",
    "loísmo": "lo-ís-mo",
    "loísta": "lo-ís-ta",
    "lojana": "lo-ja-na",
    "lojano": "lo-ja-no",
    "lojeña": "lo-je-ña",
    "lojeño": "lo-je-ño",
    "lola": "lo-la",
    "lolaje": "lo-la-je",
    "lolear": "lo-le-ar",
    "loli": "lo-li",
    "lolio": "lo-lio",
    "lolita": "lo-li-ta",
    "lolo": "lo-lo",
    "loma": "lo-ma",
    "lomada": "lo-ma-da",
    "lomaje": "lo-ma-je",
    "lomba": "lom-ba",
    "lombarda": "lom-bar-da",
    "lombardada": "lom-bar-da-da",
    "lombardear": "lom-bar-de-ar",
    "lombardería": "lom-bar-de-rí-a",
    "lombardero": "lom-bar-de-ro",
    "lombárdica": "lom-bár-di-ca",
    "lombárdico": "lom-bár-di-co",
    "lombardo": "lom-bar-do",
    "lombo": "lom-bo",
    "lombricida": "lom-bri-ci-da",
    "lombriciento": "lom-bri-cien-to",
    "lombriguera": "lom-bri-gue-ra",
    "lombriz": "lom-briz",
    "lomear": "lo-me-ar",
    "lomera": "lo-me-ra",
    "lometa": "lo-me-ta",
    "lomienhiesta": "lo-mien-hies-ta",
    "lomienhiesto": "lo-mien-hies-to",
    "lomillería": "lo-mi-lle-rí-a",
    "lomillo": "lo-mi-llo",
    "lominhiesta": "lo-min-hies-ta",
    "lominhiesto": "lo-min-hies-to",
    "lomo": "lo-mo",
    "lomosa": "lo-mo-sa",
    "lomoso": "lo-mo-so",
    "lomuda": "lo-mu-da",
    "lomudo": "lo-mu-do",
    "lona": "lo-na",
    "loncha": "lon-cha",
    "lonchera": "lon-che-ra",
    "lonchería": "lon-che-rí-a",
    "lonco": "lon-co",
    "lóndiga": "lón-di-ga",
    "londinense": "lon-di-nen-se",
    "londrina": "lon-dri-na",
    "loneta": "lo-ne-ta",
    "longa": "lon-ga",
    "longadura": "lon-ga-du-ra",
    "longamente": "lon-ga-men-te",
    "longánima": "lon-gá-ni-ma",
    "longanimidad": "lon-ga-ni-mi-dad",
    "longánimo": "lon-gá-ni-mo",
    "longaniza": "lon-ga-ni-za",
    "longar": "lon-gar",
    "longeva": "lon-ge-va",
    "longevidad": "lon-ge-vi-dad",
    "longevo": "lon-ge-vo",
    "longincua": "lon-gin-cua",
    "longincuo": "lon-gin-cuo",
    "longitud": "lon-gi-tud",
    "longitudinal": "lon-gi-tu-di-nal",
    "longitudinalmente": "lon-gi-tu-di-nal-men-te",
    "longo": "lon-go",
    "longobarda": "lon-go-bar-da",
    "longobardo": "lon-go-bar-do",
    "longor": "lon-gor",
    "longorón": "lon-go-rón",
    "longuera": "lon-gue-ra",
    "longuería": "lon-gue-rí-a",
    "longuetas": "lon-gue-tas",
    "longueza": "lon-gue-za",
    "longui": "lon-gui",
    "longuísima": "lon-guí-si-ma",
    "longuísimo": "lon-guí-si-mo",
    "longura": "lon-gu-ra",
    "lonja": "lon-ja",
    "lonjear": "lon-je-ar",
    "lonjeta": "lon-je-ta",
    "lonjista": "lon-jis-ta",
    "lontananza": "lon-ta-nan-za",
    "look": "lo-ok",
    "looping": "lo-o-ping",
    "loor": "lo-or",
    "lopesco": "lo-pes-co",
    "lópez": "ló-pez",
    "lopigia": "lo-pi-gia",
    "lopista": "lo-pis-ta",
    "loquear": "lo-que-ar",
    "loquera": "lo-que-ra",
    "loquería": "lo-que-rí-a",
    "loquerío": "lo-que-rí-o",
    "loquero": "lo-que-ro",
    "loquesca": "lo-ques-ca",
    "loquesco": "lo-ques-co",
    "loquetera": "lo-que-te-ra",
    "loquinaria": "lo-qui-na-ria",
    "loquinario": "lo-qui-na-rio",
    "loquios": "lo-quios",
    "lora": "lo-ra",
    "lorantácea": "lo-ran-tá-ce-a",
    "lorantáceo": "lo-ran-tá-ce-o",
    "lorcha": "lor-cha",
    "lordosis": "lor-do-sis",
    "lorear": "lo-re-ar",
    "lorenés": "lo-re-nés",
    "lorenesa": "lo-re-ne-sa",
    "lorenza": "lo-ren-za",
    "lorenzana": "lo-ren-za-na",
    "lorenzo": "lo-ren-zo",
    "lorero": "lo-re-ro",
    "loretana": "lo-re-ta-na",
    "loretano": "lo-re-ta-no",
    "lori": "lo-ri",
    "loriga": "lo-ri-ga",
    "lorigada": "lo-ri-ga-da",
    "lorigado": "lo-ri-ga-do",
    "lorigón": "lo-ri-gón",
    "loriguera": "lo-ri-gue-ra",
    "loriguero": "lo-ri-gue-ro",
    "loriguillo": "lo-ri-gui-llo",
    "loro": "lo-ro",
    "loroco": "lo-ro-co",
    "lorquiano": "lor-quia-no",
    "lorquina": "lor-qui-na",
    "lorquino": "lor-qui-no",
    "lorza": "lor-za",
    "losa": "lo-sa",
    "losado": "lo-sa-do",
    "losange": "lo-san-ge",
    "losar": "lo-sar",
    "loseta": "lo-se-ta",
    "losilla": "lo-si-lla",
    "losina": "lo-si-na",
    "losino": "lo-si-no",
    "lota": "lo-ta",
    "lote": "lo-te",
    "lotear": "lo-te-ar",
    "loteo": "lo-te-o",
    "lotera": "lo-te-ra",
    "lotería": "lo-te-rí-a",
    "lotero": "lo-te-ro",
    "lotificación": "lo-ti-fi-ca-ción",
    "lotificadora": "lo-ti-fi-ca-do-ra",
    "lotificar": "lo-ti-fi-car",
    "lotiforme": "lo-ti-for-me",
    "lotín": "lo-tín",
    "lotización": "lo-ti-za-ción",
    "lotizar": "lo-ti-zar",
    "loto": "lo-to",
    "lotófaga": "lo-tó-fa-ga",
    "lotófago": "lo-tó-fa-go",
    "lovaniense": "lo-va-nien-se",
    "loxodromia": "lo-xo-dro-mia",
    "loxodrómica": "lo-xo-dró-mi-ca",
    "loxodrómico": "lo-xo-dró-mi-co",
    "loza": "lo-za",
    "lozana": "lo-za-na",
    "lozanamente": "lo-za-na-men-te",
    "lozanear": "lo-za-ne-ar",
    "lozanecer": "lo-za-ne-cer",
    "lozanía": "lo-za-ní-a",
    "lozano": "lo-za-no",
    "lúa": "lú-a",
    "lubigante": "lu-bi-gan-te",
    "lubina": "lu-bi-na",
    "lubola": "lu-bo-la",
    "lubolo": "lu-bo-lo",
    "lúbrica": "lú-bri-ca",
    "lubricación": "lu-bri-ca-ción",
    "lubricador": "lu-bri-ca-dor",
    "lubricadora": "lu-bri-ca-do-ra",
    "lúbricamente": "lú-bri-ca-men-te",
    "lubricán": "lu-bri-cán",
    "lubricante": "lu-bri-can-te",
    "lubricar": "lu-bri-car",
    "lubricativa": "lu-bri-ca-ti-va",
    "lubricativo": "lu-bri-ca-ti-vo",
    "lubricidad": "lu-bri-ci-dad",
    "lúbrico": "lú-bri-co",
    "lubrificación": "lu-bri-fi-ca-ción",
    "lubrificante": "lu-bri-fi-can-te",
    "lubrificar": "lu-bri-fi-car",
    "luca": "lu-ca",
    "lucana": "lu-ca-na",
    "lucaneña": "lu-ca-ne-ña",
    "lucaneño": "lu-ca-ne-ño",
    "lucano": "lu-ca-no",
    "lucemburgués": "lu-cem-bur-gués",
    "lucemburguesa": "lu-cem-bur-gue-sa",
    "lucencia": "lu-cen-cia",
    "lucenés": "lu-ce-nés",
    "lucenesa": "lu-ce-ne-sa",
    "lucense": "lu-cen-se",
    "lucentina": "lu-cen-ti-na",
    "lucentino": "lu-cen-ti-no",
    "lucentísima": "lu-cen-tí-si-ma",
    "lucentísimo": "lu-cen-tí-si-mo",
    "lucentor": "lu-cen-tor",
    "lucera": "lu-ce-ra",
    "lucerío": "lu-ce-rí-o",
    "lucerna": "lu-cer-na",
    "lucernario": "lu-cer-na-rio",
    "lucérnula": "lu-cér-nu-la",
    "lucero": "lu-ce-ro",
    "luceta": "lu-ce-ta",
    "lucha": "lu-cha",
    "luchadero": "lu-cha-de-ro",
    "luchador": "lu-cha-dor",
    "luchadora": "lu-cha-do-ra",
    "luchar": "lu-char",
    "lucharniego": "lu-char-nie-go",
    "luche": "lu-che",
    "luchicán": "lu-chi-cán",
    "luchón": "lu-chón",
    "lucia": "lu-cia",
    "luciaco": "lu-cia-co",
    "lucianesca": "lu-cia-nes-ca",
    "lucianesco": "lu-cia-nes-co",
    "lucible": "lu-ci-ble",
    "lúcida": "lú-ci-da",
    "lucidamente": "lu-ci-da-men-te",
    "lucidez": "lu-ci-dez",
    "lucido": "lu-ci-do",
    "lúcido": "lú-ci-do",
    "lucidor": "lu-ci-dor",
    "lucidora": "lu-ci-do-ra",
    "lucidura": "lu-ci-du-ra",
    "luciente": "lu-cien-te",
    "luciérnaga": "lu-ciér-na-ga",
    "luciérnago": "lu-ciér-na-go",
    "lucifer": "lu-ci-fer",
    "lucífera": "lu-cí-fe-ra",
    "luciferal": "lu-ci-fe-ral",
    "luciferina": "lu-ci-fe-ri-na",
    "luciferino": "lu-ci-fe-ri-no",
    "lucífero": "lu-cí-fe-ro",
    "lucífuga": "lu-cí-fu-ga",
    "lucífugo": "lu-cí-fu-go",
    "lucilina": "lu-ci-li-na",
    "lucillo": "lu-ci-llo",
    "lucilo": "lu-ci-lo",
    "lucimiento": "lu-ci-mien-to",
    "lucina": "lu-ci-na",
    "lucio": "lu-cio",
    "lución": "lu-ción",
    "lucir": "lu-cir",
    "luco": "lu-co",
    "lucrar": "lu-crar",
    "lucrativa": "lu-cra-ti-va",
    "lucrativo": "lu-cra-ti-vo",
    "lucro": "lu-cro",
    "lucroniense": "lu-cro-nien-se",
    "lucrosa": "lu-cro-sa",
    "lucroso": "lu-cro-so",
    "luctuosa": "luc-tuo-sa",
    "luctuosamente": "luc-tuo-sa-men-te",
    "luctuoso": "luc-tuo-so",
    "lucubración": "lu-cu-bra-ción",
    "lucubrar": "lu-cu-brar",
    "lúcuma": "lú-cu-ma",
    "lúcumo": "lú-cu-mo",
    "ludada": "lu-da-da",
    "ludia": "lu-dia",
    "ludiar": "lu-diar",
    "ludibrio": "lu-di-brio",
    "lúdico": "lú-di-co",
    "lúdicra": "lú-di-cra",
    "lúdicro": "lú-di-cro",
    "ludimiento": "lu-di-mien-to",
    "ludio": "lu-dio",
    "ludión": "lu-dión",
    "ludir": "lu-dir",
    "ludo": "lu-do",
    "ludóloga": "lu-dó-lo-ga",
    "ludólogo": "lu-dó-lo-go",
    "ludópata": "lu-dó-pa-ta",
    "ludopatía": "lu-do-pa-tí-a",
    "ludoteca": "lu-do-te-ca",
    "ludria": "lu-dria",
    "lúdrico": "lú-dri-co",
    "lúe": "lú-e",
    "luego": "lue-go",
    "luello": "lue-llo",
    "lueñe": "lue-ñe",
    "luenga": "luen-ga",
    "luengamente": "luen-ga-men-te",
    "luengo": "luen-go",
    "lúes": "lú-es",
    "luético": "lué-ti-co",
    "lufrazo": "lu-fra-zo",
    "lugano": "lu-ga-no",
    "lugar": "lu-gar",
    "lugareña": "lu-ga-re-ña",
    "lugareño": "lu-ga-re-ño",
    "lugartenencia": "lu-gar-te-nen-cia",
    "lugarteniente": "lu-gar-te-nien-te",
    "lugdunense": "lug-du-nen-se",
    "luge": "lu-ge",
    "lugre": "lu-gre",
    "lúgubre": "lú-gu-bre",
    "lúgubremente": "lú-gu-bre-men-te",
    "lugués": "lu-gués",
    "luguesa": "lu-gue-sa",
    "luición": "lui-ción",
    "luisa": "lui-sa",
    "luismo": "luis-mo",
    "lujación": "lu-ja-ción",
    "lujar": "lu-jar",
    "lujear": "lu-je-ar",
    "lujo": "lu-jo",
    "lujosa": "lu-jo-sa",
    "lujosamente": "lu-jo-sa-men-te",
    "lujoso": "lu-jo-so",
    "lujuria": "lu-ju-ria",
    "lujuriante": "lu-ju-rian-te",
    "lujuriar": "lu-ju-riar",
    "lujuriosa": "lu-ju-rio-sa",
    "lujuriosamente": "lu-ju-rio-sa-men-te",
    "lujurioso": "lu-ju-rio-so",
    "lule": "lu-le",
    "luliana": "lu-lia-na",
    "luliano": "lu-lia-no",
    "lulismo": "lu-lis-mo",
    "lulista": "lu-lis-ta",
    "lulo": "lu-lo",
    "lulú": "lu-lú",
    "luma": "lu-ma",
    "lumaquela": "lu-ma-que-la",
    "lumazo": "lu-ma-zo",
    "lumbago": "lum-ba-go",
    "lumbalgia": "lum-bal-gia",
    "lumbar": "lum-bar",
    "lumbo": "lum-bo",
    "lumbrada": "lum-bra-da",
    "lumbral": "lum-bral",
    "lumbrarada": "lum-bra-ra-da",
    "lumbraria": "lum-bra-ria",
    "lumbre": "lum-bre",
    "lumbrera": "lum-bre-ra",
    "lumbrerada": "lum-bre-ra-da",
    "lumbrería": "lum-bre-rí-a",
    "lumbrical": "lum-bri-cal",
    "lumbricultura": "lum-bri-cul-tu-ra",
    "lumbrosa": "lum-bro-sa",
    "lumbroso": "lum-bro-so",
    "lumear": "lu-me-ar",
    "lumen": "lu-men",
    "lumia": "lu-mia",
    "lumiaco": "lu-mia-co",
    "luminancia": "lu-mi-nan-cia",
    "luminar": "lu-mi-nar",
    "luminaria": "lu-mi-na-ria",
    "lumínica": "lu-mí-ni-ca",
    "lumínico": "lu-mí-ni-co",
    "luminiscencia": "lu-mi-nis-cen-cia",
    "luminiscente": "lu-mi-nis-cen-te",
    "luminismo": "lu-mi-nis-mo",
    "luminista": "lu-mi-nis-ta",
    "luminosa": "lu-mi-no-sa",
    "luminosamente": "lu-mi-no-sa-men-te",
    "luminosidad": "lu-mi-no-si-dad",
    "luminoso": "lu-mi-no-so",
    "luminotecnia": "lu-mi-no-tec-nia",
    "luminotécnica": "lu-mi-no-téc-ni-ca",
    "luminotécnico": "lu-mi-no-téc-ni-co",
    "lumpemproletariado": "lum-pem-pro-le-ta-ria-do",
    "lumpen": "lum-pen",
    "lumpo": "lum-po",
    "luna": "lu-na",
    "lunación": "lu-na-ción",
    "lunada": "lu-na-da",
    "lunado": "lu-na-do",
    "lunanca": "lu-nan-ca",
    "lunanco": "lu-nan-co",
    "lunar": "lu-nar",
    "lunareja": "lu-na-re-ja",
    "lunarejo": "lu-na-re-jo",
    "lunaria": "lu-na-ria",
    "lunario": "lu-na-rio",
    "lunática": "lu-ná-ti-ca",
    "lunático": "lu-ná-ti-co",
    "lunatismo": "lu-na-tis-mo",
    "lunear": "lu-ne-ar",
    "lunecilla": "lu-ne-ci-lla",
    "lunel": "lu-nel",
    "lunes": "lu-nes",
    "luneta": "lu-ne-ta",
    "luneto": "lu-ne-to",
    "lunfa": "lun-fa",
    "lunfardismo": "lun-far-dis-mo",
    "lunfardo": "lun-far-do",
    "lunga": "lun-ga",
    "lungo": "lun-go",
    "lunilla": "lu-ni-lla",
    "lúnula": "lú-nu-la",
    "lupa": "lu-pa",
    "lupanar": "lu-pa-nar",
    "lupanaria": "lu-pa-na-ria",
    "lupanario": "lu-pa-na-rio",
    "lupercales": "lu-per-ca-les",
    "lupia": "lu-pia",
    "lupicia": "lu-pi-cia",
    "lupina": "lu-pi-na",
    "lupino": "lu-pi-no",
    "lupulina": "lu-pu-li-na",
    "lupulino": "lu-pu-li-no",
    "lúpulo": "lú-pu-lo",
    "lupus": "lu-pus",
    "luquear": "lu-que-ar",
    "luqués": "lu-qués",
    "luquesa": "lu-que-sa",
    "luquete": "lu-que-te",
    "luria": "lu-ria",
    "lurio": "lu-rio",
    "lurte": "lur-te",
    "lusa": "lu-sa",
    "lusca": "lus-ca",
    "lusco": "lus-co",
    "lusetana": "lu-se-ta-na",
    "lusetano": "lu-se-ta-no",
    "lusismo": "lu-sis-mo",
    "lusista": "lu-sis-ta",
    "lusitana": "lu-si-ta-na",
    "lusitánica": "lu-si-tá-ni-ca",
    "lusitánico": "lu-si-tá-ni-co",
    "lusitanismo": "lu-si-ta-nis-mo",
    "lusitanista": "lu-si-ta-nis-ta",
    "lusitano": "lu-si-ta-no",
    "luso": "lu-so",
    "lustrabotas": "lus-tra-bo-tas",
    "lustración": "lus-tra-ción",
    "lustrador": "lus-tra-dor",
    "lustradora": "lus-tra-do-ra",
    "lustral": "lus-tral",
    "lustramiento": "lus-tra-mien-to",
    "lustramueble": "lus-tra-mue-ble",
    "lustramuebles": "lus-tra-mue-bles",
    "lustrar": "lus-trar",
    "lustre": "lus-tre",
    "lustrear": "lus-tre-ar",
    "lústrica": "lús-tri-ca",
    "lústrico": "lús-tri-co",
    "lustrín": "lus-trín",
    "lustrina": "lus-tri-na",
    "lustro": "lus-tro",
    "lustrosa": "lus-tro-sa",
    "lustrosamente": "lus-tro-sa-men-te",
    "lustroso": "lus-tro-so",
    "lutada": "lu-ta-da",
    "lutado": "lu-ta-do",
    "lútea": "lú-te-a",
    "lutecio": "lu-te-cio",
    "lúteo": "lú-te-o",
    "luterana": "lu-te-ra-na",
    "luteranismo": "lu-te-ra-nis-mo",
    "luterano": "lu-te-ra-no",
    "luthier": "lu-thier",
    "lutier": "lu-tier",
    "luto": "lu-to",
    "lutona": "lu-to-na",
    "lutosa": "lu-to-sa",
    "lutoso": "lu-to-so",
    "lutria": "lu-tria",
    "luvia": "lu-via",
    "luvita": "lu-vi-ta",
    "luxación": "lu-xa-ción",
    "luxar": "lu-xar",
    "luxemburgués": "lu-xem-bur-gués",
    "luxemburguesa": "lu-xem-bur-gue-sa",
    "luxómetro": "lu-xó-me-tro",
    "luzma": "luz-ma",
    "luzula": "lu-zu-la",
    "mabí": "ma-bí",
    "mabita": "ma-bi-ta",
    "mable": "ma-ble",
    "mabolo": "ma-bo-lo",
    "maca": "ma-ca",
    "macá": "ma-cá",
    "macabea": "ma-ca-be-a",
    "macabeo": "ma-ca-be-o",
    "macabí": "ma-ca-bí",
    "macabra": "ma-ca-bra",
    "macabro": "ma-ca-bro",
    "macaca": "ma-ca-ca",
    "macacada": "ma-ca-ca-da",
    "macachín": "ma-ca-chín",
    "macacinas": "ma-ca-ci-nas",
    "macaco": "ma-ca-co",
    "macacoa": "ma-ca-co-a",
    "macadam": "ma-ca-dam",
    "macadamizar": "ma-ca-da-mi-zar",
    "macadán": "ma-ca-dán",
    "macaense": "ma-ca-en-se",
    "macagua": "ma-ca-gua",
    "macagüita": "ma-ca-güi-ta",
    "macana": "ma-ca-na",
    "macanazo": "ma-ca-na-zo",
    "macanche": "ma-can-che",
    "macancoa": "ma-can-co-a",
    "macandón": "ma-can-dón",
    "macaneada": "ma-ca-ne-a-da",
    "macaneador": "ma-ca-ne-a-dor",
    "macaneadora": "ma-ca-ne-a-do-ra",
    "macanear": "ma-ca-ne-ar",
    "macaneo": "ma-ca-ne-o",
    "macanuda": "ma-ca-nu-da",
    "macanudez": "ma-ca-nu-dez",
    "macanudo": "ma-ca-nu-do",
    "macaoense": "ma-ca-o-en-se",
    "macaón": "ma-ca-ón",
    "macaquear": "ma-ca-que-ar",
    "macar": "ma-car",
    "macarela": "ma-ca-re-la",
    "macarelo": "ma-ca-re-lo",
    "macarena": "ma-ca-re-na",
    "macareno": "ma-ca-re-no",
    "macareo": "ma-ca-re-o",
    "macarra": "ma-ca-rra",
    "macarro": "ma-ca-rro",
    "macarrón": "ma-ca-rrón",
    "macarronea": "ma-ca-rro-ne-a",
    "macarrónica": "ma-ca-rró-ni-ca",
    "macarrónicamente": "ma-ca-rró-ni-ca-men-te",
    "macarrónico": "ma-ca-rró-ni-co",
    "macartismo": "ma-car-tis-mo",
    "macasar": "ma-ca-sar",
    "macaurel": "ma-cau-rel",
    "macazuchil": "ma-ca-zu-chil",
    "maceador": "ma-ce-a-dor",
    "macear": "ma-ce-ar",
    "macedón": "ma-ce-dón",
    "macedona": "ma-ce-do-na",
    "macedonia": "ma-ce-do-nia",
    "macedónica": "ma-ce-dó-ni-ca",
    "macedónico": "ma-ce-dó-ni-co",
    "macedonio": "ma-ce-do-nio",
    "macegual": "ma-ce-gual",
    "macehual": "ma-ce-hual",
    "macelo": "ma-ce-lo",
    "maceo": "ma-ce-o",
    "maceración": "ma-ce-ra-ción",
    "maceramiento": "ma-ce-ra-mien-to",
    "macerar": "ma-ce-rar",
    "macerina": "ma-ce-ri-na",
    "macero": "ma-ce-ro",
    "maceta": "ma-ce-ta",
    "macetazo": "ma-ce-ta-zo",
    "maceteado": "ma-ce-te-a-do",
    "macetera": "ma-ce-te-ra",
    "macetero": "ma-ce-te-ro",
    "macetilla": "ma-ce-ti-lla",
    "macetón": "ma-ce-tón",
    "macetuda": "ma-ce-tu-da",
    "macetudo": "ma-ce-tu-do",
    "macfarlán": "mac-far-lán",
    "macferlán": "mac-fer-lán",
    "macha": "ma-cha",
    "machaca": "ma-cha-ca",
    "machacadera": "ma-cha-ca-de-ra",
    "machacado": "ma-cha-ca-do",
    "machacador": "ma-cha-ca-dor",
    "machacadora": "ma-cha-ca-do-ra",
    "machacadura": "ma-cha-ca-du-ra",
    "machacante": "ma-cha-can-te",
    "machacar": "ma-cha-car",
    "machacón": "ma-cha-cón",
    "machacona": "ma-cha-co-na",
    "machaconería": "ma-cha-co-ne-rí-a",
    "machada": "ma-cha-da",
    "machadiano": "ma-cha-dia-no",
    "machado": "ma-cha-do",
    "machaje": "ma-cha-je",
    "machalera": "ma-cha-le-ra",
    "machalero": "ma-cha-le-ro",
    "machamartillo": "ma-cha-mar-ti-llo",
    "machanga": "ma-chan-ga",
    "machaque": "ma-cha-que",
    "machaqueo": "ma-cha-que-o",
    "machaquera": "ma-cha-que-ra",
    "machaquería": "ma-cha-que-rí-a",
    "machaquero": "ma-cha-que-ro",
    "machar": "ma-char",
    "machazo": "ma-cha-zo",
    "machear": "ma-che-ar",
    "machenque": "ma-chen-que",
    "machepa": "ma-che-pa",
    "machera": "ma-che-ra",
    "machero": "ma-che-ro",
    "macheta": "ma-che-ta",
    "machetazo": "ma-che-ta-zo",
    "machete": "ma-che-te",
    "macheteadera": "ma-che-te-a-de-ra",
    "machetear": "ma-che-te-ar",
    "machetera": "ma-che-te-ra",
    "machetero": "ma-che-te-ro",
    "machi": "ma-chi",
    "machía": "ma-chí-a",
    "máchica": "má-chi-ca",
    "machicha": "ma-chi-cha",
    "machiega": "ma-chie-ga",
    "machigua": "ma-chi-gua",
    "machigüe": "ma-chi-güe",
    "machihembrado": "ma-chihem-bra-do",
    "machihembrar": "ma-chihem-brar",
    "machín": "ma-chín",
    "machina": "ma-chi-na",
    "machincuepa": "ma-chin-cue-pa",
    "machío": "ma-chí-o",
    "machismo": "ma-chis-mo",
    "machista": "ma-chis-ta",
    "machito": "ma-chi-to",
    "machitún": "ma-chi-tún",
    "macho": "ma-cho",
    "machón": "ma-chón",
    "machona": "ma-cho-na",
    "machorra": "ma-cho-rra",
    "machorro": "ma-cho-rro",
    "machota": "ma-cho-ta",
    "machote": "ma-cho-te",
    "machucador": "ma-chu-ca-dor",
    "machucadora": "ma-chu-ca-do-ra",
    "machucadura": "ma-chu-ca-du-ra",
    "machucamiento": "ma-chu-ca-mien-to",
    "machucante": "ma-chu-can-te",
    "machucar": "ma-chu-car",
    "machucha": "ma-chu-cha",
    "machucho": "ma-chu-cho",
    "machucón": "ma-chu-cón",
    "machuelo": "ma-chue-lo",
    "machuna": "ma-chu-na",
    "machuno": "ma-chu-no",
    "machuquillo": "ma-chu-qui-llo",
    "machurar": "ma-chu-rar",
    "macia": "ma-cia",
    "macicez": "ma-ci-cez",
    "maciega": "ma-cie-ga",
    "macilenta": "ma-ci-len-ta",
    "macilento": "ma-ci-len-to",
    "macillo": "ma-ci-llo",
    "macío": "ma-cí-o",
    "macis": "ma-cis",
    "maciza": "ma-ci-za",
    "macizamente": "ma-ci-za-men-te",
    "macizar": "ma-ci-zar",
    "macizo": "ma-ci-zo",
    "macla": "ma-cla",
    "maclado": "ma-cla-do",
    "maco": "ma-co",
    "macoca": "ma-co-ca",
    "macolla": "ma-co-lla",
    "macollar": "ma-co-llar",
    "macollo": "ma-co-llo",
    "macón": "ma-cón",
    "macona": "ma-co-na",
    "macondo": "ma-con-do",
    "maconear": "ma-co-ne-ar",
    "macopa": "ma-co-pa",
    "macramé": "ma-cra-mé",
    "macro": "ma-cro",
    "macrobiótica": "ma-cro-bió-ti-ca",
    "macrobiótico": "ma-cro-bió-ti-co",
    "macrocéfala": "ma-cro-cé-fa-la",
    "macrocefalia": "ma-cro-ce-fa-lia",
    "macrocéfalo": "ma-cro-cé-fa-lo",
    "macroconcierto": "ma-cro-con-cier-to",
    "macrocosmo": "ma-cro-cos-mo",
    "macrocosmos": "ma-cro-cos-mos",
    "macroeconomía": "ma-cro-e-co-no-mí-a",
    "macroeconómico": "ma-cro-e-co-nó-mi-co",
    "macroestructura": "ma-cro-es-truc-tu-ra",
    "macrófago": "ma-cró-fa-go",
    "macrofotografía": "ma-cro-fo-to-gra-fí-a",
    "macrogameto": "ma-cro-ga-me-to",
    "macroinstrucción": "ma-croins-truc-ción",
    "macromolécula": "ma-cro-mo-lé-cu-la",
    "macromolecular": "ma-cro-mo-le-cu-lar",
    "macroscópica": "ma-cros-có-pi-ca",
    "macroscópico": "ma-cros-có-pi-co",
    "macrospora": "ma-cros-po-ra",
    "macrosporofila": "ma-cros-po-ro-fi-la",
    "macrostomía": "ma-cros-to-mí-a",
    "macrura": "ma-cru-ra",
    "macruro": "ma-cru-ro",
    "macsura": "mac-su-ra",
    "macuá": "ma-cuá",
    "macuache": "ma-cua-che",
    "macuba": "ma-cu-ba",
    "macuca": "ma-cu-ca",
    "macuco": "ma-cu-co",
    "macuelizo": "ma-cue-li-zo",
    "mácula": "má-cu-la",
    "macular": "ma-cu-lar",
    "maculatura": "ma-cu-la-tu-ra",
    "maculosa": "ma-cu-lo-sa",
    "maculoso": "ma-cu-lo-so",
    "macumba": "ma-cum-ba",
    "macundales": "ma-cun-da-les",
    "macuquero": "ma-cu-que-ro",
    "macuquina": "ma-cu-qui-na",
    "macuquino": "ma-cu-qui-no",
    "macutena": "ma-cu-te-na",
    "macuteno": "ma-cu-te-no",
    "macuto": "ma-cu-to",
    "madagaña": "ma-da-ga-ña",
    "madalena": "ma-da-le-na",
    "madama": "ma-da-ma",
    "madame": "ma-da-me",
    "madamisela": "ma-da-mi-se-la",
    "madapolán": "ma-da-po-lán",
    "madefacción": "ma-de-fac-ción",
    "madeira": "ma-dei-ra",
    "madeja": "ma-de-ja",
    "madera": "ma-de-ra",
    "maderable": "ma-de-ra-ble",
    "maderación": "ma-de-ra-ción",
    "maderada": "ma-de-ra-da",
    "maderaje": "ma-de-ra-je",
    "maderamen": "ma-de-ra-men",
    "maderamiento": "ma-de-ra-mien-to",
    "maderar": "ma-de-rar",
    "maderera": "ma-de-re-ra",
    "maderería": "ma-de-re-rí-a",
    "maderero": "ma-de-re-ro",
    "maderiense": "ma-de-rien-se",
    "maderismo": "ma-de-ris-mo",
    "maderista": "ma-de-ris-ta",
    "madero": "ma-de-ro",
    "madi": "ma-di",
    "madianita": "ma-dia-ni-ta",
    "madona": "ma-do-na",
    "mador": "ma-dor",
    "madorosa": "ma-do-ro-sa",
    "madoroso": "ma-do-ro-so",
    "madrás": "ma-drás",
    "madrastra": "ma-dras-tra",
    "madraza": "ma-dra-za",
    "madrazo": "ma-dra-zo",
    "madre": "ma-dre",
    "madreado": "ma-dre-a-do",
    "madrear": "ma-dre-ar",
    "madrearse": "ma-dre-ar-se",
    "madrecacao": "ma-dre-ca-ca-o",
    "madrecilla": "ma-dre-ci-lla",
    "madreclavo": "ma-dre-cla-vo",
    "madrediosina": "ma-dre-dio-si-na",
    "madrediosino": "ma-dre-dio-si-no",
    "madrejón": "ma-dre-jón",
    "madreña": "ma-dre-ña",
    "madreperla": "ma-dre-per-la",
    "madrépora": "ma-dré-po-ra",
    "madreporario": "ma-dre-po-ra-rio",
    "madrepórica": "ma-dre-pó-ri-ca",
    "madrepórico": "ma-dre-pó-ri-co",
    "madrera": "ma-dre-ra",
    "madrero": "ma-dre-ro",
    "madreselva": "ma-dre-sel-va",
    "madridista": "ma-dri-dis-ta",
    "madrigada": "ma-dri-ga-da",
    "madrigado": "ma-dri-ga-do",
    "madrigal": "ma-dri-gal",
    "madrigalesca": "ma-dri-ga-les-ca",
    "madrigalesco": "ma-dri-ga-les-co",
    "madrigalista": "ma-dri-ga-lis-ta",
    "madrigalizar": "ma-dri-ga-li-zar",
    "madriguera": "ma-dri-gue-ra",
    "madrileña": "ma-dri-le-ña",
    "madrileñismo": "ma-dri-le-ñis-mo",
    "madrileñista": "ma-dri-le-ñis-ta",
    "madrileño": "ma-dri-le-ño",
    "madrilla": "ma-dri-lla",
    "madrillera": "ma-dri-lle-ra",
    "madrina": "ma-dri-na",
    "madrinazgo": "ma-dri-naz-go",
    "madrinera": "ma-dri-ne-ra",
    "madrinero": "ma-dri-ne-ro",
    "madriz": "ma-driz",
    "madriza": "ma-dri-za",
    "madrona": "ma-dro-na",
    "madroñal": "ma-dro-ñal",
    "madroncillo": "ma-dron-ci-llo",
    "madroñera": "ma-dro-ñe-ra",
    "madroñero": "ma-dro-ñe-ro",
    "madroño": "ma-dro-ño",
    "madrota": "ma-dro-ta",
    "madrugada": "ma-dru-ga-da",
    "madrugador": "ma-dru-ga-dor",
    "madrugadora": "ma-dru-ga-do-ra",
    "madrugar": "ma-dru-gar",
    "madrugón": "ma-dru-gón",
    "madrugona": "ma-dru-go-na",
    "madrugonazo": "ma-dru-go-na-zo",
    "madruguera": "ma-dru-gue-ra",
    "madruguero": "ma-dru-gue-ro",
    "madura": "ma-du-ra",
    "maduración": "ma-du-ra-ción",
    "maduradero": "ma-du-ra-de-ro",
    "madurador": "ma-du-ra-dor",
    "maduradora": "ma-du-ra-do-ra",
    "maduramente": "ma-du-ra-men-te",
    "maduramiento": "ma-du-ra-mien-to",
    "madurar": "ma-du-rar",
    "madurativa": "ma-du-ra-ti-va",
    "madurativo": "ma-du-ra-ti-vo",
    "madurazón": "ma-du-ra-zón",
    "madurez": "ma-du-rez",
    "madureza": "ma-du-re-za",
    "maduro": "ma-du-ro",
    "maeña": "ma-e-ña",
    "maeño": "ma-e-ño",
    "maesa": "ma-e-sa",
    "maese": "ma-e-se",
    "maesil": "ma-e-sil",
    "maesilla": "ma-e-si-lla",
    "maeso": "ma-e-so",
    "maestra": "ma-es-tra",
    "maestrada": "ma-es-tra-da",
    "maestradamente": "ma-es-tra-da-men-te",
    "maestradgo": "ma-es-trad-go",
    "maestrado": "ma-es-tra-do",
    "maestraje": "ma-es-tra-je",
    "maestral": "ma-es-tral",
    "maestralizar": "ma-es-tra-li-zar",
    "maestramente": "ma-es-tra-men-te",
    "maestrante": "ma-es-tran-te",
    "maestranza": "ma-es-tran-za",
    "maestrar": "ma-es-trar",
    "maestrazgo": "ma-es-traz-go",
    "maestre": "ma-es-tre",
    "maestrear": "ma-es-tre-ar",
    "maestreescuela": "ma-es-tre-es-cue-la",
    "maestrejicomar": "ma-es-tre-ji-co-mar",
    "maestrepasquín": "ma-es-tre-pas-quín",
    "maestresa": "ma-es-tre-sa",
    "maestresala": "ma-es-tre-sa-la",
    "maestrescolía": "ma-es-tres-co-lí-a",
    "maestrescuela": "ma-es-tres-cue-la",
    "maestría": "ma-es-trí-a",
    "maestril": "ma-es-tril",
    "maestro": "ma-es-tro",
    "mafia": "ma-fia",
    "mafiosa": "ma-fio-sa",
    "mafioso": "ma-fio-so",
    "mafle": "ma-fle",
    "mafufa": "ma-fu-fa",
    "mafufo": "ma-fu-fo",
    "maga": "ma-ga",
    "magacén": "ma-ga-cén",
    "magacín": "ma-ga-cín",
    "magalla": "ma-ga-lla",
    "magallánica": "ma-ga-llá-ni-ca",
    "magallánico": "ma-ga-llá-ni-co",
    "magaña": "ma-ga-ña",
    "magancear": "ma-gan-ce-ar",
    "magancería": "ma-gan-ce-rí-a",
    "magancés": "ma-gan-cés",
    "maganel": "ma-ga-nel",
    "magañosa": "ma-ga-ño-sa",
    "magañoso": "ma-ga-ño-so",
    "maganta": "ma-gan-ta",
    "maganto": "ma-gan-to",
    "maganzón": "ma-gan-zón",
    "maganzona": "ma-gan-zo-na",
    "magarza": "ma-gar-za",
    "magarzuela": "ma-gar-zue-la",
    "magaya": "ma-ga-ya",
    "magazín": "ma-ga-zín",
    "magazine": "ma-ga-zi-ne",
    "magdalena": "mag-da-le-na",
    "magdalenense": "mag-da-le-nen-se",
    "magdalénico": "mag-da-lé-ni-co",
    "magdaleniense": "mag-da-le-nien-se",
    "magdaleón": "mag-da-le-ón",
    "magenta": "ma-gen-ta",
    "magia": "ma-gia",
    "magiar": "ma-giar",
    "mágica": "má-gi-ca",
    "mágicamente": "má-gi-ca-men-te",
    "mágico": "má-gi-co",
    "magín": "ma-gín",
    "maginar": "ma-gi-nar",
    "magíster": "ma-gís-ter",
    "magisterial": "ma-gis-te-rial",
    "magisterio": "ma-gis-te-rio",
    "magistrada": "ma-gis-tra-da",
    "magistrado": "ma-gis-tra-do",
    "magistral": "ma-gis-tral",
    "magistralía": "ma-gis-tra-lí-a",
    "magistralmente": "ma-gis-tral-men-te",
    "magistratura": "ma-gis-tra-tu-ra",
    "magma": "mag-ma",
    "magmático": "mag-má-ti-co",
    "magmatismo": "mag-ma-tis-mo",
    "magna": "mag-na",
    "magnánima": "mag-ná-ni-ma",
    "magnánimamente": "mag-ná-ni-ma-men-te",
    "magnanimidad": "mag-na-ni-mi-dad",
    "magnánimo": "mag-ná-ni-mo",
    "magnate": "mag-na-te",
    "magnavoz": "mag-na-voz",
    "magnesia": "mag-ne-sia",
    "magnesiana": "mag-ne-sia-na",
    "magnesiano": "mag-ne-sia-no",
    "magnésica": "mag-né-si-ca",
    "magnésico": "mag-né-si-co",
    "magnesio": "mag-ne-sio",
    "magnesiotermia": "mag-ne-sio-ter-mia",
    "magnesita": "mag-ne-si-ta",
    "magnética": "mag-né-ti-ca",
    "magnético": "mag-né-ti-co",
    "magnetismo": "mag-ne-tis-mo",
    "magnetita": "mag-ne-ti-ta",
    "magnetizable": "mag-ne-ti-za-ble",
    "magnetización": "mag-ne-ti-za-ción",
    "magnetizador": "mag-ne-ti-za-dor",
    "magnetizadora": "mag-ne-ti-za-do-ra",
    "magnetizar": "mag-ne-ti-zar",
    "magneto": "mag-ne-to",
    "magnetocalórico": "mag-ne-to-ca-ló-ri-co",
    "magnetoeléctrico": "mag-ne-to-e-léc-tri-co",
    "magnetofón": "mag-ne-to-fón",
    "magnetofónico": "mag-ne-to-fó-ni-co",
    "magnetófono": "mag-ne-tó-fo-no",
    "magnetohidrodinámica": "mag-ne-tohi-dro-di-ná-mi-ca",
    "magnetómetro": "mag-ne-tó-me-tro",
    "magnetoóptica": "mag-ne-to-óp-ti-ca",
    "magnetopausa": "mag-ne-to-pau-sa",
    "magnetorresistencia": "mag-ne-to-rre-sis-ten-cia",
    "magnetoscopio": "mag-ne-tos-co-pio",
    "magnetosfera": "mag-ne-tos-fe-ra",
    "magnetósfera": "mag-ne-tós-fe-ra",
    "magnetostática": "mag-ne-tos-tá-ti-ca",
    "magnetostricción": "mag-ne-tos-tric-ción",
    "magnetoterapia": "mag-ne-to-te-ra-pia",
    "magnetrón": "mag-ne-trón",
    "magnicida": "mag-ni-ci-da",
    "magnicidio": "mag-ni-ci-dio",
    "magnífica": "mag-ní-fi-ca",
    "magnificador": "mag-ni-fi-ca-dor",
    "magnificadora": "mag-ni-fi-ca-do-ra",
    "magníficamente": "mag-ní-fi-ca-men-te",
    "magnificar": "mag-ni-fi-car",
    "magníficat": "mag-ní-fi-cat",
    "magnificencia": "mag-ni-fi-cen-cia",
    "magnificente": "mag-ni-fi-cen-te",
    "magnificentísimo": "mag-ni-fi-cen-tí-si-mo",
    "magnífico": "mag-ní-fi-co",
    "magnílocua": "mag-ní-lo-cua",
    "magnílocuo": "mag-ní-lo-cuo",
    "magnitud": "mag-ni-tud",
    "magno": "mag-no",
    "magnolia": "mag-no-lia",
    "magnoliácea": "mag-no-liá-ce-a",
    "magnoliáceas": "mag-no-liá-ce-as",
    "magnoliáceo": "mag-no-liá-ce-o",
    "magnolio": "mag-no-lio",
    "mago": "ma-go",
    "magolla": "ma-go-lla",
    "magosta": "ma-gos-ta",
    "magostar": "ma-gos-tar",
    "magosto": "ma-gos-to",
    "magra": "ma-gra",
    "magrear": "ma-gre-ar",
    "magrebí": "ma-gre-bí",
    "magrecer": "ma-gre-cer",
    "magreo": "ma-gre-o",
    "magrez": "ma-grez",
    "magro": "ma-gro",
    "magrura": "ma-gru-ra",
    "magua": "ma-gua",
    "maguar": "ma-guar",
    "magué": "ma-gué",
    "maguer": "ma-guer",
    "maguera": "ma-gue-ra",
    "magüeta": "ma-güe-ta",
    "magüeto": "ma-güe-to",
    "maguey": "ma-guey",
    "magueyal": "ma-gue-yal",
    "magueyera": "ma-gue-ye-ra",
    "maguillo": "ma-gui-llo",
    "magujo": "ma-gu-jo",
    "maguladura": "ma-gu-la-du-ra",
    "magular": "ma-gu-lar",
    "magullada": "ma-gu-lla-da",
    "magullado": "ma-gu-lla-do",
    "magulladura": "ma-gu-lla-du-ra",
    "magullamiento": "ma-gu-lla-mien-to",
    "magullar": "ma-gu-llar",
    "magullón": "ma-gu-llón",
    "maguntina": "ma-gun-ti-na",
    "maguntino": "ma-gun-ti-no",
    "maharajá": "ma-ha-ra-já",
    "maharaní": "ma-ha-ra-ní",
    "maharón": "ma-ha-rón",
    "maharona": "ma-ha-ro-na",
    "maharrana": "ma-ha-rra-na",
    "mahatma": "ma-hat-ma",
    "maherimiento": "ma-he-ri-mien-to",
    "maherir": "ma-he-rir",
    "mahleriana": "mah-le-ria-na",
    "mahleriano": "mah-le-ria-no",
    "mahometana": "ma-ho-me-ta-na",
    "mahometano": "ma-ho-me-ta-no",
    "mahomética": "ma-ho-mé-ti-ca",
    "mahomético": "ma-ho-mé-ti-co",
    "mahometismo": "ma-ho-me-tis-mo",
    "mahometista": "ma-ho-me-tis-ta",
    "mahometizar": "ma-ho-me-ti-zar",
    "mahomía": "ma-ho-mí-a",
    "mahomista": "ma-ho-mis-ta",
    "mahón": "ma-hón",
    "mahona": "ma-ho-na",
    "mahonés": "ma-ho-nés",
    "mahonesa": "ma-ho-ne-sa",
    "mahozmedín": "ma-hoz-me-dín",
    "maiceado": "mai-ce-a-do",
    "maicear": "mai-ce-ar",
    "maicena": "mai-ce-na",
    "maicera": "mai-ce-ra",
    "maicería": "mai-ce-rí-a",
    "maicero": "mai-ce-ro",
    "maicillo": "mai-ci-llo",
    "maído": "ma-í-do",
    "mailing": "mai-ling",
    "maílla": "ma-í-lla",
    "maíllo": "ma-í-llo",
    "maillot": "mai-llot",
    "maimón": "mai-món",
    "maimonismo": "mai-mo-nis-mo",
    "mainel": "mai-nel",
    "maipina": "mai-pi-na",
    "maipino": "mai-pi-no",
    "maistate": "mais-ta-te",
    "maitén": "mai-tén",
    "maitencito": "mai-ten-ci-to",
    "maitinada": "mai-ti-na-da",
    "maitinante": "mai-ti-nan-te",
    "maitines": "mai-ti-nes",
    "maíz": "ma-íz",
    "maizal": "mai-zal",
    "maja": "ma-ja",
    "majá": "ma-já",
    "majada": "ma-ja-da",
    "majadal": "ma-ja-dal",
    "majadear": "ma-ja-de-ar",
    "majadera": "ma-ja-de-ra",
    "majaderear": "ma-ja-de-re-ar",
    "majadería": "ma-ja-de-rí-a",
    "majaderico": "ma-ja-de-ri-co",
    "majaderillo": "ma-ja-de-ri-llo",
    "majaderito": "ma-ja-de-ri-to",
    "majadero": "ma-ja-de-ro",
    "majado": "ma-ja-do",
    "majador": "ma-ja-dor",
    "majadora": "ma-ja-do-ra",
    "majadura": "ma-ja-du-ra",
    "majagranzas": "ma-ja-gran-zas",
    "majagua": "ma-ja-gua",
    "majagual": "ma-ja-gual",
    "majagüero": "ma-ja-güe-ro",
    "majal": "ma-jal",
    "majamama": "ma-ja-ma-ma",
    "majamiento": "ma-ja-mien-to",
    "majano": "ma-ja-no",
    "majar": "ma-jar",
    "majara": "ma-ja-ra",
    "majareta": "ma-ja-re-ta",
    "majarete": "ma-ja-re-te",
    "majasear": "ma-ja-se-ar",
    "maje": "ma-je",
    "majear": "ma-je-ar",
    "majencia": "ma-jen-cia",
    "majería": "ma-je-rí-a",
    "majestad": "ma-jes-tad",
    "majestosa": "ma-jes-to-sa",
    "majestoso": "ma-jes-to-so",
    "majestuosa": "ma-jes-tuo-sa",
    "majestuosamente": "ma-jes-tuo-sa-men-te",
    "majestuosidad": "ma-jes-tuo-si-dad",
    "majestuoso": "ma-jes-tuo-so",
    "majeza": "ma-je-za",
    "majiadero": "ma-jia-de-ro",
    "majo": "ma-jo",
    "majolar": "ma-jo-lar",
    "majoleta": "ma-jo-le-ta",
    "majoleto": "ma-jo-le-to",
    "majorana": "ma-jo-ra-na",
    "majorca": "ma-jor-ca",
    "majorera": "ma-jo-re-ra",
    "majorero": "ma-jo-re-ro",
    "majuela": "ma-jue-la",
    "majuelo": "ma-jue-lo",
    "majunche": "ma-jun-che",
    "majzén": "maj-zén",
    "mala": "ma-la",
    "malabar": "ma-la-bar",
    "malabárica": "ma-la-bá-ri-ca",
    "malabárico": "ma-la-bá-ri-co",
    "malabarismo": "ma-la-ba-ris-mo",
    "malabarista": "ma-la-ba-ris-ta",
    "malacara": "ma-la-ca-ra",
    "malacate": "ma-la-ca-te",
    "malacatoso": "ma-la-ca-to-so",
    "malacia": "ma-la-cia",
    "malacitana": "ma-la-ci-ta-na",
    "malacitano": "ma-la-ci-ta-no",
    "malacología": "ma-la-co-lo-gí-a",
    "malacológica": "ma-la-co-ló-gi-ca",
    "malacológico": "ma-la-co-ló-gi-co",
    "malaconsejada": "ma-la-con-se-ja-da",
    "malaconsejado": "ma-la-con-se-ja-do",
    "malacopterigio": "ma-la-cop-te-ri-gio",
    "malacostráceo": "ma-la-cos-trá-ce-o",
    "malacostumbrada": "ma-la-cos-tum-bra-da",
    "malacostumbrado": "ma-la-cos-tum-bra-do",
    "malacostumbrar": "ma-la-cos-tum-brar",
    "malacrianza": "ma-la-crian-za",
    "malacuenda": "ma-la-cuen-da",
    "malaestanza": "ma-la-es-tan-za",
    "malafa": "ma-la-fa",
    "málaga": "má-la-ga",
    "malagana": "ma-la-ga-na",
    "malagradecida": "ma-la-gra-de-ci-da",
    "malagradecido": "ma-la-gra-de-ci-do",
    "malagueña": "ma-la-gue-ña",
    "malagueño": "ma-la-gue-ño",
    "malagués": "ma-la-gués",
    "malaguesa": "ma-la-gue-sa",
    "malagueta": "ma-la-gue-ta",
    "malaire": "ma-lai-re",
    "malaisia": "ma-lai-sia",
    "malaisio": "ma-lai-sio",
    "malaje": "ma-la-je",
    "malaleche": "ma-la-le-che",
    "malambo": "ma-lam-bo",
    "malamente": "ma-la-men-te",
    "malamistado": "ma-la-mis-ta-do",
    "malamujer": "ma-la-mu-jer",
    "malamute": "ma-la-mu-te",
    "malandante": "ma-lan-dan-te",
    "malandanza": "ma-lan-dan-za",
    "malandar": "ma-lan-dar",
    "malandra": "ma-lan-dra",
    "malandrín": "ma-lan-drín",
    "malandrina": "ma-lan-dri-na",
    "malandro": "ma-lan-dro",
    "malanga": "ma-lan-ga",
    "malangay": "ma-lan-gay",
    "malange": "ma-lan-ge",
    "malanochar": "ma-la-no-char",
    "malapata": "ma-la-pa-ta",
    "malaquita": "ma-la-qui-ta",
    "malar": "ma-lar",
    "malaria": "ma-la-ria",
    "malarrabia": "ma-la-rra-bia",
    "malasangre": "ma-la-san-gre",
    "malasia": "ma-la-sia",
    "malasio": "ma-la-sio",
    "malasombra": "ma-la-som-bra",
    "malata": "ma-la-ta",
    "malatería": "ma-la-te-rí-a",
    "malatía": "ma-la-tí-a",
    "malato": "ma-la-to",
    "malatoba": "ma-la-to-ba",
    "malatobo": "ma-la-to-bo",
    "malatraza": "ma-la-tra-za",
    "malauiana": "ma-lauia-na",
    "malauiano": "ma-lauia-no",
    "malaúva": "ma-la-ú-va",
    "malavenida": "ma-la-ve-ni-da",
    "malavenido": "ma-la-ve-ni-do",
    "malaventura": "ma-la-ven-tu-ra",
    "malaventurada": "ma-la-ven-tu-ra-da",
    "malaventurado": "ma-la-ven-tu-ra-do",
    "malaventuranza": "ma-la-ven-tu-ran-za",
    "malavés": "ma-la-vés",
    "malavez": "ma-la-vez",
    "malaviana": "ma-la-via-na",
    "malaviano": "ma-la-via-no",
    "malawiana": "ma-la-wia-na",
    "malawiano": "ma-la-wia-no",
    "malaya": "ma-la-ya",
    "malayo": "ma-la-yo",
    "malayopolinesio": "ma-la-yo-po-li-ne-sio",
    "malbaratador": "mal-ba-ra-ta-dor",
    "malbaratadora": "mal-ba-ra-ta-do-ra",
    "malbaratar": "mal-ba-ra-tar",
    "malbaratillo": "mal-ba-ra-ti-llo",
    "malbarato": "mal-ba-ra-to",
    "malcarada": "mal-ca-ra-da",
    "malcarado": "mal-ca-ra-do",
    "malcasada": "mal-ca-sa-da",
    "malcasado": "mal-ca-sa-do",
    "malcasar": "mal-ca-sar",
    "malcaso": "mal-ca-so",
    "malcocinado": "mal-co-ci-na-do",
    "malcomer": "mal-co-mer",
    "malcomida": "mal-co-mi-da",
    "malcomido": "mal-co-mi-do",
    "malconsiderada": "mal-con-si-de-ra-da",
    "malconsiderado": "mal-con-si-de-ra-do",
    "malcontenta": "mal-con-ten-ta",
    "malcontentadiza": "mal-con-ten-ta-di-za",
    "malcontentadizo": "mal-con-ten-ta-di-zo",
    "malcontento": "mal-con-ten-to",
    "malcoraje": "mal-co-ra-je",
    "malcorte": "mal-cor-te",
    "malcreer": "mal-cre-er",
    "malcriada": "mal-cria-da",
    "malcriadez": "mal-cria-dez",
    "malcriadeza": "mal-cria-de-za",
    "malcriado": "mal-cria-do",
    "malcriar": "mal-criar",
    "maldad": "mal-dad",
    "maldadosa": "mal-da-do-sa",
    "maldadosamente": "mal-da-do-sa-men-te",
    "maldadoso": "mal-da-do-so",
    "maldecida": "mal-de-ci-da",
    "maldecido": "mal-de-ci-do",
    "maldecidor": "mal-de-ci-dor",
    "maldecidora": "mal-de-ci-do-ra",
    "maldecimiento": "mal-de-ci-mien-to",
    "maldecir": "mal-de-cir",
    "maldiciente": "mal-di-cien-te",
    "maldicientemente": "mal-di-cien-te-men-te",
    "maldición": "mal-di-ción",
    "maldispuesta": "mal-dis-pues-ta",
    "maldispuesto": "mal-dis-pues-to",
    "maldita": "mal-di-ta",
    "malditamente": "mal-di-ta-men-te",
    "malditismo": "mal-di-tis-mo",
    "maldito": "mal-di-to",
    "maldiva": "mal-di-va",
    "maldivo": "mal-di-vo",
    "maldosa": "mal-do-sa",
    "maldoso": "mal-do-so",
    "maleabilidad": "ma-le-a-bi-li-dad",
    "maleable": "ma-le-a-ble",
    "maleador": "ma-le-a-dor",
    "maleadora": "ma-le-a-do-ra",
    "maleante": "ma-le-an-te",
    "malear": "ma-le-ar",
    "malecón": "ma-le-cón",
    "maledicencia": "ma-le-di-cen-cia",
    "maleducada": "ma-le-du-ca-da",
    "maleducado": "ma-le-du-ca-do",
    "maleducar": "ma-le-du-car",
    "maléfica": "ma-lé-fi-ca",
    "maleficencia": "ma-le-fi-cen-cia",
    "maleficiar": "ma-le-fi-ciar",
    "maleficio": "ma-le-fi-cio",
    "maléfico": "ma-lé-fi-co",
    "malencarado": "ma-len-ca-ra-do",
    "malencolía": "ma-len-co-lí-a",
    "malencólica": "ma-len-có-li-ca",
    "malencólico": "ma-len-có-li-co",
    "malenconía": "ma-len-co-ní-a",
    "malencónica": "ma-len-có-ni-ca",
    "malencónico": "ma-len-có-ni-co",
    "malenconiosa": "ma-len-co-nio-sa",
    "malenconioso": "ma-len-co-nio-so",
    "malenseñar": "ma-len-se-ñar",
    "malentender": "ma-len-ten-der",
    "malentendido": "ma-len-ten-di-do",
    "malentrada": "ma-len-tra-da",
    "malentretenida": "ma-len-tre-te-ni-da",
    "malentretenido": "ma-len-tre-te-ni-do",
    "maleolar": "ma-le-o-lar",
    "maléolo": "ma-lé-o-lo",
    "malero": "ma-le-ro",
    "malespín": "ma-les-pín",
    "malespino": "ma-les-pi-no",
    "malestar": "ma-les-tar",
    "maleta": "ma-le-ta",
    "maletera": "ma-le-te-ra",
    "maletero": "ma-le-te-ro",
    "maletía": "ma-le-tí-a",
    "maletilla": "ma-le-ti-lla",
    "maletín": "ma-le-tín",
    "maletón": "ma-le-tón",
    "maletudo": "ma-le-tu-do",
    "maleva": "ma-le-va",
    "malevaje": "ma-le-va-je",
    "malevo": "ma-le-vo",
    "malévola": "ma-lé-vo-la",
    "malévolamente": "ma-lé-vo-la-men-te",
    "malevolencia": "ma-le-vo-len-cia",
    "malevolente": "ma-le-vo-len-te",
    "malévolo": "ma-lé-vo-lo",
    "maleza": "ma-le-za",
    "malfacer": "mal-fa-cer",
    "malfadada": "mal-fa-da-da",
    "malfadado": "mal-fa-da-do",
    "malfecho": "mal-fe-cho",
    "malfechor": "mal-fe-chor",
    "malfetría": "mal-fe-trí-a",
    "malformación": "mal-for-ma-ción",
    "malgache": "mal-ga-che",
    "malgastador": "mal-gas-ta-dor",
    "malgastadora": "mal-gas-ta-do-ra",
    "malgastar": "mal-gas-tar",
    "malgeniado": "mal-ge-nia-do",
    "malgeniosa": "mal-ge-nio-sa",
    "malgenioso": "mal-ge-nio-so",
    "malgeniuda": "mal-ge-niu-da",
    "malgeniudo": "mal-ge-niu-do",
    "malhablada": "mal-ha-bla-da",
    "malhablado": "mal-ha-bla-do",
    "malhadada": "mal-ha-da-da",
    "malhadado": "mal-ha-da-do",
    "malhecha": "mal-he-cha",
    "malhecho": "mal-he-cho",
    "malhechor": "mal-he-chor",
    "malhechora": "mal-he-cho-ra",
    "malherido": "mal-he-ri-do",
    "malherir": "mal-he-rir",
    "malhojo": "mal-ho-jo",
    "malhora": "mal-ho-ra",
    "malhumor": "mal-hu-mor",
    "malhumorada": "mal-hu-mo-ra-da",
    "malhumoradamente": "mal-hu-mo-ra-da-men-te",
    "malhumorado": "mal-hu-mo-ra-do",
    "malhumorar": "mal-hu-mo-rar",
    "malí": "ma-lí",
    "malicia": "ma-li-cia",
    "maliciable": "ma-li-cia-ble",
    "maliciador": "ma-li-cia-dor",
    "maliciadora": "ma-li-cia-do-ra",
    "maliciar": "ma-li-ciar",
    "maliciosa": "ma-li-cio-sa",
    "maliciosamente": "ma-li-cio-sa-men-te",
    "malicioso": "ma-li-cio-so",
    "maliense": "ma-lien-se",
    "maligna": "ma-lig-na",
    "malignamente": "ma-lig-na-men-te",
    "malignar": "ma-lig-nar",
    "malignidad": "ma-lig-ni-dad",
    "malignizar": "ma-lig-ni-zar",
    "maligno": "ma-lig-no",
    "malilla": "ma-li-lla",
    "malina": "ma-li-na",
    "malinche": "ma-lin-che",
    "malinchismo": "ma-lin-chis-mo",
    "malinchista": "ma-lin-chis-ta",
    "malingrar": "ma-lin-grar",
    "malinké": "ma-lin-ké",
    "malino": "ma-li-no",
    "malintencionada": "ma-lin-ten-cio-na-da",
    "malintencionado": "ma-lin-ten-cio-na-do",
    "malinterpretar": "ma-lin-ter-pre-tar",
    "malla": "ma-lla",
    "malladar": "ma-lla-dar",
    "mallar": "ma-llar",
    "mallequina": "ma-lle-qui-na",
    "mallequino": "ma-lle-qui-no",
    "mallera": "ma-lle-ra",
    "mallero": "ma-lle-ro",
    "mallete": "ma-lle-te",
    "malleto": "ma-lle-to",
    "mallín": "ma-llín",
    "mallo": "ma-llo",
    "mallorca": "ma-llor-ca",
    "mallorquín": "ma-llor-quín",
    "mallorquina": "ma-llor-qui-na",
    "mallugar": "ma-llu-gar",
    "malmandada": "mal-man-da-da",
    "malmandado": "mal-man-da-do",
    "malmaridada": "mal-ma-ri-da-da",
    "malmarrienta": "mal-ma-rrien-ta",
    "malmarriento": "mal-ma-rrien-to",
    "malmatada": "mal-ma-ta-da",
    "malmatado": "mal-ma-ta-do",
    "malmatar": "mal-ma-tar",
    "malmatón": "mal-ma-tón",
    "malmeter": "mal-me-ter",
    "malmirada": "mal-mi-ra-da",
    "malmirado": "mal-mi-ra-do",
    "malmodear": "mal-mo-de-ar",
    "malmodienta": "mal-mo-dien-ta",
    "malmodiento": "mal-mo-dien-to",
    "malnacida": "mal-na-ci-da",
    "malnacido": "mal-na-ci-do",
    "malnutrición": "mal-nu-tri-ción",
    "malnutrido": "mal-nu-tri-do",
    "malo": "ma-lo",
    "maloca": "ma-lo-ca",
    "malogrado": "ma-lo-gra-do",
    "malogramiento": "ma-lo-gra-mien-to",
    "malograr": "ma-lo-grar",
    "malogro": "ma-lo-gro",
    "maloja": "ma-lo-ja",
    "malojal": "ma-lo-jal",
    "malojero": "ma-lo-je-ro",
    "malojo": "ma-lo-jo",
    "maloliente": "ma-lo-lien-te",
    "malón": "ma-lón",
    "maloquear": "ma-lo-que-ar",
    "maloquera": "ma-lo-que-ra",
    "maloquero": "ma-lo-que-ro",
    "malora": "ma-lo-ra",
    "maloso": "ma-lo-so",
    "malpaís": "mal-pa-ís",
    "malparada": "mal-pa-ra-da",
    "malparado": "mal-pa-ra-do",
    "malparanza": "mal-pa-ran-za",
    "malparar": "mal-pa-rar",
    "malparida": "mal-pa-ri-da",
    "malparido": "mal-pa-ri-do",
    "malparir": "mal-pa-rir",
    "malparto": "mal-par-to",
    "malpensada": "mal-pen-sa-da",
    "malpensado": "mal-pen-sa-do",
    "malpensar": "mal-pen-sar",
    "malpigiácea": "mal-pi-giá-ce-a",
    "malpigiáceo": "mal-pi-giá-ce-o",
    "malqueda": "mal-que-da",
    "malquerencia": "mal-que-ren-cia",
    "malquerer": "mal-que-rer",
    "malqueriente": "mal-que-rien-te",
    "malquista": "mal-quis-ta",
    "malquistar": "mal-quis-tar",
    "malquisto": "mal-quis-to",
    "malro": "mal-ro",
    "malrotador": "mal-ro-ta-dor",
    "malrotadora": "mal-ro-ta-do-ra",
    "malrotar": "mal-ro-tar",
    "malsana": "mal-sa-na",
    "malsanamente": "mal-sa-na-men-te",
    "malsano": "mal-sa-no",
    "malsín": "mal-sín",
    "malsinar": "mal-si-nar",
    "malsindad": "mal-sin-dad",
    "malsinería": "mal-si-ne-rí-a",
    "malsonancia": "mal-so-nan-cia",
    "malsonante": "mal-so-nan-te",
    "malsonar": "mal-so-nar",
    "malsufrida": "mal-su-fri-da",
    "malsufrido": "mal-su-fri-do",
    "malta": "mal-ta",
    "malteado": "mal-te-a-do",
    "maltear": "mal-te-ar",
    "maltés": "mal-tés",
    "maltesa": "mal-te-sa",
    "maltón": "mal-tón",
    "maltona": "mal-to-na",
    "maltosa": "mal-to-sa",
    "maltrabaja": "mal-tra-ba-ja",
    "maltraedor": "mal-tra-e-dor",
    "maltraedora": "mal-tra-e-do-ra",
    "maltraer": "mal-tra-er",
    "maltraído": "mal-tra-í-do",
    "maltrapillo": "mal-tra-pi-llo",
    "maltratador": "mal-tra-ta-dor",
    "maltratamiento": "mal-tra-ta-mien-to",
    "maltratar": "mal-tra-tar",
    "maltrato": "mal-tra-to",
    "maltrecha": "mal-tre-cha",
    "maltrecho": "mal-tre-cho",
    "maltusiana": "mal-tu-sia-na",
    "maltusianismo": "mal-tu-sia-nis-mo",
    "maltusiano": "mal-tu-sia-no",
    "maluca": "ma-lu-ca",
    "malucha": "ma-lu-cha",
    "malucho": "ma-lu-cho",
    "maluco": "ma-lu-co",
    "maluenda": "ma-luen-da",
    "malulo": "ma-lu-lo",
    "maluquencia": "ma-lu-quen-cia",
    "maluquera": "ma-lu-que-ra",
    "maluqueza": "ma-lu-que-za",
    "malura": "ma-lu-ra",
    "malva": "mal-va",
    "malvácea": "mal-vá-ce-a",
    "malváceas": "mal-vá-ce-as",
    "malváceo": "mal-vá-ce-o",
    "malvada": "mal-va-da",
    "malvadamente": "mal-va-da-men-te",
    "malvado": "mal-va-do",
    "malvar": "mal-var",
    "malvarrosa": "mal-va-rro-sa",
    "malvasía": "mal-va-sí-a",
    "malvavisco": "mal-va-vis-co",
    "malvender": "mal-ven-der",
    "malversación": "mal-ver-sa-ción",
    "malversador": "mal-ver-sa-dor",
    "malversadora": "mal-ver-sa-do-ra",
    "malversar": "mal-ver-sar",
    "malvezar": "mal-ve-zar",
    "malviento": "mal-vien-to",
    "malvinense": "mal-vi-nen-se",
    "malvinera": "mal-vi-ne-ra",
    "malvinero": "mal-vi-ne-ro",
    "malvís": "mal-vís",
    "malvisco": "mal-vis-co",
    "malviviente": "mal-vi-vien-te",
    "malvivir": "mal-vi-vir",
    "malviz": "mal-viz",
    "malvón": "mal-vón",
    "mama": "ma-ma",
    "mamá": "ma-má",
    "mamacallos": "ma-ma-ca-llos",
    "mamacona": "ma-ma-co-na",
    "mamada": "ma-ma-da",
    "mamadera": "ma-ma-de-ra",
    "mamado": "ma-ma-do",
    "mamador": "ma-ma-dor",
    "mamadora": "ma-ma-do-ra",
    "mamaíta": "ma-ma-í-ta",
    "mamalón": "ma-ma-lón",
    "mamancona": "ma-man-co-na",
    "mamandurria": "ma-man-du-rria",
    "mamante": "ma-man-te",
    "mamantón": "ma-man-tón",
    "mamantona": "ma-man-to-na",
    "mamar": "ma-mar",
    "mamaria": "ma-ma-ria",
    "mamario": "ma-ma-rio",
    "mamarón": "ma-ma-rón",
    "mamarrachada": "ma-ma-rra-cha-da",
    "mamarrachento": "ma-ma-rra-chen-to",
    "mamarrachero": "ma-ma-rra-che-ro",
    "mamarrachista": "ma-ma-rra-chis-ta",
    "mamarracho": "ma-ma-rra-cho",
    "mambí": "mam-bí",
    "mambís": "mam-bís",
    "mambisa": "mam-bi-sa",
    "mambla": "mam-bla",
    "mambo": "mam-bo",
    "mambrú": "mam-brú",
    "mame": "ma-me",
    "mamella": "ma-me-lla",
    "mamellada": "ma-me-lla-da",
    "mamellado": "ma-me-lla-do",
    "mamelón": "ma-me-lón",
    "mamelonada": "ma-me-lo-na-da",
    "mamelonado": "ma-me-lo-na-do",
    "mameluco": "ma-me-lu-co",
    "mamerta": "ma-mer-ta",
    "mamerto": "ma-mer-to",
    "mamey": "ma-mey",
    "mameyal": "ma-me-yal",
    "mameyero": "ma-me-ye-ro",
    "mamía": "ma-mí-a",
    "mamífero": "ma-mí-fe-ro",
    "mamiforme": "ma-mi-for-me",
    "mamila": "ma-mi-la",
    "mamilar": "ma-mi-lar",
    "mamita": "ma-mi-ta",
    "mamitis": "ma-mi-tis",
    "mamo": "ma-mo",
    "mamografía": "ma-mo-gra-fí-a",
    "mamógrafo": "ma-mó-gra-fo",
    "mamola": "ma-mo-la",
    "mamón": "ma-món",
    "mamona": "ma-mo-na",
    "mamoncillo": "ma-mon-ci-llo",
    "mamonear": "ma-mo-ne-ar",
    "mamoplastia": "ma-mo-plas-tia",
    "mamosa": "ma-mo-sa",
    "mamoso": "ma-mo-so",
    "mamotreto": "ma-mo-tre-to",
    "mampara": "mam-pa-ra",
    "mamparar": "mam-pa-rar",
    "mamparra": "mam-pa-rra",
    "mampastor": "mam-pas-tor",
    "mampata": "mam-pa-ta",
    "mampato": "mam-pa-to",
    "mamperlán": "mam-per-lán",
    "mampesada": "mam-pe-sa-da",
    "mampesadilla": "mam-pe-sa-di-lla",
    "mampirlán": "mam-pir-lán",
    "mamplora": "mam-plo-ra",
    "mamporrero": "mam-po-rre-ro",
    "mamporro": "mam-po-rro",
    "mampostear": "mam-pos-te-ar",
    "mampostería": "mam-pos-te-rí-a",
    "mampostero": "mam-pos-te-ro",
    "mampresar": "mam-pre-sar",
    "mampuesta": "mam-pues-ta",
    "mampuesto": "mam-pues-to",
    "mamúa": "ma-mú-a",
    "mamujar": "ma-mu-jar",
    "mamullar": "ma-mu-llar",
    "mamut": "ma-mut",
    "mana": "ma-na",
    "maná": "ma-ná",
    "maña": "ma-ña",
    "manaba": "ma-na-ba",
    "manabita": "ma-na-bi-ta",
    "manada": "ma-na-da",
    "manadera": "ma-na-de-ra",
    "manadero": "ma-na-de-ro",
    "management": "ma-na-ge-ment",
    "mánager": "má-na-ger",
    "managuá": "ma-na-guá",
    "managuaco": "ma-na-gua-co",
    "managüense": "ma-na-güen-se",
    "manal": "ma-nal",
    "mañana": "ma-ña-na",
    "mañanear": "ma-ña-ne-ar",
    "mañanera": "ma-ña-ne-ra",
    "mañanero": "ma-ña-ne-ro",
    "mañanica": "ma-ña-ni-ca",
    "mañanita": "ma-ña-ni-ta",
    "manantía": "ma-nan-tí-a",
    "manantial": "ma-nan-tial",
    "manantío": "ma-nan-tí-o",
    "manar": "ma-nar",
    "manare": "ma-na-re",
    "manatí": "ma-na-tí",
    "manatieña": "ma-na-tie-ña",
    "manatieño": "ma-na-tie-ño",
    "manato": "ma-na-to",
    "manazas": "ma-na-zas",
    "manazo": "ma-na-zo",
    "manca": "man-ca",
    "mancacaballos": "man-ca-ca-ba-llos",
    "mancamiento": "man-ca-mien-to",
    "mancaperro": "man-ca-pe-rro",
    "mancar": "man-car",
    "mancarrón": "man-ca-rrón",
    "mancarrona": "man-ca-rro-na",
    "manceba": "man-ce-ba",
    "mancebez": "man-ce-bez",
    "mancebía": "man-ce-bí-a",
    "mancebo": "man-ce-bo",
    "mancellosa": "man-ce-llo-sa",
    "mancelloso": "man-ce-llo-so",
    "máncer": "mán-cer",
    "mancera": "man-ce-ra",
    "mancerina": "man-ce-ri-na",
    "mancha": "man-cha",
    "manchabrava": "man-cha-bra-va",
    "manchada": "man-cha-da",
    "manchadiza": "man-cha-di-za",
    "manchadizo": "man-cha-di-zo",
    "manchado": "man-cha-do",
    "manchador": "man-cha-dor",
    "manchamantel": "man-cha-man-tel",
    "manchamanteles": "man-cha-man-te-les",
    "manchar": "man-char",
    "máncharras": "mán-cha-rras",
    "manchega": "man-che-ga",
    "manchego": "man-che-go",
    "manchón": "man-chón",
    "manchosa": "man-cho-sa",
    "manchoso": "man-cho-so",
    "manchú": "man-chú",
    "manchuriana": "man-chu-ria-na",
    "manchuriano": "man-chu-ria-no",
    "mancilla": "man-ci-lla",
    "mancilladera": "man-ci-lla-de-ra",
    "mancilladero": "man-ci-lla-de-ro",
    "mancillado": "man-ci-lla-do",
    "mancillamiento": "man-ci-lla-mien-to",
    "mancillar": "man-ci-llar",
    "mancillosa": "man-ci-llo-sa",
    "mancilloso": "man-ci-llo-so",
    "mancipación": "man-ci-pa-ción",
    "mancipar": "man-ci-par",
    "manco": "man-co",
    "mancomún": "man-co-mún",
    "mancomunada": "man-co-mu-na-da",
    "mancomunadamente": "man-co-mu-na-da-men-te",
    "mancomunado": "man-co-mu-na-do",
    "mancomunar": "man-co-mu-nar",
    "mancomunidad": "man-co-mu-ni-dad",
    "mancorna": "man-cor-na",
    "mancornar": "man-cor-nar",
    "mancornas": "man-cor-nas",
    "mancornera": "man-cor-ne-ra",
    "mancuerda": "man-cuer-da",
    "mancuerna": "man-cuer-na",
    "mancuernillas": "man-cuer-ni-llas",
    "mancuncho": "man-cun-cho",
    "manda": "man-da",
    "mandación": "man-da-ción",
    "mandada": "man-da-da",
    "mandadera": "man-da-de-ra",
    "mandadería": "man-da-de-rí-a",
    "mandadero": "man-da-de-ro",
    "mandado": "man-da-do",
    "mandador": "man-da-dor",
    "mandadora": "man-da-do-ra",
    "mandala": "man-da-la",
    "mándala": "mán-da-la",
    "mandamás": "man-da-más",
    "mandamiento": "man-da-mien-to",
    "mandanga": "man-dan-ga",
    "mandante": "man-dan-te",
    "mandar": "man-dar",
    "mandarín": "man-da-rín",
    "mandarina": "man-da-ri-na",
    "mandarinato": "man-da-ri-na-to",
    "mandarinero": "man-da-ri-ne-ro",
    "mandarinismo": "man-da-ri-nis-mo",
    "mandarino": "man-da-ri-no",
    "mandarria": "man-da-rria",
    "mandarriazo": "man-da-rria-zo",
    "mandatar": "man-da-tar",
    "mandataria": "man-da-ta-ria",
    "mandatario": "man-da-ta-rio",
    "mandato": "man-da-to",
    "mandeísmo": "man-de-ís-mo",
    "manderecha": "man-de-re-cha",
    "mandí": "man-dí",
    "mandíbula": "man-dí-bu-la",
    "mandibular": "man-di-bu-lar",
    "mandil": "man-dil",
    "mandilandinga": "man-di-lan-din-ga",
    "mandilar": "man-di-lar",
    "mandilete": "man-di-le-te",
    "mandilón": "man-di-lón",
    "mandinga": "man-din-ga",
    "mandioca": "man-dio-ca",
    "mando": "man-do",
    "mandoble": "man-do-ble",
    "mandolina": "man-do-li-na",
    "mandón": "man-dón",
    "mandona": "man-do-na",
    "mandorla": "man-dor-la",
    "mandra": "man-dra",
    "mandrache": "man-dra-che",
    "mandrachero": "man-dra-che-ro",
    "mandracho": "man-dra-cho",
    "mandrágora": "man-drá-go-ra",
    "mandrágula": "man-drá-gu-la",
    "mandria": "man-dria",
    "mandril": "man-dril",
    "mandrilado": "man-dri-la-do",
    "mandrilador": "man-dri-la-dor",
    "mandriladora": "man-dri-la-do-ra",
    "mandrilar": "man-dri-lar",
    "mandrinador": "man-dri-na-dor",
    "mandrinadora": "man-dri-na-do-ra",
    "mandrón": "man-drón",
    "mandubí": "man-du-bí",
    "manduca": "man-du-ca",
    "manducación": "man-du-ca-ción",
    "manducador": "man-du-ca-dor",
    "manducadora": "man-du-ca-do-ra",
    "manducar": "man-du-car",
    "manducatoria": "man-du-ca-to-ria",
    "manduco": "man-du-co",
    "mandurria": "man-du-rria",
    "manea": "ma-ne-a",
    "maneadero": "ma-ne-a-de-ro",
    "maneado": "ma-ne-a-do",
    "maneador": "ma-ne-a-dor",
    "manear": "ma-ne-ar",
    "mañear": "ma-ñe-ar",
    "manecilla": "ma-ne-ci-lla",
    "manejabilidad": "ma-ne-ja-bi-li-dad",
    "manejable": "ma-ne-ja-ble",
    "manejada": "ma-ne-ja-da",
    "manejado": "ma-ne-ja-do",
    "manejar": "ma-ne-jar",
    "manejo": "ma-ne-jo",
    "maneota": "ma-ne-o-ta",
    "manera": "ma-ne-ra",
    "mañera": "ma-ñe-ra",
    "mañerear": "ma-ñe-re-ar",
    "mañería": "ma-ñe-rí-a",
    "manero": "ma-ne-ro",
    "mañero": "ma-ñe-ro",
    "manes": "ma-nes",
    "maneto": "ma-ne-to",
    "manezuela": "ma-ne-zue-la",
    "mánfanos": "mán-fa-nos",
    "manferidor": "man-fe-ri-dor",
    "manferir": "man-fe-rir",
    "manfla": "man-fla",
    "manflorita": "man-flo-ri-ta",
    "manflota": "man-flo-ta",
    "manga": "man-ga",
    "mangaba": "man-ga-ba",
    "mangada": "man-ga-da",
    "mangado": "man-ga-do",
    "mangaja": "man-ga-ja",
    "mangajarro": "man-ga-ja-rro",
    "mangajo": "man-ga-jo",
    "mangajón": "man-ga-jón",
    "mangajona": "man-ga-jo-na",
    "mangana": "man-ga-na",
    "mangancé": "man-gan-cé",
    "mangancia": "man-gan-cia",
    "manganear": "man-ga-ne-ar",
    "manganeo": "man-ga-ne-o",
    "manganesa": "man-ga-ne-sa",
    "manganesia": "man-ga-ne-sia",
    "manganeso": "man-ga-ne-so",
    "manganeta": "man-ga-ne-ta",
    "mangangá": "man-gan-gá",
    "mangánico": "man-gá-ni-co",
    "manganilla": "man-ga-ni-lla",
    "manganiya": "man-ga-ni-ya",
    "mangante": "man-gan-te",
    "manganzón": "man-gan-zón",
    "manganzona": "man-gan-zo-na",
    "mangar": "man-gar",
    "mangazo": "man-ga-zo",
    "mangla": "man-gla",
    "manglano": "man-gla-no",
    "manglar": "man-glar",
    "mangle": "man-gle",
    "manglera": "man-gle-ra",
    "manglero": "man-gle-ro",
    "mango": "man-go",
    "mangón": "man-gón",
    "mangonada": "man-go-na-da",
    "mangoneador": "man-go-ne-a-dor",
    "mangonear": "man-go-ne-ar",
    "mangoneo": "man-go-ne-o",
    "mangonera": "man-go-ne-ra",
    "mangonero": "man-go-ne-ro",
    "mangorrera": "man-go-rre-ra",
    "mangorrero": "man-go-rre-ro",
    "mangorrillo": "man-go-rri-llo",
    "mangosta": "man-gos-ta",
    "mangostán": "man-gos-tán",
    "mangote": "man-go-te",
    "mangrullo": "man-gru-llo",
    "mangual": "man-gual",
    "manguala": "man-gua-la",
    "manguardia": "man-guar-dia",
    "manguaré": "man-gua-ré",
    "manguarear": "man-gua-re-ar",
    "mangue": "man-gue",
    "manguear": "man-gue-ar",
    "manguera": "man-gue-ra",
    "manguerear": "man-gue-re-ar",
    "manguero": "man-gue-ro",
    "mangueta": "man-gue-ta",
    "manguilla": "man-gui-lla",
    "manguillero": "man-gui-lle-ro",
    "manguita": "man-gui-ta",
    "manguitería": "man-gui-te-rí-a",
    "manguitero": "man-gui-te-ro",
    "manguito": "man-gui-to",
    "manguzada": "man-gu-za-da",
    "maní": "ma-ní",
    "manía": "ma-ní-a",
    "maníaca": "ma-ní-a-ca",
    "maniaca": "ma-nia-ca",
    "maníaco": "ma-ní-a-co",
    "maniaco": "ma-nia-co",
    "manialba": "ma-nial-ba",
    "manialbo": "ma-nial-bo",
    "maniatar": "ma-nia-tar",
    "maniática": "ma-niá-ti-ca",
    "maniático": "ma-niá-ti-co",
    "maniblaj": "ma-ni-blaj",
    "maniblanca": "ma-ni-blan-ca",
    "maniblanco": "ma-ni-blan-co",
    "manicero": "ma-ni-ce-ro",
    "manicomio": "ma-ni-co-mio",
    "manicordio": "ma-ni-cor-dio",
    "manicorta": "ma-ni-cor-ta",
    "manicorto": "ma-ni-cor-to",
    "manicura": "ma-ni-cu-ra",
    "manicurista": "ma-ni-cu-ris-ta",
    "manicuro": "ma-ni-cu-ro",
    "manida": "ma-ni-da",
    "manido": "ma-ni-do",
    "maniega": "ma-nie-ga",
    "maniego": "ma-nie-go",
    "manierismo": "ma-nie-ris-mo",
    "manierista": "ma-nie-ris-ta",
    "manifacera": "ma-ni-fa-ce-ra",
    "manifacero": "ma-ni-fa-ce-ro",
    "manifactura": "ma-ni-fac-tu-ra",
    "manifestación": "ma-ni-fes-ta-ción",
    "manifestador": "ma-ni-fes-ta-dor",
    "manifestadora": "ma-ni-fes-ta-do-ra",
    "manifestante": "ma-ni-fes-tan-te",
    "manifestar": "ma-ni-fes-tar",
    "manifestativa": "ma-ni-fes-ta-ti-va",
    "manifestativo": "ma-ni-fes-ta-ti-vo",
    "manificencia": "ma-ni-fi-cen-cia",
    "manifiesta": "ma-ni-fies-ta",
    "manifiestamente": "ma-ni-fies-ta-men-te",
    "manifiesto": "ma-ni-fies-to",
    "manigero": "ma-ni-ge-ro",
    "manigordo": "ma-ni-gor-do",
    "manigua": "ma-ni-gua",
    "manigual": "ma-ni-gual",
    "manigüera": "ma-ni-güe-ra",
    "manigüero": "ma-ni-güe-ro",
    "manigueta": "ma-ni-gue-ta",
    "manija": "ma-ni-ja",
    "manijear": "ma-ni-je-ar",
    "manijera": "ma-ni-je-ra",
    "manijero": "ma-ni-je-ro",
    "manila": "ma-ni-la",
    "manilana": "ma-ni-la-na",
    "manilano": "ma-ni-la-no",
    "manilarga": "ma-ni-lar-ga",
    "manilargo": "ma-ni-lar-go",
    "manileña": "ma-ni-le-ña",
    "manileño": "ma-ni-le-ño",
    "manilense": "ma-ni-len-se",
    "manilla": "ma-ni-lla",
    "manillar": "ma-ni-llar",
    "manilo": "ma-ni-lo",
    "maniluvio": "ma-ni-lu-vio",
    "mañío": "ma-ñí-o",
    "maniobra": "ma-nio-bra",
    "maniobrabilidad": "ma-nio-bra-bi-li-dad",
    "maniobrable": "ma-nio-bra-ble",
    "maniobrar": "ma-nio-brar",
    "maniobrera": "ma-nio-bre-ra",
    "maniobrero": "ma-nio-bre-ro",
    "maniobrista": "ma-nio-bris-ta",
    "maniota": "ma-nio-ta",
    "manipulación": "ma-ni-pu-la-ción",
    "manipulador": "ma-ni-pu-la-dor",
    "manipuladora": "ma-ni-pu-la-do-ra",
    "manipular": "ma-ni-pu-lar",
    "manipuleo": "ma-ni-pu-le-o",
    "manípulo": "ma-ní-pu-lo",
    "maniquea": "ma-ni-que-a",
    "maniqueísmo": "ma-ni-que-ís-mo",
    "maniqueo": "ma-ni-que-o",
    "maniquete": "ma-ni-que-te",
    "maniquí": "ma-ni-quí",
    "manir": "ma-nir",
    "manirrota": "ma-ni-rro-ta",
    "manirroto": "ma-ni-rro-to",
    "manirrotura": "ma-ni-rro-tu-ra",
    "manisera": "ma-ni-se-ra",
    "manisero": "ma-ni-se-ro",
    "manita": "ma-ni-ta",
    "manito": "ma-ni-to",
    "manivacía": "ma-ni-va-cí-a",
    "manivacío": "ma-ni-va-cí-o",
    "manivela": "ma-ni-ve-la",
    "manizaleña": "ma-ni-za-le-ña",
    "manizaleño": "ma-ni-za-le-ño",
    "manjar": "man-jar",
    "manjarete": "man-ja-re-te",
    "manjelín": "man-je-lín",
    "manjolar": "man-jo-lar",
    "manjorrada": "man-jo-rra-da",
    "manjúa": "man-jú-a",
    "manjuarí": "man-jua-rí",
    "manlevar": "man-le-var",
    "manlieva": "man-lie-va",
    "mano": "ma-no",
    "maño": "ma-ño",
    "manobrar": "ma-no-brar",
    "manobre": "ma-no-bre",
    "manobrero": "ma-no-bre-ro",
    "mañoco": "ma-ño-co",
    "manojear": "ma-no-je-ar",
    "manojeo": "ma-no-je-o",
    "manojera": "ma-no-je-ra",
    "manojo": "ma-no-jo",
    "manola": "ma-no-la",
    "manolarga": "ma-no-lar-ga",
    "manoletina": "ma-no-le-ti-na",
    "manolo": "ma-no-lo",
    "manométrica": "ma-no-mé-tri-ca",
    "manométrico": "ma-no-mé-tri-co",
    "manómetro": "ma-nó-me-tro",
    "manopla": "ma-no-pla",
    "manorreductor": "ma-no-rre-duc-tor",
    "mañosa": "ma-ño-sa",
    "mañosamente": "ma-ño-sa-men-te",
    "manosanta": "ma-no-san-ta",
    "manoseador": "ma-no-se-a-dor",
    "manoseadora": "ma-no-se-a-do-ra",
    "manosear": "ma-no-se-ar",
    "mañosear": "ma-ño-se-ar",
    "manoseo": "ma-no-se-o",
    "mañoso": "ma-ño-so",
    "manotada": "ma-no-ta-da",
    "manotazo": "ma-no-ta-zo",
    "manoteado": "ma-no-te-a-do",
    "manotear": "ma-no-te-ar",
    "manoteo": "ma-no-te-o",
    "manotón": "ma-no-tón",
    "manquear": "man-que-ar",
    "manquedad": "man-que-dad",
    "manquera": "man-que-ra",
    "manresana": "man-re-sa-na",
    "manresano": "man-re-sa-no",
    "manriqueño": "man-ri-que-ño",
    "mansa": "man-sa",
    "mansalva": "man-sal-va",
    "mansamente": "man-sa-men-te",
    "mansarda": "man-sar-da",
    "mansear": "man-se-ar",
    "mansedad": "man-se-dad",
    "mansedumbre": "man-se-dum-bre",
    "mansejón": "man-se-jón",
    "mansejona": "man-se-jo-na",
    "manseque": "man-se-que",
    "mansera": "man-se-ra",
    "mansesor": "man-se-sor",
    "manseza": "man-se-za",
    "mansión": "man-sión",
    "mansionario": "man-sio-na-rio",
    "mansito": "man-si-to",
    "manso": "man-so",
    "mansuefacta": "man-sue-fac-ta",
    "mansuefacto": "man-sue-fac-to",
    "mansueta": "man-sue-ta",
    "mansueto": "man-sue-to",
    "mansuetud": "man-sue-tud",
    "mansurrear": "man-su-rre-ar",
    "mansurrón": "man-su-rrón",
    "mansurrona": "man-su-rro-na",
    "mansurronear": "man-su-rro-ne-ar",
    "manta": "man-ta",
    "mantaca": "man-ta-ca",
    "mantaterilla": "man-ta-te-ri-lla",
    "mantazo": "man-ta-zo",
    "manteado": "man-te-a-do",
    "manteador": "man-te-a-dor",
    "manteadora": "man-te-a-do-ra",
    "manteamiento": "man-te-a-mien-to",
    "mantear": "man-te-ar",
    "manteca": "man-te-ca",
    "mantecada": "man-te-ca-da",
    "mantecado": "man-te-ca-do",
    "mantecón": "man-te-cón",
    "mantecosa": "man-te-co-sa",
    "mantecoso": "man-te-co-so",
    "manteísta": "man-te-ís-ta",
    "mantel": "man-tel",
    "mantelado": "man-te-la-do",
    "mantelería": "man-te-le-rí-a",
    "manteleta": "man-te-le-ta",
    "mantelete": "man-te-le-te",
    "mantelillo": "man-te-li-llo",
    "mantellina": "man-te-lli-na",
    "mantelo": "man-te-lo",
    "manteña": "man-te-ña",
    "mantención": "man-ten-ción",
    "mantenedor": "man-te-ne-dor",
    "mantenedora": "man-te-ne-do-ra",
    "mantenencia": "man-te-nen-cia",
    "mantener": "man-te-ner",
    "mantenida": "man-te-ni-da",
    "mantenido": "man-te-ni-do",
    "manteniente": "man-te-nien-te",
    "mantenimiento": "man-te-ni-mien-to",
    "manteño": "man-te-ño",
    "manteo": "man-te-o",
    "mantequera": "man-te-que-ra",
    "mantequería": "man-te-que-rí-a",
    "mantequero": "man-te-que-ro",
    "mantequilla": "man-te-qui-lla",
    "mantequillera": "man-te-qui-lle-ra",
    "mantequillero": "man-te-qui-lle-ro",
    "mantera": "man-te-ra",
    "mantero": "man-te-ro",
    "mantés": "man-tés",
    "mantesa": "man-te-sa",
    "mántica": "mán-ti-ca",
    "mantilla": "man-ti-lla",
    "mantillo": "man-ti-llo",
    "mantillón": "man-ti-llón",
    "mantillona": "man-ti-llo-na",
    "mantiniente": "man-ti-nien-te",
    "mantis": "man-tis",
    "mantisa": "man-ti-sa",
    "manto": "man-to",
    "mantón": "man-tón",
    "mantona": "man-to-na",
    "mantornar": "man-tor-nar",
    "mantra": "man-tra",
    "mantuana": "man-tua-na",
    "mantuano": "man-tua-no",
    "mantuda": "man-tu-da",
    "mantudo": "man-tu-do",
    "manuable": "ma-nua-ble",
    "manual": "ma-nual",
    "manualidad": "ma-nua-li-dad",
    "manualmente": "ma-nual-men-te",
    "manubrio": "ma-nu-brio",
    "manucodiata": "ma-nu-co-dia-ta",
    "manuda": "ma-nu-da",
    "manudo": "ma-nu-do",
    "manuela": "ma-nue-la",
    "mañuela": "ma-ñue-la",
    "manuelina": "ma-nue-li-na",
    "manuelino": "ma-nue-li-no",
    "manuella": "ma-nue-lla",
    "manufactura": "ma-nu-fac-tu-ra",
    "manufacturación": "ma-nu-fac-tu-ra-ción",
    "manufacturado": "ma-nu-fac-tu-ra-do",
    "manufacturar": "ma-nu-fac-tu-rar",
    "manufacturera": "ma-nu-fac-tu-re-ra",
    "manufacturero": "ma-nu-fac-tu-re-ro",
    "manumisa": "ma-nu-mi-sa",
    "manumisión": "ma-nu-mi-sión",
    "manumiso": "ma-nu-mi-so",
    "manumisor": "ma-nu-mi-sor",
    "manumitir": "ma-nu-mi-tir",
    "manuscribir": "ma-nus-cri-bir",
    "manuscrita": "ma-nus-cri-ta",
    "manuscrito": "ma-nus-cri-to",
    "manutención": "ma-nu-ten-ción",
    "manutenencia": "ma-nu-te-nen-cia",
    "manutener": "ma-nu-te-ner",
    "manutergio": "ma-nu-ter-gio",
    "manutigio": "ma-nu-ti-gio",
    "manutisa": "ma-nu-ti-sa",
    "manvacía": "man-va-cí-a",
    "manvacío": "man-va-cí-o",
    "manyaoreja": "man-ya-o-re-ja",
    "manzana": "man-za-na",
    "manzanal": "man-za-nal",
    "manzanar": "man-za-nar",
    "manzanera": "man-za-ne-ra",
    "manzanero": "man-za-ne-ro",
    "manzaneta": "man-za-ne-ta",
    "manzanil": "man-za-nil",
    "manzanilla": "man-za-ni-lla",
    "manzanillera": "man-za-ni-lle-ra",
    "manzanillero": "man-za-ni-lle-ro",
    "manzanillo": "man-za-ni-llo",
    "manzanita": "man-za-ni-ta",
    "manzano": "man-za-no",
    "maoísmo": "ma-o-ís-mo",
    "maoísta": "ma-o-ís-ta",
    "maoma": "ma-o-ma",
    "maorí": "ma-o-rí",
    "mapa": "ma-pa",
    "mapache": "ma-pa-che",
    "mapachín": "ma-pa-chín",
    "mapamundi": "ma-pa-mun-di",
    "mapanare": "ma-pa-na-re",
    "mapear": "ma-pe-ar",
    "mapeo": "ma-pe-o",
    "mapire": "ma-pi-re",
    "mapo": "ma-po",
    "mapuche": "ma-pu-che",
    "mapurite": "ma-pu-ri-te",
    "mapuro": "ma-pu-ro",
    "maque": "ma-que",
    "maqueador": "ma-que-a-dor",
    "maquear": "ma-que-ar",
    "maquech": "ma-quech",
    "maqueta": "ma-que-ta",
    "maquetación": "ma-que-ta-ción",
    "maquetador": "ma-que-ta-dor",
    "maquetadora": "ma-que-ta-do-ra",
    "maquetar": "ma-que-tar",
    "maquetista": "ma-que-tis-ta",
    "maqueto": "ma-que-to",
    "maqui": "ma-qui",
    "maquiavélica": "ma-quia-vé-li-ca",
    "maquiavélicamente": "ma-quia-vé-li-ca-men-te",
    "maquiavélico": "ma-quia-vé-li-co",
    "maquiavelismo": "ma-quia-ve-lis-mo",
    "maquiavelista": "ma-quia-ve-lis-ta",
    "maquila": "ma-qui-la",
    "maquilador": "ma-qui-la-dor",
    "maquiladora": "ma-qui-la-do-ra",
    "maquilar": "ma-qui-lar",
    "maquilera": "ma-qui-le-ra",
    "maquilero": "ma-qui-le-ro",
    "maquilihue": "ma-qui-li-hue",
    "maquilisguate": "ma-qui-lis-gua-te",
    "maquilishuat": "ma-qui-lis-huat",
    "maquillador": "ma-qui-lla-dor",
    "maquilladora": "ma-qui-lla-do-ra",
    "maquillaje": "ma-qui-lla-je",
    "maquillar": "ma-qui-llar",
    "maquillista": "ma-qui-llis-ta",
    "maquilón": "ma-qui-lón",
    "máquina": "má-qui-na",
    "maquinación": "ma-qui-na-ción",
    "maquinador": "ma-qui-na-dor",
    "maquinadora": "ma-qui-na-do-ra",
    "maquinal": "ma-qui-nal",
    "maquinalmente": "ma-qui-nal-men-te",
    "maquinar": "ma-qui-nar",
    "maquinaria": "ma-qui-na-ria",
    "maquinilla": "ma-qui-ni-lla",
    "maquinillero": "ma-qui-ni-lle-ro",
    "maquinismo": "ma-qui-nis-mo",
    "maquinista": "ma-qui-nis-ta",
    "maquinización": "ma-qui-ni-za-ción",
    "maquinizar": "ma-qui-ni-zar",
    "maquiritare": "ma-qui-ri-ta-re",
    "maquis": "ma-quis",
    "maquisapa": "ma-qui-sa-pa",
    "mara": "ma-ra",
    "marabino": "ma-ra-bi-no",
    "marabú": "ma-ra-bú",
    "marabunta": "ma-ra-bun-ta",
    "marabuto": "ma-ra-bu-to",
    "maraca": "ma-ra-ca",
    "maracaibera": "ma-ra-cai-be-ra",
    "maracaibero": "ma-ra-cai-be-ro",
    "maracaná": "ma-ra-ca-ná",
    "maracandacas": "ma-ra-can-da-cas",
    "maracayá": "ma-ra-ca-yá",
    "maracayera": "ma-ra-ca-ye-ra",
    "maracayero": "ma-ra-ca-ye-ro",
    "maraco": "ma-ra-co",
    "maracucha": "ma-ra-cu-cha",
    "maracucho": "ma-ra-cu-cho",
    "maracuyá": "ma-ra-cu-yá",
    "maragata": "ma-ra-ga-ta",
    "maragatería": "ma-ra-ga-te-rí-a",
    "maragato": "ma-ra-ga-to",
    "marajá": "ma-ra-já",
    "maraña": "ma-ra-ña",
    "marañal": "ma-ra-ñal",
    "marañar": "ma-ra-ñar",
    "marañera": "ma-ra-ñe-ra",
    "marañero": "ma-ra-ñe-ro",
    "marañón": "ma-ra-ñón",
    "marañosa": "ma-ra-ño-sa",
    "marañoso": "ma-ra-ño-so",
    "marantácea": "ma-ran-tá-ce-a",
    "marantáceo": "ma-ran-tá-ce-o",
    "marañuela": "ma-ra-ñue-la",
    "maraquera": "ma-ra-que-ra",
    "maraquero": "ma-ra-que-ro",
    "marasmo": "ma-ras-mo",
    "maratí": "ma-ra-tí",
    "maratón": "ma-ra-tón",
    "maratoniana": "ma-ra-to-nia-na",
    "maratoniano": "ma-ra-to-nia-no",
    "maratónico": "ma-ra-tó-ni-co",
    "maravedí": "ma-ra-ve-dí",
    "maravedinada": "ma-ra-ve-di-na-da",
    "maravilla": "ma-ra-vi-lla",
    "maravillar": "ma-ra-vi-llar",
    "maravillosa": "ma-ra-vi-llo-sa",
    "maravillosamente": "ma-ra-vi-llo-sa-men-te",
    "maravilloso": "ma-ra-vi-llo-so",
    "marbellí": "mar-be-llí",
    "marbete": "mar-be-te",
    "marca": "mar-ca",
    "marcación": "mar-ca-ción",
    "marcadamente": "mar-ca-da-men-te",
    "marcado": "mar-ca-do",
    "marcador": "mar-ca-dor",
    "marcadora": "mar-ca-do-ra",
    "marcaje": "mar-ca-je",
    "marcapaso": "mar-ca-pa-so",
    "marcapasos": "mar-ca-pa-sos",
    "marcar": "mar-car",
    "marcasita": "mar-ca-si-ta",
    "marceador": "mar-ce-a-dor",
    "marceadora": "mar-ce-a-do-ra",
    "marcear": "mar-ce-ar",
    "marcela": "mar-ce-la",
    "marcelianista": "mar-ce-lia-nis-ta",
    "marcen": "mar-cen",
    "márcena": "már-ce-na",
    "marcenar": "mar-ce-nar",
    "marceño": "mar-ce-ño",
    "marceo": "mar-ce-o",
    "marcera": "mar-ce-ra",
    "marcero": "mar-ce-ro",
    "marcescente": "mar-ces-cen-te",
    "marcha": "mar-cha",
    "marchador": "mar-cha-dor",
    "marchadora": "mar-cha-do-ra",
    "marchamador": "mar-cha-ma-dor",
    "marchamar": "mar-cha-mar",
    "marchamero": "mar-cha-me-ro",
    "marchamo": "mar-cha-mo",
    "marchanta": "mar-chan-ta",
    "marchantaje": "mar-chan-ta-je",
    "marchante": "mar-chan-te",
    "marchantería": "mar-chan-te-rí-a",
    "marchantía": "mar-chan-tí-a",
    "marchapié": "mar-cha-pié",
    "marchar": "mar-char",
    "marchita": "mar-chi-ta",
    "marchitable": "mar-chi-ta-ble",
    "marchitamiento": "mar-chi-ta-mien-to",
    "marchitar": "mar-chi-tar",
    "marchitez": "mar-chi-tez",
    "marchito": "mar-chi-to",
    "marchosa": "mar-cho-sa",
    "marchoso": "mar-cho-so",
    "marcia": "mar-cia",
    "marcial": "mar-cial",
    "marcialidad": "mar-cia-li-dad",
    "marcialmente": "mar-cial-men-te",
    "marciana": "mar-cia-na",
    "marciano": "mar-cia-no",
    "marcido": "mar-ci-do",
    "marcio": "mar-cio",
    "marcionista": "mar-cio-nis-ta",
    "marcionita": "mar-cio-ni-ta",
    "marcir": "mar-cir",
    "marco": "mar-co",
    "márcola": "már-co-la",
    "marcolador": "mar-co-la-dor",
    "marcoladora": "mar-co-la-do-ra",
    "marcomana": "mar-co-ma-na",
    "marcomano": "mar-co-ma-no",
    "marconigrama": "mar-co-ni-gra-ma",
    "mardal": "mar-dal",
    "mardano": "mar-da-no",
    "marea": "ma-re-a",
    "mareado": "ma-re-a-do",
    "mareador": "ma-re-a-dor",
    "mareadora": "ma-re-a-do-ra",
    "mareaje": "ma-re-a-je",
    "mareal": "ma-re-al",
    "mareamiento": "ma-re-a-mien-to",
    "mareante": "ma-re-an-te",
    "marear": "ma-re-ar",
    "marejada": "ma-re-ja-da",
    "marejadilla": "ma-re-ja-di-lla",
    "maremagno": "ma-re-mag-no",
    "maremágnum": "ma-re-mág-num",
    "maremoto": "ma-re-mo-to",
    "marengo": "ma-ren-go",
    "mareo": "ma-re-o",
    "mareógrafo": "ma-re-ó-gra-fo",
    "mareomotor": "ma-re-o-mo-tor",
    "mareosa": "ma-re-o-sa",
    "mareoso": "ma-re-o-so",
    "marera": "ma-re-ra",
    "marero": "ma-re-ro",
    "mareta": "ma-re-ta",
    "maretazo": "ma-re-ta-zo",
    "márfaga": "már-fa-ga",
    "márfega": "már-fe-ga",
    "marfil": "mar-fil",
    "marfileña": "mar-fi-le-ña",
    "marfileño": "mar-fi-le-ño",
    "marfilense": "mar-fi-len-se",
    "marfilina": "mar-fi-li-na",
    "marfusa": "mar-fu-sa",
    "marfuz": "mar-fuz",
    "marfuza": "mar-fu-za",
    "marga": "mar-ga",
    "margajita": "mar-ga-ji-ta",
    "margal": "mar-gal",
    "margallate": "mar-ga-lla-te",
    "margallón": "mar-ga-llón",
    "margar": "mar-gar",
    "margarina": "mar-ga-ri-na",
    "margarita": "mar-ga-ri-ta",
    "margariteña": "mar-ga-ri-te-ña",
    "margariteño": "mar-ga-ri-te-ño",
    "margayate": "mar-ga-ya-te",
    "margen": "mar-gen",
    "margenar": "mar-ge-nar",
    "margesí": "mar-ge-sí",
    "marginación": "mar-gi-na-ción",
    "marginada": "mar-gi-na-da",
    "marginado": "mar-gi-na-do",
    "marginador": "mar-gi-na-dor",
    "marginal": "mar-gi-nal",
    "marginalidad": "mar-gi-na-li-dad",
    "marginalización": "mar-gi-na-li-za-ción",
    "marginar": "mar-gi-nar",
    "margomar": "mar-go-mar",
    "margosa": "mar-go-sa",
    "margoso": "mar-go-so",
    "margrave": "mar-gra-ve",
    "margraviato": "mar-gra-via-to",
    "marguera": "mar-gue-ra",
    "margullar": "mar-gu-llar",
    "margullo": "mar-gu-llo",
    "maría": "ma-rí-a",
    "mariache": "ma-ria-che",
    "mariachi": "ma-ria-chi",
    "mariachis": "ma-ria-chis",
    "marial": "ma-rial",
    "mariana": "ma-ria-na",
    "marianista": "ma-ria-nis-ta",
    "mariano": "ma-ria-no",
    "marica": "ma-ri-ca",
    "maricangalla": "ma-ri-can-ga-lla",
    "maricón": "ma-ri-cón",
    "maricona": "ma-ri-co-na",
    "mariconada": "ma-ri-co-na-da",
    "mariconear": "ma-ri-co-ne-ar",
    "mariconeo": "ma-ri-co-ne-o",
    "mariconera": "ma-ri-co-ne-ra",
    "mariconería": "ma-ri-co-ne-rí-a",
    "maricueca": "ma-ri-cue-ca",
    "maricultura": "ma-ri-cul-tu-ra",
    "maridable": "ma-ri-da-ble",
    "maridablemente": "ma-ri-da-ble-men-te",
    "maridaje": "ma-ri-da-je",
    "maridal": "ma-ri-dal",
    "maridar": "ma-ri-dar",
    "maridazo": "ma-ri-da-zo",
    "maridillo": "ma-ri-di-llo",
    "marido": "ma-ri-do",
    "mariguana": "ma-ri-gua-na",
    "mariguanear": "ma-ri-gua-ne-ar",
    "mariguanera": "ma-ri-gua-ne-ra",
    "mariguanero": "ma-ri-gua-ne-ro",
    "mariguanza": "ma-ri-guan-za",
    "marihuana": "ma-ri-hua-na",
    "marihuanero": "ma-ri-hua-ne-ro",
    "marimacha": "ma-ri-ma-cha",
    "marimacho": "ma-ri-ma-cho",
    "marimandón": "ma-ri-man-dón",
    "marimandona": "ma-ri-man-do-na",
    "marimanta": "ma-ri-man-ta",
    "marimarica": "ma-ri-ma-ri-ca",
    "marimba": "ma-rim-ba",
    "marimbera": "ma-rim-be-ra",
    "marimbero": "ma-rim-be-ro",
    "marimbista": "ma-rim-bis-ta",
    "marimoña": "ma-ri-mo-ña",
    "marimorena": "ma-ri-mo-re-na",
    "marina": "ma-ri-na",
    "marinada": "ma-ri-na-da",
    "marinado": "ma-ri-na-do",
    "marinaje": "ma-ri-na-je",
    "marinamo": "ma-ri-na-mo",
    "marinante": "ma-ri-nan-te",
    "marinar": "ma-ri-nar",
    "marine": "ma-ri-ne",
    "marinear": "ma-ri-ne-ar",
    "marinera": "ma-ri-ne-ra",
    "marinerada": "ma-ri-ne-ra-da",
    "marinerado": "ma-ri-ne-ra-do",
    "marinerazo": "ma-ri-ne-ra-zo",
    "marinería": "ma-ri-ne-rí-a",
    "marinero": "ma-ri-ne-ro",
    "marinesca": "ma-ri-nes-ca",
    "marinesco": "ma-ri-nes-co",
    "marinismo": "ma-ri-nis-mo",
    "marinista": "ma-ri-nis-ta",
    "marino": "ma-ri-no",
    "marinovia": "ma-ri-no-via",
    "marinovio": "ma-ri-no-vio",
    "mariol": "ma-riol",
    "marióloga": "ma-rió-lo-ga",
    "mariología": "ma-rio-lo-gí-a",
    "mariólogo": "ma-rió-lo-go",
    "marión": "ma-rión",
    "mariona": "ma-rio-na",
    "marioneta": "ma-rio-ne-ta",
    "marionetista": "ma-rio-ne-tis-ta",
    "marioso": "ma-rio-so",
    "maripérez": "ma-ri-pé-rez",
    "mariposa": "ma-ri-po-sa",
    "mariposado": "ma-ri-po-sa-do",
    "mariposeador": "ma-ri-po-se-a-dor",
    "mariposeadora": "ma-ri-po-se-a-do-ra",
    "mariposear": "ma-ri-po-se-ar",
    "mariposeo": "ma-ri-po-se-o",
    "mariposista": "ma-ri-po-sis-ta",
    "mariposón": "ma-ri-po-són",
    "mariquera": "ma-ri-que-ra",
    "mariquita": "ma-ri-qui-ta",
    "marisabidilla": "ma-ri-sa-bi-di-lla",
    "mariscada": "ma-ris-ca-da",
    "mariscador": "ma-ris-ca-dor",
    "mariscadora": "ma-ris-ca-do-ra",
    "mariscal": "ma-ris-cal",
    "mariscala": "ma-ris-ca-la",
    "mariscalato": "ma-ris-ca-la-to",
    "mariscalía": "ma-ris-ca-lí-a",
    "mariscar": "ma-ris-car",
    "marisco": "ma-ris-co",
    "marisma": "ma-ris-ma",
    "marismeña": "ma-ris-me-ña",
    "marismeño": "ma-ris-me-ño",
    "marismo": "ma-ris-mo",
    "marisqueo": "ma-ris-que-o",
    "marisquera": "ma-ris-que-ra",
    "marisquería": "ma-ris-que-rí-a",
    "marisquero": "ma-ris-que-ro",
    "marista": "ma-ris-ta",
    "marital": "ma-ri-tal",
    "maritata": "ma-ri-ta-ta",
    "maritatas": "ma-ri-ta-tas",
    "maritates": "ma-ri-ta-tes",
    "marítima": "ma-rí-ti-ma",
    "marítimo": "ma-rí-ti-mo",
    "maritornes": "ma-ri-tor-nes",
    "marizar": "ma-ri-zar",
    "marizarse": "ma-ri-zar-se",
    "marjal": "mar-jal",
    "marjoleta": "mar-jo-le-ta",
    "marjoleto": "mar-jo-le-to",
    "marketing": "mar-ke-ting",
    "marlín": "mar-lín",
    "marlo": "mar-lo",
    "marlota": "mar-lo-ta",
    "marlotar": "mar-lo-tar",
    "marmaja": "mar-ma-ja",
    "marmárica": "mar-má-ri-ca",
    "marmárico": "mar-má-ri-co",
    "marmella": "mar-me-lla",
    "marmellada": "mar-me-lla-da",
    "marmellado": "mar-me-lla-do",
    "marmita": "mar-mi-ta",
    "marmitón": "mar-mi-tón",
    "mármol": "már-mol",
    "marmolado": "mar-mo-la-do",
    "marmolejo": "mar-mo-le-jo",
    "marmoleña": "mar-mo-le-ña",
    "marmoleño": "mar-mo-le-ño",
    "marmolería": "mar-mo-le-rí-a",
    "marmolillo": "mar-mo-li-llo",
    "marmolina": "mar-mo-li-na",
    "marmolista": "mar-mo-lis-ta",
    "mármor": "már-mor",
    "marmoración": "mar-mo-ra-ción",
    "marmórea": "mar-mó-re-a",
    "marmóreo": "mar-mó-re-o",
    "marmorosa": "mar-mo-ro-sa",
    "marmoroso": "mar-mo-ro-so",
    "marmosa": "mar-mo-sa",
    "marmosete": "mar-mo-se-te",
    "marmota": "mar-mo-ta",
    "marmotear": "mar-mo-te-ar",
    "marmotera": "mar-mo-te-ra",
    "marmullar": "mar-mu-llar",
    "maro": "ma-ro",
    "marocha": "ma-ro-cha",
    "marojal": "ma-ro-jal",
    "marojo": "ma-ro-jo",
    "marola": "ma-ro-la",
    "maroma": "ma-ro-ma",
    "maromear": "ma-ro-me-ar",
    "maromera": "ma-ro-me-ra",
    "maromero": "ma-ro-me-ro",
    "maromo": "ma-ro-mo",
    "marón": "ma-rón",
    "maronita": "ma-ro-ni-ta",
    "marota": "ma-ro-ta",
    "marote": "ma-ro-te",
    "marplatense": "mar-pla-ten-se",
    "marqueo": "mar-que-o",
    "marqués": "mar-qués",
    "marquesa": "mar-que-sa",
    "marquesado": "mar-que-sa-do",
    "marquesina": "mar-que-si-na",
    "marquesita": "mar-que-si-ta",
    "marquesota": "mar-que-so-ta",
    "marquesote": "mar-que-so-te",
    "marqueta": "mar-que-ta",
    "marquetera": "mar-que-te-ra",
    "marquetería": "mar-que-te-rí-a",
    "marquetero": "mar-que-te-ro",
    "marquilla": "mar-qui-lla",
    "marquista": "mar-quis-ta",
    "marra": "ma-rra",
    "márraga": "má-rra-ga",
    "marragón": "ma-rra-gón",
    "marraguero": "ma-rra-gue-ro",
    "marraja": "ma-rra-ja",
    "marrajo": "ma-rra-jo",
    "marramao": "ma-rra-ma-o",
    "marramáu": "ma-rra-máu",
    "marramizar": "ma-rra-mi-zar",
    "marrana": "ma-rra-na",
    "marranada": "ma-rra-na-da",
    "marranalla": "ma-rra-na-lla",
    "marranchón": "ma-rran-chón",
    "marranchona": "ma-rran-cho-na",
    "marranear": "ma-rra-ne-ar",
    "marranería": "ma-rra-ne-rí-a",
    "marranillo": "ma-rra-ni-llo",
    "marrano": "ma-rra-no",
    "marraqueta": "ma-rra-que-ta",
    "marrar": "ma-rrar",
    "marras": "ma-rras",
    "marrasquino": "ma-rras-qui-no",
    "marrazo": "ma-rra-zo",
    "marrear": "ma-rre-ar",
    "marrida": "ma-rri-da",
    "marrido": "ma-rri-do",
    "marrillo": "ma-rri-llo",
    "marro": "ma-rro",
    "marrocas": "ma-rro-cas",
    "marrón": "ma-rrón",
    "marronazo": "ma-rro-na-zo",
    "marroquí": "ma-rro-quí",
    "marroquín": "ma-rro-quín",
    "marroquina": "ma-rro-qui-na",
    "marroquinera": "ma-rro-qui-ne-ra",
    "marroquinería": "ma-rro-qui-ne-rí-a",
    "marroquinero": "ma-rro-qui-ne-ro",
    "marroquinidad": "ma-rro-qui-ni-dad",
    "marrubial": "ma-rru-bial",
    "marrubio": "ma-rru-bio",
    "marrueca": "ma-rrue-ca",
    "marrueco": "ma-rrue-co",
    "marrulla": "ma-rru-lla",
    "marrullar": "ma-rru-llar",
    "marrullera": "ma-rru-lle-ra",
    "marrullería": "ma-rru-lle-rí-a",
    "marrullero": "ma-rru-lle-ro",
    "marsa": "mar-sa",
    "marsellés": "mar-se-llés",
    "marsellesa": "mar-se-lle-sa",
    "marshalés": "mars-ha-lés",
    "marshalesa": "mars-ha-le-sa",
    "mársica": "már-si-ca",
    "mársico": "már-si-co",
    "marso": "mar-so",
    "marsopa": "mar-so-pa",
    "marsopla": "mar-so-pla",
    "marsupial": "mar-su-pial",
    "marsupio": "mar-su-pio",
    "marta": "mar-ta",
    "mártaga": "már-ta-ga",
    "martagón": "mar-ta-gón",
    "martagona": "mar-ta-go-na",
    "martaguilla": "mar-ta-gui-lla",
    "martajar": "mar-ta-jar",
    "martajón": "mar-ta-jón",
    "marte": "mar-te",
    "martellina": "mar-te-lli-na",
    "martelo": "mar-te-lo",
    "martes": "mar-tes",
    "martiano": "mar-tia-no",
    "martillada": "mar-ti-lla-da",
    "martillado": "mar-ti-lla-do",
    "martillador": "mar-ti-lla-dor",
    "martilladora": "mar-ti-lla-do-ra",
    "martillar": "mar-ti-llar",
    "martillazo": "mar-ti-lla-zo",
    "martillear": "mar-ti-lle-ar",
    "martillejo": "mar-ti-lle-jo",
    "martilleo": "mar-ti-lle-o",
    "martillera": "mar-ti-lle-ra",
    "martillero": "mar-ti-lle-ro",
    "martillo": "mar-ti-llo",
    "martín": "mar-tín",
    "martina": "mar-ti-na",
    "martinenco": "mar-ti-nen-co",
    "martineta": "mar-ti-ne-ta",
    "martinete": "mar-ti-ne-te",
    "martingala": "mar-tin-ga-la",
    "martini": "mar-ti-ni",
    "martinico": "mar-ti-ni-co",
    "martiniega": "mar-ti-nie-ga",
    "mártir": "már-tir",
    "martirial": "mar-ti-rial",
    "martiriar": "mar-ti-riar",
    "martirio": "mar-ti-rio",
    "martirizador": "mar-ti-ri-za-dor",
    "martirizadora": "mar-ti-ri-za-do-ra",
    "martirizante": "mar-ti-ri-zan-te",
    "martirizar": "mar-ti-ri-zar",
    "martirologio": "mar-ti-ro-lo-gio",
    "maruca": "ma-ru-ca",
    "marucha": "ma-ru-cha",
    "marucho": "ma-ru-cho",
    "marueco": "ma-rue-co",
    "marufa": "ma-ru-fa",
    "maruga": "ma-ru-ga",
    "maruja": "ma-ru-ja",
    "marujear": "ma-ru-je-ar",
    "marujeo": "ma-ru-je-o",
    "marujil": "ma-ru-jil",
    "marullo": "ma-ru-llo",
    "marxismo": "mar-xis-mo",
    "marxista": "mar-xis-ta",
    "marzadga": "mar-zad-ga",
    "marzal": "mar-zal",
    "marzante": "mar-zan-te",
    "marzas": "mar-zas",
    "marzo": "mar-zo",
    "marzoleta": "mar-zo-le-ta",
    "marzoleto": "mar-zo-le-to",
    "masa": "ma-sa",
    "masacoate": "ma-sa-co-a-te",
    "masacrar": "ma-sa-crar",
    "masacre": "ma-sa-cre",
    "masada": "ma-sa-da",
    "masadero": "ma-sa-de-ro",
    "masageta": "ma-sa-ge-ta",
    "masaje": "ma-sa-je",
    "masajear": "ma-sa-je-ar",
    "masajista": "ma-sa-jis-ta",
    "masamuda": "ma-sa-mu-da",
    "masar": "ma-sar",
    "masatepina": "ma-sa-te-pi-na",
    "masatepino": "ma-sa-te-pi-no",
    "masato": "ma-sa-to",
    "masayense": "ma-sa-yen-se",
    "mascabada": "mas-ca-ba-da",
    "mascabado": "mas-ca-ba-do",
    "mascada": "mas-ca-da",
    "mascadijo": "mas-ca-di-jo",
    "mascado": "mas-ca-do",
    "mascador": "mas-ca-dor",
    "mascadora": "mas-ca-do-ra",
    "mascadura": "mas-ca-du-ra",
    "mascar": "mas-car",
    "máscara": "más-ca-ra",
    "mascarada": "mas-ca-ra-da",
    "mascarar": "mas-ca-rar",
    "mascarera": "mas-ca-re-ra",
    "mascarero": "mas-ca-re-ro",
    "mascarilla": "mas-ca-ri-lla",
    "mascarita": "mas-ca-ri-ta",
    "mascarón": "mas-ca-rón",
    "mascarpone": "mas-car-po-ne",
    "mascota": "mas-co-ta",
    "mascujada": "mas-cu-ja-da",
    "mascujador": "mas-cu-ja-dor",
    "mascujadora": "mas-cu-ja-do-ra",
    "mascujar": "mas-cu-jar",
    "máscula": "más-cu-la",
    "masculillo": "mas-cu-li-llo",
    "masculina": "mas-cu-li-na",
    "masculinidad": "mas-cu-li-ni-dad",
    "masculinización": "mas-cu-li-ni-za-ción",
    "masculinizar": "mas-cu-li-ni-zar",
    "masculino": "mas-cu-li-no",
    "mascullar": "mas-cu-llar",
    "másculo": "más-cu-lo",
    "masear": "ma-se-ar",
    "masecoral": "ma-se-co-ral",
    "masejicomar": "ma-se-ji-co-mar",
    "masera": "ma-se-ra",
    "masería": "ma-se-rí-a",
    "masetero": "ma-se-te-ro",
    "mashca": "mash-ca",
    "mashua": "mas-hua",
    "masía": "ma-sí-a",
    "másico": "má-si-co",
    "masicoral": "ma-si-co-ral",
    "masicote": "ma-si-co-te",
    "masiena": "ma-sie-na",
    "masieno": "ma-sie-no",
    "masificación": "ma-si-fi-ca-ción",
    "masificar": "ma-si-fi-car",
    "masila": "ma-si-la",
    "masilia": "ma-si-lia",
    "masílica": "ma-sí-li-ca",
    "masílico": "ma-sí-li-co",
    "masiliense": "ma-si-lien-se",
    "masilio": "ma-si-lio",
    "masilla": "ma-si-lla",
    "masilo": "ma-si-lo",
    "masita": "ma-si-ta",
    "masiva": "ma-si-va",
    "masivamente": "ma-si-va-men-te",
    "masivo": "ma-si-vo",
    "maslo": "mas-lo",
    "masoca": "ma-so-ca",
    "masón": "ma-són",
    "masona": "ma-so-na",
    "masonería": "ma-so-ne-rí-a",
    "masónica": "ma-só-ni-ca",
    "masónico": "ma-só-ni-co",
    "masoquismo": "ma-so-quis-mo",
    "masoquista": "ma-so-quis-ta",
    "masora": "ma-so-ra",
    "masoreta": "ma-so-re-ta",
    "masorética": "ma-so-ré-ti-ca",
    "masorético": "ma-so-ré-ti-co",
    "masoterapia": "ma-so-te-ra-pia",
    "masovero": "ma-so-ve-ro",
    "mastaba": "mas-ta-ba",
    "mastate": "mas-ta-te",
    "maste": "mas-te",
    "mastectomía": "mas-tec-to-mí-a",
    "mástel": "más-tel",
    "masteleo": "mas-te-le-o",
    "mastelerillo": "mas-te-le-ri-llo",
    "mastelero": "mas-te-le-ro",
    "máster": "más-ter",
    "masterizar": "mas-te-ri-zar",
    "masters": "mas-ters",
    "masticable": "mas-ti-ca-ble",
    "masticación": "mas-ti-ca-ción",
    "masticador": "mas-ti-ca-dor",
    "masticadora": "mas-ti-ca-do-ra",
    "masticar": "mas-ti-car",
    "masticatoria": "mas-ti-ca-to-ria",
    "masticatorio": "mas-ti-ca-to-rio",
    "masticina": "mas-ti-ci-na",
    "masticino": "mas-ti-ci-no",
    "másticis": "más-ti-cis",
    "mastieno": "mas-tie-no",
    "mastigador": "mas-ti-ga-dor",
    "mastigar": "mas-ti-gar",
    "mástil": "más-til",
    "mastín": "mas-tín",
    "mastina": "mas-ti-na",
    "mastique": "mas-ti-que",
    "mástique": "más-ti-que",
    "mastitis": "mas-ti-tis",
    "masto": "mas-to",
    "mastodonte": "mas-to-don-te",
    "mastodóntico": "mas-to-dón-ti-co",
    "mastoideo": "mas-toi-de-o",
    "mastoides": "mas-toi-des",
    "mastóloga": "mas-tó-lo-ga",
    "mastología": "mas-to-lo-gí-a",
    "mastológico": "mas-to-ló-gi-co",
    "mastólogo": "mas-tó-lo-go",
    "mastopatía": "mas-to-pa-tí-a",
    "mastozoóloga": "mas-to-zo-ó-lo-ga",
    "mastozoología": "mas-to-zo-o-lo-gí-a",
    "mastozoólogo": "mas-to-zo-ó-lo-go",
    "mastranto": "mas-tran-to",
    "mastranzo": "mas-tran-zo",
    "mastuerzo": "mas-tuer-zo",
    "masturbación": "mas-tur-ba-ción",
    "masturbador": "mas-tur-ba-dor",
    "masturbar": "mas-tur-bar",
    "masturbatorio": "mas-tur-ba-to-rio",
    "masurio": "ma-su-rio",
    "masvale": "mas-va-le",
    "mata": "ma-ta",
    "matabuey": "ma-ta-buey",
    "mataburros": "ma-ta-bu-rros",
    "matacabras": "ma-ta-ca-bras",
    "matacallos": "ma-ta-ca-llos",
    "matacán": "ma-ta-cán",
    "matacandelas": "ma-ta-can-de-las",
    "matacandil": "ma-ta-can-dil",
    "matachín": "ma-ta-chín",
    "matacía": "ma-ta-cí-a",
    "matación": "ma-ta-ción",
    "mataco": "ma-ta-co",
    "matacuás": "ma-ta-cuás",
    "matada": "ma-ta-da",
    "matadero": "ma-ta-de-ro",
    "matado": "ma-ta-do",
    "matador": "ma-ta-dor",
    "matadora": "ma-ta-do-ra",
    "matadura": "ma-ta-du-ra",
    "matafuego": "ma-ta-fue-go",
    "matagallego": "ma-ta-ga-lle-go",
    "matagallegos": "ma-ta-ga-lle-gos",
    "matagallina": "ma-ta-ga-lli-na",
    "matagallos": "ma-ta-ga-llos",
    "matagalpa": "ma-ta-gal-pa",
    "matagalpina": "ma-ta-gal-pi-na",
    "matagalpino": "ma-ta-gal-pi-no",
    "matagigantes": "ma-ta-gi-gan-tes",
    "mataguayo": "ma-ta-gua-yo",
    "matahambre": "ma-ta-ham-bre",
    "matahúmos": "ma-ta-hú-mos",
    "matajudío": "ma-ta-ju-dí-o",
    "matalahúga": "ma-ta-la-hú-ga",
    "matalahúva": "ma-ta-la-hú-va",
    "matalobos": "ma-ta-lo-bos",
    "matalón": "ma-ta-lón",
    "matalona": "ma-ta-lo-na",
    "matalotaje": "ma-ta-lo-ta-je",
    "matalote": "ma-ta-lo-te",
    "matambre": "ma-tam-bre",
    "matamiento": "ma-ta-mien-to",
    "matamoros": "ma-ta-mo-ros",
    "matamoscas": "ma-ta-mos-cas",
    "matancera": "ma-tan-ce-ra",
    "matancero": "ma-tan-ce-ro",
    "matancina": "ma-tan-ci-na",
    "matanga": "ma-tan-ga",
    "matansinga": "ma-tan-sin-ga",
    "matanza": "ma-tan-za",
    "mataojo": "ma-ta-o-jo",
    "matapalo": "ma-ta-pa-lo",
    "matapasiones": "ma-ta-pa-sio-nes",
    "mataperico": "ma-ta-pe-ri-co",
    "mataperra": "ma-ta-pe-rra",
    "mataperrada": "ma-ta-pe-rra-da",
    "mataperrear": "ma-ta-pe-rre-ar",
    "mataperro": "ma-ta-pe-rro",
    "mataperros": "ma-ta-pe-rros",
    "matapiojos": "ma-ta-pio-jos",
    "matapollo": "ma-ta-po-llo",
    "matapolvo": "ma-ta-pol-vo",
    "matapulgas": "ma-ta-pul-gas",
    "mataquintos": "ma-ta-quin-tos",
    "matar": "ma-tar",
    "matarife": "ma-ta-ri-fe",
    "matarile": "ma-ta-ri-le",
    "mataronés": "ma-ta-ro-nés",
    "mataronesa": "ma-ta-ro-ne-sa",
    "matarrata": "ma-ta-rra-ta",
    "matarratas": "ma-ta-rra-tas",
    "matarrubia": "ma-ta-rru-bia",
    "matasano": "ma-ta-sa-no",
    "matasanos": "ma-ta-sa-nos",
    "matasellar": "ma-ta-se-llar",
    "matasellos": "ma-ta-se-llos",
    "matasiete": "ma-ta-sie-te",
    "matasuegras": "ma-ta-sue-gras",
    "matate": "ma-ta-te",
    "matatena": "ma-ta-te-na",
    "matatías": "ma-ta-tí-as",
    "matazón": "ma-ta-zón",
    "mate": "ma-te",
    "matea": "ma-te-a",
    "mateada": "ma-te-a-da",
    "matear": "ma-te-ar",
    "matemática": "ma-te-má-ti-ca",
    "matemáticamente": "ma-te-má-ti-ca-men-te",
    "matemático": "ma-te-má-ti-co",
    "matematismo": "ma-te-ma-tis-mo",
    "mateo": "ma-te-o",
    "matera": "ma-te-ra",
    "materia": "ma-te-ria",
    "material": "ma-te-rial",
    "materialidad": "ma-te-ria-li-dad",
    "materialismo": "ma-te-ria-lis-mo",
    "materialista": "ma-te-ria-lis-ta",
    "materialización": "ma-te-ria-li-za-ción",
    "materializar": "ma-te-ria-li-zar",
    "materialmente": "ma-te-rial-men-te",
    "materna": "ma-ter-na",
    "maternal": "ma-ter-nal",
    "maternalmente": "ma-ter-nal-men-te",
    "maternidad": "ma-ter-ni-dad",
    "maternizar": "ma-ter-ni-zar",
    "materno": "ma-ter-no",
    "matero": "ma-te-ro",
    "mates": "ma-tes",
    "matete": "ma-te-te",
    "matico": "ma-ti-co",
    "matidez": "ma-ti-dez",
    "matiega": "ma-tie-ga",
    "matiego": "ma-tie-go",
    "matihuelo": "ma-ti-hue-lo",
    "matinal": "ma-ti-nal",
    "matiné": "ma-ti-né",
    "matines": "ma-ti-nes",
    "matino": "ma-ti-no",
    "matiz": "ma-tiz",
    "matización": "ma-ti-za-ción",
    "matizar": "ma-ti-zar",
    "matizón": "ma-ti-zón",
    "mato": "ma-to",
    "matoco": "ma-to-co",
    "matojo": "ma-to-jo",
    "matón": "ma-tón",
    "matona": "ma-to-na",
    "matonear": "ma-to-ne-ar",
    "matonesco": "ma-to-nes-co",
    "matonismo": "ma-to-nis-mo",
    "matorral": "ma-to-rral",
    "matorro": "ma-to-rro",
    "matosa": "ma-to-sa",
    "matoso": "ma-to-so",
    "matraca": "ma-tra-ca",
    "matracalada": "ma-tra-ca-la-da",
    "matraco": "ma-tra-co",
    "matraquear": "ma-tra-que-ar",
    "matraqueo": "ma-tra-que-o",
    "matraquista": "ma-tra-quis-ta",
    "matraz": "ma-traz",
    "matrera": "ma-tre-ra",
    "matreramente": "ma-tre-ra-men-te",
    "matrerear": "ma-tre-re-ar",
    "matrería": "ma-tre-rí-a",
    "matrero": "ma-tre-ro",
    "matriarca": "ma-triar-ca",
    "matriarcado": "ma-triar-ca-do",
    "matriarcal": "ma-triar-cal",
    "matricaria": "ma-tri-ca-ria",
    "matricial": "ma-tri-cial",
    "matricida": "ma-tri-ci-da",
    "matricidio": "ma-tri-ci-dio",
    "matrícula": "ma-trí-cu-la",
    "matriculación": "ma-tri-cu-la-ción",
    "matriculada": "ma-tri-cu-la-da",
    "matriculado": "ma-tri-cu-la-do",
    "matriculador": "ma-tri-cu-la-dor",
    "matriculadora": "ma-tri-cu-la-do-ra",
    "matricular": "ma-tri-cu-lar",
    "matrilineal": "ma-tri-li-ne-al",
    "matrimonesca": "ma-tri-mo-nes-ca",
    "matrimonesco": "ma-tri-mo-nes-co",
    "matrimonial": "ma-tri-mo-nial",
    "matrimonialista": "ma-tri-mo-nia-lis-ta",
    "matrimonialmente": "ma-tri-mo-nial-men-te",
    "matrimoniar": "ma-tri-mo-niar",
    "matrimonio": "ma-tri-mo-nio",
    "matrimoño": "ma-tri-mo-ño",
    "matrioska": "ma-trios-ka",
    "matritense": "ma-tri-ten-se",
    "matriz": "ma-triz",
    "matrona": "ma-tro-na",
    "matronal": "ma-tro-nal",
    "matronaza": "ma-tro-na-za",
    "matucho": "ma-tu-cho",
    "matufia": "ma-tu-fia",
    "matul": "ma-tul",
    "matula": "ma-tu-la",
    "matunga": "ma-tun-ga",
    "matungo": "ma-tun-go",
    "matunguera": "ma-tun-gue-ra",
    "maturinés": "ma-tu-ri-nés",
    "maturinesa": "ma-tu-ri-ne-sa",
    "maturranga": "ma-tu-rran-ga",
    "maturrango": "ma-tu-rran-go",
    "matusalén": "ma-tu-sa-lén",
    "matusalena": "ma-tu-sa-le-na",
    "matusaleno": "ma-tu-sa-le-no",
    "matute": "ma-tu-te",
    "matutear": "ma-tu-te-ar",
    "matutera": "ma-tu-te-ra",
    "matutero": "ma-tu-te-ro",
    "matutina": "ma-tu-ti-na",
    "matutinal": "ma-tu-ti-nal",
    "matutino": "ma-tu-ti-no",
    "maula": "mau-la",
    "maular": "mau-lar",
    "maulera": "mau-le-ra",
    "maulería": "mau-le-rí-a",
    "maulero": "mau-le-ro",
    "maulina": "mau-li-na",
    "maulino": "mau-li-no",
    "maullador": "mau-lla-dor",
    "maulladora": "mau-lla-do-ra",
    "maullar": "mau-llar",
    "maullido": "mau-lli-do",
    "maúllo": "ma-ú-llo",
    "maulón": "mau-lón",
    "maulosa": "mau-lo-sa",
    "mauloso": "mau-lo-so",
    "maura": "mau-ra",
    "maure": "mau-re",
    "mauriciana": "mau-ri-cia-na",
    "mauriciano": "mau-ri-cia-no",
    "maurista": "mau-ris-ta",
    "mauritana": "mau-ri-ta-na",
    "mauritano": "mau-ri-ta-no",
    "mauro": "mau-ro",
    "mauseolo": "mau-se-o-lo",
    "máuser": "máu-ser",
    "mausoleo": "mau-so-le-o",
    "maute": "mau-te",
    "mavacure": "ma-va-cu-re",
    "mavita": "ma-vi-ta",
    "mavorcia": "ma-vor-cia",
    "mavorcio": "ma-vor-cio",
    "mavorte": "ma-vor-te",
    "maxifalda": "ma-xi-fal-da",
    "maxila": "ma-xi-la",
    "maxilar": "ma-xi-lar",
    "maxilofacial": "ma-xi-lo-fa-cial",
    "máxima": "má-xi-ma",
    "maximalismo": "ma-xi-ma-lis-mo",
    "maximalista": "ma-xi-ma-lis-ta",
    "máximamente": "má-xi-ma-men-te",
    "máxime": "má-xi-me",
    "maximización": "ma-xi-mi-za-ción",
    "maximizar": "ma-xi-mi-zar",
    "máximo": "má-xi-mo",
    "máximum": "má-xi-mum",
    "maxisingle": "ma-xi-sin-gle",
    "maxmordón": "max-mor-dón",
    "maxtate": "max-ta-te",
    "maxura": "ma-xu-ra",
    "maya": "ma-ya",
    "mayador": "ma-ya-dor",
    "mayadora": "ma-ya-do-ra",
    "mayagüezana": "ma-ya-güe-za-na",
    "mayagüezano": "ma-ya-güe-za-no",
    "mayal": "ma-yal",
    "mayar": "ma-yar",
    "mayate": "ma-ya-te",
    "mayear": "ma-ye-ar",
    "mayestática": "ma-yes-tá-ti-ca",
    "mayestático": "ma-yes-tá-ti-co",
    "mayeto": "ma-ye-to",
    "mayéutica": "ma-yéu-ti-ca",
    "mayéutico": "ma-yéu-ti-co",
    "mayido": "ma-yi-do",
    "mayismo": "ma-yis-mo",
    "mayista": "ma-yis-ta",
    "mayo": "ma-yo",
    "mayocol": "ma-yo-col",
    "mayólica": "ma-yó-li-ca",
    "mayombé": "ma-yom-bé",
    "mayonesa": "ma-yo-ne-sa",
    "mayor": "ma-yor",
    "mayora": "ma-yo-ra",
    "mayoradgo": "ma-yo-rad-go",
    "mayoral": "ma-yo-ral",
    "mayorala": "ma-yo-ra-la",
    "mayoralía": "ma-yo-ra-lí-a",
    "mayorana": "ma-yo-ra-na",
    "mayorar": "ma-yo-rar",
    "mayorazga": "ma-yo-raz-ga",
    "mayorazgo": "ma-yo-raz-go",
    "mayorazguista": "ma-yo-raz-guis-ta",
    "mayordoma": "ma-yor-do-ma",
    "mayordomazgo": "ma-yor-do-maz-go",
    "mayordombre": "ma-yor-dom-bre",
    "mayordomear": "ma-yor-do-me-ar",
    "mayordomía": "ma-yor-do-mí-a",
    "mayordomo": "ma-yor-do-mo",
    "mayorear": "ma-yo-re-ar",
    "mayoreo": "ma-yo-re-o",
    "mayoría": "ma-yo-rí-a",
    "mayoridad": "ma-yo-ri-dad",
    "mayorista": "ma-yo-ris-ta",
    "mayoritariamente": "ma-yo-ri-ta-ria-men-te",
    "mayoritario": "ma-yo-ri-ta-rio",
    "mayormente": "ma-yor-men-te",
    "mayuato": "ma-yua-to",
    "mayueta": "ma-yue-ta",
    "mayúscula": "ma-yús-cu-la",
    "mayúsculo": "ma-yús-cu-lo",
    "maza": "ma-za",
    "mazacote": "ma-za-co-te",
    "mazacotudo": "ma-za-co-tu-do",
    "mazada": "ma-za-da",
    "mazagatos": "ma-za-ga-tos",
    "mazahua": "ma-za-hua",
    "mazamorra": "ma-za-mo-rra",
    "mazana": "ma-za-na",
    "mazaneta": "ma-za-ne-ta",
    "mazapán": "ma-za-pán",
    "mazapanera": "ma-za-pa-ne-ra",
    "mazapanero": "ma-za-pa-ne-ro",
    "mazar": "ma-zar",
    "mazarí": "ma-za-rí",
    "mazarota": "ma-za-ro-ta",
    "mazarrón": "ma-za-rrón",
    "mazateca": "ma-za-te-ca",
    "mazateco": "ma-za-te-co",
    "mazatleca": "ma-za-tle-ca",
    "mazatleco": "ma-za-tle-co",
    "mazazo": "ma-za-zo",
    "mazdeísmo": "maz-de-ís-mo",
    "mazdeísta": "maz-de-ís-ta",
    "mazmodina": "maz-mo-di-na",
    "mazmorra": "maz-mo-rra",
    "maznar": "maz-nar",
    "mazo": "ma-zo",
    "mazonada": "ma-zo-na-da",
    "mazonado": "ma-zo-na-do",
    "mazonadura": "ma-zo-na-du-ra",
    "mazonar": "ma-zo-nar",
    "mazonear": "ma-zo-ne-ar",
    "mazonería": "ma-zo-ne-rí-a",
    "mazonero": "ma-zo-ne-ro",
    "mazorca": "ma-zor-ca",
    "mazorgano": "ma-zor-ga-no",
    "mazorquear": "ma-zor-que-ar",
    "mazorquera": "ma-zor-que-ra",
    "mazorquero": "ma-zor-que-ro",
    "mazorral": "ma-zo-rral",
    "mazorralmente": "ma-zo-rral-men-te",
    "mazuelo": "ma-zue-lo",
    "mazurca": "ma-zur-ca",
    "mbayá": "mba-yá",
    "mbicuré": "mbi-cu-ré",
    "mea": "me-a",
    "meada": "me-a-da",
    "meadero": "me-a-de-ro",
    "meado": "me-a-do",
    "meadura": "me-a-du-ra",
    "meaja": "me-a-ja",
    "meajuela": "me-a-jue-la",
    "meandro": "me-an-dro",
    "meano": "me-a-no",
    "meapilas": "me-a-pi-las",
    "mear": "me-ar",
    "meatad": "me-a-tad",
    "meato": "me-a-to",
    "meauca": "me-au-ca",
    "meca": "me-ca",
    "mecachis": "me-ca-chis",
    "mecana": "me-ca-na",
    "mecánica": "me-cá-ni-ca",
    "mecánicamente": "me-cá-ni-ca-men-te",
    "mecanicismo": "me-ca-ni-cis-mo",
    "mecanicista": "me-ca-ni-cis-ta",
    "mecánico": "me-cá-ni-co",
    "mecanismo": "me-ca-nis-mo",
    "mecanización": "me-ca-ni-za-ción",
    "mecanizado": "me-ca-ni-za-do",
    "mecanizar": "me-ca-ni-zar",
    "mecano": "me-ca-no",
    "mecanógrafa": "me-ca-nó-gra-fa",
    "mecanografía": "me-ca-no-gra-fí-a",
    "mecanografiar": "me-ca-no-gra-fiar",
    "mecanográfica": "me-ca-no-grá-fi-ca",
    "mecanográfico": "me-ca-no-grá-fi-co",
    "mecanógrafo": "me-ca-nó-gra-fo",
    "mecanoterapia": "me-ca-no-te-ra-pia",
    "mecapacle": "me-ca-pa-cle",
    "mecapal": "me-ca-pal",
    "mecapalera": "me-ca-pa-le-ra",
    "mecapalero": "me-ca-pa-le-ro",
    "mecatazo": "me-ca-ta-zo",
    "mecate": "me-ca-te",
    "mecateada": "me-ca-te-a-da",
    "mecateado": "me-ca-te-a-do",
    "mecatear": "me-ca-te-ar",
    "mecatera": "me-ca-te-ra",
    "mecatiar": "me-ca-tiar",
    "mecato": "me-ca-to",
    "mecedero": "me-ce-de-ro",
    "mecedor": "me-ce-dor",
    "mecedora": "me-ce-do-ra",
    "mecedura": "me-ce-du-ra",
    "mecenas": "me-ce-nas",
    "mecenazgo": "me-ce-naz-go",
    "mecer": "me-cer",
    "mecha": "me-cha",
    "mechadera": "me-cha-de-ra",
    "mechar": "me-char",
    "mechazo": "me-cha-zo",
    "mechera": "me-che-ra",
    "mechero": "me-che-ro",
    "mechificar": "me-chi-fi-car",
    "mechinal": "me-chi-nal",
    "mechoacán": "me-cho-a-cán",
    "mechón": "me-chón",
    "mechoneada": "me-cho-ne-a-da",
    "mechonear": "me-cho-ne-ar",
    "mechosa": "me-cho-sa",
    "mechoso": "me-cho-so",
    "mechuda": "me-chu-da",
    "mechudo": "me-chu-do",
    "mecida": "me-ci-da",
    "meco": "me-co",
    "meconio": "me-co-nio",
    "meda": "me-da",
    "medalla": "me-da-lla",
    "medallero": "me-da-lle-ro",
    "medallista": "me-da-llis-ta",
    "medallón": "me-da-llón",
    "medaño": "me-da-ño",
    "médano": "mé-da-no",
    "medanosa": "me-da-no-sa",
    "medanoso": "me-da-no-so",
    "medellinense": "me-de-lli-nen-se",
    "medersa": "me-der-sa",
    "media": "me-dia",
    "mediacaña": "me-dia-ca-ña",
    "mediación": "me-dia-ción",
    "mediada": "me-dia-da",
    "mediado": "me-dia-do",
    "mediador": "me-dia-dor",
    "mediadora": "me-dia-do-ra",
    "mediagua": "me-dia-gua",
    "medial": "me-dial",
    "medialuna": "me-dia-lu-na",
    "mediana": "me-dia-na",
    "medianamente": "me-dia-na-men-te",
    "medianedo": "me-dia-ne-do",
    "medianeja": "me-dia-ne-ja",
    "medianejo": "me-dia-ne-jo",
    "medianera": "me-dia-ne-ra",
    "medianería": "me-dia-ne-rí-a",
    "medianero": "me-dia-ne-ro",
    "medianeza": "me-dia-ne-za",
    "medianía": "me-dia-ní-a",
    "medianidad": "me-dia-ni-dad",
    "medianil": "me-dia-nil",
    "medianista": "me-dia-nis-ta",
    "mediano": "me-dia-no",
    "medianoche": "me-dia-no-che",
    "mediante": "me-dian-te",
    "mediapunta": "me-dia-pun-ta",
    "mediar": "me-diar",
    "mediastino": "me-dias-ti-no",
    "mediata": "me-dia-ta",
    "mediatamente": "me-dia-ta-men-te",
    "mediateca": "me-dia-te-ca",
    "mediático": "me-diá-ti-co",
    "mediatización": "me-dia-ti-za-ción",
    "mediatizar": "me-dia-ti-zar",
    "mediato": "me-dia-to",
    "mediator": "me-dia-tor",
    "mediatriz": "me-dia-triz",
    "medibacha": "me-di-ba-cha",
    "medible": "me-di-ble",
    "médica": "mé-di-ca",
    "medicable": "me-di-ca-ble",
    "medicación": "me-di-ca-ción",
    "medicamentar": "me-di-ca-men-tar",
    "medicamento": "me-di-ca-men-to",
    "medicamentosa": "me-di-ca-men-to-sa",
    "medicamentoso": "me-di-ca-men-to-so",
    "medicar": "me-di-car",
    "medicastro": "me-di-cas-tro",
    "medicatura": "me-di-ca-tu-ra",
    "mediceo": "me-di-ce-o",
    "medicina": "me-di-ci-na",
    "medicinable": "me-di-ci-na-ble",
    "medicinal": "me-di-ci-nal",
    "medicinalmente": "me-di-ci-nal-men-te",
    "medicinamiento": "me-di-ci-na-mien-to",
    "medicinante": "me-di-ci-nan-te",
    "medicinar": "me-di-ci-nar",
    "medición": "me-di-ción",
    "médico": "mé-di-co",
    "medicolegal": "me-di-co-le-gal",
    "medicucha": "me-di-cu-cha",
    "medicucho": "me-di-cu-cho",
    "medida": "me-di-da",
    "medidamente": "me-di-da-men-te",
    "medidor": "me-di-dor",
    "medidora": "me-di-do-ra",
    "mediera": "me-die-ra",
    "mediería": "me-die-rí-a",
    "mediero": "me-die-ro",
    "medieval": "me-die-val",
    "medievalidad": "me-die-va-li-dad",
    "medievalismo": "me-die-va-lis-mo",
    "medievalista": "me-die-va-lis-ta",
    "medievalizante": "me-die-va-li-zan-te",
    "medievo": "me-die-vo",
    "medina": "me-di-na",
    "medinés": "me-di-nés",
    "medinesa": "me-di-ne-sa",
    "medio": "me-dio",
    "medioambiental": "me-dio-am-bien-tal",
    "medioambiente": "me-dio-am-bien-te",
    "mediocampista": "me-dio-cam-pis-ta",
    "mediocre": "me-dio-cre",
    "mediocremente": "me-dio-cre-men-te",
    "mediocridad": "me-dio-cri-dad",
    "mediodía": "me-dio-dí-a",
    "medioeval": "me-dio-e-val",
    "medioevo": "me-dio-e-vo",
    "mediofondista": "me-dio-fon-dis-ta",
    "mediofondo": "me-dio-fon-do",
    "mediometraje": "me-dio-me-tra-je",
    "mediomundo": "me-dio-mun-do",
    "mediopaño": "me-dio-pa-ño",
    "mediopensionado": "me-dio-pen-sio-na-do",
    "mediopensionista": "me-dio-pen-sio-nis-ta",
    "mediopié": "me-dio-pié",
    "mediquillo": "me-di-qui-llo",
    "medir": "me-dir",
    "meditabunda": "me-di-ta-bun-da",
    "meditabundo": "me-di-ta-bun-do",
    "meditación": "me-di-ta-ción",
    "meditador": "me-di-ta-dor",
    "meditadora": "me-di-ta-do-ra",
    "meditar": "me-di-tar",
    "meditativa": "me-di-ta-ti-va",
    "meditativo": "me-di-ta-ti-vo",
    "mediterránea": "me-di-te-rrá-ne-a",
    "mediterráneo": "me-di-te-rrá-ne-o",
    "médium": "mé-dium",
    "medo": "me-do",
    "medra": "me-dra",
    "medrador": "me-dra-dor",
    "medradora": "me-dra-do-ra",
    "medrana": "me-dra-na",
    "medranza": "me-dran-za",
    "medrar": "me-drar",
    "medriñaque": "me-dri-ña-que",
    "medro": "me-dro",
    "medrosa": "me-dro-sa",
    "medrosamente": "me-dro-sa-men-te",
    "medrosía": "me-dro-sí-a",
    "medroso": "me-dro-so",
    "medula": "me-du-la",
    "médula": "mé-du-la",
    "medular": "me-du-lar",
    "medulosa": "me-du-lo-sa",
    "meduloso": "me-du-lo-so",
    "medusa": "me-du-sa",
    "medusea": "me-du-se-a",
    "meduseo": "me-du-se-o",
    "mefistofélica": "me-fis-to-fé-li-ca",
    "mefistofélico": "me-fis-to-fé-li-co",
    "mefítica": "me-fí-ti-ca",
    "mefítico": "me-fí-ti-co",
    "mega": "me-ga",
    "megabyte": "me-gaby-te",
    "megaciclo": "me-ga-ci-clo",
    "megafonía": "me-ga-fo-ní-a",
    "megáfono": "me-gá-fo-no",
    "megahercio": "me-ga-her-cio",
    "megahertz": "me-ga-hertz",
    "megalítica": "me-ga-lí-ti-ca",
    "megalítico": "me-ga-lí-ti-co",
    "megalito": "me-ga-li-to",
    "megalómana": "me-ga-ló-ma-na",
    "megalomanía": "me-ga-lo-ma-ní-a",
    "megalómano": "me-ga-ló-ma-no",
    "megalópolis": "me-ga-ló-po-lis",
    "megalosaurio": "me-ga-lo-sau-rio",
    "mégano": "mé-ga-no",
    "megarense": "me-ga-ren-se",
    "megarón": "me-ga-rón",
    "megaterio": "me-ga-te-rio",
    "megatón": "me-ga-tón",
    "megavatio": "me-ga-va-tio",
    "megawatt": "me-ga-watt",
    "mego": "me-go",
    "meguez": "me-guez",
    "mehala": "me-ha-la",
    "mehari": "me-ha-ri",
    "meiga": "mei-ga",
    "meigo": "mei-go",
    "meiosis": "meio-sis",
    "meitad": "mei-tad",
    "meitnerio": "meit-ne-rio",
    "mejala": "me-ja-la",
    "mejana": "me-ja-na",
    "mejedor": "me-je-dor",
    "mejenga": "me-jen-ga",
    "mejengue": "me-jen-gue",
    "mejer": "me-jer",
    "mejicana": "me-ji-ca-na",
    "mejicanismo": "me-ji-ca-nis-mo",
    "mejicano": "me-ji-ca-no",
    "mejida": "me-ji-da",
    "mejido": "me-ji-do",
    "mejilla": "me-ji-lla",
    "mejillón": "me-ji-llón",
    "mejillonera": "me-ji-llo-ne-ra",
    "mejillonero": "me-ji-llo-ne-ro",
    "mejor": "me-jor",
    "mejora": "me-jo-ra",
    "mejorable": "me-jo-ra-ble",
    "mejoramiento": "me-jo-ra-mien-to",
    "mejorana": "me-jo-ra-na",
    "mejorar": "me-jo-rar",
    "mejoría": "me-jo-rí-a",
    "mejunje": "me-jun-je",
    "mela": "me-la",
    "melada": "me-la-da",
    "melado": "me-la-do",
    "meladucha": "me-la-du-cha",
    "meladura": "me-la-du-ra",
    "meláfido": "me-lá-fi-do",
    "melamina": "me-la-mi-na",
    "melampo": "me-lam-po",
    "melancolía": "me-lan-co-lí-a",
    "melancólica": "me-lan-có-li-ca",
    "melancólicamente": "me-lan-có-li-ca-men-te",
    "melancólico": "me-lan-có-li-co",
    "melancolizar": "me-lan-co-li-zar",
    "melanconía": "me-lan-co-ní-a",
    "melanconiosa": "me-lan-co-nio-sa",
    "melanconioso": "me-lan-co-nio-so",
    "melandro": "me-lan-dro",
    "melanesia": "me-la-ne-sia",
    "melanésica": "me-la-né-si-ca",
    "melanésico": "me-la-né-si-co",
    "melanesio": "me-la-ne-sio",
    "melánico": "me-lá-ni-co",
    "melanina": "me-la-ni-na",
    "melanita": "me-la-ni-ta",
    "melanóforo": "me-la-nó-fo-ro",
    "melanoma": "me-la-no-ma",
    "melanosis": "me-la-no-sis",
    "melanuria": "me-la-nu-ria",
    "melapia": "me-la-pia",
    "melar": "me-lar",
    "melarchía": "me-lar-chí-a",
    "melarquía": "me-lar-quí-a",
    "melastomácea": "me-las-to-má-ce-a",
    "melastomáceo": "me-las-to-má-ce-o",
    "melastomatácea": "me-las-to-ma-tá-ce-a",
    "melastomatáceo": "me-las-to-ma-tá-ce-o",
    "melatonina": "me-la-to-ni-na",
    "melaza": "me-la-za",
    "melca": "mel-ca",
    "melcocha": "mel-co-cha",
    "melcochero": "mel-co-che-ro",
    "melcochón": "mel-co-chón",
    "melcochoso": "mel-co-cho-so",
    "melcochudo": "mel-co-chu-do",
    "meldar": "mel-dar",
    "meldense": "mel-den-se",
    "melé": "me-lé",
    "melecina": "me-le-ci-na",
    "melena": "me-le-na",
    "melenera": "me-le-ne-ra",
    "melengüelear": "me-len-güe-le-ar",
    "meleno": "me-le-no",
    "melense": "me-len-se",
    "melenuda": "me-le-nu-da",
    "melenudo": "me-le-nu-do",
    "melera": "me-le-ra",
    "melero": "me-le-ro",
    "melga": "mel-ga",
    "melgacho": "mel-ga-cho",
    "melgar": "mel-gar",
    "melgo": "mel-go",
    "melgrana": "mel-gra-na",
    "melguizo": "mel-gui-zo",
    "meliácea": "me-liá-ce-a",
    "meliáceo": "me-liá-ce-o",
    "mélica": "mé-li-ca",
    "mélico": "mé-li-co",
    "melífero": "me-lí-fe-ro",
    "melificación": "me-li-fi-ca-ción",
    "melificada": "me-li-fi-ca-da",
    "melificado": "me-li-fi-ca-do",
    "melificador": "me-li-fi-ca-dor",
    "melificar": "me-li-fi-car",
    "melífico": "me-lí-fi-co",
    "meliflua": "me-li-flua",
    "melifluamente": "me-li-flua-men-te",
    "melifluidad": "me-li-flui-dad",
    "melifluo": "me-li-fluo",
    "melillense": "me-li-llen-se",
    "meliloto": "me-li-lo-to",
    "melina": "me-li-na",
    "melindre": "me-lin-dre",
    "melindrear": "me-lin-dre-ar",
    "melindrera": "me-lin-dre-ra",
    "melindrería": "me-lin-dre-rí-a",
    "melindrero": "me-lin-dre-ro",
    "melindrizar": "me-lin-dri-zar",
    "melindro": "me-lin-dro",
    "melindrosa": "me-lin-dro-sa",
    "melindrosamente": "me-lin-dro-sa-men-te",
    "melindroso": "me-lin-dro-so",
    "melinita": "me-li-ni-ta",
    "melino": "me-li-no",
    "melión": "me-lión",
    "meliorativo": "me-lio-ra-ti-vo",
    "melipillana": "me-li-pi-lla-na",
    "melipillano": "me-li-pi-lla-no",
    "melis": "me-lis",
    "melisa": "me-li-sa",
    "melisma": "me-lis-ma",
    "melismático": "me-lis-má-ti-co",
    "melito": "me-li-to",
    "mella": "me-lla",
    "mellada": "me-lla-da",
    "mellado": "me-lla-do",
    "melladura": "me-lla-du-ra",
    "mellar": "me-llar",
    "melliza": "me-lli-za",
    "mellizo": "me-lli-zo",
    "melloco": "me-llo-co",
    "mellón": "me-llón",
    "melocotón": "me-lo-co-tón",
    "melocotonar": "me-lo-co-to-nar",
    "melocotonero": "me-lo-co-to-ne-ro",
    "melodía": "me-lo-dí-a",
    "melódica": "me-ló-di-ca",
    "melódicamente": "me-ló-di-ca-men-te",
    "melódico": "me-ló-di-co",
    "melodiosa": "me-lo-dio-sa",
    "melodiosamente": "me-lo-dio-sa-men-te",
    "melodioso": "me-lo-dio-so",
    "melodista": "me-lo-dis-ta",
    "melodrama": "me-lo-dra-ma",
    "melodramáticamente": "me-lo-dra-má-ti-ca-men-te",
    "melodramático": "me-lo-dra-má-ti-co",
    "melodreña": "me-lo-dre-ña",
    "melografía": "me-lo-gra-fí-a",
    "meloja": "me-lo-ja",
    "melojar": "me-lo-jar",
    "melojo": "me-lo-jo",
    "melolonta": "me-lo-lon-ta",
    "melómana": "me-ló-ma-na",
    "melomanía": "me-lo-ma-ní-a",
    "melómano": "me-ló-ma-no",
    "melón": "me-lón",
    "melona": "me-lo-na",
    "melonada": "me-lo-na-da",
    "melonar": "me-lo-nar",
    "meloncete": "me-lon-ce-te",
    "meloncillo": "me-lon-ci-llo",
    "melonera": "me-lo-ne-ra",
    "melonero": "me-lo-ne-ro",
    "melopea": "me-lo-pe-a",
    "melopeya": "me-lo-pe-ya",
    "melosa": "me-lo-sa",
    "melosidad": "me-lo-si-dad",
    "melosilla": "me-lo-si-lla",
    "meloso": "me-lo-so",
    "melote": "me-lo-te",
    "melquisedeciana": "mel-qui-se-de-cia-na",
    "melquisedeciano": "mel-qui-se-de-cia-no",
    "melsa": "mel-sa",
    "melva": "mel-va",
    "mema": "me-ma",
    "memada": "me-ma-da",
    "membrada": "mem-bra-da",
    "membrado": "mem-bra-do",
    "membráfono": "mem-brá-fo-no",
    "membrana": "mem-bra-na",
    "membranácea": "mem-bra-ná-ce-a",
    "membranáceo": "mem-bra-ná-ce-o",
    "membranófono": "mem-bra-nó-fo-no",
    "membranosa": "mem-bra-no-sa",
    "membranoso": "mem-bra-no-so",
    "membranza": "mem-bran-za",
    "membrar": "mem-brar",
    "membresía": "mem-bre-sí-a",
    "membretado": "mem-bre-ta-do",
    "membretar": "mem-bre-tar",
    "membrete": "mem-bre-te",
    "membría": "mem-brí-a",
    "membrilla": "mem-bri-lla",
    "membrillar": "mem-bri-llar",
    "membrillate": "mem-bri-lla-te",
    "membrillero": "mem-bri-lle-ro",
    "membrillete": "mem-bri-lle-te",
    "membrillo": "mem-bri-llo",
    "membruda": "mem-bru-da",
    "membrudamente": "mem-bru-da-men-te",
    "membrudo": "mem-bru-do",
    "memela": "me-me-la",
    "memento": "me-men-to",
    "memez": "me-mez",
    "memnónida": "mem-nó-ni-da",
    "memo": "me-mo",
    "memorable": "me-mo-ra-ble",
    "memoranda": "me-mo-ran-da",
    "memorando": "me-mo-ran-do",
    "memorándum": "me-mo-rán-dum",
    "memorar": "me-mo-rar",
    "memorativa": "me-mo-ra-ti-va",
    "memorativo": "me-mo-ra-ti-vo",
    "memoria": "me-mo-ria",
    "memorial": "me-mo-rial",
    "memorialesca": "me-mo-ria-les-ca",
    "memorialesco": "me-mo-ria-les-co",
    "memorialista": "me-mo-ria-lis-ta",
    "memoriógrafo": "me-mo-rió-gra-fo",
    "memorión": "me-mo-rión",
    "memoriosa": "me-mo-rio-sa",
    "memorioso": "me-mo-rio-so",
    "memorismo": "me-mo-ris-mo",
    "memorista": "me-mo-ris-ta",
    "memorísticamente": "me-mo-rís-ti-ca-men-te",
    "memorístico": "me-mo-rís-ti-co",
    "memorización": "me-mo-ri-za-ción",
    "memorizar": "me-mo-ri-zar",
    "memorosa": "me-mo-ro-sa",
    "memoroso": "me-mo-ro-so",
    "mena": "me-na",
    "ménade": "mé-na-de",
    "menaje": "me-na-je",
    "menar": "me-nar",
    "menarca": "me-nar-ca",
    "menarquia": "me-nar-quia",
    "menaza": "me-na-za",
    "menazar": "me-na-zar",
    "menchevique": "men-che-vi-que",
    "menchevismo": "men-che-vis-mo",
    "mencieña": "men-cie-ña",
    "mencieño": "men-cie-ño",
    "mención": "men-ción",
    "mencionable": "men-cio-na-ble",
    "mencionar": "men-cio-nar",
    "menda": "men-da",
    "mendacidad": "men-da-ci-dad",
    "mendacio": "men-da-cio",
    "mendaz": "men-daz",
    "mendelevio": "men-de-le-vio",
    "mendeliana": "men-de-lia-na",
    "mendeliano": "men-de-lia-no",
    "mendelismo": "men-de-lis-mo",
    "mendicación": "men-di-ca-ción",
    "mendicante": "men-di-can-te",
    "mendicidad": "men-di-ci-dad",
    "mendiga": "men-di-ga",
    "méndiga": "mén-di-ga",
    "mendiganta": "men-di-gan-ta",
    "mendigante": "men-di-gan-te",
    "mendigar": "men-di-gar",
    "mendigo": "men-di-go",
    "méndigo": "mén-di-go",
    "mendiguez": "men-di-guez",
    "mendocina": "men-do-ci-na",
    "mendocino": "men-do-ci-no",
    "mendosa": "men-do-sa",
    "mendosamente": "men-do-sa-men-te",
    "mendoso": "men-do-so",
    "mendrugo": "men-dru-go",
    "mene": "me-ne",
    "meneador": "me-ne-a-dor",
    "meneadora": "me-ne-a-do-ra",
    "menear": "me-ne-ar",
    "menegilda": "me-ne-gil-da",
    "meneo": "me-ne-o",
    "menés": "me-nés",
    "menesa": "me-ne-sa",
    "menester": "me-nes-ter",
    "menesterosa": "me-nes-te-ro-sa",
    "menesterosidad": "me-nes-te-ro-si-dad",
    "menesteroso": "me-nes-te-ro-so",
    "menestra": "me-nes-tra",
    "menestral": "me-nes-tral",
    "menestrala": "me-nes-tra-la",
    "menestralería": "me-nes-tra-le-rí-a",
    "menestralía": "me-nes-tra-lí-a",
    "menestrete": "me-nes-tre-te",
    "menestril": "me-nes-tril",
    "menesunda": "me-ne-sun-da",
    "menfita": "men-fi-ta",
    "menfítica": "men-fí-ti-ca",
    "menfítico": "men-fí-ti-co",
    "mengajo": "men-ga-jo",
    "mengala": "men-ga-la",
    "mengambrea": "men-gam-bre-a",
    "mengana": "men-ga-na",
    "mengano": "men-ga-no",
    "menge": "men-ge",
    "mengía": "men-gí-a",
    "mengua": "men-gua",
    "menguada": "men-gua-da",
    "menguadamente": "men-gua-da-men-te",
    "menguado": "men-gua-do",
    "menguamiento": "men-gua-mien-to",
    "menguante": "men-guan-te",
    "menguar": "men-guar",
    "mengue": "men-gue",
    "menhir": "men-hir",
    "menina": "me-ni-na",
    "meninge": "me-nin-ge",
    "meníngea": "me-nín-ge-a",
    "meníngeo": "me-nín-ge-o",
    "meningítica": "me-nin-gí-ti-ca",
    "meningítico": "me-nin-gí-ti-co",
    "meningitis": "me-nin-gi-tis",
    "meningocele": "me-nin-go-ce-le",
    "meningococo": "me-nin-go-co-co",
    "menino": "me-ni-no",
    "menipea": "me-ni-pe-a",
    "menipeo": "me-ni-pe-o",
    "menique": "me-ni-que",
    "meñique": "me-ñi-que",
    "menisco": "me-nis-co",
    "menispermácea": "me-nis-per-má-ce-a",
    "menispermáceo": "me-nis-per-má-ce-o",
    "menjuí": "men-juí",
    "menjunje": "men-jun-je",
    "menjurje": "men-jur-je",
    "menologio": "me-no-lo-gio",
    "menonia": "me-no-nia",
    "menonita": "me-no-ni-ta",
    "menopausia": "me-no-pau-sia",
    "menopáusico": "me-no-páu-si-co",
    "menor": "me-nor",
    "menoración": "me-no-ra-ción",
    "menorar": "me-no-rar",
    "menorera": "me-no-re-ra",
    "menorero": "me-no-re-ro",
    "menoreta": "me-no-re-ta",
    "menorete": "me-no-re-te",
    "menoría": "me-no-rí-a",
    "menoridad": "me-no-ri-dad",
    "menorista": "me-no-ris-ta",
    "menorquín": "me-nor-quín",
    "menorquina": "me-nor-qui-na",
    "menorragia": "me-no-rra-gia",
    "menos": "me-nos",
    "menoscabador": "me-nos-ca-ba-dor",
    "menoscabadora": "me-nos-ca-ba-do-ra",
    "menoscabar": "me-nos-ca-bar",
    "menoscabo": "me-nos-ca-bo",
    "menoscuenta": "me-nos-cuen-ta",
    "menospreciable": "me-nos-pre-cia-ble",
    "menospreciablemente": "me-nos-pre-cia-ble-men-te",
    "menospreciador": "me-nos-pre-cia-dor",
    "menospreciadora": "me-nos-pre-cia-do-ra",
    "menospreciamiento": "me-nos-pre-cia-mien-to",
    "menospreciar": "me-nos-pre-ciar",
    "menospreciativa": "me-nos-pre-cia-ti-va",
    "menospreciativo": "me-nos-pre-cia-ti-vo",
    "menosprecio": "me-nos-pre-cio",
    "menostasia": "me-nos-ta-sia",
    "mensa": "men-sa",
    "mensafónico": "men-sa-fó-ni-co",
    "mensáfono": "men-sá-fo-no",
    "mensaje": "men-sa-je",
    "mensajera": "men-sa-je-ra",
    "mensajería": "men-sa-je-rí-a",
    "mensajero": "men-sa-je-ro",
    "mensil": "men-sil",
    "menso": "men-so",
    "menstrua": "mens-trua",
    "menstruación": "mens-trua-ción",
    "menstrual": "mens-trual",
    "menstrualmente": "mens-trual-men-te",
    "menstruante": "mens-truan-te",
    "menstruar": "mens-truar",
    "menstruo": "mens-truo",
    "menstruosa": "mens-truo-sa",
    "menstruoso": "mens-truo-so",
    "mensú": "men-sú",
    "mensual": "men-sual",
    "mensualidad": "men-sua-li-dad",
    "mensualizar": "men-sua-li-zar",
    "mensualmente": "men-sual-men-te",
    "ménsula": "mén-su-la",
    "mensura": "men-su-ra",
    "mensurabilidad": "men-su-ra-bi-li-dad",
    "mensurable": "men-su-ra-ble",
    "mensuración": "men-su-ra-ción",
    "mensurador": "men-su-ra-dor",
    "mensuradora": "men-su-ra-do-ra",
    "mensural": "men-su-ral",
    "mensurar": "men-su-rar",
    "mensurativo": "men-su-ra-ti-vo",
    "menta": "men-ta",
    "mentada": "men-ta-da",
    "mentado": "men-ta-do",
    "mental": "men-tal",
    "mentalidad": "men-ta-li-dad",
    "mentalismo": "men-ta-lis-mo",
    "mentalización": "men-ta-li-za-ción",
    "mentalizar": "men-ta-li-zar",
    "mentalmente": "men-tal-men-te",
    "mentar": "men-tar",
    "mentas": "men-tas",
    "mentastro": "men-tas-tro",
    "mente": "men-te",
    "mentecapta": "men-te-cap-ta",
    "mentecapto": "men-te-cap-to",
    "mentecata": "men-te-ca-ta",
    "mentecatada": "men-te-ca-ta-da",
    "mentecatería": "men-te-ca-te-rí-a",
    "mentecatez": "men-te-ca-tez",
    "mentecato": "men-te-ca-to",
    "mentesana": "men-te-sa-na",
    "mentesano": "men-te-sa-no",
    "mentida": "men-ti-da",
    "mentidero": "men-ti-de-ro",
    "mentido": "men-ti-do",
    "mentir": "men-tir",
    "mentira": "men-ti-ra",
    "mentirijilla": "men-ti-ri-ji-lla",
    "mentirijillas": "men-ti-ri-ji-llas",
    "mentirosa": "men-ti-ro-sa",
    "mentirosamente": "men-ti-ro-sa-men-te",
    "mentiroso": "men-ti-ro-so",
    "mentís": "men-tís",
    "mentol": "men-tol",
    "mentolado": "men-to-la-do",
    "mentolato": "men-to-la-to",
    "mentón": "men-tón",
    "mentonera": "men-to-ne-ra",
    "mentor": "men-tor",
    "mentora": "men-to-ra",
    "menú": "me-nú",
    "menuceles": "me-nu-ce-les",
    "menucia": "me-nu-cia",
    "menuda": "me-nu-da",
    "menudamente": "me-nu-da-men-te",
    "menudear": "me-nu-de-ar",
    "menudencia": "me-nu-den-cia",
    "menudeo": "me-nu-de-o",
    "menudera": "me-nu-de-ra",
    "menudero": "me-nu-de-ro",
    "menudillo": "me-nu-di-llo",
    "menudo": "me-nu-do",
    "menudos": "me-nu-dos",
    "menuza": "me-nu-za",
    "menuzar": "me-nu-zar",
    "menuzo": "me-nu-zo",
    "meódromo": "me-ó-dro-mo",
    "meoguil": "me-o-guil",
    "meollar": "me-o-llar",
    "meollo": "me-o-llo",
    "meolluda": "me-o-llu-da",
    "meolludo": "me-o-llu-do",
    "meón": "me-ón",
    "meona": "me-o-na",
    "mequetrefe": "me-que-tre-fe",
    "mequí": "me-quí",
    "mera": "me-ra",
    "meramente": "me-ra-men-te",
    "merar": "me-rar",
    "merca": "mer-ca",
    "mercachifle": "mer-ca-chi-fle",
    "mercadante": "mer-ca-dan-te",
    "mercadear": "mer-ca-de-ar",
    "mercadeo": "mer-ca-de-o",
    "mercader": "mer-ca-der",
    "mercadera": "mer-ca-de-ra",
    "mercadería": "mer-ca-de-rí-a",
    "mercaderil": "mer-ca-de-ril",
    "mercadero": "mer-ca-de-ro",
    "mercadillo": "mer-ca-di-llo",
    "mercado": "mer-ca-do",
    "mercador": "mer-ca-dor",
    "mercadora": "mer-ca-do-ra",
    "mercadoría": "mer-ca-do-rí-a",
    "mercadotecnia": "mer-ca-do-tec-nia",
    "mercadotécnica": "mer-ca-do-téc-ni-ca",
    "mercadotécnico": "mer-ca-do-téc-ni-co",
    "mercaduría": "mer-ca-du-rí-a",
    "mercal": "mer-cal",
    "mercancear": "mer-can-ce-ar",
    "mercancía": "mer-can-cí-a",
    "mercancías": "mer-can-cí-as",
    "mercante": "mer-can-te",
    "mercantesca": "mer-can-tes-ca",
    "mercantesco": "mer-can-tes-co",
    "mercantil": "mer-can-til",
    "mercantilismo": "mer-can-ti-lis-mo",
    "mercantilista": "mer-can-ti-lis-ta",
    "mercantilización": "mer-can-ti-li-za-ción",
    "mercantilizar": "mer-can-ti-li-zar",
    "mercantilmente": "mer-can-til-men-te",
    "mercantiva": "mer-can-ti-va",
    "mercantivo": "mer-can-ti-vo",
    "mercar": "mer-car",
    "merced": "mer-ced",
    "mercedaria": "mer-ce-da-ria",
    "mercedario": "mer-ce-da-rio",
    "mercenaria": "mer-ce-na-ria",
    "mercenariamente": "mer-ce-na-ria-men-te",
    "mercenario": "mer-ce-na-rio",
    "mercendear": "mer-cen-de-ar",
    "mercendera": "mer-cen-de-ra",
    "mercendero": "mer-cen-de-ro",
    "mercera": "mer-ce-ra",
    "mercería": "mer-ce-rí-a",
    "mercerización": "mer-ce-ri-za-ción",
    "mercerizado": "mer-ce-ri-za-do",
    "mercerizar": "mer-ce-ri-zar",
    "mercero": "mer-ce-ro",
    "merchán": "mer-chán",
    "merchandising": "mer-chan-di-sing",
    "merchaniega": "mer-cha-nie-ga",
    "merchaniego": "mer-cha-nie-go",
    "merchante": "mer-chan-te",
    "merchantería": "mer-chan-te-rí-a",
    "merchera": "mer-che-ra",
    "merchero": "mer-che-ro",
    "mercromina": "mer-cro-mi-na",
    "merculina": "mer-cu-li-na",
    "merculino": "mer-cu-li-no",
    "mercurial": "mer-cu-rial",
    "mercúrica": "mer-cú-ri-ca",
    "mercúrico": "mer-cú-ri-co",
    "mercurio": "mer-cu-rio",
    "mercurioso": "mer-cu-rio-so",
    "mercurocromo": "mer-cu-ro-cro-mo",
    "merdellón": "mer-de-llón",
    "merdellona": "mer-de-llo-na",
    "merdosa": "mer-do-sa",
    "merdoso": "mer-do-so",
    "mere": "me-re",
    "merecedor": "me-re-ce-dor",
    "merecedora": "me-re-ce-do-ra",
    "merecer": "me-re-cer",
    "merecidamente": "me-re-ci-da-men-te",
    "merecido": "me-re-ci-do",
    "merecimiento": "me-re-ci-mien-to",
    "merendada": "me-ren-da-da",
    "merendar": "me-ren-dar",
    "merendero": "me-ren-de-ro",
    "merendilla": "me-ren-di-lla",
    "merendillar": "me-ren-di-llar",
    "merendita": "me-ren-di-ta",
    "merendola": "me-ren-do-la",
    "merendona": "me-ren-do-na",
    "merengado": "me-ren-ga-do",
    "merengar": "me-ren-gar",
    "merengue": "me-ren-gue",
    "merequetengue": "me-re-que-ten-gue",
    "meresunda": "me-re-sun-da",
    "meretricia": "me-re-tri-cia",
    "meretricio": "me-re-tri-cio",
    "meretriz": "me-re-triz",
    "merey": "me-rey",
    "mergánsar": "mer-gán-sar",
    "mergo": "mer-go",
    "mergón": "mer-gón",
    "mérgulo": "mér-gu-lo",
    "mericarpo": "me-ri-car-po",
    "meridana": "me-ri-da-na",
    "meridano": "me-ri-da-no",
    "merideña": "me-ri-de-ña",
    "merideño": "me-ri-de-ño",
    "meridiana": "me-ri-dia-na",
    "meridianamente": "me-ri-dia-na-men-te",
    "meridiano": "me-ri-dia-no",
    "meridión": "me-ri-dión",
    "meridional": "me-ri-dio-nal",
    "merienda": "me-rien-da",
    "merina": "me-ri-na",
    "meriñaque": "me-ri-ña-que",
    "merindad": "me-rin-dad",
    "merinera": "me-ri-ne-ra",
    "merinero": "me-ri-ne-ro",
    "merino": "me-ri-no",
    "meristema": "me-ris-te-ma",
    "meristemo": "me-ris-te-mo",
    "mérita": "mé-ri-ta",
    "méritamente": "mé-ri-ta-men-te",
    "meritar": "me-ri-tar",
    "meritísima": "me-ri-tí-si-ma",
    "meritísimo": "me-ri-tí-si-mo",
    "mérito": "mé-ri-to",
    "meritoria": "me-ri-to-ria",
    "meritoriaje": "me-ri-to-ria-je",
    "meritoriamente": "me-ri-to-ria-men-te",
    "meritorio": "me-ri-to-rio",
    "merla": "mer-la",
    "merleta": "mer-le-ta",
    "merlín": "mer-lín",
    "merlo": "mer-lo",
    "merlón": "mer-lón",
    "merluza": "mer-lu-za",
    "merluzo": "mer-lu-zo",
    "merma": "mer-ma",
    "mermador": "mer-ma-dor",
    "mermadora": "mer-ma-do-ra",
    "mermar": "mer-mar",
    "mermelada": "mer-me-la-da",
    "mero": "me-ro",
    "merode": "me-ro-de",
    "merodeador": "me-ro-de-a-dor",
    "merodeadora": "me-ro-de-a-do-ra",
    "merodear": "me-ro-de-ar",
    "merodeo": "me-ro-de-o",
    "merodista": "me-ro-dis-ta",
    "merol": "me-rol",
    "merolica": "me-ro-li-ca",
    "merolico": "me-ro-li-co",
    "merostoma": "me-ros-to-ma",
    "merovingia": "me-ro-vin-gia",
    "merovingio": "me-ro-vin-gio",
    "merquén": "mer-quén",
    "mersa": "mer-sa",
    "meruca": "me-ru-ca",
    "meruco": "me-ru-co",
    "meruéndano": "me-ruén-da-no",
    "merusa": "me-ru-sa",
    "merusear": "me-ru-se-ar",
    "mesa": "me-sa",
    "mesada": "me-sa-da",
    "mesadura": "me-sa-du-ra",
    "mesalina": "me-sa-li-na",
    "mesana": "me-sa-na",
    "mesar": "me-sar",
    "mesaraico": "me-sa-rai-co",
    "mesareico": "me-sa-rei-co",
    "mescal": "mes-cal",
    "mescalina": "mes-ca-li-na",
    "mesclamiento": "mes-cla-mien-to",
    "mesclar": "mes-clar",
    "mescolanza": "mes-co-lan-za",
    "meseguera": "me-se-gue-ra",
    "meseguería": "me-se-gue-rí-a",
    "meseguero": "me-se-gue-ro",
    "mesencéfalo": "me-sen-cé-fa-lo",
    "mesénquima": "me-sén-qui-ma",
    "mesenquimal": "me-sen-qui-mal",
    "mesentérica": "me-sen-té-ri-ca",
    "mesentérico": "me-sen-té-ri-co",
    "mesenterio": "me-sen-te-rio",
    "mesera": "me-se-ra",
    "mesero": "me-se-ro",
    "meseta": "me-se-ta",
    "mesetaria": "me-se-ta-ria",
    "mesetario": "me-se-ta-rio",
    "meseteña": "me-se-te-ña",
    "meseteño": "me-se-te-ño",
    "mesiado": "me-sia-do",
    "mesiánica": "me-siá-ni-ca",
    "mesiánico": "me-siá-ni-co",
    "mesianismo": "me-sia-nis-mo",
    "mesías": "me-sí-as",
    "mesiazgo": "me-siaz-go",
    "mesidor": "me-si-dor",
    "mesilla": "me-si-lla",
    "mesillo": "me-si-llo",
    "mesinga": "me-sin-ga",
    "mesingo": "me-sin-go",
    "mesita": "me-si-ta",
    "mesma": "mes-ma",
    "mesmedad": "mes-me-dad",
    "mesmerismo": "mes-me-ris-mo",
    "mesmo": "mes-mo",
    "mesnada": "mes-na-da",
    "mesnadería": "mes-na-de-rí-a",
    "mesnadero": "mes-na-de-ro",
    "mesoamericana": "me-so-a-me-ri-ca-na",
    "mesoamericano": "me-so-a-me-ri-ca-no",
    "mesocarpio": "me-so-car-pio",
    "mesocarpo": "me-so-car-po",
    "mesocéfala": "me-so-cé-fa-la",
    "mesocefalia": "me-so-ce-fa-lia",
    "mesocéfalo": "me-so-cé-fa-lo",
    "mesocracia": "me-so-cra-cia",
    "mesocrática": "me-so-crá-ti-ca",
    "mesocrático": "me-so-crá-ti-co",
    "mesodérmica": "me-so-dér-mi-ca",
    "mesodérmico": "me-so-dér-mi-co",
    "mesodermo": "me-so-der-mo",
    "mesolítico": "me-so-lí-ti-co",
    "mesolote": "me-so-lo-te",
    "mesomorfa": "me-so-mor-fa",
    "mesomorfo": "me-so-mor-fo",
    "mesón": "me-són",
    "mesonaje": "me-so-na-je",
    "mesonera": "me-so-ne-ra",
    "mesonero": "me-so-ne-ro",
    "mesonil": "me-so-nil",
    "mesonista": "me-so-nis-ta",
    "mesopausa": "me-so-pau-sa",
    "mesopotámico": "me-so-po-tá-mi-co",
    "mesosfera": "me-sos-fe-ra",
    "mesósfera": "me-sós-fe-ra",
    "mesosoma": "me-so-so-ma",
    "mesoterapia": "me-so-te-ra-pia",
    "mesotórax": "me-so-tó-rax",
    "mesotrofia": "me-so-tro-fia",
    "mesotrófico": "me-so-tró-fi-co",
    "mesozoico": "me-so-zoi-co",
    "mesozoo": "me-so-zo-o",
    "mesquina": "mes-qui-na",
    "mesquino": "mes-qui-no",
    "mesquital": "mes-qui-tal",
    "mesquite": "mes-qui-te",
    "mesta": "mes-ta",
    "mesta": "mes-ta",
    "mestal": "mes-tal",
    "mesteña": "mes-te-ña",
    "mestenca": "mes-ten-ca",
    "mestenco": "mes-ten-co",
    "mesteño": "mes-te-ño",
    "mester": "mes-ter",
    "mesticia": "mes-ti-cia",
    "mestiza": "mes-ti-za",
    "mestizaje": "mes-ti-za-je",
    "mestizar": "mes-ti-zar",
    "mestizo": "mes-ti-zo",
    "mesto": "mes-to",
    "mestrual": "mes-trual",
    "mestruo": "mes-truo",
    "mestura": "mes-tu-ra",
    "mesturar": "mes-tu-rar",
    "mesturera": "mes-tu-re-ra",
    "mesturero": "mes-tu-re-ro",
    "mesura": "me-su-ra",
    "mesurada": "me-su-ra-da",
    "mesuradamente": "me-su-ra-da-men-te",
    "mesurado": "me-su-ra-do",
    "mesuramiento": "me-su-ra-mien-to",
    "mesurar": "me-su-rar",
    "meta": "me-ta",
    "metábasis": "me-tá-ba-sis",
    "metabólica": "me-ta-bó-li-ca",
    "metabólico": "me-ta-bó-li-co",
    "metabolismo": "me-ta-bo-lis-mo",
    "metabolito": "me-ta-bo-li-to",
    "metabolización": "me-ta-bo-li-za-ción",
    "metacarpiana": "me-ta-car-pia-na",
    "metacarpiano": "me-ta-car-pia-no",
    "metacarpo": "me-ta-car-po",
    "metacéntrica": "me-ta-cén-tri-ca",
    "metacéntrico": "me-ta-cén-tri-co",
    "metacentro": "me-ta-cen-tro",
    "metacrilato": "me-ta-cri-la-to",
    "metad": "me-tad",
    "metadona": "me-ta-do-na",
    "metafase": "me-ta-fa-se",
    "metafísica": "me-ta-fí-si-ca",
    "metafísicamente": "me-ta-fí-si-ca-men-te",
    "metafísico": "me-ta-fí-si-co",
    "metafita": "me-ta-fi-ta",
    "metafonía": "me-ta-fo-ní-a",
    "metáfora": "me-tá-fo-ra",
    "metafórica": "me-ta-fó-ri-ca",
    "metafóricamente": "me-ta-fó-ri-ca-men-te",
    "metafórico": "me-ta-fó-ri-co",
    "metaforización": "me-ta-fo-ri-za-ción",
    "metaforizar": "me-ta-fo-ri-zar",
    "metagoge": "me-ta-go-ge",
    "metal": "me-tal",
    "metalada": "me-ta-la-da",
    "metalado": "me-ta-la-do",
    "metalario": "me-ta-la-rio",
    "metalengua": "me-ta-len-gua",
    "metalenguaje": "me-ta-len-gua-je",
    "metalepsis": "me-ta-lep-sis",
    "metalero": "me-ta-le-ro",
    "metálica": "me-tá-li-ca",
    "metálicamente": "me-tá-li-ca-men-te",
    "metálico": "me-tá-li-co",
    "metalífera": "me-ta-lí-fe-ra",
    "metalífero": "me-ta-lí-fe-ro",
    "metalina": "me-ta-li-na",
    "metalingüísticamente": "me-ta-lin-güís-ti-ca-men-te",
    "metalingüístico": "me-ta-lin-güís-ti-co",
    "metalino": "me-ta-li-no",
    "metalista": "me-ta-lis-ta",
    "metalistería": "me-ta-lis-te-rí-a",
    "metalización": "me-ta-li-za-ción",
    "metalizada": "me-ta-li-za-da",
    "metalizado": "me-ta-li-za-do",
    "metalizar": "me-ta-li-zar",
    "metalla": "me-ta-lla",
    "metalocromía": "me-ta-lo-cro-mí-a",
    "metalófono": "me-ta-ló-fo-no",
    "metalogenia": "me-ta-lo-ge-nia",
    "metalografía": "me-ta-lo-gra-fí-a",
    "metalográfico": "me-ta-lo-grá-fi-co",
    "metaloide": "me-ta-loi-de",
    "metaloterapia": "me-ta-lo-te-ra-pia",
    "metalurgia": "me-ta-lur-gia",
    "metalúrgica": "me-ta-lúr-gi-ca",
    "metalúrgico": "me-ta-lúr-gi-co",
    "metalurgista": "me-ta-lur-gis-ta",
    "metamatemática": "me-ta-ma-te-má-ti-ca",
    "metámero": "me-tá-me-ro",
    "metamórfica": "me-ta-mór-fi-ca",
    "metamórfico": "me-ta-mór-fi-co",
    "metamorfismo": "me-ta-mor-fis-mo",
    "metamorfosear": "me-ta-mor-fo-se-ar",
    "metamorfóseos": "me-ta-mor-fó-se-os",
    "metamorfosi": "me-ta-mor-fo-si",
    "metamorfosis": "me-ta-mor-fo-sis",
    "metanero": "me-ta-ne-ro",
    "metano": "me-ta-no",
    "metanol": "me-ta-nol",
    "metaplasmo": "me-ta-plas-mo",
    "metapsíquica": "me-tap-sí-qui-ca",
    "metastásico": "me-tas-tá-si-co",
    "metástasis": "me-tás-ta-sis",
    "metastatizar": "me-tas-ta-ti-zar",
    "metatarsiana": "me-ta-tar-sia-na",
    "metatarsiano": "me-ta-tar-sia-no",
    "metatarso": "me-ta-tar-so",
    "metate": "me-ta-te",
    "metateada": "me-ta-te-a-da",
    "metatear": "me-ta-te-ar",
    "metatera": "me-ta-te-ra",
    "metaterio": "me-ta-te-rio",
    "metatero": "me-ta-te-ro",
    "metátesis": "me-tá-te-sis",
    "metatizar": "me-ta-ti-zar",
    "metatórax": "me-ta-tó-rax",
    "metatudo": "me-ta-tu-do",
    "metazoo": "me-ta-zo-o",
    "meteca": "me-te-ca",
    "meteco": "me-te-co",
    "metedor": "me-te-dor",
    "metedora": "me-te-do-ra",
    "metedura": "me-te-du-ra",
    "meteduría": "me-te-du-rí-a",
    "metegol": "me-te-gol",
    "metejón": "me-te-jón",
    "metejona": "me-te-jo-na",
    "metempsicosis": "me-temp-si-co-sis",
    "metempsícosis": "me-temp-sí-co-sis",
    "metemuertos": "me-te-muer-tos",
    "metencéfalo": "me-ten-cé-fa-lo",
    "metense": "me-ten-se",
    "meteórica": "me-te-ó-ri-ca",
    "meteóricamente": "me-te-ó-ri-ca-men-te",
    "meteórico": "me-te-ó-ri-co",
    "meteorismo": "me-te-o-ris-mo",
    "meteorítico": "me-te-o-rí-ti-co",
    "meteorito": "me-te-o-ri-to",
    "meteorización": "me-te-o-ri-za-ción",
    "meteorizar": "me-te-o-ri-zar",
    "meteoro": "me-te-o-ro",
    "metéoro": "me-té-o-ro",
    "meteoróloga": "me-te-o-ró-lo-ga",
    "meteorología": "me-te-o-ro-lo-gí-a",
    "meteorológica": "me-te-o-ro-ló-gi-ca",
    "meteorológico": "me-te-o-ro-ló-gi-co",
    "meteorologista": "me-te-o-ro-lo-gis-ta",
    "meteorólogo": "me-te-o-ró-lo-go",
    "metepatas": "me-te-pa-tas",
    "meter": "me-ter",
    "meterete": "me-te-re-te",
    "metesillas": "me-te-si-llas",
    "metete": "me-te-te",
    "metical": "me-ti-cal",
    "metiche": "me-ti-che",
    "meticón": "me-ti-cón",
    "meticona": "me-ti-co-na",
    "meticulosa": "me-ti-cu-lo-sa",
    "meticulosamente": "me-ti-cu-lo-sa-men-te",
    "meticulosidad": "me-ti-cu-lo-si-dad",
    "meticuloso": "me-ti-cu-lo-so",
    "metida": "me-ti-da",
    "metidillo": "me-ti-di-llo",
    "metido": "me-ti-do",
    "metijón": "me-ti-jón",
    "metijona": "me-ti-jo-na",
    "metílica": "me-tí-li-ca",
    "metílico": "me-tí-li-co",
    "metilo": "me-ti-lo",
    "metimiento": "me-ti-mien-to",
    "metisaca": "me-ti-sa-ca",
    "metlapil": "me-tla-pil",
    "metódica": "me-tó-di-ca",
    "metódicamente": "me-tó-di-ca-men-te",
    "metódico": "me-tó-di-co",
    "metodismo": "me-to-dis-mo",
    "metodista": "me-to-dis-ta",
    "metodizar": "me-to-di-zar",
    "método": "mé-to-do",
    "metodología": "me-to-do-lo-gí-a",
    "metodológicamente": "me-to-do-ló-gi-ca-men-te",
    "metodológico": "me-to-do-ló-gi-co",
    "metomentodo": "me-to-men-to-do",
    "metonimia": "me-to-ni-mia",
    "metonímica": "me-to-ní-mi-ca",
    "metonímico": "me-to-ní-mi-co",
    "metopa": "me-to-pa",
    "métopa": "mé-to-pa",
    "metoposcopia": "me-to-pos-co-pia",
    "metra": "me-tra",
    "metraje": "me-tra-je",
    "metralla": "me-tra-lla",
    "metrallazo": "me-tra-lla-zo",
    "metralleta": "me-tra-lle-ta",
    "metras": "me-tras",
    "metreta": "me-tre-ta",
    "métrica": "mé-tri-ca",
    "métricamente": "mé-tri-ca-men-te",
    "métrico": "mé-tri-co",
    "metrificación": "me-tri-fi-ca-ción",
    "metrificador": "me-tri-fi-ca-dor",
    "metrificadora": "me-tri-fi-ca-do-ra",
    "metrificar": "me-tri-fi-car",
    "metrificatura": "me-tri-fi-ca-tu-ra",
    "metrista": "me-tris-ta",
    "metritis": "me-tri-tis",
    "metro": "me-tro",
    "metrología": "me-tro-lo-gí-a",
    "metrónomo": "me-tró-no-mo",
    "metrópoli": "me-tró-po-li",
    "metrópolis": "me-tró-po-lis",
    "metropolitana": "me-tro-po-li-ta-na",
    "metropolitano": "me-tro-po-li-ta-no",
    "metrorragia": "me-tro-rra-gia",
    "metrosexual": "me-tro-se-xual",
    "meublé": "meu-blé",
    "mexica": "me-xi-ca",
    "mexicalense": "me-xi-ca-len-se",
    "mexicana": "me-xi-ca-na",
    "mexicanismo": "me-xi-ca-nis-mo",
    "mexicanista": "me-xi-ca-nis-ta",
    "mexicano": "me-xi-ca-no",
    "mexiqueña": "me-xi-que-ña",
    "mexiqueño": "me-xi-que-ño",
    "mexiquense": "me-xi-quen-se",
    "meya": "me-ya",
    "meyba": "mey-ba",
    "meyor": "me-yor",
    "meyosis": "me-yo-sis",
    "mezcal": "mez-cal",
    "mezcalear": "mez-ca-le-ar",
    "mezcalera": "mez-ca-le-ra",
    "mezcalería": "mez-ca-le-rí-a",
    "mezcalero": "mez-ca-le-ro",
    "mezcalina": "mez-ca-li-na",
    "mezcla": "mez-cla",
    "mezclable": "mez-cla-ble",
    "mezcladamente": "mez-cla-da-men-te",
    "mezclado": "mez-cla-do",
    "mezclador": "mez-cla-dor",
    "mezcladora": "mez-cla-do-ra",
    "mezcladura": "mez-cla-du-ra",
    "mezclamiento": "mez-cla-mien-to",
    "mezclar": "mez-clar",
    "mezclilla": "mez-cli-lla",
    "mezclote": "mez-clo-te",
    "mezcolanza": "mez-co-lan-za",
    "meznada": "mez-na-da",
    "mezontete": "me-zon-te-te",
    "mezquina": "mez-qui-na",
    "mezquinamente": "mez-qui-na-men-te",
    "mezquinar": "mez-qui-nar",
    "mezquindad": "mez-quin-dad",
    "mezquino": "mez-qui-no",
    "mezquita": "mez-qui-ta",
    "mezquital": "mez-qui-tal",
    "mezquite": "mez-qui-te",
    "mezzo": "mez-zo",
    "mezzoforte": "mez-zo-for-te",
    "mezzosoprano": "mez-zo-so-pra-no",
    "mía": "mí-a",
    "miador": "mia-dor",
    "miadora": "mia-do-ra",
    "miagar": "mia-gar",
    "miaja": "mia-ja",
    "mialgia": "mial-gia",
    "mialmas": "mial-mas",
    "miañar": "mia-ñar",
    "miasma": "mias-ma",
    "miasmática": "mias-má-ti-ca",
    "miasmático": "mias-má-ti-co",
    "miastenia": "mias-te-nia",
    "mibor": "mi-bor",
    "mica": "mi-ca",
    "micácea": "mi-cá-ce-a",
    "micáceo": "mi-cá-ce-o",
    "micacita": "mi-ca-ci-ta",
    "micada": "mi-ca-da",
    "micado": "mi-ca-do",
    "micción": "mic-ción",
    "miccional": "mic-cio-nal",
    "miccionar": "mic-cio-nar",
    "micelio": "mi-ce-lio",
    "micena": "mi-ce-na",
    "micénica": "mi-cé-ni-ca",
    "micénico": "mi-cé-ni-co",
    "micer": "mi-cer",
    "micetología": "mi-ce-to-lo-gí-a",
    "micha": "mi-cha",
    "miche": "mi-che",
    "michelín": "mi-che-lín",
    "michina": "mi-chi-na",
    "michino": "mi-chi-no",
    "micho": "mi-cho",
    "michoacana": "mi-cho-a-ca-na",
    "michoacano": "mi-cho-a-ca-no",
    "mico": "mi-co",
    "micobacteria": "mi-co-bac-te-ria",
    "micoleón": "mi-co-le-ón",
    "micóloga": "mi-có-lo-ga",
    "micología": "mi-co-lo-gí-a",
    "micológico": "mi-co-ló-gi-co",
    "micólogo": "mi-có-lo-go",
    "micoplasma": "mi-co-plas-ma",
    "micorriza": "mi-co-rri-za",
    "micosis": "mi-co-sis",
    "micra": "mi-cra",
    "micrero": "mi-cre-ro",
    "micro": "mi-cro",
    "microanálisis": "mi-cro-a-ná-li-sis",
    "microbiano": "mi-cro-bia-no",
    "microbicida": "mi-cro-bi-ci-da",
    "microbio": "mi-cro-bio",
    "microbióloga": "mi-cro-bió-lo-ga",
    "microbiología": "mi-cro-bio-lo-gí-a",
    "microbiológica": "mi-cro-bio-ló-gi-ca",
    "microbiológico": "mi-cro-bio-ló-gi-co",
    "microbiólogo": "mi-cro-bió-lo-go",
    "microbús": "mi-cro-bús",
    "microcéfala": "mi-cro-cé-fa-la",
    "microcefalia": "mi-cro-ce-fa-lia",
    "microcéfalo": "mi-cro-cé-fa-lo",
    "microchip": "mi-cro-chip",
    "microcinta": "mi-cro-cin-ta",
    "microcircuito": "mi-cro-cir-cui-to",
    "microcirugía": "mi-cro-ci-ru-gí-a",
    "microcirujana": "mi-cro-ci-ru-ja-na",
    "microcirujano": "mi-cro-ci-ru-ja-no",
    "microclima": "mi-cro-cli-ma",
    "micrococo": "mi-cro-co-co",
    "microcopia": "mi-cro-co-pia",
    "microcosmo": "mi-cro-cos-mo",
    "microcosmos": "mi-cro-cos-mos",
    "microcrédito": "mi-cro-cré-di-to",
    "microeconomía": "mi-cro-e-co-no-mí-a",
    "microeconómico": "mi-cro-e-co-nó-mi-co",
    "microelectrónica": "mi-cro-e-lec-tró-ni-ca",
    "microespacio": "mi-cro-es-pa-cio",
    "microestructura": "mi-cro-es-truc-tu-ra",
    "micrófago": "mi-cró-fa-go",
    "microfaradio": "mi-cro-fa-ra-dio",
    "microfibra": "mi-cro-fi-bra",
    "microficha": "mi-cro-fi-cha",
    "microfilm": "mi-cro-film",
    "microfilmación": "mi-cro-fil-ma-ción",
    "microfilmador": "mi-cro-fil-ma-dor",
    "microfilmadora": "mi-cro-fil-ma-do-ra",
    "microfilmar": "mi-cro-fil-mar",
    "microfilme": "mi-cro-fil-me",
    "microfísica": "mi-cro-fí-si-ca",
    "micrófito": "mi-cró-fi-to",
    "microfónico": "mi-cro-fó-ni-co",
    "micrófono": "mi-cró-fo-no",
    "microfotografía": "mi-cro-fo-to-gra-fí-a",
    "microfotográfico": "mi-cro-fo-to-grá-fi-co",
    "microgameto": "mi-cro-ga-me-to",
    "micrógrafa": "mi-cró-gra-fa",
    "micrografía": "mi-cro-gra-fí-a",
    "micrográfica": "mi-cro-grá-fi-ca",
    "micrográfico": "mi-cro-grá-fi-co",
    "micrógrafo": "mi-cró-gra-fo",
    "microgravedad": "mi-cro-gra-ve-dad",
    "microinyección": "mi-croin-yec-ción",
    "microinyectar": "mi-croin-yec-tar",
    "microlentilla": "mi-cro-len-ti-lla",
    "micromanipulador": "mi-cro-ma-ni-pu-la-dor",
    "micrométrica": "mi-cro-mé-tri-ca",
    "micrométrico": "mi-cro-mé-tri-co",
    "micrómetro": "mi-cró-me-tro",
    "micromotor": "mi-cro-mo-tor",
    "micrón": "mi-crón",
    "micronesia": "mi-cro-ne-sia",
    "micronesio": "mi-cro-ne-sio",
    "micronizador": "mi-cro-ni-za-dor",
    "micronizar": "mi-cro-ni-zar",
    "microonda": "mi-cro-on-da",
    "microondas": "mi-cro-on-das",
    "microordenador": "mi-cro-or-de-na-dor",
    "microorganismo": "mi-cro-or-ga-nis-mo",
    "micropilo": "mi-cro-pi-lo",
    "microprocesador": "mi-cro-pro-ce-sa-dor",
    "microscopía": "mi-cros-co-pí-a",
    "microscopia": "mi-cros-co-pia",
    "microscópica": "mi-cros-có-pi-ca",
    "microscópico": "mi-cros-có-pi-co",
    "microscopio": "mi-cros-co-pio",
    "microscopista": "mi-cros-co-pis-ta",
    "microsegundo": "mi-cro-se-gun-do",
    "microspora": "mi-cros-po-ra",
    "microsporidio": "mi-cros-po-ri-dio",
    "microsporofila": "mi-cros-po-ro-fi-la",
    "microsurco": "mi-cro-sur-co",
    "microteléfono": "mi-cro-te-lé-fo-no",
    "microtomo": "mi-cro-to-mo",
    "microtonalismo": "mi-cro-to-na-lis-mo",
    "microtono": "mi-cro-to-no",
    "microvoltio": "mi-cro-vol-tio",
    "micuré": "mi-cu-ré",
    "mida": "mi-da",
    "midriasis": "mi-dria-sis",
    "miéchica": "mié-chi-ca",
    "miedica": "mie-di-ca",
    "mieditis": "mie-di-tis",
    "miedo": "mie-do",
    "miedosa": "mie-do-sa",
    "miedoso": "mie-do-so",
    "miedro": "mie-dro",
    "mielazo": "mie-la-zo",
    "mielera": "mie-le-ra",
    "mielero": "mie-le-ro",
    "mielga": "miel-ga",
    "mielgo": "miel-go",
    "mielina": "mie-li-na",
    "mielínico": "mie-lí-ni-co",
    "mielítica": "mie-lí-ti-ca",
    "mielítico": "mie-lí-ti-co",
    "mielitis": "mie-li-tis",
    "mieloma": "mie-lo-ma",
    "mielsa": "miel-sa",
    "miembro": "miem-bro",
    "miente": "mien-te",
    "mientra": "mien-tra",
    "mientras": "mien-tras",
    "mientre": "mien-tre",
    "miera": "mie-ra",
    "miércale": "miér-ca-le",
    "miércoles": "miér-co-les",
    "mierda": "mier-da",
    "mierdoso": "mier-do-so",
    "mierla": "mier-la",
    "mierra": "mie-rra",
    "miga": "mi-ga",
    "migaja": "mi-ga-ja",
    "migajada": "mi-ga-ja-da",
    "migajón": "mi-ga-jón",
    "migala": "mi-ga-la",
    "migale": "mi-ga-le",
    "migar": "mi-gar",
    "migra": "mi-gra",
    "migración": "mi-gra-ción",
    "migrador": "mi-gra-dor",
    "migraña": "mi-gra-ña",
    "migrante": "mi-gran-te",
    "migrar": "mi-grar",
    "migratoria": "mi-gra-to-ria",
    "migratorio": "mi-gra-to-rio",
    "miguelangelesco": "mi-gue-lan-ge-les-co",
    "miguelear": "mi-gue-le-ar",
    "migueleña": "mi-gue-le-ña",
    "migueleño": "mi-gue-le-ño",
    "miguelete": "mi-gue-le-te",
    "miguelito": "mi-gue-li-to",
    "miguera": "mi-gue-ra",
    "miguero": "mi-gue-ro",
    "mihrab": "mih-rab",
    "mija": "mi-ja",
    "mijarra": "mi-ja-rra",
    "mije": "mi-je",
    "mijero": "mi-je-ro",
    "mijitear": "mi-ji-te-ar",
    "mijo": "mi-jo",
    "mikado": "mi-ka-do",
    "milagrear": "mi-la-gre-ar",
    "milagrense": "mi-la-gren-se",
    "milagrera": "mi-la-gre-ra",
    "milagrería": "mi-la-gre-rí-a",
    "milagrero": "mi-la-gre-ro",
    "milagrienta": "mi-la-grien-ta",
    "milagriento": "mi-la-grien-to",
    "milagro": "mi-la-gro",
    "milagrón": "mi-la-grón",
    "milagrosa": "mi-la-gro-sa",
    "milagrosamente": "mi-la-gro-sa-men-te",
    "milagroso": "mi-la-gro-so",
    "milamores": "mi-la-mo-res",
    "milán": "mi-lán",
    "milanés": "mi-la-nés",
    "milanesa": "mi-la-ne-sa",
    "milano": "mi-la-no",
    "milara": "mi-la-ra",
    "milbillonésima": "mil-bi-llo-né-si-ma",
    "milbillonésimo": "mil-bi-llo-né-si-mo",
    "milcao": "mil-ca-o",
    "mildéu": "mil-déu",
    "mildiu": "mil-diu",
    "mildiú": "mil-diú",
    "milena": "mi-le-na",
    "milenaria": "mi-le-na-ria",
    "milenario": "mi-le-na-rio",
    "milenarismo": "mi-le-na-ris-mo",
    "milenarista": "mi-le-na-ris-ta",
    "milenio": "mi-le-nio",
    "mileno": "mi-le-no",
    "milenrama": "mi-len-ra-ma",
    "milenta": "mi-len-ta",
    "mileón": "mi-le-ón",
    "milesia": "mi-le-sia",
    "milésima": "mi-lé-si-ma",
    "milésimo": "mi-lé-si-mo",
    "milesio": "mi-le-sio",
    "milgrana": "mil-gra-na",
    "milgranar": "mil-gra-nar",
    "milhoja": "mil-ho-ja",
    "milhojas": "mil-ho-jas",
    "milhombres": "mil-hom-bres",
    "mili": "mi-li",
    "miliamperio": "mi-liam-pe-rio",
    "miliar": "mi-liar",
    "miliárea": "mi-liá-re-a",
    "miliaria": "mi-lia-ria",
    "miliario": "mi-lia-rio",
    "milibar": "mi-li-bar",
    "milibaro": "mi-li-ba-ro",
    "milicia": "mi-li-cia",
    "miliciana": "mi-li-cia-na",
    "miliciano": "mi-li-cia-no",
    "milico": "mi-li-co",
    "miligramo": "mi-li-gra-mo",
    "mililitro": "mi-li-li-tro",
    "milimetrado": "mi-li-me-tra-do",
    "milimétricamente": "mi-li-mé-tri-ca-men-te",
    "milimétrico": "mi-li-mé-tri-co",
    "milímetro": "mi-lí-me-tro",
    "militancia": "mi-li-tan-cia",
    "militante": "mi-li-tan-te",
    "militar": "mi-li-tar",
    "militara": "mi-li-ta-ra",
    "militarada": "mi-li-ta-ra-da",
    "militarismo": "mi-li-ta-ris-mo",
    "militarista": "mi-li-ta-ris-ta",
    "militarización": "mi-li-ta-ri-za-ción",
    "militarizar": "mi-li-ta-ri-zar",
    "militarmente": "mi-li-tar-men-te",
    "mílite": "mí-li-te",
    "militronche": "mi-li-tron-che",
    "milivoltio": "mi-li-vol-tio",
    "milla": "mi-lla",
    "millaca": "mi-lla-ca",
    "millaje": "mi-lla-je",
    "millar": "mi-llar",
    "millarada": "mi-lla-ra-da",
    "millardo": "mi-llar-do",
    "millo": "mi-llo",
    "millón": "mi-llón",
    "millonada": "mi-llo-na-da",
    "millonaria": "mi-llo-na-ria",
    "millonario": "mi-llo-na-rio",
    "millonésima": "mi-llo-né-si-ma",
    "millonésimo": "mi-llo-né-si-mo",
    "millonetis": "mi-llo-ne-tis",
    "milmillonésima": "mil-mi-llo-né-si-ma",
    "milmillonésimo": "mil-mi-llo-né-si-mo",
    "miloca": "mi-lo-ca",
    "milocha": "mi-lo-cha",
    "milonga": "mi-lon-ga",
    "milonguear": "mi-lon-gue-ar",
    "milonguera": "mi-lon-gue-ra",
    "milonguero": "mi-lon-gue-ro",
    "milord": "mi-lord",
    "milpa": "mil-pa",
    "milpear": "mil-pe-ar",
    "milpera": "mil-pe-ra",
    "milperío": "mil-pe-rí-o",
    "milpero": "mil-pe-ro",
    "milpiés": "mil-piés",
    "milrayas": "mil-ra-yas",
    "miltomate": "mil-to-ma-te",
    "miltoniano": "mil-to-nia-no",
    "mimada": "mi-ma-da",
    "mimado": "mi-ma-do",
    "mimador": "mi-ma-dor",
    "mimadora": "mi-ma-do-ra",
    "mimar": "mi-mar",
    "mimbral": "mim-bral",
    "mimbrar": "mim-brar",
    "mimbre": "mim-bre",
    "mimbrear": "mim-bre-ar",
    "mimbreña": "mim-bre-ña",
    "mimbreño": "mim-bre-ño",
    "mimbrera": "mim-bre-ra",
    "mimbreral": "mim-bre-ral",
    "mimbrero": "mim-bre-ro",
    "mimbrón": "mim-brón",
    "mimbrosa": "mim-bro-sa",
    "mimbroso": "mim-bro-so",
    "mime": "mi-me",
    "mimeografía": "mi-me-o-gra-fí-a",
    "mimeografiado": "mi-me-o-gra-fia-do",
    "mimeografiar": "mi-me-o-gra-fiar",
    "mimeógrafo": "mi-me-ó-gra-fo",
    "mimesis": "mi-me-sis",
    "mímesis": "mí-me-sis",
    "mimética": "mi-mé-ti-ca",
    "mimético": "mi-mé-ti-co",
    "mimetismo": "mi-me-tis-mo",
    "mimetización": "mi-me-ti-za-ción",
    "mimetizado": "mi-me-ti-za-do",
    "mimetizar": "mi-me-ti-zar",
    "mímica": "mí-mi-ca",
    "mímico": "mí-mi-co",
    "mimo": "mi-mo",
    "mimodrama": "mi-mo-dra-ma",
    "mimógrafa": "mi-mó-gra-fa",
    "mimógrafo": "mi-mó-gra-fo",
    "mimosa": "mi-mo-sa",
    "mimosácea": "mi-mo-sá-ce-a",
    "mimosáceas": "mi-mo-sá-ce-as",
    "mimosáceo": "mi-mo-sá-ce-o",
    "mimosamente": "mi-mo-sa-men-te",
    "mimoso": "mi-mo-so",
    "mina": "mi-na",
    "minada": "mi-na-da",
    "minado": "mi-na-do",
    "minador": "mi-na-dor",
    "minadora": "mi-na-do-ra",
    "minal": "mi-nal",
    "miñambre": "mi-ñam-bre",
    "minar": "mi-nar",
    "minarete": "mi-na-re-te",
    "minaz": "mi-naz",
    "minción": "min-ción",
    "mindanga": "min-dan-ga",
    "mindango": "min-dan-go",
    "mindanguear": "min-dan-gue-ar",
    "mindoniense": "min-do-nien-se",
    "minera": "mi-ne-ra",
    "mineraje": "mi-ne-ra-je",
    "mineral": "mi-ne-ral",
    "mineralización": "mi-ne-ra-li-za-ción",
    "mineralizar": "mi-ne-ra-li-zar",
    "mineralogía": "mi-ne-ra-lo-gí-a",
    "mineralógica": "mi-ne-ra-ló-gi-ca",
    "mineralógico": "mi-ne-ra-ló-gi-co",
    "mineralogista": "mi-ne-ra-lo-gis-ta",
    "mineralurgia": "mi-ne-ra-lur-gia",
    "minería": "mi-ne-rí-a",
    "minerista": "mi-ne-ris-ta",
    "minero": "mi-ne-ro",
    "mineromedicinal": "mi-ne-ro-me-di-ci-nal",
    "minerva": "mi-ner-va",
    "minervista": "mi-ner-vis-ta",
    "minestrone": "mi-nes-tro-ne",
    "minga": "min-ga",
    "mingaco": "min-ga-co",
    "mingar": "min-gar",
    "mingitoria": "min-gi-to-ria",
    "mingitorio": "min-gi-to-rio",
    "mingo": "min-go",
    "mingón": "min-gón",
    "minguero": "min-gue-ro",
    "miniado": "mi-nia-do",
    "miniar": "mi-niar",
    "miniatura": "mi-nia-tu-ra",
    "miniaturista": "mi-nia-tu-ris-ta",
    "miniaturización": "mi-nia-tu-ri-za-ción",
    "miniaturizar": "mi-nia-tu-ri-zar",
    "minibar": "mi-ni-bar",
    "minibásket": "mi-ni-bás-ket",
    "minicadena": "mi-ni-ca-de-na",
    "minicine": "mi-ni-ci-ne",
    "minicomputador": "mi-ni-com-pu-ta-dor",
    "minidisco": "mi-ni-dis-co",
    "minifalda": "mi-ni-fal-da",
    "minifaldera": "mi-ni-fal-de-ra",
    "minifaldero": "mi-ni-fal-de-ro",
    "minifundio": "mi-ni-fun-dio",
    "minifundismo": "mi-ni-fun-dis-mo",
    "minifundista": "mi-ni-fun-dis-ta",
    "minigolf": "mi-ni-golf",
    "mínima": "mí-ni-ma",
    "minimal": "mi-ni-mal",
    "minimalismo": "mi-ni-ma-lis-mo",
    "minimalista": "mi-ni-ma-lis-ta",
    "mínimamente": "mí-ni-ma-men-te",
    "minimista": "mi-ni-mis-ta",
    "minimización": "mi-ni-mi-za-ción",
    "minimizador": "mi-ni-mi-za-dor",
    "minimizadora": "mi-ni-mi-za-do-ra",
    "minimizar": "mi-ni-mi-zar",
    "mínimo": "mí-ni-mo",
    "mínimum": "mí-ni-mum",
    "minina": "mi-ni-na",
    "minino": "mi-ni-no",
    "minio": "mi-nio",
    "miniordenador": "mi-nior-de-na-dor",
    "miniserie": "mi-ni-se-rie",
    "ministerial": "mi-nis-te-rial",
    "ministerialismo": "mi-nis-te-ria-lis-mo",
    "ministerialmente": "mi-nis-te-rial-men-te",
    "ministerio": "mi-nis-te-rio",
    "ministra": "mi-nis-tra",
    "ministrable": "mi-nis-tra-ble",
    "ministración": "mi-nis-tra-ción",
    "ministrador": "mi-nis-tra-dor",
    "ministradora": "mi-nis-tra-do-ra",
    "ministrante": "mi-nis-tran-te",
    "ministrar": "mi-nis-trar",
    "ministril": "mi-nis-tril",
    "ministro": "mi-nis-tro",
    "miniteca": "mi-ni-te-ca",
    "mino": "mi-no",
    "minoica": "mi-noi-ca",
    "minoico": "mi-noi-co",
    "miñón": "mi-ñón",
    "miñona": "mi-ño-na",
    "minoración": "mi-no-ra-ción",
    "minorar": "mi-no-rar",
    "minorativa": "mi-no-ra-ti-va",
    "minorativo": "mi-no-ra-ti-vo",
    "minoría": "mi-no-rí-a",
    "minoridad": "mi-no-ri-dad",
    "minorista": "mi-no-ris-ta",
    "minorita": "mi-no-ri-ta",
    "minoritario": "mi-no-ri-ta-rio",
    "miñosa": "mi-ño-sa",
    "mintrosa": "min-tro-sa",
    "mintroso": "min-tro-so",
    "minuana": "mi-nua-na",
    "minuano": "mi-nua-no",
    "minucia": "mi-nu-cia",
    "minuciosa": "mi-nu-cio-sa",
    "minuciosamente": "mi-nu-cio-sa-men-te",
    "minuciosidad": "mi-nu-cio-si-dad",
    "minucioso": "mi-nu-cio-so",
    "minué": "mi-nué",
    "minuendo": "mi-nuen-do",
    "minuete": "mi-nue-te",
    "minueto": "mi-nue-to",
    "minúscula": "mi-nús-cu-la",
    "minúsculo": "mi-nús-cu-lo",
    "minusvalía": "mi-nus-va-lí-a",
    "minusválida": "mi-nus-vá-li-da",
    "minusvalidez": "mi-nus-va-li-dez",
    "minusválido": "mi-nus-vá-li-do",
    "minusvaloración": "mi-nus-va-lo-ra-ción",
    "minusvalorar": "mi-nus-va-lo-rar",
    "minuta": "mi-nu-ta",
    "minutación": "mi-nu-ta-ción",
    "minutado": "mi-nu-ta-do",
    "minutaje": "mi-nu-ta-je",
    "minutar": "mi-nu-tar",
    "minutario": "mi-nu-ta-rio",
    "minutero": "mi-nu-te-ro",
    "minutisa": "mi-nu-ti-sa",
    "minuto": "mi-nu-to",
    "mío": "mí-o",
    "miocárdico": "mio-cár-di-co",
    "miocardio": "mio-car-dio",
    "miocarditis": "mio-car-di-tis",
    "miocénico": "mio-cé-ni-co",
    "mioceno": "mio-ce-no",
    "mioclonía": "mio-clo-ní-a",
    "miodinia": "mio-di-nia",
    "mioeléctrico": "mio-e-léc-tri-co",
    "miografía": "mio-gra-fí-a",
    "miolema": "mio-le-ma",
    "miología": "mio-lo-gí-a",
    "mioma": "mio-ma",
    "miomío": "mio-mí-o",
    "miona": "mio-na",
    "mioncillo": "mion-ci-llo",
    "miopatía": "mio-pa-tí-a",
    "miope": "mio-pe",
    "miopía": "mio-pí-a",
    "miosis": "mio-sis",
    "miosota": "mio-so-ta",
    "miosotis": "mio-so-tis",
    "miquelete": "mi-que-le-te",
    "miquero": "mi-que-ro",
    "miquilo": "mi-qui-lo",
    "miquis": "mi-quis",
    "mira": "mi-ra",
    "mirabel": "mi-ra-bel",
    "mirabelle": "mi-ra-be-lle",
    "mirable": "mi-ra-ble",
    "mirabolano": "mi-ra-bo-la-no",
    "mirabolanos": "mi-ra-bo-la-nos",
    "miracaimán": "mi-ra-cai-mán",
    "miraculosa": "mi-ra-cu-lo-sa",
    "miraculosamente": "mi-ra-cu-lo-sa-men-te",
    "miraculoso": "mi-ra-cu-lo-so",
    "mirada": "mi-ra-da",
    "miradero": "mi-ra-de-ro",
    "mirado": "mi-ra-do",
    "mirador": "mi-ra-dor",
    "miradora": "mi-ra-do-ra",
    "miradura": "mi-ra-du-ra",
    "miraglo": "mi-ra-glo",
    "miraguano": "mi-ra-gua-no",
    "miralejos": "mi-ra-le-jos",
    "miramamolín": "mi-ra-ma-mo-lín",
    "miramelindos": "mi-ra-me-lin-dos",
    "miramiento": "mi-ra-mien-to",
    "miranda": "mi-ran-da",
    "mirandés": "mi-ran-dés",
    "mirandesa": "mi-ran-de-sa",
    "mirandina": "mi-ran-di-na",
    "mirandino": "mi-ran-di-no",
    "mirar": "mi-rar",
    "mirasol": "mi-ra-sol",
    "miria": "mi-ria",
    "miríada": "mi-rí-a-da",
    "miriagramo": "mi-ria-gra-mo",
    "mirialitro": "mi-ria-li-tro",
    "miriámetro": "mi-riá-me-tro",
    "miriápodo": "mi-riá-po-do",
    "mirífica": "mi-rí-fi-ca",
    "mirificar": "mi-ri-fi-car",
    "mirífico": "mi-rí-fi-co",
    "mirilla": "mi-ri-lla",
    "miriñaque": "mi-ri-ña-que",
    "miriópodo": "mi-rió-po-do",
    "mirística": "mi-rís-ti-ca",
    "miristicácea": "mi-ris-ti-cá-ce-a",
    "miristicáceo": "mi-ris-ti-cá-ce-o",
    "mirla": "mir-la",
    "mirlamiento": "mir-la-mien-to",
    "mirlar": "mir-lar",
    "mirlarse": "mir-lar-se",
    "mirliflor": "mir-li-flor",
    "mirlitón": "mir-li-tón",
    "mirlo": "mir-lo",
    "mirobálano": "mi-ro-bá-la-no",
    "mirobálanos": "mi-ro-bá-la-nos",
    "mirobrigense": "mi-ro-bri-gen-se",
    "mirón": "mi-rón",
    "mirona": "mi-ro-na",
    "mirotón": "mi-ro-tón",
    "mirra": "mi-rra",
    "mirrada": "mi-rra-da",
    "mirrado": "mi-rra-do",
    "mirrauste": "mi-rraus-te",
    "mirria": "mi-rria",
    "mirrina": "mi-rri-na",
    "mirringa": "mi-rrin-ga",
    "mirrino": "mi-rri-no",
    "mirruña": "mi-rru-ña",
    "mirrusca": "mi-rrus-ca",
    "mirsinácea": "mir-si-ná-ce-a",
    "mirsináceo": "mir-si-ná-ce-o",
    "mirtácea": "mir-tá-ce-a",
    "mirtáceas": "mir-tá-ce-as",
    "mirtáceo": "mir-tá-ce-o",
    "mirtídano": "mir-tí-da-no",
    "mirtilo": "mir-ti-lo",
    "mirtina": "mir-ti-na",
    "mirtino": "mir-ti-no",
    "mirto": "mir-to",
    "miruégano": "mi-rué-ga-no",
    "miruella": "mi-rue-lla",
    "miruello": "mi-rue-llo",
    "mirza": "mir-za",
    "misa": "mi-sa",
    "misacantano": "mi-sa-can-ta-no",
    "misachico": "mi-sa-chi-co",
    "misal": "mi-sal",
    "misántropa": "mi-sán-tro-pa",
    "misantropía": "mi-san-tro-pí-a",
    "misantrópica": "mi-san-tró-pi-ca",
    "misantrópico": "mi-san-tró-pi-co",
    "misántropo": "mi-sán-tro-po",
    "misar": "mi-sar",
    "misario": "mi-sa-rio",
    "miscelánea": "mis-ce-lá-ne-a",
    "misceláneo": "mis-ce-lá-ne-o",
    "misciadura": "mis-cia-du-ra",
    "miscible": "mis-ci-ble",
    "mísera": "mí-se-ra",
    "miserable": "mi-se-ra-ble",
    "miserablemente": "mi-se-ra-ble-men-te",
    "miseración": "mi-se-ra-ción",
    "míseramente": "mí-se-ra-men-te",
    "miseranda": "mi-se-ran-da",
    "miserando": "mi-se-ran-do",
    "miserear": "mi-se-re-ar",
    "miserere": "mi-se-re-re",
    "miseria": "mi-se-ria",
    "misericordia": "mi-se-ri-cor-dia",
    "misericordiosa": "mi-se-ri-cor-dio-sa",
    "misericordiosamente": "mi-se-ri-cor-dio-sa-men-te",
    "misericordioso": "mi-se-ri-cor-dio-so",
    "miserioso": "mi-se-rio-so",
    "misero": "mi-se-ro",
    "mísero": "mí-se-ro",
    "misérrima": "mi-sé-rri-ma",
    "misérrimo": "mi-sé-rri-mo",
    "mishiadura": "mis-hia-du-ra",
    "misia": "mi-sia",
    "misiadura": "mi-sia-du-ra",
    "misil": "mi-sil",
    "misilera": "mi-si-le-ra",
    "misio": "mi-sio",
    "misión": "mi-sión",
    "misional": "mi-sio-nal",
    "misionar": "mi-sio-nar",
    "misionario": "mi-sio-na-rio",
    "misionera": "mi-sio-ne-ra",
    "misionero": "mi-sio-ne-ro",
    "misiones": "mi-sio-nes",
    "misiva": "mi-si-va",
    "misivo": "mi-si-vo",
    "misma": "mis-ma",
    "mismamente": "mis-ma-men-te",
    "mismidad": "mis-mi-dad",
    "mismísimo": "mis-mí-si-mo",
    "mismo": "mis-mo",
    "miso": "mi-so",
    "misoginia": "mi-so-gi-nia",
    "misógino": "mi-só-gi-no",
    "misoneísmo": "mi-so-ne-ís-mo",
    "misoneísta": "mi-so-ne-ís-ta",
    "míspero": "mís-pe-ro",
    "misquita": "mis-qui-ta",
    "misquito": "mis-qui-to",
    "missing": "mis-sing",
    "mista": "mis-ta",
    "mistagógica": "mis-ta-gó-gi-ca",
    "mistagógico": "mis-ta-gó-gi-co",
    "mistagogo": "mis-ta-go-go",
    "mistar": "mis-tar",
    "mistela": "mis-te-la",
    "míster": "mís-ter",
    "misterial": "mis-te-rial",
    "mistérico": "mis-té-ri-co",
    "misterio": "mis-te-rio",
    "misteriosa": "mis-te-rio-sa",
    "misteriosamente": "mis-te-rio-sa-men-te",
    "misterioso": "mis-te-rio-so",
    "mística": "mís-ti-ca",
    "místicamente": "mís-ti-ca-men-te",
    "misticeto": "mis-ti-ce-to",
    "misticetos": "mis-ti-ce-tos",
    "misticismo": "mis-ti-cis-mo",
    "místico": "mís-ti-co",
    "misticón": "mis-ti-cón",
    "misticona": "mis-ti-co-na",
    "mistificación": "mis-ti-fi-ca-ción",
    "mistificador": "mis-ti-fi-ca-dor",
    "mistificadora": "mis-ti-fi-ca-do-ra",
    "mistificar": "mis-ti-fi-car",
    "mistifori": "mis-ti-fo-ri",
    "mistilínea": "mis-ti-lí-ne-a",
    "mistilíneo": "mis-ti-lí-ne-o",
    "mistión": "mis-tión",
    "misto": "mis-to",
    "mistol": "mis-tol",
    "mistongo": "mis-ton-go",
    "mistral": "mis-tral",
    "mistura": "mis-tu-ra",
    "misturar": "mis-tu-rar",
    "misturera": "mis-tu-re-ra",
    "misturero": "mis-tu-re-ro",
    "misumalpa": "mi-su-mal-pa",
    "mita": "mi-ta",
    "mitaca": "mi-ta-ca",
    "mitad": "mi-tad",
    "mitadenco": "mi-ta-den-co",
    "mitán": "mi-tán",
    "mitaya": "mi-ta-ya",
    "mitayo": "mi-ta-yo",
    "mite": "mi-te",
    "mítica": "mí-ti-ca",
    "mítico": "mí-ti-co",
    "miticultura": "mi-ti-cul-tu-ra",
    "mitificación": "mi-ti-fi-ca-ción",
    "mitificar": "mi-ti-fi-car",
    "mitigación": "mi-ti-ga-ción",
    "mitigadamente": "mi-ti-ga-da-men-te",
    "mitigador": "mi-ti-ga-dor",
    "mitigadora": "mi-ti-ga-do-ra",
    "mitigar": "mi-ti-gar",
    "mitigativa": "mi-ti-ga-ti-va",
    "mitigativo": "mi-ti-ga-ti-vo",
    "mitigatoria": "mi-ti-ga-to-ria",
    "mitigatorio": "mi-ti-ga-to-rio",
    "mitilicultura": "mi-ti-li-cul-tu-ra",
    "mitimae": "mi-ti-ma-e",
    "mitimaes": "mi-ti-ma-es",
    "mitin": "mi-tin",
    "mitinear": "mi-ti-ne-ar",
    "mitinera": "mi-ti-ne-ra",
    "mitinero": "mi-ti-ne-ro",
    "mito": "mi-to",
    "mitocondria": "mi-to-con-dria",
    "mitógrafa": "mi-tó-gra-fa",
    "mitografía": "mi-to-gra-fí-a",
    "mitógrafo": "mi-tó-gra-fo",
    "mitóloga": "mi-tó-lo-ga",
    "mitología": "mi-to-lo-gí-a",
    "mitológica": "mi-to-ló-gi-ca",
    "mitológicamente": "mi-to-ló-gi-ca-men-te",
    "mitológico": "mi-to-ló-gi-co",
    "mitologista": "mi-to-lo-gis-ta",
    "mitólogo": "mi-tó-lo-go",
    "mitómana": "mi-tó-ma-na",
    "mitomanía": "mi-to-ma-ní-a",
    "mitómano": "mi-tó-ma-no",
    "mitón": "mi-tón",
    "mitosis": "mi-to-sis",
    "mitote": "mi-to-te",
    "mitotera": "mi-to-te-ra",
    "mitotero": "mi-to-te-ro",
    "mitótica": "mi-tó-ti-ca",
    "mitótico": "mi-tó-ti-co",
    "mitra": "mi-tra",
    "mitrada": "mi-tra-da",
    "mitrado": "mi-tra-do",
    "mitraísmo": "mi-tra-ís-mo",
    "mitral": "mi-tral",
    "mitrar": "mi-trar",
    "mitridatismo": "mi-tri-da-tis-mo",
    "mitridato": "mi-tri-da-to",
    "mituana": "mi-tua-na",
    "mituano": "mi-tua-no",
    "mítulo": "mí-tu-lo",
    "miura": "miu-ra",
    "mixe": "mi-xe",
    "mixedema": "mi-xe-de-ma",
    "mixiote": "mi-xio-te",
    "mixoma": "mi-xo-ma",
    "mixomatosis": "mi-xo-ma-to-sis",
    "mixomiceto": "mi-xo-mi-ce-to",
    "mixta": "mix-ta",
    "mixteco": "mix-te-co",
    "mixtela": "mix-te-la",
    "mixtificación": "mix-ti-fi-ca-ción",
    "mixtificador": "mix-ti-fi-ca-dor",
    "mixtificar": "mix-ti-fi-car",
    "mixtifori": "mix-ti-fo-ri",
    "mixtilínea": "mix-ti-lí-ne-a",
    "mixtilíneo": "mix-ti-lí-ne-o",
    "mixtión": "mix-tión",
    "mixto": "mix-to",
    "mixtura": "mix-tu-ra",
    "mixturar": "mix-tu-rar",
    "mixturera": "mix-tu-re-ra",
    "mixturero": "mix-tu-re-ro",
    "miza": "mi-za",
    "mizcal": "miz-cal",
    "mízcalo": "míz-ca-lo",
    "mizo": "mi-zo",
    "mizqueña": "miz-que-ña",
    "mizqueño": "miz-que-ño",
    "mnemónica": "mne-mó-ni-ca",
    "mnemónico": "mne-mó-ni-co",
    "mnemotecnia": "mne-mo-tec-nia",
    "mnemotécnica": "mne-mo-téc-ni-ca",
    "mnemotécnico": "mne-mo-téc-ni-co",
    "moa": "mo-a",
    "moabita": "mo-a-bi-ta",
    "moái": "mo-ái",
    "moaré": "mo-a-ré",
    "moaxaja": "mo-a-xa-ja",
    "mobiliaria": "mo-bi-lia-ria",
    "mobiliario": "mo-bi-lia-rio",
    "moblaje": "mo-bla-je",
    "moblar": "mo-blar",
    "moble": "mo-ble",
    "moca": "mo-ca",
    "mocador": "mo-ca-dor",
    "mocán": "mo-cán",
    "mocana": "mo-ca-na",
    "mocano": "mo-ca-no",
    "mocar": "mo-car",
    "mocárabe": "mo-cá-ra-be",
    "mocarra": "mo-ca-rra",
    "mocarro": "mo-ca-rro",
    "mocasín": "mo-ca-sín",
    "mocear": "mo-ce-ar",
    "mocedad": "mo-ce-dad",
    "mocejón": "mo-ce-jón",
    "moceña": "mo-ce-ña",
    "moceril": "mo-ce-ril",
    "mocerío": "mo-ce-rí-o",
    "mocero": "mo-ce-ro",
    "mocete": "mo-ce-te",
    "mocetón": "mo-ce-tón",
    "mocetona": "mo-ce-to-na",
    "mocezuelo": "mo-ce-zue-lo",
    "mocha": "mo-cha",
    "mochada": "mo-cha-da",
    "mochales": "mo-cha-les",
    "mochar": "mo-char",
    "mochazo": "mo-cha-zo",
    "moche": "mo-che",
    "mocheta": "mo-che-ta",
    "mochete": "mo-che-te",
    "mochica": "mo-chi-ca",
    "mochil": "mo-chil",
    "mochila": "mo-chi-la",
    "mochilear": "mo-chi-le-ar",
    "mochilera": "mo-chi-le-ra",
    "mochilero": "mo-chi-le-ro",
    "mochillero": "mo-chi-lle-ro",
    "mocho": "mo-cho",
    "mochonga": "mo-chon-ga",
    "mochongada": "mo-chon-ga-da",
    "mochongo": "mo-chon-go",
    "mochuelo": "mo-chue-lo",
    "mocil": "mo-cil",
    "moción": "mo-ción",
    "mocionar": "mo-cio-nar",
    "mocita": "mo-ci-ta",
    "mocito": "mo-ci-to",
    "moclín": "mo-clín",
    "moco": "mo-co",
    "mocoana": "mo-co-a-na",
    "mocoano": "mo-co-a-no",
    "mococoa": "mo-co-co-a",
    "mocosa": "mo-co-sa",
    "mocoso": "mo-co-so",
    "mocosuena": "mo-co-sue-na",
    "mocoví": "mo-co-ví",
    "moda": "mo-da",
    "modado": "mo-da-do",
    "modal": "mo-dal",
    "modalidad": "mo-da-li-dad",
    "modéjar": "mo-dé-jar",
    "modelable": "mo-de-la-ble",
    "modelación": "mo-de-la-ción",
    "modelado": "mo-de-la-do",
    "modelador": "mo-de-la-dor",
    "modeladora": "mo-de-la-do-ra",
    "modelar": "mo-de-lar",
    "modélico": "mo-dé-li-co",
    "modelismo": "mo-de-lis-mo",
    "modelista": "mo-de-lis-ta",
    "modelizar": "mo-de-li-zar",
    "modelo": "mo-de-lo",
    "módem": "mó-dem",
    "modenés": "mo-de-nés",
    "modenesa": "mo-de-ne-sa",
    "moderación": "mo-de-ra-ción",
    "moderada": "mo-de-ra-da",
    "moderadamente": "mo-de-ra-da-men-te",
    "moderado": "mo-de-ra-do",
    "moderador": "mo-de-ra-dor",
    "moderadora": "mo-de-ra-do-ra",
    "moderamiento": "mo-de-ra-mien-to",
    "moderante": "mo-de-ran-te",
    "moderantismo": "mo-de-ran-tis-mo",
    "moderar": "mo-de-rar",
    "moderativa": "mo-de-ra-ti-va",
    "moderativo": "mo-de-ra-ti-vo",
    "moderato": "mo-de-ra-to",
    "moderatoria": "mo-de-ra-to-ria",
    "moderatorio": "mo-de-ra-to-rio",
    "moderna": "mo-der-na",
    "modernamente": "mo-der-na-men-te",
    "modernez": "mo-der-nez",
    "modernidad": "mo-der-ni-dad",
    "modernismo": "mo-der-nis-mo",
    "modernista": "mo-der-nis-ta",
    "modernización": "mo-der-ni-za-ción",
    "modernizador": "mo-der-ni-za-dor",
    "modernizadora": "mo-der-ni-za-do-ra",
    "modernizar": "mo-der-ni-zar",
    "moderno": "mo-der-no",
    "modesta": "mo-des-ta",
    "modestamente": "mo-des-ta-men-te",
    "modestia": "mo-des-tia",
    "modesto": "mo-des-to",
    "módica": "mó-di-ca",
    "módicamente": "mó-di-ca-men-te",
    "modicidad": "mo-di-ci-dad",
    "módico": "mó-di-co",
    "modificable": "mo-di-fi-ca-ble",
    "modificación": "mo-di-fi-ca-ción",
    "modificador": "mo-di-fi-ca-dor",
    "modificadora": "mo-di-fi-ca-do-ra",
    "modificante": "mo-di-fi-can-te",
    "modificar": "mo-di-fi-car",
    "modificativa": "mo-di-fi-ca-ti-va",
    "modificativo": "mo-di-fi-ca-ti-vo",
    "modificatoria": "mo-di-fi-ca-to-ria",
    "modificatorio": "mo-di-fi-ca-to-rio",
    "modillón": "mo-di-llón",
    "modio": "mo-dio",
    "modismo": "mo-dis-mo",
    "modista": "mo-dis-ta",
    "modistilla": "mo-dis-ti-lla",
    "modisto": "mo-dis-to",
    "modo": "mo-do",
    "modorra": "mo-do-rra",
    "modorrar": "mo-do-rrar",
    "modorrilla": "mo-do-rri-lla",
    "modorrillo": "mo-do-rri-llo",
    "modorro": "mo-do-rro",
    "modosa": "mo-do-sa",
    "modosidad": "mo-do-si-dad",
    "modoso": "mo-do-so",
    "modrego": "mo-dre-go",
    "modulación": "mo-du-la-ción",
    "modulador": "mo-du-la-dor",
    "moduladora": "mo-du-la-do-ra",
    "modular": "mo-du-lar",
    "módulo": "mó-du-lo",
    "modulosa": "mo-du-lo-sa",
    "moduloso": "mo-du-lo-so",
    "modurria": "mo-du-rria",
    "moer": "mo-er",
    "mofa": "mo-fa",
    "mofador": "mo-fa-dor",
    "mofadora": "mo-fa-do-ra",
    "mofadura": "mo-fa-du-ra",
    "mofar": "mo-far",
    "mofeta": "mo-fe-ta",
    "mofle": "mo-fle",
    "moflear": "mo-fle-ar",
    "moflete": "mo-fle-te",
    "mofletuda": "mo-fle-tu-da",
    "mofletudo": "mo-fle-tu-do",
    "moflir": "mo-flir",
    "mofuco": "mo-fu-co",
    "moga": "mo-ga",
    "mogata": "mo-ga-ta",
    "mogataz": "mo-ga-taz",
    "mogate": "mo-ga-te",
    "mogato": "mo-ga-to",
    "mogo": "mo-go",
    "mogol": "mo-gol",
    "mogola": "mo-go-la",
    "mogólica": "mo-gó-li-ca",
    "mogólico": "mo-gó-li-co",
    "mogolla": "mo-go-lla",
    "mogollar": "mo-go-llar",
    "mogollo": "mo-go-llo",
    "mogollón": "mo-go-llón",
    "mogón": "mo-gón",
    "mogona": "mo-go-na",
    "mogote": "mo-go-te",
    "mogrollo": "mo-gro-llo",
    "moguereña": "mo-gue-re-ña",
    "moguereño": "mo-gue-re-ño",
    "moguillo": "mo-gui-llo",
    "mohada": "mo-ha-da",
    "moharra": "mo-ha-rra",
    "moharrache": "mo-ha-rra-che",
    "moharracho": "mo-ha-rra-cho",
    "mohatra": "mo-ha-tra",
    "mohatrar": "mo-ha-trar",
    "mohatrera": "mo-ha-tre-ra",
    "mohatrero": "mo-ha-tre-ro",
    "mohatrón": "mo-ha-trón",
    "mohatrona": "mo-ha-tro-na",
    "mohecer": "mo-he-cer",
    "moheda": "mo-he-da",
    "mohedal": "mo-he-dal",
    "moheña": "mo-he-ña",
    "moheño": "mo-he-ño",
    "mohicano": "mohi-ca-no",
    "mohienta": "mo-hien-ta",
    "mohiento": "mo-hien-to",
    "mohín": "mo-hín",
    "mohína": "mo-hí-na",
    "mohindad": "mohin-dad",
    "mohíno": "mo-hí-no",
    "moho": "mo-ho",
    "mohosa": "mo-ho-sa",
    "mohosear": "mo-ho-se-ar",
    "mohoso": "mo-ho-so",
    "mohúr": "mo-húr",
    "moisés": "moi-sés",
    "moishe": "mois-he",
    "mojábana": "mo-já-ba-na",
    "mojada": "mo-ja-da",
    "mojado": "mo-ja-do",
    "mojador": "mo-ja-dor",
    "mojadora": "mo-ja-do-ra",
    "mojadura": "mo-ja-du-ra",
    "mojama": "mo-ja-ma",
    "mojar": "mo-jar",
    "mojarra": "mo-ja-rra",
    "mojarrilla": "mo-ja-rri-lla",
    "moje": "mo-je",
    "mojel": "mo-jel",
    "mojeño": "mo-je-ño",
    "mojera": "mo-je-ra",
    "mojete": "mo-je-te",
    "mojí": "mo-jí",
    "mojicón": "mo-ji-cón",
    "mojiganga": "mo-ji-gan-ga",
    "mojigata": "mo-ji-ga-ta",
    "mojigatería": "mo-ji-ga-te-rí-a",
    "mojigatez": "mo-ji-ga-tez",
    "mojigato": "mo-ji-ga-to",
    "mojil": "mo-jil",
    "mojinete": "mo-ji-ne-te",
    "mojito": "mo-ji-to",
    "mojo": "mo-jo",
    "mojón": "mo-jón",
    "mojona": "mo-jo-na",
    "mojonación": "mo-jo-na-ción",
    "mojonar": "mo-jo-nar",
    "mojonera": "mo-jo-ne-ra",
    "mojonero": "mo-jo-ne-ro",
    "moka": "mo-ka",
    "mola": "mo-la",
    "molacho": "mo-la-cho",
    "molada": "mo-la-da",
    "molar": "mo-lar",
    "molaridad": "mo-la-ri-dad",
    "molasa": "mo-la-sa",
    "molcajete": "mol-ca-je-te",
    "molcajetear": "mol-ca-je-te-ar",
    "moldar": "mol-dar",
    "moldava": "mol-da-va",
    "moldavita": "mol-da-vi-ta",
    "moldavo": "mol-da-vo",
    "molde": "mol-de",
    "moldeable": "mol-de-a-ble",
    "moldeado": "mol-de-a-do",
    "moldeador": "mol-de-a-dor",
    "moldeadora": "mol-de-a-do-ra",
    "moldeamiento": "mol-de-a-mien-to",
    "moldear": "mol-de-ar",
    "moldeo": "mol-de-o",
    "moldero": "mol-de-ro",
    "moldura": "mol-du-ra",
    "molduración": "mol-du-ra-ción",
    "moldurar": "mol-du-rar",
    "mole": "mo-le",
    "molécula": "mo-lé-cu-la",
    "molecular": "mo-le-cu-lar",
    "moledera": "mo-le-de-ra",
    "moledero": "mo-le-de-ro",
    "moledor": "mo-le-dor",
    "moledora": "mo-le-do-ra",
    "moledura": "mo-le-du-ra",
    "moleja": "mo-le-ja",
    "molejón": "mo-le-jón",
    "moleña": "mo-le-ña",
    "molendera": "mo-len-de-ra",
    "molendero": "mo-len-de-ro",
    "moleño": "mo-le-ño",
    "moler": "mo-ler",
    "molera": "mo-le-ra",
    "molero": "mo-le-ro",
    "molesta": "mo-les-ta",
    "molestador": "mo-les-ta-dor",
    "molestadora": "mo-les-ta-do-ra",
    "molestamente": "mo-les-ta-men-te",
    "molestar": "mo-les-tar",
    "molestia": "mo-les-tia",
    "molesto": "mo-les-to",
    "molestosa": "mo-les-to-sa",
    "molestoso": "mo-les-to-so",
    "moleta": "mo-le-ta",
    "molibdeno": "mo-lib-de-no",
    "molicie": "mo-li-cie",
    "molido": "mo-li-do",
    "molienda": "mo-lien-da",
    "moliente": "mo-lien-te",
    "molificable": "mo-li-fi-ca-ble",
    "molificación": "mo-li-fi-ca-ción",
    "molificar": "mo-li-fi-car",
    "molificativa": "mo-li-fi-ca-ti-va",
    "molificativo": "mo-li-fi-ca-ti-vo",
    "molimiento": "mo-li-mien-to",
    "molinada": "mo-li-na-da",
    "molinar": "mo-li-nar",
    "molinera": "mo-li-ne-ra",
    "molinería": "mo-li-ne-rí-a",
    "molinero": "mo-li-ne-ro",
    "molinés": "mo-li-nés",
    "molinesa": "mo-li-ne-sa",
    "molinete": "mo-li-ne-te",
    "molinetear": "mo-li-ne-te-ar",
    "molinillo": "mo-li-ni-llo",
    "molinismo": "mo-li-nis-mo",
    "molinista": "mo-li-nis-ta",
    "molinito": "mo-li-ni-to",
    "molino": "mo-li-no",
    "molinosismo": "mo-li-no-sis-mo",
    "molinosista": "mo-li-no-sis-ta",
    "molitiva": "mo-li-ti-va",
    "molitivo": "mo-li-ti-vo",
    "molla": "mo-lla",
    "mollar": "mo-llar",
    "molle": "mo-lle",
    "mollear": "mo-lle-ar",
    "molledo": "mo-lle-do",
    "molleja": "mo-lle-ja",
    "mollejo": "mo-lle-jo",
    "mollejón": "mo-lle-jón",
    "mollendina": "mo-llen-di-na",
    "mollendino": "mo-llen-di-no",
    "mollera": "mo-lle-ra",
    "mollero": "mo-lle-ro",
    "molleta": "mo-lle-ta",
    "molletas": "mo-lle-tas",
    "mollete": "mo-lle-te",
    "molletera": "mo-lle-te-ra",
    "molletero": "mo-lle-te-ro",
    "molletuda": "mo-lle-tu-da",
    "molletudo": "mo-lle-tu-do",
    "mollez": "mo-llez",
    "molleza": "mo-lle-za",
    "mollicia": "mo-lli-cia",
    "mollicio": "mo-lli-cio",
    "mollidura": "mo-lli-du-ra",
    "mollificar": "mo-lli-fi-car",
    "mollina": "mo-lli-na",
    "mollinear": "mo-lli-ne-ar",
    "mollino": "mo-lli-no",
    "mollir": "mo-llir",
    "mollizna": "mo-lliz-na",
    "molliznar": "mo-lliz-nar",
    "molliznear": "mo-lliz-ne-ar",
    "molo": "mo-lo",
    "molón": "mo-lón",
    "molona": "mo-lo-na",
    "molondra": "mo-lon-dra",
    "molondro": "mo-lon-dro",
    "molondrón": "mo-lon-drón",
    "molonquear": "mo-lon-que-ar",
    "molosa": "mo-lo-sa",
    "moloso": "mo-lo-so",
    "molote": "mo-lo-te",
    "molotera": "mo-lo-te-ra",
    "molsa": "mol-sa",
    "molso": "mol-so",
    "moltura": "mol-tu-ra",
    "molturación": "mol-tu-ra-ción",
    "molturador": "mol-tu-ra-dor",
    "molturar": "mol-tu-rar",
    "molusco": "mo-lus-co",
    "momeador": "mo-me-a-dor",
    "momeadora": "mo-me-a-do-ra",
    "momear": "mo-me-ar",
    "momentánea": "mo-men-tá-ne-a",
    "momentáneamente": "mo-men-tá-ne-a-men-te",
    "momentáneo": "mo-men-tá-ne-o",
    "momento": "mo-men-to",
    "momera": "mo-me-ra",
    "momería": "mo-me-rí-a",
    "momero": "mo-me-ro",
    "momia": "mo-mia",
    "momificación": "mo-mi-fi-ca-ción",
    "momificar": "mo-mi-fi-car",
    "momio": "mo-mio",
    "momo": "mo-mo",
    "momórdiga": "mo-mór-di-ga",
    "momperada": "mom-pe-ra-da",
    "momperado": "mom-pe-ra-do",
    "mona": "mo-na",
    "moña": "mo-ña",
    "monacal": "mo-na-cal",
    "monacato": "mo-na-ca-to",
    "monacillo": "mo-na-ci-llo",
    "monacordio": "mo-na-cor-dio",
    "monada": "mo-na-da",
    "mónada": "mó-na-da",
    "monadelfos": "mo-na-del-fos",
    "monadología": "mo-na-do-lo-gí-a",
    "monago": "mo-na-go",
    "monaguense": "mo-na-guen-se",
    "monaguillo": "mo-na-gui-llo",
    "monaquismo": "mo-na-quis-mo",
    "monarca": "mo-nar-ca",
    "monarquía": "mo-nar-quí-a",
    "monárquica": "mo-nár-qui-ca",
    "monárquicamente": "mo-nár-qui-ca-men-te",
    "monárquico": "mo-nár-qui-co",
    "monarquismo": "mo-nar-quis-mo",
    "monasterial": "mo-nas-te-rial",
    "monasterio": "mo-nas-te-rio",
    "monástica": "mo-nás-ti-ca",
    "monásticamente": "mo-nás-ti-ca-men-te",
    "monástico": "mo-nás-ti-co",
    "moncheta": "mon-che-ta",
    "monda": "mon-da",
    "mondaderas": "mon-da-de-ras",
    "mondadientes": "mon-da-dien-tes",
    "mondador": "mon-da-dor",
    "mondadora": "mon-da-do-ra",
    "mondadura": "mon-da-du-ra",
    "mondaoídos": "mon-da-o-í-dos",
    "mondaorejas": "mon-da-o-re-jas",
    "mondapozos": "mon-da-po-zos",
    "mondar": "mon-dar",
    "mondarajas": "mon-da-ra-jas",
    "mondaria": "mon-da-ria",
    "mondejo": "mon-de-jo",
    "mondiola": "mon-dio-la",
    "mondo": "mon-do",
    "mondón": "mon-dón",
    "mondonga": "mon-don-ga",
    "mondongo": "mon-don-go",
    "mondonguera": "mon-don-gue-ra",
    "mondonguería": "mon-don-gue-rí-a",
    "mondonguero": "mon-don-gue-ro",
    "mondonguil": "mon-don-guil",
    "móndriga": "món-dri-ga",
    "móndrigo": "món-dri-go",
    "monear": "mo-ne-ar",
    "monecillo": "mo-ne-ci-llo",
    "moneda": "mo-ne-da",
    "monedado": "mo-ne-da-do",
    "monedaje": "mo-ne-da-je",
    "monedar": "mo-ne-dar",
    "monedear": "mo-ne-de-ar",
    "monedería": "mo-ne-de-rí-a",
    "monedero": "mo-ne-de-ro",
    "monegasca": "mo-ne-gas-ca",
    "monegasco": "mo-ne-gas-co",
    "monegrina": "mo-ne-gri-na",
    "monegrino": "mo-ne-gri-no",
    "monema": "mo-ne-ma",
    "monera": "mo-ne-ra",
    "mónera": "mó-ne-ra",
    "monería": "mo-ne-rí-a",
    "monesca": "mo-nes-ca",
    "monesco": "mo-nes-co",
    "monesterio": "mo-nes-te-rio",
    "monetaria": "mo-ne-ta-ria",
    "monetario": "mo-ne-ta-rio",
    "monetarismo": "mo-ne-ta-ris-mo",
    "monetarista": "mo-ne-ta-ris-ta",
    "monetización": "mo-ne-ti-za-ción",
    "monetizar": "mo-ne-ti-zar",
    "monfí": "mon-fí",
    "monfortina": "mon-for-ti-na",
    "monfortino": "mon-for-ti-no",
    "monga": "mon-ga",
    "mongo": "mon-go",
    "mongol": "mon-gol",
    "mongola": "mon-go-la",
    "mongólica": "mon-gó-li-ca",
    "mongólico": "mon-gó-li-co",
    "mongolismo": "mon-go-lis-mo",
    "mongoloide": "mon-go-loi-de",
    "moni": "mo-ni",
    "moniato": "mo-nia-to",
    "monicaca": "mo-ni-ca-ca",
    "monicaco": "mo-ni-ca-co",
    "monición": "mo-ni-ción",
    "moñiga": "mo-ñi-ga",
    "monigote": "mo-ni-go-te",
    "monilla": "mo-ni-lla",
    "monillo": "mo-ni-llo",
    "monimiácea": "mo-ni-miá-ce-a",
    "monimiáceo": "mo-ni-miá-ce-o",
    "monipodio": "mo-ni-po-dio",
    "monís": "mo-nís",
    "monismo": "mo-nis-mo",
    "monista": "mo-nis-ta",
    "moñista": "mo-ñis-ta",
    "moñita": "mo-ñi-ta",
    "mónita": "mó-ni-ta",
    "monito": "mo-ni-to",
    "monitor": "mo-ni-tor",
    "monitora": "mo-ni-to-ra",
    "monitoria": "mo-ni-to-ria",
    "monitorio": "mo-ni-to-rio",
    "monitorización": "mo-ni-to-ri-za-ción",
    "monitorizar": "mo-ni-to-ri-zar",
    "monitos": "mo-ni-tos",
    "monja": "mon-ja",
    "monje": "mon-je",
    "monjerío": "mon-je-rí-o",
    "monjía": "mon-jí-a",
    "monjil": "mon-jil",
    "monjío": "mon-jí-o",
    "monjita": "mon-ji-ta",
    "mono": "mo-no",
    "moño": "mo-ño",
    "monoaural": "mo-no-au-ral",
    "monobásico": "mo-no-bá-si-co",
    "monobikini": "mo-no-bi-ki-ni",
    "monobiquini": "mo-no-bi-qui-ni",
    "monobloque": "mo-no-blo-que",
    "monocameral": "mo-no-ca-me-ral",
    "monocarril": "mo-no-ca-rril",
    "monocasco": "mo-no-cas-co",
    "monocelular": "mo-no-ce-lu-lar",
    "monoceronte": "mo-no-ce-ron-te",
    "monocerote": "mo-no-ce-ro-te",
    "monociclo": "mo-no-ci-clo",
    "monocigótico": "mo-no-ci-gó-ti-co",
    "monocito": "mo-no-ci-to",
    "monoclamídea": "mo-no-cla-mí-de-a",
    "monoclamídeo": "mo-no-cla-mí-de-o",
    "monoclinal": "mo-no-cli-nal",
    "monoclínico": "mo-no-clí-ni-co",
    "monocloroacético": "mo-no-clo-ro-a-cé-ti-co",
    "monocolor": "mo-no-co-lor",
    "monocorde": "mo-no-cor-de",
    "monocordio": "mo-no-cor-dio",
    "monocotiledón": "mo-no-co-ti-le-dón",
    "monocotiledónea": "mo-no-co-ti-le-dó-ne-a",
    "monocotiledóneas": "mo-no-co-ti-le-dó-ne-as",
    "monocotiledóneo": "mo-no-co-ti-le-dó-ne-o",
    "monocroma": "mo-no-cro-ma",
    "monocromático": "mo-no-cro-má-ti-co",
    "monocromía": "mo-no-cro-mí-a",
    "monocromo": "mo-no-cro-mo",
    "monócula": "mo-nó-cu-la",
    "monocular": "mo-no-cu-lar",
    "monóculo": "mo-nó-cu-lo",
    "monocultivo": "mo-no-cul-ti-vo",
    "monodia": "mo-no-dia",
    "monódica": "mo-nó-di-ca",
    "monódico": "mo-nó-di-co",
    "monofásica": "mo-no-fá-si-ca",
    "monofásico": "mo-no-fá-si-co",
    "monofila": "mo-no-fi-la",
    "monofilo": "mo-no-fi-lo",
    "monofisismo": "mo-no-fi-sis-mo",
    "monofisita": "mo-no-fi-si-ta",
    "monofonemático": "mo-no-fo-ne-má-ti-co",
    "monofónico": "mo-no-fó-ni-co",
    "monógama": "mo-nó-ga-ma",
    "monogamia": "mo-no-ga-mia",
    "monógamo": "mo-nó-ga-mo",
    "monogenismo": "mo-no-ge-nis-mo",
    "monogenista": "mo-no-ge-nis-ta",
    "monografía": "mo-no-gra-fí-a",
    "monográfica": "mo-no-grá-fi-ca",
    "monográfico": "mo-no-grá-fi-co",
    "monografista": "mo-no-gra-fis-ta",
    "monograma": "mo-no-gra-ma",
    "monoica": "mo-noi-ca",
    "monoico": "mo-noi-co",
    "monokini": "mo-no-ki-ni",
    "monolingüe": "mo-no-lin-güe",
    "monolingüismo": "mo-no-lin-güis-mo",
    "monolítica": "mo-no-lí-ti-ca",
    "monolíticamente": "mo-no-lí-ti-ca-men-te",
    "monolítico": "mo-no-lí-ti-co",
    "monolitismo": "mo-no-li-tis-mo",
    "monolito": "mo-no-li-to",
    "monologal": "mo-no-lo-gal",
    "monologante": "mo-no-lo-gan-te",
    "monologar": "mo-no-lo-gar",
    "monólogo": "mo-nó-lo-go",
    "monomando": "mo-no-man-do",
    "monomanía": "mo-no-ma-ní-a",
    "monomaníaca": "mo-no-ma-ní-a-ca",
    "monomaniaca": "mo-no-ma-nia-ca",
    "monomaníaco": "mo-no-ma-ní-a-co",
    "monomaniaco": "mo-no-ma-nia-co",
    "monomaniática": "mo-no-ma-niá-ti-ca",
    "monomaniático": "mo-no-ma-niá-ti-co",
    "monomaquia": "mo-no-ma-quia",
    "monómero": "mo-nó-me-ro",
    "monometalismo": "mo-no-me-ta-lis-mo",
    "monometalista": "mo-no-me-ta-lis-ta",
    "monomiario": "mo-no-mia-rio",
    "monomio": "mo-no-mio",
    "monomotor": "mo-no-mo-tor",
    "moñón": "mo-ñón",
    "monona": "mo-no-na",
    "moñona": "mo-ño-na",
    "mononucleosis": "mo-no-nu-cle-o-sis",
    "monoparental": "mo-no-pa-ren-tal",
    "monopastos": "mo-no-pas-tos",
    "monopatín": "mo-no-pa-tín",
    "monopétala": "mo-no-pé-ta-la",
    "monopétalo": "mo-no-pé-ta-lo",
    "monoplacóforo": "mo-no-pla-có-fo-ro",
    "monoplano": "mo-no-pla-no",
    "monoplaza": "mo-no-pla-za",
    "monoplejía": "mo-no-ple-jí-a",
    "monopolio": "mo-no-po-lio",
    "monopolista": "mo-no-po-lis-ta",
    "monopolístico": "mo-no-po-lís-ti-co",
    "monopolización": "mo-no-po-li-za-ción",
    "monopolizador": "mo-no-po-li-za-dor",
    "monopolizadora": "mo-no-po-li-za-do-ra",
    "monopolizar": "mo-no-po-li-zar",
    "monopsonio": "mo-nop-so-nio",
    "monóptera": "mo-nóp-te-ra",
    "monóptero": "mo-nóp-te-ro",
    "monoptongación": "mo-nop-ton-ga-ción",
    "monoptongar": "mo-nop-ton-gar",
    "monoptongo": "mo-nop-ton-go",
    "monoquini": "mo-no-qui-ni",
    "monorquidia": "mo-nor-qui-dia",
    "monorraíl": "mo-no-rra-íl",
    "monorriel": "mo-no-rriel",
    "monorrima": "mo-no-rri-ma",
    "monorrimo": "mo-no-rri-mo",
    "monorrítmica": "mo-no-rrít-mi-ca",
    "monorrítmico": "mo-no-rrít-mi-co",
    "monosabio": "mo-no-sa-bio",
    "monosacárido": "mo-no-sa-cá-ri-do",
    "monosépala": "mo-no-sé-pa-la",
    "monosépalo": "mo-no-sé-pa-lo",
    "monosílaba": "mo-no-sí-la-ba",
    "monosilábica": "mo-no-si-lá-bi-ca",
    "monosilábico": "mo-no-si-lá-bi-co",
    "monosilabismo": "mo-no-si-la-bis-mo",
    "monosílabo": "mo-no-sí-la-bo",
    "monospastos": "mo-nos-pas-tos",
    "monosperma": "mo-nos-per-ma",
    "monospermo": "mo-nos-per-mo",
    "monóstrofe": "mo-nós-tro-fe",
    "monostrófica": "mo-nos-tró-fi-ca",
    "monostrófico": "mo-nos-tró-fi-co",
    "monote": "mo-no-te",
    "monoteísmo": "mo-no-te-ís-mo",
    "monoteísta": "mo-no-te-ís-ta",
    "monotelismo": "mo-no-te-lis-mo",
    "monotelita": "mo-no-te-li-ta",
    "monotemático": "mo-no-te-má-ti-co",
    "monotipia": "mo-no-ti-pia",
    "monotipo": "mo-no-ti-po",
    "monótona": "mo-nó-to-na",
    "monótonamente": "mo-nó-to-na-men-te",
    "monotonía": "mo-no-to-ní-a",
    "monótono": "mo-nó-to-no",
    "monotrema": "mo-no-tre-ma",
    "monovalente": "mo-no-va-len-te",
    "monovera": "mo-no-ve-ra",
    "monovero": "mo-no-ve-ro",
    "monovolumen": "mo-no-vo-lu-men",
    "monóxido": "mo-nó-xi-do",
    "monóxilo": "mo-nó-xi-lo",
    "monozigótico": "mo-no-zi-gó-ti-co",
    "monra": "mon-ra",
    "monse": "mon-se",
    "monseñor": "mon-se-ñor",
    "monserga": "mon-ser-ga",
    "monstro": "mons-tro",
    "monstruo": "mons-truo",
    "monstruosa": "mons-truo-sa",
    "monstruosamente": "mons-truo-sa-men-te",
    "monstruosidad": "mons-truo-si-dad",
    "monstruoso": "mons-truo-so",
    "monta": "mon-ta",
    "montacargas": "mon-ta-car-gas",
    "montada": "mon-ta-da",
    "montadero": "mon-ta-de-ro",
    "montadgo": "mon-tad-go",
    "montado": "mon-ta-do",
    "montador": "mon-ta-dor",
    "montadora": "mon-ta-do-ra",
    "montadura": "mon-ta-du-ra",
    "montaje": "mon-ta-je",
    "montambanco": "mon-tam-ban-co",
    "montaña": "mon-ta-ña",
    "montanear": "mon-ta-ne-ar",
    "montanera": "mon-ta-ne-ra",
    "montañera": "mon-ta-ñe-ra",
    "montanero": "mon-ta-ne-ro",
    "montañero": "mon-ta-ñe-ro",
    "montañés": "mon-ta-ñés",
    "montañesa": "mon-ta-ñe-sa",
    "montañesismo": "mon-ta-ñe-sis-mo",
    "montanismo": "mon-ta-nis-mo",
    "montañismo": "mon-ta-ñis-mo",
    "montanista": "mon-ta-nis-ta",
    "montañista": "mon-ta-ñis-ta",
    "montano": "mon-ta-no",
    "montañosa": "mon-ta-ño-sa",
    "montañoso": "mon-ta-ño-so",
    "montantada": "mon-tan-ta-da",
    "montante": "mon-tan-te",
    "montantear": "mon-tan-te-ar",
    "montantero": "mon-tan-te-ro",
    "montaplatos": "mon-ta-pla-tos",
    "montar": "mon-tar",
    "montaraz": "mon-ta-raz",
    "montaraza": "mon-ta-ra-za",
    "montazal": "mon-ta-zal",
    "montazgar": "mon-taz-gar",
    "montazgo": "mon-taz-go",
    "monte": "mon-te",
    "montea": "mon-te-a",
    "monteador": "mon-te-a-dor",
    "montear": "mon-te-ar",
    "montecristeña": "mon-te-cris-te-ña",
    "montecristeño": "mon-te-cris-te-ño",
    "monteleva": "mon-te-le-va",
    "montenegrina": "mon-te-ne-gri-na",
    "montenegrino": "mon-te-ne-gri-no",
    "montepiada": "mon-te-pia-da",
    "montepiado": "mon-te-pia-do",
    "montepío": "mon-te-pí-o",
    "montera": "mon-te-ra",
    "montereña": "mon-te-re-ña",
    "montereño": "mon-te-re-ño",
    "monterera": "mon-te-re-ra",
    "monterería": "mon-te-re-rí-a",
    "monterero": "mon-te-re-ro",
    "montería": "mon-te-rí-a",
    "monteriana": "mon-te-ria-na",
    "monteriano": "mon-te-ria-no",
    "monterilla": "mon-te-ri-lla",
    "montero": "mon-te-ro",
    "monterrey": "mon-te-rrey",
    "montés": "mon-tés",
    "montesa": "mon-te-sa",
    "montesco": "mon-tes-co",
    "montesina": "mon-te-si-na",
    "montesino": "mon-te-si-no",
    "montevideana": "mon-te-vi-de-a-na",
    "montevideano": "mon-te-vi-de-a-no",
    "montgolfier": "mont-gol-fier",
    "montículo": "mon-tí-cu-lo",
    "montilla": "mon-ti-lla",
    "montillana": "mon-ti-lla-na",
    "montillano": "mon-ti-lla-no",
    "montiña": "mon-ti-ña",
    "monto": "mon-to",
    "montón": "mon-tón",
    "montonal": "mon-to-nal",
    "montonera": "mon-to-ne-ra",
    "montonero": "mon-to-ne-ro",
    "montoreña": "mon-to-re-ña",
    "montoreño": "mon-to-re-ño",
    "montosa": "mon-to-sa",
    "montoso": "mon-to-so",
    "montubia": "mon-tu-bia",
    "montubio": "mon-tu-bio",
    "montuna": "mon-tu-na",
    "montuno": "mon-tu-no",
    "montuosa": "mon-tuo-sa",
    "montuosidad": "mon-tuo-si-dad",
    "montuoso": "mon-tuo-so",
    "montura": "mon-tu-ra",
    "moñuda": "mo-ñu-da",
    "moñudo": "mo-ñu-do",
    "monuela": "mo-nue-la",
    "monuelo": "mo-nue-lo",
    "monumental": "mo-nu-men-tal",
    "monumentalidad": "mo-nu-men-ta-li-dad",
    "monumentalismo": "mo-nu-men-ta-lis-mo",
    "monumentalista": "mo-nu-men-ta-lis-ta",
    "monumentalizar": "mo-nu-men-ta-li-zar",
    "monumento": "mo-nu-men-to",
    "monzón": "mon-zón",
    "monzónico": "mon-zó-ni-co",
    "mopa": "mo-pa",
    "mopán": "mo-pán",
    "moquear": "mo-que-ar",
    "moquehuana": "mo-que-hua-na",
    "moquehuano": "mo-que-hua-no",
    "moqueo": "mo-que-o",
    "moquera": "mo-que-ra",
    "moquero": "mo-que-ro",
    "moqueta": "mo-que-ta",
    "moquete": "mo-que-te",
    "moquetear": "mo-que-te-ar",
    "moquillo": "mo-qui-llo",
    "moquita": "mo-qui-ta",
    "moquitear": "mo-qui-te-ar",
    "mora": "mo-ra",
    "morabetino": "mo-ra-be-ti-no",
    "morabito": "mo-ra-bi-to",
    "morabuto": "mo-ra-bu-to",
    "morácea": "mo-rá-ce-a",
    "moráceas": "mo-rá-ce-as",
    "moráceo": "mo-rá-ce-o",
    "moracha": "mo-ra-cha",
    "moracho": "mo-ra-cho",
    "morada": "mo-ra-da",
    "morado": "mo-ra-do",
    "morador": "mo-ra-dor",
    "moradora": "mo-ra-do-ra",
    "moradura": "mo-ra-du-ra",
    "moradux": "mo-ra-dux",
    "moraga": "mo-ra-ga",
    "morago": "mo-ra-go",
    "moral": "mo-ral",
    "moraleda": "mo-ra-le-da",
    "moraleja": "mo-ra-le-ja",
    "moralidad": "mo-ra-li-dad",
    "moralina": "mo-ra-li-na",
    "moralismo": "mo-ra-lis-mo",
    "moralista": "mo-ra-lis-ta",
    "moralización": "mo-ra-li-za-ción",
    "moralizador": "mo-ra-li-za-dor",
    "moralizadora": "mo-ra-li-za-do-ra",
    "moralizante": "mo-ra-li-zan-te",
    "moralizar": "mo-ra-li-zar",
    "moralmente": "mo-ral-men-te",
    "morán": "mo-rán",
    "moranza": "mo-ran-za",
    "morapio": "mo-ra-pio",
    "morar": "mo-rar",
    "moratiniana": "mo-ra-ti-nia-na",
    "moratiniano": "mo-ra-ti-nia-no",
    "morato": "mo-ra-to",
    "moratón": "mo-ra-tón",
    "moratoria": "mo-ra-to-ria",
    "morava": "mo-ra-va",
    "moravo": "mo-ra-vo",
    "morazanense": "mo-ra-za-nen-se",
    "mórbida": "mór-bi-da",
    "morbidez": "mor-bi-dez",
    "morbideza": "mor-bi-de-za",
    "mórbido": "mór-bi-do",
    "morbífica": "mor-bí-fi-ca",
    "morbífico": "mor-bí-fi-co",
    "morbilidad": "mor-bi-li-dad",
    "morbo": "mor-bo",
    "morbosa": "mor-bo-sa",
    "morbosamente": "mor-bo-sa-men-te",
    "morbosidad": "mor-bo-si-dad",
    "morboso": "mor-bo-so",
    "morca": "mor-ca",
    "morcacho": "mor-ca-cho",
    "morcajo": "mor-ca-jo",
    "morcal": "mor-cal",
    "morcar": "mor-car",
    "morceguila": "mor-ce-gui-la",
    "morcella": "mor-ce-lla",
    "morceña": "mor-ce-ña",
    "morciguillo": "mor-ci-gui-llo",
    "morcilla": "mor-ci-lla",
    "morcillera": "mor-ci-lle-ra",
    "morcillero": "mor-ci-lle-ro",
    "morcillo": "mor-ci-llo",
    "morcillón": "mor-ci-llón",
    "morcón": "mor-cón",
    "morcuero": "mor-cue-ro",
    "mordacear": "mor-da-ce-ar",
    "mordacidad": "mor-da-ci-dad",
    "mordaga": "mor-da-ga",
    "mordante": "mor-dan-te",
    "mordaz": "mor-daz",
    "mordaza": "mor-da-za",
    "mordazmente": "mor-daz-men-te",
    "mordedera": "mor-de-de-ra",
    "mordedor": "mor-de-dor",
    "mordedora": "mor-de-do-ra",
    "mordedura": "mor-de-du-ra",
    "mordelón": "mor-de-lón",
    "mordelona": "mor-de-lo-na",
    "mordente": "mor-den-te",
    "morder": "mor-der",
    "mordicación": "mor-di-ca-ción",
    "mordicante": "mor-di-can-te",
    "mordicar": "mor-di-car",
    "mordicativa": "mor-di-ca-ti-va",
    "mordicativo": "mor-di-ca-ti-vo",
    "mordida": "mor-di-da",
    "mordido": "mor-di-do",
    "mordidura": "mor-di-du-ra",
    "mordiente": "mor-dien-te",
    "mordihuí": "mor-di-huí",
    "mordimiento": "mor-di-mien-to",
    "mordiscar": "mor-dis-car",
    "mordisco": "mor-dis-co",
    "mordisquear": "mor-dis-que-ar",
    "mordisqueo": "mor-dis-que-o",
    "mórea": "mó-re-a",
    "moreda": "mo-re-da",
    "morelense": "mo-re-len-se",
    "moreliana": "mo-re-lia-na",
    "moreliano": "mo-re-lia-no",
    "morellana": "mo-re-lla-na",
    "morellano": "mo-re-lla-no",
    "morena": "mo-re-na",
    "morenal": "mo-re-nal",
    "morenero": "mo-re-ne-ro",
    "morenez": "mo-re-nez",
    "morenillo": "mo-re-ni-llo",
    "morenito": "mo-re-ni-to",
    "moreno": "mo-re-no",
    "morenura": "mo-re-nu-ra",
    "móreo": "mó-re-o",
    "morera": "mo-re-ra",
    "moreral": "mo-re-ral",
    "morería": "mo-re-rí-a",
    "morete": "mo-re-te",
    "moretear": "mo-re-te-ar",
    "moretón": "mo-re-tón",
    "morfa": "mor-fa",
    "morfar": "mor-far",
    "morfe": "mor-fe",
    "morfea": "mor-fe-a",
    "morfema": "mor-fe-ma",
    "morfemático": "mor-fe-má-ti-co",
    "morfeo": "mor-fe-o",
    "morfi": "mor-fi",
    "morfina": "mor-fi-na",
    "morfinismo": "mor-fi-nis-mo",
    "morfinómana": "mor-fi-nó-ma-na",
    "morfinomanía": "mor-fi-no-ma-ní-a",
    "morfinómano": "mor-fi-nó-ma-no",
    "morfo": "mor-fo",
    "morfofonología": "mor-fo-fo-no-lo-gí-a",
    "morfofonológico": "mor-fo-fo-no-ló-gi-co",
    "morfología": "mor-fo-lo-gí-a",
    "morfológica": "mor-fo-ló-gi-ca",
    "morfológico": "mor-fo-ló-gi-co",
    "morfosintáctico": "mor-fo-sin-tác-ti-co",
    "morfosintaxis": "mor-fo-sin-ta-xis",
    "morga": "mor-ga",
    "morganática": "mor-ga-ná-ti-ca",
    "morganático": "mor-ga-ná-ti-co",
    "morgaño": "mor-ga-ño",
    "morgón": "mor-gón",
    "morgue": "mor-gue",
    "morguera": "mor-gue-ra",
    "moriángano": "mo-rián-ga-no",
    "moribunda": "mo-ri-bun-da",
    "moribundo": "mo-ri-bun-do",
    "morichal": "mo-ri-chal",
    "moriche": "mo-ri-che",
    "moridera": "mo-ri-de-ra",
    "moridero": "mo-ri-de-ro",
    "moridor": "mo-ri-dor",
    "moriega": "mo-rie-ga",
    "moriego": "mo-rie-go",
    "morigeración": "mo-ri-ge-ra-ción",
    "morigerada": "mo-ri-ge-ra-da",
    "morigerado": "mo-ri-ge-ra-do",
    "morigerar": "mo-ri-ge-rar",
    "moriles": "mo-ri-les",
    "morilla": "mo-ri-lla",
    "morillero": "mo-ri-lle-ro",
    "morillo": "mo-ri-llo",
    "moringa": "mo-rin-ga",
    "moringácea": "mo-rin-gá-ce-a",
    "moringáceo": "mo-rin-gá-ce-o",
    "morionda": "mo-rion-da",
    "moriondo": "mo-rion-do",
    "morir": "mo-rir",
    "morisca": "mo-ris-ca",
    "morisco": "mo-ris-co",
    "morisma": "mo-ris-ma",
    "morisqueta": "mo-ris-que-ta",
    "morito": "mo-ri-to",
    "moriviví": "mo-ri-vi-ví",
    "morlaca": "mor-la-ca",
    "morlaco": "mor-la-co",
    "morlés": "mor-lés",
    "morlón": "mor-lón",
    "morlona": "mor-lo-na",
    "mormado": "mor-ma-do",
    "mormar": "mor-mar",
    "mormón": "mor-món",
    "mormona": "mor-mo-na",
    "mormónica": "mor-mó-ni-ca",
    "mormónico": "mor-mó-ni-co",
    "mormonismo": "mor-mo-nis-mo",
    "mormotear": "mor-mo-te-ar",
    "mormullar": "mor-mu-llar",
    "mormullo": "mor-mu-llo",
    "moro": "mo-ro",
    "morocada": "mo-ro-ca-da",
    "morocha": "mo-ro-cha",
    "morochillo": "mo-ro-chi-llo",
    "morocho": "mo-ro-cho",
    "morocota": "mo-ro-co-ta",
    "morojo": "mo-ro-jo",
    "morón": "mo-rón",
    "morona": "mo-ro-na",
    "moroncha": "mo-ron-cha",
    "moroncho": "mo-ron-cho",
    "moronda": "mo-ron-da",
    "morondanga": "mo-ron-dan-ga",
    "morondo": "mo-ron-do",
    "moronés": "mo-ro-nés",
    "moronesa": "mo-ro-ne-sa",
    "moronga": "mo-ron-ga",
    "morongazo": "mo-ron-ga-zo",
    "morongueada": "mo-ron-gue-a-da",
    "moronguear": "mo-ron-gue-ar",
    "moronía": "mo-ro-ní-a",
    "morosa": "mo-ro-sa",
    "morosamente": "mo-ro-sa-men-te",
    "morosidad": "mo-ro-si-dad",
    "moroso": "mo-ro-so",
    "morquera": "mor-que-ra",
    "morquero": "mor-que-ro",
    "morra": "mo-rra",
    "morrada": "mo-rra-da",
    "morral": "mo-rral",
    "morralada": "mo-rra-la-da",
    "morralla": "mo-rra-lla",
    "morrazo": "mo-rra-zo",
    "morrear": "mo-rre-ar",
    "morrena": "mo-rre-na",
    "morreo": "mo-rre-o",
    "morreras": "mo-rre-ras",
    "morrilla": "mo-rri-lla",
    "morrillo": "mo-rri-llo",
    "morriña": "mo-rri-ña",
    "morriñosa": "mo-rri-ño-sa",
    "morriñoso": "mo-rri-ño-so",
    "morrión": "mo-rrión",
    "morro": "mo-rro",
    "morrocota": "mo-rro-co-ta",
    "morrocotuda": "mo-rro-co-tu-da",
    "morrocotudo": "mo-rro-co-tu-do",
    "morrocoy": "mo-rro-coy",
    "morrocoyo": "mo-rro-co-yo",
    "morrón": "mo-rrón",
    "morroña": "mo-rro-ña",
    "morroncha": "mo-rron-cha",
    "morroncho": "mo-rron-cho",
    "morronga": "mo-rron-ga",
    "morrongo": "mo-rron-go",
    "morronguear": "mo-rron-gue-ar",
    "morroño": "mo-rro-ño",
    "morroñoso": "mo-rro-ño-so",
    "morruda": "mo-rru-da",
    "morrudo": "mo-rru-do",
    "morsa": "mor-sa",
    "morsana": "mor-sa-na",
    "morse": "mor-se",
    "mortadela": "mor-ta-de-la",
    "mortaja": "mor-ta-ja",
    "mortajar": "mor-ta-jar",
    "mortal": "mor-tal",
    "mortaldad": "mor-tal-dad",
    "mortalidad": "mor-ta-li-dad",
    "mortalmente": "mor-tal-men-te",
    "mortandad": "mor-tan-dad",
    "mortecina": "mor-te-ci-na",
    "mortecino": "mor-te-ci-no",
    "mortera": "mor-te-ra",
    "morterada": "mor-te-ra-da",
    "morterazo": "mor-te-ra-zo",
    "morterete": "mor-te-re-te",
    "mortero": "mor-te-ro",
    "morteruelo": "mor-te-rue-lo",
    "mortífera": "mor-tí-fe-ra",
    "mortífero": "mor-tí-fe-ro",
    "mortificación": "mor-ti-fi-ca-ción",
    "mortificador": "mor-ti-fi-ca-dor",
    "mortificadora": "mor-ti-fi-ca-do-ra",
    "mortificante": "mor-ti-fi-can-te",
    "mortificar": "mor-ti-fi-car",
    "mortiguar": "mor-ti-guar",
    "mortiñada": "mor-ti-ña-da",
    "mortinata": "mor-ti-na-ta",
    "mortinato": "mor-ti-na-to",
    "mortiño": "mor-ti-ño",
    "mortuoria": "mor-tuo-ria",
    "mortuorio": "mor-tuo-rio",
    "morucho": "mo-ru-cho",
    "morueco": "mo-rue-co",
    "moruga": "mo-ru-ga",
    "morugo": "mo-ru-go",
    "mórula": "mó-ru-la",
    "moruna": "mo-ru-na",
    "moruno": "mo-ru-no",
    "moruro": "mo-ru-ro",
    "morusa": "mo-ru-sa",
    "mosaica": "mo-sai-ca",
    "mosaico": "mo-sai-co",
    "mosaiquista": "mo-sai-quis-ta",
    "mosaísmo": "mo-sa-ís-mo",
    "mosca": "mos-ca",
    "moscabada": "mos-ca-ba-da",
    "moscabado": "mos-ca-ba-do",
    "moscada": "mos-ca-da",
    "moscadero": "mos-ca-de-ro",
    "moscado": "mos-ca-do",
    "moscar": "mos-car",
    "moscarda": "mos-car-da",
    "moscardear": "mos-car-de-ar",
    "moscardón": "mos-car-dón",
    "moscareta": "mos-ca-re-ta",
    "moscarrón": "mos-ca-rrón",
    "moscatel": "mos-ca-tel",
    "moscella": "mos-ce-lla",
    "mosco": "mos-co",
    "moscón": "mos-cón",
    "moscona": "mos-co-na",
    "mosconear": "mos-co-ne-ar",
    "mosconeo": "mos-co-ne-o",
    "moscorra": "mos-co-rra",
    "moscoso": "mos-co-so",
    "moscovita": "mos-co-vi-ta",
    "moscovítica": "mos-co-ví-ti-ca",
    "moscovítico": "mos-co-ví-ti-co",
    "mosén": "mo-sén",
    "mosolina": "mo-so-li-na",
    "mosqueada": "mos-que-a-da",
    "mosqueado": "mos-que-a-do",
    "mosqueador": "mos-que-a-dor",
    "mosquear": "mos-que-ar",
    "mosqueo": "mos-que-o",
    "mosquerío": "mos-que-rí-o",
    "mosquero": "mos-que-ro",
    "mosquerola": "mos-que-ro-la",
    "mosqueruela": "mos-que-rue-la",
    "mosqueta": "mos-que-ta",
    "mosquetazo": "mos-que-ta-zo",
    "mosquete": "mos-que-te",
    "mosquetería": "mos-que-te-rí-a",
    "mosqueteril": "mos-que-te-ril",
    "mosquetero": "mos-que-te-ro",
    "mosquetón": "mos-que-tón",
    "mosquil": "mos-quil",
    "mosquillón": "mos-qui-llón",
    "mosquina": "mos-qui-na",
    "mosquino": "mos-qui-no",
    "mosquita": "mos-qui-ta",
    "mosquitera": "mos-qui-te-ra",
    "mosquitero": "mos-qui-te-ro",
    "mosquito": "mos-qui-to",
    "mostacera": "mos-ta-ce-ra",
    "mostacero": "mos-ta-ce-ro",
    "mostacho": "mos-ta-cho",
    "mostachón": "mos-ta-chón",
    "mostachosa": "mos-ta-cho-sa",
    "mostachoso": "mos-ta-cho-so",
    "mostacilla": "mos-ta-ci-lla",
    "mostagán": "mos-ta-gán",
    "mostajo": "mos-ta-jo",
    "mostaza": "mos-ta-za",
    "mostazal": "mos-ta-zal",
    "mostazo": "mos-ta-zo",
    "moste": "mos-te",
    "mostear": "mos-te-ar",
    "mostela": "mos-te-la",
    "mostelera": "mos-te-le-ra",
    "mostellar": "mos-te-llar",
    "mostén": "mos-tén",
    "mostense": "mos-ten-se",
    "mostillo": "mos-ti-llo",
    "mosto": "mos-to",
    "mostrable": "mos-tra-ble",
    "mostración": "mos-tra-ción",
    "mostrada": "mos-tra-da",
    "mostrado": "mos-tra-do",
    "mostrador": "mos-tra-dor",
    "mostradora": "mos-tra-do-ra",
    "mostranza": "mos-tran-za",
    "mostrar": "mos-trar",
    "mostrativo": "mos-tra-ti-vo",
    "mostrenca": "mos-tren-ca",
    "mostrenco": "mos-tren-co",
    "mostro": "mos-tro",
    "mota": "mo-ta",
    "motacila": "mo-ta-ci-la",
    "motacú": "mo-ta-cú",
    "motasatol": "mo-ta-sa-tol",
    "mote": "mo-te",
    "moteado": "mo-te-a-do",
    "motear": "mo-te-ar",
    "motejador": "mo-te-ja-dor",
    "motejadora": "mo-te-ja-do-ra",
    "motejar": "mo-te-jar",
    "motejo": "mo-te-jo",
    "motel": "mo-tel",
    "motera": "mo-te-ra",
    "motero": "mo-te-ro",
    "motete": "mo-te-te",
    "motil": "mo-til",
    "motilar": "mo-ti-lar",
    "motilidad": "mo-ti-li-dad",
    "motilón": "mo-ti-lón",
    "motilona": "mo-ti-lo-na",
    "motín": "mo-tín",
    "motiva": "mo-ti-va",
    "motivación": "mo-ti-va-ción",
    "motivador": "mo-ti-va-dor",
    "motivadora": "mo-ti-va-do-ra",
    "motivar": "mo-ti-var",
    "motivo": "mo-ti-vo",
    "moto": "mo-to",
    "motobol": "mo-to-bol",
    "motobomba": "mo-to-bom-ba",
    "motocarro": "mo-to-ca-rro",
    "motocicleta": "mo-to-ci-cle-ta",
    "motociclismo": "mo-to-ci-clis-mo",
    "motociclista": "mo-to-ci-clis-ta",
    "motociclo": "mo-to-ci-clo",
    "motocine": "mo-to-ci-ne",
    "motocompresor": "mo-to-com-pre-sor",
    "motocross": "mo-to-cross",
    "motocultivador": "mo-to-cul-ti-va-dor",
    "motocultor": "mo-to-cul-tor",
    "motoesquí": "mo-to-es-quí",
    "motolita": "mo-to-li-ta",
    "motolito": "mo-to-li-to",
    "motón": "mo-tón",
    "motonáutica": "mo-to-náu-ti-ca",
    "motonáutico": "mo-to-náu-ti-co",
    "motonave": "mo-to-na-ve",
    "motonería": "mo-to-ne-rí-a",
    "motoneta": "mo-to-ne-ta",
    "motonieve": "mo-to-nie-ve",
    "motopesquero": "mo-to-pes-que-ro",
    "motopropulsión": "mo-to-pro-pul-sión",
    "motor": "mo-tor",
    "motora": "mo-to-ra",
    "motorismo": "mo-to-ris-mo",
    "motorista": "mo-to-ris-ta",
    "motorización": "mo-to-ri-za-ción",
    "motorizada": "mo-to-ri-za-da",
    "motorizado": "mo-to-ri-za-do",
    "motorizar": "mo-to-ri-zar",
    "motosa": "mo-to-sa",
    "motosierra": "mo-to-sie-rra",
    "motoso": "mo-to-so",
    "mototaxi": "mo-to-ta-xi",
    "motovelero": "mo-to-ve-le-ro",
    "motricidad": "mo-tri-ci-dad",
    "motril": "mo-tril",
    "motriz": "mo-triz",
    "motuda": "mo-tu-da",
    "motudo": "mo-tu-do",
    "mouse": "mou-se",
    "mousse": "mous-se",
    "movediza": "mo-ve-di-za",
    "movedizo": "mo-ve-di-zo",
    "movedor": "mo-ve-dor",
    "movedora": "mo-ve-do-ra",
    "movedura": "mo-ve-du-ra",
    "mover": "mo-ver",
    "movible": "mo-vi-ble",
    "movición": "mo-vi-ción",
    "movida": "mo-vi-da",
    "movido": "mo-vi-do",
    "movidoso": "mo-vi-do-so",
    "moviente": "mo-vien-te",
    "móvil": "mó-vil",
    "movilidad": "mo-vi-li-dad",
    "movilización": "mo-vi-li-za-ción",
    "movilizar": "mo-vi-li-zar",
    "movimiento": "mo-vi-mien-to",
    "moviola": "mo-vio-la",
    "moxa": "mo-xa",
    "moxibustión": "mo-xi-bus-tión",
    "moxitana": "mo-xi-ta-na",
    "moxitano": "mo-xi-ta-no",
    "moxte": "mox-te",
    "moya": "mo-ya",
    "moyana": "mo-ya-na",
    "moyo": "mo-yo",
    "moyobambina": "mo-yo-bam-bi-na",
    "moyobambino": "mo-yo-bam-bi-no",
    "moyuelo": "mo-yue-lo",
    "moza": "mo-za",
    "mozalbete": "mo-zal-be-te",
    "mozalbillo": "mo-zal-bi-llo",
    "mozallón": "mo-za-llón",
    "mozallona": "mo-za-llo-na",
    "mozambiqueña": "mo-zam-bi-que-ña",
    "mozambiqueño": "mo-zam-bi-que-ño",
    "mozancón": "mo-zan-cón",
    "mozancona": "mo-zan-co-na",
    "mozárabe": "mo-zá-ra-be",
    "mozarabía": "mo-za-ra-bí-a",
    "mozarabismo": "mo-za-ra-bis-mo",
    "mozartiano": "mo-zar-tia-no",
    "mozcorra": "moz-co-rra",
    "mozo": "mo-zo",
    "mozón": "mo-zón",
    "mozona": "mo-zo-na",
    "mozonada": "mo-zo-na-da",
    "mozonear": "mo-zo-ne-ar",
    "mozorro": "mo-zo-rro",
    "mozote": "mo-zo-te",
    "mozuco": "mo-zu-co",
    "mozuela": "mo-zue-la",
    "mozuelo": "mo-zue-lo",
    "muaré": "mua-ré",
    "muble": "mu-ble",
    "muca": "mu-ca",
    "mucama": "mu-ca-ma",
    "mucamo": "mu-ca-mo",
    "múcara": "mú-ca-ra",
    "muceta": "mu-ce-ta",
    "mucha": "mu-cha",
    "muchacha": "mu-cha-cha",
    "muchachada": "mu-cha-cha-da",
    "muchachear": "mu-cha-che-ar",
    "muchachería": "mu-cha-che-rí-a",
    "muchachero": "mu-cha-che-ro",
    "muchachez": "mu-cha-chez",
    "muchachil": "mu-cha-chil",
    "muchacho": "mu-cha-cho",
    "muchedumbre": "mu-che-dum-bre",
    "muchedumbroso": "mu-che-dum-bro-so",
    "muchiguar": "mu-chi-guar",
    "muchilero": "mu-chi-le-ro",
    "muchín": "mu-chín",
    "muchitanga": "mu-chi-tan-ga",
    "mucho": "mu-cho",
    "mucilaginosa": "mu-ci-la-gi-no-sa",
    "mucilaginoso": "mu-ci-la-gi-no-so",
    "mucilago": "mu-ci-la-go",
    "mucílago": "mu-cí-la-go",
    "mucina": "mu-ci-na",
    "muco": "mu-co",
    "mucolítico": "mu-co-lí-ti-co",
    "mucopurulento": "mu-co-pu-ru-len-to",
    "mucosa": "mu-co-sa",
    "mucosidad": "mu-co-si-dad",
    "mucositis": "mu-co-si-tis",
    "mucoso": "mu-co-so",
    "mucre": "mu-cre",
    "mucronata": "mu-cro-na-ta",
    "mucronato": "mu-cro-na-to",
    "múcura": "mú-cu-ra",
    "mucus": "mu-cus",
    "muda": "mu-da",
    "mudable": "mu-da-ble",
    "mudada": "mu-da-da",
    "mudadiza": "mu-da-di-za",
    "mudadizo": "mu-da-di-zo",
    "mudamente": "mu-da-men-te",
    "mudamiento": "mu-da-mien-to",
    "mudanza": "mu-dan-za",
    "mudar": "mu-dar",
    "mudéjar": "mu-dé-jar",
    "mudejarismo": "mu-de-ja-ris-mo",
    "mudez": "mu-dez",
    "mudo": "mu-do",
    "muebda": "mueb-da",
    "mueblaje": "mue-bla-je",
    "mueblar": "mue-blar",
    "mueble": "mue-ble",
    "mueblería": "mue-ble-rí-a",
    "mueblista": "mue-blis-ta",
    "mueca": "mue-ca",
    "muecín": "mue-cín",
    "muégano": "mué-ga-no",
    "muela": "mue-la",
    "muelar": "mue-lar",
    "muellaje": "mue-lla-je",
    "muelle": "mue-lle",
    "muellemente": "mue-lle-men-te",
    "muelo": "mue-lo",
    "muenda": "muen-da",
    "muenga": "muen-ga",
    "muengo": "muen-go",
    "muequear": "mue-que-ar",
    "muera": "mue-ra",
    "muérdago": "muér-da-go",
    "muerdisorbe": "muer-di-sor-be",
    "muerdo": "muer-do",
    "muérgano": "muér-ga-no",
    "muergo": "muer-go",
    "muermo": "muer-mo",
    "muermosa": "muer-mo-sa",
    "muermoso": "muer-mo-so",
    "muerta": "muer-ta",
    "muerte": "muer-te",
    "muertera": "muer-te-ra",
    "muertero": "muer-te-ro",
    "muerto": "muer-to",
    "muesca": "mues-ca",
    "muescar": "mues-car",
    "mueso": "mue-so",
    "muestra": "mues-tra",
    "muestral": "mues-tral",
    "muestrario": "mues-tra-rio",
    "muestrear": "mues-tre-ar",
    "muestreo": "mues-tre-o",
    "muévedo": "mué-ve-do",
    "mufa": "mu-fa",
    "mufar": "mu-far",
    "mufla": "mu-fla",
    "mufle": "mu-fle",
    "muflir": "mu-flir",
    "muflón": "mu-flón",
    "muftí": "muf-tí",
    "muga": "mu-ga",
    "mugada": "mu-ga-da",
    "mugar": "mu-gar",
    "mugido": "mu-gi-do",
    "mugidor": "mu-gi-dor",
    "mugidora": "mu-gi-do-ra",
    "múgil": "mú-gil",
    "mugir": "mu-gir",
    "mugle": "mu-gle",
    "mugor": "mu-gor",
    "mugre": "mu-gre",
    "mugrería": "mu-gre-rí-a",
    "mugrerío": "mu-gre-rí-o",
    "mugrienta": "mu-grien-ta",
    "mugriento": "mu-grien-to",
    "mugrón": "mu-grón",
    "mugrosa": "mu-gro-sa",
    "mugroso": "mu-gro-so",
    "muguet": "mu-guet",
    "muguete": "mu-gue-te",
    "muharra": "muha-rra",
    "muimuy": "mui-muy",
    "muina": "mui-na",
    "muiñeira": "mui-ñei-ra",
    "muisca": "muis-ca",
    "mujada": "mu-ja-da",
    "mujalata": "mu-ja-la-ta",
    "mujer": "mu-jer",
    "mujercilla": "mu-jer-ci-lla",
    "mujerear": "mu-je-re-ar",
    "mujerero": "mu-je-re-ro",
    "mujeriega": "mu-je-rie-ga",
    "mujeriego": "mu-je-rie-go",
    "mujeril": "mu-je-ril",
    "mujerilmente": "mu-je-ril-men-te",
    "mujerío": "mu-je-rí-o",
    "mujerona": "mu-je-ro-na",
    "mujerzuela": "mu-jer-zue-la",
    "mújol": "mú-jol",
    "mula": "mu-la",
    "mulá": "mu-lá",
    "mulada": "mu-la-da",
    "muladar": "mu-la-dar",
    "muladí": "mu-la-dí",
    "mulante": "mu-lan-te",
    "mular": "mu-lar",
    "mulata": "mu-la-ta",
    "mulatear": "mu-la-te-ar",
    "mulatero": "mu-la-te-ro",
    "mulatizar": "mu-la-ti-zar",
    "mulato": "mu-la-to",
    "mule": "mu-le",
    "múleo": "mú-le-o",
    "muléolo": "mu-lé-o-lo",
    "muleque": "mu-le-que",
    "mulera": "mu-le-ra",
    "mulero": "mu-le-ro",
    "muleta": "mu-le-ta",
    "muletada": "mu-le-ta-da",
    "muletazo": "mu-le-ta-zo",
    "muletear": "mu-le-te-ar",
    "muleteo": "mu-le-te-o",
    "muletero": "mu-le-te-ro",
    "muletilla": "mu-le-ti-lla",
    "muletillera": "mu-le-ti-lle-ra",
    "muletillero": "mu-le-ti-lle-ro",
    "muleto": "mu-le-to",
    "muletón": "mu-le-tón",
    "mulilla": "mu-li-lla",
    "mulillas": "mu-li-llas",
    "mulita": "mu-li-ta",
    "mulito": "mu-li-to",
    "mulla": "mu-lla",
    "mullicar": "mu-lli-car",
    "mullida": "mu-lli-da",
    "mullido": "mu-lli-do",
    "mullidor": "mu-lli-dor",
    "mullidora": "mu-lli-do-ra",
    "mullir": "mu-llir",
    "mullo": "mu-llo",
    "mulo": "mu-lo",
    "mulón": "mu-lón",
    "mulquía": "mul-quí-a",
    "mulquite": "mul-qui-te",
    "mulsa": "mul-sa",
    "mulso": "mul-so",
    "multa": "mul-ta",
    "multar": "mul-tar",
    "multi": "mul-ti",
    "multicaule": "mul-ti-cau-le",
    "multicentro": "mul-ti-cen-tro",
    "multicine": "mul-ti-ci-ne",
    "multicolor": "mul-ti-co-lor",
    "multicopiado": "mul-ti-co-pia-do",
    "multicopiar": "mul-ti-co-piar",
    "multicopista": "mul-ti-co-pis-ta",
    "multicultural": "mul-ti-cul-tu-ral",
    "multiculturalismo": "mul-ti-cul-tu-ra-lis-mo",
    "multidimensional": "mul-ti-di-men-sio-nal",
    "multidisciplinar": "mul-ti-dis-ci-pli-nar",
    "multidisciplinario": "mul-ti-dis-ci-pli-na-rio",
    "multifamiliar": "mul-ti-fa-mi-liar",
    "multiflora": "mul-ti-flo-ra",
    "multifloro": "mul-ti-flo-ro",
    "multifocal": "mul-ti-fo-cal",
    "multiforme": "mul-ti-for-me",
    "multifuncional": "mul-ti-fun-cio-nal",
    "multigrado": "mul-ti-gra-do",
    "multígrafo": "mul-tí-gra-fo",
    "multilátera": "mul-ti-lá-te-ra",
    "multilateral": "mul-ti-la-te-ral",
    "multilátero": "mul-ti-lá-te-ro",
    "multilingüe": "mul-ti-lin-güe",
    "multimedia": "mul-ti-me-dia",
    "multímetro": "mul-tí-me-tro",
    "multimillonaria": "mul-ti-mi-llo-na-ria",
    "multimillonario": "mul-ti-mi-llo-na-rio",
    "multinacional": "mul-ti-na-cio-nal",
    "multípara": "mul-tí-pa-ra",
    "multipartidismo": "mul-ti-par-ti-dis-mo",
    "multipartidista": "mul-ti-par-ti-dis-ta",
    "múltipla": "múl-ti-pla",
    "múltiple": "múl-ti-ple",
    "multiplete": "mul-ti-ple-te",
    "multiplexor": "mul-ti-ple-xor",
    "multiplicable": "mul-ti-pli-ca-ble",
    "multiplicación": "mul-ti-pli-ca-ción",
    "multiplicador": "mul-ti-pli-ca-dor",
    "multiplicadora": "mul-ti-pli-ca-do-ra",
    "multiplicando": "mul-ti-pli-can-do",
    "multiplicar": "mul-ti-pli-car",
    "multiplicativa": "mul-ti-pli-ca-ti-va",
    "multiplicativo": "mul-ti-pli-ca-ti-vo",
    "multíplice": "mul-tí-pli-ce",
    "multiplicidad": "mul-ti-pli-ci-dad",
    "multiplico": "mul-ti-pli-co",
    "múltiplo": "múl-ti-plo",
    "multipolar": "mul-ti-po-lar",
    "multiprogramación": "mul-ti-pro-gra-ma-ción",
    "multipropiedad": "mul-ti-pro-pie-dad",
    "multipuesto": "mul-ti-pues-to",
    "multirracial": "mul-ti-rra-cial",
    "multisectorial": "mul-ti-sec-to-rial",
    "multitud": "mul-ti-tud",
    "multitudinario": "mul-ti-tu-di-na-rio",
    "multiuso": "mul-tiu-so",
    "multiusuario": "mul-tiu-sua-rio",
    "multiválvulas": "mul-ti-vál-vu-las",
    "multivibrador": "mul-ti-vi-bra-dor",
    "multivisión": "mul-ti-vi-sión",
    "muna": "mu-na",
    "muncha": "mun-cha",
    "muncho": "mun-cho",
    "mundana": "mun-da-na",
    "mundanal": "mun-da-nal",
    "mundanalidad": "mun-da-na-li-dad",
    "mundanamente": "mun-da-na-men-te",
    "mundanear": "mun-da-ne-ar",
    "mundanería": "mun-da-ne-rí-a",
    "mundanidad": "mun-da-ni-dad",
    "mundano": "mun-da-no",
    "mundaria": "mun-da-ria",
    "mundial": "mun-dial",
    "mundialista": "mun-dia-lis-ta",
    "mundialización": "mun-dia-li-za-ción",
    "mundializar": "mun-dia-li-zar",
    "mundialmente": "mun-dial-men-te",
    "mundicia": "mun-di-cia",
    "mundificación": "mun-di-fi-ca-ción",
    "mundificar": "mun-di-fi-car",
    "mundificativa": "mun-di-fi-ca-ti-va",
    "mundificativo": "mun-di-fi-ca-ti-vo",
    "mundillo": "mun-di-llo",
    "mundinovi": "mun-di-no-vi",
    "mundo": "mun-do",
    "mundología": "mun-do-lo-gí-a",
    "mundonuevo": "mun-do-nue-vo",
    "mundovisión": "mun-do-vi-sión",
    "muñeca": "mu-ñe-ca",
    "muñeco": "mu-ñe-co",
    "muñeira": "mu-ñei-ra",
    "muñequear": "mu-ñe-que-ar",
    "muñequera": "mu-ñe-que-ra",
    "muñequería": "mu-ñe-que-rí-a",
    "muñequero": "mu-ñe-que-ro",
    "muñequilla": "mu-ñe-qui-lla",
    "muñequito": "mu-ñe-qui-to",
    "muñequitos": "mu-ñe-qui-tos",
    "munición": "mu-ni-ción",
    "municionamiento": "mu-ni-cio-na-mien-to",
    "municionar": "mu-ni-cio-nar",
    "municionera": "mu-ni-cio-ne-ra",
    "municionero": "mu-ni-cio-ne-ro",
    "municipal": "mu-ni-ci-pal",
    "municipalidad": "mu-ni-ci-pa-li-dad",
    "municipalismo": "mu-ni-ci-pa-lis-mo",
    "municipalista": "mu-ni-ci-pa-lis-ta",
    "municipalización": "mu-ni-ci-pa-li-za-ción",
    "municipalizar": "mu-ni-ci-pa-li-zar",
    "munícipe": "mu-ní-ci-pe",
    "municipio": "mu-ni-ci-pio",
    "munido": "mu-ni-do",
    "muñidor": "mu-ñi-dor",
    "muñidora": "mu-ñi-do-ra",
    "munífica": "mu-ní-fi-ca",
    "munificencia": "mu-ni-fi-cen-cia",
    "munificente": "mu-ni-fi-cen-te",
    "munífico": "mu-ní-fi-co",
    "muniqués": "mu-ni-qués",
    "muniquesa": "mu-ni-que-sa",
    "muñir": "mu-ñir",
    "munitoria": "mu-ni-to-ria",
    "muño": "mu-ño",
    "muñón": "mu-ñón",
    "muñonera": "mu-ño-ne-ra",
    "munúsculo": "mu-nús-cu-lo",
    "muquición": "mu-qui-ción",
    "muquir": "mu-quir",
    "mura": "mu-ra",
    "muradal": "mu-ra-dal",
    "murador": "mu-ra-dor",
    "muradora": "mu-ra-do-ra",
    "muraje": "mu-ra-je",
    "murajes": "mu-ra-jes",
    "mural": "mu-ral",
    "muralismo": "mu-ra-lis-mo",
    "muralista": "mu-ra-lis-ta",
    "muralla": "mu-ra-lla",
    "murallón": "mu-ra-llón",
    "murar": "mu-rar",
    "murceguillo": "mur-ce-gui-llo",
    "murceo": "mur-ce-o",
    "murciana": "mur-cia-na",
    "murciano": "mur-cia-no",
    "murciar": "mur-ciar",
    "murciégalo": "mur-cié-ga-lo",
    "murciélago": "mur-cié-la-go",
    "murcielaguina": "mur-cie-la-gui-na",
    "murcigallero": "mur-ci-ga-lle-ro",
    "murciglero": "mur-ci-gle-ro",
    "murcio": "mur-cio",
    "murecillo": "mu-re-ci-llo",
    "murena": "mu-re-na",
    "mureño": "mu-re-ño",
    "murete": "mu-re-te",
    "murga": "mur-ga",
    "murgaño": "mur-ga-ño",
    "murgón": "mur-gón",
    "murguista": "mur-guis-ta",
    "murgular": "mur-gu-lar",
    "muria": "mu-ria",
    "muriacita": "mu-ria-ci-ta",
    "muriático": "mu-riá-ti-co",
    "muriato": "mu-ria-to",
    "múrice": "mú-ri-ce",
    "múrido": "mú-ri-do",
    "murmujear": "mur-mu-je-ar",
    "murmullar": "mur-mu-llar",
    "murmullo": "mur-mu-llo",
    "murmuración": "mur-mu-ra-ción",
    "murmurador": "mur-mu-ra-dor",
    "murmuradora": "mur-mu-ra-do-ra",
    "murmurar": "mur-mu-rar",
    "murmurear": "mur-mu-re-ar",
    "murmureo": "mur-mu-re-o",
    "murmurio": "mur-mu-rio",
    "murmurón": "mur-mu-rón",
    "muro": "mu-ro",
    "murque": "mur-que",
    "murria": "mu-rria",
    "murriada": "mu-rria-da",
    "murriar": "mu-rriar",
    "múrrina": "mú-rri-na",
    "múrrino": "mú-rri-no",
    "murrio": "mu-rrio",
    "murro": "mu-rro",
    "murruca": "mu-rru-ca",
    "murruco": "mu-rru-co",
    "murta": "mur-ta",
    "murtal": "mur-tal",
    "murtilla": "mur-ti-lla",
    "murtina": "mur-ti-na",
    "murto": "mur-to",
    "murtón": "mur-tón",
    "murucullo": "mu-ru-cu-llo",
    "murucuyá": "mu-ru-cu-yá",
    "murueco": "mu-rue-co",
    "murviedrés": "mur-vie-drés",
    "murviedresa": "mur-vie-dre-sa",
    "musa": "mu-sa",
    "musácea": "mu-sá-ce-a",
    "musáceo": "mu-sá-ce-o",
    "musageta": "mu-sa-ge-ta",
    "musaica": "mu-sai-ca",
    "musaico": "mu-sai-co",
    "musaka": "mu-sa-ka",
    "musar": "mu-sar",
    "musaraña": "mu-sa-ra-ña",
    "musca": "mus-ca",
    "muscardino": "mus-car-di-no",
    "muscaria": "mus-ca-ria",
    "muscarina": "mus-ca-ri-na",
    "muscícapa": "mus-cí-ca-pa",
    "musco": "mus-co",
    "musculación": "mus-cu-la-ción",
    "musculado": "mus-cu-la-do",
    "muscular": "mus-cu-lar",
    "muscularmente": "mus-cu-lar-men-te",
    "musculatura": "mus-cu-la-tu-ra",
    "músculo": "mús-cu-lo",
    "musculosa": "mus-cu-lo-sa",
    "musculoso": "mus-cu-lo-so",
    "museal": "mu-se-al",
    "museístico": "mu-se-ís-ti-co",
    "muselina": "mu-se-li-na",
    "museo": "mu-se-o",
    "museógrafa": "mu-se-ó-gra-fa",
    "museografía": "mu-se-o-gra-fí-a",
    "museográfico": "mu-se-o-grá-fi-co",
    "museógrafo": "mu-se-ó-gra-fo",
    "museóloga": "mu-se-ó-lo-ga",
    "museología": "mu-se-o-lo-gí-a",
    "museológico": "mu-se-o-ló-gi-co",
    "museólogo": "mu-se-ó-lo-go",
    "musepo": "mu-se-po",
    "musequí": "mu-se-quí",
    "muserola": "mu-se-ro-la",
    "musga": "mus-ga",
    "musgaño": "mus-ga-ño",
    "musgo": "mus-go",
    "musgosa": "mus-go-sa",
    "musgoso": "mus-go-so",
    "música": "mú-si-ca",
    "musicable": "mu-si-ca-ble",
    "musical": "mu-si-cal",
    "musicalidad": "mu-si-ca-li-dad",
    "musicalizar": "mu-si-ca-li-zar",
    "musicalmente": "mu-si-cal-men-te",
    "musicante": "mu-si-can-te",
    "musicar": "mu-si-car",
    "musicasete": "mu-si-ca-se-te",
    "musicastro": "mu-si-cas-tro",
    "músico": "mú-si-co",
    "musicógrafa": "mu-si-có-gra-fa",
    "musicógrafo": "mu-si-có-gra-fo",
    "musicóloga": "mu-si-có-lo-ga",
    "musicología": "mu-si-co-lo-gí-a",
    "musicólogo": "mu-si-có-lo-go",
    "musicómana": "mu-si-có-ma-na",
    "musicomanía": "mu-si-co-ma-ní-a",
    "musicómano": "mu-si-có-ma-no",
    "musicoterapia": "mu-si-co-te-ra-pia",
    "musiquero": "mu-si-que-ro",
    "musiquilla": "mu-si-qui-lla",
    "musir": "mu-sir",
    "musirse": "mu-sir-se",
    "musitar": "mu-si-tar",
    "musiúa": "mu-siú-a",
    "musivo": "mu-si-vo",
    "muslera": "mus-le-ra",
    "muslim": "mus-lim",
    "muslime": "mus-li-me",
    "muslímica": "mus-lí-mi-ca",
    "muslímico": "mus-lí-mi-co",
    "muslo": "mus-lo",
    "musmón": "mus-món",
    "muso": "mu-so",
    "musola": "mu-so-la",
    "musquerola": "mus-que-ro-la",
    "mustaco": "mus-ta-co",
    "mustang": "mus-tang",
    "mustela": "mus-te-la",
    "mustélido": "mus-té-li-do",
    "musteriense": "mus-te-rien-se",
    "mustia": "mus-tia",
    "mustiamente": "mus-tia-men-te",
    "mustiar": "mus-tiar",
    "mustio": "mus-tio",
    "musuca": "mu-su-ca",
    "musuco": "mu-su-co",
    "musulmán": "mu-sul-mán",
    "musulmana": "mu-sul-ma-na",
    "muta": "mu-ta",
    "mutabilidad": "mu-ta-bi-li-dad",
    "mutable": "mu-ta-ble",
    "mutación": "mu-ta-ción",
    "mutacionismo": "mu-ta-cio-nis-mo",
    "mutagénesis": "mu-ta-gé-ne-sis",
    "mutagénico": "mu-ta-gé-ni-co",
    "mutágeno": "mu-tá-ge-no",
    "mutante": "mu-tan-te",
    "mutar": "mu-tar",
    "mute": "mu-te",
    "mútila": "mú-ti-la",
    "mutilación": "mu-ti-la-ción",
    "mutilada": "mu-ti-la-da",
    "mutilado": "mu-ti-la-do",
    "mutilador": "mu-ti-la-dor",
    "mutiladora": "mu-ti-la-do-ra",
    "mutilar": "mu-ti-lar",
    "mútilo": "mú-ti-lo",
    "mutilón": "mu-ti-lón",
    "mutis": "mu-tis",
    "mutismo": "mu-tis-mo",
    "mutón": "mu-tón",
    "mutra": "mu-tra",
    "mutre": "mu-tre",
    "mutro": "mu-tro",
    "mutua": "mu-tua",
    "mutual": "mu-tual",
    "mutualidad": "mu-tua-li-dad",
    "mutualismo": "mu-tua-lis-mo",
    "mutualista": "mu-tua-lis-ta",
    "mutuamente": "mu-tua-men-te",
    "mutuante": "mu-tuan-te",
    "mutuaria": "mu-tua-ria",
    "mutuario": "mu-tua-rio",
    "mutuataria": "mu-tua-ta-ria",
    "mutuatario": "mu-tua-ta-rio",
    "mutuo": "mu-tuo",
    "muwassaha": "mu-was-sa-ha",
    "muzárabe": "mu-zá-ra-be",
    "naba": "na-ba",
    "nabab": "na-bab",
    "nababo": "na-ba-bo",
    "nabal": "na-bal",
    "nabar": "na-bar",
    "nabatea": "na-ba-te-a",
    "nabateo": "na-ba-te-o",
    "nabato": "na-ba-to",
    "nabería": "na-be-rí-a",
    "nabí": "na-bí",
    "nabicol": "na-bi-col",
    "nabina": "na-bi-na",
    "nabiza": "na-bi-za",
    "nabla": "na-bla",
    "nabo": "na-bo",
    "naboncia": "na-bon-cia",
    "naboncio": "na-bon-cio",
    "naborí": "na-bo-rí",
    "naboría": "na-bo-rí-a",
    "nabuda": "na-bu-da",
    "naca": "na-ca",
    "nácar": "ná-car",
    "nácara": "ná-ca-ra",
    "ñácara": "ñá-ca-ra",
    "nacarada": "na-ca-ra-da",
    "nacarado": "na-ca-ra-do",
    "nacárea": "na-cá-re-a",
    "nacáreo": "na-cá-re-o",
    "nacarigüe": "na-ca-ri-güe",
    "nacarina": "na-ca-ri-na",
    "nacarino": "na-ca-ri-no",
    "nacarón": "na-ca-rón",
    "nacascolo": "na-cas-co-lo",
    "nacatamal": "na-ca-ta-mal",
    "nacatamalera": "na-ca-ta-ma-le-ra",
    "nacatamalero": "na-ca-ta-ma-le-ro",
    "nacatambuche": "na-ca-tam-bu-che",
    "nacatete": "na-ca-te-te",
    "nacedero": "na-ce-de-ro",
    "nacela": "na-ce-la",
    "nacencia": "na-cen-cia",
    "nacer": "na-cer",
    "nacha": "na-cha",
    "nacho": "na-cho",
    "naciancena": "na-cian-ce-na",
    "nacianceno": "na-cian-ce-no",
    "nacida": "na-ci-da",
    "nacido": "na-ci-do",
    "naciente": "na-cien-te",
    "nacimiento": "na-ci-mien-to",
    "nación": "na-ción",
    "nacional": "na-cio-nal",
    "nacionalcatólica": "na-cio-nal-ca-tó-li-ca",
    "nacionalcatolicismo": "na-cio-nal-ca-to-li-cis-mo",
    "nacionalcatólico": "na-cio-nal-ca-tó-li-co",
    "nacionalidad": "na-cio-na-li-dad",
    "nacionalismo": "na-cio-na-lis-mo",
    "nacionalista": "na-cio-na-lis-ta",
    "nacionalización": "na-cio-na-li-za-ción",
    "nacionalizar": "na-cio-na-li-zar",
    "nacionalmente": "na-cio-nal-men-te",
    "nacionalsindicalismo": "na-cio-nal-sin-di-ca-lis-mo",
    "nacionalsindicalista": "na-cio-nal-sin-di-ca-lis-ta",
    "nacionalsocialismo": "na-cio-nal-so-cia-lis-mo",
    "nacionalsocialista": "na-cio-nal-so-cia-lis-ta",
    "naco": "na-co",
    "nacre": "na-cre",
    "nacrita": "na-cri-ta",
    "ñacurutú": "ña-cu-ru-tú",
    "nada": "na-da",
    "nadadera": "na-da-de-ra",
    "nadadero": "na-da-de-ro",
    "nadador": "na-da-dor",
    "nadadora": "na-da-do-ra",
    "nadadura": "na-da-du-ra",
    "nadal": "na-dal",
    "nadar": "na-dar",
    "nadería": "na-de-rí-a",
    "nadga": "nad-ga",
    "nadgada": "nad-ga-da",
    "nadi": "na-di",
    "nadie": "na-die",
    "nadilla": "na-di-lla",
    "nadir": "na-dir",
    "nádir": "ná-dir",
    "nado": "na-do",
    "nafra": "na-fra",
    "nafrar": "na-frar",
    "nafre": "na-fre",
    "nafta": "naf-ta",
    "naftaleno": "naf-ta-le-no",
    "naftalina": "naf-ta-li-na",
    "naftera": "naf-te-ra",
    "naftero": "naf-te-ro",
    "ñagaza": "ña-ga-za",
    "nagra": "na-gra",
    "nagranda": "na-gran-da",
    "nagua": "na-gua",
    "nagual": "na-gual",
    "nagualismo": "na-gua-lis-mo",
    "naguapate": "na-gua-pa-te",
    "naguatlata": "na-gua-tla-ta",
    "naguatlato": "na-gua-tla-to",
    "náguatle": "ná-gua-tle",
    "nagüe": "na-güe",
    "nagüela": "na-güe-la",
    "nagüera": "na-güe-ra",
    "nagüero": "na-güe-ro",
    "nahoa": "na-ho-a",
    "nahua": "na-hua",
    "nahual": "na-hual",
    "nahualismo": "na-hua-lis-mo",
    "náhuatl": "ná-huatl",
    "nahuatlato": "na-hua-tla-to",
    "náhuatle": "ná-hua-tle",
    "nahuatlismo": "na-hua-tlis-mo",
    "naibí": "nai-bí",
    "naiboa": "nai-bo-a",
    "naíf": "na-íf",
    "naife": "nai-fe",
    "nailon": "nai-lon",
    "naipe": "nai-pe",
    "naipear": "nai-pe-ar",
    "naipera": "nai-pe-ra",
    "naipesca": "nai-pes-ca",
    "naipesco": "nai-pes-co",
    "naira": "nai-ra",
    "naire": "nai-re",
    "naja": "na-ja",
    "ñaja": "ña-ja",
    "najerana": "na-je-ra-na",
    "najerano": "na-je-ra-no",
    "najerense": "na-je-ren-se",
    "najerina": "na-je-ri-na",
    "najerino": "na-je-ri-no",
    "najesí": "na-je-sí",
    "ñajo": "ña-jo",
    "nalca": "nal-ca",
    "nalga": "nal-ga",
    "nalgada": "nal-ga-da",
    "nalgamento": "nal-ga-men-to",
    "nalgar": "nal-gar",
    "nalgatorio": "nal-ga-to-rio",
    "nalgón": "nal-gón",
    "nalgona": "nal-go-na",
    "nalguda": "nal-gu-da",
    "nalgudo": "nal-gu-do",
    "nalgueada": "nal-gue-a-da",
    "nalguear": "nal-gue-ar",
    "nambira": "nam-bi-ra",
    "ñame": "ña-me",
    "ñamería": "ña-me-rí-a",
    "namibia": "na-mi-bia",
    "namibio": "na-mi-bio",
    "namorar": "na-mo-rar",
    "ñampeado": "ñam-pe-a-do",
    "ñampear": "ñam-pe-ar",
    "ñampí": "ñam-pí",
    "ñampiar": "ñam-piar",
    "nana": "na-na",
    "ñaña": "ña-ña",
    "ñañaca": "ña-ña-ca",
    "nanacate": "na-na-ca-te",
    "ñáñara": "ñá-ña-ra",
    "nanay": "na-nay",
    "nance": "nan-ce",
    "nancear": "nan-ce-ar",
    "nancer": "nan-cer",
    "nanche": "nan-che",
    "nanchi": "nan-chi",
    "nancital": "nan-ci-tal",
    "nancite": "nan-ci-te",
    "nandaimeña": "nan-dai-me-ña",
    "nandaimeño": "nan-dai-me-ño",
    "nandrolona": "nan-dro-lo-na",
    "ñandú": "ñan-dú",
    "ñandubay": "ñan-du-bay",
    "ñandutí": "ñan-du-tí",
    "nanear": "na-ne-ar",
    "ñañería": "ña-ñe-rí-a",
    "ñanga": "ñan-ga",
    "ñangada": "ñan-ga-da",
    "ñangado": "ñan-ga-do",
    "ñangapirí": "ñan-ga-pi-rí",
    "ñángara": "ñán-ga-ra",
    "ñangazo": "ñan-ga-zo",
    "ñango": "ñan-go",
    "ñangotada": "ñan-go-ta-da",
    "ñangotado": "ñan-go-ta-do",
    "ñangotar": "ñan-go-tar",
    "ñangotismo": "ñan-go-tis-mo",
    "ñangué": "ñan-gué",
    "ñáñiga": "ñá-ñi-ga",
    "ñáñigo": "ñá-ñi-go",
    "ñañiguismo": "ña-ñi-guis-mo",
    "nanita": "na-ni-ta",
    "ñaño": "ña-ño",
    "nanociencia": "na-no-cien-cia",
    "nanómetro": "na-nó-me-tro",
    "ñanosa": "ña-no-sa",
    "nanosegundo": "na-no-se-gun-do",
    "ñanoso": "ña-no-so",
    "nanotecnología": "na-no-tec-no-lo-gí-a",
    "nanoya": "na-no-ya",
    "nanquín": "nan-quín",
    "nansa": "nan-sa",
    "nansú": "nan-sú",
    "nantar": "nan-tar",
    "nao": "na-o",
    "naonata": "na-o-na-ta",
    "naonato": "na-o-na-to",
    "naos": "na-os",
    "napa": "na-pa",
    "ñapa": "ña-pa",
    "napalm": "na-palm",
    "ñapanga": "ña-pan-ga",
    "ñapango": "ña-pan-go",
    "napar": "na-par",
    "nape": "na-pe",
    "napea": "na-pe-a",
    "napelo": "na-pe-lo",
    "napeña": "na-pe-ña",
    "napeño": "na-pe-ño",
    "napeo": "na-pe-o",
    "napia": "na-pia",
    "napias": "na-pias",
    "napiforme": "na-pi-for-me",
    "ñapindá": "ña-pin-dá",
    "napoleón": "na-po-le-ón",
    "napoleónica": "na-po-le-ó-ni-ca",
    "napoleónico": "na-po-le-ó-ni-co",
    "napolitana": "na-po-li-ta-na",
    "napolitano": "na-po-li-ta-no",
    "naque": "na-que",
    "ñaque": "ña-que",
    "naquear": "na-que-ar",
    "narango": "na-ran-go",
    "naranja": "na-ran-ja",
    "naranjada": "na-ran-ja-da",
    "naranjado": "na-ran-ja-do",
    "naranjal": "na-ran-jal",
    "naranjera": "na-ran-je-ra",
    "naranjero": "na-ran-je-ro",
    "naranjilla": "na-ran-ji-lla",
    "naranjillada": "na-ran-ji-lla-da",
    "naranjillo": "na-ran-ji-llo",
    "naranjo": "na-ran-jo",
    "narbonense": "nar-bo-nen-se",
    "narbonés": "nar-bo-nés",
    "narbonesa": "nar-bo-ne-sa",
    "narceína": "nar-ce-í-na",
    "narcisismo": "nar-ci-sis-mo",
    "narcisista": "nar-ci-sis-ta",
    "narciso": "nar-ci-so",
    "narco": "nar-co",
    "narcodólar": "nar-co-dó-lar",
    "narcolepsia": "nar-co-lep-sia",
    "narcosala": "nar-co-sa-la",
    "narcosis": "nar-co-sis",
    "narcoterapia": "nar-co-te-ra-pia",
    "narcótica": "nar-có-ti-ca",
    "narcótico": "nar-có-ti-co",
    "narcotina": "nar-co-ti-na",
    "narcotismo": "nar-co-tis-mo",
    "narcotización": "nar-co-ti-za-ción",
    "narcotizador": "nar-co-ti-za-dor",
    "narcotizadora": "nar-co-ti-za-do-ra",
    "narcotizante": "nar-co-ti-zan-te",
    "narcotizar": "nar-co-ti-zar",
    "narcotraficante": "nar-co-tra-fi-can-te",
    "narcotráfico": "nar-co-trá-fi-co",
    "nardina": "nar-di-na",
    "nardino": "nar-di-no",
    "nardo": "nar-do",
    "nares": "na-res",
    "narguile": "nar-gui-le",
    "nariceado": "na-ri-ce-a-do",
    "naricear": "na-ri-ce-ar",
    "naricera": "na-ri-ce-ra",
    "narigada": "na-ri-ga-da",
    "narigón": "na-ri-gón",
    "narigona": "na-ri-go-na",
    "nariguda": "na-ri-gu-da",
    "narigudo": "na-ri-gu-do",
    "nariguera": "na-ri-gue-ra",
    "narigueta": "na-ri-gue-ta",
    "nariguetas": "na-ri-gue-tas",
    "narigueto": "na-ri-gue-to",
    "nariguilla": "na-ri-gui-lla",
    "narina": "na-ri-na",
    "nariñense": "na-ri-ñen-se",
    "nariz": "na-riz",
    "narizón": "na-ri-zón",
    "narizona": "na-ri-zo-na",
    "narizotas": "na-ri-zo-tas",
    "narizuda": "na-ri-zu-da",
    "narizudo": "na-ri-zu-do",
    "narra": "na-rra",
    "narrable": "na-rra-ble",
    "narración": "na-rra-ción",
    "narrador": "na-rra-dor",
    "narradora": "na-rra-do-ra",
    "narrar": "na-rrar",
    "narrativa": "na-rra-ti-va",
    "narratividad": "na-rra-ti-vi-dad",
    "narrativo": "na-rra-ti-vo",
    "narratología": "na-rra-to-lo-gí-a",
    "narratoria": "na-rra-to-ria",
    "narratorio": "na-rra-to-rio",
    "ñarrear": "ña-rre-ar",
    "narria": "na-rria",
    "nártex": "nár-tex",
    "ñarusa": "ña-ru-sa",
    "ñaruso": "ña-ru-so",
    "narval": "nar-val",
    "narvaso": "nar-va-so",
    "nasa": "na-sa",
    "nasal": "na-sal",
    "nasalidad": "na-sa-li-dad",
    "nasalización": "na-sa-li-za-ción",
    "nasalizar": "na-sa-li-zar",
    "nasardo": "na-sar-do",
    "nasauense": "na-sauen-se",
    "nascencia": "nas-cen-cia",
    "nascer": "nas-cer",
    "nascimiento": "nas-ci-mien-to",
    "nasciturus": "nas-ci-tu-rus",
    "násico": "ná-si-co",
    "naso": "na-so",
    "nasofaringe": "na-so-fa-rin-ge",
    "nasofaríngea": "na-so-fa-rín-ge-a",
    "nasofaríngeo": "na-so-fa-rín-ge-o",
    "nasón": "na-són",
    "nasqueña": "nas-que-ña",
    "nasqueño": "nas-que-ño",
    "nastuerzo": "nas-tuer-zo",
    "nasuda": "na-su-da",
    "nasudo": "na-su-do",
    "nasún": "na-sún",
    "nasuna": "na-su-na",
    "nata": "na-ta",
    "ñata": "ña-ta",
    "natación": "na-ta-ción",
    "natal": "na-tal",
    "natalicia": "na-ta-li-cia",
    "natalicio": "na-ta-li-cio",
    "natalidad": "na-ta-li-dad",
    "natalina": "na-ta-li-na",
    "natalino": "na-ta-li-no",
    "natalista": "na-ta-lis-ta",
    "natátil": "na-tá-til",
    "natatoria": "na-ta-to-ria",
    "natatorio": "na-ta-to-rio",
    "ñatear": "ña-te-ar",
    "naterón": "na-te-rón",
    "natía": "na-tí-a",
    "natilla": "na-ti-lla",
    "natillas": "na-ti-llas",
    "natío": "na-tí-o",
    "nativa": "na-ti-va",
    "natividad": "na-ti-vi-dad",
    "nativismo": "na-ti-vis-mo",
    "nativo": "na-ti-vo",
    "nato": "na-to",
    "ñato": "ña-to",
    "natral": "na-tral",
    "natri": "na-tri",
    "natrón": "na-trón",
    "natura": "na-tu-ra",
    "natural": "na-tu-ral",
    "naturaleza": "na-tu-ra-le-za",
    "naturalidad": "na-tu-ra-li-dad",
    "naturalismo": "na-tu-ra-lis-mo",
    "naturalista": "na-tu-ra-lis-ta",
    "naturalización": "na-tu-ra-li-za-ción",
    "naturalizar": "na-tu-ra-li-zar",
    "naturalmente": "na-tu-ral-men-te",
    "naturismo": "na-tu-ris-mo",
    "naturista": "na-tu-ris-ta",
    "naturópata": "na-tu-ró-pa-ta",
    "naturopatía": "na-tu-ro-pa-tí-a",
    "ñatuso": "ña-tu-so",
    "naucher": "nau-cher",
    "nauclero": "nau-cle-ro",
    "náufraga": "náu-fra-ga",
    "naufragar": "nau-fra-gar",
    "naufragio": "nau-fra-gio",
    "náufrago": "náu-fra-go",
    "ñauido": "ñaui-do",
    "naumaquia": "nau-ma-quia",
    "nauruana": "nau-rua-na",
    "nauruano": "nau-rua-no",
    "náusea": "náu-se-a",
    "nauseabunda": "nau-se-a-bun-da",
    "nauseabundo": "nau-se-a-bun-do",
    "nausear": "nau-se-ar",
    "nauseativa": "nau-se-a-ti-va",
    "nauseativo": "nau-se-a-ti-vo",
    "nauseosa": "nau-se-o-sa",
    "nauseoso": "nau-se-o-so",
    "nauta": "nau-ta",
    "náutica": "náu-ti-ca",
    "náuticamente": "náu-ti-ca-men-te",
    "náutico": "náu-ti-co",
    "nautilo": "nau-ti-lo",
    "nauyaca": "nau-ya-ca",
    "nava": "na-va",
    "navacera": "na-va-ce-ra",
    "navacero": "na-va-ce-ro",
    "navaja": "na-va-ja",
    "navajada": "na-va-ja-da",
    "navajazo": "na-va-ja-zo",
    "navajear": "na-va-je-ar",
    "navajeo": "na-va-je-o",
    "navajera": "na-va-je-ra",
    "navajero": "na-va-je-ro",
    "navajo": "na-va-jo",
    "navajón": "na-va-jón",
    "navajonazo": "na-va-jo-na-zo",
    "naval": "na-val",
    "navanco": "na-van-co",
    "navarca": "na-var-ca",
    "navarra": "na-va-rra",
    "navarrisca": "na-va-rris-ca",
    "navarrisco": "na-va-rris-co",
    "navarro": "na-va-rro",
    "navarroaragonés": "na-va-rro-a-ra-go-nés",
    "navazo": "na-va-zo",
    "nave": "na-ve",
    "navecilla": "na-ve-ci-lla",
    "navegabilidad": "na-ve-ga-bi-li-dad",
    "navegable": "na-ve-ga-ble",
    "navegación": "na-ve-ga-ción",
    "navegado": "na-ve-ga-do",
    "navegador": "na-ve-ga-dor",
    "navegadora": "na-ve-ga-do-ra",
    "navegante": "na-ve-gan-te",
    "navegar": "na-ve-gar",
    "navelina": "na-ve-li-na",
    "naveta": "na-ve-ta",
    "navícula": "na-ví-cu-la",
    "navicular": "na-vi-cu-lar",
    "naviculario": "na-vi-cu-la-rio",
    "navidad": "na-vi-dad",
    "navideña": "na-vi-de-ña",
    "navideño": "na-vi-de-ño",
    "naviega": "na-vie-ga",
    "naviego": "na-vie-go",
    "naviera": "na-vie-ra",
    "naviero": "na-vie-ro",
    "navío": "na-ví-o",
    "náyade": "ná-ya-de",
    "nayarita": "na-ya-ri-ta",
    "nayuribe": "na-yu-ri-be",
    "nazarea": "na-za-re-a",
    "nazarena": "na-za-re-na",
    "nazarenas": "na-za-re-nas",
    "nazareno": "na-za-re-no",
    "nazareo": "na-za-re-o",
    "nazarí": "na-za-rí",
    "nazarita": "na-za-ri-ta",
    "nazi": "na-zi",
    "nazismo": "na-zis-mo",
    "názora": "ná-zo-ra",
    "názula": "ná-zu-la",
    "nea": "ne-a",
    "neapolitana": "ne-a-po-li-ta-na",
    "neapolitano": "ne-a-po-li-ta-no",
    "nearca": "ne-ar-ca",
    "nébeda": "né-be-da",
    "nebel": "ne-bel",
    "nebí": "ne-bí",
    "nebladura": "ne-bla-du-ra",
    "neblí": "ne-blí",
    "neblina": "ne-bli-na",
    "neblinear": "ne-bli-ne-ar",
    "neblinero": "ne-bli-ne-ro",
    "neblinosa": "ne-bli-no-sa",
    "neblinoso": "ne-bli-no-so",
    "neblumo": "ne-blu-mo",
    "nebral": "ne-bral",
    "nebreda": "ne-bre-da",
    "nebrina": "ne-bri-na",
    "nebrisense": "ne-bri-sen-se",
    "nebro": "ne-bro",
    "nebular": "ne-bu-lar",
    "nebulizador": "ne-bu-li-za-dor",
    "nebulizar": "ne-bu-li-zar",
    "nebulón": "ne-bu-lón",
    "nebulosa": "ne-bu-lo-sa",
    "nebulosamente": "ne-bu-lo-sa-men-te",
    "nebulosidad": "ne-bu-lo-si-dad",
    "nebuloso": "ne-bu-lo-so",
    "ñeca": "ñe-ca",
    "necear": "ne-ce-ar",
    "necedad": "ne-ce-dad",
    "necesaria": "ne-ce-sa-ria",
    "necesariamente": "ne-ce-sa-ria-men-te",
    "necesariedad": "ne-ce-sa-rie-dad",
    "necesario": "ne-ce-sa-rio",
    "neceser": "ne-ce-ser",
    "necesidad": "ne-ce-si-dad",
    "necesitada": "ne-ce-si-ta-da",
    "necesitado": "ne-ce-si-ta-do",
    "necesitar": "ne-ce-si-tar",
    "necia": "ne-cia",
    "neciamente": "ne-cia-men-te",
    "necio": "ne-cio",
    "ñecla": "ñe-cla",
    "ñeco": "ñe-co",
    "nécora": "né-co-ra",
    "necrocomio": "ne-cro-co-mio",
    "necrodactilar": "ne-cro-dac-ti-lar",
    "necrófaga": "ne-cró-fa-ga",
    "necrofagia": "ne-cro-fa-gia",
    "necrófago": "ne-cró-fa-go",
    "necrófila": "ne-cró-fi-la",
    "necrofilia": "ne-cro-fi-lia",
    "necrofílico": "ne-cro-fí-li-co",
    "necrófilo": "ne-cró-fi-lo",
    "necrofobia": "ne-cro-fo-bia",
    "necrófora": "ne-cró-fo-ra",
    "necróforo": "ne-cró-fo-ro",
    "necrolatría": "ne-cro-la-trí-a",
    "necrología": "ne-cro-lo-gí-a",
    "necrológica": "ne-cro-ló-gi-ca",
    "necrológicas": "ne-cro-ló-gi-cas",
    "necrológico": "ne-cro-ló-gi-co",
    "necromancía": "ne-cro-man-cí-a",
    "necromancia": "ne-cro-man-cia",
    "necrópolis": "ne-cró-po-lis",
    "necropsia": "ne-crop-sia",
    "necrópsico": "ne-cróp-si-co",
    "necrosar": "ne-cro-sar",
    "necroscopia": "ne-cros-co-pia",
    "necroscópica": "ne-cros-có-pi-ca",
    "necroscópico": "ne-cros-có-pi-co",
    "necrosis": "ne-cro-sis",
    "necrótico": "ne-cró-ti-co",
    "néctar": "néc-tar",
    "nectárea": "nec-tá-re-a",
    "nectáreo": "nec-tá-re-o",
    "nectarina": "nec-ta-ri-na",
    "nectarino": "nec-ta-ri-no",
    "nectario": "nec-ta-rio",
    "necton": "nec-ton",
    "nectónico": "nec-tó-ni-co",
    "ñecudo": "ñe-cu-do",
    "ñeembukeña": "ñe-em-bu-ke-ña",
    "ñeembukeño": "ñe-em-bu-ke-ño",
    "neerlandés": "ne-er-lan-dés",
    "neerlandesa": "ne-er-lan-de-sa",
    "nefanda": "ne-fan-da",
    "nefandamente": "ne-fan-da-men-te",
    "nefandaria": "ne-fan-da-ria",
    "nefandario": "ne-fan-da-rio",
    "nefando": "ne-fan-do",
    "nefaria": "ne-fa-ria",
    "nefariamente": "ne-fa-ria-men-te",
    "nefario": "ne-fa-rio",
    "nefasta": "ne-fas-ta",
    "nefasto": "ne-fas-to",
    "nefata": "ne-fa-ta",
    "nefato": "ne-fa-to",
    "nefelibata": "ne-fe-li-ba-ta",
    "nefelina": "ne-fe-li-na",
    "nefelismo": "ne-fe-lis-mo",
    "nefelometría": "ne-fe-lo-me-trí-a",
    "nefelómetro": "ne-fe-ló-me-tro",
    "nefología": "ne-fo-lo-gí-a",
    "nefrectomía": "ne-frec-to-mí-a",
    "nefridio": "ne-fri-dio",
    "nefrita": "ne-fri-ta",
    "nefrítica": "ne-frí-ti-ca",
    "nefrítico": "ne-frí-ti-co",
    "nefritis": "ne-fri-tis",
    "nefróloga": "ne-fró-lo-ga",
    "nefrología": "ne-fro-lo-gí-a",
    "nefrológico": "ne-fro-ló-gi-co",
    "nefrólogo": "ne-fró-lo-go",
    "nefrón": "ne-frón",
    "nefrona": "ne-fro-na",
    "nefropatía": "ne-fro-pa-tí-a",
    "nefrosis": "ne-fro-sis",
    "nefrótica": "ne-fró-ti-ca",
    "nefrótico": "ne-fró-ti-co",
    "negable": "ne-ga-ble",
    "negación": "ne-ga-ción",
    "negada": "ne-ga-da",
    "negado": "ne-ga-do",
    "negador": "ne-ga-dor",
    "negadora": "ne-ga-do-ra",
    "negamiento": "ne-ga-mien-to",
    "negar": "ne-gar",
    "negativa": "ne-ga-ti-va",
    "negativamente": "ne-ga-ti-va-men-te",
    "negatividad": "ne-ga-ti-vi-dad",
    "negativo": "ne-ga-ti-vo",
    "negatoscopio": "ne-ga-tos-co-pio",
    "negatrón": "ne-ga-trón",
    "negligé": "ne-gli-gé",
    "negligencia": "ne-gli-gen-cia",
    "negligente": "ne-gli-gen-te",
    "negligentemente": "ne-gli-gen-te-men-te",
    "negociabilidad": "ne-go-cia-bi-li-dad",
    "negociable": "ne-go-cia-ble",
    "negociación": "ne-go-cia-ción",
    "negociado": "ne-go-cia-do",
    "negociador": "ne-go-cia-dor",
    "negociadora": "ne-go-cia-do-ra",
    "negocianta": "ne-go-cian-ta",
    "negociante": "ne-go-cian-te",
    "negociar": "ne-go-ciar",
    "negocio": "ne-go-cio",
    "negociosa": "ne-go-cio-sa",
    "negocioso": "ne-go-cio-so",
    "negozuelo": "ne-go-zue-lo",
    "negra": "ne-gra",
    "negrada": "ne-gra-da",
    "negraje": "ne-gra-je",
    "negral": "ne-gral",
    "negramenta": "ne-gra-men-ta",
    "negramentazón": "ne-gra-men-ta-zón",
    "negramente": "ne-gra-men-te",
    "negrear": "ne-gre-ar",
    "negrecer": "ne-gre-cer",
    "negregar": "ne-gre-gar",
    "negreguear": "ne-gre-gue-ar",
    "negregura": "ne-gre-gu-ra",
    "negrera": "ne-gre-ra",
    "negrería": "ne-gre-rí-a",
    "negrero": "ne-gre-ro",
    "negrestina": "ne-gres-ti-na",
    "negrestino": "ne-gres-ti-no",
    "negreta": "ne-gre-ta",
    "negrete": "ne-gre-te",
    "negrilla": "ne-gri-lla",
    "negrillera": "ne-gri-lle-ra",
    "negrillo": "ne-gri-llo",
    "negrismo": "ne-gris-mo",
    "negrita": "ne-gri-ta",
    "negrito": "ne-gri-to",
    "negritud": "ne-gri-tud",
    "negrizca": "ne-griz-ca",
    "negrizco": "ne-griz-co",
    "negro": "ne-gro",
    "negroafricano": "ne-gro-a-fri-ca-no",
    "negrófila": "ne-gró-fi-la",
    "negrófilo": "ne-gró-fi-lo",
    "negroide": "ne-groi-de",
    "negror": "ne-gror",
    "negrota": "ne-gro-ta",
    "negrumo": "ne-gru-mo",
    "negrura": "ne-gru-ra",
    "negruzca": "ne-gruz-ca",
    "negruzco": "ne-gruz-co",
    "neguijón": "ne-gui-jón",
    "neguilla": "ne-gui-lla",
    "neguillón": "ne-gui-llón",
    "negundo": "ne-gun-do",
    "negus": "ne-gus",
    "neibera": "nei-be-ra",
    "neibero": "nei-be-ro",
    "néisico": "néi-si-co",
    "neivana": "nei-va-na",
    "neivano": "nei-va-no",
    "neja": "ne-ja",
    "nejayote": "ne-ja-yo-te",
    "nejo": "ne-jo",
    "neldo": "nel-do",
    "neles": "ne-les",
    "nelumbio": "ne-lum-bio",
    "nelumbo": "ne-lum-bo",
    "nema": "ne-ma",
    "nematelminto": "ne-ma-tel-min-to",
    "nematócero": "ne-ma-tó-ce-ro",
    "nematocisto": "ne-ma-to-cis-to",
    "nematodo": "ne-ma-to-do",
    "nembrar": "nem-brar",
    "neme": "ne-me",
    "nemea": "ne-me-a",
    "nemeo": "ne-me-o",
    "némesis": "né-me-sis",
    "nemon": "ne-mon",
    "nemónica": "ne-mó-ni-ca",
    "nemónico": "ne-mó-ni-co",
    "nemorosa": "ne-mo-ro-sa",
    "nemoroso": "ne-mo-ro-so",
    "nemotecnia": "ne-mo-tec-nia",
    "nemotécnica": "ne-mo-téc-ni-ca",
    "nemotécnico": "ne-mo-téc-ni-co",
    "nena": "ne-na",
    "nene": "ne-ne",
    "neneca": "ne-ne-ca",
    "neneco": "ne-ne-co",
    "neneque": "ne-ne-que",
    "ñenga": "ñen-ga",
    "ñengo": "ñen-go",
    "ñengue": "ñen-gue",
    "nenia": "ne-nia",
    "nenúfar": "ne-nú-far",
    "neo": "ne-o",
    "neobarroco": "ne-o-ba-rro-co",
    "neocaledonia": "ne-o-ca-le-do-nia",
    "neocaledonio": "ne-o-ca-le-do-nio",
    "neocapitalismo": "ne-o-ca-pi-ta-lis-mo",
    "neocapitalista": "ne-o-ca-pi-ta-lis-ta",
    "neocatólica": "ne-o-ca-tó-li-ca",
    "neocatolicismo": "ne-o-ca-to-li-cis-mo",
    "neocatólico": "ne-o-ca-tó-li-co",
    "neoclásica": "ne-o-clá-si-ca",
    "neoclasicismo": "ne-o-cla-si-cis-mo",
    "neoclásico": "ne-o-clá-si-co",
    "neocolonialismo": "ne-o-co-lo-nia-lis-mo",
    "neocolonialista": "ne-o-co-lo-nia-lis-ta",
    "neocriticismo": "ne-o-cri-ti-cis-mo",
    "neodimio": "ne-o-di-mio",
    "neoespartana": "ne-o-es-par-ta-na",
    "neoespartano": "ne-o-es-par-ta-no",
    "neofascismo": "ne-o-fas-cis-mo",
    "neofascista": "ne-o-fas-cis-ta",
    "neófita": "ne-ó-fi-ta",
    "neófito": "ne-ó-fi-to",
    "neógeno": "ne-ó-ge-no",
    "neogótico": "ne-o-gó-ti-co",
    "neogranadina": "ne-o-gra-na-di-na",
    "neogranadino": "ne-o-gra-na-di-no",
    "neogriego": "ne-o-grie-go",
    "neoguineana": "ne-o-gui-ne-a-na",
    "neoguineano": "ne-o-gui-ne-a-no",
    "neoimpresionismo": "ne-oim-pre-sio-nis-mo",
    "neokantiana": "ne-o-kan-tia-na",
    "neokantiano": "ne-o-kan-tia-no",
    "neokantismo": "ne-o-kan-tis-mo",
    "neolatín": "ne-o-la-tín",
    "neolatina": "ne-o-la-ti-na",
    "neolatino": "ne-o-la-ti-no",
    "neolector": "ne-o-lec-tor",
    "neolectora": "ne-o-lec-to-ra",
    "neoleonés": "ne-o-le-o-nés",
    "neoleonesa": "ne-o-le-o-ne-sa",
    "neoliberal": "ne-o-li-be-ral",
    "neoliberalismo": "ne-o-li-be-ra-lis-mo",
    "neolítica": "ne-o-lí-ti-ca",
    "neolítico": "ne-o-lí-ti-co",
    "neóloga": "ne-ó-lo-ga",
    "neología": "ne-o-lo-gí-a",
    "neológica": "ne-o-ló-gi-ca",
    "neológico": "ne-o-ló-gi-co",
    "neologismo": "ne-o-lo-gis-mo",
    "neologista": "ne-o-lo-gis-ta",
    "neólogo": "ne-ó-lo-go",
    "neomejicano": "ne-o-me-ji-ca-no",
    "neomenia": "ne-o-me-nia",
    "neomexicana": "ne-o-me-xi-ca-na",
    "neomexicano": "ne-o-me-xi-ca-no",
    "neón": "ne-ón",
    "neonata": "ne-o-na-ta",
    "neonatal": "ne-o-na-tal",
    "neonato": "ne-o-na-to",
    "neonatóloga": "ne-o-na-tó-lo-ga",
    "neonatología": "ne-o-na-to-lo-gí-a",
    "neonatológico": "ne-o-na-to-ló-gi-co",
    "neonatólogo": "ne-o-na-tó-lo-go",
    "neonazi": "ne-o-na-zi",
    "neonazismo": "ne-o-na-zis-mo",
    "neoplasia": "ne-o-pla-sia",
    "neoplásico": "ne-o-plá-si-co",
    "neoplasma": "ne-o-plas-ma",
    "neoplastia": "ne-o-plas-tia",
    "neoplasticismo": "ne-o-plas-ti-cis-mo",
    "neoplatónica": "ne-o-pla-tó-ni-ca",
    "neoplatonicismo": "ne-o-pla-to-ni-cis-mo",
    "neoplatónico": "ne-o-pla-tó-ni-co",
    "neoplatonismo": "ne-o-pla-to-nis-mo",
    "neopositivismo": "ne-o-po-si-ti-vis-mo",
    "neopositivista": "ne-o-po-si-ti-vis-ta",
    "neopreno": "ne-o-pre-no",
    "neoprofesional": "ne-o-pro-fe-sio-nal",
    "neorácea": "ne-o-rá-ce-a",
    "neoráceo": "ne-o-rá-ce-o",
    "neorama": "ne-o-ra-ma",
    "neorrealismo": "ne-o-rre-a-lis-mo",
    "neorrealista": "ne-o-rre-a-lis-ta",
    "neorromántica": "ne-o-rro-mán-ti-ca",
    "neorromanticismo": "ne-o-rro-man-ti-cis-mo",
    "neorromántico": "ne-o-rro-mán-ti-co",
    "neotenia": "ne-o-te-nia",
    "neotérica": "ne-o-té-ri-ca",
    "neotérico": "ne-o-té-ri-co",
    "neotestamentario": "ne-o-tes-ta-men-ta-rio",
    "neoyorquina": "ne-o-yor-qui-na",
    "neoyorquino": "ne-o-yor-qui-no",
    "neozelandés": "ne-o-ze-lan-dés",
    "neozelandesa": "ne-o-ze-lan-de-sa",
    "neozoico": "ne-o-zoi-co",
    "nepalés": "ne-pa-lés",
    "nepalesa": "ne-pa-le-sa",
    "nepe": "ne-pe",
    "nepentácea": "ne-pen-tá-ce-a",
    "nepentáceas": "ne-pen-tá-ce-as",
    "nepentáceo": "ne-pen-tá-ce-o",
    "nepente": "ne-pen-te",
    "neperiana": "ne-pe-ria-na",
    "neperiano": "ne-pe-ria-no",
    "nepote": "ne-po-te",
    "nepotismo": "ne-po-tis-mo",
    "nepotista": "ne-po-tis-ta",
    "neptúnea": "nep-tú-ne-a",
    "neptúneo": "nep-tú-ne-o",
    "neptuniana": "nep-tu-nia-na",
    "neptuniano": "nep-tu-nia-no",
    "neptúnica": "nep-tú-ni-ca",
    "neptúnico": "nep-tú-ni-co",
    "neptunio": "nep-tu-nio",
    "neptunismo": "nep-tu-nis-mo",
    "neptunista": "nep-tu-nis-ta",
    "neptuno": "nep-tu-no",
    "nequáquam": "ne-quá-quam",
    "ñeque": "ñe-que",
    "nequicia": "ne-qui-cia",
    "ñequiza": "ñe-qui-za",
    "ñera": "ñe-ra",
    "nereida": "ne-rei-da",
    "nerita": "ne-ri-ta",
    "nerítico": "ne-rí-ti-co",
    "ñero": "ñe-ro",
    "neroli": "ne-ro-li",
    "nerolí": "ne-ro-lí",
    "nerón": "ne-rón",
    "neroniana": "ne-ro-nia-na",
    "neroniano": "ne-ro-nia-no",
    "nervado": "ner-va-do",
    "nervadura": "ner-va-du-ra",
    "nervatura": "ner-va-tu-ra",
    "nérvea": "nér-ve-a",
    "nérveo": "nér-ve-o",
    "nervezuelo": "ner-ve-zue-lo",
    "nerviación": "ner-via-ción",
    "nerviar": "ner-viar",
    "nervina": "ner-vi-na",
    "nervino": "ner-vi-no",
    "nervio": "ner-vio",
    "nerviosa": "ner-vio-sa",
    "nerviosamente": "ner-vio-sa-men-te",
    "nerviosidad": "ner-vio-si-dad",
    "nerviosismo": "ner-vio-sis-mo",
    "nervioso": "ner-vio-so",
    "nervosa": "ner-vo-sa",
    "nervosamente": "ner-vo-sa-men-te",
    "nervosidad": "ner-vo-si-dad",
    "nervoso": "ner-vo-so",
    "nervuda": "ner-vu-da",
    "nervudo": "ner-vu-do",
    "nervura": "ner-vu-ra",
    "nescedad": "nes-ce-dad",
    "nescia": "nes-cia",
    "nesciencia": "nes-cien-cia",
    "nesciente": "nes-cien-te",
    "nescientemente": "nes-cien-te-men-te",
    "nescio": "nes-cio",
    "nesga": "nes-ga",
    "nesgada": "nes-ga-da",
    "nesgado": "nes-ga-do",
    "nesgar": "nes-gar",
    "néspera": "nés-pe-ra",
    "néspilo": "nés-pi-lo",
    "nesquisa": "nes-qui-sa",
    "nesquisar": "nes-qui-sar",
    "nestórea": "nes-tó-re-a",
    "nestóreo": "nes-tó-re-o",
    "nestoriana": "nes-to-ria-na",
    "nestorianismo": "nes-to-ria-nis-mo",
    "nestoriano": "nes-to-ria-no",
    "neta": "ne-ta",
    "netácea": "ne-tá-ce-a",
    "netáceo": "ne-tá-ce-o",
    "netamente": "ne-ta-men-te",
    "netezuela": "ne-te-zue-la",
    "netezuelo": "ne-te-zue-lo",
    "neto": "ne-to",
    "netzalhualcoyotleca": "net-zal-hual-co-yo-tle-ca",
    "netzalhualcoyotleco": "net-zal-hual-co-yo-tle-co",
    "neuma": "neu-ma",
    "neumática": "neu-má-ti-ca",
    "neumático": "neu-má-ti-co",
    "neumococo": "neu-mo-co-co",
    "neumoconiosis": "neu-mo-co-nio-sis",
    "neumogástrico": "neu-mo-gás-tri-co",
    "neumóloga": "neu-mó-lo-ga",
    "neumología": "neu-mo-lo-gí-a",
    "neumológico": "neu-mo-ló-gi-co",
    "neumólogo": "neu-mó-lo-go",
    "neumonía": "neu-mo-ní-a",
    "neumónica": "neu-mó-ni-ca",
    "neumónico": "neu-mó-ni-co",
    "neumonitis": "neu-mo-ni-tis",
    "neumopatía": "neu-mo-pa-tí-a",
    "neumotórax": "neu-mo-tó-rax",
    "neuquina": "neu-qui-na",
    "neuquino": "neu-qui-no",
    "neura": "neu-ra",
    "neural": "neu-ral",
    "neuralgia": "neu-ral-gia",
    "neurálgica": "neu-rál-gi-ca",
    "neurálgico": "neu-rál-gi-co",
    "neurastenia": "neu-ras-te-nia",
    "neurasténica": "neu-ras-té-ni-ca",
    "neurasténico": "neu-ras-té-ni-co",
    "neurisma": "neu-ris-ma",
    "neurita": "neu-ri-ta",
    "neuritis": "neu-ri-tis",
    "neuroanatomía": "neu-ro-a-na-to-mí-a",
    "neuroanatómico": "neu-ro-a-na-tó-mi-co",
    "neuroanatomista": "neu-ro-a-na-to-mis-ta",
    "neurobióloga": "neu-ro-bió-lo-ga",
    "neurobiología": "neu-ro-bio-lo-gí-a",
    "neurobiológico": "neu-ro-bio-ló-gi-co",
    "neurobiólogo": "neu-ro-bió-lo-go",
    "neuroblastoma": "neu-ro-blas-to-ma",
    "neurociencia": "neu-ro-cien-cia",
    "neurocirugía": "neu-ro-ci-ru-gí-a",
    "neurocirujana": "neu-ro-ci-ru-ja-na",
    "neurocirujano": "neu-ro-ci-ru-ja-no",
    "neurodegenerativo": "neu-ro-de-ge-ne-ra-ti-vo",
    "neuroembrióloga": "neu-ro-em-brió-lo-ga",
    "neuroembriología": "neu-ro-em-brio-lo-gí-a",
    "neuroembriólogo": "neu-ro-em-brió-lo-go",
    "neuroendocrino": "neu-ro-en-do-cri-no",
    "neuroendocrinóloga": "neu-ro-en-do-cri-nó-lo-ga",
    "neuroendocrinología": "neu-ro-en-do-cri-no-lo-gí-a",
    "neuroendocrinólogo": "neu-ro-en-do-cri-nó-lo-go",
    "neuroepidemiología": "neu-ro-e-pi-de-mio-lo-gí-a",
    "neuroepitelio": "neu-ro-e-pi-te-lio",
    "neuroesqueleto": "neu-ro-es-que-le-to",
    "neurofisiología": "neu-ro-fi-sio-lo-gí-a",
    "neurofisiológico": "neu-ro-fi-sio-ló-gi-co",
    "neuroglia": "neu-ro-glia",
    "neuroléptico": "neu-ro-lép-ti-co",
    "neuróloga": "neu-ró-lo-ga",
    "neurología": "neu-ro-lo-gí-a",
    "neurológico": "neu-ro-ló-gi-co",
    "neurólogo": "neu-ró-lo-go",
    "neuroma": "neu-ro-ma",
    "neurona": "neu-ro-na",
    "neuronal": "neu-ro-nal",
    "neurópata": "neu-ró-pa-ta",
    "neuropatía": "neu-ro-pa-tí-a",
    "neuropatología": "neu-ro-pa-to-lo-gí-a",
    "neuropatológico": "neu-ro-pa-to-ló-gi-co",
    "neuropsiquiatría": "neu-rop-si-quia-trí-a",
    "neuróptero": "neu-róp-te-ro",
    "neurosis": "neu-ro-sis",
    "neurótica": "neu-ró-ti-ca",
    "neuróticamente": "neu-ró-ti-ca-men-te",
    "neurótico": "neu-ró-ti-co",
    "neurotizar": "neu-ro-ti-zar",
    "neurotomía": "neu-ro-to-mí-a",
    "neurótomo": "neu-ró-to-mo",
    "neurotóxico": "neu-ro-tó-xi-co",
    "neurotransmisor": "neu-ro-trans-mi-sor",
    "neurovegetativo": "neu-ro-ve-ge-ta-ti-vo",
    "neuston": "neus-ton",
    "neutle": "neu-tle",
    "neutra": "neu-tra",
    "neutral": "neu-tral",
    "neutralidad": "neu-tra-li-dad",
    "neutralismo": "neu-tra-lis-mo",
    "neutralista": "neu-tra-lis-ta",
    "neutralizable": "neu-tra-li-za-ble",
    "neutralización": "neu-tra-li-za-ción",
    "neutralizador": "neu-tra-li-za-dor",
    "neutralizadora": "neu-tra-li-za-do-ra",
    "neutralizante": "neu-tra-li-zan-te",
    "neutralizar": "neu-tra-li-zar",
    "neutrino": "neu-tri-no",
    "neutro": "neu-tro",
    "neutrófilo": "neu-tró-fi-lo",
    "neutrón": "neu-trón",
    "neutrónico": "neu-tró-ni-co",
    "nevada": "ne-va-da",
    "nevadilla": "ne-va-di-lla",
    "nevado": "ne-va-do",
    "nevar": "ne-var",
    "nevasca": "ne-vas-ca",
    "nevatilla": "ne-va-ti-lla",
    "nevazo": "ne-va-zo",
    "nevazón": "ne-va-zón",
    "nevera": "ne-ve-ra",
    "nevereta": "ne-ve-re-ta",
    "nevería": "ne-ve-rí-a",
    "nevero": "ne-ve-ro",
    "nevisca": "ne-vis-ca",
    "neviscar": "ne-vis-car",
    "neviza": "ne-vi-za",
    "nevo": "ne-vo",
    "nevosa": "ne-vo-sa",
    "nevoso": "ne-vo-so",
    "nevus": "ne-vus",
    "newton": "new-ton",
    "newtoniano": "new-to-nia-no",
    "nexo": "ne-xo",
    "nía": "ní-a",
    "ñiachi": "ñia-chi",
    "niara": "nia-ra",
    "niazo": "nia-zo",
    "nibelunga": "ni-be-lun-ga",
    "nibelungo": "ni-be-lun-go",
    "nicaragua": "ni-ca-ra-gua",
    "nicaraguanismo": "ni-ca-ra-gua-nis-mo",
    "nicaragüe": "ni-ca-ra-güe",
    "nicaragüeña": "ni-ca-ra-güe-ña",
    "nicaragüeñismo": "ni-ca-ra-güe-ñis-mo",
    "nicaragüeño": "ni-ca-ra-güe-ño",
    "nicaragüense": "ni-ca-ra-güen-se",
    "nicaragüensismo": "ni-ca-ra-güen-sis-mo",
    "nicena": "ni-ce-na",
    "niceno": "ni-ce-no",
    "niche": "ni-che",
    "nicho": "ni-cho",
    "nicle": "ni-cle",
    "nicociana": "ni-co-cia-na",
    "nícol": "ní-col",
    "nicolita": "ni-co-li-ta",
    "nicomediense": "ni-co-me-dien-se",
    "nicótica": "ni-có-ti-ca",
    "nicótico": "ni-có-ti-co",
    "nicotina": "ni-co-ti-na",
    "nicotinismo": "ni-co-ti-nis-mo",
    "nicotismo": "ni-co-tis-mo",
    "nicromo": "ni-cro-mo",
    "nictaginácea": "nic-ta-gi-ná-ce-a",
    "nictagináceo": "nic-ta-gi-ná-ce-o",
    "nictagínea": "nic-ta-gí-ne-a",
    "nictagíneo": "nic-ta-gí-ne-o",
    "nictálope": "nic-tá-lo-pe",
    "nictalopía": "nic-ta-lo-pí-a",
    "nictémero": "nic-té-me-ro",
    "nictímero": "nic-tí-me-ro",
    "nictitación": "nic-ti-ta-ción",
    "nictitante": "nic-ti-tan-te",
    "nictofobia": "nic-to-fo-bia",
    "nidación": "ni-da-ción",
    "nidada": "ni-da-da",
    "nidal": "ni-dal",
    "nidia": "ni-dia",
    "nidícola": "ni-dí-co-la",
    "nidificación": "ni-di-fi-ca-ción",
    "nidificar": "ni-di-fi-car",
    "nidífugo": "ni-dí-fu-go",
    "nidio": "ni-dio",
    "nido": "ni-do",
    "nidria": "ni-dria",
    "nidrio": "ni-drio",
    "niebla": "nie-bla",
    "niego": "nie-go",
    "nielado": "nie-la-do",
    "nielar": "nie-lar",
    "niervo": "nier-vo",
    "niéspera": "niés-pe-ra",
    "niéspero": "niés-pe-ro",
    "niéspola": "niés-po-la",
    "nieta": "nie-ta",
    "nietastra": "nie-tas-tra",
    "nietastro": "nie-tas-tro",
    "nieto": "nie-to",
    "nietzscheana": "nietzs-che-a-na",
    "nietzscheano": "nietzs-che-a-no",
    "nieve": "nie-ve",
    "nife": "ni-fe",
    "nigeria": "ni-ge-ria",
    "nigeriana": "ni-ge-ria-na",
    "nigeriano": "ni-ge-ria-no",
    "nigerina": "ni-ge-ri-na",
    "nigerino": "ni-ge-ri-no",
    "nigerio": "ni-ge-rio",
    "nigérrimo": "ni-gé-rri-mo",
    "nigola": "ni-go-la",
    "nigromancía": "ni-gro-man-cí-a",
    "nigromancia": "ni-gro-man-cia",
    "nigromante": "ni-gro-man-te",
    "nigromántica": "ni-gro-mán-ti-ca",
    "nigromántico": "ni-gro-mán-ti-co",
    "nigua": "ni-gua",
    "nihilidad": "nihi-li-dad",
    "nihilismo": "nihi-lis-mo",
    "nihilista": "nihi-lis-ta",
    "nihua": "ni-hua",
    "nilad": "ni-lad",
    "nilón": "ni-lón",
    "nilótico": "ni-ló-ti-co",
    "nimbar": "nim-bar",
    "nimbo": "nim-bo",
    "nimboestrato": "nim-bo-es-tra-to",
    "nimia": "ni-mia",
    "nimiamente": "ni-mia-men-te",
    "nimiedad": "ni-mie-dad",
    "nimio": "ni-mio",
    "niña": "ni-ña",
    "niñada": "ni-ña-da",
    "niñata": "ni-ña-ta",
    "niñato": "ni-ña-to",
    "niñear": "ni-ñe-ar",
    "niñera": "ni-ñe-ra",
    "niñería": "ni-ñe-rí-a",
    "niñero": "ni-ñe-ro",
    "niñeta": "ni-ñe-ta",
    "niñez": "ni-ñez",
    "ninfa": "nin-fa",
    "ninfálido": "nin-fá-li-do",
    "ninfea": "nin-fe-a",
    "ninfeácea": "nin-fe-á-ce-a",
    "ninfeáceas": "nin-fe-á-ce-as",
    "ninfeáceo": "nin-fe-á-ce-o",
    "ninfo": "nin-fo",
    "ninfómana": "nin-fó-ma-na",
    "ninfomanía": "nin-fo-ma-ní-a",
    "ninfomaníaco": "nin-fo-ma-ní-a-co",
    "ñinga": "ñin-ga",
    "ningún": "nin-gún",
    "ninguna": "nin-gu-na",
    "ningunear": "nin-gu-ne-ar",
    "ninguneo": "nin-gu-ne-o",
    "ninguno": "nin-gu-no",
    "ninivita": "ni-ni-vi-ta",
    "niño": "ni-ño",
    "ninot": "ni-not",
    "niobio": "nio-bio",
    "nioto": "nio-to",
    "nipa": "ni-pa",
    "ñipe": "ñi-pe",
    "nipis": "ni-pis",
    "niple": "ni-ple",
    "nipón": "ni-pón",
    "nipona": "ni-po-na",
    "nipos": "ni-pos",
    "ñique": "ñi-que",
    "níquel": "ní-quel",
    "niquelado": "ni-que-la-do",
    "niquelador": "ni-que-la-dor",
    "niqueladora": "ni-que-la-do-ra",
    "niqueladura": "ni-que-la-du-ra",
    "niquelar": "ni-que-lar",
    "niquelina": "ni-que-li-na",
    "niqui": "ni-qui",
    "ñiquiñaque": "ñi-qui-ña-que",
    "niquira": "ni-qui-ra",
    "niquiscocio": "ni-quis-co-cio",
    "niquitosa": "ni-qui-to-sa",
    "niquitoso": "ni-qui-to-so",
    "ñire": "ñi-re",
    "nirvana": "nir-va-na",
    "nisayo": "ni-sa-yo",
    "ñisca": "ñis-ca",
    "níscalo": "nís-ca-lo",
    "niscome": "nis-co-me",
    "ñisñil": "ñis-ñil",
    "níspera": "nís-pe-ra",
    "níspero": "nís-pe-ro",
    "níspola": "nís-po-la",
    "nispolero": "nis-po-le-ro",
    "nisquear": "nis-que-ar",
    "nistagmo": "nis-tag-mo",
    "nistayol": "nis-ta-yol",
    "nistayolero": "nis-ta-yo-le-ro",
    "niste": "nis-te",
    "nitaíno": "ni-ta-í-no",
    "nítida": "ní-ti-da",
    "nítidamente": "ní-ti-da-men-te",
    "nitidez": "ni-ti-dez",
    "nítido": "ní-ti-do",
    "nito": "ni-to",
    "nitor": "ni-tor",
    "nitración": "ni-tra-ción",
    "nitrado": "ni-tra-do",
    "nitrador": "ni-tra-dor",
    "nitral": "ni-tral",
    "nitrar": "ni-trar",
    "nitrato": "ni-tra-to",
    "nitrería": "ni-tre-rí-a",
    "nítrica": "ní-tri-ca",
    "nítrico": "ní-tri-co",
    "nitrilo": "ni-tri-lo",
    "nitrito": "ni-tri-to",
    "nitro": "ni-tro",
    "nitrobenceno": "ni-tro-ben-ce-no",
    "nitrobencina": "ni-tro-ben-ci-na",
    "nitrocelulosa": "ni-tro-ce-lu-lo-sa",
    "nitrocompuesto": "ni-tro-com-pues-to",
    "nitrófilo": "ni-tró-fi-lo",
    "nitroformo": "ni-tro-for-mo",
    "nitrogelatina": "ni-tro-ge-la-ti-na",
    "nitrogenada": "ni-tro-ge-na-da",
    "nitrogenado": "ni-tro-ge-na-do",
    "nitrógeno": "ni-tró-ge-no",
    "nitroglicerina": "ni-tro-gli-ce-ri-na",
    "nitroglicol": "ni-tro-gli-col",
    "nitrón": "ni-trón",
    "nitrona": "ni-tro-na",
    "nitrosa": "ni-tro-sa",
    "nitrosidad": "ni-tro-si-dad",
    "nitroso": "ni-tro-so",
    "nitrotolueno": "ni-tro-to-lue-no",
    "nitruro": "ni-tru-ro",
    "nivación": "ni-va-ción",
    "nival": "ni-val",
    "nívea": "ní-ve-a",
    "nivel": "ni-vel",
    "nivelación": "ni-ve-la-ción",
    "nivelador": "ni-ve-la-dor",
    "niveladora": "ni-ve-la-do-ra",
    "nivelar": "ni-ve-lar",
    "níveo": "ní-ve-o",
    "nivopluvial": "ni-vo-plu-vial",
    "nivosa": "ni-vo-sa",
    "nivoso": "ni-vo-so",
    "nixquear": "nix-que-ar",
    "nixtamal": "nix-ta-mal",
    "nixtamalera": "nix-ta-ma-le-ra",
    "nixtamalero": "nix-ta-ma-le-ro",
    "nixte": "nix-te",
    "nizarda": "ni-zar-da",
    "nizardo": "ni-zar-do",
    "ñizca": "ñiz-ca",
    "nobel": "no-bel",
    "nobelio": "no-be-lio",
    "nobiliaria": "no-bi-lia-ria",
    "nobiliario": "no-bi-lia-rio",
    "nobilísimamente": "no-bi-lí-si-ma-men-te",
    "nobilísimo": "no-bi-lí-si-mo",
    "noble": "no-ble",
    "noblecer": "no-ble-cer",
    "noblemente": "no-ble-men-te",
    "nobleza": "no-ble-za",
    "noblota": "no-blo-ta",
    "noblote": "no-blo-te",
    "nobuk": "no-buk",
    "noca": "no-ca",
    "ñoca": "ño-ca",
    "nocaut": "no-caut",
    "noceda": "no-ce-da",
    "nocedal": "no-ce-dal",
    "nocente": "no-cen-te",
    "ñocha": "ño-cha",
    "nocharniega": "no-char-nie-ga",
    "nocharniego": "no-char-nie-go",
    "noche": "no-che",
    "nochebuena": "no-che-bue-na",
    "nochebueno": "no-che-bue-no",
    "nochecita": "no-che-ci-ta",
    "nochera": "no-che-ra",
    "nocheriego": "no-che-rie-go",
    "nocherniega": "no-cher-nie-ga",
    "nocherniego": "no-cher-nie-go",
    "nochero": "no-che-ro",
    "nochevieja": "no-che-vie-ja",
    "nochizo": "no-chi-zo",
    "nochote": "no-cho-te",
    "nocible": "no-ci-ble",
    "nocimiento": "no-ci-mien-to",
    "noción": "no-ción",
    "nocional": "no-cio-nal",
    "nocir": "no-cir",
    "nociva": "no-ci-va",
    "nocividad": "no-ci-vi-dad",
    "nocivo": "no-ci-vo",
    "nocla": "no-cla",
    "ñoclo": "ño-clo",
    "ñoco": "ño-co",
    "noctámbula": "noc-tám-bu-la",
    "noctambular": "noc-tam-bu-lar",
    "noctambulismo": "noc-tam-bu-lis-mo",
    "noctámbulo": "noc-tám-bu-lo",
    "noctiluca": "noc-ti-lu-ca",
    "noctívaga": "noc-tí-va-ga",
    "noctívago": "noc-tí-va-go",
    "nocturna": "noc-tur-na",
    "nocturnal": "noc-tur-nal",
    "nocturnamente": "noc-tur-na-men-te",
    "nocturnancia": "noc-tur-nan-cia",
    "nocturnidad": "noc-tur-ni-dad",
    "nocturnina": "noc-tur-ni-na",
    "nocturnino": "noc-tur-ni-no",
    "nocturno": "noc-tur-no",
    "nodación": "no-da-ción",
    "nodal": "no-dal",
    "nodátil": "no-dá-til",
    "nodo": "no-do",
    "nodriza": "no-dri-za",
    "nodular": "no-du-lar",
    "nódulo": "nó-du-lo",
    "noé": "no-é",
    "noema": "no-e-ma",
    "noemático": "no-e-má-ti-co",
    "noesis": "no-e-sis",
    "noético": "no-é-ti-co",
    "nogada": "no-ga-da",
    "nogal": "no-gal",
    "nogalina": "no-ga-li-na",
    "noguera": "no-gue-ra",
    "noguerada": "no-gue-ra-da",
    "noguerado": "no-gue-ra-do",
    "nogueral": "no-gue-ral",
    "nogueruela": "no-gue-rue-la",
    "ñola": "ño-la",
    "noli": "no-li",
    "nolí": "no-lí",
    "nolición": "no-li-ción",
    "nolit": "no-lit",
    "noluntad": "no-lun-tad",
    "noma": "no-ma",
    "nómada": "nó-ma-da",
    "nómade": "nó-ma-de",
    "nomadismo": "no-ma-dis-mo",
    "nomás": "no-más",
    "ñomblo": "ñom-blo",
    "ñomblón": "ñom-blón",
    "nombrada": "nom-bra-da",
    "nombradamente": "nom-bra-da-men-te",
    "nombradía": "nom-bra-dí-a",
    "nombrado": "nom-bra-do",
    "nombramiento": "nom-bra-mien-to",
    "nombrar": "nom-brar",
    "nombre": "nom-bre",
    "nombrete": "nom-bre-te",
    "nome": "no-me",
    "nomenclador": "no-men-cla-dor",
    "nomenclátor": "no-men-clá-tor",
    "nomenclatura": "no-men-cla-tu-ra",
    "nomenclatural": "no-men-cla-tu-ral",
    "nomeolvides": "no-me-ol-vi-des",
    "nómica": "nó-mi-ca",
    "nómico": "nó-mi-co",
    "nómina": "nó-mi-na",
    "nominación": "no-mi-na-ción",
    "nominador": "no-mi-na-dor",
    "nominadora": "no-mi-na-do-ra",
    "nominal": "no-mi-nal",
    "nominalismo": "no-mi-na-lis-mo",
    "nominalista": "no-mi-na-lis-ta",
    "nominalización": "no-mi-na-li-za-ción",
    "nominalizar": "no-mi-na-li-zar",
    "nominalmente": "no-mi-nal-men-te",
    "nominar": "no-mi-nar",
    "nominátim": "no-mi-ná-tim",
    "nominativa": "no-mi-na-ti-va",
    "nominativo": "no-mi-na-ti-vo",
    "nominilla": "no-mi-ni-lla",
    "nómino": "nó-mi-no",
    "nomo": "no-mo",
    "nomofiláctico": "no-mo-fi-lác-ti-co",
    "nomofilaxis": "no-mo-fi-la-xis",
    "nomografía": "no-mo-gra-fí-a",
    "nomograma": "no-mo-gra-ma",
    "nomon": "no-mon",
    "nomónica": "no-mó-ni-ca",
    "nomónico": "no-mó-ni-co",
    "nomparell": "nom-pa-rell",
    "nona": "no-na",
    "ñoña": "ño-ña",
    "nonada": "no-na-da",
    "nonagenaria": "no-na-ge-na-ria",
    "nonagenario": "no-na-ge-na-rio",
    "nonagésima": "no-na-gé-si-ma",
    "nonagésimo": "no-na-gé-si-mo",
    "nonágona": "no-ná-go-na",
    "nonagonal": "no-na-go-nal",
    "nonágono": "no-ná-go-no",
    "nonata": "no-na-ta",
    "nonato": "no-na-to",
    "noneca": "no-ne-ca",
    "noneco": "no-ne-co",
    "ñoñería": "ño-ñe-rí-a",
    "nones": "no-nes",
    "noneto": "no-ne-to",
    "ñoñez": "ño-ñez",
    "ñonga": "ñon-ga",
    "ñongo": "ñon-go",
    "ñonguera": "ñon-gue-ra",
    "noningentésima": "no-nin-gen-té-si-ma",
    "noningentésimo": "no-nin-gen-té-si-mo",
    "nonio": "no-nio",
    "nonius": "no-nius",
    "nono": "no-no",
    "ñoño": "ño-ño",
    "nónuplo": "nó-nu-plo",
    "noosfera": "no-os-fe-ra",
    "noósfera": "no-ós-fe-ra",
    "nopal": "no-pal",
    "nopaleda": "no-pa-le-da",
    "nopalera": "no-pa-le-ra",
    "nopalito": "no-pa-li-to",
    "nopalitos": "no-pa-li-tos",
    "ñopo": "ño-po",
    "noque": "no-que",
    "noquear": "no-que-ar",
    "noquero": "no-que-ro",
    "ñoqui": "ño-qui",
    "ñora": "ño-ra",
    "norabuena": "no-ra-bue-na",
    "noradrenalina": "no-ra-dre-na-li-na",
    "noramala": "no-ra-ma-la",
    "noray": "no-ray",
    "ñorbo": "ñor-bo",
    "norcoreana": "nor-co-re-a-na",
    "norcoreano": "nor-co-re-a-no",
    "ñorda": "ñor-da",
    "nordestal": "nor-des-tal",
    "nordeste": "nor-des-te",
    "nordestear": "nor-des-te-ar",
    "nórdica": "nór-di-ca",
    "nórdico": "nór-di-co",
    "ñórdiga": "ñór-di-ga",
    "nordista": "nor-dis-ta",
    "norepinefrina": "no-re-pi-ne-fri-na",
    "noreste": "no-res-te",
    "noria": "no-ria",
    "norial": "no-rial",
    "norirlandés": "no-rir-lan-dés",
    "norirlandesa": "no-rir-lan-de-sa",
    "norma": "nor-ma",
    "normación": "nor-ma-ción",
    "normal": "nor-mal",
    "normalidad": "nor-ma-li-dad",
    "normalista": "nor-ma-lis-ta",
    "normalización": "nor-ma-li-za-ción",
    "normalizar": "nor-ma-li-zar",
    "normalmente": "nor-mal-men-te",
    "normana": "nor-ma-na",
    "normanda": "nor-man-da",
    "normando": "nor-man-do",
    "normano": "nor-ma-no",
    "normar": "nor-mar",
    "normativa": "nor-ma-ti-va",
    "normativización": "nor-ma-ti-vi-za-ción",
    "normativizado": "nor-ma-ti-vi-za-do",
    "normativizar": "nor-ma-ti-vi-zar",
    "normativo": "nor-ma-ti-vo",
    "normotenso": "nor-mo-ten-so",
    "nornordeste": "nor-nor-des-te",
    "nornoreste": "nor-no-res-te",
    "nornoroeste": "nor-no-ro-es-te",
    "nornorueste": "nor-no-rues-te",
    "noro": "no-ro",
    "noroccidental": "no-roc-ci-den-tal",
    "noroeste": "no-ro-es-te",
    "noroestear": "no-ro-es-te-ar",
    "nororiental": "no-ro-rien-tal",
    "norsantandereana": "nor-san-tan-de-re-a-na",
    "norsantandereano": "nor-san-tan-de-re-a-no",
    "nortada": "nor-ta-da",
    "nortazo": "nor-ta-zo",
    "norte": "nor-te",
    "norteado": "nor-te-a-do",
    "norteafricana": "nor-te-a-fri-ca-na",
    "norteafricano": "nor-te-a-fri-ca-no",
    "norteamericana": "nor-te-a-me-ri-ca-na",
    "norteamericano": "nor-te-a-me-ri-ca-no",
    "nortear": "nor-te-ar",
    "norteña": "nor-te-ña",
    "norteño": "nor-te-ño",
    "nortina": "nor-ti-na",
    "nortino": "nor-ti-no",
    "noruega": "no-rue-ga",
    "noruego": "no-rue-go",
    "norueste": "no-rues-te",
    "noruestear": "no-rues-te-ar",
    "nosocomio": "no-so-co-mio",
    "nosofobia": "no-so-fo-bia",
    "nosogenia": "no-so-ge-nia",
    "nosografía": "no-so-gra-fí-a",
    "nosología": "no-so-lo-gí-a",
    "nosológica": "no-so-ló-gi-ca",
    "nosológico": "no-so-ló-gi-co",
    "nosomanía": "no-so-ma-ní-a",
    "nosomántica": "no-so-mán-ti-ca",
    "nosotras": "no-so-tras",
    "nosotros": "no-so-tros",
    "nostalgia": "nos-tal-gia",
    "nostálgica": "nos-tál-gi-ca",
    "nostálgicamente": "nos-tál-gi-ca-men-te",
    "nostálgico": "nos-tál-gi-co",
    "nóstica": "nós-ti-ca",
    "nosticismo": "nos-ti-cis-mo",
    "nóstico": "nós-ti-co",
    "nostrama": "nos-tra-ma",
    "nostramo": "nos-tra-mo",
    "nostras": "nos-tras",
    "nota": "no-ta",
    "notabilidad": "no-ta-bi-li-dad",
    "notabilísimo": "no-ta-bi-lí-si-mo",
    "notable": "no-ta-ble",
    "notablemente": "no-ta-ble-men-te",
    "notación": "no-ta-ción",
    "notar": "no-tar",
    "notaría": "no-ta-rí-a",
    "notaria": "no-ta-ria",
    "notariada": "no-ta-ria-da",
    "notariado": "no-ta-ria-do",
    "notarial": "no-ta-rial",
    "notarialmente": "no-ta-rial-men-te",
    "notariato": "no-ta-ria-to",
    "notario": "no-ta-rio",
    "noticia": "no-ti-cia",
    "noticiable": "no-ti-cia-ble",
    "noticiar": "no-ti-ciar",
    "noticiario": "no-ti-cia-rio",
    "noticiera": "no-ti-cie-ra",
    "noticiero": "no-ti-cie-ro",
    "notición": "no-ti-ción",
    "noticiosa": "no-ti-cio-sa",
    "noticioso": "no-ti-cio-so",
    "notificación": "no-ti-fi-ca-ción",
    "notificada": "no-ti-fi-ca-da",
    "notificado": "no-ti-fi-ca-do",
    "notificar": "no-ti-fi-car",
    "notificativa": "no-ti-fi-ca-ti-va",
    "notificativo": "no-ti-fi-ca-ti-vo",
    "noto": "no-to",
    "notocorda": "no-to-cor-da",
    "notocordio": "no-to-cor-dio",
    "notomía": "no-to-mí-a",
    "notoria": "no-to-ria",
    "notoriamente": "no-to-ria-men-te",
    "notoriedad": "no-to-rie-dad",
    "notorio": "no-to-rio",
    "notro": "no-tro",
    "noúmeno": "no-ú-me-no",
    "nova": "no-va",
    "novaciana": "no-va-cia-na",
    "novaciano": "no-va-cia-no",
    "novación": "no-va-ción",
    "novador": "no-va-dor",
    "novadora": "no-va-do-ra",
    "noval": "no-val",
    "novar": "no-var",
    "novata": "no-va-ta",
    "novatada": "no-va-ta-da",
    "novato": "no-va-to",
    "novator": "no-va-tor",
    "novatora": "no-va-to-ra",
    "novecentismo": "no-ve-cen-tis-mo",
    "novecentista": "no-ve-cen-tis-ta",
    "novecientas": "no-ve-cien-tas",
    "novecientos": "no-ve-cien-tos",
    "novedad": "no-ve-dad",
    "novedosa": "no-ve-do-sa",
    "novedoso": "no-ve-do-so",
    "novel": "no-vel",
    "novela": "no-ve-la",
    "novelable": "no-ve-la-ble",
    "novelador": "no-ve-la-dor",
    "noveladora": "no-ve-la-do-ra",
    "novelar": "no-ve-lar",
    "novelera": "no-ve-le-ra",
    "novelerear": "no-ve-le-re-ar",
    "novelería": "no-ve-le-rí-a",
    "novelero": "no-ve-le-ro",
    "novelesca": "no-ve-les-ca",
    "novelesco": "no-ve-les-co",
    "novelista": "no-ve-lis-ta",
    "novelística": "no-ve-lís-ti-ca",
    "novelístico": "no-ve-lís-ti-co",
    "novelizar": "no-ve-li-zar",
    "novelo": "no-ve-lo",
    "novelón": "no-ve-lón",
    "novén": "no-vén",
    "novena": "no-ve-na",
    "novenario": "no-ve-na-rio",
    "novendial": "no-ven-dial",
    "noveno": "no-ve-no",
    "noventa": "no-ven-ta",
    "noventava": "no-ven-ta-va",
    "noventavo": "no-ven-ta-vo",
    "noventayochista": "no-ven-ta-yo-chis-ta",
    "noventón": "no-ven-tón",
    "noventona": "no-ven-to-na",
    "novia": "no-via",
    "noviar": "no-viar",
    "noviazgo": "no-viaz-go",
    "novicia": "no-vi-cia",
    "noviciado": "no-vi-cia-do",
    "novicio": "no-vi-cio",
    "noviciote": "no-vi-cio-te",
    "noviembre": "no-viem-bre",
    "noviera": "no-vie-ra",
    "noviero": "no-vie-ro",
    "novilla": "no-vi-lla",
    "novillada": "no-vi-lla-da",
    "novillear": "no-vi-lle-ar",
    "novillera": "no-vi-lle-ra",
    "novillero": "no-vi-lle-ro",
    "novillo": "no-vi-llo",
    "novilunio": "no-vi-lu-nio",
    "novio": "no-vio",
    "novísima": "no-ví-si-ma",
    "novísimo": "no-ví-si-mo",
    "novocaína": "no-vo-ca-í-na",
    "novohispana": "no-vohis-pa-na",
    "novohispano": "no-vohis-pa-no",
    "novomejicano": "no-vo-me-ji-ca-no",
    "novomexicano": "no-vo-me-xi-ca-no",
    "noxa": "no-xa",
    "noyó": "no-yó",
    "nubada": "nu-ba-da",
    "nubado": "nu-ba-do",
    "nubarrada": "nu-ba-rra-da",
    "nubarrado": "nu-ba-rra-do",
    "nubarrón": "nu-ba-rrón",
    "nubazón": "nu-ba-zón",
    "nube": "nu-be",
    "nubia": "nu-bia",
    "nubiense": "nu-bien-se",
    "nubífera": "nu-bí-fe-ra",
    "nubífero": "nu-bí-fe-ro",
    "núbil": "nú-bil",
    "nubilidad": "nu-bi-li-dad",
    "nubilosa": "nu-bi-lo-sa",
    "nubiloso": "nu-bi-lo-so",
    "nubio": "nu-bio",
    "nubla": "nu-bla",
    "nublado": "nu-bla-do",
    "ñublado": "ñu-bla-do",
    "nublar": "nu-blar",
    "ñublar": "ñu-blar",
    "nublazón": "nu-bla-zón",
    "ñublense": "ñu-blen-se",
    "ñublina": "ñu-bli-na",
    "ñublino": "ñu-bli-no",
    "nublo": "nu-blo",
    "ñublo": "ñu-blo",
    "ñublosa": "ñu-blo-sa",
    "nubloso": "nu-blo-so",
    "ñubloso": "ñu-blo-so",
    "nubosa": "nu-bo-sa",
    "nubosidad": "nu-bo-si-dad",
    "nuboso": "nu-bo-so",
    "nuca": "nu-ca",
    "nuche": "nu-che",
    "nucir": "nu-cir",
    "nucleado": "nu-cle-a-do",
    "nuclear": "nu-cle-ar",
    "nuclearia": "nu-cle-a-ria",
    "nucleario": "nu-cle-a-rio",
    "nuclearización": "nu-cle-a-ri-za-ción",
    "nuclearizar": "nu-cle-a-ri-zar",
    "nucleico": "nu-clei-co",
    "nucleido": "nu-clei-do",
    "núcleo": "nú-cle-o",
    "nucléolo": "nu-clé-o-lo",
    "nucleón": "nu-cle-ón",
    "nucleónica": "nu-cle-ó-ni-ca",
    "nucleoproteína": "nu-cle-o-pro-te-í-na",
    "nucleótido": "nu-cle-ó-ti-do",
    "nuco": "nu-co",
    "ñuco": "ñu-co",
    "núcula": "nú-cu-la",
    "nuda": "nu-da",
    "nudamente": "nu-da-men-te",
    "nudillo": "nu-di-llo",
    "ñudillo": "ñu-di-llo",
    "nudismo": "nu-dis-mo",
    "nudista": "nu-dis-ta",
    "nudo": "nu-do",
    "ñudo": "ñu-do",
    "ñudosa": "ñu-do-sa",
    "nudosidad": "nu-do-si-dad",
    "nudoso": "nu-do-so",
    "ñudoso": "ñu-do-so",
    "nudrimiento": "nu-dri-mien-to",
    "nudrir": "nu-drir",
    "nuececilla": "nue-ce-ci-lla",
    "nuecera": "nue-ce-ra",
    "nuecero": "nue-ce-ro",
    "nuégado": "nué-ga-do",
    "nuera": "nue-ra",
    "nuesa": "nue-sa",
    "nueso": "nue-so",
    "nuestra": "nues-tra",
    "nuestrama": "nues-tra-ma",
    "nuestramo": "nues-tra-mo",
    "nuestro": "nues-tro",
    "nueva": "nue-va",
    "nuevamente": "nue-va-men-te",
    "nueve": "nue-ve",
    "nuevo": "nue-vo",
    "nuevoleonés": "nue-vo-le-o-nés",
    "nueza": "nue-za",
    "ñufla": "ñu-fla",
    "nugatoria": "nu-ga-to-ria",
    "nugatorio": "nu-ga-to-rio",
    "nula": "nu-la",
    "nulamente": "nu-la-men-te",
    "nulidad": "nu-li-dad",
    "nulo": "nu-lo",
    "numantina": "nu-man-ti-na",
    "numantinamente": "nu-man-ti-na-men-te",
    "numantinismo": "nu-man-ti-nis-mo",
    "numantino": "nu-man-ti-no",
    "numen": "nu-men",
    "numerable": "nu-me-ra-ble",
    "numeración": "nu-me-ra-ción",
    "numerador": "nu-me-ra-dor",
    "numeradora": "nu-me-ra-do-ra",
    "numeral": "nu-me-ral",
    "numerar": "nu-me-rar",
    "numeraria": "nu-me-ra-ria",
    "numerario": "nu-me-ra-rio",
    "numerativo": "nu-me-ra-ti-vo",
    "numérica": "nu-mé-ri-ca",
    "numéricamente": "nu-mé-ri-ca-men-te",
    "numérico": "nu-mé-ri-co",
    "número": "nú-me-ro",
    "numerología": "nu-me-ro-lo-gí-a",
    "numerosa": "nu-me-ro-sa",
    "numerosamente": "nu-me-ro-sa-men-te",
    "numerosidad": "nu-me-ro-si-dad",
    "numeroso": "nu-me-ro-so",
    "númida": "nú-mi-da",
    "numídica": "nu-mí-di-ca",
    "numídico": "nu-mí-di-co",
    "numinoso": "nu-mi-no-so",
    "numisma": "nu-mis-ma",
    "numismática": "nu-mis-má-ti-ca",
    "numismático": "nu-mis-má-ti-co",
    "numo": "nu-mo",
    "numular": "nu-mu-lar",
    "numularia": "nu-mu-la-ria",
    "numulario": "nu-mu-la-rio",
    "numulita": "nu-mu-li-ta",
    "numulites": "nu-mu-li-tes",
    "nunca": "nun-ca",
    "nunciatura": "nun-cia-tu-ra",
    "nuncio": "nun-cio",
    "nuncupativo": "nun-cu-pa-ti-vo",
    "nuncupatoria": "nun-cu-pa-to-ria",
    "nuncupatorio": "nun-cu-pa-to-rio",
    "nuño": "nu-ño",
    "nupcial": "nup-cial",
    "nupcialidad": "nup-cia-li-dad",
    "nupcias": "nup-cias",
    "ñurda": "ñur-da",
    "ñurdo": "ñur-do",
    "nurse": "nur-se",
    "ñusa": "ñu-sa",
    "ñuso": "ñu-so",
    "ñuta": "ñu-ta",
    "nutación": "nu-ta-ción",
    "ñuto": "ñu-to",
    "nutra": "nu-tra",
    "nutria": "nu-tria",
    "nutricia": "nu-tri-cia",
    "nutricio": "nu-tri-cio",
    "nutrición": "nu-tri-ción",
    "nutricional": "nu-tri-cio-nal",
    "nutricionista": "nu-tri-cio-nis-ta",
    "nutrida": "nu-tri-da",
    "nutrido": "nu-tri-do",
    "nutriente": "nu-trien-te",
    "nutriero": "nu-trie-ro",
    "nutrimental": "nu-tri-men-tal",
    "nutrimento": "nu-tri-men-to",
    "nutrimiento": "nu-tri-mien-to",
    "nutrir": "nu-trir",
    "nutritiva": "nu-tri-ti-va",
    "nutritivo": "nu-tri-ti-vo",
    "nutriz": "nu-triz",
    "nutróloga": "nu-tró-lo-ga",
    "nutrólogo": "nu-tró-lo-go",
    "nutual": "nu-tual",
    "ñuzco": "ñuz-co",
    "oa": "o-a",
    "oasis": "o-a-sis",
    "oaxaqueña": "o-a-xa-que-ña",
    "oaxaqueño": "o-a-xa-que-ño",
    "obbligato": "ob-bli-ga-to",
    "obcecación": "ob-ce-ca-ción",
    "obcecadamente": "ob-ce-ca-da-men-te",
    "obcecar": "ob-ce-car",
    "obduración": "ob-du-ra-ción",
    "obedecedor": "o-be-de-ce-dor",
    "obedecedora": "o-be-de-ce-do-ra",
    "obedecer": "o-be-de-cer",
    "obedecible": "o-be-de-ci-ble",
    "obedecimiento": "o-be-de-ci-mien-to",
    "obediencia": "o-be-dien-cia",
    "obediencial": "o-be-dien-cial",
    "obediente": "o-be-dien-te",
    "obedientemente": "o-be-dien-te-men-te",
    "obelisco": "o-be-lis-co",
    "óbelo": "ó-be-lo",
    "obencadura": "o-ben-ca-du-ra",
    "obenque": "o-ben-que",
    "obertura": "o-ber-tu-ra",
    "obesa": "o-be-sa",
    "obesidad": "o-be-si-dad",
    "obeso": "o-be-so",
    "óbice": "ó-bi-ce",
    "obispado": "o-bis-pa-do",
    "obispal": "o-bis-pal",
    "obispalía": "o-bis-pa-lí-a",
    "obispar": "o-bis-par",
    "obispillo": "o-bis-pi-llo",
    "obispo": "o-bis-po",
    "óbito": "ó-bi-to",
    "obituario": "o-bi-tua-rio",
    "obiubí": "o-biu-bí",
    "objeción": "ob-je-ción",
    "objecto": "ob-jec-to",
    "objetable": "ob-je-ta-ble",
    "objetante": "ob-je-tan-te",
    "objetar": "ob-je-tar",
    "objetiva": "ob-je-ti-va",
    "objetivación": "ob-je-ti-va-ción",
    "objetivamente": "ob-je-ti-va-men-te",
    "objetivar": "ob-je-ti-var",
    "objetividad": "ob-je-ti-vi-dad",
    "objetivismo": "ob-je-ti-vis-mo",
    "objetivista": "ob-je-ti-vis-ta",
    "objetivo": "ob-je-ti-vo",
    "objeto": "ob-je-to",
    "objetor": "ob-je-tor",
    "objetual": "ob-je-tual",
    "oblación": "o-bla-ción",
    "oblada": "o-bla-da",
    "oblata": "o-bla-ta",
    "oblativa": "o-bla-ti-va",
    "oblativo": "o-bla-ti-vo",
    "oblato": "o-bla-to",
    "oblea": "o-ble-a",
    "obleera": "o-ble-e-ra",
    "oblicua": "o-bli-cua",
    "oblicuamente": "o-bli-cua-men-te",
    "oblicuángulo": "o-bli-cuán-gu-lo",
    "oblicuar": "o-bli-cuar",
    "oblicuidad": "o-bli-cui-dad",
    "oblicuo": "o-bli-cuo",
    "obligación": "o-bli-ga-ción",
    "obligacionista": "o-bli-ga-cio-nis-ta",
    "obligada": "o-bli-ga-da",
    "obligado": "o-bli-ga-do",
    "obligamiento": "o-bli-ga-mien-to",
    "obligar": "o-bli-gar",
    "obligativa": "o-bli-ga-ti-va",
    "obligativo": "o-bli-ga-ti-vo",
    "obligatoria": "o-bli-ga-to-ria",
    "obligatoriamente": "o-bli-ga-to-ria-men-te",
    "obligatoriedad": "o-bli-ga-to-rie-dad",
    "obligatorio": "o-bli-ga-to-rio",
    "obliteración": "o-bli-te-ra-ción",
    "obliterador": "o-bli-te-ra-dor",
    "obliteradora": "o-bli-te-ra-do-ra",
    "obliterar": "o-bli-te-rar",
    "oblito": "o-bli-to",
    "oblonga": "o-blon-ga",
    "oblongada": "o-blon-ga-da",
    "oblongado": "o-blon-ga-do",
    "oblongamente": "o-blon-ga-men-te",
    "oblongo": "o-blon-go",
    "obnoxia": "ob-no-xia",
    "obnoxio": "ob-no-xio",
    "obnubilación": "ob-nu-bi-la-ción",
    "obnubilar": "ob-nu-bi-lar",
    "obo": "o-bo",
    "oboe": "o-bo-e",
    "oboísta": "o-bo-ís-ta",
    "óbolo": "ó-bo-lo",
    "obra": "o-bra",
    "obrada": "o-bra-da",
    "obradera": "o-bra-de-ra",
    "obrador": "o-bra-dor",
    "obradora": "o-bra-do-ra",
    "obradura": "o-bra-du-ra",
    "obraje": "o-bra-je",
    "obrajera": "o-bra-je-ra",
    "obrajero": "o-bra-je-ro",
    "obrantina": "o-bran-ti-na",
    "obrar": "o-brar",
    "obregón": "o-bre-gón",
    "obrejería": "o-bre-je-rí-a",
    "obrepción": "o-brep-ción",
    "obrepticia": "o-brep-ti-cia",
    "obrepticiamente": "o-brep-ti-cia-men-te",
    "obrepticio": "o-brep-ti-cio",
    "obrera": "o-bre-ra",
    "obrería": "o-bre-rí-a",
    "obrerismo": "o-bre-ris-mo",
    "obrerista": "o-bre-ris-ta",
    "obrero": "o-bre-ro",
    "obrizo": "o-bri-zo",
    "obscena": "obs-ce-na",
    "obscenamente": "obs-ce-na-men-te",
    "obscenidad": "obs-ce-ni-dad",
    "obsceno": "obs-ce-no",
    "obscura": "obs-cu-ra",
    "obscuración": "obs-cu-ra-ción",
    "obscuramente": "obs-cu-ra-men-te",
    "obscurantismo": "obs-cu-ran-tis-mo",
    "obscurantista": "obs-cu-ran-tis-ta",
    "obscurecer": "obs-cu-re-cer",
    "obscurecimiento": "obs-cu-re-ci-mien-to",
    "obscuridad": "obs-cu-ri-dad",
    "obscuro": "obs-cu-ro",
    "obsecración": "ob-se-cra-ción",
    "obsecuencia": "ob-se-cuen-cia",
    "obsecuente": "ob-se-cuen-te",
    "obsequiador": "ob-se-quia-dor",
    "obsequiadora": "ob-se-quia-do-ra",
    "obsequiante": "ob-se-quian-te",
    "obsequiar": "ob-se-quiar",
    "obsequias": "ob-se-quias",
    "obsequio": "ob-se-quio",
    "obsequiosa": "ob-se-quio-sa",
    "obsequiosamente": "ob-se-quio-sa-men-te",
    "obsequiosidad": "ob-se-quio-si-dad",
    "obsequioso": "ob-se-quio-so",
    "observable": "ob-ser-va-ble",
    "observación": "ob-ser-va-ción",
    "observacional": "ob-ser-va-cio-nal",
    "observador": "ob-ser-va-dor",
    "observadora": "ob-ser-va-do-ra",
    "observancia": "ob-ser-van-cia",
    "observante": "ob-ser-van-te",
    "observar": "ob-ser-var",
    "observatorio": "ob-ser-va-to-rio",
    "obsesa": "ob-se-sa",
    "obsesión": "ob-se-sión",
    "obsesionante": "ob-se-sio-nan-te",
    "obsesionar": "ob-se-sio-nar",
    "obsesiva": "ob-se-si-va",
    "obsesivo": "ob-se-si-vo",
    "obseso": "ob-se-so",
    "obsidiana": "ob-si-dia-na",
    "obsidional": "ob-si-dio-nal",
    "obsolescencia": "ob-so-les-cen-cia",
    "obsolescente": "ob-so-les-cen-te",
    "obsoleta": "ob-so-le-ta",
    "obsoleto": "ob-so-le-to",
    "obstaculización": "obs-ta-cu-li-za-ción",
    "obstaculizar": "obs-ta-cu-li-zar",
    "obstáculo": "obs-tá-cu-lo",
    "obstancia": "obs-tan-cia",
    "obstante": "obs-tan-te",
    "obstar": "obs-tar",
    "obstetra": "obs-te-tra",
    "obstetricia": "obs-te-tri-cia",
    "obstétrico": "obs-té-tri-co",
    "obstinación": "obs-ti-na-ción",
    "obstinadamente": "obs-ti-na-da-men-te",
    "obstinado": "obs-ti-na-do",
    "obstinante": "obs-ti-nan-te",
    "obstinar": "obs-ti-nar",
    "obstrucción": "obs-truc-ción",
    "obstruccionismo": "obs-truc-cio-nis-mo",
    "obstruccionista": "obs-truc-cio-nis-ta",
    "obstructor": "obs-truc-tor",
    "obstructora": "obs-truc-to-ra",
    "obstruir": "obs-truir",
    "obtemperar": "ob-tem-pe-rar",
    "obtención": "ob-ten-ción",
    "obtener": "ob-te-ner",
    "obtenible": "ob-te-ni-ble",
    "obtento": "ob-ten-to",
    "obtentor": "ob-ten-tor",
    "obtestación": "ob-tes-ta-ción",
    "obturación": "ob-tu-ra-ción",
    "obturador": "ob-tu-ra-dor",
    "obturar": "ob-tu-rar",
    "obtusa": "ob-tu-sa",
    "obtusángulo": "ob-tu-sán-gu-lo",
    "obtuso": "ob-tu-so",
    "obué": "o-bué",
    "obús": "o-bús",
    "obusera": "o-bu-se-ra",
    "obvención": "ob-ven-ción",
    "obvencional": "ob-ven-cio-nal",
    "obvia": "ob-via",
    "obviamente": "ob-via-men-te",
    "obviar": "ob-viar",
    "obviedad": "ob-vie-dad",
    "obvio": "ob-vio",
    "obyecta": "ob-yec-ta",
    "obyecto": "ob-yec-to",
    "oca": "o-ca",
    "ocal": "o-cal",
    "ocalear": "o-ca-le-ar",
    "ocamba": "o-cam-ba",
    "ocambo": "o-cam-bo",
    "ocañense": "o-ca-ñen-se",
    "ocapi": "o-ca-pi",
    "ocarina": "o-ca-ri-na",
    "ocasión": "o-ca-sión",
    "ocasionada": "o-ca-sio-na-da",
    "ocasionadamente": "o-ca-sio-na-da-men-te",
    "ocasionado": "o-ca-sio-na-do",
    "ocasionador": "o-ca-sio-na-dor",
    "ocasionadora": "o-ca-sio-na-do-ra",
    "ocasional": "o-ca-sio-nal",
    "ocasionalidad": "o-ca-sio-na-li-dad",
    "ocasionalismo": "o-ca-sio-na-lis-mo",
    "ocasionalmente": "o-ca-sio-nal-men-te",
    "ocasionar": "o-ca-sio-nar",
    "ocaso": "o-ca-so",
    "occidental": "oc-ci-den-tal",
    "occidentalismo": "oc-ci-den-ta-lis-mo",
    "occidentalista": "oc-ci-den-ta-lis-ta",
    "occidentalización": "oc-ci-den-ta-li-za-ción",
    "occidentalizante": "oc-ci-den-ta-li-zan-te",
    "occidentalizar": "oc-ci-den-ta-li-zar",
    "occidentalmente": "oc-ci-den-tal-men-te",
    "occidente": "oc-ci-den-te",
    "occidua": "oc-ci-dua",
    "occiduo": "oc-ci-duo",
    "occipital": "oc-ci-pi-tal",
    "occipucio": "oc-ci-pu-cio",
    "occisa": "oc-ci-sa",
    "occisión": "oc-ci-sión",
    "occiso": "oc-ci-so",
    "occitana": "oc-ci-ta-na",
    "occitánica": "oc-ci-tá-ni-ca",
    "occitánico": "oc-ci-tá-ni-co",
    "occitano": "oc-ci-ta-no",
    "oceánica": "o-ce-á-ni-ca",
    "oceánico": "o-ce-á-ni-co",
    "oceanicultura": "o-ce-a-ni-cul-tu-ra",
    "oceánida": "o-ce-á-ni-da",
    "oceánidas": "o-ce-á-ni-das",
    "oceánide": "o-ce-á-ni-de",
    "océano": "o-cé-a-no",
    "oceanógrafa": "o-ce-a-nó-gra-fa",
    "oceanografía": "o-ce-a-no-gra-fí-a",
    "oceanográfica": "o-ce-a-no-grá-fi-ca",
    "oceanográfico": "o-ce-a-no-grá-fi-co",
    "oceanógrafo": "o-ce-a-nó-gra-fo",
    "ocelada": "o-ce-la-da",
    "ocelado": "o-ce-la-do",
    "ocelo": "o-ce-lo",
    "ocelote": "o-ce-lo-te",
    "ocena": "o-ce-na",
    "ochar": "o-char",
    "ochava": "o-cha-va",
    "ochavada": "o-cha-va-da",
    "ochavado": "o-cha-va-do",
    "ochavar": "o-cha-var",
    "ochavario": "o-cha-va-rio",
    "ochavo": "o-cha-vo",
    "ochavón": "o-cha-vón",
    "ochavona": "o-cha-vo-na",
    "ochenta": "o-chen-ta",
    "ochentañal": "o-chen-ta-ñal",
    "ochentava": "o-chen-ta-va",
    "ochentavo": "o-chen-ta-vo",
    "ochentena": "o-chen-te-na",
    "ochenteno": "o-chen-te-no",
    "ochentón": "o-chen-tón",
    "ochentona": "o-chen-to-na",
    "ocho": "o-cho",
    "ochocientas": "o-cho-cien-tas",
    "ochocientos": "o-cho-cien-tos",
    "ochomil": "o-cho-mil",
    "ochosén": "o-cho-sén",
    "ociar": "o-ciar",
    "ocio": "o-cio",
    "ociosa": "o-cio-sa",
    "ociosamente": "o-cio-sa-men-te",
    "ociosidad": "o-cio-si-dad",
    "ocioso": "o-cio-so",
    "ocle": "o-cle",
    "oclocracia": "o-clo-cra-cia",
    "ocluir": "o-cluir",
    "oclusión": "o-clu-sión",
    "oclusiva": "o-clu-si-va",
    "oclusivo": "o-clu-si-vo",
    "ocobo": "o-co-bo",
    "ocoeña": "o-co-e-ña",
    "ocoeño": "o-co-e-ño",
    "ocomistle": "o-co-mis-tle",
    "ocopa": "o-co-pa",
    "ocotal": "o-co-tal",
    "ocotaleña": "o-co-ta-le-ña",
    "ocotaleño": "o-co-ta-le-ño",
    "ocotaloso": "o-co-ta-lo-so",
    "ocote": "o-co-te",
    "ocotepecana": "o-co-te-pe-ca-na",
    "ocotepecano": "o-co-te-pe-ca-no",
    "ocotera": "o-co-te-ra",
    "ocotero": "o-co-te-ro",
    "ocotillo": "o-co-ti-llo",
    "ocotita": "o-co-ti-ta",
    "ocotito": "o-co-ti-to",
    "ocotoso": "o-co-to-so",
    "ocozoal": "o-co-zo-al",
    "ocozol": "o-co-zol",
    "ocra": "o-cra",
    "ocráceo": "o-crá-ce-o",
    "ocre": "o-cre",
    "ocrey": "o-crey",
    "octacordio": "oc-ta-cor-dio",
    "octaédrica": "oc-ta-é-dri-ca",
    "octaédrico": "oc-ta-é-dri-co",
    "octaedro": "oc-ta-e-dro",
    "octágona": "oc-tá-go-na",
    "octagonal": "oc-ta-go-nal",
    "octágono": "oc-tá-go-no",
    "octanaje": "oc-ta-na-je",
    "octano": "oc-ta-no",
    "octante": "oc-tan-te",
    "octástilo": "oc-tás-ti-lo",
    "octava": "oc-ta-va",
    "octavar": "oc-ta-var",
    "octavario": "oc-ta-va-rio",
    "octaviana": "oc-ta-via-na",
    "octaviano": "oc-ta-via-no",
    "octavilla": "oc-ta-vi-lla",
    "octavín": "oc-ta-vín",
    "octavo": "oc-ta-vo",
    "octavofinalista": "oc-ta-vo-fi-na-lis-ta",
    "octeto": "oc-te-to",
    "octingentésima": "oc-tin-gen-té-si-ma",
    "octingentésimo": "oc-tin-gen-té-si-mo",
    "octocoralario": "oc-to-co-ra-la-rio",
    "octogenaria": "oc-to-ge-na-ria",
    "octogenario": "oc-to-ge-na-rio",
    "octogésima": "oc-to-gé-si-ma",
    "octogésimo": "oc-to-gé-si-mo",
    "octógona": "oc-tó-go-na",
    "octogonal": "oc-to-go-nal",
    "octógono": "oc-tó-go-no",
    "octópoda": "oc-tó-po-da",
    "octópodo": "oc-tó-po-do",
    "octosílaba": "oc-to-sí-la-ba",
    "octosilábica": "oc-to-si-lá-bi-ca",
    "octosilábico": "oc-to-si-lá-bi-co",
    "octosílabo": "oc-to-sí-la-bo",
    "octóstila": "oc-tós-ti-la",
    "octóstilo": "oc-tós-ti-lo",
    "octubre": "oc-tu-bre",
    "octubrino": "oc-tu-bri-no",
    "óctupla": "óc-tu-pla",
    "óctuple": "óc-tu-ple",
    "óctuplo": "óc-tu-plo",
    "ocuje": "o-cu-je",
    "ocular": "o-cu-lar",
    "ocularista": "o-cu-la-ris-ta",
    "ocularmente": "o-cu-lar-men-te",
    "oculista": "o-cu-lis-ta",
    "óculo": "ó-cu-lo",
    "oculta": "o-cul-ta",
    "ocultación": "o-cul-ta-ción",
    "ocultador": "o-cul-ta-dor",
    "ocultadora": "o-cul-ta-do-ra",
    "ocultamente": "o-cul-ta-men-te",
    "ocultamiento": "o-cul-ta-mien-to",
    "ocultar": "o-cul-tar",
    "ocultis": "o-cul-tis",
    "ocultismo": "o-cul-tis-mo",
    "ocultista": "o-cul-tis-ta",
    "oculto": "o-cul-to",
    "ocume": "o-cu-me",
    "ocumo": "o-cu-mo",
    "ocupa": "o-cu-pa",
    "ocupación": "o-cu-pa-ción",
    "ocupacional": "o-cu-pa-cio-nal",
    "ocupada": "o-cu-pa-da",
    "ocupado": "o-cu-pa-do",
    "ocupador": "o-cu-pa-dor",
    "ocupadora": "o-cu-pa-do-ra",
    "ocupante": "o-cu-pan-te",
    "ocupar": "o-cu-par",
    "ocurrencia": "o-cu-rren-cia",
    "ocurrente": "o-cu-rren-te",
    "ocurrido": "o-cu-rri-do",
    "ocurrir": "o-cu-rrir",
    "ocurso": "o-cur-so",
    "oda": "o-da",
    "odalisca": "o-da-lis-ca",
    "odeón": "o-de-ón",
    "odiar": "o-diar",
    "odio": "o-dio",
    "odiosa": "o-dio-sa",
    "odiosamente": "o-dio-sa-men-te",
    "odiosidad": "o-dio-si-dad",
    "odioso": "o-dio-so",
    "odisea": "o-di-se-a",
    "odómetro": "o-dó-me-tro",
    "odonato": "o-do-na-to",
    "odontalgia": "o-don-tal-gia",
    "odontálgica": "o-don-tál-gi-ca",
    "odontálgico": "o-don-tál-gi-co",
    "odontoceto": "o-don-to-ce-to",
    "odontóloga": "o-don-tó-lo-ga",
    "odontología": "o-don-to-lo-gí-a",
    "odontológica": "o-don-to-ló-gi-ca",
    "odontológico": "o-don-to-ló-gi-co",
    "odontólogo": "o-don-tó-lo-go",
    "odorable": "o-do-ra-ble",
    "odorante": "o-do-ran-te",
    "odorato": "o-do-ra-to",
    "odorífera": "o-do-rí-fe-ra",
    "odorífero": "o-do-rí-fe-ro",
    "odorífica": "o-do-rí-fi-ca",
    "odorífico": "o-do-rí-fi-co",
    "odre": "o-dre",
    "odrería": "o-dre-rí-a",
    "odrero": "o-dre-ro",
    "odrina": "o-dri-na",
    "odrisia": "o-dri-sia",
    "odrisio": "o-dri-sio",
    "oenoterácea": "o-e-no-te-rá-ce-a",
    "oenoteráceo": "o-e-no-te-rá-ce-o",
    "oersted": "o-ers-ted",
    "oesnoroeste": "o-es-no-ro-es-te",
    "oesnorueste": "o-es-no-rues-te",
    "oeste": "o-es-te",
    "oesudoeste": "o-e-su-do-es-te",
    "oesudueste": "o-e-su-dues-te",
    "oesuroeste": "o-e-su-ro-es-te",
    "ofendedor": "o-fen-de-dor",
    "ofendedora": "o-fen-de-do-ra",
    "ofender": "o-fen-der",
    "ofendículo": "o-fen-dí-cu-lo",
    "ofendida": "o-fen-di-da",
    "ofendido": "o-fen-di-do",
    "ofensa": "o-fen-sa",
    "ofensador": "o-fen-sa-dor",
    "ofensadora": "o-fen-sa-do-ra",
    "ofensar": "o-fen-sar",
    "ofensión": "o-fen-sión",
    "ofensiva": "o-fen-si-va",
    "ofensivamente": "o-fen-si-va-men-te",
    "ofensivo": "o-fen-si-vo",
    "ofensor": "o-fen-sor",
    "ofensora": "o-fen-so-ra",
    "oferente": "o-fe-ren-te",
    "oferta": "o-fer-ta",
    "ofertante": "o-fer-tan-te",
    "ofertar": "o-fer-tar",
    "ofertorio": "o-fer-to-rio",
    "office": "of-fi-ce",
    "offset": "off-set",
    "offside": "off-si-de",
    "oficial": "o-fi-cial",
    "oficiala": "o-fi-cia-la",
    "oficialía": "o-fi-cia-lí-a",
    "oficialidad": "o-fi-cia-li-dad",
    "oficialismo": "o-fi-cia-lis-mo",
    "oficialista": "o-fi-cia-lis-ta",
    "oficialización": "o-fi-cia-li-za-ción",
    "oficializar": "o-fi-cia-li-zar",
    "oficialmente": "o-fi-cial-men-te",
    "oficiante": "o-fi-cian-te",
    "oficiar": "o-fi-ciar",
    "oficina": "o-fi-ci-na",
    "oficinal": "o-fi-ci-nal",
    "oficinesca": "o-fi-ci-nes-ca",
    "oficinesco": "o-fi-ci-nes-co",
    "oficinista": "o-fi-ci-nis-ta",
    "oficio": "o-fi-cio",
    "oficionario": "o-fi-cio-na-rio",
    "oficiosa": "o-fi-cio-sa",
    "oficiosamente": "o-fi-cio-sa-men-te",
    "oficiosidad": "o-fi-cio-si-dad",
    "oficioso": "o-fi-cio-so",
    "ofidio": "o-fi-dio",
    "ofimática": "o-fi-má-ti-ca",
    "ofiolatría": "o-fio-la-trí-a",
    "ofiómaco": "o-fió-ma-co",
    "ofita": "o-fi-ta",
    "ofiura": "o-fiu-ra",
    "ofiuroideo": "o-fiu-roi-de-o",
    "oflador": "o-fla-dor",
    "oflar": "o-flar",
    "ofrecedor": "o-fre-ce-dor",
    "ofrecedora": "o-fre-ce-do-ra",
    "ofrecer": "o-fre-cer",
    "ofrecida": "o-fre-ci-da",
    "ofrecido": "o-fre-ci-do",
    "ofrecimiento": "o-fre-ci-mien-to",
    "ofrenda": "o-fren-da",
    "ofrendar": "o-fren-dar",
    "ófrico": "ó-fri-co",
    "oftalmía": "of-tal-mí-a",
    "oftalmia": "of-tal-mia",
    "oftálmica": "of-tál-mi-ca",
    "oftálmico": "of-tál-mi-co",
    "oftalmóloga": "of-tal-mó-lo-ga",
    "oftalmología": "of-tal-mo-lo-gí-a",
    "oftalmológica": "of-tal-mo-ló-gi-ca",
    "oftalmológico": "of-tal-mo-ló-gi-co",
    "oftalmólogo": "of-tal-mó-lo-go",
    "oftalmoscopia": "of-tal-mos-co-pia",
    "oftalmoscopio": "of-tal-mos-co-pio",
    "ofuscación": "o-fus-ca-ción",
    "ofuscador": "o-fus-ca-dor",
    "ofuscadora": "o-fus-ca-do-ra",
    "ofuscamiento": "o-fus-ca-mien-to",
    "ofuscar": "o-fus-car",
    "ogaño": "o-ga-ño",
    "ogresa": "o-gre-sa",
    "ogro": "o-gro",
    "óhmica": "óh-mi-ca",
    "óhmico": "óh-mi-co",
    "ohmímetro": "oh-mí-me-tro",
    "ohmio": "oh-mio",
    "oíble": "o-í-ble",
    "oída": "o-í-da",
    "oídio": "o-í-dio",
    "oído": "o-í-do",
    "oidor": "oi-dor",
    "oidora": "oi-do-ra",
    "oidoría": "oi-do-rí-a",
    "oíl": "o-íl",
    "oimiento": "oi-mien-to",
    "oír": "o-ír",
    "oíslo": "o-ís-lo",
    "ojal": "o-jal",
    "ojalá": "o-ja-lá",
    "ojalada": "o-ja-la-da",
    "ojaladera": "o-ja-la-de-ra",
    "ojalado": "o-ja-la-do",
    "ojalador": "o-ja-la-dor",
    "ojaladora": "o-ja-la-do-ra",
    "ojaladura": "o-ja-la-du-ra",
    "ojalar": "o-ja-lar",
    "ojalatero": "o-ja-la-te-ro",
    "ojanco": "o-jan-co",
    "ojar": "o-jar",
    "ojaranzo": "o-ja-ran-zo",
    "ojeada": "o-je-a-da",
    "ojeado": "o-je-a-do",
    "ojeador": "o-je-a-dor",
    "ojeadora": "o-je-a-do-ra",
    "ojear": "o-je-ar",
    "ojén": "o-jén",
    "ojeo": "o-je-o",
    "ojera": "o-je-ra",
    "ojeriza": "o-je-ri-za",
    "ojerosa": "o-je-ro-sa",
    "ojeroso": "o-je-ro-so",
    "ojeruda": "o-je-ru-da",
    "ojerudo": "o-je-ru-do",
    "ojetada": "o-je-ta-da",
    "ojete": "o-je-te",
    "ojeteado": "o-je-te-a-do",
    "ojetear": "o-je-te-ar",
    "ojetera": "o-je-te-ra",
    "ojetillo": "o-je-ti-llo",
    "ojialegre": "o-jia-le-gre",
    "ojienjuta": "o-jien-ju-ta",
    "ojienjuto": "o-jien-ju-to",
    "ojigarza": "o-ji-gar-za",
    "ojigarzo": "o-ji-gar-zo",
    "ojimel": "o-ji-mel",
    "ojímetro": "o-jí-me-tro",
    "ojimiel": "o-ji-miel",
    "ojimorena": "o-ji-mo-re-na",
    "ojimoreno": "o-ji-mo-re-no",
    "ojinegra": "o-ji-ne-gra",
    "ojinegro": "o-ji-ne-gro",
    "ojiprieta": "o-ji-prie-ta",
    "ojiprieto": "o-ji-prie-to",
    "ojito": "o-ji-to",
    "ojituerta": "o-ji-tuer-ta",
    "ojituerto": "o-ji-tuer-to",
    "ojiva": "o-ji-va",
    "ojival": "o-ji-val",
    "ojizaina": "o-ji-zai-na",
    "ojizaino": "o-ji-zai-no",
    "ojizarca": "o-ji-zar-ca",
    "ojizarco": "o-ji-zar-co",
    "ojo": "o-jo",
    "ojoche": "o-jo-che",
    "ojosa": "o-jo-sa",
    "ojoso": "o-jo-so",
    "ojota": "o-jo-ta",
    "ojudo": "o-ju-do",
    "ojuelos": "o-jue-los",
    "okapi": "o-ka-pi",
    "okupa": "o-ku-pa",
    "okupar": "o-ku-par",
    "ola": "o-la",
    "olaje": "o-la-je",
    "olambre": "o-lam-bre",
    "olambrilla": "o-lam-bri-lla",
    "olán": "o-lán",
    "ole": "o-le",
    "olé": "o-lé",
    "oleácea": "o-le-á-ce-a",
    "oleáceas": "o-le-á-ce-as",
    "oleáceo": "o-le-á-ce-o",
    "oleada": "o-le-a-da",
    "oleado": "o-le-a-do",
    "oleaginosa": "o-le-a-gi-no-sa",
    "oleaginosidad": "o-le-a-gi-no-si-dad",
    "oleaginoso": "o-le-a-gi-no-so",
    "oleaje": "o-le-a-je",
    "olear": "o-le-ar",
    "olearia": "o-le-a-ria",
    "oleario": "o-le-a-rio",
    "oleastro": "o-le-as-tro",
    "oleaza": "o-le-a-za",
    "oledera": "o-le-de-ra",
    "oledero": "o-le-de-ro",
    "oledor": "o-le-dor",
    "oledora": "o-le-do-ra",
    "oleico": "o-lei-co",
    "oleícola": "o-le-í-co-la",
    "oleicultor": "o-lei-cul-tor",
    "oleicultora": "o-lei-cul-to-ra",
    "oleicultura": "o-lei-cul-tu-ra",
    "oleífera": "o-le-í-fe-ra",
    "oleífero": "o-le-í-fe-ro",
    "oleína": "o-le-í-na",
    "óleo": "ó-le-o",
    "oleoducto": "o-le-o-duc-to",
    "oleografía": "o-le-o-gra-fí-a",
    "oleómetro": "o-le-ó-me-tro",
    "oleorresina": "o-le-o-rre-si-na",
    "oleosa": "o-le-o-sa",
    "oleosidad": "o-le-o-si-dad",
    "oleoso": "o-le-o-so",
    "oler": "o-ler",
    "olfa": "ol-fa",
    "olfacción": "ol-fac-ción",
    "olfatear": "ol-fa-te-ar",
    "olfateo": "ol-fa-te-o",
    "olfativa": "ol-fa-ti-va",
    "olfativo": "ol-fa-ti-vo",
    "olfato": "ol-fa-to",
    "olfatoria": "ol-fa-to-ria",
    "olfatorio": "ol-fa-to-rio",
    "olíbano": "o-lí-ba-no",
    "oliente": "o-lien-te",
    "oliera": "o-lie-ra",
    "olifante": "o-li-fan-te",
    "oligarca": "o-li-gar-ca",
    "oligarquía": "o-li-gar-quí-a",
    "oligárquica": "o-li-gár-qui-ca",
    "oligárquico": "o-li-gár-qui-co",
    "oligisto": "o-li-gis-to",
    "oligoceno": "o-li-go-ce-no",
    "oligoelemento": "o-li-go-e-le-men-to",
    "oligofrenia": "o-li-go-fre-nia",
    "oligofrénica": "o-li-go-fré-ni-ca",
    "oligofrénico": "o-li-go-fré-ni-co",
    "oligopolio": "o-li-go-po-lio",
    "oligopsonio": "o-li-gop-so-nio",
    "oligoqueto": "o-li-go-que-to",
    "oligosacárido": "o-li-go-sa-cá-ri-do",
    "oligospermia": "o-li-gos-per-mia",
    "oligotrofia": "o-li-go-tro-fia",
    "oligotrófico": "o-li-go-tró-fi-co",
    "oliguria": "o-li-gu-ria",
    "olimareño": "o-li-ma-re-ño",
    "olimpeña": "o-lim-pe-ña",
    "olimpeño": "o-lim-pe-ño",
    "olimpiaca": "o-lim-pia-ca",
    "olimpiaco": "o-lim-pia-co",
    "olimpiada": "o-lim-pia-da",
    "olímpica": "o-lím-pi-ca",
    "olímpicamente": "o-lím-pi-ca-men-te",
    "olímpico": "o-lím-pi-co",
    "olimpismo": "o-lim-pis-mo",
    "olimpo": "o-lim-po",
    "olingo": "o-lin-go",
    "olio": "o-lio",
    "olisca": "o-lis-ca",
    "oliscar": "o-lis-car",
    "olisco": "o-lis-co",
    "oliscoso": "o-lis-co-so",
    "olismear": "o-lis-me-ar",
    "olisquear": "o-lis-que-ar",
    "olisqueo": "o-lis-que-o",
    "oliva": "o-li-va",
    "oliváceo": "o-li-vá-ce-o",
    "olivar": "o-li-var",
    "olivarda": "o-li-var-da",
    "olivarera": "o-li-va-re-ra",
    "olivarero": "o-li-va-re-ro",
    "olivastro": "o-li-vas-tro",
    "olivera": "o-li-ve-ra",
    "olivero": "o-li-ve-ro",
    "olivícola": "o-li-ví-co-la",
    "olivicultor": "o-li-vi-cul-tor",
    "olivicultora": "o-li-vi-cul-to-ra",
    "olivicultura": "o-li-vi-cul-tu-ra",
    "olivífera": "o-li-ví-fe-ra",
    "olivífero": "o-li-ví-fe-ro",
    "olivillo": "o-li-vi-llo",
    "olivino": "o-li-vi-no",
    "olivo": "o-li-vo",
    "olivosa": "o-li-vo-sa",
    "olivoso": "o-li-vo-so",
    "olla": "o-lla",
    "ollado": "o-lla-do",
    "ollao": "o-lla-o",
    "ollar": "o-llar",
    "ollera": "o-lle-ra",
    "ollería": "o-lle-rí-a",
    "ollero": "o-lle-ro",
    "olleta": "o-lle-ta",
    "olloco": "o-llo-co",
    "olluco": "o-llu-co",
    "olma": "ol-ma",
    "olmeca": "ol-me-ca",
    "olmeda": "ol-me-da",
    "olmedana": "ol-me-da-na",
    "olmedano": "ol-me-da-no",
    "olmedo": "ol-me-do",
    "olmo": "ol-mo",
    "ológrafa": "o-ló-gra-fa",
    "ológrafo": "o-ló-gra-fo",
    "olomina": "o-lo-mi-na",
    "olopopo": "o-lo-po-po",
    "olor": "o-lor",
    "olorizar": "o-lo-ri-zar",
    "olorosa": "o-lo-ro-sa",
    "olorosar": "o-lo-ro-sar",
    "olorosear": "o-lo-ro-se-ar",
    "oloroso": "o-lo-ro-so",
    "olote": "o-lo-te",
    "olotense": "o-lo-ten-se",
    "olotera": "o-lo-te-ra",
    "olotina": "o-lo-ti-na",
    "olotino": "o-lo-ti-no",
    "olura": "o-lu-ra",
    "olvidada": "ol-vi-da-da",
    "olvidadera": "ol-vi-da-de-ra",
    "olvidadero": "ol-vi-da-de-ro",
    "olvidadiza": "ol-vi-da-di-za",
    "olvidadizo": "ol-vi-da-di-zo",
    "olvidado": "ol-vi-da-do",
    "olvidanza": "ol-vi-dan-za",
    "olvidar": "ol-vi-dar",
    "olvido": "ol-vi-do",
    "olvidosa": "ol-vi-do-sa",
    "olvidoso": "ol-vi-do-so",
    "omagua": "o-ma-gua",
    "omaguaca": "o-ma-gua-ca",
    "omaní": "o-ma-ní",
    "omaso": "o-ma-so",
    "omatidio": "o-ma-ti-dio",
    "ombligada": "om-bli-ga-da",
    "ombligo": "om-bli-go",
    "ombliguero": "om-bli-gue-ro",
    "ombría": "om-brí-a",
    "ombú": "om-bú",
    "omecillo": "o-me-ci-llo",
    "omega": "o-me-ga",
    "omental": "o-men-tal",
    "omento": "o-men-to",
    "omero": "o-me-ro",
    "omeya": "o-me-ya",
    "ómicron": "ó-mi-cron",
    "ominar": "o-mi-nar",
    "ominosa": "o-mi-no-sa",
    "ominoso": "o-mi-no-so",
    "omisa": "o-mi-sa",
    "omisible": "o-mi-si-ble",
    "omisión": "o-mi-sión",
    "omiso": "o-mi-so",
    "omitir": "o-mi-tir",
    "ommiada": "om-mia-da",
    "ómnibus": "óm-ni-bus",
    "omnicomprensivo": "om-ni-com-pren-si-vo",
    "omnidireccional": "om-ni-di-rec-cio-nal",
    "omnímoda": "om-ní-mo-da",
    "omnímodamente": "om-ní-mo-da-men-te",
    "omnímodo": "om-ní-mo-do",
    "omnipotencia": "om-ni-po-ten-cia",
    "omnipotente": "om-ni-po-ten-te",
    "omnipotentemente": "om-ni-po-ten-te-men-te",
    "omnipresencia": "om-ni-pre-sen-cia",
    "omnipresente": "om-ni-pre-sen-te",
    "omnisapiente": "om-ni-sa-pien-te",
    "omniscia": "om-nis-cia",
    "omnisciencia": "om-nis-cien-cia",
    "omnisciente": "om-nis-cien-te",
    "omniscio": "om-nis-cio",
    "omnívora": "om-ní-vo-ra",
    "omnívoro": "om-ní-vo-ro",
    "omóplato": "o-mó-pla-to",
    "omoto": "o-mo-to",
    "ona": "o-na",
    "onagra": "o-na-gra",
    "onagrariea": "o-na-gra-rie-a",
    "onagrarieo": "o-na-gra-rie-o",
    "onagro": "o-na-gro",
    "onanismo": "o-na-nis-mo",
    "onanista": "o-na-nis-ta",
    "onanístico": "o-na-nís-ti-co",
    "once": "on-ce",
    "oncear": "on-ce-ar",
    "onceavo": "on-ce-a-vo",
    "oncejera": "on-ce-je-ra",
    "oncejo": "on-ce-jo",
    "oncemil": "on-ce-mil",
    "oncena": "on-ce-na",
    "onceno": "on-ce-no",
    "oncijera": "on-ci-je-ra",
    "oncita": "on-ci-ta",
    "oncocercosis": "on-co-cer-co-sis",
    "oncogén": "on-co-gén",
    "oncogénesis": "on-co-gé-ne-sis",
    "oncogénico": "on-co-gé-ni-co",
    "oncóloga": "on-có-lo-ga",
    "oncología": "on-co-lo-gí-a",
    "oncológico": "on-co-ló-gi-co",
    "oncólogo": "on-có-lo-go",
    "onda": "on-da",
    "onde": "on-de",
    "ondeado": "on-de-a-do",
    "ondeante": "on-de-an-te",
    "ondear": "on-de-ar",
    "ondeo": "on-de-o",
    "ondina": "on-di-na",
    "ondisonante": "on-di-so-nan-te",
    "ondosa": "on-do-sa",
    "ondoso": "on-do-so",
    "ondra": "on-dra",
    "ondrar": "on-drar",
    "ondulación": "on-du-la-ción",
    "ondulada": "on-du-la-da",
    "ondulado": "on-du-la-do",
    "ondulador": "on-du-la-dor",
    "ondulante": "on-du-lan-te",
    "ondular": "on-du-lar",
    "ondulatoria": "on-du-la-to-ria",
    "ondulatorio": "on-du-la-to-rio",
    "ondulín": "on-du-lín",
    "onecer": "o-ne-cer",
    "oneraria": "o-ne-ra-ria",
    "onerario": "o-ne-ra-rio",
    "onerosa": "o-ne-ro-sa",
    "onerosamente": "o-ne-ro-sa-men-te",
    "oneroso": "o-ne-ro-so",
    "onfacino": "on-fa-ci-no",
    "onfacomeli": "on-fa-co-me-li",
    "ónice": "ó-ni-ce",
    "onicofagia": "o-ni-co-fa-gia",
    "onicóforo": "o-ni-có-fo-ro",
    "onicomancia": "o-ni-co-man-cia",
    "ónique": "ó-ni-que",
    "oniquina": "o-ni-qui-na",
    "onírica": "o-ní-ri-ca",
    "onírico": "o-ní-ri-co",
    "onirismo": "o-ni-ris-mo",
    "oniromancía": "o-ni-ro-man-cí-a",
    "oniromancia": "o-ni-ro-man-cia",
    "ónix": "ó-nix",
    "onocrótalo": "o-no-cró-ta-lo",
    "onomancia": "o-no-man-cia",
    "onomasiología": "o-no-ma-sio-lo-gí-a",
    "onomasiológico": "o-no-ma-sio-ló-gi-co",
    "onomástica": "o-no-más-ti-ca",
    "onomástico": "o-no-más-ti-co",
    "onomatopeya": "o-no-ma-to-pe-ya",
    "onomatopéyica": "o-no-ma-to-pé-yi-ca",
    "onomatopéyico": "o-no-ma-to-pé-yi-co",
    "onoquiles": "o-no-qui-les",
    "onosma": "o-nos-ma",
    "onoto": "o-no-to",
    "óntico": "ón-ti-co",
    "ontina": "on-ti-na",
    "ontogénesis": "on-to-gé-ne-sis",
    "ontogenia": "on-to-ge-nia",
    "ontogénica": "on-to-gé-ni-ca",
    "ontogénico": "on-to-gé-ni-co",
    "ontóloga": "on-tó-lo-ga",
    "ontología": "on-to-lo-gí-a",
    "ontológica": "on-to-ló-gi-ca",
    "ontológico": "on-to-ló-gi-co",
    "ontologismo": "on-to-lo-gis-mo",
    "ontólogo": "on-tó-lo-go",
    "onubense": "o-nu-ben-se",
    "onusta": "o-nus-ta",
    "onusto": "o-nus-to",
    "onza": "on-za",
    "onzava": "on-za-va",
    "onzavo": "on-za-vo",
    "oocito": "o-o-ci-to",
    "oogamia": "o-o-ga-mia",
    "oogénesis": "o-o-gé-ne-sis",
    "oogonia": "o-o-go-nia",
    "oolítica": "o-o-lí-ti-ca",
    "oolítico": "o-o-lí-ti-co",
    "oolito": "o-o-li-to",
    "oosfera": "o-os-fe-ra",
    "oósfera": "o-ós-fe-ra",
    "opa": "o-pa",
    "opa": "o-pa",
    "opaca": "o-pa-ca",
    "opacamente": "o-pa-ca-men-te",
    "opacar": "o-pa-car",
    "opacidad": "o-pa-ci-dad",
    "opaco": "o-pa-co",
    "opada": "o-pa-da",
    "opado": "o-pa-do",
    "opal": "o-pal",
    "opalescencia": "o-pa-les-cen-cia",
    "opalescente": "o-pa-les-cen-te",
    "opalina": "o-pa-li-na",
    "opalino": "o-pa-li-no",
    "opalizar": "o-pa-li-zar",
    "ópalo": "ó-pa-lo",
    "opante": "o-pan-te",
    "oparrón": "o-pa-rrón",
    "oparrona": "o-pa-rro-na",
    "opción": "op-ción",
    "opcional": "op-cio-nal",
    "opcionalmente": "op-cio-nal-men-te",
    "opear": "o-pe-ar",
    "open": "o-pen",
    "ópera": "ó-pe-ra",
    "operable": "o-pe-ra-ble",
    "operación": "o-pe-ra-ción",
    "operacional": "o-pe-ra-cio-nal",
    "operada": "o-pe-ra-da",
    "operado": "o-pe-ra-do",
    "operador": "o-pe-ra-dor",
    "operadora": "o-pe-ra-do-ra",
    "operante": "o-pe-ran-te",
    "operar": "o-pe-rar",
    "operaria": "o-pe-ra-ria",
    "operario": "o-pe-ra-rio",
    "operática": "o-pe-rá-ti-ca",
    "operático": "o-pe-rá-ti-co",
    "operativa": "o-pe-ra-ti-va",
    "operativamente": "o-pe-ra-ti-va-men-te",
    "operatividad": "o-pe-ra-ti-vi-dad",
    "operativo": "o-pe-ra-ti-vo",
    "operatoria": "o-pe-ra-to-ria",
    "operatorio": "o-pe-ra-to-rio",
    "operculado": "o-per-cu-la-do",
    "opercular": "o-per-cu-lar",
    "opérculo": "o-pér-cu-lo",
    "opereta": "o-pe-re-ta",
    "opería": "o-pe-rí-a",
    "operista": "o-pe-ris-ta",
    "operística": "o-pe-rís-ti-ca",
    "operístico": "o-pe-rís-ti-co",
    "operosa": "o-pe-ro-sa",
    "operoso": "o-pe-ro-so",
    "opiácea": "o-piá-ce-a",
    "opiáceo": "o-piá-ce-o",
    "opiada": "o-pia-da",
    "opiado": "o-pia-do",
    "opiar": "o-piar",
    "opiata": "o-pia-ta",
    "opiato": "o-pia-to",
    "opilación": "o-pi-la-ción",
    "opilar": "o-pi-lar",
    "opilativa": "o-pi-la-ti-va",
    "opilativo": "o-pi-la-ti-vo",
    "opilión": "o-pi-lión",
    "opima": "o-pi-ma",
    "opimo": "o-pi-mo",
    "opinable": "o-pi-na-ble",
    "opinante": "o-pi-nan-te",
    "opinar": "o-pi-nar",
    "opinión": "o-pi-nión",
    "opio": "o-pio",
    "opioide": "o-pioi-de",
    "opiómana": "o-pió-ma-na",
    "opiómano": "o-pió-ma-no",
    "opípara": "o-pí-pa-ra",
    "opíparamente": "o-pí-pa-ra-men-te",
    "opíparo": "o-pí-pa-ro",
    "opistógrafo": "o-pis-tó-gra-fo",
    "opitulación": "o-pi-tu-la-ción",
    "oploteca": "o-plo-te-ca",
    "opobálsamo": "o-po-bál-sa-mo",
    "oponente": "o-po-nen-te",
    "oponer": "o-po-ner",
    "oponible": "o-po-ni-ble",
    "opopánax": "o-po-pá-nax",
    "opopónace": "o-po-pó-na-ce",
    "opopónaco": "o-po-pó-na-co",
    "oporto": "o-por-to",
    "oportuna": "o-por-tu-na",
    "oportunamente": "o-por-tu-na-men-te",
    "oportunidad": "o-por-tu-ni-dad",
    "oportunismo": "o-por-tu-nis-mo",
    "oportunista": "o-por-tu-nis-ta",
    "oportuno": "o-por-tu-no",
    "oposición": "o-po-si-ción",
    "oposicionista": "o-po-si-cio-nis-ta",
    "opositar": "o-po-si-tar",
    "opósito": "o-pó-si-to",
    "opositor": "o-po-si-tor",
    "opositora": "o-po-si-to-ra",
    "opoterapia": "o-po-te-ra-pia",
    "opoterápica": "o-po-te-rá-pi-ca",
    "opoterápico": "o-po-te-rá-pi-co",
    "opresar": "o-pre-sar",
    "opresión": "o-pre-sión",
    "opresiva": "o-pre-si-va",
    "opresivamente": "o-pre-si-va-men-te",
    "opresivo": "o-pre-si-vo",
    "opresor": "o-pre-sor",
    "opresora": "o-pre-so-ra",
    "oprimida": "o-pri-mi-da",
    "oprimido": "o-pri-mi-do",
    "oprimir": "o-pri-mir",
    "oprobiar": "o-pro-biar",
    "oprobio": "o-pro-bio",
    "oprobiosa": "o-pro-bio-sa",
    "oprobiosamente": "o-pro-bio-sa-men-te",
    "oprobioso": "o-pro-bio-so",
    "oprobrio": "o-pro-brio",
    "optación": "op-ta-ción",
    "optante": "op-tan-te",
    "optar": "op-tar",
    "optativa": "op-ta-ti-va",
    "optativamente": "op-ta-ti-va-men-te",
    "optativo": "op-ta-ti-vo",
    "óptica": "óp-ti-ca",
    "óptico": "óp-ti-co",
    "óptima": "óp-ti-ma",
    "optimación": "op-ti-ma-ción",
    "óptimamente": "óp-ti-ma-men-te",
    "optimar": "op-ti-mar",
    "optimate": "op-ti-ma-te",
    "optimismo": "op-ti-mis-mo",
    "optimista": "op-ti-mis-ta",
    "optimización": "op-ti-mi-za-ción",
    "optimizar": "op-ti-mi-zar",
    "óptimo": "óp-ti-mo",
    "optometría": "op-to-me-trí-a",
    "optómetro": "op-tó-me-tro",
    "opuesta": "o-pues-ta",
    "opuestamente": "o-pues-ta-men-te",
    "opuesto": "o-pues-to",
    "opugnación": "o-pug-na-ción",
    "opugnador": "o-pug-na-dor",
    "opugnar": "o-pug-nar",
    "opulencia": "o-pu-len-cia",
    "opulenta": "o-pu-len-ta",
    "opulentamente": "o-pu-len-ta-men-te",
    "opulento": "o-pu-len-to",
    "opuncia": "o-pun-cia",
    "opus": "o-pus",
    "opúsculo": "o-pús-cu-lo",
    "oque": "o-que",
    "oquedad": "o-que-dad",
    "oquedal": "o-que-dal",
    "oqueruela": "o-que-rue-la",
    "ora": "o-ra",
    "oración": "o-ra-ción",
    "oracional": "o-ra-cio-nal",
    "oracionera": "o-ra-cio-ne-ra",
    "oracionero": "o-ra-cio-ne-ro",
    "oráculo": "o-rá-cu-lo",
    "orador": "o-ra-dor",
    "oradora": "o-ra-do-ra",
    "oraje": "o-ra-je",
    "oral": "o-ral",
    "órale": "ó-ra-le",
    "oralidad": "o-ra-li-dad",
    "oralmente": "o-ral-men-te",
    "oranés": "o-ra-nés",
    "oranesa": "o-ra-ne-sa",
    "orangista": "o-ran-gis-ta",
    "orangután": "o-ran-gu-tán",
    "orante": "o-ran-te",
    "orar": "o-rar",
    "orario": "o-ra-rio",
    "orate": "o-ra-te",
    "orático": "o-rá-ti-co",
    "oratoria": "o-ra-to-ria",
    "oratoriamente": "o-ra-to-ria-men-te",
    "oratoriano": "o-ra-to-ria-no",
    "oratorio": "o-ra-to-rio",
    "orbe": "or-be",
    "orbedad": "or-be-dad",
    "orbicular": "or-bi-cu-lar",
    "orbicularmente": "or-bi-cu-lar-men-te",
    "órbita": "ór-bi-ta",
    "orbital": "or-bi-tal",
    "orbitar": "or-bi-tar",
    "orbitaria": "or-bi-ta-ria",
    "orbitario": "or-bi-ta-rio",
    "orca": "or-ca",
    "orcaneta": "or-ca-ne-ta",
    "orcheliano": "or-che-lia-no",
    "orchilla": "or-chi-lla",
    "orcina": "or-ci-na",
    "orco": "or-co",
    "órdago": "ór-da-go",
    "ordalía": "or-da-lí-a",
    "orden": "or-den",
    "ordeña": "or-de-ña",
    "ordenación": "or-de-na-ción",
    "ordenada": "or-de-na-da",
    "ordenadamente": "or-de-na-da-men-te",
    "ordeñadero": "or-de-ña-de-ro",
    "ordenado": "or-de-na-do",
    "ordenador": "or-de-na-dor",
    "ordeñador": "or-de-ña-dor",
    "ordenadora": "or-de-na-do-ra",
    "ordeñadora": "or-de-ña-do-ra",
    "ordenamiento": "or-de-na-mien-to",
    "ordenancismo": "or-de-nan-cis-mo",
    "ordenancista": "or-de-nan-cis-ta",
    "ordenando": "or-de-nan-do",
    "ordenante": "or-de-nan-te",
    "ordenanza": "or-de-nan-za",
    "ordenar": "or-de-nar",
    "ordeñar": "or-de-ñar",
    "ordenata": "or-de-na-ta",
    "ordeñe": "or-de-ñe",
    "ordeño": "or-de-ño",
    "órdiga": "ór-di-ga",
    "ordinación": "or-di-na-ción",
    "ordinal": "or-di-nal",
    "ordinar": "or-di-nar",
    "ordinaria": "or-di-na-ria",
    "ordinariamente": "or-di-na-ria-men-te",
    "ordinariez": "or-di-na-riez",
    "ordinario": "or-di-na-rio",
    "ordinativa": "or-di-na-ti-va",
    "ordinativo": "or-di-na-ti-vo",
    "ordo": "or-do",
    "ordovícico": "or-do-ví-ci-co",
    "orduña": "or-du-ña",
    "orea": "o-re-a",
    "oréada": "o-ré-a-da",
    "oréade": "o-ré-a-de",
    "orear": "o-re-ar",
    "orebce": "o-reb-ce",
    "orégano": "o-ré-ga-no",
    "oreja": "o-re-ja",
    "orejana": "o-re-ja-na",
    "orejano": "o-re-ja-no",
    "orejeada": "o-re-je-a-da",
    "orejeado": "o-re-je-a-do",
    "orejear": "o-re-je-ar",
    "orejera": "o-re-je-ra",
    "orejero": "o-re-je-ro",
    "orejisana": "o-re-ji-sa-na",
    "orejisano": "o-re-ji-sa-no",
    "orejismo": "o-re-jis-mo",
    "orejón": "o-re-jón",
    "orejona": "o-re-jo-na",
    "orejuda": "o-re-ju-da",
    "orejudo": "o-re-ju-do",
    "orejuela": "o-re-jue-la",
    "orellana": "o-re-lla-na",
    "orellanense": "o-re-lla-nen-se",
    "orellano": "o-re-lla-no",
    "orenga": "o-ren-ga",
    "orensana": "o-ren-sa-na",
    "orensano": "o-ren-sa-no",
    "orense": "o-ren-se",
    "orenza": "o-ren-za",
    "oreo": "o-re-o",
    "oreoselino": "o-re-o-se-li-no",
    "orero": "o-re-ro",
    "oretana": "o-re-ta-na",
    "oretano": "o-re-ta-no",
    "orfanato": "or-fa-na-to",
    "orfanatorio": "or-fa-na-to-rio",
    "orfandad": "or-fan-dad",
    "orfanidad": "or-fa-ni-dad",
    "orfebre": "or-fe-bre",
    "orfebrería": "or-fe-bre-rí-a",
    "orfelinato": "or-fe-li-na-to",
    "orfeón": "or-fe-ón",
    "orfeonista": "or-fe-o-nis-ta",
    "órfica": "ór-fi-ca",
    "órfico": "ór-fi-co",
    "orfismo": "or-fis-mo",
    "orfo": "or-fo",
    "orfre": "or-fre",
    "organdí": "or-gan-dí",
    "organera": "or-ga-ne-ra",
    "organero": "or-ga-ne-ro",
    "orgánica": "or-gá-ni-ca",
    "orgánicamente": "or-gá-ni-ca-men-te",
    "organicismo": "or-ga-ni-cis-mo",
    "organicista": "or-ga-ni-cis-ta",
    "orgánico": "or-gá-ni-co",
    "organigrama": "or-ga-ni-gra-ma",
    "organillera": "or-ga-ni-lle-ra",
    "organillero": "or-ga-ni-lle-ro",
    "organillo": "or-ga-ni-llo",
    "organismo": "or-ga-nis-mo",
    "organista": "or-ga-nis-ta",
    "organístico": "or-ga-nís-ti-co",
    "organización": "or-ga-ni-za-ción",
    "organizacional": "or-ga-ni-za-cio-nal",
    "organizada": "or-ga-ni-za-da",
    "organizado": "or-ga-ni-za-do",
    "organizador": "or-ga-ni-za-dor",
    "organizadora": "or-ga-ni-za-do-ra",
    "organizar": "or-ga-ni-zar",
    "organizativo": "or-ga-ni-za-ti-vo",
    "órgano": "ór-ga-no",
    "organogénesis": "or-ga-no-gé-ne-sis",
    "organogenia": "or-ga-no-ge-nia",
    "organografía": "or-ga-no-gra-fí-a",
    "organográfica": "or-ga-no-grá-fi-ca",
    "organográfico": "or-ga-no-grá-fi-co",
    "organoléptico": "or-ga-no-lép-ti-co",
    "organología": "or-ga-no-lo-gí-a",
    "orgánulo": "or-gá-nu-lo",
    "organza": "or-gan-za",
    "orgasmo": "or-gas-mo",
    "orgía": "or-gí-a",
    "orgiástica": "or-giás-ti-ca",
    "orgiástico": "or-giás-ti-co",
    "orgivense": "or-gi-ven-se",
    "orgullecer": "or-gu-lle-cer",
    "orgulleza": "or-gu-lle-za",
    "orgullo": "or-gu-llo",
    "orgullosa": "or-gu-llo-sa",
    "orgullosamente": "or-gu-llo-sa-men-te",
    "orgulloso": "or-gu-llo-so",
    "orí": "o-rí",
    "oribe": "o-ri-be",
    "orientable": "o-rien-ta-ble",
    "orientación": "o-rien-ta-ción",
    "orientador": "o-rien-ta-dor",
    "orientadora": "o-rien-ta-do-ra",
    "oriental": "o-rien-tal",
    "orientalismo": "o-rien-ta-lis-mo",
    "orientalista": "o-rien-ta-lis-ta",
    "orientalización": "o-rien-ta-li-za-ción",
    "orientalizante": "o-rien-ta-li-zan-te",
    "orientalizar": "o-rien-ta-li-zar",
    "orientana": "o-rien-ta-na",
    "orientano": "o-rien-ta-no",
    "orientar": "o-rien-tar",
    "orientativo": "o-rien-ta-ti-vo",
    "oriente": "o-rien-te",
    "orificación": "o-ri-fi-ca-ción",
    "orificador": "o-ri-fi-ca-dor",
    "orificar": "o-ri-fi-car",
    "orífice": "o-rí-fi-ce",
    "orificia": "o-ri-fi-cia",
    "orificio": "o-ri-fi-cio",
    "oriflama": "o-ri-fla-ma",
    "orifrés": "o-ri-frés",
    "origami": "o-ri-ga-mi",
    "origen": "o-ri-gen",
    "origenismo": "o-ri-ge-nis-mo",
    "origenista": "o-ri-ge-nis-ta",
    "original": "o-ri-gi-nal",
    "originalidad": "o-ri-gi-na-li-dad",
    "originalmente": "o-ri-gi-nal-men-te",
    "originar": "o-ri-gi-nar",
    "originaria": "o-ri-gi-na-ria",
    "originariamente": "o-ri-gi-na-ria-men-te",
    "originario": "o-ri-gi-na-rio",
    "orilla": "o-ri-lla",
    "orillar": "o-ri-llar",
    "orillera": "o-ri-lle-ra",
    "orillero": "o-ri-lle-ro",
    "orillo": "o-ri-llo",
    "orín": "o-rín",
    "orina": "o-ri-na",
    "orinadera": "o-ri-na-de-ra",
    "orinal": "o-ri-nal",
    "orinar": "o-ri-nar",
    "orinecer": "o-ri-ne-cer",
    "orinienta": "o-ri-nien-ta",
    "oriniento": "o-ri-nien-to",
    "orinque": "o-rin-que",
    "oriol": "o-riol",
    "oriolana": "o-rio-la-na",
    "oriolano": "o-rio-la-no",
    "oripié": "o-ri-pié",
    "oripopo": "o-ri-po-po",
    "oriunda": "o-riun-da",
    "oriundez": "o-riun-dez",
    "oriundo": "o-riun-do",
    "orive": "o-ri-ve",
    "orla": "or-la",
    "orlador": "or-la-dor",
    "orladora": "or-la-do-ra",
    "orladura": "or-la-du-ra",
    "orlar": "or-lar",
    "orleanista": "or-le-a-nis-ta",
    "orlo": "or-lo",
    "orlón": "or-lón",
    "ormesí": "or-me-sí",
    "ormino": "or-mi-no",
    "ornadamente": "or-na-da-men-te",
    "ornamentación": "or-na-men-ta-ción",
    "ornamental": "or-na-men-tal",
    "ornamentar": "or-na-men-tar",
    "ornamento": "or-na-men-to",
    "ornar": "or-nar",
    "ornato": "or-na-to",
    "ornear": "or-ne-ar",
    "ornitodelfa": "or-ni-to-del-fa",
    "ornitodelfo": "or-ni-to-del-fo",
    "ornitóloga": "or-ni-tó-lo-ga",
    "ornitología": "or-ni-to-lo-gí-a",
    "ornitológica": "or-ni-to-ló-gi-ca",
    "ornitológico": "or-ni-to-ló-gi-co",
    "ornitólogo": "or-ni-tó-lo-go",
    "ornitomancía": "or-ni-to-man-cí-a",
    "ornitomancia": "or-ni-to-man-cia",
    "ornitóptero": "or-ni-tóp-te-ro",
    "ornitorrinco": "or-ni-to-rrin-co",
    "ornitura": "or-ni-tu-ra",
    "oro": "o-ro",
    "orobanca": "o-ro-ban-ca",
    "orobancácea": "o-ro-ban-cá-ce-a",
    "orobancáceo": "o-ro-ban-cá-ce-o",
    "orobias": "o-ro-bias",
    "orogénesis": "o-ro-gé-ne-sis",
    "orogenia": "o-ro-ge-nia",
    "orogénica": "o-ro-gé-ni-ca",
    "orogénico": "o-ro-gé-ni-co",
    "orografía": "o-ro-gra-fí-a",
    "orográfica": "o-ro-grá-fi-ca",
    "orográfico": "o-ro-grá-fi-co",
    "orón": "o-rón",
    "oronda": "o-ron-da",
    "orondada": "o-ron-da-da",
    "orondado": "o-ron-da-do",
    "orondadura": "o-ron-da-du-ra",
    "orondo": "o-ron-do",
    "oronimia": "o-ro-ni-mia",
    "oronímico": "o-ro-ní-mi-co",
    "orónimo": "o-ró-ni-mo",
    "oronja": "o-ron-ja",
    "oropel": "o-ro-pel",
    "oropelero": "o-ro-pe-le-ro",
    "oropéndola": "o-ro-pén-do-la",
    "oropesa": "o-ro-pe-sa",
    "oropimente": "o-ro-pi-men-te",
    "oroya": "o-ro-ya",
    "oroyina": "o-ro-yi-na",
    "oroyino": "o-ro-yi-no",
    "orozuz": "o-ro-zuz",
    "orquesta": "or-ques-ta",
    "orquestación": "or-ques-ta-ción",
    "orquestador": "or-ques-ta-dor",
    "orquestal": "or-ques-tal",
    "orquestar": "or-ques-tar",
    "orquestina": "or-ques-ti-na",
    "orquestra": "or-ques-tra",
    "orquidácea": "or-qui-dá-ce-a",
    "orquidáceas": "or-qui-dá-ce-as",
    "orquidáceo": "or-qui-dá-ce-o",
    "orquídea": "or-quí-de-a",
    "orquídeas": "or-quí-de-as",
    "orquídeo": "or-quí-de-o",
    "orquitis": "or-qui-tis",
    "órsay": "ór-say",
    "ortega": "or-te-ga",
    "orteguiana": "or-te-guia-na",
    "orteguiano": "or-te-guia-no",
    "ortiga": "or-ti-ga",
    "ortigal": "or-ti-gal",
    "ortiva": "or-ti-va",
    "ortivo": "or-ti-vo",
    "orto": "or-to",
    "ortocentro": "or-to-cen-tro",
    "ortoclasa": "or-to-cla-sa",
    "ortocromático": "or-to-cro-má-ti-co",
    "ortodoncia": "or-to-don-cia",
    "ortodoncista": "or-to-don-cis-ta",
    "ortodoxa": "or-to-do-xa",
    "ortodoxia": "or-to-do-xia",
    "ortodoxo": "or-to-do-xo",
    "ortodromia": "or-to-dro-mia",
    "ortodrómica": "or-to-dró-mi-ca",
    "ortodrómico": "or-to-dró-mi-co",
    "ortoedro": "or-to-e-dro",
    "ortoepía": "or-to-e-pí-a",
    "ortofonía": "or-to-fo-ní-a",
    "ortofónico": "or-to-fó-ni-co",
    "ortofonista": "or-to-fo-nis-ta",
    "ortogénesis": "or-to-gé-ne-sis",
    "ortogonal": "or-to-go-nal",
    "ortogonalidad": "or-to-go-na-li-dad",
    "ortogonio": "or-to-go-nio",
    "ortogradismo": "or-to-gra-dis-mo",
    "ortógrafa": "or-tó-gra-fa",
    "ortografía": "or-to-gra-fí-a",
    "ortográfica": "or-to-grá-fi-ca",
    "ortográficamente": "or-to-grá-fi-ca-men-te",
    "ortográfico": "or-to-grá-fi-co",
    "ortógrafo": "or-tó-gra-fo",
    "ortóloga": "or-tó-lo-ga",
    "ortología": "or-to-lo-gí-a",
    "ortológica": "or-to-ló-gi-ca",
    "ortológico": "or-to-ló-gi-co",
    "ortólogo": "or-tó-lo-go",
    "ortopantomografía": "or-to-pan-to-mo-gra-fí-a",
    "ortopeda": "or-to-pe-da",
    "ortopedia": "or-to-pe-dia",
    "ortopédica": "or-to-pé-di-ca",
    "ortopédico": "or-to-pé-di-co",
    "ortopedista": "or-to-pe-dis-ta",
    "ortoplastia": "or-to-plas-tia",
    "ortóptero": "or-tóp-te-ro",
    "ortosa": "or-to-sa",
    "ortotipografía": "or-to-ti-po-gra-fí-a",
    "ortotipográfico": "or-to-ti-po-grá-fi-co",
    "oruga": "o-ru-ga",
    "orujo": "o-ru-jo",
    "orureña": "o-ru-re-ña",
    "orureño": "o-ru-re-ño",
    "orvallar": "or-va-llar",
    "orvalle": "or-va-lle",
    "orvallo": "or-va-llo",
    "orza": "or-za",
    "orzaga": "or-za-ga",
    "orzar": "or-zar",
    "orzaya": "or-za-ya",
    "orzoyo": "or-zo-yo",
    "orzuelo": "or-zue-lo",
    "osa": "o-sa",
    "osada": "o-sa-da",
    "osadamente": "o-sa-da-men-te",
    "osadía": "o-sa-dí-a",
    "osado": "o-sa-do",
    "osambre": "o-sam-bre",
    "osamenta": "o-sa-men-ta",
    "osar": "o-sar",
    "osario": "o-sa-rio",
    "osca": "os-ca",
    "óscar": "ós-car",
    "oscense": "os-cen-se",
    "oscilación": "os-ci-la-ción",
    "oscilador": "os-ci-la-dor",
    "oscilante": "os-ci-lan-te",
    "oscilar": "os-ci-lar",
    "oscilatoria": "os-ci-la-to-ria",
    "oscilatorio": "os-ci-la-to-rio",
    "oscilógrafo": "os-ci-ló-gra-fo",
    "oscilograma": "os-ci-lo-gra-ma",
    "osciloscopio": "os-ci-los-co-pio",
    "oscitancia": "os-ci-tan-cia",
    "osco": "os-co",
    "osculatriz": "os-cu-la-triz",
    "ósculo": "ós-cu-lo",
    "oscura": "os-cu-ra",
    "oscuramente": "os-cu-ra-men-te",
    "oscurana": "os-cu-ra-na",
    "oscurantismo": "os-cu-ran-tis-mo",
    "oscurantista": "os-cu-ran-tis-ta",
    "oscurecer": "os-cu-re-cer",
    "oscurecimiento": "os-cu-re-ci-mien-to",
    "oscuridad": "os-cu-ri-dad",
    "oscuro": "os-cu-ro",
    "ósea": "ó-se-a",
    "osear": "o-se-ar",
    "óseo": "ó-se-o",
    "osera": "o-se-ra",
    "osería": "o-se-rí-a",
    "osero": "o-se-ro",
    "oseta": "o-se-ta",
    "osezno": "o-sez-no",
    "osezuelo": "o-se-zue-lo",
    "osiánica": "o-siá-ni-ca",
    "osiánico": "o-siá-ni-co",
    "osificación": "o-si-fi-ca-ción",
    "osificar": "o-si-fi-car",
    "osificarse": "o-si-fi-car-se",
    "osífraga": "o-sí-fra-ga",
    "osífrago": "o-sí-fra-go",
    "osmanlí": "os-man-lí",
    "osmazomo": "os-ma-zo-mo",
    "osmio": "os-mio",
    "osmómetro": "os-mó-me-tro",
    "ósmosis": "ós-mo-sis",
    "osmótica": "os-mó-ti-ca",
    "osmótico": "os-mó-ti-co",
    "oso": "o-so",
    "osobuco": "o-so-bu-co",
    "osornina": "o-sor-ni-na",
    "osornino": "o-sor-ni-no",
    "ososa": "o-so-sa",
    "ososo": "o-so-so",
    "ossobuco": "os-so-bu-co",
    "osta": "os-ta",
    "ostaga": "os-ta-ga",
    "oste": "os-te",
    "ostealgia": "os-te-al-gia",
    "osteíctio": "os-te-íc-tio",
    "osteína": "os-te-í-na",
    "osteítis": "os-te-í-tis",
    "ostensible": "os-ten-si-ble",
    "ostensiblemente": "os-ten-si-ble-men-te",
    "ostensión": "os-ten-sión",
    "ostensiva": "os-ten-si-va",
    "ostensivo": "os-ten-si-vo",
    "ostensorio": "os-ten-so-rio",
    "ostentación": "os-ten-ta-ción",
    "ostentador": "os-ten-ta-dor",
    "ostentadora": "os-ten-ta-do-ra",
    "ostentar": "os-ten-tar",
    "ostentativa": "os-ten-ta-ti-va",
    "ostentativo": "os-ten-ta-ti-vo",
    "ostento": "os-ten-to",
    "ostentóreo": "os-ten-tó-re-o",
    "ostentosa": "os-ten-to-sa",
    "ostentosamente": "os-ten-to-sa-men-te",
    "ostentosidad": "os-ten-to-si-dad",
    "ostentoso": "os-ten-to-so",
    "osteoblasto": "os-te-o-blas-to",
    "osteoclasto": "os-te-o-clas-to",
    "osteolito": "os-te-o-li-to",
    "osteóloga": "os-te-ó-lo-ga",
    "osteología": "os-te-o-lo-gí-a",
    "osteológica": "os-te-o-ló-gi-ca",
    "osteológico": "os-te-o-ló-gi-co",
    "osteólogo": "os-te-ó-lo-go",
    "osteoma": "os-te-o-ma",
    "osteomalacia": "os-te-o-ma-la-cia",
    "osteomielitis": "os-te-o-mie-li-tis",
    "osteópata": "os-te-ó-pa-ta",
    "osteopatía": "os-te-o-pa-tí-a",
    "osteoplastia": "os-te-o-plas-tia",
    "osteoporosis": "os-te-o-po-ro-sis",
    "osteoporótico": "os-te-o-po-ró-ti-co",
    "osteosarcoma": "os-te-o-sar-co-ma",
    "osteotomía": "os-te-o-to-mí-a",
    "ostero": "os-te-ro",
    "ostia": "os-tia",
    "ostial": "os-tial",
    "ostiariado": "os-tia-ria-do",
    "ostiario": "os-tia-rio",
    "ostilla": "os-ti-lla",
    "ostiolo": "os-tio-lo",
    "ostión": "os-tión",
    "ostionería": "os-tio-ne-rí-a",
    "ostra": "os-tra",
    "ostracismo": "os-tra-cis-mo",
    "ostragada": "os-tra-ga-da",
    "ostragado": "os-tra-ga-do",
    "ostral": "os-tral",
    "ostras": "os-tras",
    "ostrera": "os-tre-ra",
    "ostrero": "os-tre-ro",
    "ostrícola": "os-trí-co-la",
    "ostricultor": "os-tri-cul-tor",
    "ostricultora": "os-tri-cul-to-ra",
    "ostricultura": "os-tri-cul-tu-ra",
    "ostrífera": "os-trí-fe-ra",
    "ostrífero": "os-trí-fe-ro",
    "ostro": "os-tro",
    "ostrogoda": "os-tro-go-da",
    "ostrogodo": "os-tro-go-do",
    "ostrón": "os-trón",
    "ostugo": "os-tu-go",
    "osuda": "o-su-da",
    "osudo": "o-su-do",
    "osuna": "o-su-na",
    "osuno": "o-su-no",
    "otacusta": "o-ta-cus-ta",
    "otacústica": "o-ta-cús-ti-ca",
    "otacústico": "o-ta-cús-ti-co",
    "otalgia": "o-tal-gia",
    "otar": "o-tar",
    "otaria": "o-ta-ria",
    "otárido": "o-tá-ri-do",
    "otario": "o-ta-rio",
    "otatal": "o-ta-tal",
    "otate": "o-ta-te",
    "otatera": "o-ta-te-ra",
    "otavaleña": "o-ta-va-le-ña",
    "otavaleño": "o-ta-va-le-ño",
    "oteador": "o-te-a-dor",
    "oteadora": "o-te-a-do-ra",
    "otear": "o-te-ar",
    "otelo": "o-te-lo",
    "otero": "o-te-ro",
    "otilar": "o-ti-lar",
    "otitis": "o-ti-tis",
    "oto": "o-to",
    "otoba": "o-to-ba",
    "otóloga": "o-tó-lo-ga",
    "otología": "o-to-lo-gí-a",
    "otológica": "o-to-ló-gi-ca",
    "otológico": "o-to-ló-gi-co",
    "otólogo": "o-tó-lo-go",
    "otomaco": "o-to-ma-co",
    "otomán": "o-to-mán",
    "otomana": "o-to-ma-na",
    "otomano": "o-to-ma-no",
    "otomía": "o-to-mí-a",
    "otompaneco": "o-tom-pa-ne-co",
    "otoñada": "o-to-ña-da",
    "otoñal": "o-to-ñal",
    "otoñar": "o-to-ñar",
    "otoñiza": "o-to-ñi-za",
    "otoñizo": "o-to-ñi-zo",
    "otoño": "o-to-ño",
    "otorgadera": "o-tor-ga-de-ra",
    "otorgadero": "o-tor-ga-de-ro",
    "otorgador": "o-tor-ga-dor",
    "otorgadora": "o-tor-ga-do-ra",
    "otorgamiento": "o-tor-ga-mien-to",
    "otorgante": "o-tor-gan-te",
    "otorgar": "o-tor-gar",
    "otorgo": "o-tor-go",
    "otorragia": "o-to-rra-gia",
    "otorrea": "o-to-rre-a",
    "otorrino": "o-to-rri-no",
    "otorrinolaringóloga": "o-to-rri-no-la-rin-gó-lo-ga",
    "otorrinolaringología": "o-to-rri-no-la-rin-go-lo-gí-a",
    "otorrinolaringólogo": "o-to-rri-no-la-rin-gó-lo-go",
    "otosclerosis": "o-tos-cle-ro-sis",
    "otoscopia": "o-tos-co-pia",
    "otoscopio": "o-tos-co-pio",
    "otra": "o-tra",
    "otramente": "o-tra-men-te",
    "otraño": "o-tra-ño",
    "otre": "o-tre",
    "otredad": "o-tre-dad",
    "otri": "o-tri",
    "otro": "o-tro",
    "otrora": "o-tro-ra",
    "otrosí": "o-tro-sí",
    "otubre": "o-tu-bre",
    "otumbeña": "o-tum-be-ña",
    "otumbeño": "o-tum-be-ño",
    "ouija": "oui-ja",
    "output": "out-put",
    "outsider": "out-si-der",
    "ouzo": "ou-zo",
    "ova": "o-va",
    "ovación": "o-va-ción",
    "ovacionar": "o-va-cio-nar",
    "ovada": "o-va-da",
    "ovado": "o-va-do",
    "oval": "o-val",
    "ovalada": "o-va-la-da",
    "ovalado": "o-va-la-do",
    "ovalar": "o-va-lar",
    "ovallina": "o-va-lli-na",
    "ovallino": "o-va-lli-no",
    "óvalo": "ó-va-lo",
    "ovante": "o-van-te",
    "ovar": "o-var",
    "ovárica": "o-vá-ri-ca",
    "ovárico": "o-vá-ri-co",
    "ovariectomía": "o-va-riec-to-mí-a",
    "ovario": "o-va-rio",
    "ovariotomía": "o-va-rio-to-mí-a",
    "ovaritis": "o-va-ri-tis",
    "ovas": "o-vas",
    "oveja": "o-ve-ja",
    "ovejera": "o-ve-je-ra",
    "ovejería": "o-ve-je-rí-a",
    "ovejero": "o-ve-je-ro",
    "ovejo": "o-ve-jo",
    "ovejuna": "o-ve-ju-na",
    "ovejuno": "o-ve-ju-no",
    "overa": "o-ve-ra",
    "overbooking": "o-ver-bo-o-king",
    "overlista": "o-ver-lis-ta",
    "overo": "o-ve-ro",
    "overol": "o-ve-rol",
    "ovetense": "o-ve-ten-se",
    "ovia": "o-via",
    "ovicida": "o-vi-ci-da",
    "ovidiana": "o-vi-dia-na",
    "ovidiano": "o-vi-dia-no",
    "óvido": "ó-vi-do",
    "oviducto": "o-vi-duc-to",
    "oviforme": "o-vi-for-me",
    "ovil": "o-vil",
    "ovillado": "o-vi-lla-do",
    "ovilladora": "o-vi-lla-do-ra",
    "ovillar": "o-vi-llar",
    "ovillejo": "o-vi-lle-jo",
    "ovillo": "o-vi-llo",
    "ovina": "o-vi-na",
    "ovino": "o-vi-no",
    "ovio": "o-vio",
    "ovípara": "o-ví-pa-ra",
    "ovíparo": "o-ví-pa-ro",
    "oviscapto": "o-vis-cap-to",
    "ovni": "ov-ni",
    "ovo": "o-vo",
    "ovoalbúmina": "o-vo-al-bú-mi-na",
    "ovocito": "o-vo-ci-to",
    "ovogénesis": "o-vo-gé-ne-sis",
    "ovogonia": "o-vo-go-nia",
    "ovoide": "o-voi-de",
    "ovoidea": "o-voi-de-a",
    "ovoideo": "o-voi-de-o",
    "ovolacto": "o-vo-lac-to",
    "óvolo": "ó-vo-lo",
    "ovopositor": "o-vo-po-si-tor",
    "ovoproducto": "o-vo-pro-duc-to",
    "ovosa": "o-vo-sa",
    "ovoso": "o-vo-so",
    "ovovivípara": "o-vo-vi-ví-pa-ra",
    "ovovivíparo": "o-vo-vi-ví-pa-ro",
    "ovulación": "o-vu-la-ción",
    "ovular": "o-vu-lar",
    "ovulatorio": "o-vu-la-to-rio",
    "óvulo": "ó-vu-lo",
    "oxácido": "o-xá-ci-do",
    "oxalato": "o-xa-la-to",
    "oxálica": "o-xá-li-ca",
    "oxálico": "o-xá-li-co",
    "oxalidácea": "o-xa-li-dá-ce-a",
    "oxalidáceo": "o-xa-li-dá-ce-o",
    "oxalídea": "o-xa-lí-de-a",
    "oxalídeo": "o-xa-lí-de-o",
    "oxalme": "o-xal-me",
    "oxe": "o-xe",
    "oxear": "o-xe-ar",
    "oxiacanta": "o-xia-can-ta",
    "oxiacetilénico": "o-xia-ce-ti-lé-ni-co",
    "oxiácido": "o-xiá-ci-do",
    "oxicorte": "o-xi-cor-te",
    "oxidable": "o-xi-da-ble",
    "oxidación": "o-xi-da-ción",
    "oxidante": "o-xi-dan-te",
    "oxidar": "o-xi-dar",
    "óxido": "ó-xi-do",
    "oxidrilo": "o-xi-dri-lo",
    "oxigenación": "o-xi-ge-na-ción",
    "oxigenada": "o-xi-ge-na-da",
    "oxigenado": "o-xi-ge-na-do",
    "oxigenar": "o-xi-ge-nar",
    "oxígeno": "o-xí-ge-no",
    "oxigenoterapia": "o-xi-ge-no-te-ra-pia",
    "oxigonio": "o-xi-go-nio",
    "oxihemoglobina": "o-xihe-mo-glo-bi-na",
    "oximel": "o-xi-mel",
    "oximiel": "o-xi-miel",
    "oxímoron": "o-xí-mo-ron",
    "oxipétalo": "o-xi-pé-ta-lo",
    "oxitetraciclina": "o-xi-te-tra-ci-cli-na",
    "oxitócico": "o-xi-tó-ci-co",
    "oxitocina": "o-xi-to-ci-na",
    "oxítona": "o-xí-to-na",
    "oxítono": "o-xí-to-no",
    "oxiuro": "o-xiu-ro",
    "oxizacre": "o-xi-za-cre",
    "oxoácido": "o-xo-á-ci-do",
    "oxoniense": "o-xo-nien-se",
    "oxte": "ox-te",
    "oyamel": "o-ya-mel",
    "oye": "o-ye",
    "oyente": "o-yen-te",
    "ozena": "o-ze-na",
    "ozona": "o-zo-na",
    "ozonizar": "o-zo-ni-zar",
    "ozono": "o-zo-no",
    "ozonómetro": "o-zo-nó-me-tro",
    "ozonosfera": "o-zo-nos-fe-ra",
    "ozonósfera": "o-zo-nós-fe-ra",
    "ozonoterapia": "o-zo-no-te-ra-pia",
    "pabellón": "pa-be-llón",
    "pabilo": "pa-bi-lo",
    "pábilo": "pá-bi-lo",
    "pabilón": "pa-bi-lón",
    "pabilosa": "pa-bi-lo-sa",
    "pabiloso": "pa-bi-lo-so",
    "pablar": "pa-blar",
    "pablo": "pa-blo",
    "pábulo": "pá-bu-lo",
    "paca": "pa-ca",
    "pacada": "pa-ca-da",
    "pacado": "pa-ca-do",
    "pacae": "pa-ca-e",
    "pacana": "pa-ca-na",
    "pacano": "pa-ca-no",
    "pacata": "pa-ca-ta",
    "pacatería": "pa-ca-te-rí-a",
    "pacato": "pa-ca-to",
    "pacay": "pa-cay",
    "pacaya": "pa-ca-ya",
    "pacayal": "pa-ca-yal",
    "pacayar": "pa-ca-yar",
    "paccionar": "pac-cio-nar",
    "pacedera": "pa-ce-de-ra",
    "pacedero": "pa-ce-de-ro",
    "pacedura": "pa-ce-du-ra",
    "paceña": "pa-ce-ña",
    "paceño": "pa-ce-ño",
    "pacense": "pa-cen-se",
    "pacer": "pa-cer",
    "pacha": "pa-cha",
    "pachá": "pa-chá",
    "pachaca": "pa-cha-ca",
    "pachacha": "pa-cha-cha",
    "pachacho": "pa-cha-cho",
    "pachaco": "pa-cha-co",
    "pachamanca": "pa-cha-man-ca",
    "pachanga": "pa-chan-ga",
    "pachango": "pa-chan-go",
    "pachangón": "pa-chan-gón",
    "pachanguear": "pa-chan-gue-ar",
    "pachanguero": "pa-chan-gue-ro",
    "pachanguita": "pa-chan-gui-ta",
    "pacharán": "pa-cha-rán",
    "pacheco": "pa-che-co",
    "pachiche": "pa-chi-che",
    "pachilla": "pa-chi-lla",
    "pachiquil": "pa-chi-quil",
    "pacho": "pa-cho",
    "pachocha": "pa-cho-cha",
    "pachola": "pa-cho-la",
    "pachón": "pa-chón",
    "pachona": "pa-cho-na",
    "pachorra": "pa-cho-rra",
    "pachorrear": "pa-cho-rre-ar",
    "pachorrienta": "pa-cho-rrien-ta",
    "pachorriento": "pa-cho-rrien-to",
    "pachorruda": "pa-cho-rru-da",
    "pachorrudo": "pa-cho-rru-do",
    "pachotada": "pa-cho-ta-da",
    "pachotera": "pa-cho-te-ra",
    "pachotero": "pa-cho-te-ro",
    "pachuca": "pa-chu-ca",
    "pachucada": "pa-chu-ca-da",
    "pachucha": "pa-chu-cha",
    "pachucho": "pa-chu-cho",
    "pachuco": "pa-chu-co",
    "pachuli": "pa-chu-li",
    "pachulí": "pa-chu-lí",
    "pachuquear": "pa-chu-que-ar",
    "pachuqueña": "pa-chu-que-ña",
    "pachuqueño": "pa-chu-que-ño",
    "paciencia": "pa-cien-cia",
    "paciente": "pa-cien-te",
    "pacientemente": "pa-cien-te-men-te",
    "pacienzuda": "pa-cien-zu-da",
    "pacienzudo": "pa-cien-zu-do",
    "pacífica": "pa-cí-fi-ca",
    "pacificación": "pa-ci-fi-ca-ción",
    "pacificador": "pa-ci-fi-ca-dor",
    "pacificadora": "pa-ci-fi-ca-do-ra",
    "pacíficamente": "pa-cí-fi-ca-men-te",
    "pacificar": "pa-ci-fi-car",
    "pacífico": "pa-cí-fi-co",
    "pacifismo": "pa-ci-fis-mo",
    "pacifista": "pa-ci-fis-ta",
    "pación": "pa-ción",
    "paco": "pa-co",
    "pacón": "pa-cón",
    "pacora": "pa-co-ra",
    "pacota": "pa-co-ta",
    "pacotilla": "pa-co-ti-lla",
    "pacotillera": "pa-co-ti-lle-ra",
    "pacotillero": "pa-co-ti-lle-ro",
    "pactante": "pac-tan-te",
    "pactar": "pac-tar",
    "pactismo": "pac-tis-mo",
    "pactista": "pac-tis-ta",
    "pacto": "pac-to",
    "pacú": "pa-cú",
    "pácul": "pá-cul",
    "pacumutu": "pa-cu-mu-tu",
    "pacuna": "pa-cu-na",
    "pada": "pa-da",
    "paddle": "padd-le",
    "paddock": "pad-dock",
    "padecer": "pa-de-cer",
    "padecimiento": "pa-de-ci-mien-to",
    "pádel": "pá-del",
    "padilla": "pa-di-lla",
    "padrastro": "pa-dras-tro",
    "padrazo": "pa-dra-zo",
    "padre": "pa-dre",
    "padrear": "pa-dre-ar",
    "padrejón": "pa-dre-jón",
    "padrenuestro": "pa-dre-nues-tro",
    "padrillo": "pa-dri-llo",
    "padrina": "pa-dri-na",
    "padrinaje": "pa-dri-na-je",
    "padrinazgo": "pa-dri-naz-go",
    "padrino": "pa-dri-no",
    "padrísimo": "pa-drí-si-mo",
    "padrón": "pa-drón",
    "padronero": "pa-dro-ne-ro",
    "padronés": "pa-dro-nés",
    "padronesa": "pa-dro-ne-sa",
    "padrote": "pa-dro-te",
    "padrotear": "pa-dro-te-ar",
    "paduana": "pa-dua-na",
    "paduano": "pa-dua-no",
    "paella": "pa-e-lla",
    "paellera": "pa-e-lle-ra",
    "pafia": "pa-fia",
    "pafio": "pa-fio",
    "paflón": "pa-flón",
    "paga": "pa-ga",
    "pagable": "pa-ga-ble",
    "pagadera": "pa-ga-de-ra",
    "pagadero": "pa-ga-de-ro",
    "pagado": "pa-ga-do",
    "pagador": "pa-ga-dor",
    "pagadora": "pa-ga-do-ra",
    "pagaduría": "pa-ga-du-rí-a",
    "págalo": "pá-ga-lo",
    "pagamento": "pa-ga-men-to",
    "pagamiento": "pa-ga-mien-to",
    "pagana": "pa-ga-na",
    "paganía": "pa-ga-ní-a",
    "paganini": "pa-ga-ni-ni",
    "paganismo": "pa-ga-nis-mo",
    "paganizar": "pa-ga-ni-zar",
    "pagano": "pa-ga-no",
    "pagar": "pa-gar",
    "pagaré": "pa-ga-ré",
    "pagaya": "pa-ga-ya",
    "pagaza": "pa-ga-za",
    "pagel": "pa-gel",
    "página": "pá-gi-na",
    "paginación": "pa-gi-na-ción",
    "paginante": "pa-gi-nan-te",
    "paginar": "pa-gi-nar",
    "pago": "pa-go",
    "pagoda": "pa-go-da",
    "pagote": "pa-go-te",
    "pagro": "pa-gro",
    "pagua": "pa-gua",
    "paguro": "pa-gu-ro",
    "pahua": "pa-hua",
    "pahuichi": "pa-hui-chi",
    "paico": "pai-co",
    "paidófila": "pai-dó-fi-la",
    "paidofilia": "pai-do-fi-lia",
    "paidófilo": "pai-dó-fi-lo",
    "paidología": "pai-do-lo-gí-a",
    "paidológica": "pai-do-ló-gi-ca",
    "paidológico": "pai-do-ló-gi-co",
    "paila": "pai-la",
    "pailada": "pai-la-da",
    "pailebot": "pai-le-bot",
    "pailebote": "pai-le-bo-te",
    "pailera": "pai-le-ra",
    "pailero": "pai-le-ro",
    "pailetas": "pai-le-tas",
    "pailón": "pai-lón",
    "pailona": "pai-lo-na",
    "paina": "pai-na",
    "painel": "pai-nel",
    "paipái": "pai-pái",
    "paipay": "pai-pay",
    "paipudo": "pai-pu-do",
    "pairar": "pai-rar",
    "paire": "pai-re",
    "pairo": "pai-ro",
    "país": "pa-ís",
    "paisa": "pai-sa",
    "paisaje": "pai-sa-je",
    "paisajismo": "pai-sa-jis-mo",
    "paisajista": "pai-sa-jis-ta",
    "paisajística": "pai-sa-jís-ti-ca",
    "paisajístico": "pai-sa-jís-ti-co",
    "paisana": "pai-sa-na",
    "paisanaje": "pai-sa-na-je",
    "paisano": "pai-sa-no",
    "paisista": "pai-sis-ta",
    "paiteña": "pai-te-ña",
    "paiteño": "pai-te-ño",
    "paja": "pa-ja",
    "pajada": "pa-ja-da",
    "pajado": "pa-ja-do",
    "pajar": "pa-jar",
    "pájara": "pá-ja-ra",
    "pajarear": "pa-ja-re-ar",
    "pajarel": "pa-ja-rel",
    "pajarera": "pa-ja-re-ra",
    "pajarería": "pa-ja-re-rí-a",
    "pajarero": "pa-ja-re-ro",
    "pajarete": "pa-ja-re-te",
    "pajaril": "pa-ja-ril",
    "pajarilla": "pa-ja-ri-lla",
    "pajarita": "pa-ja-ri-ta",
    "pajarito": "pa-ja-ri-to",
    "pájaro": "pá-ja-ro",
    "pajarón": "pa-ja-rón",
    "pajarona": "pa-ja-ro-na",
    "pajarota": "pa-ja-ro-ta",
    "pajarotada": "pa-ja-ro-ta-da",
    "pajarraca": "pa-ja-rra-ca",
    "pajarraco": "pa-ja-rra-co",
    "pajaza": "pa-ja-za",
    "pajazo": "pa-ja-zo",
    "paje": "pa-je",
    "pajea": "pa-je-a",
    "pajear": "pa-je-ar",
    "pajecillo": "pa-je-ci-llo",
    "pajel": "pa-jel",
    "pajera": "pa-je-ra",
    "pajería": "pa-je-rí-a",
    "pajero": "pa-je-ro",
    "pajil": "pa-jil",
    "pajilla": "pa-ji-lla",
    "pajillera": "pa-ji-lle-ra",
    "pajillero": "pa-ji-lle-ro",
    "pajista": "pa-jis-ta",
    "pajiza": "pa-ji-za",
    "pajizo": "pa-ji-zo",
    "pajo": "pa-jo",
    "pajolera": "pa-jo-le-ra",
    "pajolero": "pa-jo-le-ro",
    "pajón": "pa-jón",
    "pajonal": "pa-jo-nal",
    "pajonear": "pa-jo-ne-ar",
    "pajosa": "pa-jo-sa",
    "pajoso": "pa-jo-so",
    "pajote": "pa-jo-te",
    "pajuata": "pa-jua-ta",
    "pajuato": "pa-jua-to",
    "pajucero": "pa-ju-ce-ro",
    "pajuela": "pa-jue-la",
    "pajuerana": "pa-jue-ra-na",
    "pajuerano": "pa-jue-ra-no",
    "pajuil": "pa-juil",
    "pajuila": "pa-jui-la",
    "pajuilla": "pa-jui-lla",
    "pajuna": "pa-ju-na",
    "pajuncio": "pa-jun-cio",
    "pajuno": "pa-ju-no",
    "pajuye": "pa-ju-ye",
    "pajuz": "pa-juz",
    "pajuzo": "pa-ju-zo",
    "pakistaní": "pa-kis-ta-ní",
    "pala": "pa-la",
    "palabra": "pa-la-bra",
    "palabrada": "pa-la-bra-da",
    "palabrear": "pa-la-bre-ar",
    "palabreja": "pa-la-bre-ja",
    "palabreo": "pa-la-bre-o",
    "palabrera": "pa-la-bre-ra",
    "palabrería": "pa-la-bre-rí-a",
    "palabrerío": "pa-la-bre-rí-o",
    "palabrero": "pa-la-bre-ro",
    "palabrimujer": "pa-la-bri-mu-jer",
    "palabrista": "pa-la-bris-ta",
    "palabrita": "pa-la-bri-ta",
    "palabro": "pa-la-bro",
    "palabrón": "pa-la-brón",
    "palabrona": "pa-la-bro-na",
    "palabroso": "pa-la-bro-so",
    "palabrota": "pa-la-bro-ta",
    "palabrotera": "pa-la-bro-te-ra",
    "palabrotero": "pa-la-bro-te-ro",
    "palacete": "pa-la-ce-te",
    "palacial": "pa-la-cial",
    "palaciana": "pa-la-cia-na",
    "palaciano": "pa-la-cia-no",
    "palaciega": "pa-la-cie-ga",
    "palaciego": "pa-la-cie-go",
    "palacio": "pa-la-cio",
    "palada": "pa-la-da",
    "paladar": "pa-la-dar",
    "paladear": "pa-la-de-ar",
    "paladeo": "pa-la-de-o",
    "paladial": "pa-la-dial",
    "paladiano": "pa-la-dia-no",
    "paladín": "pa-la-dín",
    "paladina": "pa-la-di-na",
    "paladinamente": "pa-la-di-na-men-te",
    "paladino": "pa-la-di-no",
    "paladio": "pa-la-dio",
    "paladión": "pa-la-dión",
    "palado": "pa-la-do",
    "palafítico": "pa-la-fí-ti-co",
    "palafito": "pa-la-fi-to",
    "palafrén": "pa-la-frén",
    "palafrenero": "pa-la-fre-ne-ro",
    "palahierro": "pa-la-hie-rro",
    "palamallo": "pa-la-ma-llo",
    "palamenta": "pa-la-men-ta",
    "palanca": "pa-lan-ca",
    "palancada": "pa-lan-ca-da",
    "palancana": "pa-lan-ca-na",
    "palancazo": "pa-lan-ca-zo",
    "palanciana": "pa-lan-cia-na",
    "palanciano": "pa-lan-cia-no",
    "palancón": "pa-lan-cón",
    "palancona": "pa-lan-co-na",
    "palangana": "pa-lan-ga-na",
    "palanganear": "pa-lan-ga-ne-ar",
    "palanganeo": "pa-lan-ga-ne-o",
    "palanganero": "pa-lan-ga-ne-ro",
    "palangre": "pa-lan-gre",
    "palangrero": "pa-lan-gre-ro",
    "palangrismo": "pa-lan-gris-mo",
    "palangrista": "pa-lan-gris-ta",
    "palanqueada": "pa-lan-que-a-da",
    "palanqueado": "pa-lan-que-a-do",
    "palanqueador": "pa-lan-que-a-dor",
    "palanqueadora": "pa-lan-que-a-do-ra",
    "palanquear": "pa-lan-que-ar",
    "palanqueo": "pa-lan-que-o",
    "palanquera": "pa-lan-que-ra",
    "palanquero": "pa-lan-que-ro",
    "palanqueta": "pa-lan-que-ta",
    "palanquetazo": "pa-lan-que-ta-zo",
    "palanquilla": "pa-lan-qui-lla",
    "palanquín": "pa-lan-quín",
    "palapa": "pa-la-pa",
    "palar": "pa-lar",
    "palasan": "pa-la-san",
    "palastro": "pa-las-tro",
    "palatabilidad": "pa-la-ta-bi-li-dad",
    "palatal": "pa-la-tal",
    "palatalización": "pa-la-ta-li-za-ción",
    "palatalizar": "pa-la-ta-li-zar",
    "palatina": "pa-la-ti-na",
    "palatinado": "pa-la-ti-na-do",
    "palatino": "pa-la-ti-no",
    "palatograma": "pa-la-to-gra-ma",
    "palauana": "pa-laua-na",
    "palauano": "pa-laua-no",
    "palay": "pa-lay",
    "palazo": "pa-la-zo",
    "palazón": "pa-la-zón",
    "palca": "pal-ca",
    "palco": "pal-co",
    "palé": "pa-lé",
    "paleador": "pa-le-a-dor",
    "paleal": "pa-le-al",
    "palear": "pa-le-ar",
    "palencia": "pa-len-cia",
    "palencón": "pa-len-cón",
    "palenense": "pa-le-nen-se",
    "palenque": "pa-len-que",
    "palenquear": "pa-len-que-ar",
    "palense": "pa-len-se",
    "palente": "pa-len-te",
    "palentina": "pa-len-ti-na",
    "palentino": "pa-len-ti-no",
    "paleoceno": "pa-le-o-ce-no",
    "paleocristiano": "pa-le-o-cris-tia-no",
    "paleofitopatología": "pa-le-o-fi-to-pa-to-lo-gí-a",
    "paleógeno": "pa-le-ó-ge-no",
    "paleógrafa": "pa-le-ó-gra-fa",
    "paleografía": "pa-le-o-gra-fí-a",
    "paleográfica": "pa-le-o-grá-fi-ca",
    "paleográfico": "pa-le-o-grá-fi-co",
    "paleógrafo": "pa-le-ó-gra-fo",
    "paleolítica": "pa-le-o-lí-ti-ca",
    "paleolítico": "pa-le-o-lí-ti-co",
    "paleóloga": "pa-le-ó-lo-ga",
    "paleología": "pa-le-o-lo-gí-a",
    "paleólogo": "pa-le-ó-lo-go",
    "paleontografía": "pa-le-on-to-gra-fí-a",
    "paleontográfica": "pa-le-on-to-grá-fi-ca",
    "paleontográfico": "pa-le-on-to-grá-fi-co",
    "paleontóloga": "pa-le-on-tó-lo-ga",
    "paleontología": "pa-le-on-to-lo-gí-a",
    "paleontológica": "pa-le-on-to-ló-gi-ca",
    "paleontológico": "pa-le-on-to-ló-gi-co",
    "paleontólogo": "pa-le-on-tó-lo-go",
    "paleopatóloga": "pa-le-o-pa-tó-lo-ga",
    "paleopatología": "pa-le-o-pa-to-lo-gí-a",
    "paleopatológico": "pa-le-o-pa-to-ló-gi-co",
    "paleopatólogo": "pa-le-o-pa-tó-lo-go",
    "paleoterio": "pa-le-o-te-rio",
    "paleotestamentario": "pa-le-o-tes-ta-men-ta-rio",
    "paleozoica": "pa-le-o-zoi-ca",
    "paleozoico": "pa-le-o-zoi-co",
    "paleozoología": "pa-le-o-zo-o-lo-gí-a",
    "palera": "pa-le-ra",
    "palería": "pa-le-rí-a",
    "palermitana": "pa-ler-mi-ta-na",
    "palermitano": "pa-ler-mi-ta-no",
    "palero": "pa-le-ro",
    "palestina": "pa-les-ti-na",
    "palestino": "pa-les-ti-no",
    "palestra": "pa-les-tra",
    "paléstrica": "pa-lés-tri-ca",
    "paléstrico": "pa-lés-tri-co",
    "palestrita": "pa-les-tri-ta",
    "palet": "pa-let",
    "paleta": "pa-le-ta",
    "paletada": "pa-le-ta-da",
    "paletazo": "pa-le-ta-zo",
    "paleteada": "pa-le-te-a-da",
    "paleteado": "pa-le-te-a-do",
    "paletear": "pa-le-te-ar",
    "paleteo": "pa-le-te-o",
    "paletera": "pa-le-te-ra",
    "paletería": "pa-le-te-rí-a",
    "paletero": "pa-le-te-ro",
    "paletica": "pa-le-ti-ca",
    "paletilla": "pa-le-ti-lla",
    "paletín": "pa-le-tín",
    "paleto": "pa-le-to",
    "paletó": "pa-le-tó",
    "paletón": "pa-le-tón",
    "paletoque": "pa-le-to-que",
    "palhuén": "pal-huén",
    "pali": "pa-li",
    "palia": "pa-lia",
    "paliacate": "pa-lia-ca-te",
    "paliación": "pa-lia-ción",
    "paliadamente": "pa-lia-da-men-te",
    "paliar": "pa-liar",
    "paliativa": "pa-lia-ti-va",
    "paliativo": "pa-lia-ti-vo",
    "paliatoria": "pa-lia-to-ria",
    "paliatorio": "pa-lia-to-rio",
    "pálida": "pá-li-da",
    "palidecer": "pa-li-de-cer",
    "palidez": "pa-li-dez",
    "pálido": "pá-li-do",
    "paliducha": "pa-li-du-cha",
    "paliducho": "pa-li-du-cho",
    "palier": "pa-lier",
    "palilla": "pa-li-lla",
    "palillera": "pa-li-lle-ra",
    "palillero": "pa-li-lle-ro",
    "palillo": "pa-li-llo",
    "palillona": "pa-li-llo-na",
    "palimpsesto": "pa-limp-ses-to",
    "palíndromo": "pa-lín-dro-mo",
    "palingenesia": "pa-lin-ge-ne-sia",
    "palingenésica": "pa-lin-ge-né-si-ca",
    "palingenésico": "pa-lin-ge-né-si-co",
    "palinodia": "pa-li-no-dia",
    "palinología": "pa-li-no-lo-gí-a",
    "palio": "pa-lio",
    "palique": "pa-li-que",
    "paliquear": "pa-li-que-ar",
    "palisandro": "pa-li-san-dro",
    "palista": "pa-lis-ta",
    "palito": "pa-li-to",
    "palitoque": "pa-li-to-que",
    "palitroque": "pa-li-tro-que",
    "paliza": "pa-li-za",
    "palizada": "pa-li-za-da",
    "palizón": "pa-li-zón",
    "palla": "pa-lla",
    "pallaco": "pa-lla-co",
    "pallada": "pa-lla-da",
    "pallador": "pa-lla-dor",
    "pallaquear": "pa-lla-que-ar",
    "pallar": "pa-llar",
    "pallas": "pa-llas",
    "pallasquina": "pa-llas-qui-na",
    "pallasquino": "pa-llas-qui-no",
    "pallaza": "pa-lla-za",
    "pallet": "pa-llet",
    "pallete": "pa-lle-te",
    "palliri": "pa-lli-ri",
    "pallón": "pa-llón",
    "palloza": "pa-llo-za",
    "palma": "pal-ma",
    "palmácea": "pal-má-ce-a",
    "palmáceas": "pal-má-ce-as",
    "palmáceo": "pal-má-ce-o",
    "palmacristi": "pal-ma-cris-ti",
    "palmada": "pal-ma-da",
    "palmadilla": "pal-ma-di-lla",
    "palmado": "pal-ma-do",
    "palmar": "pal-mar",
    "palmarés": "pal-ma-rés",
    "palmaria": "pal-ma-ria",
    "palmariamente": "pal-ma-ria-men-te",
    "palmario": "pal-ma-rio",
    "palmatoria": "pal-ma-to-ria",
    "palmazón": "pal-ma-zón",
    "palmeada": "pal-me-a-da",
    "palmeado": "pal-me-a-do",
    "palmear": "pal-me-ar",
    "palmejar": "pal-me-jar",
    "palmense": "pal-men-se",
    "palmenta": "pal-men-ta",
    "palmentero": "pal-men-te-ro",
    "palmeo": "pal-me-o",
    "palmera": "pal-me-ra",
    "palmeral": "pal-me-ral",
    "palmerita": "pal-me-ri-ta",
    "palmero": "pal-me-ro",
    "palmesana": "pal-me-sa-na",
    "palmesano": "pal-me-sa-no",
    "palmeta": "pal-me-ta",
    "palmetazo": "pal-me-ta-zo",
    "palmiche": "pal-mi-che",
    "palmífera": "pal-mí-fe-ra",
    "palmífero": "pal-mí-fe-ro",
    "palmiforme": "pal-mi-for-me",
    "palmilla": "pal-mi-lla",
    "palmípeda": "pal-mí-pe-da",
    "palmípedo": "pal-mí-pe-do",
    "palmiste": "pal-mis-te",
    "palmita": "pal-mi-ta",
    "palmitiesa": "pal-mi-tie-sa",
    "palmitieso": "pal-mi-tie-so",
    "palmito": "pal-mi-to",
    "palmo": "pal-mo",
    "palmotada": "pal-mo-ta-da",
    "palmotear": "pal-mo-te-ar",
    "palmoteo": "pal-mo-te-o",
    "palo": "pa-lo",
    "paloapique": "pa-lo-a-pi-que",
    "paloduz": "pa-lo-duz",
    "paloma": "pa-lo-ma",
    "palomadura": "pa-lo-ma-du-ra",
    "palomar": "pa-lo-mar",
    "palomariega": "pa-lo-ma-rie-ga",
    "palomear": "pa-lo-me-ar",
    "palomera": "pa-lo-me-ra",
    "palomería": "pa-lo-me-rí-a",
    "palomero": "pa-lo-me-ro",
    "palometa": "pa-lo-me-ta",
    "palomilla": "pa-lo-mi-lla",
    "palomillear": "pa-lo-mi-lle-ar",
    "palomina": "pa-lo-mi-na",
    "palomino": "pa-lo-mi-no",
    "palomita": "pa-lo-mi-ta",
    "palomo": "pa-lo-mo",
    "palón": "pa-lón",
    "palopique": "pa-lo-pi-que",
    "palor": "pa-lor",
    "palosanto": "pa-lo-san-to",
    "palotada": "pa-lo-ta-da",
    "palotazo": "pa-lo-ta-zo",
    "palote": "pa-lo-te",
    "paloteado": "pa-lo-te-a-do",
    "palotear": "pa-lo-te-ar",
    "paloteo": "pa-lo-te-o",
    "palpable": "pal-pa-ble",
    "palpablemente": "pal-pa-ble-men-te",
    "palpación": "pal-pa-ción",
    "palpadura": "pal-pa-du-ra",
    "palpallén": "pal-pa-llén",
    "palpamiento": "pal-pa-mien-to",
    "palpar": "pal-par",
    "pálpebra": "pál-pe-bra",
    "palpebral": "pal-pe-bral",
    "palpi": "pal-pi",
    "palpitación": "pal-pi-ta-ción",
    "palpitante": "pal-pi-tan-te",
    "palpitar": "pal-pi-tar",
    "pálpito": "pál-pi-to",
    "palpo": "pal-po",
    "palqui": "pal-qui",
    "palquista": "pal-quis-ta",
    "palta": "pal-ta",
    "palto": "pal-to",
    "paltó": "pal-tó",
    "palucha": "pa-lu-cha",
    "paluchear": "pa-lu-che-ar",
    "paluchera": "pa-lu-che-ra",
    "paluchería": "pa-lu-che-rí-a",
    "paluchero": "pa-lu-che-ro",
    "paludamento": "pa-lu-da-men-to",
    "palude": "pa-lu-de",
    "palúdica": "pa-lú-di-ca",
    "palúdico": "pa-lú-di-co",
    "paludícola": "pa-lu-dí-co-la",
    "paludismo": "pa-lu-dis-mo",
    "paludo": "pa-lu-do",
    "palumbario": "pa-lum-ba-rio",
    "palurda": "pa-lur-da",
    "palurdo": "pa-lur-do",
    "palustre": "pa-lus-tre",
    "pamandabuán": "pa-man-da-buán",
    "pamba": "pam-ba",
    "pambaceada": "pam-ba-ce-a-da",
    "pambacear": "pam-ba-ce-ar",
    "pambazo": "pam-ba-zo",
    "pambil": "pam-bil",
    "pambiza": "pam-bi-za",
    "pame": "pa-me",
    "pamela": "pa-me-la",
    "pamema": "pa-me-ma",
    "pamentera": "pa-men-te-ra",
    "pamentero": "pa-men-te-ro",
    "pamento": "pa-men-to",
    "pampa": "pam-pa",
    "pámpana": "pám-pa-na",
    "pampanada": "pam-pa-na-da",
    "pampanaje": "pam-pa-na-je",
    "pampanga": "pam-pan-ga",
    "pampango": "pam-pan-go",
    "pampanilla": "pam-pa-ni-lla",
    "pámpano": "pám-pa-no",
    "pampanosa": "pam-pa-no-sa",
    "pampanoso": "pam-pa-no-so",
    "pampeana": "pam-pe-a-na",
    "pampeano": "pam-pe-a-no",
    "pampear": "pam-pe-ar",
    "pampera": "pam-pe-ra",
    "pamperdido": "pam-per-di-do",
    "pampero": "pam-pe-ro",
    "pampina": "pam-pi-na",
    "pampino": "pam-pi-no",
    "pampirolada": "pam-pi-ro-la-da",
    "pamplina": "pam-pli-na",
    "pamplinada": "pam-pli-na-da",
    "pamplinera": "pam-pli-ne-ra",
    "pamplinero": "pam-pli-ne-ro",
    "pamplinosa": "pam-pli-no-sa",
    "pamplinoso": "pam-pli-no-so",
    "pamplona": "pam-plo-na",
    "pamplonés": "pam-plo-nés",
    "pamplonesa": "pam-plo-ne-sa",
    "pamplonica": "pam-plo-ni-ca",
    "pampón": "pam-pón",
    "pamporcino": "pam-por-ci-no",
    "pamposada": "pam-po-sa-da",
    "pamposado": "pam-po-sa-do",
    "pampringada": "pam-prin-ga-da",
    "pampsiquismo": "pamp-si-quis-mo",
    "pamue": "pa-mue",
    "pana": "pa-na",
    "pánace": "pá-na-ce",
    "panacea": "pa-na-ce-a",
    "panaché": "pa-na-ché",
    "panada": "pa-na-da",
    "panadear": "pa-na-de-ar",
    "panadeo": "pa-na-de-o",
    "panadera": "pa-na-de-ra",
    "panadería": "pa-na-de-rí-a",
    "panadero": "pa-na-de-ro",
    "panadizo": "pa-na-di-zo",
    "panado": "pa-na-do",
    "panafricanismo": "pa-na-fri-ca-nis-mo",
    "panafricano": "pa-na-fri-ca-no",
    "panal": "pa-nal",
    "pañal": "pa-ñal",
    "pañalera": "pa-ña-le-ra",
    "pañalón": "pa-ña-lón",
    "panamá": "pa-na-má",
    "panamaca": "pa-na-ma-ca",
    "panameña": "pa-na-me-ña",
    "panameñismo": "pa-na-me-ñis-mo",
    "panameño": "pa-na-me-ño",
    "panamericana": "pa-na-me-ri-ca-na",
    "panamericanismo": "pa-na-me-ri-ca-nis-mo",
    "panamericanista": "pa-na-me-ri-ca-nis-ta",
    "panamericano": "pa-na-me-ri-ca-no",
    "pañanga": "pa-ñan-ga",
    "panapén": "pa-na-pén",
    "panarabismo": "pa-na-ra-bis-mo",
    "panarabista": "pa-na-ra-bis-ta",
    "panare": "pa-na-re",
    "panarizo": "pa-na-ri-zo",
    "panarra": "pa-na-rra",
    "panatela": "pa-na-te-la",
    "panatenaico": "pa-na-te-nai-co",
    "panateneas": "pa-na-te-ne-as",
    "panática": "pa-ná-ti-ca",
    "panatier": "pa-na-tier",
    "panavisión": "pa-na-vi-sión",
    "panca": "pan-ca",
    "pancada": "pan-ca-da",
    "pancake": "pan-ca-ke",
    "pancarpia": "pan-car-pia",
    "pancarta": "pan-car-ta",
    "pancellar": "pan-ce-llar",
    "pancera": "pan-ce-ra",
    "panceta": "pan-ce-ta",
    "panchito": "pan-chi-to",
    "pancho": "pan-cho",
    "panchón": "pan-chón",
    "pancilla": "pan-ci-lla",
    "pancismo": "pan-cis-mo",
    "pancista": "pan-cis-ta",
    "pancit": "pan-cit",
    "pancita": "pan-ci-ta",
    "pancitería": "pan-ci-te-rí-a",
    "panclastita": "pan-clas-ti-ta",
    "panco": "pan-co",
    "pancraciasta": "pan-cra-cias-ta",
    "pancracio": "pan-cra-cio",
    "pancrática": "pan-crá-ti-ca",
    "pancrático": "pan-crá-ti-co",
    "páncreas": "pán-cre-as",
    "pancreática": "pan-cre-á-ti-ca",
    "pancreático": "pan-cre-á-ti-co",
    "pancreatitis": "pan-cre-a-ti-tis",
    "pancromática": "pan-cro-má-ti-ca",
    "pancromático": "pan-cro-má-ti-co",
    "pancutra": "pan-cu-tra",
    "panda": "pan-da",
    "pandanácea": "pan-da-ná-ce-a",
    "pandanáceo": "pan-da-ná-ce-o",
    "pandánea": "pan-dá-ne-a",
    "pandáneo": "pan-dá-ne-o",
    "pandar": "pan-dar",
    "pandeada": "pan-de-a-da",
    "pandear": "pan-de-ar",
    "pandectas": "pan-dec-tas",
    "pandeirada": "pan-dei-ra-da",
    "pandeiro": "pan-dei-ro",
    "pandemia": "pan-de-mia",
    "pandémico": "pan-dé-mi-co",
    "pandemonio": "pan-de-mo-nio",
    "pandemónium": "pan-de-mó-nium",
    "pandeo": "pan-de-o",
    "pandera": "pan-de-ra",
    "panderada": "pan-de-ra-da",
    "panderazo": "pan-de-ra-zo",
    "pandereta": "pan-de-re-ta",
    "panderetazo": "pan-de-re-ta-zo",
    "panderete": "pan-de-re-te",
    "panderetear": "pan-de-re-te-ar",
    "pandereteo": "pan-de-re-te-o",
    "panderetera": "pan-de-re-te-ra",
    "panderetero": "pan-de-re-te-ro",
    "panderetólogo": "pan-de-re-tó-lo-go",
    "pandero": "pan-de-ro",
    "panderón": "pan-de-rón",
    "pandiculación": "pan-di-cu-la-ción",
    "pandilla": "pan-di-lla",
    "pandillaje": "pan-di-lla-je",
    "pandillera": "pan-di-lle-ra",
    "pandillero": "pan-di-lle-ro",
    "pandillista": "pan-di-llis-ta",
    "pandina": "pan-di-na",
    "pandino": "pan-di-no",
    "pandit": "pan-dit",
    "pando": "pan-do",
    "pandorga": "pan-dor-ga",
    "pandroguear": "pan-dro-gue-ar",
    "pandura": "pan-du-ra",
    "pandureco": "pan-du-re-co",
    "panear": "pa-ne-ar",
    "panecillo": "pa-ne-ci-llo",
    "panegírica": "pa-ne-gí-ri-ca",
    "panegírico": "pa-ne-gí-ri-co",
    "panegirista": "pa-ne-gi-ris-ta",
    "panegirizar": "pa-ne-gi-ri-zar",
    "panel": "pa-nel",
    "panela": "pa-ne-la",
    "panelera": "pa-ne-le-ra",
    "panelero": "pa-ne-le-ro",
    "panelista": "pa-ne-lis-ta",
    "panenteísmo": "pa-nen-te-ís-mo",
    "panera": "pa-ne-ra",
    "pañera": "pa-ñe-ra",
    "pañería": "pa-ñe-rí-a",
    "panero": "pa-ne-ro",
    "pañero": "pa-ñe-ro",
    "paneslavismo": "pa-nes-la-vis-mo",
    "paneslavista": "pa-nes-la-vis-ta",
    "paneta": "pa-ne-ta",
    "pañetar": "pa-ñe-tar",
    "pañete": "pa-ñe-te",
    "panetela": "pa-ne-te-la",
    "panetera": "pa-ne-te-ra",
    "panetería": "pa-ne-te-rí-a",
    "panetero": "pa-ne-te-ro",
    "paneuropeísmo": "pa-neu-ro-pe-ís-mo",
    "paneuropeísta": "pa-neu-ro-pe-ís-ta",
    "paneuropeo": "pa-neu-ro-pe-o",
    "pánfila": "pán-fi-la",
    "panfilismo": "pan-fi-lis-mo",
    "pánfilo": "pán-fi-lo",
    "panfletaria": "pan-fle-ta-ria",
    "panfletario": "pan-fle-ta-rio",
    "panfletista": "pan-fle-tis-ta",
    "panfleto": "pan-fle-to",
    "panga": "pan-ga",
    "pangal": "pan-gal",
    "pangaré": "pan-ga-ré",
    "pangasinán": "pan-ga-si-nán",
    "pangelín": "pan-ge-lín",
    "pangermánico": "pan-ger-má-ni-co",
    "pangermanismo": "pan-ger-ma-nis-mo",
    "pangermanista": "pan-ger-ma-nis-ta",
    "pangolín": "pan-go-lín",
    "pangue": "pan-gue",
    "panguero": "pan-gue-ro",
    "panhelénico": "pan-he-lé-ni-co",
    "panhelenismo": "pan-he-le-nis-mo",
    "panhispánico": "pan-his-pá-ni-co",
    "pañí": "pa-ñí",
    "paniaguado": "pa-nia-gua-do",
    "pánica": "pá-ni-ca",
    "pánico": "pá-ni-co",
    "panícula": "pa-ní-cu-la",
    "paniculada": "pa-ni-cu-la-da",
    "paniculado": "pa-ni-cu-la-do",
    "panicular": "pa-ni-cu-lar",
    "panículo": "pa-ní-cu-lo",
    "panida": "pa-ni-da",
    "paniega": "pa-nie-ga",
    "paniego": "pa-nie-go",
    "panificable": "pa-ni-fi-ca-ble",
    "panificación": "pa-ni-fi-ca-ción",
    "panificador": "pa-ni-fi-ca-dor",
    "panificadora": "pa-ni-fi-ca-do-ra",
    "panificar": "pa-ni-fi-car",
    "paniguada": "pa-ni-gua-da",
    "paniguado": "pa-ni-gua-do",
    "pañil": "pa-ñil",
    "panilla": "pa-ni-lla",
    "panique": "pa-ni-que",
    "panislámico": "pa-nis-lá-mi-co",
    "panislamismo": "pa-nis-la-mis-mo",
    "panislamista": "pa-nis-la-mis-ta",
    "panitela": "pa-ni-te-la",
    "pañito": "pa-ñi-to",
    "panizal": "pa-ni-zal",
    "panizo": "pa-ni-zo",
    "pañizuelo": "pa-ñi-zue-lo",
    "panjí": "pan-jí",
    "panléxico": "pan-lé-xi-co",
    "panllevar": "pan-lle-var",
    "panlogismo": "pan-lo-gis-mo",
    "pano": "pa-no",
    "paño": "pa-ño",
    "panocha": "pa-no-cha",
    "panocho": "pa-no-cho",
    "panoja": "pa-no-ja",
    "pañol": "pa-ñol",
    "pañolera": "pa-ño-le-ra",
    "pañolería": "pa-ño-le-rí-a",
    "pañolero": "pa-ño-le-ro",
    "pañoleta": "pa-ño-le-ta",
    "panoli": "pa-no-li",
    "pañolito": "pa-ño-li-to",
    "pañolón": "pa-ño-lón",
    "panonia": "pa-no-nia",
    "panonio": "pa-no-nio",
    "panoplia": "pa-no-plia",
    "panóptica": "pa-nóp-ti-ca",
    "panóptico": "pa-nóp-ti-co",
    "panorama": "pa-no-ra-ma",
    "panorámica": "pa-no-rá-mi-ca",
    "panorámico": "pa-no-rá-mi-co",
    "panormitana": "pa-nor-mi-ta-na",
    "panormitano": "pa-nor-mi-ta-no",
    "pañosa": "pa-ño-sa",
    "panoso": "pa-no-so",
    "pañoso": "pa-ño-so",
    "panque": "pan-que",
    "panqueca": "pan-que-ca",
    "panqueque": "pan-que-que",
    "pansa": "pan-sa",
    "pansexualismo": "pan-se-xua-lis-mo",
    "pansida": "pan-si-da",
    "pansido": "pan-si-do",
    "panspermia": "pans-per-mia",
    "pantagruélica": "pan-ta-grué-li-ca",
    "pantagruélico": "pan-ta-grué-li-co",
    "pantalán": "pan-ta-lán",
    "pantaleta": "pan-ta-le-ta",
    "pantalla": "pan-ta-lla",
    "pantallazo": "pan-ta-lla-zo",
    "pantallear": "pan-ta-lle-ar",
    "pantallosa": "pan-ta-llo-sa",
    "pantalloso": "pan-ta-llo-so",
    "pantalón": "pan-ta-lón",
    "pantaloncillo": "pan-ta-lon-ci-llo",
    "pantalonera": "pan-ta-lo-ne-ra",
    "pantalonero": "pan-ta-lo-ne-ro",
    "pantaloneta": "pan-ta-lo-ne-ta",
    "pantana": "pan-ta-na",
    "pantanal": "pan-ta-nal",
    "pantano": "pan-ta-no",
    "pantanosa": "pan-ta-no-sa",
    "pantanoso": "pan-ta-no-so",
    "pantasana": "pan-ta-sa-na",
    "panteísmo": "pan-te-ís-mo",
    "panteísta": "pan-te-ís-ta",
    "panteística": "pan-te-ís-ti-ca",
    "panteístico": "pan-te-ís-ti-co",
    "panteón": "pan-te-ón",
    "panteonero": "pan-te-o-ne-ro",
    "pantera": "pan-te-ra",
    "panti": "pan-ti",
    "pantimedia": "pan-ti-me-dia",
    "pantimedias": "pan-ti-me-dias",
    "pantocrátor": "pan-to-crá-tor",
    "pantógrafo": "pan-tó-gra-fo",
    "pantómetra": "pan-tó-me-tra",
    "pantómetro": "pan-tó-me-tro",
    "pantomima": "pan-to-mi-ma",
    "pantomimera": "pan-to-mi-me-ra",
    "pantomimero": "pan-to-mi-me-ro",
    "pantomímica": "pan-to-mí-mi-ca",
    "pantomímico": "pan-to-mí-mi-co",
    "pantomimo": "pan-to-mi-mo",
    "pantoque": "pan-to-que",
    "pantorra": "pan-to-rra",
    "pantorrilla": "pan-to-rri-lla",
    "pantorrillera": "pan-to-rri-lle-ra",
    "pantorrilluda": "pan-to-rri-llu-da",
    "pantorrilludo": "pan-to-rri-llu-do",
    "pantruca": "pan-tru-ca",
    "pantufla": "pan-tu-fla",
    "pantuflazo": "pan-tu-fla-zo",
    "pantuflo": "pan-tu-flo",
    "panucha": "pa-nu-cha",
    "panuchera": "pa-nu-che-ra",
    "panuchero": "pa-nu-che-ro",
    "panucho": "pa-nu-cho",
    "panudo": "pa-nu-do",
    "pañuelo": "pa-ñue-lo",
    "panul": "pa-nul",
    "pañusa": "pa-ñu-sa",
    "pañuso": "pa-ñu-so",
    "panza": "pan-za",
    "panzada": "pan-za-da",
    "panzaleo": "pan-za-le-o",
    "panzazo": "pan-za-zo",
    "panzón": "pan-zón",
    "panzona": "pan-zo-na",
    "panzuda": "pan-zu-da",
    "panzudo": "pan-zu-do",
    "pao": "pa-o",
    "papa": "pa-pa",
    "papá": "pa-pá",
    "papable": "pa-pa-ble",
    "papacara": "pa-pa-ca-ra",
    "papachar": "pa-pa-char",
    "papacho": "pa-pa-cho",
    "papada": "pa-pa-da",
    "papadgo": "pa-pad-go",
    "papado": "pa-pa-do",
    "papadzul": "pa-pad-zul",
    "papafigo": "pa-pa-fi-go",
    "papafrita": "pa-pa-fri-ta",
    "papagaya": "pa-pa-ga-ya",
    "papagayo": "pa-pa-ga-yo",
    "papahígo": "pa-pa-hí-go",
    "papahuevos": "pa-pa-hue-vos",
    "papaína": "pa-pa-í-na",
    "papaíto": "pa-pa-í-to",
    "papal": "pa-pal",
    "papalina": "pa-pa-li-na",
    "papalino": "pa-pa-li-no",
    "papalisa": "pa-pa-li-sa",
    "papalmente": "pa-pal-men-te",
    "papalomayo": "pa-pa-lo-ma-yo",
    "papalota": "pa-pa-lo-ta",
    "papalote": "pa-pa-lo-te",
    "papalotear": "pa-pa-lo-te-ar",
    "papamoscas": "pa-pa-mos-cas",
    "papamóvil": "pa-pa-mó-vil",
    "papanatas": "pa-pa-na-tas",
    "papanatería": "pa-pa-na-te-rí-a",
    "papanatismo": "pa-pa-na-tis-mo",
    "papanduja": "pa-pan-du-ja",
    "papandujo": "pa-pan-du-jo",
    "papar": "pa-par",
    "pápara": "pá-pa-ra",
    "paparapa": "pa-pa-ra-pa",
    "paparazzi": "pa-pa-raz-zi",
    "páparo": "pá-pa-ro",
    "paparota": "pa-pa-ro-ta",
    "paparote": "pa-pa-ro-te",
    "paparrabias": "pa-pa-rra-bias",
    "paparrasolla": "pa-pa-rra-so-lla",
    "paparrucha": "pa-pa-rru-cha",
    "paparruchada": "pa-pa-rru-cha-da",
    "paparula": "pa-pa-ru-la",
    "paparulo": "pa-pa-ru-lo",
    "papasal": "pa-pa-sal",
    "papatla": "pa-pa-tla",
    "papatoste": "pa-pa-tos-te",
    "papaverácea": "pa-pa-ve-rá-ce-a",
    "papaveráceas": "pa-pa-ve-rá-ce-as",
    "papaveráceo": "pa-pa-ve-rá-ce-o",
    "papaverina": "pa-pa-ve-ri-na",
    "papaya": "pa-pa-ya",
    "papayácea": "pa-pa-yá-ce-a",
    "papayáceo": "pa-pa-yá-ce-o",
    "papayal": "pa-pa-yal",
    "papayera": "pa-pa-ye-ra",
    "papayero": "pa-pa-ye-ro",
    "papayo": "pa-pa-yo",
    "papaz": "pa-paz",
    "papazgo": "pa-paz-go",
    "pape": "pa-pe",
    "papear": "pa-pe-ar",
    "papel": "pa-pel",
    "papela": "pa-pe-la",
    "papelacera": "pa-pe-la-ce-ra",
    "papelacero": "pa-pe-la-ce-ro",
    "papelear": "pa-pe-le-ar",
    "papeleo": "pa-pe-le-o",
    "papelera": "pa-pe-le-ra",
    "papelería": "pa-pe-le-rí-a",
    "papelerío": "pa-pe-le-rí-o",
    "papelero": "pa-pe-le-ro",
    "papeleta": "pa-pe-le-ta",
    "papeletear": "pa-pe-le-te-ar",
    "papeleteo": "pa-pe-le-te-o",
    "papeletizar": "pa-pe-le-ti-zar",
    "papelillo": "pa-pe-li-llo",
    "papelina": "pa-pe-li-na",
    "papelista": "pa-pe-lis-ta",
    "papelón": "pa-pe-lón",
    "papelona": "pa-pe-lo-na",
    "papelonado": "pa-pe-lo-na-do",
    "papelonear": "pa-pe-lo-ne-ar",
    "papelonera": "pa-pe-lo-ne-ra",
    "papelonero": "pa-pe-lo-ne-ro",
    "papelorio": "pa-pe-lo-rio",
    "papelote": "pa-pe-lo-te",
    "papelucho": "pa-pe-lu-cho",
    "papelujo": "pa-pe-lu-jo",
    "papeo": "pa-pe-o",
    "papera": "pa-pe-ra",
    "papero": "pa-pe-ro",
    "paperuda": "pa-pe-ru-da",
    "paperudo": "pa-pe-ru-do",
    "papi": "pa-pi",
    "papialbillo": "pa-pial-bi-llo",
    "papiamenta": "pa-pia-men-ta",
    "papiamento": "pa-pia-men-to",
    "papiche": "pa-pi-che",
    "papila": "pa-pi-la",
    "papilar": "pa-pi-lar",
    "papilionácea": "pa-pi-lio-ná-ce-a",
    "papilionáceas": "pa-pi-lio-ná-ce-as",
    "papilionáceo": "pa-pi-lio-ná-ce-o",
    "papilla": "pa-pi-lla",
    "papillote": "pa-pi-llo-te",
    "papiloma": "pa-pi-lo-ma",
    "papín": "pa-pín",
    "papión": "pa-pión",
    "papiro": "pa-pi-ro",
    "pápiro": "pá-pi-ro",
    "papiroflexia": "pa-pi-ro-fle-xia",
    "papirofléxico": "pa-pi-ro-flé-xi-co",
    "papirola": "pa-pi-ro-la",
    "papirolada": "pa-pi-ro-la-da",
    "papiróloga": "pa-pi-ró-lo-ga",
    "papirología": "pa-pi-ro-lo-gí-a",
    "papirólogo": "pa-pi-ró-lo-go",
    "papirotada": "pa-pi-ro-ta-da",
    "papirotazo": "pa-pi-ro-ta-zo",
    "papirote": "pa-pi-ro-te",
    "papisa": "pa-pi-sa",
    "papismo": "pa-pis-mo",
    "papista": "pa-pis-ta",
    "papo": "pa-po",
    "papón": "pa-pón",
    "papona": "pa-po-na",
    "paporrear": "pa-po-rre-ar",
    "paporreta": "pa-po-rre-ta",
    "paporretear": "pa-po-rre-te-ar",
    "paporretera": "pa-po-rre-te-ra",
    "paporretero": "pa-po-rre-te-ro",
    "páprika": "pá-pri-ka",
    "papú": "pa-pú",
    "papúa": "pa-pú-a",
    "papuda": "pa-pu-da",
    "papudo": "pa-pu-do",
    "papuja": "pa-pu-ja",
    "papujada": "pa-pu-ja-da",
    "papujado": "pa-pu-ja-do",
    "papujo": "pa-pu-jo",
    "pápula": "pá-pu-la",
    "papulosa": "pa-pu-lo-sa",
    "papuloso": "pa-pu-lo-so",
    "paquear": "pa-que-ar",
    "paquebot": "pa-que-bot",
    "paquebote": "pa-que-bo-te",
    "paqueo": "pa-que-o",
    "paquera": "pa-que-ra",
    "paquero": "pa-que-ro",
    "paqueta": "pa-que-ta",
    "paquetazo": "pa-que-ta-zo",
    "paquete": "pa-que-te",
    "paquetear": "pa-que-te-ar",
    "paquetera": "pa-que-te-ra",
    "paquetería": "pa-que-te-rí-a",
    "paquetero": "pa-que-te-ro",
    "paquetudo": "pa-que-tu-do",
    "paquidermia": "pa-qui-der-mia",
    "paquidérmico": "pa-qui-dér-mi-co",
    "paquidermo": "pa-qui-der-mo",
    "paquín": "pa-quín",
    "paquistaní": "pa-quis-ta-ní",
    "para": "pa-ra",
    "paraba": "pa-ra-ba",
    "parabién": "pa-ra-bién",
    "parábola": "pa-rá-bo-la",
    "parabolano": "pa-ra-bo-la-no",
    "parabólica": "pa-ra-bó-li-ca",
    "parabólico": "pa-ra-bó-li-co",
    "parabolizar": "pa-ra-bo-li-zar",
    "paraboloide": "pa-ra-bo-loi-de",
    "parabrisa": "pa-ra-bri-sa",
    "parabrisas": "pa-ra-bri-sas",
    "paraca": "pa-ra-ca",
    "paracaídas": "pa-ra-ca-í-das",
    "paracaidismo": "pa-ra-cai-dis-mo",
    "paracaidista": "pa-ra-cai-dis-ta",
    "paracentesis": "pa-ra-cen-te-sis",
    "paracetamol": "pa-ra-ce-ta-mol",
    "parachispas": "pa-ra-chis-pas",
    "parachoques": "pa-ra-cho-ques",
    "parachute": "pa-ra-chu-te",
    "paracleto": "pa-ra-cle-to",
    "paráclito": "pa-rá-cli-to",
    "paracronismo": "pa-ra-cro-nis-mo",
    "parada": "pa-ra-da",
    "paradera": "pa-ra-de-ra",
    "paradero": "pa-ra-de-ro",
    "paradetas": "pa-ra-de-tas",
    "paradiástole": "pa-ra-diás-to-le",
    "paradigma": "pa-ra-dig-ma",
    "paradigmático": "pa-ra-dig-má-ti-co",
    "paradina": "pa-ra-di-na",
    "paradisiaca": "pa-ra-di-sia-ca",
    "paradisíaco": "pa-ra-di-sí-a-co",
    "paradisiaco": "pa-ra-di-sia-co",
    "paradislero": "pa-ra-dis-le-ro",
    "parado": "pa-ra-do",
    "paradocente": "pa-ra-do-cen-te",
    "paradoja": "pa-ra-do-ja",
    "paradojal": "pa-ra-do-jal",
    "paradójica": "pa-ra-dó-ji-ca",
    "paradójico": "pa-ra-dó-ji-co",
    "paradojo": "pa-ra-do-jo",
    "paradón": "pa-ra-dón",
    "parador": "pa-ra-dor",
    "paradora": "pa-ra-do-ra",
    "paraestatal": "pa-ra-es-ta-tal",
    "parafango": "pa-ra-fan-go",
    "parafernales": "pa-ra-fer-na-les",
    "parafernalia": "pa-ra-fer-na-lia",
    "parafilia": "pa-ra-fi-lia",
    "parafina": "pa-ra-fi-na",
    "parafinado": "pa-ra-fi-na-do",
    "parafinar": "pa-ra-fi-nar",
    "parafínico": "pa-ra-fí-ni-co",
    "parafraseador": "pa-ra-fra-se-a-dor",
    "parafraseadora": "pa-ra-fra-se-a-do-ra",
    "parafrasear": "pa-ra-fra-se-ar",
    "paráfrasis": "pa-rá-fra-sis",
    "parafraste": "pa-ra-fras-te",
    "parafrástica": "pa-ra-frás-ti-ca",
    "parafrásticamente": "pa-ra-frás-ti-ca-men-te",
    "parafrástico": "pa-ra-frás-ti-co",
    "paragoge": "pa-ra-go-ge",
    "paragógica": "pa-ra-gó-gi-ca",
    "paragógico": "pa-ra-gó-gi-co",
    "paragolpe": "pa-ra-gol-pe",
    "paragolpes": "pa-ra-gol-pes",
    "paragón": "pa-ra-gón",
    "paragonar": "pa-ra-go-nar",
    "parágrafo": "pa-rá-gra-fo",
    "paragranizo": "pa-ra-gra-ni-zo",
    "paraguariense": "pa-ra-gua-rien-se",
    "paraguas": "pa-ra-guas",
    "paraguatán": "pa-ra-gua-tán",
    "paraguay": "pa-ra-guay",
    "paraguaya": "pa-ra-gua-ya",
    "paraguayismo": "pa-ra-gua-yis-mo",
    "paraguayo": "pa-ra-gua-yo",
    "paraguazo": "pa-ra-gua-zo",
    "paragüera": "pa-ra-güe-ra",
    "paragüería": "pa-ra-güe-rí-a",
    "paragüero": "pa-ra-güe-ro",
    "parahusar": "pa-rahu-sar",
    "parahúso": "pa-ra-hú-so",
    "paraiseña": "pa-rai-se-ña",
    "paraiseño": "pa-rai-se-ño",
    "paraíso": "pa-ra-í-so",
    "paraje": "pa-ra-je",
    "parajismera": "pa-ra-jis-me-ra",
    "parajismero": "pa-ra-jis-me-ro",
    "parajismo": "pa-ra-jis-mo",
    "paral": "pa-ral",
    "paraláctica": "pa-ra-lác-ti-ca",
    "paraláctico": "pa-ra-lác-ti-co",
    "paralaje": "pa-ra-la-je",
    "paralalia": "pa-ra-la-lia",
    "paralasis": "pa-ra-la-sis",
    "paralaxi": "pa-ra-la-xi",
    "paralela": "pa-ra-le-la",
    "paralelamente": "pa-ra-le-la-men-te",
    "paralelar": "pa-ra-le-lar",
    "paralelepípedo": "pa-ra-le-le-pí-pe-do",
    "paralelismo": "pa-ra-le-lis-mo",
    "paralelo": "pa-ra-le-lo",
    "paralelogramo": "pa-ra-le-lo-gra-mo",
    "paralimpíada": "pa-ra-lim-pí-a-da",
    "paralimpiada": "pa-ra-lim-pia-da",
    "paralímpica": "pa-ra-lím-pi-ca",
    "paralímpico": "pa-ra-lím-pi-co",
    "paralipómenos": "pa-ra-li-pó-me-nos",
    "paralipsis": "pa-ra-lip-sis",
    "parálisis": "pa-rá-li-sis",
    "paralítica": "pa-ra-lí-ti-ca",
    "paraliticada": "pa-ra-li-ti-ca-da",
    "paraliticado": "pa-ra-li-ti-ca-do",
    "paraliticar": "pa-ra-li-ti-car",
    "paraliticarse": "pa-ra-li-ti-car-se",
    "paralítico": "pa-ra-lí-ti-co",
    "paralización": "pa-ra-li-za-ción",
    "paralizador": "pa-ra-li-za-dor",
    "paralizadora": "pa-ra-li-za-do-ra",
    "paralizante": "pa-ra-li-zan-te",
    "paralizar": "pa-ra-li-zar",
    "paralogismo": "pa-ra-lo-gis-mo",
    "paralogizar": "pa-ra-lo-gi-zar",
    "paramada": "pa-ra-ma-da",
    "paramagnético": "pa-ra-mag-né-ti-co",
    "paramagnetismo": "pa-ra-mag-ne-tis-mo",
    "paramar": "pa-ra-mar",
    "paramear": "pa-ra-me-ar",
    "paramecio": "pa-ra-me-cio",
    "paramédica": "pa-ra-mé-di-ca",
    "paramédico": "pa-ra-mé-di-co",
    "paramentar": "pa-ra-men-tar",
    "paramento": "pa-ra-men-to",
    "paramera": "pa-ra-me-ra",
    "paramero": "pa-ra-me-ro",
    "parámetro": "pa-rá-me-tro",
    "paramilitar": "pa-ra-mi-li-tar",
    "paramnesia": "pa-ram-ne-sia",
    "páramo": "pá-ra-mo",
    "paramoso": "pa-ra-mo-so",
    "paranaense": "pa-ra-na-en-se",
    "parancero": "pa-ran-ce-ro",
    "paranense": "pa-ra-nen-se",
    "parangón": "pa-ran-gón",
    "parangona": "pa-ran-go-na",
    "parangonable": "pa-ran-go-na-ble",
    "parangonar": "pa-ran-go-nar",
    "parangonizar": "pa-ran-go-ni-zar",
    "paranínfico": "pa-ra-nín-fi-co",
    "paraninfo": "pa-ra-nin-fo",
    "paranoia": "pa-ra-noia",
    "paranoica": "pa-ra-noi-ca",
    "paranoico": "pa-ra-noi-co",
    "paranoide": "pa-ra-noi-de",
    "paranomasia": "pa-ra-no-ma-sia",
    "paranormal": "pa-ra-nor-mal",
    "paranza": "pa-ran-za",
    "parao": "pa-ra-o",
    "paraoficial": "pa-ra-o-fi-cial",
    "paraolimpiada": "pa-ra-o-lim-pia-da",
    "paraolímpico": "pa-ra-o-lím-pi-co",
    "parapara": "pa-ra-pa-ra",
    "paraparo": "pa-ra-pa-ro",
    "parapente": "pa-ra-pen-te",
    "parapentista": "pa-ra-pen-tis-ta",
    "parapetar": "pa-ra-pe-tar",
    "parapetear": "pa-ra-pe-te-ar",
    "parapeto": "pa-ra-pe-to",
    "paraplejía": "pa-ra-ple-jí-a",
    "paraplejia": "pa-ra-ple-jia",
    "parapléjica": "pa-ra-plé-ji-ca",
    "parapléjico": "pa-ra-plé-ji-co",
    "parapoco": "pa-ra-po-co",
    "parapolicial": "pa-ra-po-li-cial",
    "parapsicóloga": "pa-rap-si-có-lo-ga",
    "parapsicología": "pa-rap-si-co-lo-gí-a",
    "parapsicológico": "pa-rap-si-co-ló-gi-co",
    "parapsicólogo": "pa-rap-si-có-lo-go",
    "parar": "pa-rar",
    "pararrayo": "pa-ra-rra-yo",
    "pararrayos": "pa-ra-rra-yos",
    "parasanga": "pa-ra-san-ga",
    "parasceve": "pa-ras-ce-ve",
    "paraselene": "pa-ra-se-le-ne",
    "parasemo": "pa-ra-se-mo",
    "parasicóloga": "pa-ra-si-có-lo-ga",
    "parasicología": "pa-ra-si-co-lo-gí-a",
    "parasicológico": "pa-ra-si-co-ló-gi-co",
    "parasicólogo": "pa-ra-si-có-lo-go",
    "parasimpático": "pa-ra-sim-pá-ti-co",
    "parasíntesis": "pa-ra-sín-te-sis",
    "parasintética": "pa-ra-sin-té-ti-ca",
    "parasintético": "pa-ra-sin-té-ti-co",
    "parasismo": "pa-ra-sis-mo",
    "parásita": "pa-rá-si-ta",
    "parasitar": "pa-ra-si-tar",
    "parasitaria": "pa-ra-si-ta-ria",
    "parasitario": "pa-ra-si-ta-rio",
    "parasítica": "pa-ra-sí-ti-ca",
    "parasiticida": "pa-ra-si-ti-ci-da",
    "parasítico": "pa-ra-sí-ti-co",
    "parasitismo": "pa-ra-si-tis-mo",
    "parásito": "pa-rá-si-to",
    "parasitología": "pa-ra-si-to-lo-gí-a",
    "parasitosis": "pa-ra-si-to-sis",
    "parasol": "pa-ra-sol",
    "parástade": "pa-rás-ta-de",
    "parata": "pa-ra-ta",
    "paratáctico": "pa-ra-tác-ti-co",
    "parataxis": "pa-ra-ta-xis",
    "paratífica": "pa-ra-tí-fi-ca",
    "paratífico": "pa-ra-tí-fi-co",
    "paratifoidea": "pa-ra-ti-foi-de-a",
    "paratifoideo": "pa-ra-ti-foi-de-o",
    "paratifus": "pa-ra-ti-fus",
    "paratiroideo": "pa-ra-ti-roi-de-o",
    "paratiroides": "pa-ra-ti-roi-des",
    "paraulata": "pa-rau-la-ta",
    "parazonio": "pa-ra-zo-nio",
    "parca": "par-ca",
    "parcamente": "par-ca-men-te",
    "parce": "par-ce",
    "parcela": "par-ce-la",
    "parcelable": "par-ce-la-ble",
    "parcelación": "par-ce-la-ción",
    "parcelar": "par-ce-lar",
    "parcelaria": "par-ce-la-ria",
    "parcelario": "par-ce-la-rio",
    "parcha": "par-cha",
    "parchar": "par-char",
    "parchazo": "par-cha-zo",
    "parche": "par-che",
    "parchear": "par-che-ar",
    "parcheo": "par-che-o",
    "parchís": "par-chís",
    "parchista": "par-chis-ta",
    "parchita": "par-chi-ta",
    "parcho": "par-cho",
    "parchón": "par-chón",
    "parcial": "par-cial",
    "parcialidad": "par-cia-li-dad",
    "parcializar": "par-cia-li-zar",
    "parcialmente": "par-cial-men-te",
    "parcidad": "par-ci-dad",
    "parcionera": "par-cio-ne-ra",
    "parcionero": "par-cio-ne-ro",
    "parcir": "par-cir",
    "parco": "par-co",
    "parda": "par-da",
    "pardal": "par-dal",
    "pardear": "par-de-ar",
    "pardela": "par-de-la",
    "pardete": "par-de-te",
    "pardiez": "par-diez",
    "pardilla": "par-di-lla",
    "pardillo": "par-di-llo",
    "pardina": "par-di-na",
    "pardiobre": "par-dio-bre",
    "pardisca": "par-dis-ca",
    "pardisco": "par-dis-co",
    "pardo": "par-do",
    "pardomonte": "par-do-mon-te",
    "pardusca": "par-dus-ca",
    "pardusco": "par-dus-co",
    "parduzco": "par-duz-co",
    "pareado": "pa-re-a-do",
    "parear": "pa-re-ar",
    "parecencia": "pa-re-cen-cia",
    "parecer": "pa-re-cer",
    "parecida": "pa-re-ci-da",
    "parecido": "pa-re-ci-do",
    "pared": "pa-red",
    "paredaña": "pa-re-da-ña",
    "paredaño": "pa-re-da-ño",
    "paredina": "pa-re-di-na",
    "paredón": "pa-re-dón",
    "pareja": "pa-re-ja",
    "parejamente": "pa-re-ja-men-te",
    "parejera": "pa-re-je-ra",
    "parejería": "pa-re-je-rí-a",
    "parejero": "pa-re-je-ro",
    "parejita": "pa-re-ji-ta",
    "parejo": "pa-re-jo",
    "parejura": "pa-re-ju-ra",
    "parel": "pa-rel",
    "parella": "pa-re-lla",
    "parellada": "pa-re-lla-da",
    "paremia": "pa-re-mia",
    "paremiario": "pa-re-mia-rio",
    "paremióloga": "pa-re-mió-lo-ga",
    "paremiología": "pa-re-mio-lo-gí-a",
    "paremiológica": "pa-re-mio-ló-gi-ca",
    "paremiológico": "pa-re-mio-ló-gi-co",
    "paremiólogo": "pa-re-mió-lo-go",
    "parénesis": "pa-ré-ne-sis",
    "parenética": "pa-re-né-ti-ca",
    "parenético": "pa-re-né-ti-co",
    "parénquima": "pa-rén-qui-ma",
    "parenquimático": "pa-ren-qui-má-ti-co",
    "parenquimatosa": "pa-ren-qui-ma-to-sa",
    "parenquimatoso": "pa-ren-qui-ma-to-so",
    "parentación": "pa-ren-ta-ción",
    "parentado": "pa-ren-ta-do",
    "parental": "pa-ren-tal",
    "parentela": "pa-ren-te-la",
    "parenteral": "pa-ren-te-ral",
    "parentesco": "pa-ren-tes-co",
    "paréntesis": "pa-rén-te-sis",
    "parentética": "pa-ren-té-ti-ca",
    "parentético": "pa-ren-té-ti-co",
    "pareo": "pa-re-o",
    "parergon": "pa-rer-gon",
    "paresa": "pa-re-sa",
    "paresia": "pa-re-sia",
    "parestesia": "pa-res-te-sia",
    "pargo": "par-go",
    "parguela": "par-gue-la",
    "parhelia": "pa-rhe-lia",
    "parhelio": "pa-rhe-lio",
    "parhilera": "pa-rhi-le-ra",
    "paria": "pa-ria",
    "pariambo": "pa-riam-bo",
    "parián": "pa-rián",
    "parias": "pa-rias",
    "parición": "pa-ri-ción",
    "parida": "pa-ri-da",
    "paridad": "pa-ri-dad",
    "paridera": "pa-ri-de-ra",
    "paridigitado": "pa-ri-di-gi-ta-do",
    "párido": "pá-ri-do",
    "paridora": "pa-ri-do-ra",
    "parienta": "pa-rien-ta",
    "pariente": "pa-rien-te",
    "parietal": "pa-rie-tal",
    "parietaria": "pa-rie-ta-ria",
    "parificación": "pa-ri-fi-ca-ción",
    "parificar": "pa-ri-fi-car",
    "parigual": "pa-ri-gual",
    "pariguaya": "pa-ri-gua-ya",
    "pariguayo": "pa-ri-gua-yo",
    "parihuela": "pa-ri-hue-la",
    "parima": "pa-ri-ma",
    "parimiento": "pa-ri-mien-to",
    "parinacoteña": "pa-ri-na-co-te-ña",
    "parinacoteño": "pa-ri-na-co-te-ño",
    "pario": "pa-rio",
    "paripé": "pa-ri-pé",
    "parir": "pa-rir",
    "parís": "pa-rís",
    "parisién": "pa-ri-sién",
    "parisiena": "pa-ri-sie-na",
    "parisiense": "pa-ri-sien-se",
    "parisílaba": "pa-ri-sí-la-ba",
    "parisilábica": "pa-ri-si-lá-bi-ca",
    "parisilábico": "pa-ri-si-lá-bi-co",
    "parisílabo": "pa-ri-sí-la-bo",
    "parisina": "pa-ri-si-na",
    "parisino": "pa-ri-si-no",
    "paritaria": "pa-ri-ta-ria",
    "paritario": "pa-ri-ta-rio",
    "paritorio": "pa-ri-to-rio",
    "parka": "par-ka",
    "parking": "par-king",
    "párkinson": "pár-kin-son",
    "parkinsonismo": "par-kin-so-nis-mo",
    "parla": "par-la",
    "parlache": "par-la-che",
    "parlador": "par-la-dor",
    "parladora": "par-la-do-ra",
    "parladuría": "par-la-du-rí-a",
    "parlaembalde": "par-la-em-bal-de",
    "parlamentar": "par-la-men-tar",
    "parlamentaria": "par-la-men-ta-ria",
    "parlamentariamente": "par-la-men-ta-ria-men-te",
    "parlamentario": "par-la-men-ta-rio",
    "parlamentarismo": "par-la-men-ta-ris-mo",
    "parlamento": "par-la-men-to",
    "parlanchín": "par-lan-chín",
    "parlanchina": "par-lan-chi-na",
    "parlante": "par-lan-te",
    "parlar": "par-lar",
    "parlatorio": "par-la-to-rio",
    "parlera": "par-le-ra",
    "parlería": "par-le-rí-a",
    "parlero": "par-le-ro",
    "parleta": "par-le-ta",
    "parlón": "par-lón",
    "parlona": "par-lo-na",
    "parlotear": "par-lo-te-ar",
    "parloteo": "par-lo-te-o",
    "parmesana": "par-me-sa-na",
    "parmesano": "par-me-sa-no",
    "parnasiana": "par-na-sia-na",
    "parnasianismo": "par-na-sia-nis-mo",
    "parnasiano": "par-na-sia-no",
    "parnaso": "par-na-so",
    "parné": "par-né",
    "paro": "pa-ro",
    "parodia": "pa-ro-dia",
    "parodiador": "pa-ro-dia-dor",
    "parodiadora": "pa-ro-dia-do-ra",
    "parodiar": "pa-ro-diar",
    "paródica": "pa-ró-di-ca",
    "paródico": "pa-ró-di-co",
    "parodista": "pa-ro-dis-ta",
    "parola": "pa-ro-la",
    "parolera": "pa-ro-le-ra",
    "parolero": "pa-ro-le-ro",
    "pároli": "pá-ro-li",
    "parolimpíada": "pa-ro-lim-pí-a-da",
    "parolimpiada": "pa-ro-lim-pia-da",
    "parolímpico": "pa-ro-lím-pi-co",
    "parolina": "pa-ro-li-na",
    "parónima": "pa-ró-ni-ma",
    "paronimia": "pa-ro-ni-mia",
    "parónimo": "pa-ró-ni-mo",
    "paroniquia": "pa-ro-ni-quia",
    "paroniquiácea": "pa-ro-ni-quiá-ce-a",
    "paroniquiáceo": "pa-ro-ni-quiá-ce-o",
    "paronomasia": "pa-ro-no-ma-sia",
    "paronomástica": "pa-ro-no-más-ti-ca",
    "paronomásticamente": "pa-ro-no-más-ti-ca-men-te",
    "paronomástico": "pa-ro-no-más-ti-co",
    "parótida": "pa-ró-ti-da",
    "parotídeo": "pa-ro-tí-de-o",
    "parotiditis": "pa-ro-ti-di-tis",
    "paroxismal": "pa-ro-xis-mal",
    "paroxismo": "pa-ro-xis-mo",
    "paroxística": "pa-ro-xís-ti-ca",
    "paroxístico": "pa-ro-xís-ti-co",
    "paroxítona": "pa-ro-xí-to-na",
    "paroxítono": "pa-ro-xí-to-no",
    "parpadeante": "par-pa-de-an-te",
    "parpadear": "par-pa-de-ar",
    "parpadeo": "par-pa-de-o",
    "párpado": "pár-pa-do",
    "parpalla": "par-pa-lla",
    "parpallota": "par-pa-llo-ta",
    "parpar": "par-par",
    "parpayuela": "par-pa-yue-la",
    "parque": "par-que",
    "parqué": "par-qué",
    "parqueadero": "par-que-a-de-ro",
    "parquear": "par-que-ar",
    "parquedad": "par-que-dad",
    "parqueo": "par-que-o",
    "parquet": "par-quet",
    "parqui": "par-qui",
    "parquímetro": "par-quí-me-tro",
    "parra": "pa-rra",
    "parrada": "pa-rra-da",
    "parrado": "pa-rra-do",
    "parrafada": "pa-rra-fa-da",
    "parrafear": "pa-rra-fe-ar",
    "parrafeo": "pa-rra-fe-o",
    "párrafo": "pá-rra-fo",
    "parragón": "pa-rra-gón",
    "parral": "pa-rral",
    "parrancas": "pa-rran-cas",
    "parranda": "pa-rran-da",
    "parrandear": "pa-rran-de-ar",
    "parrandeo": "pa-rran-de-o",
    "parrandera": "pa-rran-de-ra",
    "parrandero": "pa-rran-de-ro",
    "parrandista": "pa-rran-dis-ta",
    "parrar": "pa-rrar",
    "parrel": "pa-rrel",
    "parresia": "pa-rre-sia",
    "parricida": "pa-rri-ci-da",
    "parricidio": "pa-rri-ci-dio",
    "parrilla": "pa-rri-lla",
    "parrillada": "pa-rri-lla-da",
    "parrillera": "pa-rri-lle-ra",
    "parrillero": "pa-rri-lle-ro",
    "parrilludo": "pa-rri-llu-do",
    "parriza": "pa-rri-za",
    "parro": "pa-rro",
    "parrocha": "pa-rro-cha",
    "párroco": "pá-rro-co",
    "parrón": "pa-rrón",
    "parroquia": "pa-rro-quia",
    "parroquial": "pa-rro-quial",
    "parroquialidad": "pa-rro-quia-li-dad",
    "parroquiana": "pa-rro-quia-na",
    "parroquiano": "pa-rro-quia-no",
    "parsec": "par-sec",
    "pársec": "pár-sec",
    "parsi": "par-si",
    "parsimonia": "par-si-mo-nia",
    "parsimoniosa": "par-si-mo-nio-sa",
    "parsimonioso": "par-si-mo-nio-so",
    "parsismo": "par-sis-mo",
    "parta": "par-ta",
    "parte": "par-te",
    "partear": "par-te-ar",
    "parteluz": "par-te-luz",
    "partenaire": "par-te-nai-re",
    "partencia": "par-ten-cia",
    "partenogénesis": "par-te-no-gé-ne-sis",
    "partenogenética": "par-te-no-ge-né-ti-ca",
    "partenogenético": "par-te-no-ge-né-ti-co",
    "partenopea": "par-te-no-pe-a",
    "partenopeo": "par-te-no-pe-o",
    "partera": "par-te-ra",
    "partería": "par-te-rí-a",
    "partero": "par-te-ro",
    "parterre": "par-te-rre",
    "partesana": "par-te-sa-na",
    "partible": "par-ti-ble",
    "partición": "par-ti-ción",
    "particionera": "par-ti-cio-ne-ra",
    "particionero": "par-ti-cio-ne-ro",
    "participación": "par-ti-ci-pa-ción",
    "participante": "par-ti-ci-pan-te",
    "participar": "par-ti-ci-par",
    "participativo": "par-ti-ci-pa-ti-vo",
    "partícipe": "par-tí-ci-pe",
    "participial": "par-ti-ci-pial",
    "participio": "par-ti-ci-pio",
    "partícula": "par-tí-cu-la",
    "particular": "par-ti-cu-lar",
    "particularidad": "par-ti-cu-la-ri-dad",
    "particularismo": "par-ti-cu-la-ris-mo",
    "particularista": "par-ti-cu-la-ris-ta",
    "particularización": "par-ti-cu-la-ri-za-ción",
    "particularizar": "par-ti-cu-la-ri-zar",
    "particularmente": "par-ti-cu-lar-men-te",
    "partida": "par-ti-da",
    "partidamente": "par-ti-da-men-te",
    "partidaria": "par-ti-da-ria",
    "partidario": "par-ti-da-rio",
    "partideña": "par-ti-de-ña",
    "partideño": "par-ti-de-ño",
    "partidero": "par-ti-de-ro",
    "partidismo": "par-ti-dis-mo",
    "partidista": "par-ti-dis-ta",
    "partido": "par-ti-do",
    "partidor": "par-ti-dor",
    "partidura": "par-ti-du-ra",
    "partija": "par-ti-ja",
    "partil": "par-til",
    "partimiento": "par-ti-mien-to",
    "partiquina": "par-ti-qui-na",
    "partiquino": "par-ti-qui-no",
    "partir": "par-tir",
    "partisana": "par-ti-sa-na",
    "partisano": "par-ti-sa-no",
    "partitiva": "par-ti-ti-va",
    "partitivo": "par-ti-ti-vo",
    "partitocracia": "par-ti-to-cra-cia",
    "partitura": "par-ti-tu-ra",
    "parto": "par-to",
    "partura": "par-tu-ra",
    "parturienta": "par-tu-rien-ta",
    "parturiente": "par-tu-rien-te",
    "partusa": "par-tu-sa",
    "párulis": "pá-ru-lis",
    "parusía": "pa-ru-sí-a",
    "parva": "par-va",
    "parvada": "par-va-da",
    "parvedad": "par-ve-dad",
    "parvero": "par-ve-ro",
    "parvidad": "par-vi-dad",
    "parvífica": "par-ví-fi-ca",
    "parvificar": "par-vi-fi-car",
    "parvificencia": "par-vi-fi-cen-cia",
    "parvífico": "par-ví-fi-co",
    "parvifundio": "par-vi-fun-dio",
    "parvo": "par-vo",
    "párvula": "pár-vu-la",
    "parvulario": "par-vu-la-rio",
    "parvulez": "par-vu-lez",
    "parvulista": "par-vu-lis-ta",
    "párvulo": "pár-vu-lo",
    "pasa": "pa-sa",
    "pasable": "pa-sa-ble",
    "pasabocas": "pa-sa-bo-cas",
    "pasabola": "pa-sa-bo-la",
    "pasacaballo": "pa-sa-ca-ba-llo",
    "pasacalle": "pa-sa-ca-lle",
    "pasacana": "pa-sa-ca-na",
    "pasacasete": "pa-sa-ca-se-te",
    "pasacólica": "pa-sa-có-li-ca",
    "pasada": "pa-sa-da",
    "pasadera": "pa-sa-de-ra",
    "pasaderamente": "pa-sa-de-ra-men-te",
    "pasadero": "pa-sa-de-ro",
    "pasadía": "pa-sa-dí-a",
    "pasadillo": "pa-sa-di-llo",
    "pasadiscos": "pa-sa-dis-cos",
    "pasadizo": "pa-sa-di-zo",
    "pasado": "pa-sa-do",
    "pasador": "pa-sa-dor",
    "pasadora": "pa-sa-do-ra",
    "pasadura": "pa-sa-du-ra",
    "pasagonzalo": "pa-sa-gon-za-lo",
    "pasaje": "pa-sa-je",
    "pasajera": "pa-sa-je-ra",
    "pasajero": "pa-sa-je-ro",
    "pasajuego": "pa-sa-jue-go",
    "pasamanar": "pa-sa-ma-nar",
    "pasamanera": "pa-sa-ma-ne-ra",
    "pasamanería": "pa-sa-ma-ne-rí-a",
    "pasamanero": "pa-sa-ma-ne-ro",
    "pasamano": "pa-sa-ma-no",
    "pasamanos": "pa-sa-ma-nos",
    "pasamiento": "pa-sa-mien-to",
    "pasamontañas": "pa-sa-mon-ta-ñas",
    "pasamuros": "pa-sa-mu-ros",
    "pasancalla": "pa-san-ca-lla",
    "pasante": "pa-san-te",
    "pasantía": "pa-san-tí-a",
    "pasanza": "pa-san-za",
    "pasapalo": "pa-sa-pa-lo",
    "pasapán": "pa-sa-pán",
    "pasapasa": "pa-sa-pa-sa",
    "pasaperro": "pa-sa-pe-rro",
    "pasaplatos": "pa-sa-pla-tos",
    "pasaportar": "pa-sa-por-tar",
    "pasaporte": "pa-sa-por-te",
    "pasapuré": "pa-sa-pu-ré",
    "pasapurés": "pa-sa-pu-rés",
    "pasar": "pa-sar",
    "pasarela": "pa-sa-re-la",
    "pasarraya": "pa-sa-rra-ya",
    "pasatiempo": "pa-sa-tiem-po",
    "pasatoro": "pa-sa-to-ro",
    "pasaturo": "pa-sa-tu-ro",
    "pasavante": "pa-sa-van-te",
    "pasavolante": "pa-sa-vo-lan-te",
    "pasavoleo": "pa-sa-vo-le-o",
    "pascal": "pas-cal",
    "pascana": "pas-ca-na",
    "pascasio": "pas-ca-sio",
    "pasco": "pas-co",
    "pascón": "pas-cón",
    "pascua": "pas-cua",
    "pascual": "pas-cual",
    "pascuense": "pas-cuen-se",
    "pascuero": "pas-cue-ro",
    "pascuilla": "pas-cui-lla",
    "pase": "pa-se",
    "paseada": "pa-se-a-da",
    "paseadero": "pa-se-a-de-ro",
    "paseador": "pa-se-a-dor",
    "paseadora": "pa-se-a-do-ra",
    "paseandera": "pa-se-an-de-ra",
    "paseandero": "pa-se-an-de-ro",
    "paseante": "pa-se-an-te",
    "pasear": "pa-se-ar",
    "paseata": "pa-se-a-ta",
    "paseíllo": "pa-se-í-llo",
    "paseo": "pa-se-o",
    "pasera": "pa-se-ra",
    "paseriforme": "pa-se-ri-for-me",
    "pasero": "pa-se-ro",
    "pasibilidad": "pa-si-bi-li-dad",
    "pasible": "pa-si-ble",
    "pasicorta": "pa-si-cor-ta",
    "pasicorto": "pa-si-cor-to",
    "pasiega": "pa-sie-ga",
    "pasiego": "pa-sie-go",
    "pasificación": "pa-si-fi-ca-ción",
    "pasiflora": "pa-si-flo-ra",
    "pasiflorácea": "pa-si-flo-rá-ce-a",
    "pasifloráceo": "pa-si-flo-rá-ce-o",
    "pasiflórea": "pa-si-fló-re-a",
    "pasiflóreo": "pa-si-fló-re-o",
    "pasil": "pa-sil",
    "pasilarga": "pa-si-lar-ga",
    "pasilargo": "pa-si-lar-go",
    "pasillo": "pa-si-llo",
    "pasión": "pa-sión",
    "pasional": "pa-sio-nal",
    "pasionaria": "pa-sio-na-ria",
    "pasionario": "pa-sio-na-rio",
    "pasioncilla": "pa-sion-ci-lla",
    "pasionera": "pa-sio-ne-ra",
    "pasionero": "pa-sio-ne-ro",
    "pasionista": "pa-sio-nis-ta",
    "pasitamente": "pa-si-ta-men-te",
    "pasito": "pa-si-to",
    "pasitrote": "pa-si-tro-te",
    "pasiva": "pa-si-va",
    "pasivamente": "pa-si-va-men-te",
    "pasividad": "pa-si-vi-dad",
    "pasivo": "pa-si-vo",
    "pasma": "pas-ma",
    "pasmada": "pas-ma-da",
    "pasmado": "pas-ma-do",
    "pasmar": "pas-mar",
    "pasmarota": "pas-ma-ro-ta",
    "pasmarotada": "pas-ma-ro-ta-da",
    "pasmarote": "pas-ma-ro-te",
    "pasmo": "pas-mo",
    "pasmón": "pas-món",
    "pasmona": "pas-mo-na",
    "pasmosa": "pas-mo-sa",
    "pasmosamente": "pas-mo-sa-men-te",
    "pasmoso": "pas-mo-so",
    "paso": "pa-so",
    "pasodoble": "pa-so-do-ble",
    "pasoso": "pa-so-so",
    "pasota": "pa-so-ta",
    "pasote": "pa-so-te",
    "pasotismo": "pa-so-tis-mo",
    "paspado": "pas-pa-do",
    "paspadura": "pas-pa-du-ra",
    "paspar": "pas-par",
    "paspartú": "pas-par-tú",
    "paspié": "pas-pié",
    "pasqueña": "pas-que-ña",
    "pasqueño": "pas-que-ño",
    "pasquín": "pas-quín",
    "pasquinada": "pas-qui-na-da",
    "pasquinar": "pas-qui-nar",
    "pássim": "pás-sim",
    "pasta": "pas-ta",
    "pastaceña": "pas-ta-ce-ña",
    "pastaceño": "pas-ta-ce-ño",
    "pastadero": "pas-ta-de-ro",
    "pastador": "pas-ta-dor",
    "pastadora": "pas-ta-do-ra",
    "pastaflora": "pas-ta-flo-ra",
    "pastar": "pas-tar",
    "paste": "pas-te",
    "pasteada": "pas-te-a-da",
    "pastear": "pas-te-ar",
    "pasteca": "pas-te-ca",
    "pastel": "pas-tel",
    "pastelear": "pas-te-le-ar",
    "pasteleo": "pas-te-le-o",
    "pastelera": "pas-te-le-ra",
    "pastelería": "pas-te-le-rí-a",
    "pastelero": "pas-te-le-ro",
    "pastelillo": "pas-te-li-llo",
    "pastelista": "pas-te-lis-ta",
    "pastelón": "pas-te-lón",
    "pastenca": "pas-ten-ca",
    "pastenco": "pas-ten-co",
    "pastense": "pas-ten-se",
    "pasterización": "pas-te-ri-za-ción",
    "pasterizar": "pas-te-ri-zar",
    "pastero": "pas-te-ro",
    "pasteurización": "pas-teu-ri-za-ción",
    "pasteurizar": "pas-teu-ri-zar",
    "pastiche": "pas-ti-che",
    "pasticho": "pas-ti-cho",
    "pastilla": "pas-ti-lla",
    "pastillera": "pas-ti-lle-ra",
    "pastillero": "pas-ti-lle-ro",
    "pastina": "pas-ti-na",
    "pastinaca": "pas-ti-na-ca",
    "pastines": "pas-ti-nes",
    "pastizal": "pas-ti-zal",
    "pastle": "pas-tle",
    "pasto": "pas-to",
    "pastoforio": "pas-to-fo-rio",
    "pastón": "pas-tón",
    "pastor": "pas-tor",
    "pastora": "pas-to-ra",
    "pastorada": "pas-to-ra-da",
    "pastoral": "pas-to-ral",
    "pastoralmente": "pas-to-ral-men-te",
    "pastorear": "pas-to-re-ar",
    "pastorela": "pas-to-re-la",
    "pastoreo": "pas-to-re-o",
    "pastoría": "pas-to-rí-a",
    "pastoricia": "pas-to-ri-cia",
    "pastoricio": "pas-to-ri-cio",
    "pastoriego": "pas-to-rie-go",
    "pastoril": "pas-to-ril",
    "pastorilmente": "pas-to-ril-men-te",
    "pastosa": "pas-to-sa",
    "pastosidad": "pas-to-si-dad",
    "pastoso": "pas-to-so",
    "pastral": "pas-tral",
    "pastrana": "pas-tra-na",
    "pastraña": "pas-tra-ña",
    "pastrano": "pas-tra-no",
    "pastrija": "pas-tri-ja",
    "pastueño": "pas-tue-ño",
    "pastura": "pas-tu-ra",
    "pasturaje": "pas-tu-ra-je",
    "pasturar": "pas-tu-rar",
    "pastusa": "pas-tu-sa",
    "pastuso": "pas-tu-so",
    "pasuda": "pa-su-da",
    "pasudo": "pa-su-do",
    "pásula": "pá-su-la",
    "pata": "pa-ta",
    "patabán": "pa-ta-bán",
    "pataca": "pa-ta-ca",
    "patacamayeña": "pa-ta-ca-ma-ye-ña",
    "patacamayeño": "pa-ta-ca-ma-ye-ño",
    "patache": "pa-ta-che",
    "pataco": "pa-ta-co",
    "patacón": "pa-ta-cón",
    "patada": "pa-ta-da",
    "patadión": "pa-ta-dión",
    "patado": "pa-ta-do",
    "patadura": "pa-ta-du-ra",
    "patagón": "pa-ta-gón",
    "patagona": "pa-ta-go-na",
    "patagónica": "pa-ta-gó-ni-ca",
    "patagónico": "pa-ta-gó-ni-co",
    "patagorrilla": "pa-ta-go-rri-lla",
    "patagorrillo": "pa-ta-go-rri-llo",
    "patagua": "pa-ta-gua",
    "patagüino": "pa-ta-güi-no",
    "pataiperro": "pa-tai-pe-rro",
    "pataje": "pa-ta-je",
    "patajú": "pa-ta-jú",
    "patalear": "pa-ta-le-ar",
    "pataleo": "pa-ta-le-o",
    "pataleta": "pa-ta-le-ta",
    "pataletilla": "pa-ta-le-ti-lla",
    "patalsuelo": "pa-tal-sue-lo",
    "patán": "pa-tán",
    "patanco": "pa-tan-co",
    "patanería": "pa-ta-ne-rí-a",
    "patango": "pa-tan-go",
    "patantaca": "pa-tan-ta-ca",
    "patao": "pa-ta-o",
    "patapelada": "pa-ta-pe-la-da",
    "pataperro": "pa-ta-pe-rro",
    "pataplum": "pa-ta-plum",
    "patarata": "pa-ta-ra-ta",
    "pataratera": "pa-ta-ra-te-ra",
    "pataratero": "pa-ta-ra-te-ro",
    "patarra": "pa-ta-rra",
    "patarráez": "pa-ta-rrá-ez",
    "pataruco": "pa-ta-ru-co",
    "patas": "pa-tas",
    "patasca": "pa-tas-ca",
    "patasola": "pa-ta-so-la",
    "patata": "pa-ta-ta",
    "patatal": "pa-ta-tal",
    "patatar": "pa-ta-tar",
    "patatear": "pa-ta-te-ar",
    "patatera": "pa-ta-te-ra",
    "patatero": "pa-ta-te-ro",
    "patatín": "pa-ta-tín",
    "patatús": "pa-ta-tús",
    "patavina": "pa-ta-vi-na",
    "patavino": "pa-ta-vi-no",
    "patax": "pa-tax",
    "patay": "pa-tay",
    "pate": "pa-te",
    "paté": "pa-té",
    "pateada": "pa-te-a-da",
    "pateadura": "pa-te-a-du-ra",
    "pateamiento": "pa-te-a-mien-to",
    "patear": "pa-te-ar",
    "patena": "pa-te-na",
    "patencia": "pa-ten-cia",
    "patentado": "pa-ten-ta-do",
    "patentar": "pa-ten-tar",
    "patente": "pa-ten-te",
    "patentemente": "pa-ten-te-men-te",
    "patentizar": "pa-ten-ti-zar",
    "pateo": "pa-te-o",
    "páter": "pá-ter",
    "patera": "pa-te-ra",
    "pátera": "pá-te-ra",
    "paterfamilias": "pa-ter-fa-mi-lias",
    "patería": "pa-te-rí-a",
    "paterna": "pa-ter-na",
    "paternal": "pa-ter-nal",
    "paternalismo": "pa-ter-na-lis-mo",
    "paternalista": "pa-ter-na-lis-ta",
    "paternalmente": "pa-ter-nal-men-te",
    "paternidad": "pa-ter-ni-dad",
    "paterno": "pa-ter-no",
    "paternóster": "pa-ter-nós-ter",
    "patero": "pa-te-ro",
    "pateta": "pa-te-ta",
    "patética": "pa-té-ti-ca",
    "patéticamente": "pa-té-ti-ca-men-te",
    "patético": "pa-té-ti-co",
    "patetismo": "pa-te-tis-mo",
    "patí": "pa-tí",
    "patiabierta": "pa-tia-bier-ta",
    "patiabierto": "pa-tia-bier-to",
    "patialba": "pa-tial-ba",
    "patialbillo": "pa-tial-bi-llo",
    "patialbo": "pa-tial-bo",
    "patiblanca": "pa-ti-blan-ca",
    "patiblanco": "pa-ti-blan-co",
    "patibularia": "pa-ti-bu-la-ria",
    "patibulario": "pa-ti-bu-la-rio",
    "patíbulo": "pa-tí-bu-lo",
    "patichueco": "pa-ti-chue-co",
    "paticoja": "pa-ti-co-ja",
    "paticojo": "pa-ti-co-jo",
    "paticorto": "pa-ti-cor-to",
    "patidifusa": "pa-ti-di-fu-sa",
    "patidifuso": "pa-ti-di-fu-so",
    "patiestevada": "pa-ties-te-va-da",
    "patiestevado": "pa-ties-te-va-do",
    "patihendida": "pa-tihen-di-da",
    "patihendido": "pa-tihen-di-do",
    "patilla": "pa-ti-lla",
    "patilluda": "pa-ti-llu-da",
    "patilludo": "pa-ti-llu-do",
    "patimuleña": "pa-ti-mu-le-ña",
    "patimuleño": "pa-ti-mu-le-ño",
    "patín": "pa-tín",
    "pátina": "pá-ti-na",
    "patinada": "pa-ti-na-da",
    "patinadero": "pa-ti-na-de-ro",
    "patinador": "pa-ti-na-dor",
    "patinadora": "pa-ti-na-do-ra",
    "patinaje": "pa-ti-na-je",
    "patinar": "pa-ti-nar",
    "patinata": "pa-ti-na-ta",
    "patinazo": "pa-ti-na-zo",
    "patineta": "pa-ti-ne-ta",
    "patinete": "pa-ti-ne-te",
    "patinillo": "pa-ti-ni-llo",
    "patio": "pa-tio",
    "patipelada": "pa-ti-pe-la-da",
    "patipelado": "pa-ti-pe-la-do",
    "patiperra": "pa-ti-pe-rra",
    "patiperrear": "pa-ti-pe-rre-ar",
    "patiperro": "pa-ti-pe-rro",
    "patiquebrar": "pa-ti-que-brar",
    "patitiesa": "pa-ti-tie-sa",
    "patitieso": "pa-ti-tie-so",
    "patito": "pa-ti-to",
    "patituerta": "pa-ti-tuer-ta",
    "patituerto": "pa-ti-tuer-to",
    "patiza": "pa-ti-za",
    "patizamba": "pa-ti-zam-ba",
    "patizambo": "pa-ti-zam-bo",
    "pato": "pa-to",
    "patochada": "pa-to-cha-da",
    "patofobia": "pa-to-fo-bia",
    "patógena": "pa-tó-ge-na",
    "patogénesis": "pa-to-gé-ne-sis",
    "patogenia": "pa-to-ge-nia",
    "patogénica": "pa-to-gé-ni-ca",
    "patogénico": "pa-to-gé-ni-co",
    "patógeno": "pa-tó-ge-no",
    "patognomónica": "pa-tog-no-mó-ni-ca",
    "patognomónico": "pa-tog-no-mó-ni-co",
    "patografía": "pa-to-gra-fí-a",
    "patoja": "pa-to-ja",
    "patojear": "pa-to-je-ar",
    "patojera": "pa-to-je-ra",
    "patojo": "pa-to-jo",
    "patóloga": "pa-tó-lo-ga",
    "patología": "pa-to-lo-gí-a",
    "patológica": "pa-to-ló-gi-ca",
    "patológico": "pa-to-ló-gi-co",
    "patólogo": "pa-tó-lo-go",
    "patón": "pa-tón",
    "patona": "pa-to-na",
    "patosa": "pa-to-sa",
    "patoso": "pa-to-so",
    "patota": "pa-to-ta",
    "patotear": "pa-to-te-ar",
    "patotera": "pa-to-te-ra",
    "patotero": "pa-to-te-ro",
    "patraña": "pa-tra-ña",
    "patrañera": "pa-tra-ñe-ra",
    "patrañero": "pa-tra-ñe-ro",
    "patria": "pa-tria",
    "patriada": "pa-tria-da",
    "patriar": "pa-triar",
    "patriarca": "pa-triar-ca",
    "patriarcado": "pa-triar-ca-do",
    "patriarcal": "pa-triar-cal",
    "patricia": "pa-tri-cia",
    "patriciado": "pa-tri-cia-do",
    "patriciana": "pa-tri-cia-na",
    "patriciano": "pa-tri-cia-no",
    "patricida": "pa-tri-ci-da",
    "patricio": "pa-tri-cio",
    "patriedad": "pa-trie-dad",
    "patrilineal": "pa-tri-li-ne-al",
    "patrimonial": "pa-tri-mo-nial",
    "patrimonialidad": "pa-tri-mo-nia-li-dad",
    "patrimonialista": "pa-tri-mo-nia-lis-ta",
    "patrimonio": "pa-tri-mo-nio",
    "patrinquear": "pa-trin-que-ar",
    "patrio": "pa-trio",
    "patriota": "pa-trio-ta",
    "patriotera": "pa-trio-te-ra",
    "patriotería": "pa-trio-te-rí-a",
    "patrioterismo": "pa-trio-te-ris-mo",
    "patriotero": "pa-trio-te-ro",
    "patriótica": "pa-trió-ti-ca",
    "patrióticamente": "pa-trió-ti-ca-men-te",
    "patriótico": "pa-trió-ti-co",
    "patriotismo": "pa-trio-tis-mo",
    "patrística": "pa-trís-ti-ca",
    "patrístico": "pa-trís-ti-co",
    "patrocinada": "pa-tro-ci-na-da",
    "patrocinado": "pa-tro-ci-na-do",
    "patrocinador": "pa-tro-ci-na-dor",
    "patrocinadora": "pa-tro-ci-na-do-ra",
    "patrocinar": "pa-tro-ci-nar",
    "patrocinio": "pa-tro-ci-nio",
    "patrología": "pa-tro-lo-gí-a",
    "patrón": "pa-trón",
    "patrona": "pa-tro-na",
    "patronada": "pa-tro-na-da",
    "patronado": "pa-tro-na-do",
    "patronal": "pa-tro-nal",
    "patronato": "pa-tro-na-to",
    "patronazgo": "pa-tro-naz-go",
    "patronear": "pa-tro-ne-ar",
    "patronero": "pa-tro-ne-ro",
    "patronil": "pa-tro-nil",
    "patronímica": "pa-tro-ní-mi-ca",
    "patronímico": "pa-tro-ní-mi-co",
    "patrono": "pa-tro-no",
    "patrulla": "pa-tru-lla",
    "patrullaje": "pa-tru-lla-je",
    "patrullar": "pa-tru-llar",
    "patrullera": "pa-tru-lle-ra",
    "patrullero": "pa-tru-lle-ro",
    "patucha": "pa-tu-cha",
    "patucho": "pa-tu-cho",
    "patuco": "pa-tu-co",
    "patuda": "pa-tu-da",
    "patudez": "pa-tu-dez",
    "patudo": "pa-tu-do",
    "patujú": "pa-tu-jú",
    "patulea": "pa-tu-le-a",
    "patuleco": "pa-tu-le-co",
    "patullar": "pa-tu-llar",
    "paturra": "pa-tu-rra",
    "paturro": "pa-tu-rro",
    "patuto": "pa-tu-to",
    "paucartambina": "pau-car-tam-bi-na",
    "paucartambino": "pau-car-tam-bi-no",
    "paujé": "pau-jé",
    "paují": "pau-jí",
    "paujil": "pau-jil",
    "paúl": "pa-úl",
    "paular": "pau-lar",
    "paulatina": "pau-la-ti-na",
    "paulatinamente": "pau-la-ti-na-men-te",
    "paulatino": "pau-la-ti-no",
    "paulilla": "pau-li-lla",
    "paulina": "pau-li-na",
    "paulinia": "pau-li-nia",
    "paulino": "pau-li-no",
    "paulista": "pau-lis-ta",
    "paulonia": "pau-lo-nia",
    "pauperismo": "pau-pe-ris-mo",
    "pauperización": "pau-pe-ri-za-ción",
    "pauperizar": "pau-pe-ri-zar",
    "paupérrima": "pau-pé-rri-ma",
    "paupérrimo": "pau-pé-rri-mo",
    "paurópodo": "pau-ró-po-do",
    "pausa": "pau-sa",
    "pausada": "pau-sa-da",
    "pausadamente": "pau-sa-da-men-te",
    "pausado": "pau-sa-do",
    "pausar": "pau-sar",
    "pauta": "pau-ta",
    "pautada": "pau-ta-da",
    "pautado": "pau-ta-do",
    "pautador": "pau-ta-dor",
    "pautar": "pau-tar",
    "pauto": "pau-to",
    "pava": "pa-va",
    "pavada": "pa-va-da",
    "pavana": "pa-va-na",
    "pavear": "pa-ve-ar",
    "pavera": "pa-ve-ra",
    "pavero": "pa-ve-ro",
    "pavés": "pa-vés",
    "pavesa": "pa-ve-sa",
    "pavesada": "pa-ve-sa-da",
    "pavesina": "pa-ve-si-na",
    "pavezno": "pa-vez-no",
    "pavía": "pa-ví-a",
    "paviana": "pa-via-na",
    "paviano": "pa-via-no",
    "pávida": "pá-vi-da",
    "pávido": "pá-vi-do",
    "pavimentación": "pa-vi-men-ta-ción",
    "pavimentar": "pa-vi-men-tar",
    "pavimento": "pa-vi-men-to",
    "pavimiento": "pa-vi-mien-to",
    "paviota": "pa-vio-ta",
    "pavipollo": "pa-vi-po-llo",
    "pavisosa": "pa-vi-so-sa",
    "pavisoso": "pa-vi-so-so",
    "pavita": "pa-vi-ta",
    "pavito": "pa-vi-to",
    "pavitonta": "pa-vi-ton-ta",
    "pavitonto": "pa-vi-ton-to",
    "pavo": "pa-vo",
    "pavón": "pa-vón",
    "pavonada": "pa-vo-na-da",
    "pavonado": "pa-vo-na-do",
    "pavonador": "pa-vo-na-dor",
    "pavonadora": "pa-vo-na-do-ra",
    "pavonar": "pa-vo-nar",
    "pavonazo": "pa-vo-na-zo",
    "pavonear": "pa-vo-ne-ar",
    "pavoneo": "pa-vo-ne-o",
    "pavor": "pa-vor",
    "pavorde": "pa-vor-de",
    "pavordear": "pa-vor-de-ar",
    "pavordía": "pa-vor-dí-a",
    "pavorida": "pa-vo-ri-da",
    "pavorido": "pa-vo-ri-do",
    "pavorosa": "pa-vo-ro-sa",
    "pavorosamente": "pa-vo-ro-sa-men-te",
    "pavoroso": "pa-vo-ro-so",
    "pavota": "pa-vo-ta",
    "pavote": "pa-vo-te",
    "pavura": "pa-vu-ra",
    "paxte": "pax-te",
    "paya": "pa-ya",
    "payacate": "pa-ya-ca-te",
    "payada": "pa-ya-da",
    "payador": "pa-ya-dor",
    "payadora": "pa-ya-do-ra",
    "payaguá": "pa-ya-guá",
    "payama": "pa-ya-ma",
    "payana": "pa-ya-na",
    "payanés": "pa-ya-nés",
    "payanesa": "pa-ya-ne-sa",
    "payar": "pa-yar",
    "payasa": "pa-ya-sa",
    "payasada": "pa-ya-sa-da",
    "payasear": "pa-ya-se-ar",
    "payaso": "pa-ya-so",
    "payaya": "pa-ya-ya",
    "payé": "pa-yé",
    "payés": "pa-yés",
    "payesa": "pa-ye-sa",
    "payo": "pa-yo",
    "payuca": "pa-yu-ca",
    "payuco": "pa-yu-co",
    "payuelas": "pa-yue-las",
    "payulo": "pa-yu-lo",
    "pazcón": "paz-cón",
    "pazguata": "paz-gua-ta",
    "pazguatería": "paz-gua-te-rí-a",
    "pazguato": "paz-gua-to",
    "pazo": "pa-zo",
    "pazote": "pa-zo-te",
    "pazpuerca": "paz-puer-ca",
    "pea": "pe-a",
    "peaje": "pe-a-je",
    "peajero": "pe-a-je-ro",
    "peal": "pe-al",
    "pealada": "pe-a-la-da",
    "pealar": "pe-a-lar",
    "pealera": "pe-a-le-ra",
    "peán": "pe-án",
    "peana": "pe-a-na",
    "peaña": "pe-a-ña",
    "pear": "pe-ar",
    "peatón": "pe-a-tón",
    "peatona": "pe-a-to-na",
    "peatonal": "pe-a-to-nal",
    "peatonalización": "pe-a-to-na-li-za-ción",
    "peatonalizar": "pe-a-to-na-li-zar",
    "pebeta": "pe-be-ta",
    "pebete": "pe-be-te",
    "pebetero": "pe-be-te-ro",
    "pebida": "pe-bi-da",
    "pebrada": "pe-bra-da",
    "pebre": "pe-bre",
    "pebrina": "pe-bri-na",
    "peca": "pe-ca",
    "pecable": "pe-ca-ble",
    "pecado": "pe-ca-do",
    "pecador": "pe-ca-dor",
    "pecadora": "pe-ca-do-ra",
    "pecadoriza": "pe-ca-do-ri-za",
    "pecadorizo": "pe-ca-do-ri-zo",
    "pecaminosa": "pe-ca-mi-no-sa",
    "pecaminoso": "pe-ca-mi-no-so",
    "pecán": "pe-cán",
    "pecana": "pe-ca-na",
    "pecante": "pe-can-te",
    "pecar": "pe-car",
    "pecarí": "pe-ca-rí",
    "pecatriz": "pe-ca-triz",
    "pecblenda": "pec-blen-da",
    "pece": "pe-ce",
    "peceña": "pe-ce-ña",
    "peceño": "pe-ce-ño",
    "pecera": "pe-ce-ra",
    "pecero": "pe-ce-ro",
    "peceto": "pe-ce-to",
    "pecha": "pe-cha",
    "pechada": "pe-cha-da",
    "pechador": "pe-cha-dor",
    "pechadora": "pe-cha-do-ra",
    "pechal": "pe-chal",
    "pechar": "pe-char",
    "pechardino": "pe-char-di-no",
    "pechazo": "pe-cha-zo",
    "pechblenda": "pech-blen-da",
    "peche": "pe-che",
    "pechear": "pe-che-ar",
    "pechelingue": "pe-che-lin-gue",
    "pechera": "pe-che-ra",
    "pechería": "pe-che-rí-a",
    "pechero": "pe-che-ro",
    "pechiazul": "pe-chia-zul",
    "pechiblanca": "pe-chi-blan-ca",
    "pechiblanco": "pe-chi-blan-co",
    "pechiche": "pe-chi-che",
    "pechicolorado": "pe-chi-co-lo-ra-do",
    "pechigonga": "pe-chi-gon-ga",
    "pechil": "pe-chil",
    "pechillo": "pe-chi-llo",
    "pechín": "pe-chín",
    "pechina": "pe-chi-na",
    "pechirrojo": "pe-chi-rro-jo",
    "pechisacada": "pe-chi-sa-ca-da",
    "pechisacado": "pe-chi-sa-ca-do",
    "pecho": "pe-cho",
    "pechoña": "pe-cho-ña",
    "pechoño": "pe-cho-ño",
    "pechuga": "pe-chu-ga",
    "pechugazo": "pe-chu-ga-zo",
    "pechugón": "pe-chu-gón",
    "pechugona": "pe-chu-go-na",
    "pechuguera": "pe-chu-gue-ra",
    "pecienta": "pe-cien-ta",
    "peciento": "pe-cien-to",
    "pecilgo": "pe-cil-go",
    "peciluenga": "pe-ci-luen-ga",
    "peciluengo": "pe-ci-luen-go",
    "pecina": "pe-ci-na",
    "pecinal": "pe-ci-nal",
    "pecinosa": "pe-ci-no-sa",
    "pecinoso": "pe-ci-no-so",
    "pecio": "pe-cio",
    "peciolada": "pe-cio-la-da",
    "peciolado": "pe-cio-la-do",
    "pecíolo": "pe-cí-o-lo",
    "peciolo": "pe-cio-lo",
    "pécora": "pé-co-ra",
    "pecorea": "pe-co-re-a",
    "pecorear": "pe-co-re-ar",
    "pecosa": "pe-co-sa",
    "pecoso": "pe-co-so",
    "pectar": "pec-tar",
    "pectina": "pec-ti-na",
    "pectíneo": "pec-tí-ne-o",
    "pectiniforme": "pec-ti-ni-for-me",
    "pectoral": "pec-to-ral",
    "pectosa": "pec-to-sa",
    "pecuaria": "pe-cua-ria",
    "pecuario": "pe-cua-rio",
    "pecueca": "pe-cue-ca",
    "peculado": "pe-cu-la-do",
    "peculiar": "pe-cu-liar",
    "peculiaridad": "pe-cu-lia-ri-dad",
    "peculiarismo": "pe-cu-lia-ris-mo",
    "peculiarmente": "pe-cu-liar-men-te",
    "peculio": "pe-cu-lio",
    "pecunia": "pe-cu-nia",
    "pecunial": "pe-cu-nial",
    "pecuniaria": "pe-cu-nia-ria",
    "pecuniariamente": "pe-cu-nia-ria-men-te",
    "pecuniario": "pe-cu-nia-rio",
    "pedacear": "pe-da-ce-ar",
    "pedacería": "pe-da-ce-rí-a",
    "pedagoga": "pe-da-go-ga",
    "pedagogía": "pe-da-go-gí-a",
    "pedagógica": "pe-da-gó-gi-ca",
    "pedagógicamente": "pe-da-gó-gi-ca-men-te",
    "pedagógico": "pe-da-gó-gi-co",
    "pedagogo": "pe-da-go-go",
    "pedal": "pe-dal",
    "pedalada": "pe-da-la-da",
    "pedalear": "pe-da-le-ar",
    "pedaleo": "pe-da-le-o",
    "pedalera": "pe-da-le-ra",
    "pedalero": "pe-da-le-ro",
    "pedaliácea": "pe-da-liá-ce-a",
    "pedaliáceo": "pe-da-liá-ce-o",
    "pedáneo": "pe-dá-ne-o",
    "pedanía": "pe-da-ní-a",
    "pedante": "pe-dan-te",
    "pedantear": "pe-dan-te-ar",
    "pedantería": "pe-dan-te-rí-a",
    "pedantesca": "pe-dan-tes-ca",
    "pedantescamente": "pe-dan-tes-ca-men-te",
    "pedantesco": "pe-dan-tes-co",
    "pedantismo": "pe-dan-tis-mo",
    "pedazo": "pe-da-zo",
    "pederasta": "pe-de-ras-ta",
    "pederastia": "pe-de-ras-tia",
    "pedernal": "pe-der-nal",
    "pedernalense": "pe-der-na-len-se",
    "pedernalina": "pe-der-na-li-na",
    "pedernalino": "pe-der-na-li-no",
    "pedestal": "pe-des-tal",
    "pedestre": "pe-des-tre",
    "pedestrismo": "pe-des-tris-mo",
    "pediatra": "pe-dia-tra",
    "pediatría": "pe-dia-trí-a",
    "pediátrico": "pe-diá-tri-co",
    "pedicelo": "pe-di-ce-lo",
    "pediche": "pe-di-che",
    "pedicoj": "pe-di-coj",
    "pediculado": "pe-di-cu-la-do",
    "pedicular": "pe-di-cu-lar",
    "pediculicida": "pe-di-cu-li-ci-da",
    "pedículo": "pe-dí-cu-lo",
    "pediculosis": "pe-di-cu-lo-sis",
    "pedicura": "pe-di-cu-ra",
    "pedicurista": "pe-di-cu-ris-ta",
    "pedicuro": "pe-di-cu-ro",
    "pedida": "pe-di-da",
    "pedido": "pe-di-do",
    "pedidor": "pe-di-dor",
    "pedidora": "pe-di-do-ra",
    "pedidura": "pe-di-du-ra",
    "pedigón": "pe-di-gón",
    "pedigona": "pe-di-go-na",
    "pedigrí": "pe-di-grí",
    "pedigüeña": "pe-di-güe-ña",
    "pedigüeñería": "pe-di-güe-ñe-rí-a",
    "pedigüeño": "pe-di-güe-ño",
    "pedilón": "pe-di-lón",
    "pediluvio": "pe-di-lu-vio",
    "pedimento": "pe-di-men-to",
    "pedimiento": "pe-di-mien-to",
    "pedinche": "pe-din-che",
    "pedio": "pe-dio",
    "pedipalpo": "pe-di-pal-po",
    "pedir": "pe-dir",
    "pedo": "pe-do",
    "pedófila": "pe-dó-fi-la",
    "pedofilia": "pe-do-fi-lia",
    "pedófilo": "pe-dó-fi-lo",
    "pedorra": "pe-do-rra",
    "pedorrear": "pe-do-rre-ar",
    "pedorreo": "pe-do-rre-o",
    "pedorrera": "pe-do-rre-ra",
    "pedorrero": "pe-do-rre-ro",
    "pedorreta": "pe-do-rre-ta",
    "pedorrienta": "pe-do-rrien-ta",
    "pedorriento": "pe-do-rrien-to",
    "pedorro": "pe-do-rro",
    "pedrada": "pe-dra-da",
    "pedral": "pe-dral",
    "pedraplén": "pe-dra-plén",
    "pedrea": "pe-dre-a",
    "pedregal": "pe-dre-gal",
    "pedregosa": "pe-dre-go-sa",
    "pedregoso": "pe-dre-go-so",
    "pedregullo": "pe-dre-gu-llo",
    "pedrejón": "pe-dre-jón",
    "pedreñal": "pe-dre-ñal",
    "pedrense": "pe-dren-se",
    "pedrera": "pe-dre-ra",
    "pedreral": "pe-dre-ral",
    "pedrería": "pe-dre-rí-a",
    "pedrerío": "pe-dre-rí-o",
    "pedrero": "pe-dre-ro",
    "pedrés": "pe-drés",
    "pedreta": "pe-dre-ta",
    "pedrezuela": "pe-dre-zue-la",
    "pedrisca": "pe-dris-ca",
    "pedriscal": "pe-dris-cal",
    "pedrisco": "pe-dris-co",
    "pedrisquero": "pe-dris-que-ro",
    "pedriza": "pe-dri-za",
    "pedrizo": "pe-dri-zo",
    "pedro": "pe-dro",
    "pedroche": "pe-dro-che",
    "pedrojiménez": "pe-dro-ji-mé-nez",
    "pedrojuanina": "pe-dro-jua-ni-na",
    "pedrojuanino": "pe-dro-jua-ni-no",
    "pedrosa": "pe-dro-sa",
    "pedroso": "pe-dro-so",
    "pedrusco": "pe-drus-co",
    "pedunculada": "pe-dun-cu-la-da",
    "pedunculado": "pe-dun-cu-la-do",
    "pedúnculo": "pe-dún-cu-lo",
    "pedurría": "pe-du-rrí-a",
    "peeling": "pe-e-ling",
    "peer": "pe-er",
    "pega": "pe-ga",
    "pegada": "pe-ga-da",
    "pegadillo": "pe-ga-di-llo",
    "pegadiza": "pe-ga-di-za",
    "pegadizo": "pe-ga-di-zo",
    "pegado": "pe-ga-do",
    "pegador": "pe-ga-dor",
    "pegadora": "pe-ga-do-ra",
    "pegadura": "pe-ga-du-ra",
    "pegajosa": "pe-ga-jo-sa",
    "pegajosidad": "pe-ga-jo-si-dad",
    "pegajoso": "pe-ga-jo-so",
    "pegalón": "pe-ga-lón",
    "pegalona": "pe-ga-lo-na",
    "pegamento": "pe-ga-men-to",
    "pegamiento": "pe-ga-mien-to",
    "pegamín": "pe-ga-mín",
    "pegamoide": "pe-ga-moi-de",
    "pegamoscas": "pe-ga-mos-cas",
    "pegante": "pe-gan-te",
    "pegapases": "pe-ga-pa-ses",
    "pegar": "pe-gar",
    "pegasea": "pe-ga-se-a",
    "pegaseo": "pe-ga-se-o",
    "pegásides": "pe-gá-si-des",
    "pegata": "pe-ga-ta",
    "pegatina": "pe-ga-ti-na",
    "pegatoste": "pe-ga-tos-te",
    "pegmatita": "peg-ma-ti-ta",
    "pego": "pe-go",
    "pegollo": "pe-go-llo",
    "pegón": "pe-gón",
    "pegona": "pe-go-na",
    "pegote": "pe-go-te",
    "pegotear": "pe-go-te-ar",
    "pegotera": "pe-go-te-ra",
    "pegotería": "pe-go-te-rí-a",
    "pegotero": "pe-go-te-ro",
    "pegual": "pe-gual",
    "pegue": "pe-gue",
    "peguera": "pe-gue-ra",
    "peguero": "pe-gue-ro",
    "pegujal": "pe-gu-jal",
    "pegujalero": "pe-gu-ja-le-ro",
    "pegujar": "pe-gu-jar",
    "pegujarero": "pe-gu-ja-re-ro",
    "pegujón": "pe-gu-jón",
    "pegullo": "pe-gu-llo",
    "pegullón": "pe-gu-llón",
    "pegunta": "pe-gun-ta",
    "peguntar": "pe-gun-tar",
    "pegunte": "pe-gun-te",
    "peguntosa": "pe-gun-to-sa",
    "peguntoso": "pe-gun-to-so",
    "pehuén": "pe-huén",
    "pehuenche": "pe-huen-che",
    "peina": "pei-na",
    "peinada": "pei-na-da",
    "peinado": "pei-na-do",
    "peinador": "pei-na-dor",
    "peinadora": "pei-na-do-ra",
    "peinadura": "pei-na-du-ra",
    "peinar": "pei-nar",
    "peinazo": "pei-na-zo",
    "peindra": "pein-dra",
    "peine": "pei-ne",
    "peinecillo": "pei-ne-ci-llo",
    "peinera": "pei-ne-ra",
    "peinería": "pei-ne-rí-a",
    "peinero": "pei-ne-ro",
    "peineta": "pei-ne-ta",
    "peinetero": "pei-ne-te-ro",
    "peinilla": "pei-ni-lla",
    "peje": "pe-je",
    "pejegallo": "pe-je-ga-llo",
    "pejemuller": "pe-je-mu-ller",
    "pejepalo": "pe-je-pa-lo",
    "pejerrey": "pe-je-rrey",
    "pejesapo": "pe-je-sa-po",
    "pejibaye": "pe-ji-ba-ye",
    "pejiguera": "pe-ji-gue-ra",
    "pejiguero": "pe-ji-gue-ro",
    "pejín": "pe-jín",
    "pejina": "pe-ji-na",
    "pejino": "pe-ji-no",
    "pekinés": "pe-ki-nés",
    "pekinesa": "pe-ki-ne-sa",
    "pela": "pe-la",
    "pelacables": "pe-la-ca-bles",
    "pelada": "pe-la-da",
    "peladaje": "pe-la-da-je",
    "peladera": "pe-la-de-ra",
    "peladero": "pe-la-de-ro",
    "peladez": "pe-la-dez",
    "peladilla": "pe-la-di-lla",
    "peladillo": "pe-la-di-llo",
    "pelado": "pe-la-do",
    "pelador": "pe-la-dor",
    "peladora": "pe-la-do-ra",
    "peladura": "pe-la-du-ra",
    "pelafustán": "pe-la-fus-tán",
    "pelafustana": "pe-la-fus-ta-na",
    "pelagallos": "pe-la-ga-llos",
    "pelagatos": "pe-la-ga-tos",
    "pelagiana": "pe-la-gia-na",
    "pelagianismo": "pe-la-gia-nis-mo",
    "pelagiano": "pe-la-gia-no",
    "pelágica": "pe-lá-gi-ca",
    "pelágico": "pe-lá-gi-co",
    "pelagoscopio": "pe-la-gos-co-pio",
    "pelagra": "pe-la-gra",
    "pelagrosa": "pe-la-gro-sa",
    "pelagroso": "pe-la-gro-so",
    "pelaire": "pe-lai-re",
    "pelairía": "pe-lai-rí-a",
    "pelaje": "pe-la-je",
    "pelambrar": "pe-lam-brar",
    "pelambre": "pe-lam-bre",
    "pelambrera": "pe-lam-bre-ra",
    "pelambrero": "pe-lam-bre-ro",
    "pelamen": "pe-la-men",
    "pelamesa": "pe-la-me-sa",
    "pelanas": "pe-la-nas",
    "pelandrún": "pe-lan-drún",
    "pelandruna": "pe-lan-dru-na",
    "pelandusca": "pe-lan-dus-ca",
    "pelangocha": "pe-lan-go-cha",
    "pelangoche": "pe-lan-go-che",
    "pelantrín": "pe-lan-trín",
    "pelar": "pe-lar",
    "pelarela": "pe-la-re-la",
    "pelargonio": "pe-lar-go-nio",
    "pelarruecas": "pe-la-rrue-cas",
    "pelasga": "pe-las-ga",
    "pelásgica": "pe-lás-gi-ca",
    "pelásgico": "pe-lás-gi-co",
    "pelasgo": "pe-las-go",
    "pelaza": "pe-la-za",
    "pelazga": "pe-laz-ga",
    "peldaño": "pel-da-ño",
    "pelde": "pel-de",
    "peldefebre": "pel-de-fe-bre",
    "pelea": "pe-le-a",
    "peleada": "pe-le-a-da",
    "peleadera": "pe-le-a-de-ra",
    "peleador": "pe-le-a-dor",
    "peleadora": "pe-le-a-do-ra",
    "peleano": "pe-le-a-no",
    "pelear": "pe-le-ar",
    "pelecaniforme": "pe-le-ca-ni-for-me",
    "pelecha": "pe-le-cha",
    "pelechar": "pe-le-char",
    "pelecho": "pe-le-cho",
    "pelegrina": "pe-le-gri-na",
    "pelegrino": "pe-le-gri-no",
    "pelela": "pe-le-la",
    "pelele": "pe-le-le",
    "pelendengue": "pe-len-den-gue",
    "pelendón": "pe-len-dón",
    "pelendona": "pe-len-do-na",
    "peleón": "pe-le-ón",
    "peleona": "pe-le-o-na",
    "peleonera": "pe-le-o-ne-ra",
    "peleonero": "pe-le-o-ne-ro",
    "pelería": "pe-le-rí-a",
    "pelerina": "pe-le-ri-na",
    "pelero": "pe-le-ro",
    "pelete": "pe-le-te",
    "peletera": "pe-le-te-ra",
    "peletería": "pe-le-te-rí-a",
    "peletero": "pe-le-te-ro",
    "pelgar": "pel-gar",
    "peliaguda": "pe-lia-gu-da",
    "peliagudo": "pe-lia-gu-do",
    "peliblanca": "pe-li-blan-ca",
    "peliblanco": "pe-li-blan-co",
    "peliblanda": "pe-li-blan-da",
    "peliblando": "pe-li-blan-do",
    "pelicano": "pe-li-ca-no",
    "pelícano": "pe-lí-ca-no",
    "pelicorta": "pe-li-cor-ta",
    "pelicorto": "pe-li-cor-to",
    "película": "pe-lí-cu-la",
    "pelicular": "pe-li-cu-lar",
    "peliculera": "pe-li-cu-le-ra",
    "peliculero": "pe-li-cu-le-ro",
    "peliculón": "pe-li-cu-lón",
    "peliduro": "pe-li-du-ro",
    "peliforra": "pe-li-fo-rra",
    "peligna": "pe-lig-na",
    "peligno": "pe-lig-no",
    "peligrar": "pe-li-grar",
    "peligro": "pe-li-gro",
    "peligrosa": "pe-li-gro-sa",
    "peligrosamente": "pe-li-gro-sa-men-te",
    "peligrosidad": "pe-li-gro-si-dad",
    "peligroso": "pe-li-gro-so",
    "pelilarga": "pe-li-lar-ga",
    "pelilargo": "pe-li-lar-go",
    "pelillo": "pe-li-llo",
    "pelillosa": "pe-li-llo-sa",
    "pelilloso": "pe-li-llo-so",
    "pelinca": "pe-lin-ca",
    "pelinco": "pe-lin-co",
    "pelinegra": "pe-li-ne-gra",
    "pelinegro": "pe-li-ne-gro",
    "pelirroja": "pe-li-rro-ja",
    "pelirrojo": "pe-li-rro-jo",
    "pelirrubia": "pe-li-rru-bia",
    "pelirrubio": "pe-li-rru-bio",
    "pelis": "pe-lis",
    "pelitiesa": "pe-li-tie-sa",
    "pelitieso": "pe-li-tie-so",
    "pelitre": "pe-li-tre",
    "pelitrique": "pe-li-tri-que",
    "pelizorrero": "pe-li-zo-rre-ro",
    "pella": "pe-lla",
    "pellada": "pe-lla-da",
    "pelleja": "pe-lle-ja",
    "pellejera": "pe-lle-je-ra",
    "pellejería": "pe-lle-je-rí-a",
    "pellejero": "pe-lle-je-ro",
    "pellejina": "pe-lle-ji-na",
    "pellejo": "pe-lle-jo",
    "pellejuda": "pe-lle-ju-da",
    "pellejudo": "pe-lle-ju-do",
    "pelleta": "pe-lle-ta",
    "pelletera": "pe-lle-te-ra",
    "pelletería": "pe-lle-te-rí-a",
    "pelletero": "pe-lle-te-ro",
    "pellica": "pe-lli-ca",
    "pellico": "pe-lli-co",
    "pellijera": "pe-lli-je-ra",
    "pellijero": "pe-lli-je-ro",
    "pellín": "pe-llín",
    "pelliquera": "pe-lli-que-ra",
    "pelliquero": "pe-lli-que-ro",
    "pelliza": "pe-lli-za",
    "pellizcador": "pe-lliz-ca-dor",
    "pellizcadora": "pe-lliz-ca-do-ra",
    "pellizcar": "pe-lliz-car",
    "pellizco": "pe-lliz-co",
    "pello": "pe-llo",
    "pellón": "pe-llón",
    "pellote": "pe-llo-te",
    "pelluzgón": "pe-lluz-gón",
    "pelma": "pel-ma",
    "pelmacería": "pel-ma-ce-rí-a",
    "pelmaza": "pel-ma-za",
    "pelmazo": "pel-ma-zo",
    "pelo": "pe-lo",
    "pelón": "pe-lón",
    "pelona": "pe-lo-na",
    "pelonear": "pe-lo-ne-ar",
    "pelonería": "pe-lo-ne-rí-a",
    "pelonía": "pe-lo-ní-a",
    "peloponense": "pe-lo-po-nen-se",
    "peloponesia": "pe-lo-po-ne-sia",
    "peloponesiaco": "pe-lo-po-ne-sia-co",
    "peloponesio": "pe-lo-po-ne-sio",
    "pelosa": "pe-lo-sa",
    "pelosilla": "pe-lo-si-lla",
    "peloso": "pe-lo-so",
    "pelota": "pe-lo-ta",
    "pelotari": "pe-lo-ta-ri",
    "pelotazo": "pe-lo-ta-zo",
    "pelote": "pe-lo-te",
    "pelotear": "pe-lo-te-ar",
    "peloteo": "pe-lo-te-o",
    "pelotera": "pe-lo-te-ra",
    "pelotería": "pe-lo-te-rí-a",
    "pelotero": "pe-lo-te-ro",
    "pelotilla": "pe-lo-ti-lla",
    "pelotilleo": "pe-lo-ti-lle-o",
    "pelotillera": "pe-lo-ti-lle-ra",
    "pelotillero": "pe-lo-ti-lle-ro",
    "peloto": "pe-lo-to",
    "pelotón": "pe-lo-tón",
    "pelotuda": "pe-lo-tu-da",
    "pelotudear": "pe-lo-tu-de-ar",
    "pelotudez": "pe-lo-tu-dez",
    "pelotudo": "pe-lo-tu-do",
    "pelta": "pel-ta",
    "peltado": "pel-ta-do",
    "peltasta": "pel-tas-ta",
    "peltre": "pel-tre",
    "peltrero": "pel-tre-ro",
    "pelú": "pe-lú",
    "peluca": "pe-lu-ca",
    "peluche": "pe-lu-che",
    "peluco": "pe-lu-co",
    "pelucona": "pe-lu-co-na",
    "peluda": "pe-lu-da",
    "peludear": "pe-lu-de-ar",
    "peludo": "pe-lu-do",
    "peluqueada": "pe-lu-que-a-da",
    "peluquear": "pe-lu-que-ar",
    "peluquera": "pe-lu-que-ra",
    "peluquería": "pe-lu-que-rí-a",
    "peluquero": "pe-lu-que-ro",
    "peluquín": "pe-lu-quín",
    "pelusa": "pe-lu-sa",
    "pelusear": "pe-lu-se-ar",
    "pelusilla": "pe-lu-si-lla",
    "pelvi": "pel-vi",
    "pelviana": "pel-via-na",
    "pelviano": "pel-via-no",
    "pélvico": "pél-vi-co",
    "pelvímetro": "pel-ví-me-tro",
    "pelvis": "pel-vis",
    "pemón": "pe-món",
    "pena": "pe-na",
    "peña": "pe-ña",
    "penable": "pe-na-ble",
    "penachera": "pe-na-che-ra",
    "penacho": "pe-na-cho",
    "penachuda": "pe-na-chu-da",
    "penachudo": "pe-na-chu-do",
    "penada": "pe-na-da",
    "penadamente": "pe-na-da-men-te",
    "penadilla": "pe-na-di-lla",
    "penado": "pe-na-do",
    "penador": "pe-na-dor",
    "penadura": "pe-na-du-ra",
    "penal": "pe-nal",
    "penalidad": "pe-na-li-dad",
    "penalista": "pe-na-lis-ta",
    "penalización": "pe-na-li-za-ción",
    "penalizar": "pe-na-li-zar",
    "penalmente": "pe-nal-men-te",
    "penalti": "pe-nal-ti",
    "péname": "pé-na-me",
    "penante": "pe-nan-te",
    "penar": "pe-nar",
    "peñaranda": "pe-ña-ran-da",
    "peñascal": "pe-ñas-cal",
    "peñascaró": "pe-ñas-ca-ró",
    "peñascazo": "pe-ñas-ca-zo",
    "peñasco": "pe-ñas-co",
    "peñascosa": "pe-ñas-co-sa",
    "peñascoso": "pe-ñas-co-so",
    "peñasquear": "pe-ñas-que-ar",
    "penates": "pe-na-tes",
    "peñazo": "pe-ña-zo",
    "penca": "pen-ca",
    "pencada": "pen-ca-da",
    "pencal": "pen-cal",
    "pencar": "pen-car",
    "pencazal": "pen-ca-zal",
    "pencazo": "pen-ca-zo",
    "penco": "pen-co",
    "pencuda": "pen-cu-da",
    "pencudo": "pen-cu-do",
    "pendanga": "pen-dan-ga",
    "pendeja": "pen-de-ja",
    "pendejada": "pen-de-ja-da",
    "pendejear": "pen-de-je-ar",
    "pendejez": "pen-de-jez",
    "pendejo": "pen-de-jo",
    "pendencia": "pen-den-cia",
    "pendenciar": "pen-den-ciar",
    "pendenciera": "pen-den-cie-ra",
    "pendenciero": "pen-den-cie-ro",
    "pender": "pen-der",
    "pendiente": "pen-dien-te",
    "pendil": "pen-dil",
    "pendingue": "pen-din-gue",
    "pendol": "pen-dol",
    "péndola": "pén-do-la",
    "pendolaje": "pen-do-la-je",
    "pendolario": "pen-do-la-rio",
    "pendolista": "pen-do-lis-ta",
    "pendolón": "pen-do-lón",
    "pendón": "pen-dón",
    "pendona": "pen-do-na",
    "pendonear": "pen-do-ne-ar",
    "pendoneo": "pen-do-ne-o",
    "pendoneta": "pen-do-ne-ta",
    "pendonista": "pen-do-nis-ta",
    "pendorcho": "pen-dor-cho",
    "pendrar": "pen-drar",
    "péndula": "pén-du-la",
    "pendular": "pen-du-lar",
    "péndulo": "pén-du-lo",
    "pendura": "pen-du-ra",
    "pene": "pe-ne",
    "peneca": "pe-ne-ca",
    "penedés": "pe-ne-dés",
    "peñedo": "pe-ñe-do",
    "peneirar": "pe-nei-rar",
    "penene": "pe-ne-ne",
    "peneque": "pe-ne-que",
    "penera": "pe-ne-ra",
    "peñera": "pe-ñe-ra",
    "penerar": "pe-ne-rar",
    "peñerar": "pe-ñe-rar",
    "peñero": "pe-ñe-ro",
    "penetrabilidad": "pe-ne-tra-bi-li-dad",
    "penetrable": "pe-ne-tra-ble",
    "penetración": "pe-ne-tra-ción",
    "penetrador": "pe-ne-tra-dor",
    "penetradora": "pe-ne-tra-do-ra",
    "penetral": "pe-ne-tral",
    "penetrante": "pe-ne-tran-te",
    "penetrar": "pe-ne-trar",
    "penetrativa": "pe-ne-tra-ti-va",
    "penetrativo": "pe-ne-tra-ti-vo",
    "penetro": "pe-ne-tro",
    "penetrómetro": "pe-ne-tró-me-tro",
    "peneuvista": "pe-neu-vis-ta",
    "pénfigo": "pén-fi-go",
    "peni": "pe-ni",
    "peniano": "pe-nia-no",
    "penibética": "pe-ni-bé-ti-ca",
    "penibético": "pe-ni-bé-ti-co",
    "penicilina": "pe-ni-ci-li-na",
    "penígera": "pe-ní-ge-ra",
    "penígero": "pe-ní-ge-ro",
    "penillanura": "pe-ni-lla-nu-ra",
    "penino": "pe-ni-no",
    "península": "pe-nín-su-la",
    "peninsular": "pe-nin-su-lar",
    "penique": "pe-ni-que",
    "penisla": "pe-nis-la",
    "penitencia": "pe-ni-ten-cia",
    "penitenciada": "pe-ni-ten-cia-da",
    "penitenciado": "pe-ni-ten-cia-do",
    "penitencial": "pe-ni-ten-cial",
    "penitenciar": "pe-ni-ten-ciar",
    "penitenciaría": "pe-ni-ten-cia-rí-a",
    "penitenciaria": "pe-ni-ten-cia-ria",
    "penitenciario": "pe-ni-ten-cia-rio",
    "penitenta": "pe-ni-ten-ta",
    "penitente": "pe-ni-ten-te",
    "peno": "pe-no",
    "peño": "pe-ño",
    "penol": "pe-nol",
    "peñol": "pe-ñol",
    "péñola": "pé-ño-la",
    "peñolada": "pe-ño-la-da",
    "peñón": "pe-ñón",
    "penonomeña": "pe-no-no-me-ña",
    "penonomeño": "pe-no-no-me-ño",
    "penosa": "pe-no-sa",
    "penoso": "pe-no-so",
    "penqueada": "pen-que-a-da",
    "penquear": "pen-que-ar",
    "penquista": "pen-quis-ta",
    "pensable": "pen-sa-ble",
    "pensada": "pen-sa-da",
    "pensado": "pen-sa-do",
    "pensador": "pen-sa-dor",
    "pensadora": "pen-sa-do-ra",
    "pensamiento": "pen-sa-mien-to",
    "pensante": "pen-san-te",
    "pensar": "pen-sar",
    "pensativa": "pen-sa-ti-va",
    "pensativo": "pen-sa-ti-vo",
    "pensel": "pen-sel",
    "penseque": "pen-se-que",
    "pensier": "pen-sier",
    "pensil": "pen-sil",
    "pénsil": "pén-sil",
    "pensilvana": "pen-sil-va-na",
    "pensilvano": "pen-sil-va-no",
    "pensión": "pen-sión",
    "pensionada": "pen-sio-na-da",
    "pensionado": "pen-sio-na-do",
    "pensionar": "pen-sio-nar",
    "pensionario": "pen-sio-na-rio",
    "pensionista": "pen-sio-nis-ta",
    "pentacampeón": "pen-ta-cam-pe-ón",
    "pentacordio": "pen-ta-cor-dio",
    "pentadáctila": "pen-ta-dác-ti-la",
    "pentadáctilo": "pen-ta-dác-ti-lo",
    "pentadecágono": "pen-ta-de-cá-go-no",
    "pentadecasílabo": "pen-ta-de-ca-sí-la-bo",
    "pentaedro": "pen-ta-e-dro",
    "pentágona": "pen-tá-go-na",
    "pentagonal": "pen-ta-go-nal",
    "pentágono": "pen-tá-go-no",
    "pentagrama": "pen-ta-gra-ma",
    "pentágrama": "pen-tá-gra-ma",
    "pentámera": "pen-tá-me-ra",
    "pentámero": "pen-tá-me-ro",
    "pentámetro": "pen-tá-me-tro",
    "pentano": "pen-ta-no",
    "pentápolis": "pen-tá-po-lis",
    "pentapolitana": "pen-ta-po-li-ta-na",
    "pentapolitano": "pen-ta-po-li-ta-no",
    "pentarquía": "pen-tar-quí-a",
    "pentasílaba": "pen-ta-sí-la-ba",
    "pentasílabo": "pen-ta-sí-la-bo",
    "pentatleta": "pen-ta-tle-ta",
    "pentatlón": "pen-ta-tlón",
    "pentavalente": "pen-ta-va-len-te",
    "pentecostal": "pen-te-cos-tal",
    "pentecostés": "pen-te-cos-tés",
    "pentélica": "pen-té-li-ca",
    "pentélico": "pen-té-li-co",
    "penthouse": "pent-house",
    "pentodo": "pen-to-do",
    "pentotal": "pen-to-tal",
    "pentrita": "pen-tri-ta",
    "penúltima": "pe-núl-ti-ma",
    "penúltimo": "pe-núl-ti-mo",
    "penumbra": "pe-num-bra",
    "penumbrosa": "pe-num-bro-sa",
    "penumbroso": "pe-num-bro-so",
    "penuria": "pe-nu-ria",
    "peón": "pe-ón",
    "peonada": "pe-o-na-da",
    "peonaje": "pe-o-na-je",
    "peonería": "pe-o-ne-rí-a",
    "peonero": "pe-o-ne-ro",
    "peoneta": "pe-o-ne-ta",
    "peonía": "pe-o-ní-a",
    "peonia": "pe-o-nia",
    "peonio": "pe-o-nio",
    "peonza": "pe-on-za",
    "peor": "pe-or",
    "peora": "pe-o-ra",
    "peorar": "pe-o-rar",
    "peoría": "pe-o-rí-a",
    "pepa": "pe-pa",
    "pepazo": "pe-pa-zo",
    "pepe": "pe-pe",
    "pepena": "pe-pe-na",
    "pepenable": "pe-pe-na-ble",
    "pepenador": "pe-pe-na-dor",
    "pepenadora": "pe-pe-na-do-ra",
    "pepenar": "pe-pe-nar",
    "peperina": "pe-pe-ri-na",
    "pepesca": "pe-pes-ca",
    "pepián": "pe-pián",
    "pepinar": "pe-pi-nar",
    "pepinazo": "pe-pi-na-zo",
    "pepinillo": "pe-pi-ni-llo",
    "pepino": "pe-pi-no",
    "pepión": "pe-pión",
    "pepita": "pe-pi-ta",
    "pepitazo": "pe-pi-ta-zo",
    "pepitero": "pe-pi-te-ro",
    "pepito": "pe-pi-to",
    "pepitoria": "pe-pi-to-ria",
    "pepitoso": "pe-pi-to-so",
    "pepla": "pe-pla",
    "peplo": "pe-plo",
    "péplum": "pé-plum",
    "pepón": "pe-pón",
    "pepona": "pe-po-na",
    "pepónide": "pe-pó-ni-de",
    "pepsina": "pep-si-na",
    "peptídico": "pep-tí-di-co",
    "péptido": "pép-ti-do",
    "peptona": "pep-to-na",
    "pepú": "pe-pú",
    "peque": "pe-que",
    "pequén": "pe-quén",
    "pequeña": "pe-que-ña",
    "pequeñaja": "pe-que-ña-ja",
    "pequeñajo": "pe-que-ña-jo",
    "pequeñamente": "pe-que-ña-men-te",
    "pequeñarra": "pe-que-ña-rra",
    "pequeñez": "pe-que-ñez",
    "pequeñeza": "pe-que-ñe-za",
    "pequeño": "pe-que-ño",
    "pequeñoburgués": "pe-que-ño-bur-gués",
    "pequeñoburguesa": "pe-que-ño-bur-gue-sa",
    "pequín": "pe-quín",
    "pequinense": "pe-qui-nen-se",
    "pequinés": "pe-qui-nés",
    "pequinesa": "pe-qui-ne-sa",
    "pequista": "pe-quis-ta",
    "pera": "pe-ra",
    "perada": "pe-ra-da",
    "peragrar": "pe-ra-grar",
    "peraile": "pe-rai-le",
    "peral": "pe-ral",
    "peraleda": "pe-ra-le-da",
    "peralejo": "pe-ra-le-jo",
    "peraltar": "pe-ral-tar",
    "peralte": "pe-ral-te",
    "peralto": "pe-ral-to",
    "perantón": "pe-ran-tón",
    "perborato": "per-bo-ra-to",
    "perca": "per-ca",
    "percador": "per-ca-dor",
    "percal": "per-cal",
    "percala": "per-ca-la",
    "percalina": "per-ca-li-na",
    "percán": "per-cán",
    "percance": "per-can-ce",
    "percanzar": "per-can-zar",
    "percatación": "per-ca-ta-ción",
    "percatar": "per-ca-tar",
    "percebe": "per-ce-be",
    "percebimiento": "per-ce-bi-mien-to",
    "percentil": "per-cen-til",
    "percepción": "per-cep-ción",
    "perceptibilidad": "per-cep-ti-bi-li-dad",
    "perceptible": "per-cep-ti-ble",
    "perceptiblemente": "per-cep-ti-ble-men-te",
    "perceptiva": "per-cep-ti-va",
    "perceptivo": "per-cep-ti-vo",
    "percepto": "per-cep-to",
    "perceptor": "per-cep-tor",
    "perceptora": "per-cep-to-ra",
    "perceptual": "per-cep-tual",
    "percha": "per-cha",
    "perchada": "per-cha-da",
    "perchado": "per-cha-do",
    "perchar": "per-char",
    "perchel": "per-chel",
    "perchelera": "per-che-le-ra",
    "perchelero": "per-che-le-ro",
    "perchero": "per-che-ro",
    "percherón": "per-che-rón",
    "percherona": "per-che-ro-na",
    "perchista": "per-chis-ta",
    "perchón": "per-chón",
    "perchonar": "per-cho-nar",
    "percibir": "per-ci-bir",
    "percibo": "per-ci-bo",
    "perciforme": "per-ci-for-me",
    "percloruro": "per-clo-ru-ro",
    "percocería": "per-co-ce-rí-a",
    "percocero": "per-co-ce-ro",
    "percochar": "per-co-char",
    "percocho": "per-co-cho",
    "percochón": "per-co-chón",
    "percochona": "per-co-cho-na",
    "percolación": "per-co-la-ción",
    "percolar": "per-co-lar",
    "percollar": "per-co-llar",
    "percuciente": "per-cu-cien-te",
    "percudir": "per-cu-dir",
    "percusión": "per-cu-sión",
    "percusionista": "per-cu-sio-nis-ta",
    "percusor": "per-cu-sor",
    "percutáneo": "per-cu-tá-ne-o",
    "percutiente": "per-cu-tien-te",
    "percutir": "per-cu-tir",
    "percutor": "per-cu-tor",
    "perdedero": "per-de-de-ro",
    "perdedor": "per-de-dor",
    "perdedora": "per-de-do-ra",
    "perder": "per-der",
    "perdición": "per-di-ción",
    "perdida": "per-di-da",
    "pérdida": "pér-di-da",
    "perdidamente": "per-di-da-men-te",
    "perdidiza": "per-di-di-za",
    "perdidizo": "per-di-di-zo",
    "perdido": "per-di-do",
    "perdidosa": "per-di-do-sa",
    "perdidoso": "per-di-do-so",
    "perdigana": "per-di-ga-na",
    "perdigar": "per-di-gar",
    "perdigón": "per-di-gón",
    "perdigonada": "per-di-go-na-da",
    "perdigonera": "per-di-go-ne-ra",
    "perdiguera": "per-di-gue-ra",
    "perdiguero": "per-di-gue-ro",
    "perdimiento": "per-di-mien-to",
    "perdis": "per-dis",
    "perdiz": "per-diz",
    "perdón": "per-dón",
    "perdonable": "per-do-na-ble",
    "perdonador": "per-do-na-dor",
    "perdonadora": "per-do-na-do-ra",
    "perdonamiento": "per-do-na-mien-to",
    "perdonanza": "per-do-nan-za",
    "perdonar": "per-do-nar",
    "perdonavidas": "per-do-na-vi-das",
    "perdularia": "per-du-la-ria",
    "perdulario": "per-du-la-rio",
    "perdurabilidad": "per-du-ra-bi-li-dad",
    "perdurable": "per-du-ra-ble",
    "perdurablemente": "per-du-ra-ble-men-te",
    "perduración": "per-du-ra-ción",
    "perdurar": "per-du-rar",
    "perecear": "pe-re-ce-ar",
    "perecedera": "pe-re-ce-de-ra",
    "perecedero": "pe-re-ce-de-ro",
    "perecer": "pe-re-cer",
    "perecible": "pe-re-ci-ble",
    "pereciendo": "pe-re-cien-do",
    "perecimiento": "pe-re-ci-mien-to",
    "pereda": "pe-re-da",
    "peregrina": "pe-re-gri-na",
    "peregrinación": "pe-re-gri-na-ción",
    "peregrinaje": "pe-re-gri-na-je",
    "peregrinamente": "pe-re-gri-na-men-te",
    "peregrinar": "pe-re-gri-nar",
    "peregrinidad": "pe-re-gri-ni-dad",
    "peregrino": "pe-re-gri-no",
    "peregueta": "pe-re-gue-ta",
    "pereion": "pe-reion",
    "perejil": "pe-re-jil",
    "perejila": "pe-re-ji-la",
    "perenal": "pe-re-nal",
    "perencejo": "pe-ren-ce-jo",
    "perención": "pe-ren-ción",
    "perendeca": "pe-ren-de-ca",
    "perendengue": "pe-ren-den-gue",
    "perene": "pe-re-ne",
    "perengana": "pe-ren-ga-na",
    "perengano": "pe-ren-ga-no",
    "perennal": "pe-ren-nal",
    "perennalmente": "pe-ren-nal-men-te",
    "perenne": "pe-ren-ne",
    "perennemente": "pe-ren-ne-men-te",
    "perennidad": "pe-ren-ni-dad",
    "perennifolio": "pe-ren-ni-fo-lio",
    "perennigélido": "pe-ren-ni-gé-li-do",
    "perennizar": "pe-ren-ni-zar",
    "perenquén": "pe-ren-quén",
    "perentoria": "pe-ren-to-ria",
    "perentoriamente": "pe-ren-to-ria-men-te",
    "perentoriedad": "pe-ren-to-rie-dad",
    "perentorio": "pe-ren-to-rio",
    "pereque": "pe-re-que",
    "perero": "pe-re-ro",
    "perestroika": "pe-res-troi-ka",
    "pereta": "pe-re-ta",
    "peretero": "pe-re-te-ro",
    "pereto": "pe-re-to",
    "pereza": "pe-re-za",
    "perezosa": "pe-re-zo-sa",
    "perezosamente": "pe-re-zo-sa-men-te",
    "perezoso": "pe-re-zo-so",
    "perfección": "per-fec-ción",
    "perfeccionable": "per-fec-cio-na-ble",
    "perfeccionador": "per-fec-cio-na-dor",
    "perfeccionadora": "per-fec-cio-na-do-ra",
    "perfeccionamiento": "per-fec-cio-na-mien-to",
    "perfeccionar": "per-fec-cio-nar",
    "perfeccionismo": "per-fec-cio-nis-mo",
    "perfeccionista": "per-fec-cio-nis-ta",
    "perfecta": "per-fec-ta",
    "perfectamente": "per-fec-ta-men-te",
    "perfectibilidad": "per-fec-ti-bi-li-dad",
    "perfectible": "per-fec-ti-ble",
    "perfectiva": "per-fec-ti-va",
    "perfectivamente": "per-fec-ti-va-men-te",
    "perfectivo": "per-fec-ti-vo",
    "perfecto": "per-fec-to",
    "perfeta": "per-fe-ta",
    "perfeto": "per-fe-to",
    "perficiente": "per-fi-cien-te",
    "pérfida": "pér-fi-da",
    "pérfidamente": "pér-fi-da-men-te",
    "perfidia": "per-fi-dia",
    "pérfido": "pér-fi-do",
    "perfil": "per-fil",
    "perfilada": "per-fi-la-da",
    "perfilado": "per-fi-la-do",
    "perfilador": "per-fi-la-dor",
    "perfiladora": "per-fi-la-do-ra",
    "perfiladura": "per-fi-la-du-ra",
    "perfilar": "per-fi-lar",
    "perfoliada": "per-fo-lia-da",
    "perfoliata": "per-fo-lia-ta",
    "perfolla": "per-fo-lla",
    "perforación": "per-fo-ra-ción",
    "perforado": "per-fo-ra-do",
    "perforador": "per-fo-ra-dor",
    "perforadora": "per-fo-ra-do-ra",
    "perforar": "per-fo-rar",
    "perforista": "per-fo-ris-ta",
    "performance": "per-for-man-ce",
    "perfumadero": "per-fu-ma-de-ro",
    "perfumador": "per-fu-ma-dor",
    "perfumadora": "per-fu-ma-do-ra",
    "perfumar": "per-fu-mar",
    "perfume": "per-fu-me",
    "perfumear": "per-fu-me-ar",
    "perfumera": "per-fu-me-ra",
    "perfumería": "per-fu-me-rí-a",
    "perfumero": "per-fu-me-ro",
    "perfumista": "per-fu-mis-ta",
    "perfunctoria": "per-func-to-ria",
    "perfunctoriamente": "per-func-to-ria-men-te",
    "perfunctorio": "per-func-to-rio",
    "perfundir": "per-fun-dir",
    "perfusión": "per-fu-sión",
    "pergal": "per-gal",
    "pergaminero": "per-ga-mi-ne-ro",
    "pergamino": "per-ga-mi-no",
    "pergeñar": "per-ge-ñar",
    "pergenio": "per-ge-nio",
    "pergeño": "per-ge-ño",
    "pérgola": "pér-go-la",
    "peri": "pe-ri",
    "periambo": "pe-riam-bo",
    "periantal": "pe-rian-tal",
    "periantio": "pe-rian-tio",
    "perianto": "pe-rian-to",
    "perica": "pe-ri-ca",
    "pericárdico": "pe-ri-cár-di-co",
    "pericardio": "pe-ri-car-dio",
    "pericarditis": "pe-ri-car-di-tis",
    "pericarpio": "pe-ri-car-pio",
    "pericarpo": "pe-ri-car-po",
    "pericia": "pe-ri-cia",
    "pericial": "pe-ri-cial",
    "pericialmente": "pe-ri-cial-men-te",
    "periciclo": "pe-ri-ci-clo",
    "periclitar": "pe-ri-cli-tar",
    "perico": "pe-ri-co",
    "pericón": "pe-ri-cón",
    "pericona": "pe-ri-co-na",
    "pericote": "pe-ri-co-te",
    "pericráneo": "pe-ri-crá-ne-o",
    "peridotita": "pe-ri-do-ti-ta",
    "peridoto": "pe-ri-do-to",
    "peridural": "pe-ri-du-ral",
    "perieca": "pe-rie-ca",
    "perieco": "pe-rie-co",
    "periferia": "pe-ri-fe-ria",
    "periférica": "pe-ri-fé-ri-ca",
    "periférico": "pe-ri-fé-ri-co",
    "perifollo": "pe-ri-fo-llo",
    "perifonear": "pe-ri-fo-ne-ar",
    "perifonía": "pe-ri-fo-ní-a",
    "perífono": "pe-rí-fo-no",
    "periforme": "pe-ri-for-me",
    "perifrasear": "pe-ri-fra-se-ar",
    "perífrasi": "pe-rí-fra-si",
    "perífrasis": "pe-rí-fra-sis",
    "perifrástica": "pe-ri-frás-ti-ca",
    "perifrástico": "pe-ri-frás-ti-co",
    "perigallo": "pe-ri-ga-llo",
    "perigeo": "pe-ri-ge-o",
    "perigonio": "pe-ri-go-nio",
    "perihelio": "pe-rihe-lio",
    "perilla": "pe-ri-lla",
    "perillán": "pe-ri-llán",
    "perillana": "pe-ri-lla-na",
    "perillo": "pe-ri-llo",
    "perilustre": "pe-ri-lus-tre",
    "perimetral": "pe-ri-me-tral",
    "perimétrica": "pe-ri-mé-tri-ca",
    "perimétrico": "pe-ri-mé-tri-co",
    "perímetro": "pe-rí-me-tro",
    "perimido": "pe-ri-mi-do",
    "perimir": "pe-ri-mir",
    "perimisio": "pe-ri-mi-sio",
    "perinatal": "pe-ri-na-tal",
    "perínclita": "pe-rín-cli-ta",
    "perínclito": "pe-rín-cli-to",
    "perindola": "pe-rin-do-la",
    "periné": "pe-ri-né",
    "perineal": "pe-ri-ne-al",
    "perineo": "pe-ri-ne-o",
    "perineumonía": "pe-ri-neu-mo-ní-a",
    "peringundín": "pe-rin-gun-dín",
    "perinola": "pe-ri-no-la",
    "perinquina": "pe-rin-qui-na",
    "perinquinosa": "pe-rin-qui-no-sa",
    "perinquinoso": "pe-rin-qui-no-so",
    "períoca": "pe-rí-o-ca",
    "periódica": "pe-rió-di-ca",
    "periódicamente": "pe-rió-di-ca-men-te",
    "periodicidad": "pe-rio-di-ci-dad",
    "periódico": "pe-rió-di-co",
    "periodicucho": "pe-rio-di-cu-cho",
    "periodismo": "pe-rio-dis-mo",
    "periodista": "pe-rio-dis-ta",
    "periodística": "pe-rio-dís-ti-ca",
    "periodísticamente": "pe-rio-dís-ti-ca-men-te",
    "periodístico": "pe-rio-dís-ti-co",
    "periodización": "pe-rio-di-za-ción",
    "periodizar": "pe-rio-di-zar",
    "período": "pe-rí-o-do",
    "periodo": "pe-rio-do",
    "periodoncia": "pe-rio-don-cia",
    "periodontal": "pe-rio-don-tal",
    "periodontitis": "pe-rio-don-ti-tis",
    "periodonto": "pe-rio-don-to",
    "periostio": "pe-rios-tio",
    "periostitis": "pe-rios-ti-tis",
    "peripatética": "pe-ri-pa-té-ti-ca",
    "peripatético": "pe-ri-pa-té-ti-co",
    "peripato": "pe-ri-pa-to",
    "peripecia": "pe-ri-pe-cia",
    "periplo": "pe-ri-plo",
    "períptera": "pe-ríp-te-ra",
    "períptero": "pe-ríp-te-ro",
    "peripuesta": "pe-ri-pues-ta",
    "peripuesto": "pe-ri-pues-to",
    "periquear": "pe-ri-que-ar",
    "periquera": "pe-ri-que-ra",
    "periquete": "pe-ri-que-te",
    "periquillo": "pe-ri-qui-llo",
    "periquita": "pe-ri-qui-ta",
    "periquito": "pe-ri-qui-to",
    "periscia": "pe-ris-cia",
    "periscio": "pe-ris-cio",
    "periscópica": "pe-ris-có-pi-ca",
    "periscópico": "pe-ris-có-pi-co",
    "periscopio": "pe-ris-co-pio",
    "perisodáctilo": "pe-ri-so-dác-ti-lo",
    "perisología": "pe-ri-so-lo-gí-a",
    "perista": "pe-ris-ta",
    "peristalsis": "pe-ris-tal-sis",
    "peristáltica": "pe-ris-tál-ti-ca",
    "peristáltico": "pe-ris-tál-ti-co",
    "perístasis": "pe-rís-ta-sis",
    "peristilo": "pe-ris-ti-lo",
    "perístole": "pe-rís-to-le",
    "perita": "pe-ri-ta",
    "peritación": "pe-ri-ta-ción",
    "peritaje": "pe-ri-ta-je",
    "peritar": "pe-ri-tar",
    "perito": "pe-ri-to",
    "peritoneal": "pe-ri-to-ne-al",
    "peritoneo": "pe-ri-to-ne-o",
    "peritonitis": "pe-ri-to-ni-tis",
    "perjudicada": "per-ju-di-ca-da",
    "perjudicado": "per-ju-di-ca-do",
    "perjudicador": "per-ju-di-ca-dor",
    "perjudicadora": "per-ju-di-ca-do-ra",
    "perjudicar": "per-ju-di-car",
    "perjudicial": "per-ju-di-cial",
    "perjudicialmente": "per-ju-di-cial-men-te",
    "perjuicio": "per-jui-cio",
    "perjuicioso": "per-jui-cio-so",
    "perjura": "per-ju-ra",
    "perjurador": "per-ju-ra-dor",
    "perjuradora": "per-ju-ra-do-ra",
    "perjurar": "per-ju-rar",
    "perjurio": "per-ju-rio",
    "perjuro": "per-ju-ro",
    "perla": "per-la",
    "perlada": "per-la-da",
    "perlado": "per-la-do",
    "perlar": "per-lar",
    "perlática": "per-lá-ti-ca",
    "perlático": "per-lá-ti-co",
    "perlé": "per-lé",
    "perlera": "per-le-ra",
    "perlería": "per-le-rí-a",
    "perlero": "per-le-ro",
    "perlesía": "per-le-sí-a",
    "perlífero": "per-lí-fe-ro",
    "perlina": "per-li-na",
    "perlino": "per-li-no",
    "perlita": "per-li-ta",
    "perlongar": "per-lon-gar",
    "permanecer": "per-ma-ne-cer",
    "permanencia": "per-ma-nen-cia",
    "permanente": "per-ma-nen-te",
    "permanentemente": "per-ma-nen-te-men-te",
    "permanganato": "per-man-ga-na-to",
    "permansión": "per-man-sión",
    "permeabilidad": "per-me-a-bi-li-dad",
    "permeable": "per-me-a-ble",
    "permear": "per-me-ar",
    "pérmica": "pér-mi-ca",
    "pérmico": "pér-mi-co",
    "permisible": "per-mi-si-ble",
    "permisión": "per-mi-sión",
    "permisionaria": "per-mi-sio-na-ria",
    "permisionario": "per-mi-sio-na-rio",
    "permisiva": "per-mi-si-va",
    "permisivamente": "per-mi-si-va-men-te",
    "permisividad": "per-mi-si-vi-dad",
    "permisivo": "per-mi-si-vo",
    "permiso": "per-mi-so",
    "permisor": "per-mi-sor",
    "permisora": "per-mi-so-ra",
    "permistión": "per-mis-tión",
    "permitidera": "per-mi-ti-de-ra",
    "permitidero": "per-mi-ti-de-ro",
    "permitidor": "per-mi-ti-dor",
    "permitidora": "per-mi-ti-do-ra",
    "permitir": "per-mi-tir",
    "permitividad": "per-mi-ti-vi-dad",
    "permuta": "per-mu-ta",
    "permutabilidad": "per-mu-ta-bi-li-dad",
    "permutable": "per-mu-ta-ble",
    "permutación": "per-mu-ta-ción",
    "permutar": "per-mu-tar",
    "perna": "per-na",
    "pernada": "per-na-da",
    "pernales": "per-na-les",
    "pernambuco": "per-nam-bu-co",
    "perneador": "per-ne-a-dor",
    "perneadora": "per-ne-a-do-ra",
    "pernear": "per-ne-ar",
    "perneo": "per-ne-o",
    "pernera": "per-ne-ra",
    "pernería": "per-ne-rí-a",
    "pernezuela": "per-ne-zue-la",
    "perniabierta": "per-nia-bier-ta",
    "perniabierto": "per-nia-bier-to",
    "pernicie": "per-ni-cie",
    "perniciosa": "per-ni-cio-sa",
    "perniciosamente": "per-ni-cio-sa-men-te",
    "pernicioso": "per-ni-cio-so",
    "pernicote": "per-ni-co-te",
    "pernigón": "per-ni-gón",
    "pernil": "per-nil",
    "pernio": "per-nio",
    "perniquebrar": "per-ni-que-brar",
    "pernituerta": "per-ni-tuer-ta",
    "pernituerto": "per-ni-tuer-to",
    "perno": "per-no",
    "pernocta": "per-noc-ta",
    "pernoctación": "per-noc-ta-ción",
    "pernoctar": "per-noc-tar",
    "pernotar": "per-no-tar",
    "pero": "pe-ro",
    "perogrullada": "pe-ro-gru-lla-da",
    "perogrullesca": "pe-ro-gru-lles-ca",
    "perogrullesco": "pe-ro-gru-lles-co",
    "perogrullo": "pe-ro-gru-llo",
    "perojimén": "pe-ro-ji-mén",
    "perojiménez": "pe-ro-ji-mé-nez",
    "perojo": "pe-ro-jo",
    "perol": "pe-rol",
    "perola": "pe-ro-la",
    "peroné": "pe-ro-né",
    "peroneo": "pe-ro-ne-o",
    "peronismo": "pe-ro-nis-mo",
    "peronista": "pe-ro-nis-ta",
    "peroración": "pe-ro-ra-ción",
    "perorar": "pe-ro-rar",
    "perorata": "pe-ro-ra-ta",
    "perote": "pe-ro-te",
    "perotó": "pe-ro-tó",
    "peróxido": "pe-ró-xi-do",
    "perpalo": "per-pa-lo",
    "perpejana": "per-pe-ja-na",
    "perpendicular": "per-pen-di-cu-lar",
    "perpendicularidad": "per-pen-di-cu-la-ri-dad",
    "perpendicularmente": "per-pen-di-cu-lar-men-te",
    "perpendículo": "per-pen-dí-cu-lo",
    "perpetración": "per-pe-tra-ción",
    "perpetrador": "per-pe-tra-dor",
    "perpetradora": "per-pe-tra-do-ra",
    "perpetrar": "per-pe-trar",
    "perpetua": "per-pe-tua",
    "perpetuación": "per-pe-tua-ción",
    "perpetuamente": "per-pe-tua-men-te",
    "perpetuán": "per-pe-tuán",
    "perpetuar": "per-pe-tuar",
    "perpetuidad": "per-pe-tui-dad",
    "perpetuo": "per-pe-tuo",
    "perpiaño": "per-pia-ño",
    "perpiñanés": "per-pi-ña-nés",
    "perpiñanesa": "per-pi-ña-ne-sa",
    "perpleja": "per-ple-ja",
    "perplejamente": "per-ple-ja-men-te",
    "perplejidad": "per-ple-ji-dad",
    "perplejo": "per-ple-jo",
    "perpunte": "per-pun-te",
    "perqué": "per-qué",
    "perquirir": "per-qui-rir",
    "perra": "pe-rra",
    "perrada": "pe-rra-da",
    "perraje": "pe-rra-je",
    "perramenta": "pe-rra-men-ta",
    "perramente": "pe-rra-men-te",
    "perras": "pe-rras",
    "perrear": "pe-rre-ar",
    "perreda": "pe-rre-da",
    "perredismo": "pe-rre-dis-mo",
    "perredista": "pe-rre-dis-ta",
    "perrengue": "pe-rren-gue",
    "perrera": "pe-rre-ra",
    "perrería": "pe-rre-rí-a",
    "perrero": "pe-rre-ro",
    "perrezno": "pe-rrez-no",
    "perrilla": "pe-rri-lla",
    "perrillo": "pe-rri-llo",
    "perrina": "pe-rri-na",
    "perrito": "pe-rri-to",
    "perro": "pe-rro",
    "perrona": "pe-rro-na",
    "perroquete": "pe-rro-que-te",
    "perruna": "pe-rru-na",
    "perrunilla": "pe-rru-ni-lla",
    "perruno": "pe-rru-no",
    "persa": "per-sa",
    "persecución": "per-se-cu-ción",
    "persecutor": "per-se-cu-tor",
    "persecutoria": "per-se-cu-to-ria",
    "persecutorio": "per-se-cu-to-rio",
    "perseguible": "per-se-gui-ble",
    "perseguidor": "per-se-gui-dor",
    "perseguidora": "per-se-gui-do-ra",
    "perseguimiento": "per-se-gui-mien-to",
    "perseguir": "per-se-guir",
    "persevante": "per-se-van-te",
    "perseveración": "per-se-ve-ra-ción",
    "perseverancia": "per-se-ve-ran-cia",
    "perseverante": "per-se-ve-ran-te",
    "perseverantemente": "per-se-ve-ran-te-men-te",
    "perseverar": "per-se-ve-rar",
    "persiana": "per-sia-na",
    "persianista": "per-sia-nis-ta",
    "persiano": "per-sia-no",
    "pérsica": "pér-si-ca",
    "persicaria": "per-si-ca-ria",
    "pérsico": "pér-si-co",
    "persignar": "per-sig-nar",
    "pérsigo": "pér-si-go",
    "persistencia": "per-sis-ten-cia",
    "persistente": "per-sis-ten-te",
    "persistir": "per-sis-tir",
    "persogo": "per-so-go",
    "persona": "per-so-na",
    "personación": "per-so-na-ción",
    "personada": "per-so-na-da",
    "personado": "per-so-na-do",
    "personaje": "per-so-na-je",
    "personal": "per-so-nal",
    "personalidad": "per-so-na-li-dad",
    "personalismo": "per-so-na-lis-mo",
    "personalista": "per-so-na-lis-ta",
    "personalización": "per-so-na-li-za-ción",
    "personalizar": "per-so-na-li-zar",
    "personalmente": "per-so-nal-men-te",
    "personamiento": "per-so-na-mien-to",
    "personar": "per-so-nar",
    "personarse": "per-so-nar-se",
    "personera": "per-so-ne-ra",
    "personería": "per-so-ne-rí-a",
    "personero": "per-so-ne-ro",
    "personificación": "per-so-ni-fi-ca-ción",
    "personificar": "per-so-ni-fi-car",
    "personilla": "per-so-ni-lla",
    "personuda": "per-so-nu-da",
    "personudo": "per-so-nu-do",
    "perspectiva": "pers-pec-ti-va",
    "perspectivismo": "pers-pec-ti-vis-mo",
    "perspectivo": "pers-pec-ti-vo",
    "perspicacia": "pers-pi-ca-cia",
    "perspicacidad": "pers-pi-ca-ci-dad",
    "perspicaz": "pers-pi-caz",
    "perspicua": "pers-pi-cua",
    "perspicuidad": "pers-pi-cui-dad",
    "perspicuo": "pers-pi-cuo",
    "persuadidor": "per-sua-di-dor",
    "persuadidora": "per-sua-di-do-ra",
    "persuadir": "per-sua-dir",
    "persuasible": "per-sua-si-ble",
    "persuasión": "per-sua-sión",
    "persuasiva": "per-sua-si-va",
    "persuasivo": "per-sua-si-vo",
    "persuasor": "per-sua-sor",
    "persuasora": "per-sua-so-ra",
    "persuasorio": "per-sua-so-rio",
    "perta": "per-ta",
    "pertenecer": "per-te-ne-cer",
    "pertenecido": "per-te-ne-ci-do",
    "perteneciente": "per-te-ne-cien-te",
    "pertenencia": "per-te-nen-cia",
    "pértica": "pér-ti-ca",
    "pértiga": "pér-ti-ga",
    "pertigal": "per-ti-gal",
    "pértigo": "pér-ti-go",
    "pertigueño": "per-ti-gue-ño",
    "pertiguería": "per-ti-gue-rí-a",
    "pertiguero": "per-ti-gue-ro",
    "pertiguista": "per-ti-guis-ta",
    "pertinacia": "per-ti-na-cia",
    "pertinaz": "per-ti-naz",
    "pertinazmente": "per-ti-naz-men-te",
    "pertinencia": "per-ti-nen-cia",
    "pertinente": "per-ti-nen-te",
    "pertinentemente": "per-ti-nen-te-men-te",
    "pertrechar": "per-tre-char",
    "pertrechos": "per-tre-chos",
    "perturbable": "per-tur-ba-ble",
    "perturbación": "per-tur-ba-ción",
    "perturbada": "per-tur-ba-da",
    "perturbadamente": "per-tur-ba-da-men-te",
    "perturbado": "per-tur-ba-do",
    "perturbador": "per-tur-ba-dor",
    "perturbadora": "per-tur-ba-do-ra",
    "perturbar": "per-tur-bar",
    "perú": "pe-rú",
    "peruana": "pe-rua-na",
    "peruanismo": "pe-rua-nis-mo",
    "peruano": "pe-rua-no",
    "peruétano": "pe-rué-ta-no",
    "perulera": "pe-ru-le-ra",
    "perulero": "pe-ru-le-ro",
    "perusina": "pe-ru-si-na",
    "perusino": "pe-ru-si-no",
    "peruviana": "pe-ru-via-na",
    "peruviano": "pe-ru-via-no",
    "perversa": "per-ver-sa",
    "perversamente": "per-ver-sa-men-te",
    "perversidad": "per-ver-si-dad",
    "perversión": "per-ver-sión",
    "perverso": "per-ver-so",
    "pervertida": "per-ver-ti-da",
    "pervertido": "per-ver-ti-do",
    "pervertidor": "per-ver-ti-dor",
    "pervertidora": "per-ver-ti-do-ra",
    "pervertimiento": "per-ver-ti-mien-to",
    "pervertir": "per-ver-tir",
    "pervigilio": "per-vi-gi-lio",
    "pervinca": "per-vin-ca",
    "pervivencia": "per-vi-ven-cia",
    "pervivir": "per-vi-vir",
    "pervulgar": "per-vul-gar",
    "pesa": "pe-sa",
    "pesabebés": "pe-sa-be-bés",
    "pesacartas": "pe-sa-car-tas",
    "pesada": "pe-sa-da",
    "pesadamente": "pe-sa-da-men-te",
    "pesadez": "pe-sa-dez",
    "pesadilla": "pe-sa-di-lla",
    "pesado": "pe-sa-do",
    "pesador": "pe-sa-dor",
    "pesadora": "pe-sa-do-ra",
    "pesadumbre": "pe-sa-dum-bre",
    "pesadura": "pe-sa-du-ra",
    "pesaje": "pe-sa-je",
    "pesalicores": "pe-sa-li-co-res",
    "pésame": "pé-sa-me",
    "pesamedello": "pe-sa-me-de-llo",
    "pesante": "pe-san-te",
    "pesantez": "pe-san-tez",
    "pesar": "pe-sar",
    "pesario": "pe-sa-rio",
    "pesarosa": "pe-sa-ro-sa",
    "pesaroso": "pe-sa-ro-so",
    "pesca": "pes-ca",
    "pescada": "pes-ca-da",
    "pescadera": "pes-ca-de-ra",
    "pescadería": "pes-ca-de-rí-a",
    "pescadero": "pes-ca-de-ro",
    "pescadilla": "pes-ca-di-lla",
    "pescado": "pes-ca-do",
    "pescador": "pes-ca-dor",
    "pescadora": "pes-ca-do-ra",
    "pescante": "pes-can-te",
    "pescar": "pes-car",
    "pesce": "pes-ce",
    "pesceto": "pes-ce-to",
    "pescocear": "pes-co-ce-ar",
    "pescola": "pes-co-la",
    "pescozada": "pes-co-za-da",
    "pescozón": "pes-co-zón",
    "pescozuda": "pes-co-zu-da",
    "pescozudo": "pes-co-zu-do",
    "pescuda": "pes-cu-da",
    "pescudar": "pes-cu-dar",
    "pescuecear": "pes-cue-ce-ar",
    "pescueceo": "pes-cue-ce-o",
    "pescuezo": "pes-cue-zo",
    "pescuezudo": "pes-cue-zu-do",
    "pescuño": "pes-cu-ño",
    "pesebre": "pe-se-bre",
    "pesebrejo": "pe-se-bre-jo",
    "pesebrera": "pe-se-bre-ra",
    "pesebrista": "pe-se-bris-ta",
    "pesebrón": "pe-se-brón",
    "pesera": "pe-se-ra",
    "pesero": "pe-se-ro",
    "peseta": "pe-se-ta",
    "pésete": "pé-se-te",
    "pesetera": "pe-se-te-ra",
    "pesetero": "pe-se-te-ro",
    "pesga": "pes-ga",
    "pesgar": "pes-gar",
    "pesgo": "pes-go",
    "pesgua": "pes-gua",
    "pesia": "pe-sia",
    "pesiar": "pe-siar",
    "pésicos": "pé-si-cos",
    "pesillo": "pe-si-llo",
    "pésima": "pé-si-ma",
    "pésimamente": "pé-si-ma-men-te",
    "pesimismo": "pe-si-mis-mo",
    "pesimista": "pe-si-mis-ta",
    "pésimo": "pé-si-mo",
    "peso": "pe-so",
    "pésol": "pé-sol",
    "pesor": "pe-sor",
    "pespuntador": "pes-pun-ta-dor",
    "pespuntadora": "pes-pun-ta-do-ra",
    "pespuntar": "pes-pun-tar",
    "pespunte": "pes-pun-te",
    "pespuntear": "pes-pun-te-ar",
    "pesquera": "pes-que-ra",
    "pesquería": "pes-que-rí-a",
    "pesquerir": "pes-que-rir",
    "pesquero": "pes-que-ro",
    "pesquis": "pes-quis",
    "pesquisa": "pes-qui-sa",
    "pesquisar": "pes-qui-sar",
    "pesquisidor": "pes-qui-si-dor",
    "pesquisidora": "pes-qui-si-do-ra",
    "pesquisón": "pes-qui-són",
    "pestalociana": "pes-ta-lo-cia-na",
    "pestalociano": "pes-ta-lo-cia-no",
    "pestana": "pes-ta-na",
    "pestaña": "pes-ta-ña",
    "pestañazo": "pes-ta-ña-zo",
    "pestañear": "pes-ta-ñe-ar",
    "pestañeo": "pes-ta-ñe-o",
    "pestano": "pes-ta-no",
    "pestañosa": "pes-ta-ño-sa",
    "pestañoso": "pes-ta-ño-so",
    "pestazo": "pes-ta-zo",
    "peste": "pes-te",
    "pesticida": "pes-ti-ci-da",
    "pestífera": "pes-tí-fe-ra",
    "pestíferamente": "pes-tí-fe-ra-men-te",
    "pestífero": "pes-tí-fe-ro",
    "pestilencia": "pes-ti-len-cia",
    "pestilencial": "pes-ti-len-cial",
    "pestilencialmente": "pes-ti-len-cial-men-te",
    "pestilenciosa": "pes-ti-len-cio-sa",
    "pestilencioso": "pes-ti-len-cio-so",
    "pestilente": "pes-ti-len-te",
    "pestillo": "pes-ti-llo",
    "pestiño": "pes-ti-ño",
    "pesto": "pes-to",
    "pestorejazo": "pes-to-re-ja-zo",
    "pestorejo": "pes-to-re-jo",
    "pestorejón": "pes-to-re-jón",
    "pestuga": "pes-tu-ga",
    "pesudo": "pe-su-do",
    "pesuña": "pe-su-ña",
    "pesuño": "pe-su-ño",
    "peta": "pe-ta",
    "petaca": "pe-ta-ca",
    "petaco": "pe-ta-co",
    "petacón": "pe-ta-cón",
    "petacona": "pe-ta-co-na",
    "petacudo": "pe-ta-cu-do",
    "petalismo": "pe-ta-lis-mo",
    "petalita": "pe-ta-li-ta",
    "pétalo": "pé-ta-lo",
    "petanca": "pe-tan-ca",
    "petanque": "pe-tan-que",
    "petaquera": "pe-ta-que-ra",
    "petaquería": "pe-ta-que-rí-a",
    "petaquero": "pe-ta-que-ro",
    "petaquita": "pe-ta-qui-ta",
    "petar": "pe-tar",
    "petarda": "pe-tar-da",
    "petardear": "pe-tar-de-ar",
    "petardeo": "pe-tar-de-o",
    "petardero": "pe-tar-de-ro",
    "petardista": "pe-tar-dis-ta",
    "petardo": "pe-tar-do",
    "petarte": "pe-tar-te",
    "pétaso": "pé-ta-so",
    "petate": "pe-ta-te",
    "petateada": "pe-ta-te-a-da",
    "petatear": "pe-ta-te-ar",
    "petatera": "pe-ta-te-ra",
    "petatero": "pe-ta-te-ro",
    "petatillo": "pe-ta-ti-llo",
    "petenera": "pe-te-ne-ra",
    "petequenes": "pe-te-que-nes",
    "petequia": "pe-te-quia",
    "petequial": "pe-te-quial",
    "petera": "pe-te-ra",
    "peteretes": "pe-te-re-tes",
    "peticano": "pe-ti-ca-no",
    "peticanon": "pe-ti-ca-non",
    "petición": "pe-ti-ción",
    "peticionar": "pe-ti-cio-nar",
    "peticionaria": "pe-ti-cio-na-ria",
    "peticionario": "pe-ti-cio-na-rio",
    "peticote": "pe-ti-co-te",
    "petifoque": "pe-ti-fo-que",
    "petigrís": "pe-ti-grís",
    "petillo": "pe-ti-llo",
    "petimetra": "pe-ti-me-tra",
    "petimetre": "pe-ti-me-tre",
    "petirrojo": "pe-ti-rro-jo",
    "petisa": "pe-ti-sa",
    "petiseco": "pe-ti-se-co",
    "petiso": "pe-ti-so",
    "petisú": "pe-ti-sú",
    "petitero": "pe-ti-te-ro",
    "petitoria": "pe-ti-to-ria",
    "petitorio": "pe-ti-to-rio",
    "petiza": "pe-ti-za",
    "petizo": "pe-ti-zo",
    "peto": "pe-to",
    "petorquina": "pe-tor-qui-na",
    "petorquino": "pe-tor-qui-no",
    "petra": "pe-tra",
    "petral": "pe-tral",
    "petraria": "pe-tra-ria",
    "petrarquesca": "pe-trar-ques-ca",
    "petrarquesco": "pe-trar-ques-co",
    "petrarquismo": "pe-trar-quis-mo",
    "petrarquista": "pe-trar-quis-ta",
    "pétrea": "pé-tre-a",
    "petrel": "pe-trel",
    "pétreo": "pé-tre-o",
    "petrera": "pe-tre-ra",
    "petrífica": "pe-trí-fi-ca",
    "petrificación": "pe-tri-fi-ca-ción",
    "petrificar": "pe-tri-fi-car",
    "petrífico": "pe-trí-fi-co",
    "petril": "pe-tril",
    "petrodólar": "pe-tro-dó-lar",
    "petroglifo": "pe-tro-gli-fo",
    "petrografía": "pe-tro-gra-fí-a",
    "petrográfico": "pe-tro-grá-fi-co",
    "petrolear": "pe-tro-le-ar",
    "petróleo": "pe-tró-le-o",
    "petroleología": "pe-tro-le-o-lo-gí-a",
    "petroleoquímica": "pe-tro-le-o-quí-mi-ca",
    "petroleoquímico": "pe-tro-le-o-quí-mi-co",
    "petrolera": "pe-tro-le-ra",
    "petrolero": "pe-tro-le-ro",
    "petrolífera": "pe-tro-lí-fe-ra",
    "petrolífero": "pe-tro-lí-fe-ro",
    "petrología": "pe-tro-lo-gí-a",
    "petrológico": "pe-tro-ló-gi-co",
    "petrolquímico": "pe-trol-quí-mi-co",
    "petromacorisana": "pe-tro-ma-co-ri-sa-na",
    "petromacorisano": "pe-tro-ma-co-ri-sa-no",
    "petroquímica": "pe-tro-quí-mi-ca",
    "petroquímico": "pe-tro-quí-mi-co",
    "petrosa": "pe-tro-sa",
    "petroso": "pe-tro-so",
    "petulancia": "pe-tu-lan-cia",
    "petulante": "pe-tu-lan-te",
    "petulantemente": "pe-tu-lan-te-men-te",
    "petunia": "pe-tu-nia",
    "peucédano": "peu-cé-da-no",
    "peúco": "pe-ú-co",
    "peuco": "peu-co",
    "peumo": "peu-mo",
    "peyorar": "pe-yo-rar",
    "peyorativa": "pe-yo-ra-ti-va",
    "peyorativo": "pe-yo-ra-ti-vo",
    "peyote": "pe-yo-te",
    "peyotera": "pe-yo-te-ra",
    "peyotero": "pe-yo-te-ro",
    "pezolada": "pe-zo-la-da",
    "pezón": "pe-zón",
    "pezonera": "pe-zo-ne-ra",
    "pezpalo": "pez-pa-lo",
    "pezpita": "pez-pi-ta",
    "pezpítalo": "pez-pí-ta-lo",
    "pezuelo": "pe-zue-lo",
    "pezuña": "pe-zu-ña",
    "pía": "pí-a",
    "piache": "pia-che",
    "piada": "pia-da",
    "piador": "pia-dor",
    "piadora": "pia-do-ra",
    "piadosa": "pia-do-sa",
    "piadosamente": "pia-do-sa-men-te",
    "piadoso": "pia-do-so",
    "piafar": "pia-far",
    "piajeno": "pia-je-no",
    "pialar": "pia-lar",
    "piamadre": "pia-ma-dre",
    "piamáter": "pia-má-ter",
    "píamente": "pí-a-men-te",
    "piamontés": "pia-mon-tés",
    "piamontesa": "pia-mon-te-sa",
    "pianísimo": "pia-ní-si-mo",
    "pianismo": "pia-nis-mo",
    "pianissimo": "pia-nis-si-mo",
    "pianista": "pia-nis-ta",
    "pianístico": "pia-nís-ti-co",
    "piano": "pia-no",
    "pianoforte": "pia-no-for-te",
    "pianola": "pia-no-la",
    "piantada": "pian-ta-da",
    "piantado": "pian-ta-do",
    "piantar": "pian-tar",
    "piante": "pian-te",
    "piapoco": "pia-po-co",
    "piara": "pia-ra",
    "piariega": "pia-rie-ga",
    "piariego": "pia-rie-go",
    "piaroa": "pia-ro-a",
    "piastra": "pias-tra",
    "piba": "pi-ba",
    "pibe": "pi-be",
    "piberío": "pi-be-rí-o",
    "pibil": "pi-bil",
    "pica": "pi-ca",
    "picacaballo": "pi-ca-ca-ba-llo",
    "picacera": "pi-ca-ce-ra",
    "picacero": "pi-ca-ce-ro",
    "picacho": "pi-ca-cho",
    "picada": "pi-ca-da",
    "picadero": "pi-ca-de-ro",
    "picadillo": "pi-ca-di-llo",
    "picado": "pi-ca-do",
    "picador": "pi-ca-dor",
    "picadora": "pi-ca-do-ra",
    "picadura": "pi-ca-du-ra",
    "picafigo": "pi-ca-fi-go",
    "picaflor": "pi-ca-flor",
    "picagallina": "pi-ca-ga-lli-na",
    "picagrega": "pi-ca-gre-ga",
    "picahúye": "pi-ca-hú-ye",
    "picajón": "pi-ca-jón",
    "picajona": "pi-ca-jo-na",
    "picajosa": "pi-ca-jo-sa",
    "picajoso": "pi-ca-jo-so",
    "pical": "pi-cal",
    "picamaderos": "pi-ca-ma-de-ros",
    "picana": "pi-ca-na",
    "picaña": "pi-ca-ña",
    "picanear": "pi-ca-ne-ar",
    "picaño": "pi-ca-ño",
    "picante": "pi-can-te",
    "picantemente": "pi-can-te-men-te",
    "picantería": "pi-can-te-rí-a",
    "picanterío": "pi-can-te-rí-o",
    "picapedrera": "pi-ca-pe-dre-ra",
    "picapedrero": "pi-ca-pe-dre-ro",
    "picapica": "pi-ca-pi-ca",
    "picapinos": "pi-ca-pi-nos",
    "picapleitos": "pi-ca-plei-tos",
    "picaporte": "pi-ca-por-te",
    "picaposte": "pi-ca-pos-te",
    "picapuerco": "pi-ca-puer-co",
    "picar": "pi-car",
    "pícara": "pí-ca-ra",
    "pícaramente": "pí-ca-ra-men-te",
    "picaraza": "pi-ca-ra-za",
    "picarazado": "pi-ca-ra-za-do",
    "picarda": "pi-car-da",
    "picardear": "pi-car-de-ar",
    "picardía": "pi-car-dí-a",
    "picardías": "pi-car-dí-as",
    "picardo": "pi-car-do",
    "picaresca": "pi-ca-res-ca",
    "picaresco": "pi-ca-res-co",
    "picaril": "pi-ca-ril",
    "picarizar": "pi-ca-ri-zar",
    "pícaro": "pí-ca-ro",
    "picarón": "pi-ca-rón",
    "picarona": "pi-ca-ro-na",
    "picaronaza": "pi-ca-ro-na-za",
    "picaronazo": "pi-ca-ro-na-zo",
    "picarote": "pi-ca-ro-te",
    "picarrelincho": "pi-ca-rre-lin-cho",
    "picarro": "pi-ca-rro",
    "picarúa": "pi-ca-rú-a",
    "picassiano": "pi-cas-sia-no",
    "picatoste": "pi-ca-tos-te",
    "picayos": "pi-ca-yos",
    "picaza": "pi-ca-za",
    "picazo": "pi-ca-zo",
    "picazón": "pi-ca-zón",
    "picazuroba": "pi-ca-zu-ro-ba",
    "piccolo": "pic-co-lo",
    "pícea": "pí-ce-a",
    "píceo": "pí-ce-o",
    "picha": "pi-cha",
    "pichacha": "pi-cha-cha",
    "pichado": "pi-cha-do",
    "pichagua": "pi-cha-gua",
    "pichagüero": "pi-cha-güe-ro",
    "pichana": "pi-cha-na",
    "pichanal": "pi-cha-nal",
    "pichanga": "pi-chan-ga",
    "pichanguear": "pi-chan-gue-ar",
    "pichaque": "pi-cha-que",
    "pichar": "pi-char",
    "piche": "pi-che",
    "pichel": "pi-chel",
    "pichelería": "pi-che-le-rí-a",
    "pichelero": "pi-che-le-ro",
    "pichelingue": "pi-che-lin-gue",
    "pichella": "pi-che-lla",
    "pichete": "pi-che-te",
    "pichi": "pi-chi",
    "pichí": "pi-chí",
    "pichica": "pi-chi-ca",
    "pichicata": "pi-chi-ca-ta",
    "pichicatear": "pi-chi-ca-te-ar",
    "pichicatería": "pi-chi-ca-te-rí-a",
    "pichicato": "pi-chi-ca-to",
    "pichichi": "pi-chi-chi",
    "pichichuela": "pi-chi-chue-la",
    "pichihuén": "pi-chi-huén",
    "pichín": "pi-chín",
    "pichincha": "pi-chin-cha",
    "pichinchana": "pi-chin-cha-na",
    "pichinchano": "pi-chin-cha-no",
    "pichinchera": "pi-chin-che-ra",
    "pichinchero": "pi-chin-che-ro",
    "pichinga": "pi-chin-ga",
    "pichinglis": "pi-chin-glis",
    "pichingo": "pi-chin-go",
    "pichintún": "pi-chin-tún",
    "pichiriche": "pi-chi-ri-che",
    "pichirre": "pi-chi-rre",
    "pichirrear": "pi-chi-rre-ar",
    "pichirrería": "pi-chi-rre-rí-a",
    "pichirruchi": "pi-chi-rru-chi",
    "pichiruche": "pi-chi-ru-che",
    "pichoa": "pi-cho-a",
    "pichola": "pi-cho-la",
    "pichón": "pi-chón",
    "pichona": "pi-cho-na",
    "pichonear": "pi-cho-ne-ar",
    "pichuelo": "pi-chue-lo",
    "pichula": "pi-chu-la",
    "pichulear": "pi-chu-le-ar",
    "pichuleo": "pi-chu-le-o",
    "pichulera": "pi-chu-le-ra",
    "pichulero": "pi-chu-le-ro",
    "pichulín": "pi-chu-lín",
    "pichuncho": "pi-chun-cho",
    "pichurri": "pi-chu-rri",
    "picia": "pi-cia",
    "piciforme": "pi-ci-for-me",
    "picio": "pi-cio",
    "picles": "pi-cles",
    "picnic": "pic-nic",
    "pícnica": "píc-ni-ca",
    "pícnico": "píc-ni-co",
    "picnogónido": "pic-no-gó-ni-do",
    "picnómetro": "pic-nó-me-tro",
    "pico": "pi-co",
    "picodecera": "pi-co-de-ce-ra",
    "picofeo": "pi-co-fe-o",
    "picogordo": "pi-co-gor-do",
    "picola": "pi-co-la",
    "picoleta": "pi-co-le-ta",
    "picolete": "pi-co-le-te",
    "picoleto": "pi-co-le-to",
    "picoloro": "pi-co-lo-ro",
    "picón": "pi-cón",
    "picona": "pi-co-na",
    "piconera": "pi-co-ne-ra",
    "piconero": "pi-co-ne-ro",
    "picop": "pi-cop",
    "picor": "pi-cor",
    "picosa": "pi-co-sa",
    "picoso": "pi-co-so",
    "picota": "pi-co-ta",
    "picotada": "pi-co-ta-da",
    "picotazo": "pi-co-ta-zo",
    "picote": "pi-co-te",
    "picoteada": "pi-co-te-a-da",
    "picoteado": "pi-co-te-a-do",
    "picotear": "pi-co-te-ar",
    "picoteo": "pi-co-te-o",
    "picotera": "pi-co-te-ra",
    "picotería": "pi-co-te-rí-a",
    "picotero": "pi-co-te-ro",
    "picotillo": "pi-co-ti-llo",
    "picotín": "pi-co-tín",
    "picrato": "pi-cra-to",
    "pícrico": "pí-cri-co",
    "pictografía": "pic-to-gra-fí-a",
    "pictográfica": "pic-to-grá-fi-ca",
    "pictográfico": "pic-to-grá-fi-co",
    "pictograma": "pic-to-gra-ma",
    "pictórica": "pic-tó-ri-ca",
    "pictóricamente": "pic-tó-ri-ca-men-te",
    "pictórico": "pic-tó-ri-co",
    "picuala": "pi-cua-la",
    "picuda": "pi-cu-da",
    "picudear": "pi-cu-de-ar",
    "picudilla": "pi-cu-di-lla",
    "picudo": "pi-cu-do",
    "picunche": "pi-cun-che",
    "picure": "pi-cu-re",
    "picuy": "pi-cuy",
    "picuya": "pi-cu-ya",
    "pidén": "pi-dén",
    "pidevías": "pi-de-ví-as",
    "pidgin": "pid-gin",
    "pidiche": "pi-di-che",
    "pidientero": "pi-dien-te-ro",
    "pídola": "pí-do-la",
    "pidón": "pi-dón",
    "pidona": "pi-do-na",
    "piecito": "pie-ci-to",
    "piedad": "pie-dad",
    "piedemonte": "pie-de-mon-te",
    "piedra": "pie-dra",
    "piedrero": "pie-dre-ro",
    "piedrín": "pie-drín",
    "piejo": "pie-jo",
    "piélago": "pié-la-go",
    "pielero": "pie-le-ro",
    "pielga": "piel-ga",
    "pielgo": "piel-go",
    "pielonefritis": "pie-lo-ne-fri-tis",
    "piensador": "pien-sa-dor",
    "pienso": "pien-so",
    "piercing": "pier-cing",
    "pierde": "pier-de",
    "pieria": "pie-ria",
    "piérides": "pié-ri-des",
    "pierio": "pie-rio",
    "pierna": "pier-na",
    "piernicorto": "pier-ni-cor-to",
    "piernitendida": "pier-ni-ten-di-da",
    "piernitendido": "pier-ni-ten-di-do",
    "pierrot": "pie-rrot",
    "piesco": "pies-co",
    "piesllo": "pies-llo",
    "pietismo": "pie-tis-mo",
    "pietista": "pie-tis-ta",
    "pieza": "pie-za",
    "piezgo": "piez-go",
    "piezoeléctrica": "pie-zo-e-léc-tri-ca",
    "piezoelectricidad": "pie-zo-e-lec-tri-ci-dad",
    "piezoeléctrico": "pie-zo-e-léc-tri-co",
    "piezometría": "pie-zo-me-trí-a",
    "piezómetro": "pie-zó-me-tro",
    "pífano": "pí-fa-no",
    "pífaro": "pí-fa-ro",
    "pifas": "pi-fas",
    "pifia": "pi-fia",
    "pifiada": "pi-fia-da",
    "pifiar": "pi-fiar",
    "pigargo": "pi-gar-go",
    "pigidio": "pi-gi-dio",
    "pigmea": "pig-me-a",
    "pigmentación": "pig-men-ta-ción",
    "pigmentar": "pig-men-tar",
    "pigmentaria": "pig-men-ta-ria",
    "pigmentario": "pig-men-ta-rio",
    "pigmento": "pig-men-to",
    "pigmeo": "pig-me-o",
    "pignoración": "pig-no-ra-ción",
    "pignorar": "pig-no-rar",
    "pignoraticia": "pig-no-ra-ti-cia",
    "pignoraticio": "pig-no-ra-ti-cio",
    "pigra": "pi-gra",
    "pigre": "pi-gre",
    "pigricia": "pi-gri-cia",
    "pigro": "pi-gro",
    "pigua": "pi-gua",
    "pihua": "pi-hua",
    "pihuela": "pi-hue-la",
    "pija": "pi-ja",
    "pijada": "pi-ja-da",
    "pijama": "pi-ja-ma",
    "pije": "pi-je",
    "pijería": "pi-je-rí-a",
    "pijerío": "pi-je-rí-o",
    "pijibay": "pi-ji-bay",
    "pijije": "pi-ji-je",
    "pijín": "pi-jín",
    "pijinear": "pi-ji-ne-ar",
    "pijo": "pi-jo",
    "pijota": "pi-jo-ta",
    "pijotada": "pi-jo-ta-da",
    "pijote": "pi-jo-te",
    "pijotera": "pi-jo-te-ra",
    "pijotería": "pi-jo-te-rí-a",
    "pijotero": "pi-jo-te-ro",
    "pijuda": "pi-ju-da",
    "pijudo": "pi-ju-do",
    "pijul": "pi-jul",
    "pijuy": "pi-juy",
    "pijuyo": "pi-ju-yo",
    "pila": "pi-la",
    "pilada": "pi-la-da",
    "pilaf": "pi-laf",
    "pilagá": "pi-la-gá",
    "pilapila": "pi-la-pi-la",
    "pilar": "pi-lar",
    "pilarense": "pi-la-ren-se",
    "pilastra": "pi-las-tra",
    "pilastrón": "pi-las-trón",
    "pilatero": "pi-la-te-ro",
    "pilatuna": "pi-la-tu-na",
    "pilca": "pil-ca",
    "pilcha": "pil-cha",
    "pilche": "pil-che",
    "píldora": "píl-do-ra",
    "pildorero": "pil-do-re-ro",
    "píleo": "pí-le-o",
    "pilero": "pi-le-ro",
    "pileta": "pi-le-ta",
    "pilífero": "pi-lí-fe-ro",
    "pilila": "pi-li-la",
    "pililo": "pi-li-lo",
    "pilipina": "pi-li-pi-na",
    "pilipino": "pi-li-pi-no",
    "pilixte": "pi-lix-te",
    "pilla": "pi-lla",
    "pillabán": "pi-lla-bán",
    "pillada": "pi-lla-da",
    "pillado": "pi-lla-do",
    "pillador": "pi-lla-dor",
    "pilladora": "pi-lla-do-ra",
    "pillaje": "pi-lla-je",
    "pillán": "pi-llán",
    "pillar": "pi-llar",
    "pillastre": "pi-llas-tre",
    "pillear": "pi-lle-ar",
    "pillería": "pi-lle-rí-a",
    "pillo": "pi-llo",
    "pillopillo": "pi-llo-pi-llo",
    "pillullo": "pi-llu-llo",
    "pilma": "pil-ma",
    "pilmama": "pil-ma-ma",
    "pilme": "pil-me",
    "pilo": "pi-lo",
    "pilocarpina": "pi-lo-car-pi-na",
    "pilón": "pi-lón",
    "piloncillo": "pi-lon-ci-llo",
    "pilonera": "pi-lo-ne-ra",
    "pilonero": "pi-lo-ne-ro",
    "pilonga": "pi-lon-ga",
    "pilongo": "pi-lon-go",
    "pilono": "pi-lo-no",
    "pilórica": "pi-ló-ri-ca",
    "pilórico": "pi-ló-ri-co",
    "píloro": "pí-lo-ro",
    "pilosa": "pi-lo-sa",
    "piloso": "pi-lo-so",
    "pilot": "pi-lot",
    "pilotaje": "pi-lo-ta-je",
    "pilotar": "pi-lo-tar",
    "pilote": "pi-lo-te",
    "pilotear": "pi-lo-te-ar",
    "pilotín": "pi-lo-tín",
    "piloto": "pi-lo-to",
    "pilpil": "pil-pil",
    "pilpilén": "pil-pi-lén",
    "pilpinto": "pil-pin-to",
    "piltra": "pil-tra",
    "piltraca": "pil-tra-ca",
    "piltrafa": "pil-tra-fa",
    "piltriento": "pil-trien-to",
    "piltro": "pil-tro",
    "pilucho": "pi-lu-cho",
    "pilvén": "pil-vén",
    "pimental": "pi-men-tal",
    "pimentero": "pi-men-te-ro",
    "pimentón": "pi-men-tón",
    "pimentonera": "pi-men-to-ne-ra",
    "pimentonero": "pi-men-to-ne-ro",
    "pimienta": "pi-mien-ta",
    "pimientilla": "pi-mien-ti-lla",
    "pimiento": "pi-mien-to",
    "pimientoso": "pi-mien-to-so",
    "pimpampum": "pim-pam-pum",
    "pimpante": "pim-pan-te",
    "pimpido": "pim-pi-do",
    "pimpín": "pim-pín",
    "pimpina": "pim-pi-na",
    "pimpinela": "pim-pi-ne-la",
    "pimplar": "pim-plar",
    "pimplea": "pim-ple-a",
    "pimpleo": "pim-ple-o",
    "pimpollada": "pim-po-lla-da",
    "pimpollar": "pim-po-llar",
    "pimpollear": "pim-po-lle-ar",
    "pimpollecer": "pim-po-lle-cer",
    "pimpollo": "pim-po-llo",
    "pimpolluda": "pim-po-llu-da",
    "pimpolludo": "pim-po-llu-do",
    "pimpón": "pim-pón",
    "pina": "pi-na",
    "piña": "pi-ña",
    "pinabete": "pi-na-be-te",
    "pinacate": "pi-na-ca-te",
    "pinácea": "pi-ná-ce-a",
    "pináceas": "pi-ná-ce-as",
    "pináceo": "pi-ná-ce-o",
    "pinacle": "pi-na-cle",
    "pinacoteca": "pi-na-co-te-ca",
    "pináculo": "pi-ná-cu-lo",
    "pinada": "pi-na-da",
    "pinado": "pi-na-do",
    "pinal": "pi-nal",
    "piñal": "pi-ñal",
    "pinar": "pi-nar",
    "pinareña": "pi-na-re-ña",
    "pinareño": "pi-na-re-ño",
    "pinariega": "pi-na-rie-ga",
    "pinariego": "pi-na-rie-go",
    "pinastro": "pi-nas-tro",
    "piñata": "pi-ña-ta",
    "pinatero": "pi-na-te-ro",
    "piñatero": "pi-ña-te-ro",
    "pinatífida": "pi-na-tí-fi-da",
    "pinatífido": "pi-na-tí-fi-do",
    "pinato": "pi-na-to",
    "pinaza": "pi-na-za",
    "pincarrasca": "pin-ca-rras-ca",
    "pincarrascal": "pin-ca-rras-cal",
    "pincarrasco": "pin-ca-rras-co",
    "pincel": "pin-cel",
    "pincelada": "pin-ce-la-da",
    "pincelar": "pin-ce-lar",
    "pincelera": "pin-ce-le-ra",
    "pincelero": "pin-ce-le-ro",
    "pincerna": "pin-cer-na",
    "pincha": "pin-cha",
    "pinchadiscos": "pin-cha-dis-cos",
    "pinchadura": "pin-cha-du-ra",
    "pinchar": "pin-char",
    "pinchaúvas": "pin-cha-ú-vas",
    "pinchazo": "pin-cha-zo",
    "pinche": "pin-che",
    "pinchis": "pin-chis",
    "pinchito": "pin-chi-to",
    "pincho": "pin-cho",
    "pinchón": "pin-chón",
    "pinchonazo": "pin-cho-na-zo",
    "pinchuda": "pin-chu-da",
    "pinchudo": "pin-chu-do",
    "pinciana": "pin-cia-na",
    "pinciano": "pin-cia-no",
    "pincullo": "pin-cu-llo",
    "pindárica": "pin-dá-ri-ca",
    "pindárico": "pin-dá-ri-co",
    "pindinga": "pin-din-ga",
    "pindonga": "pin-don-ga",
    "pindonguear": "pin-don-gue-ar",
    "pindongueo": "pin-don-gue-o",
    "pineal": "pi-ne-al",
    "pineda": "pi-ne-da",
    "pinedo": "pi-ne-do",
    "piñén": "pi-ñén",
    "pinera": "pi-ne-ra",
    "pinero": "pi-ne-ro",
    "pinga": "pin-ga",
    "pingajo": "pin-ga-jo",
    "pingajosa": "pin-ga-jo-sa",
    "pingajoso": "pin-ga-jo-so",
    "pinganello": "pin-ga-ne-llo",
    "pinganilla": "pin-ga-ni-lla",
    "pinganillo": "pin-ga-ni-llo",
    "pinganitos": "pin-ga-ni-tos",
    "pingar": "pin-gar",
    "pingo": "pin-go",
    "pingopingo": "pin-go-pin-go",
    "pingorota": "pin-go-ro-ta",
    "pingorote": "pin-go-ro-te",
    "pingorotuda": "pin-go-ro-tu-da",
    "pingorotudo": "pin-go-ro-tu-do",
    "pingue": "pin-gue",
    "pingüe": "pin-güe",
    "pingüedinosa": "pin-güe-di-no-sa",
    "pingüedinoso": "pin-güe-di-no-so",
    "pingüinera": "pin-güi-ne-ra",
    "pingüino": "pin-güi-no",
    "pingullo": "pin-gu-llo",
    "pinguosidad": "pin-guo-si-dad",
    "pinífera": "pi-ní-fe-ra",
    "pinífero": "pi-ní-fe-ro",
    "pinillo": "pi-ni-llo",
    "pininos": "pi-ni-nos",
    "pinito": "pi-ni-to",
    "pinitos": "pi-ni-tos",
    "pinjado": "pin-ja-do",
    "pinjante": "pin-jan-te",
    "pinjar": "pin-jar",
    "pinna": "pin-na",
    "pinnado": "pin-na-do",
    "pinnípedo": "pin-ní-pe-do",
    "pino": "pi-no",
    "piño": "pi-ño",
    "pinocha": "pi-no-cha",
    "pinochera": "pi-no-che-ra",
    "pinocho": "pi-no-cho",
    "pinol": "pi-nol",
    "pinolate": "pi-no-la-te",
    "pinole": "pi-no-le",
    "pinolera": "pi-no-le-ra",
    "pinolero": "pi-no-le-ro",
    "pinolillo": "pi-no-li-llo",
    "piñón": "pi-ñón",
    "piñonata": "pi-ño-na-ta",
    "piñonate": "pi-ño-na-te",
    "piñoncillo": "pi-ñon-ci-llo",
    "piñonear": "pi-ño-ne-ar",
    "piñoneo": "pi-ño-ne-o",
    "piñonero": "pi-ño-ne-ro",
    "pinosa": "pi-no-sa",
    "pinoso": "pi-no-so",
    "pinrel": "pin-rel",
    "pinsapar": "pin-sa-par",
    "pinsapo": "pin-sa-po",
    "pinta": "pin-ta",
    "pintacilgo": "pin-ta-cil-go",
    "pintada": "pin-ta-da",
    "pintadera": "pin-ta-de-ra",
    "pintadillo": "pin-ta-di-llo",
    "pintado": "pin-ta-do",
    "pintador": "pin-ta-dor",
    "pintadora": "pin-ta-do-ra",
    "pintalabios": "pin-ta-la-bios",
    "pintamonas": "pin-ta-mo-nas",
    "pintar": "pin-tar",
    "pintarrajar": "pin-ta-rra-jar",
    "pintarrajear": "pin-ta-rra-je-ar",
    "pintarrajo": "pin-ta-rra-jo",
    "pintarroja": "pin-ta-rro-ja",
    "pintaúñas": "pin-ta-ú-ñas",
    "pintear": "pin-te-ar",
    "pinteña": "pin-te-ña",
    "pinteño": "pin-te-ño",
    "pintiparada": "pin-ti-pa-ra-da",
    "pintiparado": "pin-ti-pa-ra-do",
    "pintiparar": "pin-ti-pa-rar",
    "pinto": "pin-to",
    "pintoja": "pin-to-ja",
    "pintojo": "pin-to-jo",
    "pintón": "pin-tón",
    "pintona": "pin-to-na",
    "pintonear": "pin-to-ne-ar",
    "pintor": "pin-tor",
    "pintora": "pin-to-ra",
    "pintoresca": "pin-to-res-ca",
    "pintoresco": "pin-to-res-co",
    "pintoresquismo": "pin-to-res-quis-mo",
    "pintorrear": "pin-to-rre-ar",
    "pintoso": "pin-to-so",
    "pintuda": "pin-tu-da",
    "pintudo": "pin-tu-do",
    "pintura": "pin-tu-ra",
    "pinturera": "pin-tu-re-ra",
    "pinturería": "pin-tu-re-rí-a",
    "pinturero": "pin-tu-re-ro",
    "pinuca": "pi-nu-ca",
    "piñuela": "pi-ñue-la",
    "piñuelo": "pi-ñue-lo",
    "piñufla": "pi-ñu-fla",
    "pínula": "pí-nu-la",
    "pinza": "pin-za",
    "pinzamiento": "pin-za-mien-to",
    "pinzar": "pin-zar",
    "pinzón": "pin-zón",
    "pinzote": "pin-zo-te",
    "pío": "pí-o",
    "piocha": "pio-cha",
    "piochazo": "pio-cha-zo",
    "piogenia": "pio-ge-nia",
    "piojenta": "pio-jen-ta",
    "piojento": "pio-jen-to",
    "piojera": "pio-je-ra",
    "piojería": "pio-je-rí-a",
    "piojillo": "pio-ji-llo",
    "piojo": "pio-jo",
    "piojosa": "pio-jo-sa",
    "piojoso": "pio-jo-so",
    "piojuelo": "pio-jue-lo",
    "piola": "pio-la",
    "piolar": "pio-lar",
    "piolet": "pio-let",
    "piolín": "pio-lín",
    "piona": "pio-na",
    "pionera": "pio-ne-ra",
    "pionero": "pio-ne-ro",
    "pionía": "pio-ní-a",
    "pionono": "pio-no-no",
    "piopollo": "pio-po-llo",
    "piornal": "pior-nal",
    "piorneda": "pior-ne-da",
    "piorno": "pior-no",
    "piorrea": "pio-rre-a",
    "pipa": "pi-pa",
    "pipar": "pi-par",
    "pipe": "pi-pe",
    "pipencia": "pi-pen-cia",
    "pipeño": "pi-pe-ño",
    "pipera": "pi-pe-ra",
    "piperácea": "pi-pe-rá-ce-a",
    "piperáceo": "pi-pe-rá-ce-o",
    "pipería": "pi-pe-rí-a",
    "piperina": "pi-pe-ri-na",
    "pipermín": "pi-per-mín",
    "pipero": "pi-pe-ro",
    "pipeta": "pi-pe-ta",
    "pipetear": "pi-pe-te-ar",
    "pipi": "pi-pi",
    "pipí": "pi-pí",
    "pipián": "pi-pián",
    "pipiar": "pi-piar",
    "pipiciego": "pi-pi-cie-go",
    "pipil": "pi-pil",
    "pípila": "pí-pi-la",
    "pipilacha": "pi-pi-la-cha",
    "pipilla": "pi-pi-lla",
    "pipiol": "pi-piol",
    "pipiola": "pi-pio-la",
    "pipiolera": "pi-pio-le-ra",
    "pipiolo": "pi-pio-lo",
    "pipiricojo": "pi-pi-ri-co-jo",
    "pipirigallo": "pi-pi-ri-ga-llo",
    "pipirigaña": "pi-pi-ri-ga-ña",
    "pipirijaina": "pi-pi-ri-jai-na",
    "pipiriles": "pi-pi-ri-les",
    "pipirín": "pi-pi-rín",
    "pipiripao": "pi-pi-ri-pa-o",
    "pipiritaña": "pi-pi-ri-ta-ña",
    "pipirrana": "pi-pi-rra-na",
    "pipita": "pi-pi-ta",
    "pipitaña": "pi-pi-ta-ña",
    "pipo": "pi-po",
    "pipocas": "pi-po-cas",
    "pipón": "pi-pón",
    "pipona": "pi-po-na",
    "piporro": "pi-po-rro",
    "pipote": "pi-po-te",
    "pippermint": "pip-per-mint",
    "pique": "pi-que",
    "piqué": "pi-qué",
    "piquear": "pi-que-ar",
    "piqueo": "pi-que-o",
    "piquera": "pi-que-ra",
    "piquería": "pi-que-rí-a",
    "piquero": "pi-que-ro",
    "piqueta": "pi-que-ta",
    "piquetazo": "pi-que-ta-zo",
    "piquete": "pi-que-te",
    "piquetear": "pi-que-te-ar",
    "piquetero": "pi-que-te-ro",
    "piquetilla": "pi-que-ti-lla",
    "piquillín": "pi-qui-llín",
    "piquín": "pi-quín",
    "piquiña": "pi-qui-ña",
    "piquituerto": "pi-qui-tuer-to",
    "pira": "pi-ra",
    "pirada": "pi-ra-da",
    "pirado": "pi-ra-do",
    "piragón": "pi-ra-gón",
    "piragua": "pi-ra-gua",
    "piragüera": "pi-ra-güe-ra",
    "piragüero": "pi-ra-güe-ro",
    "piragüismo": "pi-ra-güis-mo",
    "piragüista": "pi-ra-güis-ta",
    "piral": "pi-ral",
    "piramidal": "pi-ra-mi-dal",
    "pirámide": "pi-rá-mi-de",
    "piraña": "pi-ra-ña",
    "pirandelliano": "pi-ran-de-llia-no",
    "pirandón": "pi-ran-dón",
    "pirandona": "pi-ran-do-na",
    "pirante": "pi-ran-te",
    "pirar": "pi-rar",
    "pirata": "pi-ra-ta",
    "piratear": "pi-ra-te-ar",
    "pirateo": "pi-ra-te-o",
    "piratería": "pi-ra-te-rí-a",
    "pirática": "pi-rá-ti-ca",
    "pirático": "pi-rá-ti-co",
    "pirausta": "pi-raus-ta",
    "pirca": "pir-ca",
    "pircar": "pir-car",
    "pirco": "pir-co",
    "pircún": "pir-cún",
    "pireca": "pi-re-ca",
    "pirenaica": "pi-re-nai-ca",
    "pirenaico": "pi-re-nai-co",
    "pireneísmo": "pi-re-ne-ís-mo",
    "pireneísta": "pi-re-ne-ís-ta",
    "pirético": "pi-ré-ti-co",
    "piretógeno": "pi-re-tó-ge-no",
    "piretología": "pi-re-to-lo-gí-a",
    "piretro": "pi-re-tro",
    "pirexia": "pi-re-xia",
    "pírgano": "pír-ga-no",
    "pirgüín": "pir-güín",
    "pirhuín": "pir-huín",
    "pírica": "pí-ri-ca",
    "pírico": "pí-ri-co",
    "piriforme": "pi-ri-for-me",
    "pirimidina": "pi-ri-mi-di-na",
    "pirimidínico": "pi-ri-mi-dí-ni-co",
    "piriñaca": "pi-ri-ña-ca",
    "pirinaico": "pi-ri-nai-co",
    "pirincho": "pi-rin-cho",
    "pirinea": "pi-ri-ne-a",
    "pirineísmo": "pi-ri-ne-ís-mo",
    "pirineísta": "pi-ri-ne-ís-ta",
    "pirineo": "pi-ri-ne-o",
    "piringundín": "pi-rin-gun-dín",
    "pirinola": "pi-ri-no-la",
    "piripi": "pi-ri-pi",
    "piripicho": "pi-ri-pi-cho",
    "pirita": "pi-ri-ta",
    "piritosa": "pi-ri-to-sa",
    "piritoso": "pi-ri-to-so",
    "pirla": "pir-la",
    "pirlitero": "pir-li-te-ro",
    "piro": "pi-ro",
    "pirobolista": "pi-ro-bo-lis-ta",
    "piroelectricidad": "pi-ro-e-lec-tri-ci-dad",
    "piroeléctrico": "pi-ro-e-léc-tri-co",
    "pirofilacio": "pi-ro-fi-la-cio",
    "pirofórico": "pi-ro-fó-ri-co",
    "pirogálico": "pi-ro-gá-li-co",
    "pirogalol": "pi-ro-ga-lol",
    "pirogénesis": "pi-ro-gé-ne-sis",
    "pirógeno": "pi-ró-ge-no",
    "pirograbado": "pi-ro-gra-ba-do",
    "pirograbador": "pi-ro-gra-ba-dor",
    "pirograbadora": "pi-ro-gra-ba-do-ra",
    "pirograbar": "pi-ro-gra-bar",
    "pirolatría": "pi-ro-la-trí-a",
    "pirólisis": "pi-ró-li-sis",
    "pirología": "pi-ro-lo-gí-a",
    "pirolusita": "pi-ro-lu-si-ta",
    "pirómana": "pi-ró-ma-na",
    "piromancía": "pi-ro-man-cí-a",
    "piromancia": "pi-ro-man-cia",
    "piromanía": "pi-ro-ma-ní-a",
    "pirómano": "pi-ró-ma-no",
    "piromántica": "pi-ro-mán-ti-ca",
    "piromántico": "pi-ro-mán-ti-co",
    "pirometría": "pi-ro-me-trí-a",
    "pirómetro": "pi-ró-me-tro",
    "pirón": "pi-rón",
    "piropear": "pi-ro-pe-ar",
    "piropeo": "pi-ro-pe-o",
    "piropo": "pi-ro-po",
    "piróscafo": "pi-rós-ca-fo",
    "pirosfera": "pi-ros-fe-ra",
    "pirósfera": "pi-rós-fe-ra",
    "pirosis": "pi-ro-sis",
    "pirotecnia": "pi-ro-tec-nia",
    "pirotécnica": "pi-ro-téc-ni-ca",
    "pirotécnico": "pi-ro-téc-ni-co",
    "piroxena": "pi-ro-xe-na",
    "piroxeno": "pi-ro-xe-no",
    "piroxilina": "pi-ro-xi-li-na",
    "piróxilo": "pi-ró-xi-lo",
    "pirquén": "pir-quén",
    "pirquín": "pir-quín",
    "pirquinear": "pir-qui-ne-ar",
    "pirquinera": "pir-qui-ne-ra",
    "pirquinero": "pir-qui-ne-ro",
    "pirracha": "pi-rra-cha",
    "pirrar": "pi-rrar",
    "pirrarse": "pi-rrar-se",
    "pirriar": "pi-rriar",
    "pírrica": "pí-rri-ca",
    "pírrico": "pí-rri-co",
    "pirriquio": "pi-rri-quio",
    "pirrol": "pi-rrol",
    "pirrólico": "pi-rró-li-co",
    "pirroniana": "pi-rro-nia-na",
    "pirroniano": "pi-rro-nia-no",
    "pirrónica": "pi-rró-ni-ca",
    "pirrónico": "pi-rró-ni-co",
    "pirronismo": "pi-rro-nis-mo",
    "pirú": "pi-rú",
    "pirua": "pi-rua",
    "pirueta": "pi-rue-ta",
    "piruétano": "pi-rué-ta-no",
    "piruetear": "pi-rue-te-ar",
    "piruja": "pi-ru-ja",
    "pirujo": "pi-ru-jo",
    "pirul": "pi-rul",
    "pirula": "pi-ru-la",
    "piruleta": "pi-ru-le-ta",
    "pirulí": "pi-ru-lí",
    "pirulo": "pi-ru-lo",
    "pisa": "pi-sa",
    "pisada": "pi-sa-da",
    "pisadera": "pi-sa-de-ra",
    "pisadero": "pi-sa-de-ro",
    "pisado": "pi-sa-do",
    "pisador": "pi-sa-dor",
    "pisadora": "pi-sa-do-ra",
    "pisadura": "pi-sa-du-ra",
    "pisana": "pi-sa-na",
    "pisano": "pi-sa-no",
    "pisapapeles": "pi-sa-pa-pe-les",
    "pisapasito": "pi-sa-pa-si-to",
    "pisar": "pi-sar",
    "pisarropas": "pi-sa-rro-pas",
    "pisasfalto": "pi-sas-fal-to",
    "pisataria": "pi-sa-ta-ria",
    "pisatario": "pi-sa-ta-rio",
    "pisaúvas": "pi-sa-ú-vas",
    "pisaverde": "pi-sa-ver-de",
    "pisca": "pis-ca",
    "piscator": "pis-ca-tor",
    "piscatoria": "pis-ca-to-ria",
    "piscatorio": "pis-ca-to-rio",
    "pisciana": "pis-cia-na",
    "pisciano": "pis-cia-no",
    "piscícola": "pis-cí-co-la",
    "piscicultor": "pis-ci-cul-tor",
    "piscicultora": "pis-ci-cul-to-ra",
    "piscicultura": "pis-ci-cul-tu-ra",
    "piscifactoría": "pis-ci-fac-to-rí-a",
    "pisciforme": "pis-ci-for-me",
    "piscina": "pis-ci-na",
    "piscis": "pis-cis",
    "piscívora": "pis-cí-vo-ra",
    "piscívoro": "pis-cí-vo-ro",
    "pisco": "pis-co",
    "piscola": "pis-co-la",
    "piscolabis": "pis-co-la-bis",
    "pishishe": "pis-his-he",
    "pisiforme": "pi-si-for-me",
    "pisirico": "pi-si-ri-co",
    "pisito": "pi-si-to",
    "piso": "pi-so",
    "pisón": "pi-són",
    "pisonear": "pi-so-ne-ar",
    "pisoteada": "pi-so-te-a-da",
    "pisotear": "pi-so-te-ar",
    "pisoteo": "pi-so-te-o",
    "pisotón": "pi-so-tón",
    "pispa": "pis-pa",
    "pispajo": "pis-pa-jo",
    "pispar": "pis-par",
    "pispear": "pis-pe-ar",
    "pispelo": "pis-pe-lo",
    "pispiar": "pis-piar",
    "pispilear": "pis-pi-le-ar",
    "pispo": "pis-po",
    "pisque": "pis-que",
    "pisqueña": "pis-que-ña",
    "pisqueño": "pis-que-ño",
    "pista": "pis-ta",
    "pistache": "pis-ta-che",
    "pistachero": "pis-ta-che-ro",
    "pistacho": "pis-ta-cho",
    "pistadero": "pis-ta-de-ro",
    "pistar": "pis-tar",
    "piste": "pis-te",
    "pistear": "pis-te-ar",
    "pistera": "pis-te-ra",
    "pistero": "pis-te-ro",
    "pistilo": "pis-ti-lo",
    "pisto": "pis-to",
    "pistojo": "pis-to-jo",
    "pistola": "pis-to-la",
    "pistolear": "pis-to-le-ar",
    "pistolera": "pis-to-le-ra",
    "pistolerismo": "pis-to-le-ris-mo",
    "pistolero": "pis-to-le-ro",
    "pistoletazo": "pis-to-le-ta-zo",
    "pistolete": "pis-to-le-te",
    "pistón": "pis-tón",
    "pistonear": "pis-to-ne-ar",
    "pistonudo": "pis-to-nu-do",
    "pistoresa": "pis-to-re-sa",
    "pistraje": "pis-tra-je",
    "pistraque": "pis-tra-que",
    "pistudo": "pis-tu-do",
    "pistura": "pis-tu-ra",
    "pita": "pi-ta",
    "pitaco": "pi-ta-co",
    "pitada": "pi-ta-da",
    "pitadera": "pi-ta-de-ra",
    "pitagórica": "pi-ta-gó-ri-ca",
    "pitagórico": "pi-ta-gó-ri-co",
    "pitagorín": "pi-ta-go-rín",
    "pitagorina": "pi-ta-go-ri-na",
    "pitagorismo": "pi-ta-go-ris-mo",
    "pitahaya": "pi-ta-ha-ya",
    "pitajaña": "pi-ta-ja-ña",
    "pitajaya": "pi-ta-ja-ya",
    "pital": "pi-tal",
    "pitaña": "pi-ta-ña",
    "pitancería": "pi-tan-ce-rí-a",
    "pitancero": "pi-tan-ce-ro",
    "pitanga": "pi-tan-ga",
    "pitanguero": "pi-tan-gue-ro",
    "pitañosa": "pi-ta-ño-sa",
    "pitañoso": "pi-ta-ño-so",
    "pitanza": "pi-tan-za",
    "pitao": "pi-ta-o",
    "pitar": "pi-tar",
    "pitarra": "pi-ta-rra",
    "pitarro": "pi-ta-rro",
    "pitarrosa": "pi-ta-rro-sa",
    "pitarroso": "pi-ta-rro-so",
    "pitaya": "pi-ta-ya",
    "pitayal": "pi-ta-yal",
    "pitayar": "pi-ta-yar",
    "pitayera": "pi-ta-ye-ra",
    "pitayero": "pi-ta-ye-ro",
    "pitayo": "pi-ta-yo",
    "pitazo": "pi-ta-zo",
    "pitbull": "pit-bull",
    "pitcher": "pit-cher",
    "pite": "pi-te",
    "pitear": "pi-te-ar",
    "pitecántropo": "pi-te-cán-tro-po",
    "pítele": "pí-te-le",
    "pitera": "pi-te-ra",
    "pitero": "pi-te-ro",
    "pitezna": "pi-tez-na",
    "piti": "pi-ti",
    "pitia": "pi-tia",
    "pítica": "pí-ti-ca",
    "piticiega": "pi-ti-cie-ga",
    "piticiego": "pi-ti-cie-go",
    "piticlín": "pi-ti-clín",
    "pítico": "pí-ti-co",
    "pitido": "pi-ti-do",
    "pitihué": "pi-ti-hué",
    "pitilla": "pi-ti-lla",
    "pitillera": "pi-ti-lle-ra",
    "pitillo": "pi-ti-llo",
    "pítima": "pí-ti-ma",
    "pitiminí": "pi-ti-mi-ní",
    "pitio": "pi-tio",
    "pitipié": "pi-ti-pié",
    "pitiriasis": "pi-ti-ria-sis",
    "pitirre": "pi-ti-rre",
    "pitiyanqui": "pi-ti-yan-qui",
    "pito": "pi-to",
    "pitoche": "pi-to-che",
    "pitoflera": "pi-to-fle-ra",
    "pitoflero": "pi-to-fle-ro",
    "pitoitoy": "pi-toi-toy",
    "pitón": "pi-tón",
    "pitonazo": "pi-to-na-zo",
    "pitonisa": "pi-to-ni-sa",
    "pitopausia": "pi-to-pau-sia",
    "pitopáusico": "pi-to-páu-si-co",
    "pitora": "pi-to-ra",
    "pitorá": "pi-to-rá",
    "pitoreta": "pi-to-re-ta",
    "pitorra": "pi-to-rra",
    "pitorrear": "pi-to-rre-ar",
    "pitorrearse": "pi-to-rre-ar-se",
    "pitorreo": "pi-to-rre-o",
    "pitorro": "pi-to-rro",
    "pitósporo": "pi-tós-po-ro",
    "pitote": "pi-to-te",
    "pitpit": "pit-pit",
    "pitraca": "pi-tra-ca",
    "pitraco": "pi-tra-co",
    "pitreo": "pi-tre-o",
    "pituca": "pi-tu-ca",
    "pituco": "pi-tu-co",
    "pitudo": "pi-tu-do",
    "pituita": "pi-tui-ta",
    "pituitaria": "pi-tui-ta-ria",
    "pituitario": "pi-tui-ta-rio",
    "pituitosa": "pi-tui-to-sa",
    "pituitoso": "pi-tui-to-so",
    "pituquear": "pi-tu-que-ar",
    "pituquería": "pi-tu-que-rí-a",
    "piturriaca": "pi-tu-rria-ca",
    "pitusa": "pi-tu-sa",
    "pituso": "pi-tu-so",
    "pitutear": "pi-tu-te-ar",
    "pituto": "pi-tu-to",
    "piujar": "piu-jar",
    "piular": "piu-lar",
    "piulido": "piu-li-do",
    "piune": "piu-ne",
    "piuquén": "piu-quén",
    "piurana": "piu-ra-na",
    "piurano": "piu-ra-no",
    "piure": "piu-re",
    "pívot": "pí-vot",
    "pivotante": "pi-vo-tan-te",
    "pivotar": "pi-vo-tar",
    "pivote": "pi-vo-te",
    "píxel": "pí-xel",
    "píxide": "pí-xi-de",
    "pixtón": "pix-tón",
    "piyama": "pi-ya-ma",
    "pizareño": "pi-za-re-ño",
    "pizarra": "pi-za-rra",
    "pizarral": "pi-za-rral",
    "pizarreña": "pi-za-rre-ña",
    "pizarreño": "pi-za-rre-ño",
    "pizarrería": "pi-za-rre-rí-a",
    "pizarrero": "pi-za-rre-ro",
    "pizarrín": "pi-za-rrín",
    "pizarrista": "pi-za-rris-ta",
    "pizarrón": "pi-za-rrón",
    "pizarrosa": "pi-za-rro-sa",
    "pizarroso": "pi-za-rro-so",
    "pizate": "pi-za-te",
    "pizca": "piz-ca",
    "pizcar": "piz-car",
    "pizco": "piz-co",
    "pizcucha": "piz-cu-cha",
    "pizmienta": "piz-mien-ta",
    "pizmiento": "piz-mien-to",
    "pizote": "pi-zo-te",
    "pizpereta": "piz-pe-re-ta",
    "pizpierno": "piz-pier-no",
    "pizpireta": "piz-pi-re-ta",
    "pizpireto": "piz-pi-re-to",
    "pizpirigaña": "piz-pi-ri-ga-ña",
    "pizpita": "piz-pi-ta",
    "pizpitillo": "piz-pi-ti-llo",
    "pizza": "piz-za",
    "pizzera": "piz-ze-ra",
    "pizzería": "piz-ze-rí-a",
    "pizzero": "piz-ze-ro",
    "pizzicato": "piz-zi-ca-to",
    "placa": "pla-ca",
    "placabilidad": "pla-ca-bi-li-dad",
    "placable": "pla-ca-ble",
    "placación": "pla-ca-ción",
    "placaje": "pla-ca-je",
    "placar": "pla-car",
    "placarte": "pla-car-te",
    "placativa": "pla-ca-ti-va",
    "placativo": "pla-ca-ti-vo",
    "placear": "pla-ce-ar",
    "placebo": "pla-ce-bo",
    "placel": "pla-cel",
    "pláceme": "plá-ce-me",
    "placemiento": "pla-ce-mien-to",
    "placenta": "pla-cen-ta",
    "placentación": "pla-cen-ta-ción",
    "placentaria": "pla-cen-ta-ria",
    "placentario": "pla-cen-ta-rio",
    "placentera": "pla-cen-te-ra",
    "placenteramente": "pla-cen-te-ra-men-te",
    "placentería": "pla-cen-te-rí-a",
    "placentero": "pla-cen-te-ro",
    "placentín": "pla-cen-tín",
    "placentina": "pla-cen-ti-na",
    "placentino": "pla-cen-ti-no",
    "placer": "pla-cer",
    "placera": "pla-ce-ra",
    "placeramente": "pla-ce-ra-men-te",
    "placero": "pla-ce-ro",
    "plácet": "plá-cet",
    "placibilidad": "pla-ci-bi-li-dad",
    "placible": "pla-ci-ble",
    "placiblemente": "pla-ci-ble-men-te",
    "plácida": "plá-ci-da",
    "plácidamente": "plá-ci-da-men-te",
    "placidez": "pla-ci-dez",
    "plácido": "plá-ci-do",
    "placiente": "pla-cien-te",
    "placimiento": "pla-ci-mien-to",
    "plácito": "plá-ci-to",
    "plafón": "pla-fón",
    "plaga": "pla-ga",
    "plagada": "pla-ga-da",
    "plagado": "pla-ga-do",
    "plagal": "pla-gal",
    "plagar": "pla-gar",
    "plagiada": "pla-gia-da",
    "plagiado": "pla-gia-do",
    "plagiador": "pla-gia-dor",
    "plagiar": "pla-giar",
    "plagiaria": "pla-gia-ria",
    "plagiario": "pla-gia-rio",
    "plagio": "pla-gio",
    "plagioclasa": "pla-gio-cla-sa",
    "plagióstomo": "pla-giós-to-mo",
    "plagosa": "pla-go-sa",
    "plagoso": "pla-go-so",
    "plaguear": "pla-gue-ar",
    "plagueo": "pla-gue-o",
    "plaguero": "pla-gue-ro",
    "plaguicida": "pla-gui-ci-da",
    "plana": "pla-na",
    "planada": "pla-na-da",
    "planador": "pla-na-dor",
    "planadora": "pla-na-do-ra",
    "planazo": "pla-na-zo",
    "planazón": "pla-na-zón",
    "plancha": "plan-cha",
    "planchada": "plan-cha-da",
    "planchado": "plan-cha-do",
    "planchador": "plan-cha-dor",
    "planchadora": "plan-cha-do-ra",
    "planchar": "plan-char",
    "planchazo": "plan-cha-zo",
    "planchear": "plan-che-ar",
    "planchera": "plan-che-ra",
    "planchero": "plan-che-ro",
    "plancheta": "plan-che-ta",
    "planchón": "plan-chón",
    "planchoso": "plan-cho-so",
    "planchuela": "plan-chue-la",
    "planco": "plan-co",
    "plancton": "planc-ton",
    "planctónico": "planc-tó-ni-co",
    "planeación": "pla-ne-a-ción",
    "planeador": "pla-ne-a-dor",
    "planeadora": "pla-ne-a-do-ra",
    "planeamiento": "pla-ne-a-mien-to",
    "planear": "pla-ne-ar",
    "planeo": "pla-ne-o",
    "planeta": "pla-ne-ta",
    "planetaria": "pla-ne-ta-ria",
    "planetario": "pla-ne-ta-rio",
    "planetícola": "pla-ne-tí-co-la",
    "planetoide": "pla-ne-toi-de",
    "planga": "plan-ga",
    "planicidad": "pla-ni-ci-dad",
    "planicie": "pla-ni-cie",
    "plañidera": "pla-ñi-de-ra",
    "plañidero": "pla-ñi-de-ro",
    "plañido": "pla-ñi-do",
    "planificación": "pla-ni-fi-ca-ción",
    "planificado": "pla-ni-fi-ca-do",
    "planificador": "pla-ni-fi-ca-dor",
    "planificadora": "pla-ni-fi-ca-do-ra",
    "planificar": "pla-ni-fi-car",
    "planilla": "pla-ni-lla",
    "planimetría": "pla-ni-me-trí-a",
    "planímetro": "pla-ní-me-tro",
    "plañimiento": "pla-ñi-mien-to",
    "plañir": "pla-ñir",
    "planisferio": "pla-nis-fe-rio",
    "planning": "plan-ning",
    "plano": "pla-no",
    "planta": "plan-ta",
    "plantación": "plan-ta-ción",
    "plantada": "plan-ta-da",
    "plantado": "plan-ta-do",
    "plantador": "plan-ta-dor",
    "plantadora": "plan-ta-do-ra",
    "plantaginácea": "plan-ta-gi-ná-ce-a",
    "plantagináceo": "plan-ta-gi-ná-ce-o",
    "plantaina": "plan-tai-na",
    "plantaje": "plan-ta-je",
    "plantar": "plan-tar",
    "plantario": "plan-ta-rio",
    "plante": "plan-te",
    "planteamiento": "plan-te-a-mien-to",
    "plantear": "plan-te-ar",
    "plantel": "plan-tel",
    "planteo": "plan-te-o",
    "plantía": "plan-tí-a",
    "plantificación": "plan-ti-fi-ca-ción",
    "plantificar": "plan-ti-fi-car",
    "plantígrada": "plan-tí-gra-da",
    "plantígrado": "plan-tí-gra-do",
    "plantilla": "plan-ti-lla",
    "plantillar": "plan-ti-llar",
    "plantillazo": "plan-ti-lla-zo",
    "plantillera": "plan-ti-lle-ra",
    "plantillero": "plan-ti-lle-ro",
    "plantiniana": "plan-ti-nia-na",
    "plantiniano": "plan-ti-nia-no",
    "plantío": "plan-tí-o",
    "plantista": "plan-tis-ta",
    "planto": "plan-to",
    "plantón": "plan-tón",
    "plantonar": "plan-to-nar",
    "plantosa": "plan-to-sa",
    "plántula": "plán-tu-la",
    "planuda": "pla-nu-da",
    "planudo": "pla-nu-do",
    "plaqué": "pla-qué",
    "plaqueta": "pla-que-ta",
    "plaquetario": "pla-que-ta-rio",
    "plaquín": "pla-quín",
    "plasenciana": "pla-sen-cia-na",
    "plasenciano": "pla-sen-cia-no",
    "plasentina": "pla-sen-ti-na",
    "plasentino": "pla-sen-ti-no",
    "plasma": "plas-ma",
    "plasmación": "plas-ma-ción",
    "plasmador": "plas-ma-dor",
    "plasmadora": "plas-ma-do-ra",
    "plasmar": "plas-mar",
    "plasmática": "plas-má-ti-ca",
    "plasmático": "plas-má-ti-co",
    "plasmodio": "plas-mo-dio",
    "plasta": "plas-ta",
    "plaste": "plas-te",
    "plastecer": "plas-te-cer",
    "plastecido": "plas-te-ci-do",
    "plastelina": "plas-te-li-na",
    "plastia": "plas-tia",
    "plástica": "plás-ti-ca",
    "plásticamente": "plás-ti-ca-men-te",
    "plasticidad": "plas-ti-ci-dad",
    "plástico": "plás-ti-co",
    "plastidio": "plas-ti-dio",
    "plastificación": "plas-ti-fi-ca-ción",
    "plastificado": "plas-ti-fi-ca-do",
    "plastificar": "plas-ti-fi-car",
    "plastilina": "plas-ti-li-na",
    "plasto": "plas-to",
    "plastrón": "plas-trón",
    "plata": "pla-ta",
    "platabanda": "pla-ta-ban-da",
    "platado": "pla-ta-do",
    "plataforma": "pla-ta-for-ma",
    "platal": "pla-tal",
    "platalea": "pla-ta-le-a",
    "platanácea": "pla-ta-ná-ce-a",
    "platanáceo": "pla-ta-ná-ce-o",
    "platanal": "pla-ta-nal",
    "platanar": "pla-ta-nar",
    "platanazo": "pla-ta-na-zo",
    "platánea": "pla-tá-ne-a",
    "platáneo": "pla-tá-ne-o",
    "platanera": "pla-ta-ne-ra",
    "platanero": "pla-ta-ne-ro",
    "plátano": "plá-ta-no",
    "platea": "pla-te-a",
    "plateada": "pla-te-a-da",
    "plateado": "pla-te-a-do",
    "plateador": "pla-te-a-dor",
    "plateadora": "pla-te-a-do-ra",
    "plateadura": "pla-te-a-du-ra",
    "platear": "pla-te-ar",
    "platel": "pla-tel",
    "platelminto": "pla-tel-min-to",
    "platense": "pla-ten-se",
    "platera": "pla-te-ra",
    "plateresca": "pla-te-res-ca",
    "plateresco": "pla-te-res-co",
    "platería": "pla-te-rí-a",
    "platero": "pla-te-ro",
    "plática": "plá-ti-ca",
    "platicable": "pla-ti-ca-ble",
    "platicada": "pla-ti-ca-da",
    "platicadera": "pla-ti-ca-de-ra",
    "platicador": "pla-ti-ca-dor",
    "platicar": "pla-ti-car",
    "platija": "pla-ti-ja",
    "platilla": "pla-ti-lla",
    "platillera": "pla-ti-lle-ra",
    "platillero": "pla-ti-lle-ro",
    "platillo": "pla-ti-llo",
    "platina": "pla-ti-na",
    "platinado": "pla-ti-na-do",
    "platinar": "pla-ti-nar",
    "platinífera": "pla-ti-ní-fe-ra",
    "platinífero": "pla-ti-ní-fe-ro",
    "platinista": "pla-ti-nis-ta",
    "platino": "pla-ti-no",
    "platinoide": "pla-ti-noi-de",
    "platinotipia": "pla-ti-no-ti-pia",
    "platirrinia": "pla-ti-rri-nia",
    "platirrino": "pla-ti-rri-no",
    "platívolo": "pla-tí-vo-lo",
    "plato": "pla-to",
    "plató": "pla-tó",
    "platón": "pla-tón",
    "platónica": "pla-tó-ni-ca",
    "platónicamente": "pla-tó-ni-ca-men-te",
    "platónico": "pla-tó-ni-co",
    "platonismo": "pla-to-nis-mo",
    "platonizante": "pla-to-ni-zan-te",
    "platuda": "pla-tu-da",
    "platudo": "pla-tu-do",
    "platuja": "pla-tu-ja",
    "platusa": "pla-tu-sa",
    "plausibilidad": "plau-si-bi-li-dad",
    "plausible": "plau-si-ble",
    "plausiblemente": "plau-si-ble-men-te",
    "plausiva": "plau-si-va",
    "plausivo": "plau-si-vo",
    "plauso": "plau-so",
    "plaustro": "plaus-tro",
    "plautina": "plau-ti-na",
    "plautino": "plau-ti-no",
    "playa": "pla-ya",
    "playada": "pla-ya-da",
    "playado": "pla-ya-do",
    "playar": "pla-yar",
    "playazo": "pla-ya-zo",
    "playera": "pla-ye-ra",
    "playero": "pla-ye-ro",
    "playo": "pla-yo",
    "playón": "pla-yón",
    "plaza": "pla-za",
    "plazo": "pla-zo",
    "plazoleta": "pla-zo-le-ta",
    "plazuela": "pla-zue-la",
    "pleamar": "ple-a-mar",
    "plebano": "ple-ba-no",
    "plebe": "ple-be",
    "plebea": "ple-be-a",
    "plebeo": "ple-be-o",
    "plebeya": "ple-be-ya",
    "plebeyez": "ple-be-yez",
    "plebeyo": "ple-be-yo",
    "plebiscitaria": "ple-bis-ci-ta-ria",
    "plebiscitario": "ple-bis-ci-ta-rio",
    "plebiscito": "ple-bis-ci-to",
    "pleca": "ple-ca",
    "plectognato": "plec-tog-na-to",
    "plectro": "plec-tro",
    "plegable": "ple-ga-ble",
    "plegadamente": "ple-ga-da-men-te",
    "plegadera": "ple-ga-de-ra",
    "plegadiza": "ple-ga-di-za",
    "plegadizo": "ple-ga-di-zo",
    "plegado": "ple-ga-do",
    "plegador": "ple-ga-dor",
    "plegadora": "ple-ga-do-ra",
    "plegadura": "ple-ga-du-ra",
    "plegamiento": "ple-ga-mien-to",
    "plegar": "ple-gar",
    "plegaria": "ple-ga-ria",
    "pleguería": "ple-gue-rí-a",
    "pleguete": "ple-gue-te",
    "pleistoceno": "pleis-to-ce-no",
    "pleita": "plei-ta",
    "pleiteador": "plei-te-a-dor",
    "pleiteadora": "plei-te-a-do-ra",
    "pleiteante": "plei-te-an-te",
    "pleitear": "plei-te-ar",
    "pleités": "plei-tés",
    "pleitesía": "plei-te-sí-a",
    "pleitista": "plei-tis-ta",
    "pleito": "plei-to",
    "plementería": "ple-men-te-rí-a",
    "plemento": "ple-men-to",
    "plena": "ple-na",
    "plenamar": "ple-na-mar",
    "plenamente": "ple-na-men-te",
    "plenaria": "ple-na-ria",
    "plenariamente": "ple-na-ria-men-te",
    "plenario": "ple-na-rio",
    "plenilunio": "ple-ni-lu-nio",
    "plenipotencia": "ple-ni-po-ten-cia",
    "plenipotenciaria": "ple-ni-po-ten-cia-ria",
    "plenipotenciario": "ple-ni-po-ten-cia-rio",
    "plenitud": "ple-ni-tud",
    "pleno": "ple-no",
    "pleon": "ple-on",
    "pleonasmo": "ple-o-nas-mo",
    "pleonástica": "ple-o-nás-ti-ca",
    "pleonásticamente": "ple-o-nás-ti-ca-men-te",
    "pleonástico": "ple-o-nás-ti-co",
    "plepa": "ple-pa",
    "plesímetro": "ple-sí-me-tro",
    "plesiosaurio": "ple-sio-sau-rio",
    "plesiosauro": "ple-sio-sau-ro",
    "pletina": "ple-ti-na",
    "plétora": "plé-to-ra",
    "pletórica": "ple-tó-ri-ca",
    "pletórico": "ple-tó-ri-co",
    "pleura": "pleu-ra",
    "pleural": "pleu-ral",
    "pleuresía": "pleu-re-sí-a",
    "pleurítica": "pleu-rí-ti-ca",
    "pleurítico": "pleu-rí-ti-co",
    "pleuritis": "pleu-ri-tis",
    "pleurodinia": "pleu-ro-di-nia",
    "pleuronectiforme": "pleu-ro-nec-ti-for-me",
    "pleuronecto": "pleu-ro-nec-to",
    "pleuroneumonía": "pleu-ro-neu-mo-ní-a",
    "plexiglás": "ple-xi-glás",
    "plexo": "ple-xo",
    "pléyade": "plé-ya-de",
    "plica": "pli-ca",
    "pliego": "plie-go",
    "pliegue": "plie-gue",
    "plieguecillo": "plie-gue-ci-llo",
    "plinto": "plin-to",
    "plioceno": "plio-ce-no",
    "plisado": "pli-sa-do",
    "plisar": "pli-sar",
    "plomada": "plo-ma-da",
    "plomar": "plo-mar",
    "plomazo": "plo-ma-zo",
    "plomazón": "plo-ma-zón",
    "plombagina": "plom-ba-gi-na",
    "plomear": "plo-me-ar",
    "plomera": "plo-me-ra",
    "plomería": "plo-me-rí-a",
    "plomero": "plo-me-ro",
    "plomífero": "plo-mí-fe-ro",
    "plomiza": "plo-mi-za",
    "plomizo": "plo-mi-zo",
    "plomo": "plo-mo",
    "plomosa": "plo-mo-sa",
    "plomoso": "plo-mo-so",
    "plorar": "plo-rar",
    "plotear": "plo-te-ar",
    "plóter": "pló-ter",
    "plotter": "plot-ter",
    "pluma": "plu-ma",
    "plumada": "plu-ma-da",
    "plumado": "plu-ma-do",
    "plumaje": "plu-ma-je",
    "plumajear": "plu-ma-je-ar",
    "plumajería": "plu-ma-je-rí-a",
    "plumajero": "plu-ma-je-ro",
    "plumaria": "plu-ma-ria",
    "plumario": "plu-ma-rio",
    "plumazo": "plu-ma-zo",
    "plumazón": "plu-ma-zón",
    "plumbada": "plum-ba-da",
    "plumbado": "plum-ba-do",
    "plumbagina": "plum-ba-gi-na",
    "plumbaginácea": "plum-ba-gi-ná-ce-a",
    "plumbagináceo": "plum-ba-gi-ná-ce-o",
    "plumbagínea": "plum-ba-gí-ne-a",
    "plumbagíneo": "plum-ba-gí-ne-o",
    "plumbago": "plum-ba-go",
    "plúmbea": "plúm-be-a",
    "plúmbeo": "plúm-be-o",
    "plúmbica": "plúm-bi-ca",
    "plúmbico": "plúm-bi-co",
    "plumbífero": "plum-bí-fe-ro",
    "plumcake": "plum-ca-ke",
    "plúmea": "plú-me-a",
    "plumeado": "plu-me-a-do",
    "plumear": "plu-me-ar",
    "plúmeo": "plú-me-o",
    "plumería": "plu-me-rí-a",
    "plumerilla": "plu-me-ri-lla",
    "plumerío": "plu-me-rí-o",
    "plumero": "plu-me-ro",
    "plumier": "plu-mier",
    "plumífera": "plu-mí-fe-ra",
    "plumífero": "plu-mí-fe-ro",
    "plumilla": "plu-mi-lla",
    "plumín": "plu-mín",
    "plumión": "plu-mión",
    "plumista": "plu-mis-ta",
    "plumón": "plu-món",
    "plumosa": "plu-mo-sa",
    "plumoso": "plu-mo-so",
    "plúmula": "plú-mu-la",
    "plural": "plu-ral",
    "pluralidad": "plu-ra-li-dad",
    "pluralismo": "plu-ra-lis-mo",
    "pluralista": "plu-ra-lis-ta",
    "pluralización": "plu-ra-li-za-ción",
    "pluralizar": "plu-ra-li-zar",
    "plurianual": "plu-ria-nual",
    "pluricelular": "plu-ri-ce-lu-lar",
    "pluridimensional": "plu-ri-di-men-sio-nal",
    "pluridisciplinar": "plu-ri-dis-ci-pli-nar",
    "pluriempleada": "plu-riem-ple-a-da",
    "pluriempleado": "plu-riem-ple-a-do",
    "pluriempleo": "plu-riem-ple-o",
    "pluriforme": "plu-ri-for-me",
    "plurilateral": "plu-ri-la-te-ral",
    "plurilingüe": "plu-ri-lin-güe",
    "plurilingüismo": "plu-ri-lin-güis-mo",
    "plurimembre": "plu-ri-mem-bre",
    "plurinacional": "plu-ri-na-cio-nal",
    "pluripartidismo": "plu-ri-par-ti-dis-mo",
    "pluripartidista": "plu-ri-par-ti-dis-ta",
    "plurivalencia": "plu-ri-va-len-cia",
    "plurivalente": "plu-ri-va-len-te",
    "pluscuamperfecto": "plus-cuam-per-fec-to",
    "plusmarca": "plus-mar-ca",
    "plusmarquista": "plus-mar-quis-ta",
    "pluspetición": "plus-pe-ti-ción",
    "plusvalía": "plus-va-lí-a",
    "plúteo": "plú-te-o",
    "plutocracia": "plu-to-cra-cia",
    "plutócrata": "plu-tó-cra-ta",
    "plutocrática": "plu-to-crá-ti-ca",
    "plutocrático": "plu-to-crá-ti-co",
    "plutoniana": "plu-to-nia-na",
    "plutoniano": "plu-to-nia-no",
    "plutónica": "plu-tó-ni-ca",
    "plutónico": "plu-tó-ni-co",
    "plutonio": "plu-to-nio",
    "plutonismo": "plu-to-nis-mo",
    "plutonista": "plu-to-nis-ta",
    "pluvia": "plu-via",
    "pluvial": "plu-vial",
    "pluvímetro": "plu-ví-me-tro",
    "pluviometría": "plu-vio-me-trí-a",
    "pluviométrica": "plu-vio-mé-tri-ca",
    "pluviométrico": "plu-vio-mé-tri-co",
    "pluviómetro": "plu-vió-me-tro",
    "pluvionival": "plu-vio-ni-val",
    "pluviosa": "plu-vio-sa",
    "pluviosidad": "plu-vio-si-dad",
    "pluvioso": "plu-vio-so",
    "pneuma": "pneu-ma",
    "poa": "po-a",
    "pobeda": "po-be-da",
    "poblacho": "po-bla-cho",
    "población": "po-bla-ción",
    "poblacional": "po-bla-cio-nal",
    "poblada": "po-bla-da",
    "poblado": "po-bla-do",
    "poblador": "po-bla-dor",
    "pobladora": "po-bla-do-ra",
    "poblamiento": "po-bla-mien-to",
    "poblana": "po-bla-na",
    "poblano": "po-bla-no",
    "poblar": "po-blar",
    "poblazo": "po-bla-zo",
    "poblazón": "po-bla-zón",
    "pobo": "po-bo",
    "pobra": "po-bra",
    "pobre": "po-bre",
    "pobredad": "po-bre-dad",
    "pobremente": "po-bre-men-te",
    "pobrería": "po-bre-rí-a",
    "pobrero": "po-bre-ro",
    "pobreta": "po-bre-ta",
    "pobrete": "po-bre-te",
    "pobretear": "po-bre-te-ar",
    "pobretería": "po-bre-te-rí-a",
    "pobreto": "po-bre-to",
    "pobretón": "po-bre-tón",
    "pobretona": "po-bre-to-na",
    "pobreza": "po-bre-za",
    "pobrismo": "po-bris-mo",
    "poca": "po-ca",
    "pocera": "po-ce-ra",
    "pocero": "po-ce-ro",
    "poceta": "po-ce-ta",
    "pocha": "po-cha",
    "pochismo": "po-chis-mo",
    "pocho": "po-cho",
    "pochoclo": "po-cho-clo",
    "pocholada": "po-cho-la-da",
    "pocholo": "po-cho-lo",
    "pochotal": "po-cho-tal",
    "pochote": "po-cho-te",
    "pochotera": "po-cho-te-ra",
    "pochotero": "po-cho-te-ro",
    "pocilga": "po-cil-ga",
    "pocillero": "po-ci-lle-ro",
    "pocillo": "po-ci-llo",
    "pócima": "pó-ci-ma",
    "poción": "po-ción",
    "poco": "po-co",
    "pocomam": "po-co-mam",
    "pocomchí": "po-com-chí",
    "pocotón": "po-co-tón",
    "pocoyo": "po-co-yo",
    "póculo": "pó-cu-lo",
    "poda": "po-da",
    "podada": "po-da-da",
    "podadera": "po-da-de-ra",
    "podador": "po-da-dor",
    "podadora": "po-da-do-ra",
    "podadura": "po-da-du-ra",
    "podagra": "po-da-gra",
    "podal": "po-dal",
    "podálico": "po-dá-li-co",
    "podar": "po-dar",
    "podatario": "po-da-ta-rio",
    "podazón": "po-da-zón",
    "podenca": "po-den-ca",
    "podenco": "po-den-co",
    "podenquero": "po-den-que-ro",
    "poder": "po-der",
    "poderdante": "po-der-dan-te",
    "poderhabiente": "po-de-rha-bien-te",
    "poderío": "po-de-rí-o",
    "poderosa": "po-de-ro-sa",
    "poderosamente": "po-de-ro-sa-men-te",
    "poderoso": "po-de-ro-so",
    "podiatra": "po-dia-tra",
    "podio": "po-dio",
    "pódium": "pó-dium",
    "podo": "po-do",
    "podóloga": "po-dó-lo-ga",
    "podología": "po-do-lo-gí-a",
    "podólogo": "po-dó-lo-go",
    "podómetro": "po-dó-me-tro",
    "podón": "po-dón",
    "podre": "po-dre",
    "podrecer": "po-dre-cer",
    "podrecimiento": "po-dre-ci-mien-to",
    "podredumbre": "po-dre-dum-bre",
    "podredura": "po-dre-du-ra",
    "podrición": "po-dri-ción",
    "podrida": "po-dri-da",
    "podridero": "po-dri-de-ro",
    "podrido": "po-dri-do",
    "podrigorio": "po-dri-go-rio",
    "podrimiento": "po-dri-mien-to",
    "podrir": "po-drir",
    "poema": "po-e-ma",
    "poemario": "po-e-ma-rio",
    "poemática": "po-e-má-ti-ca",
    "poemático": "po-e-má-ti-co",
    "poesía": "po-e-sí-a",
    "poeta": "po-e-ta",
    "poetar": "po-e-tar",
    "poetastra": "po-e-tas-tra",
    "poetastro": "po-e-tas-tro",
    "poética": "po-é-ti-ca",
    "poéticamente": "po-é-ti-ca-men-te",
    "poético": "po-é-ti-co",
    "poetisa": "po-e-ti-sa",
    "poetización": "po-e-ti-za-ción",
    "poetizar": "po-e-ti-zar",
    "poetría": "po-e-trí-a",
    "pogromo": "po-gro-mo",
    "poíno": "po-í-no",
    "poiquiloterma": "poi-qui-lo-ter-ma",
    "poiquilotermia": "poi-qui-lo-ter-mia",
    "poiquilotérmico": "poi-qui-lo-tér-mi-co",
    "poiquilotermo": "poi-qui-lo-ter-mo",
    "poisa": "poi-sa",
    "poise": "poi-se",
    "polaca": "po-la-ca",
    "polacada": "po-la-ca-da",
    "polaco": "po-la-co",
    "polacra": "po-la-cra",
    "polada": "po-la-da",
    "polaina": "po-lai-na",
    "polaquear": "po-la-que-ar",
    "polar": "po-lar",
    "polaridad": "po-la-ri-dad",
    "polarimetría": "po-la-ri-me-trí-a",
    "polarimétrico": "po-la-ri-mé-tri-co",
    "polarímetro": "po-la-rí-me-tro",
    "polariscopio": "po-la-ris-co-pio",
    "polarización": "po-la-ri-za-ción",
    "polarizador": "po-la-ri-za-dor",
    "polarizar": "po-la-ri-zar",
    "polca": "pol-ca",
    "polcar": "pol-car",
    "polcas": "pol-cas",
    "polco": "pol-co",
    "pólder": "pól-der",
    "polea": "po-le-a",
    "poleadas": "po-le-a-das",
    "poleame": "po-le-a-me",
    "polemarca": "po-le-mar-ca",
    "polémica": "po-lé-mi-ca",
    "polémico": "po-lé-mi-co",
    "polemista": "po-le-mis-ta",
    "polemizar": "po-le-mi-zar",
    "polemología": "po-le-mo-lo-gí-a",
    "polemoniácea": "po-le-mo-niá-ce-a",
    "polemoniáceo": "po-le-mo-niá-ce-o",
    "polemonio": "po-le-mo-nio",
    "polen": "po-len",
    "polenta": "po-len-ta",
    "poleo": "po-le-o",
    "polera": "po-le-ra",
    "polerón": "po-le-rón",
    "poleví": "po-le-ví",
    "pólex": "pó-lex",
    "poli": "po-li",
    "poliadelfos": "po-lia-del-fos",
    "polialcohol": "po-lial-co-hol",
    "poliamida": "po-lia-mi-da",
    "poliandria": "po-lian-dria",
    "poliantea": "po-lian-te-a",
    "poliaquenio": "po-lia-que-nio",
    "poliarca": "po-liar-ca",
    "poliarquía": "po-liar-quí-a",
    "poliárquica": "po-liár-qui-ca",
    "poliárquico": "po-liár-qui-co",
    "polibán": "po-li-bán",
    "policarbonato": "po-li-car-bo-na-to",
    "pólice": "pó-li-ce",
    "polichinela": "po-li-chi-ne-la",
    "policía": "po-li-cí-a",
    "policiaca": "po-li-cia-ca",
    "policíaco": "po-li-cí-a-co",
    "policiaco": "po-li-cia-co",
    "policial": "po-li-cial",
    "policitación": "po-li-ci-ta-ción",
    "policivo": "po-li-ci-vo",
    "policlínica": "po-li-clí-ni-ca",
    "policlínico": "po-li-clí-ni-co",
    "policopia": "po-li-co-pia",
    "policopiador": "po-li-co-pia-dor",
    "policopista": "po-li-co-pis-ta",
    "policroísmo": "po-li-cro-ís-mo",
    "policroma": "po-li-cro-ma",
    "policromado": "po-li-cro-ma-do",
    "policromar": "po-li-cro-mar",
    "policromía": "po-li-cro-mí-a",
    "policromo": "po-li-cro-mo",
    "policultivo": "po-li-cul-ti-vo",
    "polida": "po-li-da",
    "polideportiva": "po-li-de-por-ti-va",
    "polideportivo": "po-li-de-por-ti-vo",
    "polideza": "po-li-de-za",
    "polidipsia": "po-li-dip-sia",
    "polido": "po-li-do",
    "polidor": "po-li-dor",
    "poliédrica": "po-lié-dri-ca",
    "poliédrico": "po-lié-dri-co",
    "poliedro": "po-lie-dro",
    "poliéster": "po-liés-ter",
    "poliestireno": "po-lies-ti-re-no",
    "polietileno": "po-lie-ti-le-no",
    "polifacético": "po-li-fa-cé-ti-co",
    "polífaga": "po-lí-fa-ga",
    "polifagia": "po-li-fa-gia",
    "polífago": "po-lí-fa-go",
    "polifarmacia": "po-li-far-ma-cia",
    "polifásica": "po-li-fá-si-ca",
    "polifásico": "po-li-fá-si-co",
    "polífona": "po-lí-fo-na",
    "polifonemático": "po-li-fo-ne-má-ti-co",
    "polifonía": "po-li-fo-ní-a",
    "polifónica": "po-li-fó-ni-ca",
    "polifónico": "po-li-fó-ni-co",
    "polífono": "po-lí-fo-no",
    "polígala": "po-lí-ga-la",
    "poligalácea": "po-li-ga-lá-ce-a",
    "poligaláceo": "po-li-ga-lá-ce-o",
    "poligálea": "po-li-gá-le-a",
    "poligáleo": "po-li-gá-le-o",
    "poligalia": "po-li-ga-lia",
    "polígama": "po-lí-ga-ma",
    "poligamia": "po-li-ga-mia",
    "poligámico": "po-li-gá-mi-co",
    "polígamo": "po-lí-ga-mo",
    "poligenismo": "po-li-ge-nis-mo",
    "poligenista": "po-li-ge-nis-ta",
    "poliginia": "po-li-gi-nia",
    "políglota": "po-lí-glo-ta",
    "poliglotía": "po-li-glo-tí-a",
    "poliglotismo": "po-li-glo-tis-mo",
    "polígloto": "po-lí-glo-to",
    "polígona": "po-lí-go-na",
    "poligonácea": "po-li-go-ná-ce-a",
    "poligonáceo": "po-li-go-ná-ce-o",
    "poligonal": "po-li-go-nal",
    "polígono": "po-lí-go-no",
    "polígrafa": "po-lí-gra-fa",
    "poligrafía": "po-li-gra-fí-a",
    "poligráfica": "po-li-grá-fi-ca",
    "poligráfico": "po-li-grá-fi-co",
    "polígrafo": "po-lí-gra-fo",
    "polilla": "po-li-lla",
    "polimatía": "po-li-ma-tí-a",
    "polimerasa": "po-li-me-ra-sa",
    "polimérico": "po-li-mé-ri-co",
    "polimerización": "po-li-me-ri-za-ción",
    "polímero": "po-lí-me-ro",
    "polimetría": "po-li-me-trí-a",
    "polimétrica": "po-li-mé-tri-ca",
    "polimétrico": "po-li-mé-tri-co",
    "polímita": "po-lí-mi-ta",
    "polimorfa": "po-li-mor-fa",
    "polimórfico": "po-li-mór-fi-co",
    "polimorfismo": "po-li-mor-fis-mo",
    "polimorfo": "po-li-mor-fo",
    "polín": "po-lín",
    "polinesia": "po-li-ne-sia",
    "polinésica": "po-li-né-si-ca",
    "polinésico": "po-li-né-si-co",
    "polinesio": "po-li-ne-sio",
    "polineuritis": "po-li-neu-ri-tis",
    "polínico": "po-lí-ni-co",
    "polinización": "po-li-ni-za-ción",
    "polinizar": "po-li-ni-zar",
    "polinomio": "po-li-no-mio",
    "polinosis": "po-li-no-sis",
    "polio": "po-lio",
    "poliomielítica": "po-lio-mie-lí-ti-ca",
    "poliomielítico": "po-lio-mie-lí-ti-co",
    "poliomielitis": "po-lio-mie-li-tis",
    "poliorcética": "po-lior-cé-ti-ca",
    "polipasto": "po-li-pas-to",
    "polipero": "po-li-pe-ro",
    "polipétala": "po-li-pé-ta-la",
    "polipétalo": "po-li-pé-ta-lo",
    "poliplacóforo": "po-li-pla-có-fo-ro",
    "pólipo": "pó-li-po",
    "polipodiácea": "po-li-po-diá-ce-a",
    "polipodiáceo": "po-li-po-diá-ce-o",
    "polipodio": "po-li-po-dio",
    "polipote": "po-li-po-te",
    "políptico": "po-líp-ti-co",
    "poliptoton": "po-lip-to-ton",
    "poliqueto": "po-li-que-to",
    "polir": "po-lir",
    "polirritmia": "po-li-rrit-mia",
    "polis": "po-lis",
    "polisacárido": "po-li-sa-cá-ri-do",
    "polisarcia": "po-li-sar-cia",
    "polisemia": "po-li-se-mia",
    "polisémico": "po-li-sé-mi-co",
    "polisépala": "po-li-sé-pa-la",
    "polisépalo": "po-li-sé-pa-lo",
    "polisílaba": "po-li-sí-la-ba",
    "polisílabo": "po-li-sí-la-bo",
    "polisíndeton": "po-li-sín-de-ton",
    "polisintética": "po-li-sin-té-ti-ca",
    "polisintético": "po-li-sin-té-ti-co",
    "polisón": "po-li-són",
    "polispasto": "po-lis-pas-to",
    "polista": "po-lis-ta",
    "polistila": "po-lis-ti-la",
    "polistilo": "po-lis-ti-lo",
    "politburó": "po-lit-bu-ró",
    "politécnica": "po-li-téc-ni-ca",
    "politécnico": "po-li-téc-ni-co",
    "politeísmo": "po-li-te-ís-mo",
    "politeísta": "po-li-te-ís-ta",
    "política": "po-lí-ti-ca",
    "políticamente": "po-lí-ti-ca-men-te",
    "politicastra": "po-li-ti-cas-tra",
    "politicastro": "po-li-ti-cas-tro",
    "politicismo": "po-li-ti-cis-mo",
    "político": "po-lí-ti-co",
    "politicón": "po-li-ti-cón",
    "politicona": "po-li-ti-co-na",
    "politiquear": "po-li-ti-que-ar",
    "politiqueo": "po-li-ti-que-o",
    "politiquera": "po-li-ti-que-ra",
    "politiquería": "po-li-ti-que-rí-a",
    "politiquero": "po-li-ti-que-ro",
    "politización": "po-li-ti-za-ción",
    "politizar": "po-li-ti-zar",
    "politóloga": "po-li-tó-lo-ga",
    "politología": "po-li-to-lo-gí-a",
    "politólogo": "po-li-tó-lo-go",
    "politonal": "po-li-to-nal",
    "politonalidad": "po-li-to-na-li-dad",
    "politraumatismo": "po-li-trau-ma-tis-mo",
    "poliuretano": "po-liu-re-ta-no",
    "poliuria": "po-liu-ria",
    "polivalencia": "po-li-va-len-cia",
    "polivalente": "po-li-va-len-te",
    "polivalva": "po-li-val-va",
    "polivalvo": "po-li-val-vo",
    "polivinílico": "po-li-vi-ní-li-co",
    "polivinilo": "po-li-vi-ni-lo",
    "póliza": "pó-li-za",
    "polizón": "po-li-zón",
    "polizona": "po-li-zo-na",
    "polizonte": "po-li-zon-te",
    "polje": "pol-je",
    "polka": "pol-ka",
    "polla": "po-lla",
    "pollada": "po-lla-da",
    "pollancón": "po-llan-cón",
    "pollancona": "po-llan-co-na",
    "pollastra": "po-llas-tra",
    "pollastre": "po-llas-tre",
    "pollastro": "po-llas-tro",
    "pollazón": "po-lla-zón",
    "pollear": "po-lle-ar",
    "pollera": "po-lle-ra",
    "pollería": "po-lle-rí-a",
    "pollero": "po-lle-ro",
    "pollerudo": "po-lle-ru-do",
    "pollez": "po-llez",
    "pollina": "po-lli-na",
    "pollinarmente": "po-lli-nar-men-te",
    "pollino": "po-lli-no",
    "pollita": "po-lli-ta",
    "pollito": "po-lli-to",
    "pollo": "po-llo",
    "polluela": "po-llue-la",
    "polluelo": "po-llue-lo",
    "polo": "po-lo",
    "pololear": "po-lo-le-ar",
    "pololo": "po-lo-lo",
    "polona": "po-lo-na",
    "polonés": "po-lo-nés",
    "polonesa": "po-lo-ne-sa",
    "polonia": "po-lo-nia",
    "polonio": "po-lo-nio",
    "polono": "po-lo-no",
    "polquitas": "pol-qui-tas",
    "poltergeist": "pol-ter-geist",
    "poltrón": "pol-trón",
    "poltrona": "pol-tro-na",
    "poltronería": "pol-tro-ne-rí-a",
    "poltronizar": "pol-tro-ni-zar",
    "poltronizarse": "pol-tro-ni-zar-se",
    "polución": "po-lu-ción",
    "polucionar": "po-lu-cio-nar",
    "poluta": "po-lu-ta",
    "poluto": "po-lu-to",
    "polvareda": "pol-va-re-da",
    "polvazal": "pol-va-zal",
    "polvear": "pol-ve-ar",
    "polvera": "pol-ve-ra",
    "polverío": "pol-ve-rí-o",
    "polvero": "pol-ve-ro",
    "polvificar": "pol-vi-fi-car",
    "polvillo": "pol-vi-llo",
    "polvo": "pol-vo",
    "pólvora": "pól-vo-ra",
    "polvoraduque": "pol-vo-ra-du-que",
    "polvoreamiento": "pol-vo-re-a-mien-to",
    "polvorear": "pol-vo-re-ar",
    "polvorera": "pol-vo-re-ra",
    "polvorienta": "pol-vo-rien-ta",
    "polvoriento": "pol-vo-rien-to",
    "polvorilla": "pol-vo-ri-lla",
    "polvorín": "pol-vo-rín",
    "polvorista": "pol-vo-ris-ta",
    "polvorizable": "pol-vo-ri-za-ble",
    "polvorización": "pol-vo-ri-za-ción",
    "polvorizar": "pol-vo-ri-zar",
    "polvorón": "pol-vo-rón",
    "polvorosa": "pol-vo-ro-sa",
    "polvoroso": "pol-vo-ro-so",
    "poma": "po-ma",
    "pomabambina": "po-ma-bam-bi-na",
    "pomabambino": "po-ma-bam-bi-no",
    "pomácea": "po-má-ce-a",
    "pomáceo": "po-má-ce-o",
    "pomada": "po-ma-da",
    "pomar": "po-mar",
    "pomarada": "po-ma-ra-da",
    "pomarrosa": "po-ma-rro-sa",
    "pombero": "pom-be-ro",
    "pomelo": "po-me-lo",
    "pomerana": "po-me-ra-na",
    "pomerano": "po-me-ra-no",
    "pómez": "pó-mez",
    "pomífera": "po-mí-fe-ra",
    "pomífero": "po-mí-fe-ro",
    "pomiforme": "po-mi-for-me",
    "pomo": "po-mo",
    "pomóloga": "po-mó-lo-ga",
    "pomología": "po-mo-lo-gí-a",
    "pomológico": "po-mo-ló-gi-co",
    "pomologista": "po-mo-lo-gis-ta",
    "pomólogo": "po-mó-lo-go",
    "pompa": "pom-pa",
    "pompática": "pom-pá-ti-ca",
    "pompático": "pom-pá-ti-co",
    "pompear": "pom-pe-ar",
    "pompeyana": "pom-pe-ya-na",
    "pompeyano": "pom-pe-ya-no",
    "pompi": "pom-pi",
    "pompis": "pom-pis",
    "pompo": "pom-po",
    "pompón": "pom-pón",
    "pomponear": "pom-po-ne-ar",
    "pomponearse": "pom-po-ne-ar-se",
    "pomponera": "pom-po-ne-ra",
    "pomposa": "pom-po-sa",
    "pomposamente": "pom-po-sa-men-te",
    "pomposidad": "pom-po-si-dad",
    "pomposo": "pom-po-so",
    "pómulo": "pó-mu-lo",
    "ponasí": "po-na-sí",
    "poncella": "pon-ce-lla",
    "ponceña": "pon-ce-ña",
    "ponceño": "pon-ce-ño",
    "poncha": "pon-cha",
    "ponchada": "pon-cha-da",
    "ponchar": "pon-char",
    "ponchazo": "pon-cha-zo",
    "ponche": "pon-che",
    "ponchera": "pon-che-ra",
    "poncho": "pon-cho",
    "poncí": "pon-cí",
    "poncidre": "pon-ci-dre",
    "poncil": "pon-cil",
    "ponderable": "pon-de-ra-ble",
    "ponderación": "pon-de-ra-ción",
    "ponderada": "pon-de-ra-da",
    "ponderadamente": "pon-de-ra-da-men-te",
    "ponderado": "pon-de-ra-do",
    "ponderador": "pon-de-ra-dor",
    "ponderadora": "pon-de-ra-do-ra",
    "ponderal": "pon-de-ral",
    "ponderar": "pon-de-rar",
    "ponderativa": "pon-de-ra-ti-va",
    "ponderativo": "pon-de-ra-ti-vo",
    "ponderosa": "pon-de-ro-sa",
    "ponderosamente": "pon-de-ro-sa-men-te",
    "ponderosidad": "pon-de-ro-si-dad",
    "ponderoso": "pon-de-ro-so",
    "poneca": "po-ne-ca",
    "ponededo": "po-ne-de-do",
    "ponedera": "po-ne-de-ra",
    "ponedero": "po-ne-de-ro",
    "ponedor": "po-ne-dor",
    "ponedora": "po-ne-do-ra",
    "ponencia": "po-nen-cia",
    "ponente": "po-nen-te",
    "ponentina": "po-nen-ti-na",
    "ponentino": "po-nen-ti-no",
    "ponentisca": "po-nen-tis-ca",
    "ponentisco": "po-nen-tis-co",
    "poner": "po-ner",
    "póney": "pó-ney",
    "ponferradina": "pon-fe-rra-di-na",
    "ponferradino": "pon-fe-rra-di-no",
    "póngido": "pón-gi-do",
    "pongo": "pon-go",
    "poni": "po-ni",
    "ponible": "po-ni-ble",
    "ponientada": "po-nien-ta-da",
    "poniente": "po-nien-te",
    "ponimiento": "po-ni-mien-to",
    "ponleví": "pon-le-ví",
    "ponor": "po-nor",
    "ponqué": "pon-qué",
    "pontaje": "pon-ta-je",
    "pontana": "pon-ta-na",
    "pontazgo": "pon-taz-go",
    "pontazguera": "pon-taz-gue-ra",
    "pontazguero": "pon-taz-gue-ro",
    "ponteadero": "pon-te-a-de-ro",
    "pontear": "pon-te-ar",
    "pontederiácea": "pon-te-de-riá-ce-a",
    "pontederiáceo": "pon-te-de-riá-ce-o",
    "pontevedrés": "pon-te-ve-drés",
    "pontevedresa": "pon-te-ve-dre-sa",
    "pontezuela": "pon-te-zue-la",
    "pontezuelo": "pon-te-zue-lo",
    "póntica": "pón-ti-ca",
    "póntico": "pón-ti-co",
    "pontificado": "pon-ti-fi-ca-do",
    "pontifical": "pon-ti-fi-cal",
    "pontificalmente": "pon-ti-fi-cal-men-te",
    "pontificar": "pon-ti-fi-car",
    "pontífice": "pon-tí-fi-ce",
    "pontificia": "pon-ti-fi-cia",
    "pontificio": "pon-ti-fi-cio",
    "pontín": "pon-tín",
    "ponto": "pon-to",
    "pontocón": "pon-to-cón",
    "pontón": "pon-tón",
    "pontonero": "pon-to-ne-ro",
    "ponzoña": "pon-zo-ña",
    "ponzoñosa": "pon-zo-ño-sa",
    "ponzoñosamente": "pon-zo-ño-sa-men-te",
    "ponzoñoso": "pon-zo-ño-so",
    "popa": "po-pa",
    "popamiento": "po-pa-mien-to",
    "popar": "po-par",
    "popayaneja": "po-pa-ya-ne-ja",
    "popayanejo": "po-pa-ya-ne-jo",
    "pope": "po-pe",
    "popel": "po-pel",
    "popelín": "po-pe-lín",
    "popelina": "po-pe-li-na",
    "popero": "po-pe-ro",
    "popés": "po-pés",
    "popis": "po-pis",
    "poplín": "po-plín",
    "poplítea": "po-plí-te-a",
    "poplíteo": "po-plí-te-o",
    "popó": "po-pó",
    "popocha": "po-po-cha",
    "popocho": "po-po-cho",
    "poporoila": "po-po-roi-la",
    "poporopo": "po-po-ro-po",
    "popotal": "po-po-tal",
    "popote": "po-po-te",
    "popperiana": "pop-pe-ria-na",
    "popperiano": "pop-pe-ria-no",
    "poptí": "pop-tí",
    "populachera": "po-pu-la-che-ra",
    "populachería": "po-pu-la-che-rí-a",
    "populachero": "po-pu-la-che-ro",
    "populacho": "po-pu-la-cho",
    "populación": "po-pu-la-ción",
    "popular": "po-pu-lar",
    "popularidad": "po-pu-la-ri-dad",
    "popularismo": "po-pu-la-ris-mo",
    "popularista": "po-pu-la-ris-ta",
    "popularización": "po-pu-la-ri-za-ción",
    "popularizar": "po-pu-la-ri-zar",
    "popularmente": "po-pu-lar-men-te",
    "populazo": "po-pu-la-zo",
    "populeón": "po-pu-le-ón",
    "populetana": "po-pu-le-ta-na",
    "populetano": "po-pu-le-ta-no",
    "populismo": "po-pu-lis-mo",
    "populista": "po-pu-lis-ta",
    "pópulo": "pó-pu-lo",
    "populosa": "po-pu-lo-sa",
    "populoso": "po-pu-lo-so",
    "popurrí": "po-pu-rrí",
    "popusa": "po-pu-sa",
    "poquedad": "po-que-dad",
    "póquer": "pó-quer",
    "poqueza": "po-que-za",
    "póquil": "pó-quil",
    "poquitera": "po-qui-te-ra",
    "poquitero": "po-qui-te-ro",
    "poquito": "po-qui-to",
    "pora": "po-ra",
    "porcal": "por-cal",
    "porcarizo": "por-ca-ri-zo",
    "porcel": "por-cel",
    "porcelana": "por-ce-la-na",
    "porcelanita": "por-ce-la-ni-ta",
    "porcentaje": "por-cen-ta-je",
    "porcentual": "por-cen-tual",
    "porche": "por-che",
    "porcicultor": "por-ci-cul-tor",
    "porcicultora": "por-ci-cul-to-ra",
    "porcicultura": "por-ci-cul-tu-ra",
    "porcina": "por-ci-na",
    "porcino": "por-ci-no",
    "porción": "por-ción",
    "porcionera": "por-cio-ne-ra",
    "porcionero": "por-cio-ne-ro",
    "porcionista": "por-cio-nis-ta",
    "porcipelo": "por-ci-pe-lo",
    "porciúncula": "por-ciún-cu-la",
    "porco": "por-co",
    "porcuna": "por-cu-na",
    "porcuno": "por-cu-no",
    "pordiosear": "por-dio-se-ar",
    "pordioseo": "por-dio-se-o",
    "pordiosera": "por-dio-se-ra",
    "pordiosería": "por-dio-se-rí-a",
    "pordiosero": "por-dio-se-ro",
    "porexpán": "po-rex-pán",
    "porfa": "por-fa",
    "porfía": "por-fí-a",
    "porfiada": "por-fia-da",
    "porfiadamente": "por-fia-da-men-te",
    "porfiado": "por-fia-do",
    "porfiador": "por-fia-dor",
    "porfiadora": "por-fia-do-ra",
    "porfiar": "por-fiar",
    "porfídica": "por-fí-di-ca",
    "porfídico": "por-fí-di-co",
    "pórfido": "pór-fi-do",
    "porfiosa": "por-fio-sa",
    "porfioso": "por-fio-so",
    "porfiriato": "por-fi-ria-to",
    "porfirina": "por-fi-ri-na",
    "porfirismo": "por-fi-ris-mo",
    "porfirista": "por-fi-ris-ta",
    "porfirizar": "por-fi-ri-zar",
    "porfolio": "por-fo-lio",
    "porgadero": "por-ga-de-ro",
    "porgar": "por-gar",
    "poridad": "po-ri-dad",
    "porífero": "po-rí-fe-ro",
    "pormenor": "por-me-nor",
    "pormenorizar": "por-me-no-ri-zar",
    "porno": "por-no",
    "pornógrafa": "por-nó-gra-fa",
    "pornografía": "por-no-gra-fí-a",
    "pornográfica": "por-no-grá-fi-ca",
    "pornográfico": "por-no-grá-fi-co",
    "pornógrafo": "por-nó-gra-fo",
    "poro": "po-ro",
    "poronga": "po-ron-ga",
    "porongo": "po-ron-go",
    "poronguera": "po-ron-gue-ra",
    "poronguero": "po-ron-gue-ro",
    "pororó": "po-ro-ró",
    "porosa": "po-ro-sa",
    "porosidad": "po-ro-si-dad",
    "poroso": "po-ro-so",
    "porota": "po-ro-ta",
    "porotazo": "po-ro-ta-zo",
    "poroto": "po-ro-to",
    "porque": "por-que",
    "porqué": "por-qué",
    "porquera": "por-que-ra",
    "porquería": "por-que-rí-a",
    "porqueriza": "por-que-ri-za",
    "porquerizo": "por-que-ri-zo",
    "porquero": "por-que-ro",
    "porquerón": "por-que-rón",
    "porqueta": "por-que-ta",
    "porquezuela": "por-que-zue-la",
    "porra": "po-rra",
    "porrácea": "po-rrá-ce-a",
    "porracear": "po-rra-ce-ar",
    "porráceo": "po-rrá-ce-o",
    "porrada": "po-rra-da",
    "porral": "po-rral",
    "porrazo": "po-rra-zo",
    "porrear": "po-rre-ar",
    "porrera": "po-rre-ra",
    "porrería": "po-rre-rí-a",
    "porrero": "po-rre-ro",
    "porreta": "po-rre-ta",
    "porretada": "po-rre-ta-da",
    "porrilla": "po-rri-lla",
    "porrillo": "po-rri-llo",
    "porrina": "po-rri-na",
    "porrino": "po-rri-no",
    "porrista": "po-rris-ta",
    "porro": "po-rro",
    "porrón": "po-rrón",
    "porrona": "po-rro-na",
    "porruda": "po-rru-da",
    "porrudo": "po-rru-do",
    "porsiacaso": "por-sia-ca-so",
    "porta": "por-ta",
    "portaaeronaves": "por-ta-a-e-ro-na-ves",
    "portaalmizcle": "por-ta-al-miz-cle",
    "portaaviones": "por-ta-a-vio-nes",
    "portabandera": "por-ta-ban-de-ra",
    "portabebés": "por-ta-be-bés",
    "portabrocas": "por-ta-bro-cas",
    "portabusto": "por-ta-bus-to",
    "portacaja": "por-ta-ca-ja",
    "portacarabina": "por-ta-ca-ra-bi-na",
    "portacartas": "por-ta-car-tas",
    "portachuelo": "por-ta-chue-lo",
    "portacincha": "por-ta-cin-cha",
    "portación": "por-ta-ción",
    "portacomidas": "por-ta-co-mi-das",
    "portacontenedores": "por-ta-con-te-ne-do-res",
    "portada": "por-ta-da",
    "portadera": "por-ta-de-ra",
    "portadgo": "por-tad-go",
    "portadilla": "por-ta-di-lla",
    "portado": "por-ta-do",
    "portadocumentos": "por-ta-do-cu-men-tos",
    "portador": "por-ta-dor",
    "portadora": "por-ta-do-ra",
    "portaequipaje": "por-ta-e-qui-pa-je",
    "portaequipajes": "por-ta-e-qui-pa-jes",
    "portaestandarte": "por-ta-es-tan-dar-te",
    "portafolio": "por-ta-fo-lio",
    "portafolios": "por-ta-fo-lios",
    "portafusil": "por-ta-fu-sil",
    "portaguión": "por-ta-guión",
    "portahelicópteros": "por-ta-he-li-cóp-te-ros",
    "portaherramientas": "por-ta-he-rra-mien-tas",
    "portaje": "por-ta-je",
    "portal": "por-tal",
    "portalada": "por-ta-la-da",
    "portalámpara": "por-ta-lám-pa-ra",
    "portalámparas": "por-ta-lám-pa-ras",
    "portalápiz": "por-ta-lá-piz",
    "portaleña": "por-ta-le-ña",
    "portalero": "por-ta-le-ro",
    "portalibros": "por-ta-li-bros",
    "portaligas": "por-ta-li-gas",
    "portalira": "por-ta-li-ra",
    "portallaves": "por-ta-lla-ves",
    "portalón": "por-ta-lón",
    "portamaletas": "por-ta-ma-le-tas",
    "portamantas": "por-ta-man-tas",
    "portamanteo": "por-ta-man-te-o",
    "portaminas": "por-ta-mi-nas",
    "portamira": "por-ta-mi-ra",
    "portamonedas": "por-ta-mo-ne-das",
    "portanario": "por-ta-na-rio",
    "portañola": "por-ta-ño-la",
    "portante": "por-tan-te",
    "portantillo": "por-tan-ti-llo",
    "portañuela": "por-ta-ñue-la",
    "portanuevas": "por-ta-nue-vas",
    "portaobjeto": "por-ta-ob-je-to",
    "portaobjetos": "por-ta-ob-je-tos",
    "portapapeles": "por-ta-pa-pe-les",
    "portapaz": "por-ta-paz",
    "portapliegos": "por-ta-plie-gos",
    "portaplumas": "por-ta-plu-mas",
    "portar": "por-tar",
    "portarretrato": "por-ta-rre-tra-to",
    "portarretratos": "por-ta-rre-tra-tos",
    "portarrevistas": "por-ta-rre-vis-tas",
    "portarrollos": "por-ta-rro-llos",
    "portaservilleta": "por-ta-ser-vi-lle-ta",
    "portátil": "por-tá-til",
    "portatrajes": "por-ta-tra-jes",
    "portavalijas": "por-ta-va-li-jas",
    "portavasos": "por-ta-va-sos",
    "portaventanero": "por-ta-ven-ta-ne-ro",
    "portaviandas": "por-ta-vian-das",
    "portavocía": "por-ta-vo-cí-a",
    "portavoz": "por-ta-voz",
    "portazgar": "por-taz-gar",
    "portazgo": "por-taz-go",
    "portazguero": "por-taz-gue-ro",
    "portazo": "por-ta-zo",
    "porte": "por-te",
    "porteador": "por-te-a-dor",
    "porteadora": "por-te-a-do-ra",
    "portear": "por-te-ar",
    "portegado": "por-te-ga-do",
    "porteña": "por-te-ña",
    "porteño": "por-te-ño",
    "portento": "por-ten-to",
    "portentosa": "por-ten-to-sa",
    "portentosamente": "por-ten-to-sa-men-te",
    "portentoso": "por-ten-to-so",
    "porteo": "por-te-o",
    "portera": "por-te-ra",
    "portería": "por-te-rí-a",
    "porteril": "por-te-ril",
    "portero": "por-te-ro",
    "portezuela": "por-te-zue-la",
    "portezuelo": "por-te-zue-lo",
    "portfolio": "port-fo-lio",
    "porticado": "por-ti-ca-do",
    "portichuelo": "por-ti-chue-lo",
    "pórtico": "pór-ti-co",
    "portier": "por-tier",
    "portilla": "por-ti-lla",
    "portillera": "por-ti-lle-ra",
    "portillo": "por-ti-llo",
    "pórtland": "pór-tland",
    "portón": "por-tón",
    "portor": "por-tor",
    "portorriqueña": "por-to-rri-que-ña",
    "portorriqueño": "por-to-rri-que-ño",
    "portovejense": "por-to-ve-jen-se",
    "portrecho": "por-tre-cho",
    "portuaria": "por-tua-ria",
    "portuario": "por-tua-rio",
    "portuense": "por-tuen-se",
    "portugalés": "por-tu-ga-lés",
    "portugalesa": "por-tu-ga-le-sa",
    "portugaluja": "por-tu-ga-lu-ja",
    "portugalujo": "por-tu-ga-lu-jo",
    "portugués": "por-tu-gués",
    "portuguesa": "por-tu-gue-sa",
    "portuguesada": "por-tu-gue-sa-da",
    "portugueseña": "por-tu-gue-se-ña",
    "portugueseño": "por-tu-gue-se-ño",
    "portuguesismo": "por-tu-gue-sis-mo",
    "portuguesista": "por-tu-gue-sis-ta",
    "portulacácea": "por-tu-la-cá-ce-a",
    "portulacáceo": "por-tu-la-cá-ce-o",
    "portulano": "por-tu-la-no",
    "porvenir": "por-ve-nir",
    "porvenireña": "por-ve-ni-re-ña",
    "porvenireño": "por-ve-ni-re-ño",
    "porvida": "por-vi-da",
    "posa": "po-sa",
    "posada": "po-sa-da",
    "posadeña": "po-sa-de-ña",
    "posadeño": "po-sa-de-ño",
    "posadera": "po-sa-de-ra",
    "posaderas": "po-sa-de-ras",
    "posadero": "po-sa-de-ro",
    "posado": "po-sa-do",
    "posador": "po-sa-dor",
    "posadora": "po-sa-do-ra",
    "posante": "po-san-te",
    "posar": "po-sar",
    "posavasos": "po-sa-va-sos",
    "posaverga": "po-sa-ver-ga",
    "posbélico": "pos-bé-li-co",
    "posca": "pos-ca",
    "poscombustión": "pos-com-bus-tión",
    "poscomunión": "pos-co-mu-nión",
    "posdata": "pos-da-ta",
    "posdiluviano": "pos-di-lu-via-no",
    "posdorsal": "pos-dor-sal",
    "pose": "po-se",
    "poseedor": "po-se-e-dor",
    "poseedora": "po-se-e-do-ra",
    "poseer": "po-se-er",
    "poseída": "po-se-í-da",
    "poseído": "po-se-í-do",
    "poselectoral": "po-se-lec-to-ral",
    "posentador": "po-sen-ta-dor",
    "posentadora": "po-sen-ta-do-ra",
    "posera": "po-se-ra",
    "posero": "po-se-ro",
    "posesa": "po-se-sa",
    "posesión": "po-se-sión",
    "posesional": "po-se-sio-nal",
    "posesionar": "po-se-sio-nar",
    "posesionero": "po-se-sio-ne-ro",
    "posesiva": "po-se-si-va",
    "posesividad": "po-se-si-vi-dad",
    "posesivo": "po-se-si-vo",
    "poseso": "po-se-so",
    "posesor": "po-se-sor",
    "posesora": "po-se-so-ra",
    "posesoria": "po-se-so-ria",
    "posesorio": "po-se-so-rio",
    "posfecha": "pos-fe-cha",
    "posfijo": "pos-fi-jo",
    "posglosador": "pos-glo-sa-dor",
    "posgrado": "pos-gra-do",
    "posgraduado": "pos-gra-dua-do",
    "posguerra": "pos-gue-rra",
    "posibilidad": "po-si-bi-li-dad",
    "posibilismo": "po-si-bi-lis-mo",
    "posibilista": "po-si-bi-lis-ta",
    "posibilitación": "po-si-bi-li-ta-ción",
    "posibilitar": "po-si-bi-li-tar",
    "posible": "po-si-ble",
    "posiblemente": "po-si-ble-men-te",
    "posición": "po-si-ción",
    "posicional": "po-si-cio-nal",
    "posicionamiento": "po-si-cio-na-mien-to",
    "posicionar": "po-si-cio-nar",
    "posidonia": "po-si-do-nia",
    "posindustrial": "po-sin-dus-trial",
    "pósit": "pó-sit",
    "positiva": "po-si-ti-va",
    "positivado": "po-si-ti-va-do",
    "positivar": "po-si-ti-var",
    "positividad": "po-si-ti-vi-dad",
    "positivismo": "po-si-ti-vis-mo",
    "positivista": "po-si-ti-vis-ta",
    "positivo": "po-si-ti-vo",
    "pósito": "pó-si-to",
    "positrón": "po-si-trón",
    "positura": "po-si-tu-ra",
    "posliminio": "pos-li-mi-nio",
    "posma": "pos-ma",
    "posmeridiano": "pos-me-ri-dia-no",
    "posmo": "pos-mo",
    "posmoderna": "pos-mo-der-na",
    "posmodernidad": "pos-mo-der-ni-dad",
    "posmodernismo": "pos-mo-der-nis-mo",
    "posmodernista": "pos-mo-der-nis-ta",
    "posmoderno": "pos-mo-der-no",
    "posnatal": "pos-na-tal",
    "posnominal": "pos-no-mi-nal",
    "poso": "po-so",
    "posó": "po-só",
    "posología": "po-so-lo-gí-a",
    "posón": "po-són",
    "posoperatorio": "po-so-pe-ra-to-rio",
    "pospalatal": "pos-pa-la-tal",
    "posparto": "pos-par-to",
    "pospelo": "pos-pe-lo",
    "pospierna": "pos-pier-na",
    "posponer": "pos-po-ner",
    "posposición": "pos-po-si-ción",
    "pospositiva": "pos-po-si-ti-va",
    "pospositivo": "pos-po-si-ti-vo",
    "posprandial": "pos-pran-dial",
    "pospretérito": "pos-pre-té-ri-to",
    "posproducción": "pos-pro-duc-ción",
    "pospuesta": "pos-pues-ta",
    "pospuesto": "pos-pues-to",
    "posromanticismo": "pos-ro-man-ti-cis-mo",
    "posromántico": "pos-ro-mán-ti-co",
    "posta": "pos-ta",
    "postación": "pos-ta-ción",
    "postaje": "pos-ta-je",
    "postal": "pos-tal",
    "postar": "pos-tar",
    "postbélico": "post-bé-li-co",
    "postcombustión": "post-com-bus-tión",
    "postdata": "post-da-ta",
    "postdiluviana": "post-di-lu-via-na",
    "postdiluviano": "post-di-lu-via-no",
    "postdorsal": "post-dor-sal",
    "poste": "pos-te",
    "postear": "pos-te-ar",
    "postelero": "pos-te-le-ro",
    "postema": "pos-te-ma",
    "postemación": "pos-te-ma-ción",
    "postemero": "pos-te-me-ro",
    "postemilla": "pos-te-mi-lla",
    "póster": "pós-ter",
    "pósteramente": "pós-te-ra-men-te",
    "postergación": "pos-ter-ga-ción",
    "postergar": "pos-ter-gar",
    "posteridad": "pos-te-ri-dad",
    "posterío": "pos-te-rí-o",
    "posterior": "pos-te-rior",
    "posterioridad": "pos-te-rio-ri-dad",
    "posteriormente": "pos-te-rior-men-te",
    "posteta": "pos-te-ta",
    "postfijo": "post-fi-jo",
    "postgrado": "post-gra-do",
    "postgraduado": "post-gra-dua-do",
    "postigo": "pos-ti-go",
    "postila": "pos-ti-la",
    "postilación": "pos-ti-la-ción",
    "postilador": "pos-ti-la-dor",
    "postiladora": "pos-ti-la-do-ra",
    "postilar": "pos-ti-lar",
    "postilla": "pos-ti-lla",
    "postillón": "pos-ti-llón",
    "postillosa": "pos-ti-llo-sa",
    "postilloso": "pos-ti-llo-so",
    "postimpresionismo": "pos-tim-pre-sio-nis-mo",
    "postín": "pos-tín",
    "postinear": "pos-ti-ne-ar",
    "postinera": "pos-ti-ne-ra",
    "postinero": "pos-ti-ne-ro",
    "postinudo": "pos-ti-nu-do",
    "postismo": "pos-tis-mo",
    "postiza": "pos-ti-za",
    "postizo": "pos-ti-zo",
    "postliminio": "pos-tli-mi-nio",
    "postmeridiana": "post-me-ri-dia-na",
    "postmeridiano": "post-me-ri-dia-no",
    "postmoderna": "post-mo-der-na",
    "postmodernismo": "post-mo-der-nis-mo",
    "postmoderno": "post-mo-der-no",
    "postnominal": "post-no-mi-nal",
    "postón": "pos-tón",
    "postónica": "pos-tó-ni-ca",
    "postónico": "pos-tó-ni-co",
    "postoperatorio": "pos-to-pe-ra-to-rio",
    "postor": "pos-tor",
    "postora": "pos-to-ra",
    "postpalatal": "post-pa-la-tal",
    "postración": "pos-tra-ción",
    "postrador": "pos-tra-dor",
    "postradora": "pos-tra-do-ra",
    "postrar": "pos-trar",
    "postre": "pos-tre",
    "postrema": "pos-tre-ma",
    "postremas": "pos-tre-mas",
    "postremera": "pos-tre-me-ra",
    "postremero": "pos-tre-me-ro",
    "postremo": "pos-tre-mo",
    "postrer": "pos-trer",
    "postrera": "pos-tre-ra",
    "postreramente": "pos-tre-ra-men-te",
    "postrero": "pos-tre-ro",
    "postrimer": "pos-tri-mer",
    "postrimera": "pos-tri-me-ra",
    "postrimeramente": "pos-tri-me-ra-men-te",
    "postrimería": "pos-tri-me-rí-a",
    "postrimero": "pos-tri-me-ro",
    "postromántico": "pos-tro-mán-ti-co",
    "póstula": "pós-tu-la",
    "postulación": "pos-tu-la-ción",
    "postulado": "pos-tu-la-do",
    "postulador": "pos-tu-la-dor",
    "postulanta": "pos-tu-lan-ta",
    "postulante": "pos-tu-lan-te",
    "postular": "pos-tu-lar",
    "póstuma": "pós-tu-ma",
    "póstumo": "pós-tu-mo",
    "postura": "pos-tu-ra",
    "postural": "pos-tu-ral",
    "postventa": "post-ven-ta",
    "postverbal": "post-ver-bal",
    "posventa": "pos-ven-ta",
    "posverbal": "pos-ver-bal",
    "pota": "po-ta",
    "potabilidad": "po-ta-bi-li-dad",
    "potabilizador": "po-ta-bi-li-za-dor",
    "potabilizadora": "po-ta-bi-li-za-do-ra",
    "potabilizar": "po-ta-bi-li-zar",
    "potable": "po-ta-ble",
    "potación": "po-ta-ción",
    "potada": "po-ta-da",
    "potador": "po-ta-dor",
    "potadora": "po-ta-do-ra",
    "potaje": "po-ta-je",
    "potajera": "po-ta-je-ra",
    "potajería": "po-ta-je-rí-a",
    "potajier": "po-ta-jier",
    "potala": "po-ta-la",
    "potámide": "po-tá-mi-de",
    "potar": "po-tar",
    "potasa": "po-ta-sa",
    "potásica": "po-tá-si-ca",
    "potásico": "po-tá-si-co",
    "potasio": "po-ta-sio",
    "pote": "po-te",
    "potear": "po-te-ar",
    "potencia": "po-ten-cia",
    "potenciación": "po-ten-cia-ción",
    "potenciador": "po-ten-cia-dor",
    "potencial": "po-ten-cial",
    "potencialidad": "po-ten-cia-li-dad",
    "potencialmente": "po-ten-cial-men-te",
    "potenciar": "po-ten-ciar",
    "potenciómetro": "po-ten-ció-me-tro",
    "potentada": "po-ten-ta-da",
    "potentado": "po-ten-ta-do",
    "potente": "po-ten-te",
    "potentemente": "po-ten-te-men-te",
    "potenza": "po-ten-za",
    "potenzada": "po-ten-za-da",
    "potenzado": "po-ten-za-do",
    "potera": "po-te-ra",
    "poterna": "po-ter-na",
    "potero": "po-te-ro",
    "potestad": "po-tes-tad",
    "potestativa": "po-tes-ta-ti-va",
    "potestativo": "po-tes-ta-ti-vo",
    "potetería": "po-te-te-rí-a",
    "potingue": "po-tin-gue",
    "potista": "po-tis-ta",
    "potito": "po-ti-to",
    "poto": "po-to",
    "potoca": "po-to-ca",
    "potoco": "po-to-co",
    "potorillo": "po-to-ri-llo",
    "potorro": "po-to-rro",
    "potos": "po-tos",
    "potosí": "po-to-sí",
    "potosina": "po-to-si-na",
    "potosino": "po-to-si-no",
    "potra": "po-tra",
    "potrada": "po-tra-da",
    "potranca": "po-tran-ca",
    "potranco": "po-tran-co",
    "potrear": "po-tre-ar",
    "potrera": "po-tre-ra",
    "potreraje": "po-tre-ra-je",
    "potrero": "po-tre-ro",
    "potril": "po-tril",
    "potrilla": "po-tri-lla",
    "potrillo": "po-tri-llo",
    "potro": "po-tro",
    "potrosa": "po-tro-sa",
    "potroso": "po-tro-so",
    "povisa": "po-vi-sa",
    "poya": "po-ya",
    "poyal": "po-yal",
    "poyar": "po-yar",
    "poyata": "po-ya-ta",
    "poyato": "po-ya-to",
    "poyete": "po-ye-te",
    "poyo": "po-yo",
    "poza": "po-za",
    "pozal": "po-zal",
    "pozalero": "po-za-le-ro",
    "pozanco": "po-zan-co",
    "pozo": "po-zo",
    "pozol": "po-zol",
    "pozole": "po-zo-le",
    "pozuela": "po-zue-la",
    "pozuelo": "po-zue-lo",
    "prácrito": "prá-cri-to",
    "práctica": "prác-ti-ca",
    "practicable": "prac-ti-ca-ble",
    "practicador": "prac-ti-ca-dor",
    "practicadora": "prac-ti-ca-do-ra",
    "practicaje": "prac-ti-ca-je",
    "prácticamente": "prác-ti-ca-men-te",
    "practicanta": "prac-ti-can-ta",
    "practicante": "prac-ti-can-te",
    "practicar": "prac-ti-car",
    "practicidad": "prac-ti-ci-dad",
    "práctico": "prác-ti-co",
    "practicón": "prac-ti-cón",
    "practicona": "prac-ti-co-na",
    "pradal": "pra-dal",
    "pradejón": "pra-de-jón",
    "pradeña": "pra-de-ña",
    "pradeño": "pra-de-ño",
    "pradera": "pra-de-ra",
    "pradería": "pra-de-rí-a",
    "praderosa": "pra-de-ro-sa",
    "praderoso": "pra-de-ro-so",
    "pradial": "pra-dial",
    "prado": "pra-do",
    "pragmática": "prag-má-ti-ca",
    "pragmático": "prag-má-ti-co",
    "pragmatismo": "prag-ma-tis-mo",
    "pragmatista": "prag-ma-tis-ta",
    "praguense": "pra-guen-se",
    "praliné": "pra-li-né",
    "prangán": "pran-gán",
    "prángana": "prán-ga-na",
    "prao": "pra-o",
    "praseodimio": "pra-se-o-di-mio",
    "prasio": "pra-sio",
    "prasma": "pras-ma",
    "pratense": "pra-ten-se",
    "praticultura": "pra-ti-cul-tu-ra",
    "prava": "pra-va",
    "pravedad": "pra-ve-dad",
    "praviana": "pra-via-na",
    "pravo": "pra-vo",
    "praxis": "pra-xis",
    "praza": "pra-za",
    "prea": "pre-a",
    "preacuerdo": "pre-a-cuer-do",
    "preadamita": "pre-a-da-mi-ta",
    "preadamítica": "pre-a-da-mí-ti-ca",
    "preadamítico": "pre-a-da-mí-ti-co",
    "preámbulo": "pre-ám-bu-lo",
    "prear": "pre-ar",
    "preaviso": "pre-a-vi-so",
    "prebélico": "pre-bé-li-co",
    "prebenda": "pre-ben-da",
    "prebendado": "pre-ben-da-do",
    "prebendar": "pre-ben-dar",
    "prebiótico": "pre-bió-ti-co",
    "prebostal": "pre-bos-tal",
    "prebostazgo": "pre-bos-taz-go",
    "preboste": "pre-bos-te",
    "precalentamiento": "pre-ca-len-ta-mien-to",
    "precámbrico": "pre-cám-bri-co",
    "precampaña": "pre-cam-pa-ña",
    "precaria": "pre-ca-ria",
    "precariamente": "pre-ca-ria-men-te",
    "precariedad": "pre-ca-rie-dad",
    "precario": "pre-ca-rio",
    "precarista": "pre-ca-ris-ta",
    "precarización": "pre-ca-ri-za-ción",
    "precarizar": "pre-ca-ri-zar",
    "precaución": "pre-cau-ción",
    "precaucionar": "pre-cau-cio-nar",
    "precaucionarse": "pre-cau-cio-nar-se",
    "precautelar": "pre-cau-te-lar",
    "precautoria": "pre-cau-to-ria",
    "precautorio": "pre-cau-to-rio",
    "precaver": "pre-ca-ver",
    "precavida": "pre-ca-vi-da",
    "precavidamente": "pre-ca-vi-da-men-te",
    "precavido": "pre-ca-vi-do",
    "precedencia": "pre-ce-den-cia",
    "precedente": "pre-ce-den-te",
    "preceder": "pre-ce-der",
    "precelente": "pre-ce-len-te",
    "precepción": "pre-cep-ción",
    "preceptista": "pre-cep-tis-ta",
    "preceptiva": "pre-cep-ti-va",
    "preceptivamente": "pre-cep-ti-va-men-te",
    "preceptivo": "pre-cep-ti-vo",
    "precepto": "pre-cep-to",
    "preceptor": "pre-cep-tor",
    "preceptora": "pre-cep-to-ra",
    "preceptoril": "pre-cep-to-ril",
    "preceptuar": "pre-cep-tuar",
    "preces": "pre-ces",
    "precesión": "pre-ce-sión",
    "preciada": "pre-cia-da",
    "preciado": "pre-cia-do",
    "preciador": "pre-cia-dor",
    "preciadora": "pre-cia-do-ra",
    "preciar": "pre-ciar",
    "precinta": "pre-cin-ta",
    "precintado": "pre-cin-ta-do",
    "precintar": "pre-cin-tar",
    "precinto": "pre-cin-to",
    "precio": "pre-cio",
    "preciosa": "pre-cio-sa",
    "preciosamente": "pre-cio-sa-men-te",
    "preciosidad": "pre-cio-si-dad",
    "preciosismo": "pre-cio-sis-mo",
    "preciosista": "pre-cio-sis-ta",
    "precioso": "pre-cio-so",
    "preciosura": "pre-cio-su-ra",
    "precipicio": "pre-ci-pi-cio",
    "precipitación": "pre-ci-pi-ta-ción",
    "precipitada": "pre-ci-pi-ta-da",
    "precipitadamente": "pre-ci-pi-ta-da-men-te",
    "precipitadero": "pre-ci-pi-ta-de-ro",
    "precipitado": "pre-ci-pi-ta-do",
    "precipitante": "pre-ci-pi-tan-te",
    "precipitar": "pre-ci-pi-tar",
    "precípite": "pre-cí-pi-te",
    "precipitosa": "pre-ci-pi-to-sa",
    "precipitosamente": "pre-ci-pi-to-sa-men-te",
    "precipitoso": "pre-ci-pi-to-so",
    "precipua": "pre-ci-pua",
    "precipuamente": "pre-ci-pua-men-te",
    "precipuo": "pre-ci-puo",
    "precisa": "pre-ci-sa",
    "precisado": "pre-ci-sa-do",
    "precisamente": "pre-ci-sa-men-te",
    "precisar": "pre-ci-sar",
    "precisión": "pre-ci-sión",
    "preciso": "pre-ci-so",
    "precita": "pre-ci-ta",
    "precitada": "pre-ci-ta-da",
    "precitado": "pre-ci-ta-do",
    "precito": "pre-ci-to",
    "preclara": "pre-cla-ra",
    "preclaramente": "pre-cla-ra-men-te",
    "preclaro": "pre-cla-ro",
    "preclásica": "pre-clá-si-ca",
    "preclásico": "pre-clá-si-co",
    "preclusión": "pre-clu-sión",
    "preclusivo": "pre-clu-si-vo",
    "precocidad": "pre-co-ci-dad",
    "precocinada": "pre-co-ci-na-da",
    "precocinado": "pre-co-ci-na-do",
    "precognición": "pre-cog-ni-ción",
    "precolombina": "pre-co-lom-bi-na",
    "precolombino": "pre-co-lom-bi-no",
    "preconcebido": "pre-con-ce-bi-do",
    "preconcebir": "pre-con-ce-bir",
    "preconización": "pre-co-ni-za-ción",
    "preconizador": "pre-co-ni-za-dor",
    "preconizadora": "pre-co-ni-za-do-ra",
    "preconizar": "pre-co-ni-zar",
    "preconocer": "pre-co-no-cer",
    "preconstitucional": "pre-cons-ti-tu-cio-nal",
    "precontrato": "pre-con-tra-to",
    "precordial": "pre-cor-dial",
    "precortesiano": "pre-cor-te-sia-no",
    "precotesiano": "pre-co-te-sia-no",
    "precoz": "pre-coz",
    "precursor": "pre-cur-sor",
    "precursora": "pre-cur-so-ra",
    "preda": "pre-da",
    "predador": "pre-da-dor",
    "predadora": "pre-da-do-ra",
    "predar": "pre-dar",
    "predatorio": "pre-da-to-rio",
    "predecesor": "pre-de-ce-sor",
    "predecesora": "pre-de-ce-so-ra",
    "predecible": "pre-de-ci-ble",
    "predecir": "pre-de-cir",
    "predefinición": "pre-de-fi-ni-ción",
    "predefinir": "pre-de-fi-nir",
    "predela": "pre-de-la",
    "predestinación": "pre-des-ti-na-ción",
    "predestinada": "pre-des-ti-na-da",
    "predestinado": "pre-des-ti-na-do",
    "predestinar": "pre-des-ti-nar",
    "predeterminación": "pre-de-ter-mi-na-ción",
    "predeterminar": "pre-de-ter-mi-nar",
    "predial": "pre-dial",
    "prédica": "pré-di-ca",
    "predicable": "pre-di-ca-ble",
    "predicación": "pre-di-ca-ción",
    "predicadera": "pre-di-ca-de-ra",
    "predicado": "pre-di-ca-do",
    "predicador": "pre-di-ca-dor",
    "predicadora": "pre-di-ca-do-ra",
    "predicamental": "pre-di-ca-men-tal",
    "predicamento": "pre-di-ca-men-to",
    "predicante": "pre-di-can-te",
    "predicar": "pre-di-car",
    "predicativa": "pre-di-ca-ti-va",
    "predicativo": "pre-di-ca-ti-vo",
    "predicatorio": "pre-di-ca-to-rio",
    "predicción": "pre-dic-ción",
    "predicha": "pre-di-cha",
    "predicho": "pre-di-cho",
    "predictibilidad": "pre-dic-ti-bi-li-dad",
    "predictible": "pre-dic-ti-ble",
    "predictivo": "pre-dic-ti-vo",
    "predictor": "pre-dic-tor",
    "predictora": "pre-dic-to-ra",
    "predilección": "pre-di-lec-ción",
    "predilecta": "pre-di-lec-ta",
    "predilecto": "pre-di-lec-to",
    "predio": "pre-dio",
    "predisponer": "pre-dis-po-ner",
    "predisposición": "pre-dis-po-si-ción",
    "predispuesto": "pre-dis-pues-to",
    "predominación": "pre-do-mi-na-ción",
    "predominancia": "pre-do-mi-nan-cia",
    "predominante": "pre-do-mi-nan-te",
    "predominantemente": "pre-do-mi-nan-te-men-te",
    "predominar": "pre-do-mi-nar",
    "predominio": "pre-do-mi-nio",
    "predorsal": "pre-dor-sal",
    "predorso": "pre-dor-so",
    "preeclampsia": "pre-e-clamp-sia",
    "preelectoral": "pre-e-lec-to-ral",
    "preelegir": "pre-e-le-gir",
    "preeminencia": "pre-e-mi-nen-cia",
    "preeminente": "pre-e-mi-nen-te",
    "preescolar": "pre-es-co-lar",
    "preestablecido": "pre-es-ta-ble-ci-do",
    "preestreno": "pre-es-tre-no",
    "preexcelsa": "pre-ex-cel-sa",
    "preexcelso": "pre-ex-cel-so",
    "preexistencia": "pre-e-xis-ten-cia",
    "preexistente": "pre-e-xis-ten-te",
    "preexistir": "pre-e-xis-tir",
    "prefabricación": "pre-fa-bri-ca-ción",
    "prefabricado": "pre-fa-bri-ca-do",
    "prefabricar": "pre-fa-bri-car",
    "prefacio": "pre-fa-cio",
    "prefación": "pre-fa-ción",
    "prefecto": "pre-fec-to",
    "prefectura": "pre-fec-tu-ra",
    "preferencia": "pre-fe-ren-cia",
    "preferencial": "pre-fe-ren-cial",
    "preferente": "pre-fe-ren-te",
    "preferentemente": "pre-fe-ren-te-men-te",
    "preferible": "pre-fe-ri-ble",
    "preferiblemente": "pre-fe-ri-ble-men-te",
    "preferir": "pre-fe-rir",
    "prefiguración": "pre-fi-gu-ra-ción",
    "prefigurar": "pre-fi-gu-rar",
    "prefija": "pre-fi-ja",
    "prefijación": "pre-fi-ja-ción",
    "prefijal": "pre-fi-jal",
    "prefijar": "pre-fi-jar",
    "prefijo": "pre-fi-jo",
    "prefilatelia": "pre-fi-la-te-lia",
    "prefinición": "pre-fi-ni-ción",
    "prefinir": "pre-fi-nir",
    "prefloración": "pre-flo-ra-ción",
    "prefoliación": "pre-fo-lia-ción",
    "preformación": "pre-for-ma-ción",
    "preformado": "pre-for-ma-do",
    "preformismo": "pre-for-mis-mo",
    "preformista": "pre-for-mis-ta",
    "prefulgente": "pre-ful-gen-te",
    "pregancia": "pre-gan-cia",
    "pregar": "pre-gar",
    "preglaciar": "pre-gla-ciar",
    "pregnancia": "preg-nan-cia",
    "pregnante": "preg-nan-te",
    "pregón": "pre-gón",
    "pregonar": "pre-go-nar",
    "pregonera": "pre-go-ne-ra",
    "pregonería": "pre-go-ne-rí-a",
    "pregonero": "pre-go-ne-ro",
    "preguerra": "pre-gue-rra",
    "pregunta": "pre-gun-ta",
    "preguntadera": "pre-gun-ta-de-ra",
    "preguntador": "pre-gun-ta-dor",
    "preguntadora": "pre-gun-ta-do-ra",
    "preguntar": "pre-gun-tar",
    "pregunteo": "pre-gun-te-o",
    "preguntón": "pre-gun-tón",
    "preguntona": "pre-gun-to-na",
    "pregustación": "pre-gus-ta-ción",
    "pregustar": "pre-gus-tar",
    "prehelénica": "pre-he-lé-ni-ca",
    "prehelénico": "pre-he-lé-ni-co",
    "prehispánico": "prehis-pá-ni-co",
    "prehistoria": "prehis-to-ria",
    "prehistórica": "prehis-tó-ri-ca",
    "prehistórico": "prehis-tó-ri-co",
    "prehomínido": "pre-ho-mí-ni-do",
    "preincaico": "prein-cai-co",
    "preindustrial": "prein-dus-trial",
    "preinscribir": "preins-cri-bir",
    "preinscripción": "preins-crip-ción",
    "preinserta": "prein-ser-ta",
    "preinserto": "prein-ser-to",
    "preinstalación": "preins-ta-la-ción",
    "preislámico": "preis-lá-mi-co",
    "prejubilación": "pre-ju-bi-la-ción",
    "prejubilar": "pre-ju-bi-lar",
    "prejudicial": "pre-ju-di-cial",
    "prejudicio": "pre-ju-di-cio",
    "prejuiciado": "pre-jui-cia-do",
    "prejuicio": "pre-jui-cio",
    "prejuzgar": "pre-juz-gar",
    "prelacía": "pre-la-cí-a",
    "prelación": "pre-la-ción",
    "prelada": "pre-la-da",
    "prelado": "pre-la-do",
    "prelaticia": "pre-la-ti-cia",
    "prelaticio": "pre-la-ti-cio",
    "prelatura": "pre-la-tu-ra",
    "preliminar": "pre-li-mi-nar",
    "preliminarmente": "pre-li-mi-nar-men-te",
    "preliterario": "pre-li-te-ra-rio",
    "prelucir": "pre-lu-cir",
    "preludiar": "pre-lu-diar",
    "preludio": "pre-lu-dio",
    "prelusión": "pre-lu-sión",
    "premamá": "pre-ma-má",
    "premática": "pre-má-ti-ca",
    "prematrimonial": "pre-ma-tri-mo-nial",
    "prematura": "pre-ma-tu-ra",
    "prematuramente": "pre-ma-tu-ra-men-te",
    "prematuridad": "pre-ma-tu-ri-dad",
    "prematuro": "pre-ma-tu-ro",
    "premeditación": "pre-me-di-ta-ción",
    "premeditadamente": "pre-me-di-ta-da-men-te",
    "premeditado": "pre-me-di-ta-do",
    "premeditar": "pre-me-di-tar",
    "premenstrual": "pre-mens-trual",
    "premia": "pre-mia",
    "premiación": "pre-mia-ción",
    "premiada": "pre-mia-da",
    "premiado": "pre-mia-do",
    "premiador": "pre-mia-dor",
    "premiadora": "pre-mia-do-ra",
    "premiar": "pre-miar",
    "premidera": "pre-mi-de-ra",
    "premio": "pre-mio",
    "premiosa": "pre-mio-sa",
    "premiosamente": "pre-mio-sa-men-te",
    "premiosidad": "pre-mio-si-dad",
    "premioso": "pre-mio-so",
    "premir": "pre-mir",
    "premisa": "pre-mi-sa",
    "premiso": "pre-mi-so",
    "premitir": "pre-mi-tir",
    "premoción": "pre-mo-ción",
    "premolar": "pre-mo-lar",
    "premonición": "pre-mo-ni-ción",
    "premonitor": "pre-mo-ni-tor",
    "premonitoria": "pre-mo-ni-to-ria",
    "premonitorio": "pre-mo-ni-to-rio",
    "premonstratense": "pre-mons-tra-ten-se",
    "premoriencia": "pre-mo-rien-cia",
    "premoriente": "pre-mo-rien-te",
    "premorir": "pre-mo-rir",
    "premostrar": "pre-mos-trar",
    "premostratense": "pre-mos-tra-ten-se",
    "premuerta": "pre-muer-ta",
    "premuerto": "pre-muer-to",
    "premunir": "pre-mu-nir",
    "premura": "pre-mu-ra",
    "preñada": "pre-ña-da",
    "preñado": "pre-ña-do",
    "preñar": "pre-ñar",
    "prenatal": "pre-na-tal",
    "prenda": "pren-da",
    "prendador": "pren-da-dor",
    "prendadora": "pren-da-do-ra",
    "prendamiento": "pren-da-mien-to",
    "prendar": "pren-dar",
    "prendaria": "pren-da-ria",
    "prendario": "pren-da-rio",
    "prendedero": "pren-de-de-ro",
    "prendedor": "pren-de-dor",
    "prendedura": "pren-de-du-ra",
    "prender": "pren-der",
    "prendera": "pren-de-ra",
    "prendería": "pren-de-rí-a",
    "prendero": "pren-de-ro",
    "prendida": "pren-di-da",
    "prendido": "pren-di-do",
    "prendimiento": "pren-di-mien-to",
    "prendón": "pren-dón",
    "preñez": "pre-ñez",
    "prenoción": "pre-no-ción",
    "prenombre": "pre-nom-bre",
    "prenominal": "pre-no-mi-nal",
    "prenotar": "pre-no-tar",
    "prensa": "pren-sa",
    "prensado": "pren-sa-do",
    "prensador": "pren-sa-dor",
    "prensadora": "pren-sa-do-ra",
    "prensadura": "pren-sa-du-ra",
    "prensaestopas": "pren-sa-es-to-pas",
    "prensar": "pren-sar",
    "prensero": "pren-se-ro",
    "prensil": "pren-sil",
    "prensión": "pren-sión",
    "prensista": "pren-sis-ta",
    "prensor": "pren-sor",
    "prensora": "pren-so-ra",
    "prenunciar": "pre-nun-ciar",
    "prenuncio": "pre-nun-cio",
    "prenupcial": "pre-nup-cial",
    "preocupación": "pre-o-cu-pa-ción",
    "preocupadamente": "pre-o-cu-pa-da-men-te",
    "preocupado": "pre-o-cu-pa-do",
    "preocupante": "pre-o-cu-pan-te",
    "preocupar": "pre-o-cu-par",
    "preolímpica": "pre-o-lím-pi-ca",
    "preolímpico": "pre-o-lím-pi-co",
    "preoperatorio": "pre-o-pe-ra-to-rio",
    "preopinante": "pre-o-pi-nan-te",
    "preordinación": "pre-or-di-na-ción",
    "preordinadamente": "pre-or-di-na-da-men-te",
    "preordinar": "pre-or-di-nar",
    "prepalatal": "pre-pa-la-tal",
    "preparación": "pre-pa-ra-ción",
    "preparada": "pre-pa-ra-da",
    "preparado": "pre-pa-ra-do",
    "preparador": "pre-pa-ra-dor",
    "preparadora": "pre-pa-ra-do-ra",
    "preparamento": "pre-pa-ra-men-to",
    "preparamiento": "pre-pa-ra-mien-to",
    "preparar": "pre-pa-rar",
    "preparativa": "pre-pa-ra-ti-va",
    "preparativo": "pre-pa-ra-ti-vo",
    "preparatoria": "pre-pa-ra-to-ria",
    "preparatoriamente": "pre-pa-ra-to-ria-men-te",
    "preparatoriana": "pre-pa-ra-to-ria-na",
    "preparatoriano": "pre-pa-ra-to-ria-no",
    "preparatorio": "pre-pa-ra-to-rio",
    "prepasada": "pre-pa-sa-da",
    "prepasado": "pre-pa-sa-do",
    "prepear": "pre-pe-ar",
    "preplatónico": "pre-pla-tó-ni-co",
    "preponderancia": "pre-pon-de-ran-cia",
    "preponderante": "pre-pon-de-ran-te",
    "preponderar": "pre-pon-de-rar",
    "preponer": "pre-po-ner",
    "preposición": "pre-po-si-ción",
    "preposicional": "pre-po-si-cio-nal",
    "prepositiva": "pre-po-si-ti-va",
    "prepositivo": "pre-po-si-ti-vo",
    "prepósito": "pre-pó-si-to",
    "prepositura": "pre-po-si-tu-ra",
    "prepóstera": "pre-pós-te-ra",
    "preposteración": "pre-pos-te-ra-ción",
    "prepósteramente": "pre-pós-te-ra-men-te",
    "preposterar": "pre-pos-te-rar",
    "prepóstero": "pre-pós-te-ro",
    "prepotencia": "pre-po-ten-cia",
    "prepotente": "pre-po-ten-te",
    "prepucial": "pre-pu-cial",
    "prepucio": "pre-pu-cio",
    "prepuesta": "pre-pues-ta",
    "prepuesto": "pre-pues-to",
    "prerrafaelismo": "pre-rra-fa-e-lis-mo",
    "prerrafaelista": "pre-rra-fa-e-lis-ta",
    "prerrafaelita": "pre-rra-fa-e-li-ta",
    "prerrequisito": "pre-rre-qui-si-to",
    "prerrogativa": "pre-rro-ga-ti-va",
    "prerromance": "pre-rro-man-ce",
    "prerrománico": "pre-rro-má-ni-co",
    "prerromano": "pre-rro-ma-no",
    "prerromántica": "pre-rro-mán-ti-ca",
    "prerromanticismo": "pre-rro-man-ti-cis-mo",
    "prerromántico": "pre-rro-mán-ti-co",
    "presa": "pre-sa",
    "presada": "pre-sa-da",
    "presado": "pre-sa-do",
    "présaga": "pré-sa-ga",
    "presagiar": "pre-sa-giar",
    "presagio": "pre-sa-gio",
    "presagiosa": "pre-sa-gio-sa",
    "presagioso": "pre-sa-gio-so",
    "présago": "pré-sa-go",
    "presar": "pre-sar",
    "presbicia": "pres-bi-cia",
    "présbita": "prés-bi-ta",
    "présbite": "prés-bi-te",
    "presbiterado": "pres-bi-te-ra-do",
    "presbiteral": "pres-bi-te-ral",
    "presbiterato": "pres-bi-te-ra-to",
    "presbiteriana": "pres-bi-te-ria-na",
    "presbiterianismo": "pres-bi-te-ria-nis-mo",
    "presbiteriano": "pres-bi-te-ria-no",
    "presbiterio": "pres-bi-te-rio",
    "presbítero": "pres-bí-te-ro",
    "presciencia": "pres-cien-cia",
    "prescindencia": "pres-cin-den-cia",
    "prescindible": "pres-cin-di-ble",
    "prescindir": "pres-cin-dir",
    "prescita": "pres-ci-ta",
    "prescito": "pres-ci-to",
    "prescribir": "pres-cri-bir",
    "prescripción": "pres-crip-ción",
    "prescripta": "pres-crip-ta",
    "prescriptible": "pres-crip-ti-ble",
    "prescriptivo": "pres-crip-ti-vo",
    "prescripto": "pres-crip-to",
    "prescrita": "pres-cri-ta",
    "prescrito": "pres-cri-to",
    "presea": "pre-se-a",
    "preselección": "pre-se-lec-ción",
    "preseleccionada": "pre-se-lec-cio-na-da",
    "preseleccionado": "pre-se-lec-cio-na-do",
    "preseleccionar": "pre-se-lec-cio-nar",
    "presencia": "pre-sen-cia",
    "presencial": "pre-sen-cial",
    "presencialmente": "pre-sen-cial-men-te",
    "presenciar": "pre-sen-ciar",
    "presenil": "pre-se-nil",
    "presentable": "pre-sen-ta-ble",
    "presentación": "pre-sen-ta-ción",
    "presentada": "pre-sen-ta-da",
    "presentado": "pre-sen-ta-do",
    "presentador": "pre-sen-ta-dor",
    "presentadora": "pre-sen-ta-do-ra",
    "presentalla": "pre-sen-ta-lla",
    "presentánea": "pre-sen-tá-ne-a",
    "presentáneamente": "pre-sen-tá-ne-a-men-te",
    "presentáneo": "pre-sen-tá-ne-o",
    "presentar": "pre-sen-tar",
    "presente": "pre-sen-te",
    "presentemente": "pre-sen-te-men-te",
    "presentero": "pre-sen-te-ro",
    "presentimiento": "pre-sen-ti-mien-to",
    "presentir": "pre-sen-tir",
    "presepio": "pre-se-pio",
    "presera": "pre-se-ra",
    "presero": "pre-se-ro",
    "preservación": "pre-ser-va-ción",
    "preservador": "pre-ser-va-dor",
    "preservadora": "pre-ser-va-do-ra",
    "preservar": "pre-ser-var",
    "preservativa": "pre-ser-va-ti-va",
    "preservativamente": "pre-ser-va-ti-va-men-te",
    "preservativo": "pre-ser-va-ti-vo",
    "presidario": "pre-si-da-rio",
    "presidencia": "pre-si-den-cia",
    "presidenciable": "pre-si-den-cia-ble",
    "presidencial": "pre-si-den-cial",
    "presidencialismo": "pre-si-den-cia-lis-mo",
    "presidencialista": "pre-si-den-cia-lis-ta",
    "presidenta": "pre-si-den-ta",
    "presidente": "pre-si-den-te",
    "presidiable": "pre-si-dia-ble",
    "presidiar": "pre-si-diar",
    "presidiaria": "pre-si-dia-ria",
    "presidiario": "pre-si-dia-rio",
    "presidio": "pre-si-dio",
    "presidir": "pre-si-dir",
    "presídium": "pre-sí-dium",
    "presierra": "pre-sie-rra",
    "presilla": "pre-si-lla",
    "presilladora": "pre-si-lla-do-ra",
    "presintonía": "pre-sin-to-ní-a",
    "presión": "pre-sión",
    "presionar": "pre-sio-nar",
    "preso": "pre-so",
    "presocrático": "pre-so-crá-ti-co",
    "presostato": "pre-sos-ta-to",
    "presoterapia": "pre-so-te-ra-pia",
    "pressing": "pres-sing",
    "presta": "pres-ta",
    "prestación": "pres-ta-ción",
    "prestadiza": "pres-ta-di-za",
    "prestadizo": "pres-ta-di-zo",
    "prestado": "pres-ta-do",
    "prestador": "pres-ta-dor",
    "prestadora": "pres-ta-do-ra",
    "prestamente": "pres-ta-men-te",
    "prestamera": "pres-ta-me-ra",
    "prestamero": "pres-ta-me-ro",
    "prestamista": "pres-ta-mis-ta",
    "préstamo": "prés-ta-mo",
    "prestancia": "pres-tan-cia",
    "prestante": "pres-tan-te",
    "prestar": "pres-tar",
    "prestataria": "pres-ta-ta-ria",
    "prestatario": "pres-ta-ta-rio",
    "preste": "pres-te",
    "presteza": "pres-te-za",
    "prestidigitación": "pres-ti-di-gi-ta-ción",
    "prestidigitador": "pres-ti-di-gi-ta-dor",
    "prestidigitadora": "pres-ti-di-gi-ta-do-ra",
    "préstido": "prés-ti-do",
    "prestigiador": "pres-ti-gia-dor",
    "prestigiadora": "pres-ti-gia-do-ra",
    "prestigiar": "pres-ti-giar",
    "prestigio": "pres-ti-gio",
    "prestigiosa": "pres-ti-gio-sa",
    "prestigioso": "pres-ti-gio-so",
    "prestímano": "pres-tí-ma-no",
    "prestimonio": "pres-ti-mo-nio",
    "prestiño": "pres-ti-ño",
    "prestissimo": "pres-tis-si-mo",
    "presto": "pres-to",
    "presumible": "pre-su-mi-ble",
    "presumiblemente": "pre-su-mi-ble-men-te",
    "presumida": "pre-su-mi-da",
    "presumido": "pre-su-mi-do",
    "presumir": "pre-su-mir",
    "presunción": "pre-sun-ción",
    "presunciosa": "pre-sun-cio-sa",
    "presuncioso": "pre-sun-cio-so",
    "presunta": "pre-sun-ta",
    "presuntamente": "pre-sun-ta-men-te",
    "presuntiva": "pre-sun-ti-va",
    "presuntivamente": "pre-sun-ti-va-men-te",
    "presuntivo": "pre-sun-ti-vo",
    "presunto": "pre-sun-to",
    "presuntuosa": "pre-sun-tuo-sa",
    "presuntuosamente": "pre-sun-tuo-sa-men-te",
    "presuntuosidad": "pre-sun-tuo-si-dad",
    "presuntuoso": "pre-sun-tuo-so",
    "presuponer": "pre-su-po-ner",
    "presuposición": "pre-su-po-si-ción",
    "presupuestal": "pre-su-pues-tal",
    "presupuestar": "pre-su-pues-tar",
    "presupuestaria": "pre-su-pues-ta-ria",
    "presupuestario": "pre-su-pues-ta-rio",
    "presupuesto": "pre-su-pues-to",
    "presura": "pre-su-ra",
    "presurización": "pre-su-ri-za-ción",
    "presurizar": "pre-su-ri-zar",
    "presurosa": "pre-su-ro-sa",
    "presurosamente": "pre-su-ro-sa-men-te",
    "presuroso": "pre-su-ro-so",
    "pretal": "pre-tal",
    "pretemporada": "pre-tem-po-ra-da",
    "pretención": "pre-ten-ción",
    "pretenciosidad": "pre-ten-cio-si-dad",
    "pretencioso": "pre-ten-cio-so",
    "pretendencia": "pre-ten-den-cia",
    "pretender": "pre-ten-der",
    "pretendido": "pre-ten-di-do",
    "pretendienta": "pre-ten-dien-ta",
    "pretendiente": "pre-ten-dien-te",
    "pretensa": "pre-ten-sa",
    "pretensión": "pre-ten-sión",
    "pretensioso": "pre-ten-sio-so",
    "pretenso": "pre-ten-so",
    "pretensor": "pre-ten-sor",
    "pretensora": "pre-ten-so-ra",
    "preterición": "pre-te-ri-ción",
    "preterintencional": "pre-te-rin-ten-cio-nal",
    "preterintencionalidad": "pre-te-rin-ten-cio-na-li-dad",
    "preterir": "pre-te-rir",
    "pretérita": "pre-té-ri-ta",
    "pretérito": "pre-té-ri-to",
    "pretermisión": "pre-ter-mi-sión",
    "pretermitir": "pre-ter-mi-tir",
    "preternatural": "pre-ter-na-tu-ral",
    "preternaturalizar": "pre-ter-na-tu-ra-li-zar",
    "preternaturalmente": "pre-ter-na-tu-ral-men-te",
    "pretexta": "pre-tex-ta",
    "pretextar": "pre-tex-tar",
    "pretexto": "pre-tex-to",
    "pretil": "pre-til",
    "pretina": "pre-ti-na",
    "pretinazo": "pre-ti-na-zo",
    "pretinero": "pre-ti-ne-ro",
    "pretinilla": "pre-ti-ni-lla",
    "pretónica": "pre-tó-ni-ca",
    "pretónico": "pre-tó-ni-co",
    "pretor": "pre-tor",
    "pretoría": "pre-to-rí-a",
    "pretorial": "pre-to-rial",
    "pretoriana": "pre-to-ria-na",
    "pretorianismo": "pre-to-ria-nis-mo",
    "pretoriano": "pre-to-ria-no",
    "pretoriense": "pre-to-rien-se",
    "pretorio": "pre-to-rio",
    "pretura": "pre-tu-ra",
    "preuniversitario": "preu-ni-ver-si-ta-rio",
    "prevalecer": "pre-va-le-cer",
    "prevaleciente": "pre-va-le-cien-te",
    "prevalencia": "pre-va-len-cia",
    "prevalente": "pre-va-len-te",
    "prevaler": "pre-va-ler",
    "prevaricación": "pre-va-ri-ca-ción",
    "prevaricador": "pre-va-ri-ca-dor",
    "prevaricadora": "pre-va-ri-ca-do-ra",
    "prevaricar": "pre-va-ri-car",
    "prevaricato": "pre-va-ri-ca-to",
    "prevención": "pre-ven-ción",
    "prevenible": "pre-ve-ni-ble",
    "prevenida": "pre-ve-ni-da",
    "prevenidamente": "pre-ve-ni-da-men-te",
    "prevenido": "pre-ve-ni-do",
    "prevenir": "pre-ve-nir",
    "preventiva": "pre-ven-ti-va",
    "preventivamente": "pre-ven-ti-va-men-te",
    "preventivo": "pre-ven-ti-vo",
    "preventorio": "pre-ven-to-rio",
    "prever": "pre-ver",
    "preverbal": "pre-ver-bal",
    "previa": "pre-via",
    "previamente": "pre-via-men-te",
    "previdencia": "pre-vi-den-cia",
    "previdente": "pre-vi-den-te",
    "previlejar": "pre-vi-le-jar",
    "previo": "pre-vio",
    "previsibilidad": "pre-vi-si-bi-li-dad",
    "previsible": "pre-vi-si-ble",
    "previsión": "pre-vi-sión",
    "previsivo": "pre-vi-si-vo",
    "previsor": "pre-vi-sor",
    "previsora": "pre-vi-so-ra",
    "previsorio": "pre-vi-so-rio",
    "prevista": "pre-vis-ta",
    "previsto": "pre-vis-to",
    "priado": "pria-do",
    "priapismo": "pria-pis-mo",
    "príapo": "prí-a-po",
    "priego": "prie-go",
    "priesa": "prie-sa",
    "prieta": "prie-ta",
    "prietamente": "prie-ta-men-te",
    "prieto": "prie-to",
    "prima": "pri-ma",
    "primacía": "pri-ma-cí-a",
    "primacial": "pri-ma-cial",
    "primada": "pri-ma-da",
    "primado": "pri-ma-do",
    "primal": "pri-mal",
    "primala": "pri-ma-la",
    "primamente": "pri-ma-men-te",
    "primar": "pri-mar",
    "primaria": "pri-ma-ria",
    "primariamente": "pri-ma-ria-men-te",
    "primarias": "pri-ma-rias",
    "primario": "pri-ma-rio",
    "primate": "pri-ma-te",
    "primavera": "pri-ma-ve-ra",
    "primaveral": "pri-ma-ve-ral",
    "primaz": "pri-maz",
    "primazgo": "pri-maz-go",
    "primear": "pri-me-ar",
    "primearse": "pri-me-ar-se",
    "primer": "pri-mer",
    "primera": "pri-me-ra",
    "primeramente": "pri-me-ra-men-te",
    "primería": "pri-me-rí-a",
    "primeridad": "pri-me-ri-dad",
    "primeriza": "pri-me-ri-za",
    "primerizo": "pri-me-ri-zo",
    "primero": "pri-me-ro",
    "primeva": "pri-me-va",
    "primevo": "pri-me-vo",
    "primiceria": "pri-mi-ce-ria",
    "primicerio": "pri-mi-ce-rio",
    "primichón": "pri-mi-chón",
    "primicia": "pri-mi-cia",
    "primicial": "pri-mi-cial",
    "primiciero": "pri-mi-cie-ro",
    "primiclerio": "pri-mi-cle-rio",
    "primigenia": "pri-mi-ge-nia",
    "primigenio": "pri-mi-ge-nio",
    "primilla": "pri-mi-lla",
    "primípara": "pri-mí-pa-ra",
    "primitiva": "pri-mi-ti-va",
    "primitivamente": "pri-mi-ti-va-men-te",
    "primitivismo": "pri-mi-ti-vis-mo",
    "primitivo": "pri-mi-ti-vo",
    "primo": "pri-mo",
    "primogénita": "pri-mo-gé-ni-ta",
    "primogénito": "pri-mo-gé-ni-to",
    "primogenitor": "pri-mo-ge-ni-tor",
    "primogenitura": "pri-mo-ge-ni-tu-ra",
    "primor": "pri-mor",
    "primordial": "pri-mor-dial",
    "primordio": "pri-mor-dio",
    "primorear": "pri-mo-re-ar",
    "primorosa": "pri-mo-ro-sa",
    "primorosamente": "pri-mo-ro-sa-men-te",
    "primoroso": "pri-mo-ro-so",
    "prímula": "prí-mu-la",
    "primulácea": "pri-mu-lá-ce-a",
    "primuláceas": "pri-mu-lá-ce-as",
    "primuláceo": "pri-mu-lá-ce-o",
    "primus": "pri-mus",
    "prínceps": "prín-ceps",
    "princesa": "prin-ce-sa",
    "principada": "prin-ci-pa-da",
    "principado": "prin-ci-pa-do",
    "principal": "prin-ci-pal",
    "principalía": "prin-ci-pa-lí-a",
    "principalidad": "prin-ci-pa-li-dad",
    "principalmente": "prin-ci-pal-men-te",
    "principar": "prin-ci-par",
    "príncipe": "prín-ci-pe",
    "principela": "prin-ci-pe-la",
    "principesa": "prin-ci-pe-sa",
    "principesca": "prin-ci-pes-ca",
    "principesco": "prin-ci-pes-co",
    "principiador": "prin-ci-pia-dor",
    "principiadora": "prin-ci-pia-do-ra",
    "principianta": "prin-ci-pian-ta",
    "principiante": "prin-ci-pian-te",
    "principiar": "prin-ci-piar",
    "principio": "prin-ci-pio",
    "principote": "prin-ci-po-te",
    "pringa": "prin-ga",
    "pringada": "prin-ga-da",
    "pringado": "prin-ga-do",
    "pringamoza": "prin-ga-mo-za",
    "pringapié": "prin-ga-pié",
    "pringar": "prin-gar",
    "pringo": "prin-go",
    "pringón": "prin-gón",
    "pringona": "prin-go-na",
    "pringor": "prin-gor",
    "pringosa": "prin-go-sa",
    "pringoso": "prin-go-so",
    "pringote": "prin-go-te",
    "pringue": "prin-gue",
    "prionodonte": "prio-no-don-te",
    "priora": "prio-ra",
    "prioradgo": "prio-rad-go",
    "prioral": "prio-ral",
    "priorato": "prio-ra-to",
    "priorazgo": "prio-raz-go",
    "prioresa": "prio-re-sa",
    "prioridad": "prio-ri-dad",
    "prioritario": "prio-ri-ta-rio",
    "priorizar": "prio-ri-zar",
    "prioste": "prios-te",
    "prisa": "pri-sa",
    "priscal": "pris-cal",
    "prisciliana": "pris-ci-lia-na",
    "priscilianismo": "pris-ci-lia-nis-mo",
    "priscilianista": "pris-ci-lia-nis-ta",
    "prisciliano": "pris-ci-lia-no",
    "prisco": "pris-co",
    "prisión": "pri-sión",
    "prisionera": "pri-sio-ne-ra",
    "prisionero": "pri-sio-ne-ro",
    "prisma": "pris-ma",
    "prismática": "pris-má-ti-ca",
    "prismático": "pris-má-ti-co",
    "prismáticos": "pris-má-ti-cos",
    "priste": "pris-te",
    "prístina": "prís-ti-na",
    "prístino": "prís-ti-no",
    "prisuelo": "pri-sue-lo",
    "priva": "pri-va",
    "privacidad": "pri-va-ci-dad",
    "privación": "pri-va-ción",
    "privada": "pri-va-da",
    "privadamente": "pri-va-da-men-te",
    "privadero": "pri-va-de-ro",
    "privado": "pri-va-do",
    "privanza": "pri-van-za",
    "privar": "pri-var",
    "privatista": "pri-va-tis-ta",
    "privativa": "pri-va-ti-va",
    "privativamente": "pri-va-ti-va-men-te",
    "privatividad": "pri-va-ti-vi-dad",
    "privativo": "pri-va-ti-vo",
    "privatización": "pri-va-ti-za-ción",
    "privatizador": "pri-va-ti-za-dor",
    "privatizadora": "pri-va-ti-za-do-ra",
    "privatizar": "pri-va-ti-zar",
    "privilegiada": "pri-vi-le-gia-da",
    "privilegiadamente": "pri-vi-le-gia-da-men-te",
    "privilegiado": "pri-vi-le-gia-do",
    "privilegiar": "pri-vi-le-giar",
    "privilegiativa": "pri-vi-le-gia-ti-va",
    "privilegiativo": "pri-vi-le-gia-ti-vo",
    "privilegio": "pri-vi-le-gio",
    "proa": "pro-a",
    "proal": "pro-al",
    "proba": "pro-ba",
    "probabilidad": "pro-ba-bi-li-dad",
    "probabilismo": "pro-ba-bi-lis-mo",
    "probabilista": "pro-ba-bi-lis-ta",
    "probabilístico": "pro-ba-bi-lís-ti-co",
    "probable": "pro-ba-ble",
    "probablemente": "pro-ba-ble-men-te",
    "probación": "pro-ba-ción",
    "probada": "pro-ba-da",
    "probado": "pro-ba-do",
    "probador": "pro-ba-dor",
    "probadora": "pro-ba-do-ra",
    "probadura": "pro-ba-du-ra",
    "probana": "pro-ba-na",
    "probanza": "pro-ban-za",
    "probar": "pro-bar",
    "probática": "pro-bá-ti-ca",
    "probativo": "pro-ba-ti-vo",
    "probatoria": "pro-ba-to-ria",
    "probatorio": "pro-ba-to-rio",
    "probatura": "pro-ba-tu-ra",
    "probeta": "pro-be-ta",
    "probidad": "pro-bi-dad",
    "probiótico": "pro-bió-ti-co",
    "problema": "pro-ble-ma",
    "problemática": "pro-ble-má-ti-ca",
    "problemáticamente": "pro-ble-má-ti-ca-men-te",
    "problematicidad": "pro-ble-ma-ti-ci-dad",
    "problemático": "pro-ble-má-ti-co",
    "problematismo": "pro-ble-ma-tis-mo",
    "problematizar": "pro-ble-ma-ti-zar",
    "probo": "pro-bo",
    "probóscide": "pro-bós-ci-de",
    "proboscídeo": "pro-bos-cí-de-o",
    "proboscidio": "pro-bos-ci-dio",
    "procacidad": "pro-ca-ci-dad",
    "procaína": "pro-ca-í-na",
    "procapellán": "pro-ca-pe-llán",
    "procarionte": "pro-ca-rion-te",
    "procariota": "pro-ca-rio-ta",
    "procaz": "pro-caz",
    "procedencia": "pro-ce-den-cia",
    "procedente": "pro-ce-den-te",
    "proceder": "pro-ce-der",
    "procedido": "pro-ce-di-do",
    "procedimental": "pro-ce-di-men-tal",
    "procedimiento": "pro-ce-di-mien-to",
    "procela": "pro-ce-la",
    "procelariforme": "pro-ce-la-ri-for-me",
    "proceleusmático": "pro-ce-leus-má-ti-co",
    "procelosa": "pro-ce-lo-sa",
    "proceloso": "pro-ce-lo-so",
    "prócer": "pró-cer",
    "procera": "pro-ce-ra",
    "procerato": "pro-ce-ra-to",
    "proceridad": "pro-ce-ri-dad",
    "procero": "pro-ce-ro",
    "procerosa": "pro-ce-ro-sa",
    "proceroso": "pro-ce-ro-so",
    "procesada": "pro-ce-sa-da",
    "procesado": "pro-ce-sa-do",
    "procesador": "pro-ce-sa-dor",
    "procesal": "pro-ce-sal",
    "procesamiento": "pro-ce-sa-mien-to",
    "procesar": "pro-ce-sar",
    "procesión": "pro-ce-sión",
    "procesional": "pro-ce-sio-nal",
    "procesionalmente": "pro-ce-sio-nal-men-te",
    "procesionaria": "pro-ce-sio-na-ria",
    "procesionario": "pro-ce-sio-na-rio",
    "proceso": "pro-ce-so",
    "procinto": "pro-cin-to",
    "proclama": "pro-cla-ma",
    "proclamación": "pro-cla-ma-ción",
    "proclamar": "pro-cla-mar",
    "proclisis": "pro-cli-sis",
    "proclítica": "pro-clí-ti-ca",
    "proclítico": "pro-clí-ti-co",
    "proclive": "pro-cli-ve",
    "proclividad": "pro-cli-vi-dad",
    "proco": "pro-co",
    "procomún": "pro-co-mún",
    "procomunal": "pro-co-mu-nal",
    "procónsul": "pro-cón-sul",
    "proconsulado": "pro-con-su-la-do",
    "proconsular": "pro-con-su-lar",
    "procordado": "pro-cor-da-do",
    "procrastinación": "pro-cras-ti-na-ción",
    "procrastinar": "pro-cras-ti-nar",
    "procreación": "pro-cre-a-ción",
    "procreador": "pro-cre-a-dor",
    "procreadora": "pro-cre-a-do-ra",
    "procrear": "pro-cre-ar",
    "proctóloga": "proc-tó-lo-ga",
    "proctología": "proc-to-lo-gí-a",
    "proctológico": "proc-to-ló-gi-co",
    "proctólogo": "proc-tó-lo-go",
    "proctoscopia": "proc-tos-co-pia",
    "proctoscopio": "proc-tos-co-pio",
    "procura": "pro-cu-ra",
    "procuración": "pro-cu-ra-ción",
    "procurador": "pro-cu-ra-dor",
    "procuradora": "pro-cu-ra-do-ra",
    "procuraduría": "pro-cu-ra-du-rí-a",
    "procurar": "pro-cu-rar",
    "procurrente": "pro-cu-rren-te",
    "prodición": "pro-di-ción",
    "pródiga": "pró-di-ga",
    "prodigalidad": "pro-di-ga-li-dad",
    "pródigamente": "pró-di-ga-men-te",
    "prodigar": "pro-di-gar",
    "prodigiador": "pro-di-gia-dor",
    "prodigio": "pro-di-gio",
    "prodigiosa": "pro-di-gio-sa",
    "prodigiosamente": "pro-di-gio-sa-men-te",
    "prodigiosidad": "pro-di-gio-si-dad",
    "prodigioso": "pro-di-gio-so",
    "pródigo": "pró-di-go",
    "proditor": "pro-di-tor",
    "proditorio": "pro-di-to-rio",
    "prodrómica": "pro-dró-mi-ca",
    "prodrómico": "pro-dró-mi-co",
    "pródromo": "pró-dro-mo",
    "producción": "pro-duc-ción",
    "producibilidad": "pro-du-ci-bi-li-dad",
    "producible": "pro-du-ci-ble",
    "producidor": "pro-du-ci-dor",
    "producidora": "pro-du-ci-do-ra",
    "producimiento": "pro-du-ci-mien-to",
    "producir": "pro-du-cir",
    "productibilidad": "pro-duc-ti-bi-li-dad",
    "productible": "pro-duc-ti-ble",
    "productiva": "pro-duc-ti-va",
    "productividad": "pro-duc-ti-vi-dad",
    "productivismo": "pro-duc-ti-vis-mo",
    "productivista": "pro-duc-ti-vis-ta",
    "productivo": "pro-duc-ti-vo",
    "producto": "pro-duc-to",
    "productor": "pro-duc-tor",
    "productora": "pro-duc-to-ra",
    "proejar": "pro-e-jar",
    "proel": "pro-el",
    "proemial": "pro-e-mial",
    "proemio": "pro-e-mio",
    "proeza": "pro-e-za",
    "profa": "pro-fa",
    "profana": "pro-fa-na",
    "profanación": "pro-fa-na-ción",
    "profanador": "pro-fa-na-dor",
    "profanadora": "pro-fa-na-do-ra",
    "profanamente": "pro-fa-na-men-te",
    "profanamiento": "pro-fa-na-mien-to",
    "profanar": "pro-fa-nar",
    "profanía": "pro-fa-ní-a",
    "profanidad": "pro-fa-ni-dad",
    "profano": "pro-fa-no",
    "profase": "pro-fa-se",
    "profazador": "pro-fa-za-dor",
    "profazadora": "pro-fa-za-do-ra",
    "profazamiento": "pro-fa-za-mien-to",
    "profazar": "pro-fa-zar",
    "profazo": "pro-fa-zo",
    "profe": "pro-fe",
    "profecía": "pro-fe-cí-a",
    "proferimiento": "pro-fe-ri-mien-to",
    "proferir": "pro-fe-rir",
    "proferta": "pro-fer-ta",
    "profesa": "pro-fe-sa",
    "profesar": "pro-fe-sar",
    "profesión": "pro-fe-sión",
    "profesional": "pro-fe-sio-nal",
    "profesionalidad": "pro-fe-sio-na-li-dad",
    "profesionalismo": "pro-fe-sio-na-lis-mo",
    "profesionalización": "pro-fe-sio-na-li-za-ción",
    "profesionalizar": "pro-fe-sio-na-li-zar",
    "profesionalmente": "pro-fe-sio-nal-men-te",
    "profesionista": "pro-fe-sio-nis-ta",
    "profeso": "pro-fe-so",
    "profesor": "pro-fe-sor",
    "profesora": "pro-fe-so-ra",
    "profesorado": "pro-fe-so-ra-do",
    "profesoral": "pro-fe-so-ral",
    "profeta": "pro-fe-ta",
    "profetal": "pro-fe-tal",
    "profetar": "pro-fe-tar",
    "profética": "pro-fé-ti-ca",
    "proféticamente": "pro-fé-ti-ca-men-te",
    "profético": "pro-fé-ti-co",
    "profetisa": "pro-fe-ti-sa",
    "profetismo": "pro-fe-tis-mo",
    "profetizador": "pro-fe-ti-za-dor",
    "profetizadora": "pro-fe-ti-za-do-ra",
    "profetizar": "pro-fe-ti-zar",
    "proficiente": "pro-fi-cien-te",
    "proficua": "pro-fi-cua",
    "proficuo": "pro-fi-cuo",
    "profierta": "pro-fier-ta",
    "profiláctica": "pro-fi-lác-ti-ca",
    "profiláctico": "pro-fi-lác-ti-co",
    "profilaxia": "pro-fi-la-xia",
    "profilaxis": "pro-fi-la-xis",
    "profiterol": "pro-fi-te-rol",
    "profligar": "pro-fli-gar",
    "prófuga": "pró-fu-ga",
    "prófugo": "pró-fu-go",
    "profunda": "pro-fun-da",
    "profundamente": "pro-fun-da-men-te",
    "profundar": "pro-fun-dar",
    "profundidad": "pro-fun-di-dad",
    "profundización": "pro-fun-di-za-ción",
    "profundizar": "pro-fun-di-zar",
    "profundo": "pro-fun-do",
    "profusa": "pro-fu-sa",
    "profusamente": "pro-fu-sa-men-te",
    "profusión": "pro-fu-sión",
    "profuso": "pro-fu-so",
    "progenie": "pro-ge-nie",
    "progenitor": "pro-ge-ni-tor",
    "progenitora": "pro-ge-ni-to-ra",
    "progenitura": "pro-ge-ni-tu-ra",
    "progeria": "pro-ge-ria",
    "progestágeno": "pro-ges-tá-ge-no",
    "progesterona": "pro-ges-te-ro-na",
    "progimnasma": "pro-gim-nas-ma",
    "proglotis": "pro-glo-tis",
    "prognata": "prog-na-ta",
    "prognatismo": "prog-na-tis-mo",
    "prognato": "prog-na-to",
    "progne": "prog-ne",
    "prognosis": "prog-no-sis",
    "programa": "pro-gra-ma",
    "programable": "pro-gra-ma-ble",
    "programación": "pro-gra-ma-ción",
    "programador": "pro-gra-ma-dor",
    "programadora": "pro-gra-ma-do-ra",
    "programar": "pro-gra-mar",
    "programática": "pro-gra-má-ti-ca",
    "programático": "pro-gra-má-ti-co",
    "progre": "pro-gre",
    "progresar": "pro-gre-sar",
    "progresía": "pro-gre-sí-a",
    "progresión": "pro-gre-sión",
    "progresismo": "pro-gre-sis-mo",
    "progresista": "pro-gre-sis-ta",
    "progresiva": "pro-gre-si-va",
    "progresivamente": "pro-gre-si-va-men-te",
    "progresivo": "pro-gre-si-vo",
    "progreso": "pro-gre-so",
    "prohibición": "prohi-bi-ción",
    "prohibicionismo": "prohi-bi-cio-nis-mo",
    "prohibicionista": "prohi-bi-cio-nis-ta",
    "prohibido": "prohi-bi-do",
    "prohibir": "prohi-bir",
    "prohibitiva": "prohi-bi-ti-va",
    "prohibitivo": "prohi-bi-ti-vo",
    "prohibitoria": "prohi-bi-to-ria",
    "prohibitorio": "prohi-bi-to-rio",
    "prohijación": "prohi-ja-ción",
    "prohijador": "prohi-ja-dor",
    "prohijadora": "prohi-ja-do-ra",
    "prohijamiento": "prohi-ja-mien-to",
    "prohijar": "prohi-jar",
    "prohombre": "pro-hom-bre",
    "proindivisión": "proin-di-vi-sión",
    "proís": "pro-ís",
    "proíz": "pro-íz",
    "prójima": "pró-ji-ma",
    "prójimo": "pró-ji-mo",
    "prolación": "pro-la-ción",
    "prolactina": "pro-lac-ti-na",
    "prolapso": "pro-lap-so",
    "prole": "pro-le",
    "prolegómeno": "pro-le-gó-me-no",
    "prolepsis": "pro-lep-sis",
    "proletaria": "pro-le-ta-ria",
    "proletariado": "pro-le-ta-ria-do",
    "proletario": "pro-le-ta-rio",
    "proletarización": "pro-le-ta-ri-za-ción",
    "proletarizar": "pro-le-ta-ri-zar",
    "proliferación": "pro-li-fe-ra-ción",
    "proliferante": "pro-li-fe-ran-te",
    "proliferar": "pro-li-fe-rar",
    "prolífero": "pro-lí-fe-ro",
    "prolífica": "pro-lí-fi-ca",
    "prolífico": "pro-lí-fi-co",
    "prolija": "pro-li-ja",
    "prolijamente": "pro-li-ja-men-te",
    "prolijear": "pro-li-je-ar",
    "prolijidad": "pro-li-ji-dad",
    "prolijo": "pro-li-jo",
    "prologal": "pro-lo-gal",
    "prologar": "pro-lo-gar",
    "prólogo": "pró-lo-go",
    "prologuista": "pro-lo-guis-ta",
    "prolonga": "pro-lon-ga",
    "prolongable": "pro-lon-ga-ble",
    "prolongación": "pro-lon-ga-ción",
    "prolongada": "pro-lon-ga-da",
    "prolongadamente": "pro-lon-ga-da-men-te",
    "prolongado": "pro-lon-ga-do",
    "prolongador": "pro-lon-ga-dor",
    "prolongadora": "pro-lon-ga-do-ra",
    "prolongamiento": "pro-lon-ga-mien-to",
    "prolongar": "pro-lon-gar",
    "proloquio": "pro-lo-quio",
    "prolusión": "pro-lu-sión",
    "promanar": "pro-ma-nar",
    "promecio": "pro-me-cio",
    "promediar": "pro-me-diar",
    "promedio": "pro-me-dio",
    "promesa": "pro-me-sa",
    "promesante": "pro-me-san-te",
    "promesar": "pro-me-sar",
    "prometazina": "pro-me-ta-zi-na",
    "prometedor": "pro-me-te-dor",
    "prometedora": "pro-me-te-do-ra",
    "prometer": "pro-me-ter",
    "prometida": "pro-me-ti-da",
    "prometido": "pro-me-ti-do",
    "prometimiento": "pro-me-ti-mien-to",
    "prometio": "pro-me-tio",
    "prominencia": "pro-mi-nen-cia",
    "prominente": "pro-mi-nen-te",
    "promiscua": "pro-mis-cua",
    "promiscuación": "pro-mis-cua-ción",
    "promiscuamente": "pro-mis-cua-men-te",
    "promiscuar": "pro-mis-cuar",
    "promiscuidad": "pro-mis-cui-dad",
    "promiscuo": "pro-mis-cuo",
    "promisión": "pro-mi-sión",
    "promisor": "pro-mi-sor",
    "promisoria": "pro-mi-so-ria",
    "promisorio": "pro-mi-so-rio",
    "promitente": "pro-mi-ten-te",
    "promoción": "pro-mo-ción",
    "promocional": "pro-mo-cio-nal",
    "promocionar": "pro-mo-cio-nar",
    "promontorio": "pro-mon-to-rio",
    "promotor": "pro-mo-tor",
    "promotora": "pro-mo-to-ra",
    "promovedor": "pro-mo-ve-dor",
    "promovedora": "pro-mo-ve-do-ra",
    "promover": "pro-mo-ver",
    "promulgación": "pro-mul-ga-ción",
    "promulgador": "pro-mul-ga-dor",
    "promulgadora": "pro-mul-ga-do-ra",
    "promulgar": "pro-mul-gar",
    "prona": "pro-na",
    "pronación": "pro-na-ción",
    "pronador": "pro-na-dor",
    "pronaos": "pro-na-os",
    "prono": "pro-no",
    "pronombre": "pro-nom-bre",
    "pronominado": "pro-no-mi-na-do",
    "pronominal": "pro-no-mi-nal",
    "pronosticación": "pro-nos-ti-ca-ción",
    "pronosticador": "pro-nos-ti-ca-dor",
    "pronosticadora": "pro-nos-ti-ca-do-ra",
    "pronosticar": "pro-nos-ti-car",
    "pronóstico": "pro-nós-ti-co",
    "pronta": "pron-ta",
    "prontamente": "pron-ta-men-te",
    "pronteza": "pron-te-za",
    "prontitud": "pron-ti-tud",
    "pronto": "pron-to",
    "prontuario": "pron-tua-rio",
    "prónuba": "pró-nu-ba",
    "pronuncia": "pro-nun-cia",
    "pronunciable": "pro-nun-cia-ble",
    "pronunciación": "pro-nun-cia-ción",
    "pronunciado": "pro-nun-cia-do",
    "pronunciador": "pro-nun-cia-dor",
    "pronunciadora": "pro-nun-cia-do-ra",
    "pronunciamiento": "pro-nun-cia-mien-to",
    "pronunciar": "pro-nun-ciar",
    "pronuncio": "pro-nun-cio",
    "propagación": "pro-pa-ga-ción",
    "propagador": "pro-pa-ga-dor",
    "propagadora": "pro-pa-ga-do-ra",
    "propaganda": "pro-pa-gan-da",
    "propagandismo": "pro-pa-gan-dis-mo",
    "propagandista": "pro-pa-gan-dis-ta",
    "propagandístico": "pro-pa-gan-dís-ti-co",
    "propagante": "pro-pa-gan-te",
    "propagar": "pro-pa-gar",
    "propagativa": "pro-pa-ga-ti-va",
    "propagativo": "pro-pa-ga-ti-vo",
    "propalador": "pro-pa-la-dor",
    "propaladora": "pro-pa-la-do-ra",
    "propalar": "pro-pa-lar",
    "propano": "pro-pa-no",
    "propao": "pro-pa-o",
    "proparoxítona": "pro-pa-ro-xí-to-na",
    "proparoxítono": "pro-pa-ro-xí-to-no",
    "propartida": "pro-par-ti-da",
    "propasar": "pro-pa-sar",
    "propedéutica": "pro-pe-déu-ti-ca",
    "propedéutico": "pro-pe-déu-ti-co",
    "propelente": "pro-pe-len-te",
    "propender": "pro-pen-der",
    "propeno": "pro-pe-no",
    "propensa": "pro-pen-sa",
    "propensamente": "pro-pen-sa-men-te",
    "propensión": "pro-pen-sión",
    "propenso": "pro-pen-so",
    "propergol": "pro-per-gol",
    "propia": "pro-pia",
    "propiamente": "pro-pia-men-te",
    "propicia": "pro-pi-cia",
    "propiciación": "pro-pi-cia-ción",
    "propiciador": "pro-pi-cia-dor",
    "propiciadora": "pro-pi-cia-do-ra",
    "propiciamente": "pro-pi-cia-men-te",
    "propiciar": "pro-pi-ciar",
    "propiciatoria": "pro-pi-cia-to-ria",
    "propiciatorio": "pro-pi-cia-to-rio",
    "propicio": "pro-pi-cio",
    "propiedad": "pro-pie-dad",
    "propienda": "pro-pien-da",
    "propietaria": "pro-pie-ta-ria",
    "propietariamente": "pro-pie-ta-ria-men-te",
    "propietario": "pro-pie-ta-rio",
    "propileno": "pro-pi-le-no",
    "propileo": "pro-pi-le-o",
    "propina": "pro-pi-na",
    "propinación": "pro-pi-na-ción",
    "propinar": "pro-pi-nar",
    "propincua": "pro-pin-cua",
    "propincuidad": "pro-pin-cui-dad",
    "propincuo": "pro-pin-cuo",
    "propino": "pro-pi-no",
    "propio": "pro-pio",
    "propóleos": "pro-pó-le-os",
    "proponedor": "pro-po-ne-dor",
    "proponedora": "pro-po-ne-do-ra",
    "proponente": "pro-po-nen-te",
    "proponer": "pro-po-ner",
    "proporción": "pro-por-ción",
    "proporcionable": "pro-por-cio-na-ble",
    "proporcionablemente": "pro-por-cio-na-ble-men-te",
    "proporcionada": "pro-por-cio-na-da",
    "proporcionadamente": "pro-por-cio-na-da-men-te",
    "proporcionado": "pro-por-cio-na-do",
    "proporcional": "pro-por-cio-nal",
    "proporcionalidad": "pro-por-cio-na-li-dad",
    "proporcionalmente": "pro-por-cio-nal-men-te",
    "proporcionar": "pro-por-cio-nar",
    "proposición": "pro-po-si-ción",
    "proposicional": "pro-po-si-cio-nal",
    "propósito": "pro-pó-si-to",
    "propretor": "pro-pre-tor",
    "propretura": "pro-pre-tu-ra",
    "propria": "pro-pria",
    "propriedad": "pro-prie-dad",
    "proprio": "pro-prio",
    "propuesta": "pro-pues-ta",
    "propuesto": "pro-pues-to",
    "propugnación": "pro-pug-na-ción",
    "propugnáculo": "pro-pug-ná-cu-lo",
    "propugnador": "pro-pug-na-dor",
    "propugnadora": "pro-pug-na-do-ra",
    "propugnar": "pro-pug-nar",
    "propulsa": "pro-pul-sa",
    "propulsar": "pro-pul-sar",
    "propulsión": "pro-pul-sión",
    "propulsor": "pro-pul-sor",
    "propulsora": "pro-pul-so-ra",
    "prora": "pro-ra",
    "prorrata": "pro-rra-ta",
    "prorratear": "pro-rra-te-ar",
    "prorrateo": "pro-rra-te-o",
    "prórroga": "pró-rro-ga",
    "prorrogable": "pro-rro-ga-ble",
    "prorrogación": "pro-rro-ga-ción",
    "prorrogar": "pro-rro-gar",
    "prorrogativa": "pro-rro-ga-ti-va",
    "prorrogativo": "pro-rro-ga-ti-vo",
    "prorrumpir": "pro-rrum-pir",
    "prosa": "pro-sa",
    "prosada": "pro-sa-da",
    "prosado": "pro-sa-do",
    "prosador": "pro-sa-dor",
    "prosadora": "pro-sa-do-ra",
    "prosaica": "pro-sai-ca",
    "prosaicamente": "pro-sai-ca-men-te",
    "prosaico": "pro-sai-co",
    "prosaísmo": "pro-sa-ís-mo",
    "prosapia": "pro-sa-pia",
    "proscenio": "pros-ce-nio",
    "proscribir": "pros-cri-bir",
    "proscripción": "pros-crip-ción",
    "proscripta": "pros-crip-ta",
    "proscripto": "pros-crip-to",
    "proscriptor": "pros-crip-tor",
    "proscriptora": "pros-crip-to-ra",
    "proscrita": "pros-cri-ta",
    "proscrito": "pros-cri-to",
    "prosear": "pro-se-ar",
    "prosecretario": "pro-se-cre-ta-rio",
    "prosecución": "pro-se-cu-ción",
    "proseguible": "pro-se-gui-ble",
    "proseguimiento": "pro-se-gui-mien-to",
    "proseguir": "pro-se-guir",
    "proselitismo": "pro-se-li-tis-mo",
    "proselitista": "pro-se-li-tis-ta",
    "prosélito": "pro-sé-li-to",
    "prosencéfalo": "pro-sen-cé-fa-lo",
    "prosénquima": "pro-sén-qui-ma",
    "proseo": "pro-se-o",
    "prosificación": "pro-si-fi-ca-ción",
    "prosificador": "pro-si-fi-ca-dor",
    "prosificadora": "pro-si-fi-ca-do-ra",
    "prosificar": "pro-si-fi-car",
    "prosimio": "pro-si-mio",
    "prosista": "pro-sis-ta",
    "prosística": "pro-sís-ti-ca",
    "prosístico": "pro-sís-ti-co",
    "prosita": "pro-si-ta",
    "prosodema": "pro-so-de-ma",
    "prosodia": "pro-so-dia",
    "prosódica": "pro-só-di-ca",
    "prosódico": "pro-só-di-co",
    "prosopografía": "pro-so-po-gra-fí-a",
    "prosopopeya": "pro-so-po-pe-ya",
    "prosopopéyico": "pro-so-po-pé-yi-co",
    "prospección": "pros-pec-ción",
    "prospectar": "pros-pec-tar",
    "prospectiva": "pros-pec-ti-va",
    "prospectivo": "pros-pec-ti-vo",
    "prospecto": "pros-pec-to",
    "próspera": "prós-pe-ra",
    "prosperada": "pros-pe-ra-da",
    "prosperado": "pros-pe-ra-do",
    "prósperamente": "prós-pe-ra-men-te",
    "prosperar": "pros-pe-rar",
    "prosperidad": "pros-pe-ri-dad",
    "próspero": "prós-pe-ro",
    "prostaféresis": "pros-ta-fé-re-sis",
    "próstata": "prós-ta-ta",
    "prostática": "pros-tá-ti-ca",
    "prostático": "pros-tá-ti-co",
    "prostatitis": "pros-ta-ti-tis",
    "prosternación": "pros-ter-na-ción",
    "prosternar": "pros-ter-nar",
    "prosternarse": "pros-ter-nar-se",
    "próstesis": "prós-te-sis",
    "prostética": "pros-té-ti-ca",
    "prostético": "pros-té-ti-co",
    "prostibularia": "pros-ti-bu-la-ria",
    "prostibulario": "pros-ti-bu-la-rio",
    "prostíbulo": "pros-tí-bu-lo",
    "próstilo": "prós-ti-lo",
    "prostitución": "pros-ti-tu-ción",
    "prostituir": "pros-ti-tuir",
    "prostituta": "pros-ti-tu-ta",
    "prostituto": "pros-ti-tu-to",
    "prostomio": "pros-to-mio",
    "prostrar": "pros-trar",
    "prosudo": "pro-su-do",
    "prosuponer": "pro-su-po-ner",
    "prosupuesto": "pro-su-pues-to",
    "protactinio": "pro-tac-ti-nio",
    "protagónico": "pro-ta-gó-ni-co",
    "protagonismo": "pro-ta-go-nis-mo",
    "protagonista": "pro-ta-go-nis-ta",
    "protagonizar": "pro-ta-go-ni-zar",
    "protalo": "pro-ta-lo",
    "prótasis": "pró-ta-sis",
    "protática": "pro-tá-ti-ca",
    "protático": "pro-tá-ti-co",
    "proteácea": "pro-te-á-ce-a",
    "proteáceo": "pro-te-á-ce-o",
    "proteasa": "pro-te-a-sa",
    "protección": "pro-tec-ción",
    "proteccionismo": "pro-tec-cio-nis-mo",
    "proteccionista": "pro-tec-cio-nis-ta",
    "protector": "pro-tec-tor",
    "protectora": "pro-tec-to-ra",
    "protectorado": "pro-tec-to-ra-do",
    "protectoría": "pro-tec-to-rí-a",
    "protectorio": "pro-tec-to-rio",
    "protectriz": "pro-tec-triz",
    "proteger": "pro-te-ger",
    "protegida": "pro-te-gi-da",
    "protegido": "pro-te-gi-do",
    "proteica": "pro-tei-ca",
    "proteico": "pro-tei-co",
    "proteína": "pro-te-í-na",
    "proteínica": "pro-te-í-ni-ca",
    "proteínico": "pro-te-í-ni-co",
    "proteinuria": "pro-tei-nu-ria",
    "proteo": "pro-te-o",
    "proterva": "pro-ter-va",
    "protervamente": "pro-ter-va-men-te",
    "protervia": "pro-ter-via",
    "protervidad": "pro-ter-vi-dad",
    "protervo": "pro-ter-vo",
    "protésica": "pro-té-si-ca",
    "protésico": "pro-té-si-co",
    "prótesis": "pró-te-sis",
    "protesta": "pro-tes-ta",
    "protestación": "pro-tes-ta-ción",
    "protestante": "pro-tes-tan-te",
    "protestantismo": "pro-tes-tan-tis-mo",
    "protestar": "pro-tes-tar",
    "protestataria": "pro-tes-ta-ta-ria",
    "protestatario": "pro-tes-ta-ta-rio",
    "protestativa": "pro-tes-ta-ti-va",
    "protestativo": "pro-tes-ta-ti-vo",
    "protesto": "pro-tes-to",
    "protestón": "pro-tes-tón",
    "protestona": "pro-tes-to-na",
    "protética": "pro-té-ti-ca",
    "protético": "pro-té-ti-co",
    "prótido": "pró-ti-do",
    "protio": "pro-tio",
    "protista": "pro-tis-ta",
    "proto": "pro-to",
    "protoalbéitar": "pro-to-al-béi-tar",
    "protoalbeiterato": "pro-to-al-bei-te-ra-to",
    "protocloruro": "pro-to-clo-ru-ro",
    "protocolar": "pro-to-co-lar",
    "protocolaria": "pro-to-co-la-ria",
    "protocolario": "pro-to-co-la-rio",
    "protocolización": "pro-to-co-li-za-ción",
    "protocolizar": "pro-to-co-li-zar",
    "protocolo": "pro-to-co-lo",
    "protohistoria": "pro-tohis-to-ria",
    "protohistórica": "pro-tohis-tó-ri-ca",
    "protohistórico": "pro-tohis-tó-ri-co",
    "protomártir": "pro-to-már-tir",
    "protomedicato": "pro-to-me-di-ca-to",
    "protomédico": "pro-to-mé-di-co",
    "protón": "pro-tón",
    "protonema": "pro-to-ne-ma",
    "protónica": "pro-tó-ni-ca",
    "protónico": "pro-tó-ni-co",
    "protonotario": "pro-to-no-ta-rio",
    "protoplaneta": "pro-to-pla-ne-ta",
    "protoplasma": "pro-to-plas-ma",
    "protoplasmática": "pro-to-plas-má-ti-ca",
    "protoplasmático": "pro-to-plas-má-ti-co",
    "protórax": "pro-tó-rax",
    "protosol": "pro-to-sol",
    "protosulfuro": "pro-to-sul-fu-ro",
    "prototerio": "pro-to-te-rio",
    "prototípico": "pro-to-tí-pi-co",
    "prototipo": "pro-to-ti-po",
    "protóxido": "pro-tó-xi-do",
    "protozoaria": "pro-to-zo-a-ria",
    "protozoario": "pro-to-zo-a-rio",
    "protozoo": "pro-to-zo-o",
    "protráctil": "pro-trác-til",
    "protrombina": "pro-trom-bi-na",
    "protruir": "pro-truir",
    "protrusión": "pro-tru-sión",
    "protuberancia": "pro-tu-be-ran-cia",
    "protuberante": "pro-tu-be-ran-te",
    "protutor": "pro-tu-tor",
    "protutora": "pro-tu-to-ra",
    "provagar": "pro-va-gar",
    "provechar": "pro-ve-char",
    "provecho": "pro-ve-cho",
    "provechosa": "pro-ve-cho-sa",
    "provechosamente": "pro-ve-cho-sa-men-te",
    "provechoso": "pro-ve-cho-so",
    "provecta": "pro-vec-ta",
    "provecto": "pro-vec-to",
    "proveedor": "pro-ve-e-dor",
    "proveedora": "pro-ve-e-do-ra",
    "proveeduría": "pro-ve-e-du-rí-a",
    "proveer": "pro-ve-er",
    "proveído": "pro-ve-í-do",
    "proveimiento": "pro-vei-mien-to",
    "provena": "pro-ve-na",
    "proveniencia": "pro-ve-nien-cia",
    "proveniente": "pro-ve-nien-te",
    "provenir": "pro-ve-nir",
    "provento": "pro-ven-to",
    "provenzal": "pro-ven-zal",
    "provenzalismo": "pro-ven-za-lis-mo",
    "provenzalista": "pro-ven-za-lis-ta",
    "proverbiador": "pro-ver-bia-dor",
    "proverbial": "pro-ver-bial",
    "proverbialmente": "pro-ver-bial-men-te",
    "proverbio": "pro-ver-bio",
    "proverbista": "pro-ver-bis-ta",
    "proveza": "pro-ve-za",
    "provicero": "pro-vi-ce-ro",
    "próvida": "pró-vi-da",
    "próvidamente": "pró-vi-da-men-te",
    "providencia": "pro-vi-den-cia",
    "providencial": "pro-vi-den-cial",
    "providencialismo": "pro-vi-den-cia-lis-mo",
    "providencialista": "pro-vi-den-cia-lis-ta",
    "providencialmente": "pro-vi-den-cial-men-te",
    "providenciar": "pro-vi-den-ciar",
    "providente": "pro-vi-den-te",
    "próvido": "pró-vi-do",
    "provincia": "pro-vin-cia",
    "provincial": "pro-vin-cial",
    "provinciala": "pro-vin-cia-la",
    "provincialato": "pro-vin-cia-la-to",
    "provincialismo": "pro-vin-cia-lis-mo",
    "provinciana": "pro-vin-cia-na",
    "provincianismo": "pro-vin-cia-nis-mo",
    "provinciano": "pro-vin-cia-no",
    "provinente": "pro-vi-nen-te",
    "proviniente": "pro-vi-nien-te",
    "provisión": "pro-vi-sión",
    "provisional": "pro-vi-sio-nal",
    "provisionalidad": "pro-vi-sio-na-li-dad",
    "provisionalmente": "pro-vi-sio-nal-men-te",
    "proviso": "pro-vi-so",
    "provisor": "pro-vi-sor",
    "provisora": "pro-vi-so-ra",
    "provisorato": "pro-vi-so-ra-to",
    "provisoría": "pro-vi-so-rí-a",
    "provisorio": "pro-vi-so-rio",
    "provista": "pro-vis-ta",
    "provisto": "pro-vis-to",
    "provocación": "pro-vo-ca-ción",
    "provocador": "pro-vo-ca-dor",
    "provocadora": "pro-vo-ca-do-ra",
    "provocante": "pro-vo-can-te",
    "provocar": "pro-vo-car",
    "provocativa": "pro-vo-ca-ti-va",
    "provocativo": "pro-vo-ca-ti-vo",
    "proxémica": "pro-xé-mi-ca",
    "proxeneta": "pro-xe-ne-ta",
    "proxenética": "pro-xe-né-ti-ca",
    "proxenético": "pro-xe-né-ti-co",
    "proxenetismo": "pro-xe-ne-tis-mo",
    "próxima": "pró-xi-ma",
    "proximal": "pro-xi-mal",
    "próximamente": "pró-xi-ma-men-te",
    "proximidad": "pro-xi-mi-dad",
    "próximo": "pró-xi-mo",
    "proyección": "pro-yec-ción",
    "proyeccionista": "pro-yec-cio-nis-ta",
    "proyecta": "pro-yec-ta",
    "proyectante": "pro-yec-tan-te",
    "proyectar": "pro-yec-tar",
    "proyectil": "pro-yec-til",
    "proyectista": "pro-yec-tis-ta",
    "proyectivo": "pro-yec-ti-vo",
    "proyecto": "pro-yec-to",
    "proyector": "pro-yec-tor",
    "proyectora": "pro-yec-to-ra",
    "proyectura": "pro-yec-tu-ra",
    "prudencia": "pru-den-cia",
    "prudencial": "pru-den-cial",
    "prudencialmente": "pru-den-cial-men-te",
    "prudente": "pru-den-te",
    "prudentemente": "pru-den-te-men-te",
    "prueba": "prue-ba",
    "pruina": "prui-na",
    "pruinoso": "prui-no-so",
    "pruna": "pru-na",
    "prunela": "pru-ne-la",
    "pruno": "pru-no",
    "pruriginoso": "pru-ri-gi-no-so",
    "prurigo": "pru-ri-go",
    "prurito": "pru-ri-to",
    "prusia": "pru-sia",
    "prusiana": "pru-sia-na",
    "prusiano": "pru-sia-no",
    "prusiato": "pru-sia-to",
    "prúsico": "prú-si-co",
    "pseudo": "pseu-do",
    "pseudónimo": "pseu-dó-ni-mo",
    "psicagogia": "psi-ca-go-gia",
    "psicastenia": "psi-cas-te-nia",
    "psicasténica": "psi-cas-té-ni-ca",
    "psicasténico": "psi-cas-té-ni-co",
    "psicoactivo": "psi-co-ac-ti-vo",
    "psicoanálisis": "psi-co-a-ná-li-sis",
    "psicoanalista": "psi-co-a-na-lis-ta",
    "psicoanalítica": "psi-co-a-na-lí-ti-ca",
    "psicoanalítico": "psi-co-a-na-lí-ti-co",
    "psicoanalizar": "psi-co-a-na-li-zar",
    "psicobolche": "psi-co-bol-che",
    "psicodelia": "psi-co-de-lia",
    "psicodélico": "psi-co-dé-li-co",
    "psicodiagnóstico": "psi-co-diag-nós-ti-co",
    "psicodinámico": "psi-co-di-ná-mi-co",
    "psicodrama": "psi-co-dra-ma",
    "psicofármaco": "psi-co-fár-ma-co",
    "psicofarmacología": "psi-co-far-ma-co-lo-gí-a",
    "psicofísica": "psi-co-fí-si-ca",
    "psicofísico": "psi-co-fí-si-co",
    "psicofisiología": "psi-co-fi-sio-lo-gí-a",
    "psicofisiológico": "psi-co-fi-sio-ló-gi-co",
    "psicofonía": "psi-co-fo-ní-a",
    "psicogénico": "psi-co-gé-ni-co",
    "psicógeno": "psi-có-ge-no",
    "psicohistoria": "psi-cohis-to-ria",
    "psicokinesia": "psi-co-ki-ne-sia",
    "psicolingüista": "psi-co-lin-güis-ta",
    "psicolingüística": "psi-co-lin-güís-ti-ca",
    "psicolingüístico": "psi-co-lin-güís-ti-co",
    "psicóloga": "psi-có-lo-ga",
    "psicología": "psi-co-lo-gí-a",
    "psicológica": "psi-co-ló-gi-ca",
    "psicológico": "psi-co-ló-gi-co",
    "psicologismo": "psi-co-lo-gis-mo",
    "psicólogo": "psi-có-lo-go",
    "psicómetra": "psi-có-me-tra",
    "psicometría": "psi-co-me-trí-a",
    "psicomotor": "psi-co-mo-tor",
    "psicomotricidad": "psi-co-mo-tri-ci-dad",
    "psicomotriz": "psi-co-mo-triz",
    "psicópata": "psi-có-pa-ta",
    "psicopatía": "psi-co-pa-tí-a",
    "psicopática": "psi-co-pá-ti-ca",
    "psicopático": "psi-co-pá-ti-co",
    "psicopatología": "psi-co-pa-to-lo-gí-a",
    "psicopatológico": "psi-co-pa-to-ló-gi-co",
    "psicopedagoga": "psi-co-pe-da-go-ga",
    "psicopedagogía": "psi-co-pe-da-go-gí-a",
    "psicopedagógico": "psi-co-pe-da-gó-gi-co",
    "psicopedagogo": "psi-co-pe-da-go-go",
    "psicoquinesia": "psi-co-qui-ne-sia",
    "psicosis": "psi-co-sis",
    "psicosocial": "psi-co-so-cial",
    "psicosociología": "psi-co-so-cio-lo-gí-a",
    "psicosomático": "psi-co-so-má-ti-co",
    "psicotecnia": "psi-co-tec-nia",
    "psicotécnico": "psi-co-téc-ni-co",
    "psicoterapeuta": "psi-co-te-ra-peu-ta",
    "psicoterapéutico": "psi-co-te-ra-péu-ti-co",
    "psicoterapia": "psi-co-te-ra-pia",
    "psicoterápico": "psi-co-te-rá-pi-co",
    "psicótica": "psi-có-ti-ca",
    "psicótico": "psi-có-ti-co",
    "psicotrópico": "psi-co-tró-pi-co",
    "psicótropo": "psi-có-tro-po",
    "psicrómetro": "psi-cró-me-tro",
    "psique": "psi-que",
    "psiquiatra": "psi-quia-tra",
    "psiquiatría": "psi-quia-trí-a",
    "psiquiátrico": "psi-quiá-tri-co",
    "psíquica": "psí-qui-ca",
    "psíquico": "psí-qui-co",
    "psiquis": "psi-quis",
    "psiquismo": "psi-quis-mo",
    "psitácida": "psi-tá-ci-da",
    "psitaciforme": "psi-ta-ci-for-me",
    "psitacismo": "psi-ta-cis-mo",
    "psitacosis": "psi-ta-co-sis",
    "psoriasis": "pso-ria-sis",
    "pteridofita": "pte-ri-do-fi-ta",
    "pteridofitas": "pte-ri-do-fi-tas",
    "pteridofito": "pte-ri-do-fi-to",
    "pterodáctilo": "pte-ro-dác-ti-lo",
    "ptialina": "ptia-li-na",
    "ptialismo": "ptia-lis-mo",
    "ptolemaico": "pto-le-mai-co",
    "ptosis": "pto-sis",
    "púa": "pú-a",
    "puado": "pua-do",
    "púber": "pú-ber",
    "púbera": "pú-be-ra",
    "puberal": "pu-be-ral",
    "púbero": "pú-be-ro",
    "pubertad": "pu-ber-tad",
    "pubes": "pu-bes",
    "pubescencia": "pu-bes-cen-cia",
    "pubescente": "pu-bes-cen-te",
    "pubescer": "pu-bes-cer",
    "pubiana": "pu-bia-na",
    "pubiano": "pu-bia-no",
    "púbico": "pú-bi-co",
    "pubis": "pu-bis",
    "pública": "pú-bli-ca",
    "publicable": "pu-bli-ca-ble",
    "publicación": "pu-bli-ca-ción",
    "publicador": "pu-bli-ca-dor",
    "publicadora": "pu-bli-ca-do-ra",
    "públicamente": "pú-bli-ca-men-te",
    "publicano": "pu-bli-ca-no",
    "publicar": "pu-bli-car",
    "publicata": "pu-bli-ca-ta",
    "publicidad": "pu-bli-ci-dad",
    "publicista": "pu-bli-cis-ta",
    "publicitar": "pu-bli-ci-tar",
    "publicitaria": "pu-bli-ci-ta-ria",
    "publicitario": "pu-bli-ci-ta-rio",
    "público": "pú-bli-co",
    "publificar": "pu-bli-fi-car",
    "publirreportaje": "pu-bli-rre-por-ta-je",
    "pucallpeño": "pu-call-pe-ño",
    "pucallpina": "pu-call-pi-na",
    "pucallpino": "pu-call-pi-no",
    "pucara": "pu-ca-ra",
    "pucará": "pu-ca-rá",
    "pucela": "pu-ce-la",
    "pucelana": "pu-ce-la-na",
    "pucelano": "pu-ce-la-no",
    "pucha": "pu-cha",
    "puchada": "pu-cha-da",
    "puchera": "pu-che-ra",
    "pucherazo": "pu-che-ra-zo",
    "pucherear": "pu-che-re-ar",
    "puchero": "pu-che-ro",
    "puches": "pu-ches",
    "púchica": "pú-chi-ca",
    "puchinela": "pu-chi-ne-la",
    "puchis": "pu-chis",
    "puchito": "pu-chi-to",
    "pucho": "pu-cho",
    "puchuela": "pu-chue-la",
    "puchusca": "pu-chus-ca",
    "puchusco": "pu-chus-co",
    "pucia": "pu-cia",
    "pudding": "pud-ding",
    "pudelación": "pu-de-la-ción",
    "pudelar": "pu-de-lar",
    "pudenda": "pu-den-da",
    "pudendo": "pu-den-do",
    "pudibunda": "pu-di-bun-da",
    "pudibundez": "pu-di-bun-dez",
    "pudibundo": "pu-di-bun-do",
    "púdica": "pú-di-ca",
    "pudicia": "pu-di-cia",
    "pudicicia": "pu-di-ci-cia",
    "púdico": "pú-di-co",
    "pudiente": "pu-dien-te",
    "pudin": "pu-din",
    "pudín": "pu-dín",
    "pudinga": "pu-din-ga",
    "pudio": "pu-dio",
    "pudir": "pu-dir",
    "pudor": "pu-dor",
    "pudorosa": "pu-do-ro-sa",
    "pudoroso": "pu-do-ro-so",
    "pudrición": "pu-dri-ción",
    "pudridero": "pu-dri-de-ro",
    "pudridor": "pu-dri-dor",
    "pudrigorio": "pu-dri-go-rio",
    "pudrimiento": "pu-dri-mien-to",
    "pudrir": "pu-drir",
    "pudu": "pu-du",
    "pudú": "pu-dú",
    "puebla": "pue-bla",
    "pueblada": "pue-bla-da",
    "pueble": "pue-ble",
    "pueblera": "pue-ble-ra",
    "pueblerina": "pue-ble-ri-na",
    "pueblerino": "pue-ble-ri-no",
    "pueblero": "pue-ble-ro",
    "pueblo": "pue-blo",
    "puelche": "puel-che",
    "puente": "puen-te",
    "puentealtina": "puen-te-al-ti-na",
    "puentealtino": "puen-te-al-ti-no",
    "puentear": "puen-te-ar",
    "puentecilla": "puen-te-ci-lla",
    "puenteo": "puen-te-o",
    "puenting": "puen-ting",
    "puerca": "puer-ca",
    "puercada": "puer-ca-da",
    "puercamente": "puer-ca-men-te",
    "puerco": "puer-co",
    "puercoespín": "puer-co-es-pín",
    "puericia": "pue-ri-cia",
    "puericultor": "pue-ri-cul-tor",
    "puericultora": "pue-ri-cul-to-ra",
    "puericultura": "pue-ri-cul-tu-ra",
    "pueril": "pue-ril",
    "puerilidad": "pue-ri-li-dad",
    "puerilmente": "pue-ril-men-te",
    "puérpera": "puér-pe-ra",
    "puerperal": "puer-pe-ral",
    "puerperio": "puer-pe-rio",
    "puerro": "pue-rro",
    "puerta": "puer-ta",
    "puertaventana": "puer-ta-ven-ta-na",
    "puerto": "puer-to",
    "puertoaisenina": "puer-to-ai-se-ni-na",
    "puertoaisenino": "puer-to-ai-se-ni-no",
    "puertobarreña": "puer-to-ba-rre-ña",
    "puertobarreño": "puer-to-ba-rre-ño",
    "puertomontina": "puer-to-mon-ti-na",
    "puertomontino": "puer-to-mon-ti-no",
    "puertoplateña": "puer-to-pla-te-ña",
    "puertoplateño": "puer-to-pla-te-ño",
    "puertorriqueña": "puer-to-rri-que-ña",
    "puertorriqueñismo": "puer-to-rri-que-ñis-mo",
    "puertorriqueño": "puer-to-rri-que-ño",
    "puesta": "pues-ta",
    "puestera": "pues-te-ra",
    "puestero": "pues-te-ro",
    "puesto": "pues-to",
    "pufo": "pu-fo",
    "puga": "pu-ga",
    "púgil": "pú-gil",
    "pugilar": "pu-gi-lar",
    "pugilato": "pu-gi-la-to",
    "pugilismo": "pu-gi-lis-mo",
    "pugilista": "pu-gi-lis-ta",
    "pugilístico": "pu-gi-lís-ti-co",
    "pugna": "pug-na",
    "pugnacidad": "pug-na-ci-dad",
    "pugnante": "pug-nan-te",
    "pugnar": "pug-nar",
    "pugnaz": "pug-naz",
    "puja": "pu-ja",
    "pujador": "pu-ja-dor",
    "pujadora": "pu-ja-do-ra",
    "pujagua": "pu-ja-gua",
    "pujame": "pu-ja-me",
    "pujamen": "pu-ja-men",
    "pujamiento": "pu-ja-mien-to",
    "pujante": "pu-jan-te",
    "pujantemente": "pu-jan-te-men-te",
    "pujanza": "pu-jan-za",
    "pujar": "pu-jar",
    "pujavante": "pu-ja-van-te",
    "pujés": "pu-jés",
    "pujido": "pu-ji-do",
    "pujo": "pu-jo",
    "pularda": "pu-lar-da",
    "pulchinela": "pul-chi-ne-la",
    "pulcra": "pul-cra",
    "pulcritud": "pul-cri-tud",
    "pulcro": "pul-cro",
    "pulento": "pu-len-to",
    "pulga": "pul-ga",
    "pulgada": "pul-ga-da",
    "pulgar": "pul-gar",
    "pulgarada": "pul-ga-ra-da",
    "pulgón": "pul-gón",
    "pulgosa": "pul-go-sa",
    "pulgoso": "pul-go-so",
    "pulguera": "pul-gue-ra",
    "pulgueral": "pul-gue-ral",
    "pulguerío": "pul-gue-rí-o",
    "pulguero": "pul-gue-ro",
    "pulguienta": "pul-guien-ta",
    "pulguiento": "pul-guien-to",
    "pulguillas": "pul-gui-llas",
    "pulicán": "pu-li-cán",
    "pulida": "pu-li-da",
    "pulidamente": "pu-li-da-men-te",
    "pulidero": "pu-li-de-ro",
    "pulidez": "pu-li-dez",
    "pulideza": "pu-li-de-za",
    "pulido": "pu-li-do",
    "pulidor": "pu-li-dor",
    "pulidora": "pu-li-do-ra",
    "pulimentación": "pu-li-men-ta-ción",
    "pulimentar": "pu-li-men-tar",
    "pulimento": "pu-li-men-to",
    "pulique": "pu-li-que",
    "pulir": "pu-lir",
    "pulla": "pu-lla",
    "pullar": "pu-llar",
    "pullazo": "pu-lla-zo",
    "pullés": "pu-llés",
    "pullesa": "pu-lle-sa",
    "pullista": "pu-llis-ta",
    "pulmón": "pul-món",
    "pulmonado": "pul-mo-na-do",
    "pulmonar": "pul-mo-nar",
    "pulmonaria": "pul-mo-na-ria",
    "pulmonía": "pul-mo-ní-a",
    "pulmoníaca": "pul-mo-ní-a-ca",
    "pulmoniaca": "pul-mo-nia-ca",
    "pulmoníaco": "pul-mo-ní-a-co",
    "pulmoniaco": "pul-mo-nia-co",
    "pulóver": "pu-ló-ver",
    "pulpa": "pul-pa",
    "pulpear": "pul-pe-ar",
    "pulpejo": "pul-pe-jo",
    "pulpera": "pul-pe-ra",
    "pulpería": "pul-pe-rí-a",
    "pulpero": "pul-pe-ro",
    "pulpeta": "pul-pe-ta",
    "púlpito": "púl-pi-to",
    "pulpo": "pul-po",
    "pulposa": "pul-po-sa",
    "pulposo": "pul-po-so",
    "pulque": "pul-que",
    "pulquera": "pul-que-ra",
    "pulquería": "pul-que-rí-a",
    "pulquero": "pul-que-ro",
    "pulquérrima": "pul-qué-rri-ma",
    "pulquérrimo": "pul-qué-rri-mo",
    "pulsación": "pul-sa-ción",
    "pulsada": "pul-sa-da",
    "pulsador": "pul-sa-dor",
    "pulsadora": "pul-sa-do-ra",
    "pulsamiento": "pul-sa-mien-to",
    "pulsante": "pul-san-te",
    "pulsar": "pul-sar",
    "pulsátil": "pul-sá-til",
    "pulsatila": "pul-sa-ti-la",
    "pulsativa": "pul-sa-ti-va",
    "pulsativo": "pul-sa-ti-vo",
    "pulseada": "pul-se-a-da",
    "pulsear": "pul-se-ar",
    "pulsera": "pul-se-ra",
    "pulsímetro": "pul-sí-me-tro",
    "pulsión": "pul-sión",
    "pulsional": "pul-sio-nal",
    "pulsista": "pul-sis-ta",
    "pulso": "pul-so",
    "pultácea": "pul-tá-ce-a",
    "pultáceo": "pul-tá-ce-o",
    "pululación": "pu-lu-la-ción",
    "pululante": "pu-lu-lan-te",
    "pulular": "pu-lu-lar",
    "pululo": "pu-lu-lo",
    "pulverizable": "pul-ve-ri-za-ble",
    "pulverización": "pul-ve-ri-za-ción",
    "pulverizador": "pul-ve-ri-za-dor",
    "pulverizar": "pul-ve-ri-zar",
    "pulverulenta": "pul-ve-ru-len-ta",
    "pulverulento": "pul-ve-ru-len-to",
    "puma": "pu-ma",
    "pumarada": "pu-ma-ra-da",
    "pumba": "pum-ba",
    "pumente": "pu-men-te",
    "pumita": "pu-mi-ta",
    "pumpunear": "pum-pu-ne-ar",
    "puna": "pu-na",
    "puñada": "pu-ña-da",
    "puñado": "pu-ña-do",
    "puñal": "pu-ñal",
    "puñalada": "pu-ña-la-da",
    "puñalero": "pu-ña-le-ro",
    "puñales": "pu-ña-les",
    "punar": "pu-nar",
    "puñar": "pu-ñar",
    "punateña": "pu-na-te-ña",
    "punateño": "pu-na-te-ño",
    "puncetear": "pun-ce-te-ar",
    "puncha": "pun-cha",
    "punchar": "pun-char",
    "punción": "pun-ción",
    "puncionar": "pun-cio-nar",
    "pundonor": "pun-do-nor",
    "pundonorosa": "pun-do-no-ro-sa",
    "pundonorosamente": "pun-do-no-ro-sa-men-te",
    "pundonoroso": "pun-do-no-ro-so",
    "puneña": "pu-ne-ña",
    "puneño": "pu-ne-ño",
    "puñera": "pu-ñe-ra",
    "puñeta": "pu-ñe-ta",
    "puñetazo": "pu-ñe-ta-zo",
    "puñete": "pu-ñe-te",
    "puñeteada": "pu-ñe-te-a-da",
    "puñetear": "pu-ñe-te-ar",
    "puñetería": "pu-ñe-te-rí-a",
    "puñetero": "pu-ñe-te-ro",
    "punga": "pun-ga",
    "pungimiento": "pun-gi-mien-to",
    "pungir": "pun-gir",
    "pungitiva": "pun-gi-ti-va",
    "pungitivo": "pun-gi-ti-vo",
    "punguista": "pun-guis-ta",
    "punibilidad": "pu-ni-bi-li-dad",
    "punible": "pu-ni-ble",
    "púnica": "pú-ni-ca",
    "punicácea": "pu-ni-cá-ce-a",
    "punicáceo": "pu-ni-cá-ce-o",
    "punición": "pu-ni-ción",
    "púnico": "pú-ni-co",
    "punidor": "pu-ni-dor",
    "punidora": "pu-ni-do-ra",
    "puñimiento": "pu-ñi-mien-to",
    "punir": "pu-nir",
    "puñir": "pu-ñir",
    "punitiva": "pu-ni-ti-va",
    "punitivo": "pu-ni-ti-vo",
    "punki": "pun-ki",
    "puño": "pu-ño",
    "punta": "pun-ta",
    "puntabolas": "pun-ta-bo-las",
    "puntación": "pun-ta-ción",
    "puntada": "pun-ta-da",
    "puntador": "pun-ta-dor",
    "puntaje": "pun-ta-je",
    "puntal": "pun-tal",
    "puntana": "pun-ta-na",
    "puntano": "pun-ta-no",
    "puntapié": "pun-ta-pié",
    "puntar": "pun-tar",
    "puntarenense": "pun-ta-re-nen-se",
    "puntazo": "pun-ta-zo",
    "punteada": "pun-te-a-da",
    "punteado": "pun-te-a-do",
    "punteador": "pun-te-a-dor",
    "puntear": "pun-te-ar",
    "puntel": "pun-tel",
    "punteo": "pun-te-o",
    "puntera": "pun-te-ra",
    "punterazo": "pun-te-ra-zo",
    "puntería": "pun-te-rí-a",
    "puntero": "pun-te-ro",
    "punterol": "pun-te-rol",
    "punterola": "pun-te-ro-la",
    "puntete": "pun-te-te",
    "puntiaguda": "pun-tia-gu-da",
    "puntiagudo": "pun-tia-gu-do",
    "puntido": "pun-ti-do",
    "puntilla": "pun-ti-lla",
    "puntillado": "pun-ti-lla-do",
    "puntillazo": "pun-ti-lla-zo",
    "puntillero": "pun-ti-lle-ro",
    "puntillismo": "pun-ti-llis-mo",
    "puntillista": "pun-ti-llis-ta",
    "puntillo": "pun-ti-llo",
    "puntillón": "pun-ti-llón",
    "puntillosa": "pun-ti-llo-sa",
    "puntillosidad": "pun-ti-llo-si-dad",
    "puntilloso": "pun-ti-llo-so",
    "puntiseca": "pun-ti-se-ca",
    "puntisecar": "pun-ti-se-car",
    "puntiseco": "pun-ti-se-co",
    "puntizón": "pun-ti-zón",
    "punto": "pun-to",
    "puntosa": "pun-to-sa",
    "puntoso": "pun-to-so",
    "puntuable": "pun-tua-ble",
    "puntuación": "pun-tua-ción",
    "puntual": "pun-tual",
    "puntualidad": "pun-tua-li-dad",
    "puntualización": "pun-tua-li-za-ción",
    "puntualizar": "pun-tua-li-zar",
    "puntualmente": "pun-tual-men-te",
    "puntuar": "pun-tuar",
    "puntudo": "pun-tu-do",
    "puntuosa": "pun-tuo-sa",
    "puntuoso": "pun-tuo-so",
    "puntura": "pun-tu-ra",
    "punzada": "pun-za-da",
    "punzador": "pun-za-dor",
    "punzadora": "pun-za-do-ra",
    "punzadura": "pun-za-du-ra",
    "punzante": "pun-zan-te",
    "punzar": "pun-zar",
    "punzó": "pun-zó",
    "punzón": "pun-zón",
    "punzonería": "pun-zo-ne-rí-a",
    "pupa": "pu-pa",
    "pupal": "pu-pal",
    "pupar": "pu-par",
    "pupila": "pu-pi-la",
    "pupilaje": "pu-pi-la-je",
    "pupilar": "pu-pi-lar",
    "pupilente": "pu-pi-len-te",
    "pupilera": "pu-pi-le-ra",
    "pupilero": "pu-pi-le-ro",
    "pupilo": "pu-pi-lo",
    "pupitre": "pu-pi-tre",
    "pupo": "pu-po",
    "puposa": "pu-po-sa",
    "puposo": "pu-po-so",
    "pupu": "pu-pu",
    "pupusa": "pu-pu-sa",
    "pupusería": "pu-pu-se-rí-a",
    "puquina": "pu-qui-na",
    "puquio": "pu-quio",
    "pura": "pu-ra",
    "puramente": "pu-ra-men-te",
    "purana": "pu-ra-na",
    "purasangre": "pu-ra-san-gre",
    "puré": "pu-ré",
    "purear": "pu-re-ar",
    "purera": "pu-re-ra",
    "pureta": "pu-re-ta",
    "purete": "pu-re-te",
    "pureza": "pu-re-za",
    "purga": "pur-ga",
    "purgable": "pur-ga-ble",
    "purgación": "pur-ga-ción",
    "purgador": "pur-ga-dor",
    "purgadora": "pur-ga-do-ra",
    "purgamiento": "pur-ga-mien-to",
    "purgante": "pur-gan-te",
    "purgar": "pur-gar",
    "purgativa": "pur-ga-ti-va",
    "purgativo": "pur-ga-ti-vo",
    "purgatoria": "pur-ga-to-ria",
    "purgatorio": "pur-ga-to-rio",
    "púrico": "pú-ri-co",
    "puridad": "pu-ri-dad",
    "purificación": "pu-ri-fi-ca-ción",
    "purificadera": "pu-ri-fi-ca-de-ra",
    "purificadero": "pu-ri-fi-ca-de-ro",
    "purificador": "pu-ri-fi-ca-dor",
    "purificadora": "pu-ri-fi-ca-do-ra",
    "purificar": "pu-ri-fi-car",
    "purificatoria": "pu-ri-fi-ca-to-ria",
    "purificatorio": "pu-ri-fi-ca-to-rio",
    "purín": "pu-rín",
    "purina": "pu-ri-na",
    "purisca": "pu-ris-ca",
    "puriscar": "pu-ris-car",
    "purísima": "pu-rí-si-ma",
    "purismo": "pu-ris-mo",
    "purista": "pu-ris-ta",
    "puritana": "pu-ri-ta-na",
    "puritanismo": "pu-ri-ta-nis-mo",
    "puritano": "pu-ri-ta-no",
    "puro": "pu-ro",
    "púrpura": "púr-pu-ra",
    "purpurado": "pur-pu-ra-do",
    "purpurar": "pur-pu-rar",
    "purpúrea": "pur-pú-re-a",
    "purpurear": "pur-pu-re-ar",
    "purpúreo": "pur-pú-re-o",
    "purpurina": "pur-pu-ri-na",
    "purpurino": "pur-pu-ri-no",
    "purraja": "pu-rra-ja",
    "purré": "pu-rré",
    "purrela": "pu-rre-la",
    "purrete": "pu-rre-te",
    "purria": "pu-rria",
    "purriela": "pu-rrie-la",
    "purrir": "pu-rrir",
    "purrusalda": "pu-rru-sal-da",
    "puruhá": "pur-uhá",
    "purulencia": "pu-ru-len-cia",
    "purulenta": "pu-ru-len-ta",
    "purulento": "pu-ru-len-to",
    "pusilánima": "pu-si-lá-ni-ma",
    "pusilánime": "pu-si-lá-ni-me",
    "pusilanimidad": "pu-si-la-ni-mi-dad",
    "pusilánimo": "pu-si-lá-ni-mo",
    "pusinesca": "pu-si-nes-ca",
    "pusinesco": "pu-si-nes-co",
    "puspo": "pus-po",
    "pústula": "pús-tu-la",
    "pustulosa": "pus-tu-lo-sa",
    "pustuloso": "pus-tu-lo-so",
    "puta": "pu-ta",
    "putada": "pu-ta-da",
    "putaísmo": "pu-ta-ís-mo",
    "putal": "pu-tal",
    "putamadral": "pu-ta-ma-dral",
    "putañear": "pu-ta-ñe-ar",
    "putañero": "pu-ta-ñe-ro",
    "putanismo": "pu-ta-nis-mo",
    "putativa": "pu-ta-ti-va",
    "putativo": "pu-ta-ti-vo",
    "puteada": "pu-te-a-da",
    "putear": "pu-te-ar",
    "putería": "pu-te-rí-a",
    "puterío": "pu-te-rí-o",
    "putero": "pu-te-ro",
    "putesca": "pu-tes-ca",
    "putesco": "pu-tes-co",
    "putiferio": "pu-ti-fe-rio",
    "putiza": "pu-ti-za",
    "puto": "pu-to",
    "putón": "pu-tón",
    "putrefacción": "pu-tre-fac-ción",
    "putrefacta": "pu-tre-fac-ta",
    "putrefactiva": "pu-tre-fac-ti-va",
    "putrefactivo": "pu-tre-fac-ti-vo",
    "putrefacto": "pu-tre-fac-to",
    "putreña": "pu-tre-ña",
    "putreño": "pu-tre-ño",
    "putrescencia": "pu-tres-cen-cia",
    "putrescente": "pu-tres-cen-te",
    "putrescible": "pu-tres-ci-ble",
    "pútrida": "pú-tri-da",
    "putridez": "pu-tri-dez",
    "pútrido": "pú-tri-do",
    "putrílago": "pu-trí-la-go",
    "putumayense": "pu-tu-ma-yen-se",
    "pututo": "pu-tu-to",
    "pututu": "pu-tu-tu",
    "puya": "pu-ya",
    "puyado": "pu-ya-do",
    "puyar": "pu-yar",
    "puyazo": "pu-ya-zo",
    "puyo": "pu-yo",
    "puyón": "pu-yón",
    "puyudo": "pu-yu-do",
    "puzle": "puz-le",
    "puzol": "pu-zol",
    "puzolana": "pu-zo-la-na",
    "puzzle": "puzz-le",
    "qatarí": "qa-ta-rí",
    "quada": "qua-da",
    "quado": "qua-do",
    "quadrívium": "qua-drí-vium",
    "quagga": "quag-ga",
    "quásar": "quá-sar",
    "quáter": "quá-ter",
    "quattrocento": "quat-tro-cen-to",
    "quebequense": "que-be-quen-se",
    "quebequés": "que-be-qués",
    "quebequesa": "que-be-que-sa",
    "quebrachal": "que-bra-chal",
    "quebracho": "que-bra-cho",
    "quebrada": "que-bra-da",
    "quebradero": "que-bra-de-ro",
    "quebradillo": "que-bra-di-llo",
    "quebradiza": "que-bra-di-za",
    "quebradizo": "que-bra-di-zo",
    "quebrado": "que-bra-do",
    "quebrador": "que-bra-dor",
    "quebradora": "que-bra-do-ra",
    "quebradura": "que-bra-du-ra",
    "quebraja": "que-bra-ja",
    "quebrajar": "que-bra-jar",
    "quebrajeado": "que-bra-je-a-do",
    "quebrajosa": "que-bra-jo-sa",
    "quebrajoso": "que-bra-jo-so",
    "quebramiento": "que-bra-mien-to",
    "quebrancina": "que-bran-ci-na",
    "quebrandoso": "que-bran-do-so",
    "quebrantable": "que-bran-ta-ble",
    "quebrantada": "que-bran-ta-da",
    "quebrantado": "que-bran-ta-do",
    "quebrantador": "que-bran-ta-dor",
    "quebrantadora": "que-bran-ta-do-ra",
    "quebrantadura": "que-bran-ta-du-ra",
    "quebrantahuesos": "que-bran-ta-hue-sos",
    "quebrantamiento": "que-bran-ta-mien-to",
    "quebrantaolas": "que-bran-ta-o-las",
    "quebrantapiedras": "que-bran-ta-pie-dras",
    "quebrantar": "que-bran-tar",
    "quebranto": "que-bran-to",
    "quebrar": "que-brar",
    "quebraza": "que-bra-za",
    "quebrazar": "que-bra-zar",
    "quebrazón": "que-bra-zón",
    "queche": "que-che",
    "quechemarín": "que-che-ma-rín",
    "quechol": "que-chol",
    "quechua": "que-chua",
    "quechuismo": "que-chuis-mo",
    "queco": "que-co",
    "queda": "que-da",
    "quedada": "que-da-da",
    "quedadizo": "que-da-di-zo",
    "quedado": "que-da-do",
    "quedamente": "que-da-men-te",
    "quedamiento": "que-da-mien-to",
    "quedar": "que-dar",
    "quedito": "que-di-to",
    "quedo": "que-do",
    "quedó": "que-dó",
    "quedón": "que-dón",
    "quedona": "que-do-na",
    "quegua": "que-gua",
    "quehacer": "que-ha-cer",
    "queimada": "quei-ma-da",
    "queísmo": "que-ís-mo",
    "queja": "que-ja",
    "quejada": "que-ja-da",
    "quejar": "que-jar",
    "quejica": "que-ji-ca",
    "quejicosa": "que-ji-co-sa",
    "quejicoso": "que-ji-co-so",
    "quejido": "que-ji-do",
    "quejigal": "que-ji-gal",
    "quejigar": "que-ji-gar",
    "quejigo": "que-ji-go",
    "quejigueta": "que-ji-gue-ta",
    "quejillosa": "que-ji-llo-sa",
    "quejilloso": "que-ji-llo-so",
    "quejo": "que-jo",
    "quejosa": "que-jo-sa",
    "quejosamente": "que-jo-sa-men-te",
    "quejoso": "que-jo-so",
    "quejumbrar": "que-jum-brar",
    "quejumbre": "que-jum-bre",
    "quejumbrosa": "que-jum-bro-sa",
    "quejumbroso": "que-jum-bro-so",
    "quejura": "que-ju-ra",
    "quekchí": "quek-chí",
    "quela": "que-la",
    "quelachina": "que-la-chi-na",
    "queldón": "quel-dón",
    "quelenquelén": "que-len-que-lén",
    "queli": "que-li",
    "quelicerado": "que-li-ce-ra-do",
    "quelícero": "que-lí-ce-ro",
    "quelital": "que-li-tal",
    "quelite": "que-li-te",
    "quelitera": "que-li-te-ra",
    "quelmahue": "quel-ma-hue",
    "quelonio": "que-lo-nio",
    "queltehue": "quel-te-hue",
    "queltro": "quel-tro",
    "quema": "que-ma",
    "quemacocos": "que-ma-co-cos",
    "quemada": "que-ma-da",
    "quemadera": "que-ma-de-ra",
    "quemadero": "que-ma-de-ro",
    "quemado": "que-ma-do",
    "quemador": "que-ma-dor",
    "quemadora": "que-ma-do-ra",
    "quemados": "que-ma-dos",
    "quemadura": "que-ma-du-ra",
    "quemajosa": "que-ma-jo-sa",
    "quemajoso": "que-ma-jo-so",
    "quemamiento": "que-ma-mien-to",
    "quemante": "que-man-te",
    "quemar": "que-mar",
    "quemarropa": "que-ma-rro-pa",
    "quemazón": "que-ma-zón",
    "quemazosa": "que-ma-zo-sa",
    "quemazoso": "que-ma-zo-so",
    "quemeimportismo": "que-meim-por-tis-mo",
    "quemí": "que-mí",
    "quemo": "que-mo",
    "quemón": "que-món",
    "quena": "que-na",
    "quendi": "quen-di",
    "quenopodiácea": "que-no-po-diá-ce-a",
    "quenopodiáceo": "que-no-po-diá-ce-o",
    "queo": "que-o",
    "quepí": "que-pí",
    "quepis": "que-pis",
    "queque": "que-que",
    "quequeo": "que-que-o",
    "quequier": "que-quier",
    "quequisque": "que-quis-que",
    "quera": "que-ra",
    "querandí": "que-ran-dí",
    "queratina": "que-ra-ti-na",
    "queratitis": "que-ra-ti-tis",
    "queratosis": "que-ra-to-sis",
    "queratotomía": "que-ra-to-to-mí-a",
    "querella": "que-re-lla",
    "querellada": "que-re-lla-da",
    "querellado": "que-re-lla-do",
    "querellador": "que-re-lla-dor",
    "querelladora": "que-re-lla-do-ra",
    "querellante": "que-re-llan-te",
    "querellar": "que-re-llar",
    "querellarse": "que-re-llar-se",
    "querellosa": "que-re-llo-sa",
    "querellosamente": "que-re-llo-sa-men-te",
    "querelloso": "que-re-llo-so",
    "quereme": "que-re-me",
    "querencia": "que-ren-cia",
    "querenciosa": "que-ren-cio-sa",
    "querencioso": "que-ren-cio-so",
    "querendón": "que-ren-dón",
    "querendona": "que-ren-do-na",
    "querequeté": "que-re-que-té",
    "querer": "que-rer",
    "queresa": "que-re-sa",
    "queretana": "que-re-ta-na",
    "queretano": "que-re-ta-no",
    "querida": "que-ri-da",
    "querido": "que-ri-do",
    "querindanga": "que-rin-dan-ga",
    "querindango": "que-rin-dan-go",
    "querindonga": "que-rin-don-ga",
    "querindongo": "que-rin-don-go",
    "quermes": "quer-mes",
    "quermés": "quer-més",
    "quero": "que-ro",
    "querocha": "que-ro-cha",
    "querochar": "que-ro-char",
    "querosén": "que-ro-sén",
    "querosene": "que-ro-se-ne",
    "queroseno": "que-ro-se-no",
    "querosín": "que-ro-sín",
    "querque": "quer-que",
    "querrequerre": "que-rre-que-rre",
    "quersoneso": "quer-so-ne-so",
    "querub": "que-rub",
    "querube": "que-ru-be",
    "querúbica": "que-rú-bi-ca",
    "querúbico": "que-rú-bi-co",
    "querubín": "que-ru-bín",
    "querusca": "que-rus-ca",
    "querusco": "que-rus-co",
    "querva": "quer-va",
    "quesada": "que-sa-da",
    "quesadilla": "que-sa-di-lla",
    "quesear": "que-se-ar",
    "quesera": "que-se-ra",
    "quesería": "que-se-rí-a",
    "quesero": "que-se-ro",
    "quesillo": "que-si-llo",
    "quesiqués": "que-si-qués",
    "quesito": "que-si-to",
    "queso": "que-so",
    "quesuismo": "que-suis-mo",
    "queta": "que-ta",
    "quetro": "que-tro",
    "quetzal": "quet-zal",
    "quetzalteca": "quet-zal-te-ca",
    "quetzalteco": "quet-zal-te-co",
    "queule": "queu-le",
    "quevedesca": "que-ve-des-ca",
    "quevedesco": "que-ve-des-co",
    "quevedos": "que-ve-dos",
    "quía": "quí-a",
    "quiaca": "quia-ca",
    "quianti": "quian-ti",
    "quiasma": "quias-ma",
    "quiasmo": "quias-mo",
    "quibdoana": "quib-do-a-na",
    "quibdoano": "quib-do-a-no",
    "quibey": "qui-bey",
    "quibla": "qui-bla",
    "quica": "qui-ca",
    "quiche": "qui-che",
    "quiché": "qui-ché",
    "quichelense": "qui-che-len-se",
    "quichua": "qui-chua",
    "quichuismo": "qui-chuis-mo",
    "quichuista": "qui-chuis-ta",
    "quicial": "qui-cial",
    "quicialera": "qui-cia-le-ra",
    "quicio": "qui-cio",
    "quico": "qui-co",
    "quídam": "quí-dam",
    "quiebra": "quie-bra",
    "quiebrabarriga": "quie-bra-ba-rri-ga",
    "quiebracajete": "quie-bra-ca-je-te",
    "quiebrahacha": "quie-bra-ha-cha",
    "quiebramuelas": "quie-bra-mue-las",
    "quiebraojo": "quie-bra-o-jo",
    "quiebrapatas": "quie-bra-pa-tas",
    "quiebraplata": "quie-bra-pla-ta",
    "quiebre": "quie-bre",
    "quiebro": "quie-bro",
    "quienesquiera": "quie-nes-quie-ra",
    "quienquier": "quien-quier",
    "quienquiera": "quien-quie-ra",
    "quienquita": "quien-qui-ta",
    "quiescencia": "quies-cen-cia",
    "quiescente": "quies-cen-te",
    "quieta": "quie-ta",
    "quietación": "quie-ta-ción",
    "quietador": "quie-ta-dor",
    "quietadora": "quie-ta-do-ra",
    "quietamente": "quie-ta-men-te",
    "quietar": "quie-tar",
    "quiete": "quie-te",
    "quietismo": "quie-tis-mo",
    "quietista": "quie-tis-ta",
    "quieto": "quie-to",
    "quietud": "quie-tud",
    "quihuicha": "qui-hui-cha",
    "quijada": "qui-ja-da",
    "quijal": "qui-jal",
    "quijar": "qui-jar",
    "quijaruda": "qui-ja-ru-da",
    "quijarudo": "qui-ja-ru-do",
    "quijera": "qui-je-ra",
    "quijero": "qui-je-ro",
    "quijinicuil": "qui-ji-ni-cuil",
    "quijo": "qui-jo",
    "quijones": "qui-jo-nes",
    "quijongo": "qui-jon-go",
    "quijotada": "qui-jo-ta-da",
    "quijote": "qui-jo-te",
    "quijotería": "qui-jo-te-rí-a",
    "quijotesa": "qui-jo-te-sa",
    "quijotesca": "qui-jo-tes-ca",
    "quijotescamente": "qui-jo-tes-ca-men-te",
    "quijotesco": "qui-jo-tes-co",
    "quijotil": "qui-jo-til",
    "quijotismo": "qui-jo-tis-mo",
    "quila": "qui-la",
    "quilar": "qui-lar",
    "quilatador": "qui-la-ta-dor",
    "quilatar": "qui-la-tar",
    "quilate": "qui-la-te",
    "quilatera": "qui-la-te-ra",
    "quilco": "quil-co",
    "quilde": "quil-de",
    "quildear": "quil-de-ar",
    "quilete": "qui-le-te",
    "quili": "qui-li",
    "quiliárea": "qui-liá-re-a",
    "quilico": "qui-li-co",
    "quilífera": "qui-lí-fe-ra",
    "quilífero": "qui-lí-fe-ro",
    "quilificación": "qui-li-fi-ca-ción",
    "quilificar": "qui-li-fi-car",
    "quilla": "qui-lla",
    "quillacolleña": "qui-lla-co-lle-ña",
    "quillacolleño": "qui-lla-co-lle-ño",
    "quillango": "qui-llan-go",
    "quillay": "qui-llay",
    "quillotana": "qui-llo-ta-na",
    "quillotano": "qui-llo-ta-no",
    "quillotra": "qui-llo-tra",
    "quillotrador": "qui-llo-tra-dor",
    "quillotradora": "qui-llo-tra-do-ra",
    "quillotranza": "qui-llo-tran-za",
    "quillotrar": "qui-llo-trar",
    "quillotro": "qui-llo-tro",
    "quilma": "quil-ma",
    "quilmay": "quil-may",
    "quilo": "qui-lo",
    "quilográmetro": "qui-lo-grá-me-tro",
    "quilogramo": "qui-lo-gra-mo",
    "quilolitro": "qui-lo-li-tro",
    "quilombear": "qui-lom-be-ar",
    "quilombera": "qui-lom-be-ra",
    "quilombero": "qui-lom-be-ro",
    "quilombo": "qui-lom-bo",
    "quilométrica": "qui-lo-mé-tri-ca",
    "quilométrico": "qui-lo-mé-tri-co",
    "quilómetro": "qui-ló-me-tro",
    "quilópodo": "qui-ló-po-do",
    "quilosa": "qui-lo-sa",
    "quiloso": "qui-lo-so",
    "quilquil": "quil-quil",
    "quiltonil": "quil-to-nil",
    "quiltra": "quil-tra",
    "quiltro": "quil-tro",
    "quima": "qui-ma",
    "quimba": "quim-ba",
    "quimbalete": "quim-ba-le-te",
    "quimbambas": "quim-bam-bas",
    "quimbo": "quim-bo",
    "quimbombó": "quim-bom-bó",
    "quimera": "qui-me-ra",
    "quimerear": "qui-me-re-ar",
    "quimérica": "qui-mé-ri-ca",
    "quimérico": "qui-mé-ri-co",
    "quimerina": "qui-me-ri-na",
    "quimerino": "qui-me-ri-no",
    "quimerista": "qui-me-ris-ta",
    "quimerizar": "qui-me-ri-zar",
    "química": "quí-mi-ca",
    "químicamente": "quí-mi-ca-men-te",
    "químico": "quí-mi-co",
    "quimificación": "qui-mi-fi-ca-ción",
    "quimificar": "qui-mi-fi-car",
    "quimio": "qui-mio",
    "quimioluminiscencia": "qui-mio-lu-mi-nis-cen-cia",
    "quimioprofiláctico": "qui-mio-pro-fi-lác-ti-co",
    "quimiorreceptor": "qui-mio-rre-cep-tor",
    "quimiotaxia": "qui-mio-ta-xia",
    "quimioterapia": "qui-mio-te-ra-pia",
    "quimo": "qui-mo",
    "quimón": "qui-món",
    "quimono": "qui-mo-no",
    "quimosina": "qui-mo-si-na",
    "quina": "qui-na",
    "quinacha": "qui-na-cha",
    "quinada": "qui-na-da",
    "quinado": "qui-na-do",
    "quinal": "qui-nal",
    "quinao": "qui-na-o",
    "quinaquina": "qui-na-qui-na",
    "quiñar": "qui-ñar",
    "quinario": "qui-na-rio",
    "quiñazo": "qui-ña-zo",
    "quincalla": "quin-ca-lla",
    "quincallera": "quin-ca-lle-ra",
    "quincallería": "quin-ca-lle-rí-a",
    "quincallero": "quin-ca-lle-ro",
    "quince": "quin-ce",
    "quinceañera": "quin-ce-a-ñe-ra",
    "quinceañero": "quin-ce-a-ñe-ro",
    "quinceavo": "quin-ce-a-vo",
    "quincena": "quin-ce-na",
    "quincenal": "quin-ce-nal",
    "quincenalmente": "quin-ce-nal-men-te",
    "quincenaria": "quin-ce-na-ria",
    "quincenario": "quin-ce-na-rio",
    "quinceno": "quin-ce-no",
    "quincha": "quin-cha",
    "quinchada": "quin-cha-da",
    "quinchado": "quin-cha-do",
    "quinchamalí": "quin-cha-ma-lí",
    "quinchar": "quin-char",
    "quinchihue": "quin-chi-hue",
    "quincho": "quin-cho",
    "quinchoncho": "quin-chon-cho",
    "quincineta": "quin-ci-ne-ta",
    "quincuagena": "quin-cua-ge-na",
    "quincuagenaria": "quin-cua-ge-na-ria",
    "quincuagenario": "quin-cua-ge-na-rio",
    "quincuagésima": "quin-cua-gé-si-ma",
    "quincuagésimo": "quin-cua-gé-si-mo",
    "quincunce": "quin-cun-ce",
    "quincuncial": "quin-cun-cial",
    "quinde": "quin-de",
    "quindécima": "quin-dé-ci-ma",
    "quindécimo": "quin-dé-ci-mo",
    "quindenial": "quin-de-nial",
    "quindenio": "quin-de-nio",
    "quindiano": "quin-dia-no",
    "quinésica": "qui-né-si-ca",
    "quinésico": "qui-né-si-co",
    "quinesióloga": "qui-ne-sió-lo-ga",
    "quinesiología": "qui-ne-sio-lo-gí-a",
    "quinesiológico": "qui-ne-sio-ló-gi-co",
    "quinesiólogo": "qui-ne-sió-lo-go",
    "quinesioterapia": "qui-ne-sio-te-ra-pia",
    "quinesioterápico": "qui-ne-sio-te-rá-pi-co",
    "quinesiterapia": "qui-ne-si-te-ra-pia",
    "quinete": "qui-ne-te",
    "quinfa": "quin-fa",
    "quingentésima": "quin-gen-té-si-ma",
    "quingentésimo": "quin-gen-té-si-mo",
    "quingo": "quin-go",
    "quingombó": "quin-gom-bó",
    "quinicho": "qui-ni-cho",
    "quiniela": "qui-nie-la",
    "quinielera": "qui-nie-le-ra",
    "quinielero": "qui-nie-le-ro",
    "quinielista": "qui-nie-lis-ta",
    "quinielístico": "qui-nie-lís-ti-co",
    "quinientas": "qui-nien-tas",
    "quinientista": "qui-nien-tis-ta",
    "quinientos": "qui-nien-tos",
    "quinina": "qui-ni-na",
    "quinismo": "qui-nis-mo",
    "quino": "qui-no",
    "quiño": "qui-ño",
    "quínoa": "quí-no-a",
    "quínola": "quí-no-la",
    "quinolear": "qui-no-le-ar",
    "quinolillas": "qui-no-li-llas",
    "quiñón": "qui-ñón",
    "quiñonero": "qui-ño-ne-ro",
    "quinoto": "qui-no-to",
    "quinqué": "quin-qué",
    "quinquefolio": "quin-que-fo-lio",
    "quinquelingüe": "quin-que-lin-güe",
    "quinquenal": "quin-que-nal",
    "quinquenervia": "quin-que-ner-via",
    "quinquenio": "quin-que-nio",
    "quinqui": "quin-qui",
    "quinquies": "quin-quies",
    "quinquillería": "quin-qui-lle-rí-a",
    "quinquillero": "quin-qui-lle-ro",
    "quinquina": "quin-qui-na",
    "quinta": "quin-ta",
    "quintacolumnista": "quin-ta-co-lum-nis-ta",
    "quintada": "quin-ta-da",
    "quintador": "quin-ta-dor",
    "quintadora": "quin-ta-do-ra",
    "quintaesencia": "quin-ta-e-sen-cia",
    "quintaesenciar": "quin-ta-e-sen-ciar",
    "quintal": "quin-tal",
    "quintalada": "quin-ta-la-da",
    "quintaleña": "quin-ta-le-ña",
    "quintaleño": "quin-ta-le-ño",
    "quintalera": "quin-ta-le-ra",
    "quintalero": "quin-ta-le-ro",
    "quintana": "quin-ta-na",
    "quintanarroense": "quin-ta-na-rro-en-se",
    "quintañón": "quin-ta-ñón",
    "quintañona": "quin-ta-ño-na",
    "quintante": "quin-tan-te",
    "quintar": "quin-tar",
    "quintería": "quin-te-rí-a",
    "quinterna": "quin-ter-na",
    "quinterno": "quin-ter-no",
    "quintero": "quin-te-ro",
    "quinteto": "quin-te-to",
    "quintil": "quin-til",
    "quintilla": "quin-ti-lla",
    "quintilliza": "quin-ti-lli-za",
    "quintillizo": "quin-ti-lli-zo",
    "quintillo": "quin-ti-llo",
    "quintín": "quin-tín",
    "quinto": "quin-to",
    "quintonil": "quin-to-nil",
    "quintral": "quin-tral",
    "quíntupla": "quín-tu-pla",
    "quíntuple": "quín-tu-ple",
    "quintuplicación": "quin-tu-pli-ca-ción",
    "quintuplicar": "quin-tu-pli-car",
    "quíntuplo": "quín-tu-plo",
    "quinua": "qui-nua",
    "quinuza": "qui-nu-za",
    "quinzal": "quin-zal",
    "quinzava": "quin-za-va",
    "quinzavo": "quin-za-vo",
    "quío": "quí-o",
    "quiosco": "quios-co",
    "quiosquera": "quios-que-ra",
    "quiosquero": "quios-que-ro",
    "quiote": "quio-te",
    "quipe": "qui-pe",
    "quipu": "qui-pu",
    "quique": "qui-que",
    "quiqui": "qui-qui",
    "quiquiriquí": "qui-qui-ri-quí",
    "quiquisque": "qui-quis-que",
    "quiragra": "qui-ra-gra",
    "quirate": "qui-ra-te",
    "quirguiz": "quir-guiz",
    "quirico": "qui-ri-co",
    "quiridio": "qui-ri-dio",
    "quirie": "qui-rie",
    "quirigalla": "qui-ri-ga-lla",
    "quirina": "qui-ri-na",
    "quirinal": "qui-ri-nal",
    "quirinca": "qui-rin-ca",
    "quiritaria": "qui-ri-ta-ria",
    "quiritario": "qui-ri-ta-rio",
    "quirite": "qui-ri-te",
    "quirófano": "qui-ró-fa-no",
    "quirógrafa": "qui-ró-gra-fa",
    "quirografaria": "qui-ro-gra-fa-ria",
    "quirografario": "qui-ro-gra-fa-rio",
    "quirógrafo": "qui-ró-gra-fo",
    "quiromancía": "qui-ro-man-cí-a",
    "quiromancia": "qui-ro-man-cia",
    "quiromante": "qui-ro-man-te",
    "quiromántica": "qui-ro-mán-ti-ca",
    "quiromántico": "qui-ro-mán-ti-co",
    "quiromasaje": "qui-ro-ma-sa-je",
    "quiromasajista": "qui-ro-ma-sa-jis-ta",
    "quiropráctica": "qui-ro-prác-ti-ca",
    "quiropráctico": "qui-ro-prác-ti-co",
    "quiróptero": "qui-róp-te-ro",
    "quiroteca": "qui-ro-te-ca",
    "quirquincho": "quir-quin-cho",
    "quirúrgica": "qui-rúr-gi-ca",
    "quirúrgico": "qui-rúr-gi-co",
    "quirurgo": "qui-rur-go",
    "quisa": "qui-sa",
    "quísame": "quí-sa-me",
    "quisca": "quis-ca",
    "quiscamote": "quis-ca-mo-te",
    "quisco": "quis-co",
    "quiscudo": "quis-cu-do",
    "quisicosa": "qui-si-co-sa",
    "quisnear": "quis-ne-ar",
    "quisneto": "quis-ne-to",
    "quisquilla": "quis-qui-lla",
    "quisquillosa": "quis-qui-llo-sa",
    "quisquillosidad": "quis-qui-llo-si-dad",
    "quisquilloso": "quis-qui-llo-so",
    "quista": "quis-ta",
    "quistar": "quis-tar",
    "quistarse": "quis-tar-se",
    "quiste": "quis-te",
    "quístico": "quís-ti-co",
    "quistión": "quis-tión",
    "quisto": "quis-to",
    "quita": "qui-ta",
    "quitacalzón": "qui-ta-cal-zón",
    "quitación": "qui-ta-ción",
    "quitada": "qui-ta-da",
    "quitado": "qui-ta-do",
    "quitador": "qui-ta-dor",
    "quitadora": "qui-ta-do-ra",
    "quitaesmalte": "qui-ta-es-mal-te",
    "quitaguas": "qui-ta-guas",
    "quitagustos": "qui-ta-gus-tos",
    "quitaipón": "qui-tai-pón",
    "quitalodo": "qui-ta-lo-do",
    "quitamanchas": "qui-ta-man-chas",
    "quitamente": "qui-ta-men-te",
    "quitameriendas": "qui-ta-me-rien-das",
    "quitamiedos": "qui-ta-mie-dos",
    "quitamiento": "qui-ta-mien-to",
    "quitamotas": "qui-ta-mo-tas",
    "quitanieves": "qui-ta-nie-ves",
    "quitanza": "qui-tan-za",
    "quitapelillos": "qui-ta-pe-li-llos",
    "quitapenas": "qui-ta-pe-nas",
    "quitapesares": "qui-ta-pe-sa-res",
    "quitapiedras": "qui-ta-pie-dras",
    "quitapón": "qui-ta-pón",
    "quitar": "qui-tar",
    "quitasol": "qui-ta-sol",
    "quitasolillo": "qui-ta-so-li-llo",
    "quitasueño": "qui-ta-sue-ño",
    "quite": "qui-te",
    "quiteña": "qui-te-ña",
    "quiteño": "qui-te-ño",
    "quitilipi": "qui-ti-li-pi",
    "quitina": "qui-ti-na",
    "quitinosa": "qui-ti-no-sa",
    "quitinoso": "qui-ti-no-so",
    "quito": "qui-to",
    "quitón": "qui-tón",
    "quitrín": "qui-trín",
    "quitu": "qui-tu",
    "quiubra": "quiu-bra",
    "quiupi": "quiu-pi",
    "quivi": "qui-vi",
    "quiyaya": "qui-ya-ya",
    "quizá": "qui-zá",
    "quizarrá": "qui-za-rrá",
    "quizás": "qui-zás",
    "quizcuate": "quiz-cua-te",
    "quórum": "quó-rum",
    "raba": "ra-ba",
    "rabada": "ra-ba-da",
    "rabadán": "ra-ba-dán",
    "rabadilla": "ra-ba-di-lla",
    "rabal": "ra-bal",
    "rabalaje": "ra-ba-la-je",
    "rabalera": "ra-ba-le-ra",
    "rabalero": "ra-ba-le-ro",
    "rabanal": "ra-ba-nal",
    "rabanera": "ra-ba-ne-ra",
    "rabanero": "ra-ba-ne-ro",
    "rabanillo": "ra-ba-ni-llo",
    "rabaniza": "ra-ba-ni-za",
    "rábano": "rá-ba-no",
    "rabárbaro": "ra-bár-ba-ro",
    "rabasaire": "ra-ba-sai-re",
    "rabazuz": "ra-ba-zuz",
    "rabdomancia": "rab-do-man-cia",
    "rabdomante": "rab-do-man-te",
    "rabear": "ra-be-ar",
    "rabel": "ra-bel",
    "rabelera": "ra-be-le-ra",
    "rabelero": "ra-be-le-ro",
    "rabelista": "ra-be-lis-ta",
    "rabeo": "ra-be-o",
    "rabera": "ra-be-ra",
    "raberón": "ra-be-rón",
    "rabí": "ra-bí",
    "rabia": "ra-bia",
    "rabiacana": "ra-bia-ca-na",
    "rabiada": "ra-bia-da",
    "rabiadero": "ra-bia-de-ro",
    "rabiar": "ra-biar",
    "rabiatar": "ra-bia-tar",
    "rabiazorras": "ra-bia-zo-rras",
    "rábica": "rá-bi-ca",
    "rabicán": "ra-bi-cán",
    "rabicana": "ra-bi-ca-na",
    "rabicano": "ra-bi-ca-no",
    "rábico": "rá-bi-co",
    "rabicorta": "ra-bi-cor-ta",
    "rabicorto": "ra-bi-cor-to",
    "rábida": "rá-bi-da",
    "rábido": "rá-bi-do",
    "rabieta": "ra-bie-ta",
    "rabihorcado": "ra-bihor-ca-do",
    "rabijunco": "ra-bi-jun-co",
    "rabil": "ra-bil",
    "rabilar": "ra-bi-lar",
    "rabilarga": "ra-bi-lar-ga",
    "rabilargo": "ra-bi-lar-go",
    "rabillo": "ra-bi-llo",
    "rabínica": "ra-bí-ni-ca",
    "rabínico": "ra-bí-ni-co",
    "rabinismo": "ra-bi-nis-mo",
    "rabinista": "ra-bi-nis-ta",
    "rabino": "ra-bi-no",
    "rabión": "ra-bión",
    "rabiosa": "ra-bio-sa",
    "rabiosamente": "ra-bio-sa-men-te",
    "rabioso": "ra-bio-so",
    "rabipelado": "ra-bi-pe-la-do",
    "rabirrubia": "ra-bi-rru-bia",
    "rabisalsera": "ra-bi-sal-se-ra",
    "rábita": "rá-bi-ta",
    "rabiza": "ra-bi-za",
    "rabo": "ra-bo",
    "raboamarillo": "ra-bo-a-ma-ri-llo",
    "rabón": "ra-bón",
    "rabona": "ra-bo-na",
    "rabonear": "ra-bo-ne-ar",
    "rabopelado": "ra-bo-pe-la-do",
    "rabosa": "ra-bo-sa",
    "raboseada": "ra-bo-se-a-da",
    "raboseado": "ra-bo-se-a-do",
    "raboseadura": "ra-bo-se-a-du-ra",
    "rabosear": "ra-bo-se-ar",
    "raboso": "ra-bo-so",
    "rabotada": "ra-bo-ta-da",
    "rabotazo": "ra-bo-ta-zo",
    "rabotear": "ra-bo-te-ar",
    "raboteo": "ra-bo-te-o",
    "rabuda": "ra-bu-da",
    "rabudo": "ra-bu-do",
    "rábula": "rá-bu-la",
    "racamenta": "ra-ca-men-ta",
    "racamento": "ra-ca-men-to",
    "rácana": "rá-ca-na",
    "racanear": "ra-ca-ne-ar",
    "racaneo": "ra-ca-ne-o",
    "racanería": "ra-ca-ne-rí-a",
    "rácano": "rá-ca-no",
    "racear": "ra-ce-ar",
    "racel": "ra-cel",
    "racero": "ra-ce-ro",
    "racha": "ra-cha",
    "rachar": "ra-char",
    "racheado": "ra-che-a-do",
    "rachear": "ra-che-ar",
    "racial": "ra-cial",
    "racima": "ra-ci-ma",
    "racimada": "ra-ci-ma-da",
    "racimado": "ra-ci-ma-do",
    "racimal": "ra-ci-mal",
    "racimar": "ra-ci-mar",
    "racimo": "ra-ci-mo",
    "racimosa": "ra-ci-mo-sa",
    "racimoso": "ra-ci-mo-so",
    "racimuda": "ra-ci-mu-da",
    "racimudo": "ra-ci-mu-do",
    "raciocinación": "ra-cio-ci-na-ción",
    "raciocinar": "ra-cio-ci-nar",
    "raciocinio": "ra-cio-ci-nio",
    "ración": "ra-ción",
    "racionabilidad": "ra-cio-na-bi-li-dad",
    "racionado": "ra-cio-na-do",
    "racional": "ra-cio-nal",
    "racionalidad": "ra-cio-na-li-dad",
    "racionalismo": "ra-cio-na-lis-mo",
    "racionalista": "ra-cio-na-lis-ta",
    "racionalización": "ra-cio-na-li-za-ción",
    "racionalizar": "ra-cio-na-li-zar",
    "racionalmente": "ra-cio-nal-men-te",
    "racionamiento": "ra-cio-na-mien-to",
    "racionar": "ra-cio-nar",
    "racionero": "ra-cio-ne-ro",
    "racionista": "ra-cio-nis-ta",
    "raciovitalismo": "ra-cio-vi-ta-lis-mo",
    "racismo": "ra-cis-mo",
    "racista": "ra-cis-ta",
    "raco": "ra-co",
    "racor": "ra-cor",
    "rada": "ra-da",
    "radal": "ra-dal",
    "radar": "ra-dar",
    "radarista": "ra-da-ris-ta",
    "radiación": "ra-dia-ción",
    "radiactiva": "ra-diac-ti-va",
    "radiactividad": "ra-diac-ti-vi-dad",
    "radiactivo": "ra-diac-ti-vo",
    "radiada": "ra-dia-da",
    "radiado": "ra-dia-do",
    "radiador": "ra-dia-dor",
    "radial": "ra-dial",
    "radián": "ra-dián",
    "radiante": "ra-dian-te",
    "radiar": "ra-diar",
    "radiata": "ra-dia-ta",
    "radicación": "ra-di-ca-ción",
    "radicado": "ra-di-ca-do",
    "radical": "ra-di-cal",
    "radicalidad": "ra-di-ca-li-dad",
    "radicalismo": "ra-di-ca-lis-mo",
    "radicalización": "ra-di-ca-li-za-ción",
    "radicalizar": "ra-di-ca-li-zar",
    "radicalmente": "ra-di-cal-men-te",
    "radicando": "ra-di-can-do",
    "radicar": "ra-di-car",
    "radicícola": "ra-di-cí-co-la",
    "radicosa": "ra-di-co-sa",
    "radicoso": "ra-di-co-so",
    "radícula": "ra-dí-cu-la",
    "radicular": "ra-di-cu-lar",
    "radiculitis": "ra-di-cu-li-tis",
    "radiestesia": "ra-dies-te-sia",
    "radiestesista": "ra-dies-te-sis-ta",
    "radio": "ra-dio",
    "radioactividad": "ra-dio-ac-ti-vi-dad",
    "radioactivo": "ra-dio-ac-ti-vo",
    "radioaficionada": "ra-dio-a-fi-cio-na-da",
    "radioaficionado": "ra-dio-a-fi-cio-na-do",
    "radioastronomía": "ra-dio-as-tro-no-mí-a",
    "radioaudición": "ra-dio-au-di-ción",
    "radiobaliza": "ra-dio-ba-li-za",
    "radiobemba": "ra-dio-bem-ba",
    "radiobiología": "ra-dio-bio-lo-gí-a",
    "radiocasete": "ra-dio-ca-se-te",
    "radiocasetera": "ra-dio-ca-se-te-ra",
    "radiocassette": "ra-dio-cas-set-te",
    "radiocomunicación": "ra-dio-co-mu-ni-ca-ción",
    "radiocontrol": "ra-dio-con-trol",
    "radiodiagnóstico": "ra-dio-diag-nós-ti-co",
    "radiodifundir": "ra-dio-di-fun-dir",
    "radiodifusión": "ra-dio-di-fu-sión",
    "radiodifusor": "ra-dio-di-fu-sor",
    "radiodifusora": "ra-dio-di-fu-so-ra",
    "radiodirigir": "ra-dio-di-ri-gir",
    "radioeléctrica": "ra-dio-e-léc-tri-ca",
    "radioelectricidad": "ra-dio-e-lec-tri-ci-dad",
    "radioeléctrico": "ra-dio-e-léc-tri-co",
    "radioemisión": "ra-dio-e-mi-sión",
    "radioemisora": "ra-dio-e-mi-so-ra",
    "radioescucha": "ra-dio-es-cu-cha",
    "radiofaro": "ra-dio-fa-ro",
    "radiofonía": "ra-dio-fo-ní-a",
    "radiofónica": "ra-dio-fó-ni-ca",
    "radiofónico": "ra-dio-fó-ni-co",
    "radiofonista": "ra-dio-fo-nis-ta",
    "radiofrecuencia": "ra-dio-fre-cuen-cia",
    "radiofuente": "ra-dio-fuen-te",
    "radiogalaxia": "ra-dio-ga-la-xia",
    "radiogoniómetro": "ra-dio-go-nió-me-tro",
    "radiograbador": "ra-dio-gra-ba-dor",
    "radiograbadora": "ra-dio-gra-ba-do-ra",
    "radiografía": "ra-dio-gra-fí-a",
    "radiografiar": "ra-dio-gra-fiar",
    "radiográfica": "ra-dio-grá-fi-ca",
    "radiográfico": "ra-dio-grá-fi-co",
    "radiograma": "ra-dio-gra-ma",
    "radiogramola": "ra-dio-gra-mo-la",
    "radioinmunoensayo": "ra-dioin-mu-no-en-sa-yo",
    "radioisótopo": "ra-dioi-só-to-po",
    "radiola": "ra-dio-la",
    "radiolario": "ra-dio-la-rio",
    "radiolocalización": "ra-dio-lo-ca-li-za-ción",
    "radióloga": "ra-dió-lo-ga",
    "radiología": "ra-dio-lo-gí-a",
    "radiológico": "ra-dio-ló-gi-co",
    "radiólogo": "ra-dió-lo-go",
    "radioluminiscencia": "ra-dio-lu-mi-nis-cen-cia",
    "radioluminiscente": "ra-dio-lu-mi-nis-cen-te",
    "radiometría": "ra-dio-me-trí-a",
    "radiómetro": "ra-dió-me-tro",
    "radionavegación": "ra-dio-na-ve-ga-ción",
    "radionovela": "ra-dio-no-ve-la",
    "radiorreceptor": "ra-dio-rre-cep-tor",
    "radiosa": "ra-dio-sa",
    "radioscopia": "ra-dios-co-pia",
    "radioscópica": "ra-dios-có-pi-ca",
    "radioscópico": "ra-dios-có-pi-co",
    "radioso": "ra-dio-so",
    "radiosonda": "ra-dio-son-da",
    "radiotaxi": "ra-dio-ta-xi",
    "radioteatro": "ra-dio-te-a-tro",
    "radiotecnia": "ra-dio-tec-nia",
    "radiotécnica": "ra-dio-téc-ni-ca",
    "radiotécnico": "ra-dio-téc-ni-co",
    "radiotelecomunicación": "ra-dio-te-le-co-mu-ni-ca-ción",
    "radiotelefonía": "ra-dio-te-le-fo-ní-a",
    "radiotelefónica": "ra-dio-te-le-fó-ni-ca",
    "radiotelefónico": "ra-dio-te-le-fó-ni-co",
    "radiotelefonista": "ra-dio-te-le-fo-nis-ta",
    "radioteléfono": "ra-dio-te-lé-fo-no",
    "radiotelegrafía": "ra-dio-te-le-gra-fí-a",
    "radiotelegrafiar": "ra-dio-te-le-gra-fiar",
    "radiotelegráfica": "ra-dio-te-le-grá-fi-ca",
    "radiotelegráfico": "ra-dio-te-le-grá-fi-co",
    "radiotelegrafista": "ra-dio-te-le-gra-fis-ta",
    "radiotelégrafo": "ra-dio-te-lé-gra-fo",
    "radiotelegrama": "ra-dio-te-le-gra-ma",
    "radiotelescopio": "ra-dio-te-les-co-pio",
    "radiotelevisión": "ra-dio-te-le-vi-sión",
    "radioterapeuta": "ra-dio-te-ra-peu-ta",
    "radioterapéutico": "ra-dio-te-ra-péu-ti-co",
    "radioterapia": "ra-dio-te-ra-pia",
    "radioterápico": "ra-dio-te-rá-pi-co",
    "radiotoxicidad": "ra-dio-to-xi-ci-dad",
    "radiotóxico": "ra-dio-tó-xi-co",
    "radiotransmisor": "ra-dio-trans-mi-sor",
    "radiotransmitir": "ra-dio-trans-mi-tir",
    "radioyente": "ra-dio-yen-te",
    "radiumterapia": "ra-dium-te-ra-pia",
    "radón": "ra-dón",
    "rádula": "rá-du-la",
    "raedera": "ra-e-de-ra",
    "raediza": "ra-e-di-za",
    "raedizo": "ra-e-di-zo",
    "raedor": "ra-e-dor",
    "raedora": "ra-e-do-ra",
    "raedura": "ra-e-du-ra",
    "raer": "ra-er",
    "rafa": "ra-fa",
    "rafaelesco": "ra-fa-e-les-co",
    "ráfaga": "rá-fa-ga",
    "rafaila": "ra-fai-la",
    "rafal": "ra-fal",
    "rafalla": "ra-fa-lla",
    "rafania": "ra-fa-nia",
    "rafe": "ra-fe",
    "rafear": "ra-fe-ar",
    "rafez": "ra-fez",
    "rafezar": "ra-fe-zar",
    "rafezmente": "ra-fez-men-te",
    "rafia": "ra-fia",
    "rafting": "raf-ting",
    "ragadía": "ra-ga-dí-a",
    "raglán": "ra-glán",
    "ragú": "ra-gú",
    "ragua": "ra-gua",
    "ragusea": "ra-gu-se-a",
    "raguseo": "ra-gu-se-o",
    "rahalí": "ra-ha-lí",
    "rahez": "ra-hez",
    "rahezar": "ra-he-zar",
    "raíble": "ra-í-ble",
    "raicear": "rai-ce-ar",
    "raicerío": "rai-ce-rí-o",
    "raicero": "rai-ce-ro",
    "raicilla": "rai-ci-lla",
    "raicita": "rai-ci-ta",
    "raída": "ra-í-da",
    "raído": "ra-í-do",
    "raigal": "rai-gal",
    "raigambre": "rai-gam-bre",
    "raigar": "rai-gar",
    "raigón": "rai-gón",
    "raigrás": "rai-grás",
    "raijo": "rai-jo",
    "raíl": "ra-íl",
    "raimiento": "rai-mien-to",
    "raíz": "ra-íz",
    "raizal": "rai-zal",
    "raizalismo": "rai-za-lis-mo",
    "raizar": "rai-zar",
    "raja": "ra-ja",
    "rajá": "ra-já",
    "rajable": "ra-ja-ble",
    "rajabroqueles": "ra-ja-bro-que-les",
    "rajada": "ra-ja-da",
    "rajadiablos": "ra-ja-dia-blos",
    "rajadillo": "ra-ja-di-llo",
    "rajadiza": "ra-ja-di-za",
    "rajadizo": "ra-ja-di-zo",
    "rajado": "ra-ja-do",
    "rajador": "ra-ja-dor",
    "rajadura": "ra-ja-du-ra",
    "rajar": "ra-jar",
    "rajatabla": "ra-ja-ta-bla",
    "rajatablas": "ra-ja-ta-blas",
    "raje": "ra-je",
    "rajeta": "ra-je-ta",
    "rajón": "ra-jón",
    "rajona": "ra-jo-na",
    "rajonada": "ra-jo-na-da",
    "rajudo": "ra-ju-do",
    "rajuela": "ra-jue-la",
    "rajuñados": "ra-ju-ña-dos",
    "rala": "ra-la",
    "ralbar": "ral-bar",
    "ralea": "ra-le-a",
    "ralear": "ra-le-ar",
    "ralentí": "ra-len-tí",
    "ralentización": "ra-len-ti-za-ción",
    "ralentizar": "ra-len-ti-zar",
    "raleo": "ra-le-o",
    "raleón": "ra-le-ón",
    "raleona": "ra-le-o-na",
    "raleza": "ra-le-za",
    "rallado": "ra-lla-do",
    "rallador": "ra-lla-dor",
    "ralladora": "ra-lla-do-ra",
    "ralladura": "ra-lla-du-ra",
    "rallante": "ra-llan-te",
    "rallar": "ra-llar",
    "rallo": "ra-llo",
    "rallón": "ra-llón",
    "ralo": "ra-lo",
    "ralvar": "ral-var",
    "rama": "ra-ma",
    "ramada": "ra-ma-da",
    "ramadán": "ra-ma-dán",
    "ramaje": "ra-ma-je",
    "ramajear": "ra-ma-je-ar",
    "ramal": "ra-mal",
    "ramalazo": "ra-ma-la-zo",
    "ramalear": "ra-ma-le-ar",
    "ramalera": "ra-ma-le-ra",
    "ramalillo": "ra-ma-li-llo",
    "ramasco": "ra-mas-co",
    "ramazón": "ra-ma-zón",
    "rambla": "ram-bla",
    "ramblar": "ram-blar",
    "ramblazo": "ram-bla-zo",
    "ramblizo": "ram-bli-zo",
    "rambulería": "ram-bu-le-rí-a",
    "rambután": "ram-bu-tán",
    "rámea": "rá-me-a",
    "rameada": "ra-me-a-da",
    "rameado": "ra-me-a-do",
    "rameal": "ra-me-al",
    "ramear": "ra-me-ar",
    "rámeo": "rá-me-o",
    "ramera": "ra-me-ra",
    "ramería": "ra-me-rí-a",
    "ramero": "ra-me-ro",
    "ramial": "ra-mial",
    "ramificación": "ra-mi-fi-ca-ción",
    "ramificar": "ra-mi-fi-car",
    "rámila": "rá-mi-la",
    "ramilla": "ra-mi-lla",
    "ramillete": "ra-mi-lle-te",
    "ramilletera": "ra-mi-lle-te-ra",
    "ramilletero": "ra-mi-lle-te-ro",
    "ramina": "ra-mi-na",
    "ramio": "ra-mio",
    "ramirense": "ra-mi-ren-se",
    "ramiro": "ra-mi-ro",
    "ramito": "ra-mi-to",
    "ramiza": "ra-mi-za",
    "ramnácea": "ram-ná-ce-a",
    "ramnáceo": "ram-ná-ce-o",
    "rámnea": "rám-ne-a",
    "rámneo": "rám-ne-o",
    "ramo": "ra-mo",
    "ramojo": "ra-mo-jo",
    "ramón": "ra-món",
    "ramona": "ra-mo-na",
    "ramonear": "ra-mo-ne-ar",
    "ramoneo": "ra-mo-ne-o",
    "ramoniano": "ra-mo-nia-no",
    "ramosa": "ra-mo-sa",
    "ramoso": "ra-mo-so",
    "rampa": "ram-pa",
    "rampante": "ram-pan-te",
    "rampar": "ram-par",
    "rampete": "ram-pe-te",
    "rampiñete": "ram-pi-ñe-te",
    "rampla": "ram-pla",
    "ramplón": "ram-plón",
    "ramplona": "ram-plo-na",
    "ramplonería": "ram-plo-ne-rí-a",
    "rampojo": "ram-po-jo",
    "rampollo": "ram-po-llo",
    "ramuja": "ra-mu-ja",
    "ramujo": "ra-mu-jo",
    "ramulla": "ra-mu-lla",
    "rana": "ra-na",
    "raña": "ra-ña",
    "ranacuajo": "ra-na-cua-jo",
    "rancagüina": "ran-ca-güi-na",
    "rancagüino": "ran-ca-güi-no",
    "rancajada": "ran-ca-ja-da",
    "rancajado": "ran-ca-ja-do",
    "rancajo": "ran-ca-jo",
    "rancar": "ran-car",
    "rancha": "ran-cha",
    "ranchar": "ran-char",
    "rancheadero": "ran-che-a-de-ro",
    "ranchear": "ran-che-ar",
    "ranchera": "ran-che-ra",
    "ranchería": "ran-che-rí-a",
    "rancherío": "ran-che-rí-o",
    "ranchero": "ran-che-ro",
    "ranchito": "ran-chi-to",
    "rancho": "ran-cho",
    "rancia": "ran-cia",
    "ranciar": "ran-ciar",
    "rancidez": "ran-ci-dez",
    "ranciedad": "ran-cie-dad",
    "rancio": "ran-cio",
    "ranciosa": "ran-cio-sa",
    "rancioso": "ran-cio-so",
    "rancla": "ran-cla",
    "ranclar": "ran-clar",
    "rancor": "ran-cor",
    "rancura": "ran-cu-ra",
    "rancurosa": "ran-cu-ro-sa",
    "rancuroso": "ran-cu-ro-so",
    "randa": "ran-da",
    "randada": "ran-da-da",
    "randado": "ran-da-do",
    "randear": "ran-de-ar",
    "randera": "ran-de-ra",
    "ranero": "ra-ne-ro",
    "ranfañosa": "ran-fa-ño-sa",
    "ranfañoso": "ran-fa-ño-so",
    "rangífero": "ran-gí-fe-ro",
    "ranglan": "ran-glan",
    "ranglán": "ran-glán",
    "rango": "ran-go",
    "rangosa": "ran-go-sa",
    "rangoso": "ran-go-so",
    "rangua": "ran-gua",
    "ranilla": "ra-ni-lla",
    "ranina": "ra-ni-na",
    "ranita": "ra-ni-ta",
    "ranking": "ran-king",
    "rano": "ra-no",
    "raño": "ra-ño",
    "ranquel": "ran-quel",
    "ranquelina": "ran-que-li-na",
    "ranquelino": "ran-que-li-no",
    "rantifusa": "ran-ti-fu-sa",
    "rantifuso": "ran-ti-fu-so",
    "ránula": "rá-nu-la",
    "ranunculácea": "ra-nun-cu-lá-ce-a",
    "ranunculáceas": "ra-nun-cu-lá-ce-as",
    "ranunculáceo": "ra-nun-cu-lá-ce-o",
    "ranúnculo": "ra-nún-cu-lo",
    "ranura": "ra-nu-ra",
    "ranzal": "ran-zal",
    "ranzón": "ran-zón",
    "rapa": "ra-pa",
    "rapabarbas": "ra-pa-bar-bas",
    "rapacejo": "ra-pa-ce-jo",
    "rapacería": "ra-pa-ce-rí-a",
    "rapacidad": "ra-pa-ci-dad",
    "rapada": "ra-pa-da",
    "rapado": "ra-pa-do",
    "rapador": "ra-pa-dor",
    "rapadora": "ra-pa-do-ra",
    "rapadura": "ra-pa-du-ra",
    "rapagón": "ra-pa-gón",
    "rapamiento": "ra-pa-mien-to",
    "rapante": "ra-pan-te",
    "rapapiés": "ra-pa-piés",
    "rapapolvo": "ra-pa-pol-vo",
    "rapar": "ra-par",
    "rapavelas": "ra-pa-ve-las",
    "rapaz": "ra-paz",
    "rapaza": "ra-pa-za",
    "rapazada": "ra-pa-za-da",
    "rape": "ra-pe",
    "rapé": "ra-pé",
    "rapear": "ra-pe-ar",
    "rápel": "rá-pel",
    "rapera": "ra-pe-ra",
    "rapero": "ra-pe-ro",
    "rápida": "rá-pi-da",
    "rápidamente": "rá-pi-da-men-te",
    "rapidez": "ra-pi-dez",
    "rapidito": "ra-pi-di-to",
    "rápido": "rá-pi-do",
    "rapiega": "ra-pie-ga",
    "rapina": "ra-pi-na",
    "rapiña": "ra-pi-ña",
    "rapiñador": "ra-pi-ña-dor",
    "rapiñadora": "ra-pi-ña-do-ra",
    "rapiñar": "ra-pi-ñar",
    "rapingacho": "ra-pin-ga-cho",
    "rapista": "ra-pis-ta",
    "rápita": "rá-pi-ta",
    "rapo": "ra-po",
    "rapónchigo": "ra-pón-chi-go",
    "rapóntico": "ra-pón-ti-co",
    "raposa": "ra-po-sa",
    "raposear": "ra-po-se-ar",
    "raposeo": "ra-po-se-o",
    "raposera": "ra-po-se-ra",
    "raposería": "ra-po-se-rí-a",
    "raposero": "ra-po-se-ro",
    "raposía": "ra-po-sí-a",
    "raposina": "ra-po-si-na",
    "raposino": "ra-po-si-no",
    "raposo": "ra-po-so",
    "raposuna": "ra-po-su-na",
    "raposuno": "ra-po-su-no",
    "rappel": "rap-pel",
    "rapsoda": "rap-so-da",
    "rapsodia": "rap-so-dia",
    "rapsódico": "rap-só-di-co",
    "rapsodo": "rap-so-do",
    "rapta": "rap-ta",
    "raptar": "rap-tar",
    "rapto": "rap-to",
    "raptor": "rap-tor",
    "raptora": "rap-to-ra",
    "rapuzar": "ra-pu-zar",
    "raque": "ra-que",
    "raquear": "ra-que-ar",
    "raquera": "ra-que-ra",
    "raquero": "ra-que-ro",
    "raqueta": "ra-que-ta",
    "raquetazo": "ra-que-ta-zo",
    "raquetera": "ra-que-te-ra",
    "raquetero": "ra-que-te-ro",
    "raquetista": "ra-que-tis-ta",
    "raquialgia": "ra-quial-gia",
    "raquianestesia": "ra-quia-nes-te-sia",
    "raquídea": "ra-quí-de-a",
    "raquídeo": "ra-quí-de-o",
    "raquis": "ra-quis",
    "raquítica": "ra-quí-ti-ca",
    "raquítico": "ra-quí-ti-co",
    "raquitis": "ra-qui-tis",
    "raquitismo": "ra-qui-tis-mo",
    "raquítomo": "ra-quí-to-mo",
    "rara": "ra-ra",
    "raramente": "ra-ra-men-te",
    "rarámuri": "ra-rá-mu-ri",
    "rarear": "ra-re-ar",
    "rarefacción": "ra-re-fac-ción",
    "rarefacer": "ra-re-fa-cer",
    "rareza": "ra-re-za",
    "raridad": "ra-ri-dad",
    "rarificar": "ra-ri-fi-car",
    "rarificativa": "ra-ri-fi-ca-ti-va",
    "rarificativo": "ra-ri-fi-ca-ti-vo",
    "rarífico": "ra-rí-fi-co",
    "raro": "ra-ro",
    "rasa": "ra-sa",
    "rasadura": "ra-sa-du-ra",
    "rasamente": "ra-sa-men-te",
    "rasante": "ra-san-te",
    "rasar": "ra-sar",
    "rasarse": "ra-sar-se",
    "rasca": "ras-ca",
    "rascabuchar": "ras-ca-bu-char",
    "rascacielos": "ras-ca-cie-los",
    "rascacio": "ras-ca-cio",
    "rascada": "ras-ca-da",
    "rascadera": "ras-ca-de-ra",
    "rascado": "ras-ca-do",
    "rascador": "ras-ca-dor",
    "rascadura": "ras-ca-du-ra",
    "rascalino": "ras-ca-li-no",
    "rascamiento": "ras-ca-mien-to",
    "rascamoño": "ras-ca-mo-ño",
    "rascar": "ras-car",
    "rascatripas": "ras-ca-tri-pas",
    "rascazón": "ras-ca-zón",
    "rascle": "ras-cle",
    "rascón": "ras-cón",
    "rascona": "ras-co-na",
    "rascuache": "ras-cua-che",
    "rascuachera": "ras-cua-che-ra",
    "rascuñar": "ras-cu-ñar",
    "rascuño": "ras-cu-ño",
    "rasear": "ra-se-ar",
    "rasel": "ra-sel",
    "rasera": "ra-se-ra",
    "rasero": "ra-se-ro",
    "rasete": "ra-se-te",
    "rasgada": "ras-ga-da",
    "rasgado": "ras-ga-do",
    "rasgador": "ras-ga-dor",
    "rasgadora": "ras-ga-do-ra",
    "rasgadura": "ras-ga-du-ra",
    "rasgar": "ras-gar",
    "rasgo": "ras-go",
    "rasgón": "ras-gón",
    "rasgueado": "ras-gue-a-do",
    "rasgueador": "ras-gue-a-dor",
    "rasgueadora": "ras-gue-a-do-ra",
    "rasguear": "ras-gue-ar",
    "rasgueo": "ras-gue-o",
    "rasguñada": "ras-gu-ña-da",
    "rasguñadura": "ras-gu-ña-du-ra",
    "rasguñar": "ras-gu-ñar",
    "rasguño": "ras-gu-ño",
    "rasguñón": "ras-gu-ñón",
    "rasí": "ra-sí",
    "rasilla": "ra-si-lla",
    "rasión": "ra-sión",
    "rasmia": "ras-mia",
    "rasmillar": "ras-mi-llar",
    "rasmillón": "ras-mi-llón",
    "raso": "ra-so",
    "rasoliso": "ra-so-li-so",
    "raspa": "ras-pa",
    "raspada": "ras-pa-da",
    "raspadera": "ras-pa-de-ra",
    "raspadilla": "ras-pa-di-lla",
    "raspadillo": "ras-pa-di-llo",
    "raspadita": "ras-pa-di-ta",
    "raspado": "ras-pa-do",
    "raspador": "ras-pa-dor",
    "raspadura": "ras-pa-du-ra",
    "raspahilar": "ras-pahi-lar",
    "raspaje": "ras-pa-je",
    "raspajo": "ras-pa-jo",
    "raspamiento": "ras-pa-mien-to",
    "ráspano": "rás-pa-no",
    "raspante": "ras-pan-te",
    "raspar": "ras-par",
    "raspazón": "ras-pa-zón",
    "raspe": "ras-pe",
    "raspear": "ras-pe-ar",
    "raspilla": "ras-pi-lla",
    "raspinegra": "ras-pi-ne-gra",
    "raspinegro": "ras-pi-ne-gro",
    "raspón": "ras-pón",
    "rasponazo": "ras-po-na-zo",
    "rasposa": "ras-po-sa",
    "rasposo": "ras-po-so",
    "raspudo": "ras-pu-do",
    "rasqueta": "ras-que-ta",
    "rasquetear": "ras-que-te-ar",
    "rasquiña": "ras-qui-ña",
    "rasta": "ras-ta",
    "rastacuero": "ras-ta-cue-ro",
    "rastafari": "ras-ta-fa-ri",
    "rastel": "ras-tel",
    "rastillador": "ras-ti-lla-dor",
    "rastilladora": "ras-ti-lla-do-ra",
    "rastillar": "ras-ti-llar",
    "rastillo": "ras-ti-llo",
    "rastra": "ras-tra",
    "rastrallar": "ras-tra-llar",
    "rastrar": "ras-trar",
    "rastreado": "ras-tre-a-do",
    "rastreador": "ras-tre-a-dor",
    "rastreadora": "ras-tre-a-do-ra",
    "rastrear": "ras-tre-ar",
    "rastrel": "ras-trel",
    "rastreo": "ras-tre-o",
    "rastrera": "ras-tre-ra",
    "rastreramente": "ras-tre-ra-men-te",
    "rastrero": "ras-tre-ro",
    "rastrilla": "ras-tri-lla",
    "rastrillada": "ras-tri-lla-da",
    "rastrillado": "ras-tri-lla-do",
    "rastrillador": "ras-tri-lla-dor",
    "rastrilladora": "ras-tri-lla-do-ra",
    "rastrillaje": "ras-tri-lla-je",
    "rastrillar": "ras-tri-llar",
    "rastrillo": "ras-tri-llo",
    "rastro": "ras-tro",
    "rastrojal": "ras-tro-jal",
    "rastrojar": "ras-tro-jar",
    "rastrojear": "ras-tro-je-ar",
    "rastrojera": "ras-tro-je-ra",
    "rastrojo": "ras-tro-jo",
    "rasura": "ra-su-ra",
    "rasuración": "ra-su-ra-ción",
    "rasurada": "ra-su-ra-da",
    "rasuradora": "ra-su-ra-do-ra",
    "rasurar": "ra-su-rar",
    "rata": "ra-ta",
    "ratafía": "ra-ta-fí-a",
    "ratania": "ra-ta-nia",
    "rataplán": "ra-ta-plán",
    "ratear": "ra-te-ar",
    "rateo": "ra-te-o",
    "ratera": "ra-te-ra",
    "rateramente": "ra-te-ra-men-te",
    "ratería": "ra-te-rí-a",
    "rateril": "ra-te-ril",
    "ratero": "ra-te-ro",
    "raticida": "ra-ti-ci-da",
    "ratificación": "ra-ti-fi-ca-ción",
    "ratificador": "ra-ti-fi-ca-dor",
    "ratificar": "ra-ti-fi-car",
    "ratificatoria": "ra-ti-fi-ca-to-ria",
    "ratificatorio": "ra-ti-fi-ca-to-rio",
    "ratigar": "ra-ti-gar",
    "rátigo": "rá-ti-go",
    "ratimago": "ra-ti-ma-go",
    "ratímetro": "ra-tí-me-tro",
    "ratina": "ra-ti-na",
    "ratinado": "ra-ti-na-do",
    "ratinadora": "ra-ti-na-do-ra",
    "ratinar": "ra-ti-nar",
    "rating": "ra-ting",
    "ratino": "ra-ti-no",
    "ratiño": "ra-ti-ño",
    "ratio": "ra-tio",
    "rato": "ra-to",
    "ratón": "ra-tón",
    "ratona": "ra-to-na",
    "ratonar": "ra-to-nar",
    "ratonera": "ra-to-ne-ra",
    "ratonero": "ra-to-ne-ro",
    "ratonesca": "ra-to-nes-ca",
    "ratonesco": "ra-to-nes-co",
    "ratonil": "ra-to-nil",
    "rauca": "rau-ca",
    "rauco": "rau-co",
    "rauda": "rau-da",
    "raudal": "rau-dal",
    "raudamente": "rau-da-men-te",
    "raudo": "rau-do",
    "raulí": "rau-lí",
    "rauta": "rau-ta",
    "ravenala": "ra-ve-na-la",
    "ravenés": "ra-ve-nés",
    "ravenesa": "ra-ve-ne-sa",
    "raviol": "ra-viol",
    "raviole": "ra-vio-le",
    "ravioli": "ra-vio-li",
    "rawsense": "raw-sen-se",
    "raya": "ra-ya",
    "rayable": "ra-ya-ble",
    "rayada": "ra-ya-da",
    "rayadillo": "ra-ya-di-llo",
    "rayado": "ra-ya-do",
    "rayador": "ra-ya-dor",
    "rayana": "ra-ya-na",
    "rayano": "ra-ya-no",
    "rayar": "ra-yar",
    "rayente": "ra-yen-te",
    "rayero": "ra-ye-ro",
    "ráyido": "rá-yi-do",
    "rayo": "ra-yo",
    "rayón": "ra-yón",
    "rayosa": "ra-yo-sa",
    "rayoso": "ra-yo-so",
    "rayuela": "ra-yue-la",
    "rayuelo": "ra-yue-lo",
    "raza": "ra-za",
    "razada": "ra-za-da",
    "razado": "ra-za-do",
    "rázago": "rá-za-go",
    "razar": "ra-zar",
    "razia": "ra-zia",
    "razón": "ra-zón",
    "razonable": "ra-zo-na-ble",
    "razonablemente": "ra-zo-na-ble-men-te",
    "razonada": "ra-zo-na-da",
    "razonadamente": "ra-zo-na-da-men-te",
    "razonado": "ra-zo-na-do",
    "razonador": "ra-zo-na-dor",
    "razonadora": "ra-zo-na-do-ra",
    "razonal": "ra-zo-nal",
    "razonamiento": "ra-zo-na-mien-to",
    "razonar": "ra-zo-nar",
    "razzia": "raz-zia",
    "rea": "re-a",
    "reabrir": "re-a-brir",
    "reabsorber": "re-ab-sor-ber",
    "reabsorción": "re-ab-sor-ción",
    "reacción": "re-ac-ción",
    "reaccionar": "re-ac-cio-nar",
    "reaccionaria": "re-ac-cio-na-ria",
    "reaccionario": "re-ac-cio-na-rio",
    "reacia": "re-a-cia",
    "reacio": "re-a-cio",
    "reactancia": "re-ac-tan-cia",
    "reactante": "re-ac-tan-te",
    "reactiva": "re-ac-ti-va",
    "reactivación": "re-ac-ti-va-ción",
    "reactivar": "re-ac-ti-var",
    "reactividad": "re-ac-ti-vi-dad",
    "reactivo": "re-ac-ti-vo",
    "reactor": "re-ac-tor",
    "reacuñación": "re-a-cu-ña-ción",
    "reacuñar": "re-a-cu-ñar",
    "readaptación": "re-a-dap-ta-ción",
    "readaptar": "re-a-dap-tar",
    "readmisión": "re-ad-mi-sión",
    "readmitir": "re-ad-mi-tir",
    "ready": "re-ady",
    "reafirmación": "re-a-fir-ma-ción",
    "reafirmante": "re-a-fir-man-te",
    "reafirmar": "re-a-fir-mar",
    "reagravación": "re-a-gra-va-ción",
    "reagravar": "re-a-gra-var",
    "reagrupación": "re-a-gru-pa-ción",
    "reagrupamiento": "re-a-gru-pa-mien-to",
    "reagrupar": "re-a-gru-par",
    "reaguda": "re-a-gu-da",
    "reagudo": "re-a-gu-do",
    "reaje": "re-a-je",
    "reajustar": "re-a-jus-tar",
    "reajuste": "re-a-jus-te",
    "real": "re-al",
    "reala": "re-a-la",
    "realce": "re-al-ce",
    "realdad": "re-al-dad",
    "realegrar": "re-a-le-grar",
    "realegrarse": "re-a-le-grar-se",
    "realejo": "re-a-le-jo",
    "realenga": "re-a-len-ga",
    "realengo": "re-a-len-go",
    "realera": "re-a-le-ra",
    "realero": "re-a-le-ro",
    "realete": "re-a-le-te",
    "realeza": "re-a-le-za",
    "realidad": "re-a-li-dad",
    "realillo": "re-a-li-llo",
    "realimentación": "re-a-li-men-ta-ción",
    "realimentar": "re-a-li-men-tar",
    "realismo": "re-a-lis-mo",
    "realista": "re-a-lis-ta",
    "realístico": "re-a-lís-ti-co",
    "realito": "re-a-li-to",
    "realizable": "re-a-li-za-ble",
    "realización": "re-a-li-za-ción",
    "realizador": "re-a-li-za-dor",
    "realizadora": "re-a-li-za-do-ra",
    "realizar": "re-a-li-zar",
    "realme": "re-al-me",
    "realmente": "re-al-men-te",
    "realojamiento": "re-a-lo-ja-mien-to",
    "realojar": "re-a-lo-jar",
    "realojo": "re-a-lo-jo",
    "realquilada": "re-al-qui-la-da",
    "realquilado": "re-al-qui-la-do",
    "realquilar": "re-al-qui-lar",
    "realzado": "re-al-za-do",
    "realzar": "re-al-zar",
    "reamar": "re-a-mar",
    "reanimación": "re-a-ni-ma-ción",
    "reanimar": "re-a-ni-mar",
    "reaños": "re-a-ños",
    "reanudación": "re-a-nu-da-ción",
    "reanudar": "re-a-nu-dar",
    "reaparecer": "re-a-pa-re-cer",
    "reaparición": "re-a-pa-ri-ción",
    "reapertura": "re-a-per-tu-ra",
    "reapretar": "re-a-pre-tar",
    "reaprovisionamiento": "re-a-pro-vi-sio-na-mien-to",
    "rearar": "re-a-rar",
    "reargüir": "re-ar-güir",
    "rearmar": "re-ar-mar",
    "rearme": "re-ar-me",
    "reasegurar": "re-a-se-gu-rar",
    "reaseguro": "re-a-se-gu-ro",
    "reasumir": "re-a-su-mir",
    "reasunción": "re-a-sun-ción",
    "reata": "re-a-ta",
    "reatadura": "re-a-ta-du-ra",
    "reatar": "re-a-tar",
    "reatazo": "re-a-ta-zo",
    "reatina": "re-a-ti-na",
    "reatino": "re-a-ti-no",
    "reatiza": "re-a-ti-za",
    "reato": "re-a-to",
    "reaventar": "re-a-ven-tar",
    "reavivación": "re-a-vi-va-ción",
    "reavivar": "re-a-vi-var",
    "rebaba": "re-ba-ba",
    "rebaja": "re-ba-ja",
    "rebajado": "re-ba-ja-do",
    "rebajador": "re-ba-ja-dor",
    "rebajadora": "re-ba-ja-do-ra",
    "rebajamiento": "re-ba-ja-mien-to",
    "rebajar": "re-ba-jar",
    "rebaje": "re-ba-je",
    "rebajo": "re-ba-jo",
    "rebalaje": "re-ba-la-je",
    "rebalsa": "re-bal-sa",
    "rebalsar": "re-bal-sar",
    "rebalse": "re-bal-se",
    "rebanada": "re-ba-na-da",
    "rebañadera": "re-ba-ña-de-ra",
    "rebañador": "re-ba-ña-dor",
    "rebañadora": "re-ba-ña-do-ra",
    "rebañadura": "re-ba-ña-du-ra",
    "rebanar": "re-ba-nar",
    "rebañar": "re-ba-ñar",
    "rebanco": "re-ban-co",
    "rebane": "re-ba-ne",
    "rebanear": "re-ba-ne-ar",
    "rebañega": "re-ba-ñe-ga",
    "rebañego": "re-ba-ñe-go",
    "rebaño": "re-ba-ño",
    "rebasadero": "re-ba-sa-de-ro",
    "rebasar": "re-ba-sar",
    "rebatar": "re-ba-tar",
    "rebate": "re-ba-te",
    "rebatible": "re-ba-ti-ble",
    "rebatimiento": "re-ba-ti-mien-to",
    "rebatiña": "re-ba-ti-ña",
    "rebatinga": "re-ba-tin-ga",
    "rebatir": "re-ba-tir",
    "rebato": "re-ba-to",
    "rebautizar": "re-bau-ti-zar",
    "rebeca": "re-be-ca",
    "rebeco": "re-be-co",
    "rebelar": "re-be-lar",
    "rebelde": "re-bel-de",
    "rebeldía": "re-bel-dí-a",
    "rebelión": "re-be-lión",
    "rebelón": "re-be-lón",
    "rebelona": "re-be-lo-na",
    "rebencazo": "re-ben-ca-zo",
    "rebenque": "re-ben-que",
    "rebina": "re-bi-na",
    "rebinar": "re-bi-nar",
    "rebisabuela": "re-bi-sa-bue-la",
    "rebisabuelo": "re-bi-sa-bue-lo",
    "rebisco": "re-bis-co",
    "rebisnieta": "re-bis-nie-ta",
    "rebisnieto": "re-bis-nie-to",
    "rebitar": "re-bi-tar",
    "rebite": "re-bi-te",
    "reblagar": "re-bla-gar",
    "reblandecer": "re-blan-de-cer",
    "reblandecimiento": "re-blan-de-ci-mien-to",
    "reblar": "re-blar",
    "reble": "re-ble",
    "rebobinado": "re-bo-bi-na-do",
    "rebobinar": "re-bo-bi-nar",
    "rebocera": "re-bo-ce-ra",
    "rebocería": "re-bo-ce-rí-a",
    "rebocero": "re-bo-ce-ro",
    "rebocillo": "re-bo-ci-llo",
    "rebociño": "re-bo-ci-ño",
    "rebojo": "re-bo-jo",
    "rebol": "re-bol",
    "rebollar": "re-bo-llar",
    "rebolledo": "re-bo-lle-do",
    "rebollidura": "re-bo-lli-du-ra",
    "rebollo": "re-bo-llo",
    "rebolluda": "re-bo-llu-da",
    "rebolludo": "re-bo-llu-do",
    "rebombar": "re-bom-bar",
    "reborda": "re-bor-da",
    "reborde": "re-bor-de",
    "rebordeador": "re-bor-de-a-dor",
    "rebordear": "re-bor-de-ar",
    "reborujar": "re-bo-ru-jar",
    "rebosadero": "re-bo-sa-de-ro",
    "rebosadura": "re-bo-sa-du-ra",
    "rebosamiento": "re-bo-sa-mien-to",
    "rebosante": "re-bo-san-te",
    "rebosar": "re-bo-sar",
    "rebotación": "re-bo-ta-ción",
    "rebotada": "re-bo-ta-da",
    "rebotadera": "re-bo-ta-de-ra",
    "rebotado": "re-bo-ta-do",
    "rebotador": "re-bo-ta-dor",
    "rebotadora": "re-bo-ta-do-ra",
    "rebotadura": "re-bo-ta-du-ra",
    "rebotar": "re-bo-tar",
    "rebote": "re-bo-te",
    "reboteador": "re-bo-te-a-dor",
    "rebotear": "re-bo-te-ar",
    "rebotica": "re-bo-ti-ca",
    "rebotiga": "re-bo-ti-ga",
    "rebotín": "re-bo-tín",
    "rebotón": "re-bo-tón",
    "rebozado": "re-bo-za-do",
    "rebozar": "re-bo-zar",
    "rebozo": "re-bo-zo",
    "rebozuelo": "re-bo-zue-lo",
    "rebramar": "re-bra-mar",
    "rebramo": "re-bra-mo",
    "rebrillar": "re-bri-llar",
    "rebrillo": "re-bri-llo",
    "rebrincar": "re-brin-car",
    "rebrotar": "re-bro-tar",
    "rebrote": "re-bro-te",
    "rebudiar": "re-bu-diar",
    "rebudio": "re-bu-dio",
    "rebufar": "re-bu-far",
    "rebufe": "re-bu-fe",
    "rebufo": "re-bu-fo",
    "rebujada": "re-bu-ja-da",
    "rebujado": "re-bu-ja-do",
    "rebujal": "re-bu-jal",
    "rebujar": "re-bu-jar",
    "rebujina": "re-bu-ji-na",
    "rebujiña": "re-bu-ji-ña",
    "rebujo": "re-bu-jo",
    "rebulicio": "re-bu-li-cio",
    "rebullicio": "re-bu-lli-cio",
    "rebullir": "re-bu-llir",
    "rebultada": "re-bul-ta-da",
    "rebultado": "re-bul-ta-do",
    "rebumbar": "re-bum-bar",
    "rebumbio": "re-bum-bio",
    "reburujar": "re-bu-ru-jar",
    "reburujón": "re-bu-ru-jón",
    "rebús": "re-bús",
    "rebusca": "re-bus-ca",
    "rebuscado": "re-bus-ca-do",
    "rebuscador": "re-bus-ca-dor",
    "rebuscadora": "re-bus-ca-do-ra",
    "rebuscamiento": "re-bus-ca-mien-to",
    "rebuscar": "re-bus-car",
    "rebusco": "re-bus-co",
    "rebusque": "re-bus-que",
    "rebutir": "re-bu-tir",
    "rebuznador": "re-buz-na-dor",
    "rebuznadora": "re-buz-na-do-ra",
    "rebuznar": "re-buz-nar",
    "rebuzno": "re-buz-no",
    "recabar": "re-ca-bar",
    "recabdador": "re-cab-da-dor",
    "recabdamiento": "re-cab-da-mien-to",
    "recabdar": "re-cab-dar",
    "recabdo": "re-cab-do",
    "recabita": "re-ca-bi-ta",
    "recadar": "re-ca-dar",
    "recadera": "re-ca-de-ra",
    "recadero": "re-ca-de-ro",
    "recadista": "re-ca-dis-ta",
    "recado": "re-ca-do",
    "recaer": "re-ca-er",
    "recaída": "re-ca-í-da",
    "recalada": "re-ca-la-da",
    "recalar": "re-ca-lar",
    "recalcada": "re-cal-ca-da",
    "recalcadamente": "re-cal-ca-da-men-te",
    "recalcadora": "re-cal-ca-do-ra",
    "recalcadura": "re-cal-ca-du-ra",
    "recalcar": "re-cal-car",
    "recalce": "re-cal-ce",
    "recalcitrante": "re-cal-ci-tran-te",
    "recalcitrar": "re-cal-ci-trar",
    "recalentado": "re-ca-len-ta-do",
    "recalentamiento": "re-ca-len-ta-mien-to",
    "recalentar": "re-ca-len-tar",
    "recalentón": "re-ca-len-tón",
    "recalificación": "re-ca-li-fi-ca-ción",
    "recalificar": "re-ca-li-fi-car",
    "recalmón": "re-cal-món",
    "recalvastra": "re-cal-vas-tra",
    "recalvastro": "re-cal-vas-tro",
    "recalzar": "re-cal-zar",
    "recalzo": "re-cal-zo",
    "recalzón": "re-cal-zón",
    "recamado": "re-ca-ma-do",
    "recamador": "re-ca-ma-dor",
    "recamadora": "re-ca-ma-do-ra",
    "recamar": "re-ca-mar",
    "recámara": "re-cá-ma-ra",
    "recamarera": "re-ca-ma-re-ra",
    "recamarero": "re-ca-ma-re-ro",
    "recambiable": "re-cam-bia-ble",
    "recambiar": "re-cam-biar",
    "recambio": "re-cam-bio",
    "recamo": "re-ca-mo",
    "recancamusa": "re-can-ca-mu-sa",
    "recancanilla": "re-can-ca-ni-lla",
    "recantación": "re-can-ta-ción",
    "recantón": "re-can-tón",
    "recapacitar": "re-ca-pa-ci-tar",
    "recapitulación": "re-ca-pi-tu-la-ción",
    "recapitular": "re-ca-pi-tu-lar",
    "recarga": "re-car-ga",
    "recargable": "re-car-ga-ble",
    "recargado": "re-car-ga-do",
    "recargamiento": "re-car-ga-mien-to",
    "recargar": "re-car-gar",
    "recargo": "re-car-go",
    "recata": "re-ca-ta",
    "recatada": "re-ca-ta-da",
    "recatadamente": "re-ca-ta-da-men-te",
    "recatado": "re-ca-ta-do",
    "recatamiento": "re-ca-ta-mien-to",
    "recatar": "re-ca-tar",
    "recatear": "re-ca-te-ar",
    "recatería": "re-ca-te-rí-a",
    "recato": "re-ca-to",
    "recatón": "re-ca-tón",
    "recatona": "re-ca-to-na",
    "recatonazo": "re-ca-to-na-zo",
    "recatonear": "re-ca-to-ne-ar",
    "recatonería": "re-ca-to-ne-rí-a",
    "recatonía": "re-ca-to-ní-a",
    "recauchado": "re-cau-cha-do",
    "recauchaje": "re-cau-cha-je",
    "recauchar": "re-cau-char",
    "recauchutado": "re-cau-chu-ta-do",
    "recauchutar": "re-cau-chu-tar",
    "recaudación": "re-cau-da-ción",
    "recaudador": "re-cau-da-dor",
    "recaudadora": "re-cau-da-do-ra",
    "recaudamiento": "re-cau-da-mien-to",
    "recaudanza": "re-cau-dan-za",
    "recaudar": "re-cau-dar",
    "recaudatoria": "re-cau-da-to-ria",
    "recaudatorio": "re-cau-da-to-rio",
    "recaudera": "re-cau-de-ra",
    "recaudería": "re-cau-de-rí-a",
    "recaudero": "re-cau-de-ro",
    "recaudo": "re-cau-do",
    "recavar": "re-ca-var",
    "recazo": "re-ca-zo",
    "recazón": "re-ca-zón",
    "rección": "rec-ción",
    "recebar": "re-ce-bar",
    "recebo": "re-ce-bo",
    "recechar": "re-ce-char",
    "rececho": "re-ce-cho",
    "recejar": "re-ce-jar",
    "recejo": "re-ce-jo",
    "recel": "re-cel",
    "recela": "re-ce-la",
    "recelador": "re-ce-la-dor",
    "recelamiento": "re-ce-la-mien-to",
    "recelar": "re-ce-lar",
    "recelo": "re-ce-lo",
    "recelosa": "re-ce-lo-sa",
    "receloso": "re-ce-lo-so",
    "recencellada": "re-cen-ce-lla-da",
    "recencio": "re-cen-cio",
    "receñir": "re-ce-ñir",
    "recensión": "re-cen-sión",
    "recensor": "re-cen-sor",
    "recensora": "re-cen-so-ra",
    "recentadura": "re-cen-ta-du-ra",
    "recental": "re-cen-tal",
    "recentar": "re-cen-tar",
    "recentín": "re-cen-tín",
    "recentina": "re-cen-ti-na",
    "recentísima": "re-cen-tí-si-ma",
    "recentísimo": "re-cen-tí-si-mo",
    "recepción": "re-cep-ción",
    "recepcionista": "re-cep-cio-nis-ta",
    "recepta": "re-cep-ta",
    "receptación": "re-cep-ta-ción",
    "receptáculo": "re-cep-tá-cu-lo",
    "receptador": "re-cep-ta-dor",
    "receptadora": "re-cep-ta-do-ra",
    "receptar": "re-cep-tar",
    "receptiva": "re-cep-ti-va",
    "receptividad": "re-cep-ti-vi-dad",
    "receptivo": "re-cep-ti-vo",
    "recepto": "re-cep-to",
    "receptor": "re-cep-tor",
    "receptora": "re-cep-to-ra",
    "receptoría": "re-cep-to-rí-a",
    "recercador": "re-cer-ca-dor",
    "recercadora": "re-cer-ca-do-ra",
    "recercar": "re-cer-car",
    "recesar": "re-ce-sar",
    "recesión": "re-ce-sión",
    "recésit": "re-cé-sit",
    "recesivo": "re-ce-si-vo",
    "receso": "re-ce-so",
    "receta": "re-ce-ta",
    "recetador": "re-ce-ta-dor",
    "recetadora": "re-ce-ta-do-ra",
    "recetar": "re-ce-tar",
    "recetario": "re-ce-ta-rio",
    "recetor": "re-ce-tor",
    "recetoría": "re-ce-to-rí-a",
    "rechace": "re-cha-ce",
    "rechazable": "re-cha-za-ble",
    "rechazador": "re-cha-za-dor",
    "rechazadora": "re-cha-za-do-ra",
    "rechazamiento": "re-cha-za-mien-to",
    "rechazar": "re-cha-zar",
    "rechazo": "re-cha-zo",
    "rechifla": "re-chi-fla",
    "rechiflar": "re-chi-flar",
    "rechinador": "re-chi-na-dor",
    "rechinadora": "re-chi-na-do-ra",
    "rechinamiento": "re-chi-na-mien-to",
    "rechinar": "re-chi-nar",
    "rechinido": "re-chi-ni-do",
    "rechino": "re-chi-no",
    "rechistar": "re-chis-tar",
    "rechizar": "re-chi-zar",
    "recholata": "re-cho-la-ta",
    "rechoncha": "re-chon-cha",
    "rechoncho": "re-chon-cho",
    "rechupete": "re-chu-pe-te",
    "recia": "re-cia",
    "recial": "re-cial",
    "reciamente": "re-cia-men-te",
    "reciario": "re-cia-rio",
    "recibí": "re-ci-bí",
    "recibida": "re-ci-bi-da",
    "recibidera": "re-ci-bi-de-ra",
    "recibidero": "re-ci-bi-de-ro",
    "recibido": "re-ci-bi-do",
    "recibidor": "re-ci-bi-dor",
    "recibidora": "re-ci-bi-do-ra",
    "recibimiento": "re-ci-bi-mien-to",
    "recibir": "re-ci-bir",
    "recibo": "re-ci-bo",
    "reciclable": "re-ci-cla-ble",
    "reciclado": "re-ci-cla-do",
    "reciclaje": "re-ci-cla-je",
    "reciclamiento": "re-ci-cla-mien-to",
    "reciclar": "re-ci-clar",
    "recidiva": "re-ci-di-va",
    "recidivar": "re-ci-di-var",
    "reciedumbre": "re-cie-dum-bre",
    "recién": "re-cién",
    "reciente": "re-cien-te",
    "recientemente": "re-cien-te-men-te",
    "recinchar": "re-cin-char",
    "recincho": "re-cin-cho",
    "recinto": "re-cin-to",
    "recio": "re-cio",
    "récipe": "ré-ci-pe",
    "recipiendaria": "re-ci-pien-da-ria",
    "recipiendario": "re-ci-pien-da-rio",
    "recipiente": "re-ci-pien-te",
    "recíproca": "re-cí-pro-ca",
    "reciprocación": "re-ci-pro-ca-ción",
    "recíprocamente": "re-cí-pro-ca-men-te",
    "reciprocar": "re-ci-pro-car",
    "reciprocidad": "re-ci-pro-ci-dad",
    "recíproco": "re-cí-pro-co",
    "recitación": "re-ci-ta-ción",
    "recitáculo": "re-ci-tá-cu-lo",
    "recitado": "re-ci-ta-do",
    "recitador": "re-ci-ta-dor",
    "recitadora": "re-ci-ta-do-ra",
    "recital": "re-ci-tal",
    "recitanta": "re-ci-tan-ta",
    "recitante": "re-ci-tan-te",
    "recitar": "re-ci-tar",
    "recitativo": "re-ci-ta-ti-vo",
    "reciura": "re-ciu-ra",
    "recizalla": "re-ci-za-lla",
    "reclamación": "re-cla-ma-ción",
    "reclamante": "re-cla-man-te",
    "reclamar": "re-cla-mar",
    "reclame": "re-cla-me",
    "reclamo": "re-cla-mo",
    "recle": "re-cle",
    "reclinable": "re-cli-na-ble",
    "reclinación": "re-cli-na-ción",
    "reclinar": "re-cli-nar",
    "reclinatorio": "re-cli-na-to-rio",
    "recluir": "re-cluir",
    "reclusa": "re-clu-sa",
    "reclusión": "re-clu-sión",
    "recluso": "re-clu-so",
    "reclusorio": "re-clu-so-rio",
    "recluta": "re-clu-ta",
    "reclutador": "re-clu-ta-dor",
    "reclutamiento": "re-clu-ta-mien-to",
    "reclutar": "re-clu-tar",
    "recobración": "re-co-bra-ción",
    "recobramiento": "re-co-bra-mien-to",
    "recobrar": "re-co-brar",
    "recobro": "re-co-bro",
    "recocer": "re-co-cer",
    "recocha": "re-co-cha",
    "recochinear": "re-co-chi-ne-ar",
    "recochineo": "re-co-chi-ne-o",
    "recocho": "re-co-cho",
    "recocida": "re-co-ci-da",
    "recocido": "re-co-ci-do",
    "recocina": "re-co-ci-na",
    "recocta": "re-coc-ta",
    "recodadero": "re-co-da-de-ro",
    "recodar": "re-co-dar",
    "recodir": "re-co-dir",
    "recodo": "re-co-do",
    "recogeabuelos": "re-co-ge-a-bue-los",
    "recogedero": "re-co-ge-de-ro",
    "recogedor": "re-co-ge-dor",
    "recogedora": "re-co-ge-do-ra",
    "recogemigas": "re-co-ge-mi-gas",
    "recogepelotas": "re-co-ge-pe-lo-tas",
    "recoger": "re-co-ger",
    "recogida": "re-co-gi-da",
    "recogidamente": "re-co-gi-da-men-te",
    "recogido": "re-co-gi-do",
    "recogimiento": "re-co-gi-mien-to",
    "recolado": "re-co-la-do",
    "recolar": "re-co-lar",
    "recolección": "re-co-lec-ción",
    "recolectar": "re-co-lec-tar",
    "recolector": "re-co-lec-tor",
    "recolectora": "re-co-lec-to-ra",
    "recolegir": "re-co-le-gir",
    "recoleta": "re-co-le-ta",
    "recoleto": "re-co-le-to",
    "recolocación": "re-co-lo-ca-ción",
    "recombinación": "re-com-bi-na-ción",
    "recomendable": "re-co-men-da-ble",
    "recomendablemente": "re-co-men-da-ble-men-te",
    "recomendación": "re-co-men-da-ción",
    "recomendada": "re-co-men-da-da",
    "recomendado": "re-co-men-da-do",
    "recomendante": "re-co-men-dan-te",
    "recomendar": "re-co-men-dar",
    "recomendatoria": "re-co-men-da-to-ria",
    "recomendatorio": "re-co-men-da-to-rio",
    "recomenzar": "re-co-men-zar",
    "recomer": "re-co-mer",
    "recomerse": "re-co-mer-se",
    "recompensa": "re-com-pen-sa",
    "recompensable": "re-com-pen-sa-ble",
    "recompensación": "re-com-pen-sa-ción",
    "recompensar": "re-com-pen-sar",
    "recomponer": "re-com-po-ner",
    "recomposición": "re-com-po-si-ción",
    "recompuesta": "re-com-pues-ta",
    "recompuesto": "re-com-pues-to",
    "reconcentración": "re-con-cen-tra-ción",
    "reconcentramiento": "re-con-cen-tra-mien-to",
    "reconcentrar": "re-con-cen-trar",
    "reconciliable": "re-con-ci-lia-ble",
    "reconciliación": "re-con-ci-lia-ción",
    "reconciliador": "re-con-ci-lia-dor",
    "reconciliadora": "re-con-ci-lia-do-ra",
    "reconciliar": "re-con-ci-liar",
    "reconcomer": "re-con-co-mer",
    "reconcomerse": "re-con-co-mer-se",
    "reconcomio": "re-con-co-mio",
    "recondenar": "re-con-de-nar",
    "recóndita": "re-cón-di-ta",
    "reconditez": "re-con-di-tez",
    "recóndito": "re-cón-di-to",
    "reconducción": "re-con-duc-ción",
    "reconducir": "re-con-du-cir",
    "reconfortante": "re-con-for-tan-te",
    "reconfortar": "re-con-for-tar",
    "reconocedor": "re-co-no-ce-dor",
    "reconocedora": "re-co-no-ce-do-ra",
    "reconocer": "re-co-no-cer",
    "reconocible": "re-co-no-ci-ble",
    "reconocida": "re-co-no-ci-da",
    "reconocidamente": "re-co-no-ci-da-men-te",
    "reconocido": "re-co-no-ci-do",
    "reconocimiento": "re-co-no-ci-mien-to",
    "reconquista": "re-con-quis-ta",
    "reconquistador": "re-con-quis-ta-dor",
    "reconquistar": "re-con-quis-tar",
    "reconsideración": "re-con-si-de-ra-ción",
    "reconsiderar": "re-con-si-de-rar",
    "reconstitución": "re-cons-ti-tu-ción",
    "reconstituir": "re-cons-ti-tuir",
    "reconstituyente": "re-cons-ti-tu-yen-te",
    "reconstrucción": "re-cons-truc-ción",
    "reconstructiva": "re-cons-truc-ti-va",
    "reconstructivo": "re-cons-truc-ti-vo",
    "reconstruir": "re-cons-truir",
    "recontamiento": "re-con-ta-mien-to",
    "recontar": "re-con-tar",
    "recontenta": "re-con-ten-ta",
    "recontento": "re-con-ten-to",
    "reconvalecer": "re-con-va-le-cer",
    "reconvención": "re-con-ven-ción",
    "reconvenir": "re-con-ve-nir",
    "reconversión": "re-con-ver-sión",
    "reconvertir": "re-con-ver-tir",
    "recopilación": "re-co-pi-la-ción",
    "recopilada": "re-co-pi-la-da",
    "recopilado": "re-co-pi-la-do",
    "recopilador": "re-co-pi-la-dor",
    "recopiladora": "re-co-pi-la-do-ra",
    "recopilar": "re-co-pi-lar",
    "recopilatorio": "re-co-pi-la-to-rio",
    "recoquín": "re-co-quín",
    "recórcholis": "re-cór-cho-lis",
    "récord": "ré-cord",
    "recordable": "re-cor-da-ble",
    "recordación": "re-cor-da-ción",
    "recordador": "re-cor-da-dor",
    "recordadora": "re-cor-da-do-ra",
    "recordamiento": "re-cor-da-mien-to",
    "recordar": "re-cor-dar",
    "recordativa": "re-cor-da-ti-va",
    "recordativo": "re-cor-da-ti-vo",
    "recordatorio": "re-cor-da-to-rio",
    "recorrer": "re-co-rrer",
    "recorrida": "re-co-rri-da",
    "recorrido": "re-co-rri-do",
    "recortable": "re-cor-ta-ble",
    "recortada": "re-cor-ta-da",
    "recortado": "re-cor-ta-do",
    "recortadura": "re-cor-ta-du-ra",
    "recortar": "re-cor-tar",
    "recorte": "re-cor-te",
    "recorva": "re-cor-va",
    "recorvar": "re-cor-var",
    "recorvo": "re-cor-vo",
    "recoser": "re-co-ser",
    "recosido": "re-co-si-do",
    "recostadero": "re-cos-ta-de-ro",
    "recostar": "re-cos-tar",
    "recova": "re-co-va",
    "recovar": "re-co-var",
    "recoveco": "re-co-ve-co",
    "recovera": "re-co-ve-ra",
    "recovero": "re-co-ve-ro",
    "recre": "re-cre",
    "recreable": "re-cre-a-ble",
    "recreación": "re-cre-a-ción",
    "recrear": "re-cre-ar",
    "recreativa": "re-cre-a-ti-va",
    "recreativo": "re-cre-a-ti-vo",
    "recrecer": "re-cre-cer",
    "recrecimiento": "re-cre-ci-mien-to",
    "recreída": "re-cre-í-da",
    "recreído": "re-cre-í-do",
    "recrementicia": "re-cre-men-ti-cia",
    "recrementicio": "re-cre-men-ti-cio",
    "recremento": "re-cre-men-to",
    "recreo": "re-cre-o",
    "recría": "re-crí-a",
    "recriador": "re-cria-dor",
    "recriar": "re-criar",
    "recriminación": "re-cri-mi-na-ción",
    "recriminador": "re-cri-mi-na-dor",
    "recriminadora": "re-cri-mi-na-do-ra",
    "recriminar": "re-cri-mi-nar",
    "recriminatorio": "re-cri-mi-na-to-rio",
    "recrucetada": "re-cru-ce-ta-da",
    "recrucetado": "re-cru-ce-ta-do",
    "recrudecer": "re-cru-de-cer",
    "recrudecimiento": "re-cru-de-ci-mien-to",
    "recrudescencia": "re-cru-des-cen-cia",
    "recrujir": "re-cru-jir",
    "recruzar": "re-cru-zar",
    "recta": "rec-ta",
    "rectal": "rec-tal",
    "rectamente": "rec-ta-men-te",
    "rectángula": "rec-tán-gu-la",
    "rectangular": "rec-tan-gu-lar",
    "rectángulo": "rec-tán-gu-lo",
    "rectar": "rec-tar",
    "rectificable": "rec-ti-fi-ca-ble",
    "rectificación": "rec-ti-fi-ca-ción",
    "rectificador": "rec-ti-fi-ca-dor",
    "rectificadora": "rec-ti-fi-ca-do-ra",
    "rectificar": "rec-ti-fi-car",
    "rectificativa": "rec-ti-fi-ca-ti-va",
    "rectificativo": "rec-ti-fi-ca-ti-vo",
    "rectilínea": "rec-ti-lí-ne-a",
    "rectilíneo": "rec-ti-lí-ne-o",
    "rectitud": "rec-ti-tud",
    "recto": "rec-to",
    "rector": "rec-tor",
    "rectora": "rec-to-ra",
    "rectorado": "rec-to-ra-do",
    "rectoral": "rec-to-ral",
    "rectorar": "rec-to-rar",
    "rectoría": "rec-to-rí-a",
    "rectoscopia": "rec-tos-co-pia",
    "rectoscopio": "rec-tos-co-pio",
    "recua": "re-cua",
    "recuadrar": "re-cua-drar",
    "recuadro": "re-cua-dro",
    "recuaje": "re-cua-je",
    "recuarta": "re-cuar-ta",
    "recubierto": "re-cu-bier-to",
    "recubrimiento": "re-cu-bri-mien-to",
    "recubrir": "re-cu-brir",
    "recudida": "re-cu-di-da",
    "recudidero": "re-cu-di-de-ro",
    "recudimento": "re-cu-di-men-to",
    "recudimiento": "re-cu-di-mien-to",
    "recudir": "re-cu-dir",
    "recuelo": "re-cue-lo",
    "recuento": "re-cuen-to",
    "recuentro": "re-cuen-tro",
    "recuerdo": "re-cuer-do",
    "recuero": "re-cue-ro",
    "recuesta": "re-cues-ta",
    "recuestador": "re-cues-ta-dor",
    "recuestadora": "re-cues-ta-do-ra",
    "recuestar": "re-cues-tar",
    "recuesto": "re-cues-to",
    "recula": "re-cu-la",
    "reculada": "re-cu-la-da",
    "recular": "re-cu-lar",
    "reculo": "re-cu-lo",
    "reculón": "re-cu-lón",
    "reculona": "re-cu-lo-na",
    "recuñar": "re-cu-ñar",
    "recuperable": "re-cu-pe-ra-ble",
    "recuperación": "re-cu-pe-ra-ción",
    "recuperador": "re-cu-pe-ra-dor",
    "recuperadora": "re-cu-pe-ra-do-ra",
    "recuperar": "re-cu-pe-rar",
    "recuperativa": "re-cu-pe-ra-ti-va",
    "recuperativo": "re-cu-pe-ra-ti-vo",
    "recupero": "re-cu-pe-ro",
    "recura": "re-cu-ra",
    "recurar": "re-cu-rar",
    "recurrencia": "re-cu-rren-cia",
    "recurrente": "re-cu-rren-te",
    "recurrible": "re-cu-rri-ble",
    "recurrida": "re-cu-rri-da",
    "recurrido": "re-cu-rri-do",
    "recurrir": "re-cu-rrir",
    "recursividad": "re-cur-si-vi-dad",
    "recursivo": "re-cur-si-vo",
    "recurso": "re-cur-so",
    "recurvado": "re-cur-va-do",
    "recusable": "re-cu-sa-ble",
    "recusación": "re-cu-sa-ción",
    "recusante": "re-cu-san-te",
    "recusar": "re-cu-sar",
    "redacción": "re-dac-ción",
    "redactar": "re-dac-tar",
    "redactor": "re-dac-tor",
    "redactora": "re-dac-to-ra",
    "redada": "re-da-da",
    "redaño": "re-da-ño",
    "redar": "re-dar",
    "redargución": "re-dar-gu-ción",
    "redargüir": "re-dar-güir",
    "redaya": "re-da-ya",
    "redecilla": "re-de-ci-lla",
    "redecir": "re-de-cir",
    "rededor": "re-de-dor",
    "redefinición": "re-de-fi-ni-ción",
    "redefinir": "re-de-fi-nir",
    "redejón": "re-de-jón",
    "redel": "re-del",
    "redeña": "re-de-ña",
    "redención": "re-den-ción",
    "redendija": "re-den-di-ja",
    "redentor": "re-den-tor",
    "redentora": "re-den-to-ra",
    "redentorista": "re-den-to-ris-ta",
    "redera": "re-de-ra",
    "redero": "re-de-ro",
    "redescontar": "re-des-con-tar",
    "redescubrimiento": "re-des-cu-bri-mien-to",
    "redescubrir": "re-des-cu-brir",
    "redescuento": "re-des-cuen-to",
    "redespachar": "re-des-pa-char",
    "redespacho": "re-des-pa-cho",
    "redhibición": "re-dhi-bi-ción",
    "redhibir": "re-dhi-bir",
    "redhibitoria": "re-dhi-bi-to-ria",
    "redhibitorio": "re-dhi-bi-to-rio",
    "redicha": "re-di-cha",
    "redicho": "re-di-cho",
    "redición": "re-di-ción",
    "rediez": "re-diez",
    "rediezmar": "re-diez-mar",
    "rediezmo": "re-diez-mo",
    "redil": "re-dil",
    "redilar": "re-di-lar",
    "redilas": "re-di-las",
    "redilear": "re-di-le-ar",
    "redileo": "re-di-le-o",
    "redimensionamiento": "re-di-men-sio-na-mien-to",
    "redimensionar": "re-di-men-sio-nar",
    "redimible": "re-di-mi-ble",
    "redimidor": "re-di-mi-dor",
    "redimidora": "re-di-mi-do-ra",
    "redimir": "re-di-mir",
    "redingote": "re-din-go-te",
    "rediós": "re-diós",
    "rediseñar": "re-di-se-ñar",
    "redistribución": "re-dis-tri-bu-ción",
    "redistribuir": "re-dis-tri-buir",
    "rédito": "ré-di-to",
    "redituable": "re-di-tua-ble",
    "reditual": "re-di-tual",
    "redituar": "re-di-tuar",
    "rediviva": "re-di-vi-va",
    "redivivo": "re-di-vi-vo",
    "redoblada": "re-do-bla-da",
    "redoblado": "re-do-bla-do",
    "redobladura": "re-do-bla-du-ra",
    "redoblamiento": "re-do-bla-mien-to",
    "redoblante": "re-do-blan-te",
    "redoblar": "re-do-blar",
    "redoble": "re-do-ble",
    "redoblegar": "re-do-ble-gar",
    "redoblón": "re-do-blón",
    "redol": "re-dol",
    "redola": "re-do-la",
    "redolada": "re-do-la-da",
    "redolar": "re-do-lar",
    "redolente": "re-do-len-te",
    "redoliente": "re-do-lien-te",
    "redolón": "re-do-lón",
    "redolor": "re-do-lor",
    "redoma": "re-do-ma",
    "redomada": "re-do-ma-da",
    "redomado": "re-do-ma-do",
    "redomazo": "re-do-ma-zo",
    "redomón": "re-do-món",
    "redomona": "re-do-mo-na",
    "redonda": "re-don-da",
    "redondamente": "re-don-da-men-te",
    "redondeada": "re-don-de-a-da",
    "redondeado": "re-don-de-a-do",
    "redondear": "re-don-de-ar",
    "redondel": "re-don-del",
    "redondela": "re-don-de-la",
    "redondeo": "re-don-de-o",
    "redondez": "re-don-dez",
    "redondilla": "re-don-di-lla",
    "redondillo": "re-don-di-llo",
    "redondo": "re-don-do",
    "redondón": "re-don-dón",
    "redopelo": "re-do-pe-lo",
    "redor": "re-dor",
    "redorar": "re-do-rar",
    "redova": "re-do-va",
    "redrar": "re-drar",
    "redro": "re-dro",
    "redrojar": "re-dro-jar",
    "redrojo": "re-dro-jo",
    "redropelo": "re-dro-pe-lo",
    "redrosaca": "re-dro-sa-ca",
    "redroviento": "re-dro-vien-to",
    "redruejo": "re-drue-jo",
    "reducción": "re-duc-ción",
    "reduccionismo": "re-duc-cio-nis-mo",
    "reducible": "re-du-ci-ble",
    "reducida": "re-du-ci-da",
    "reducido": "re-du-ci-do",
    "reducidor": "re-du-ci-dor",
    "reducidora": "re-du-ci-do-ra",
    "reducimiento": "re-du-ci-mien-to",
    "reducir": "re-du-cir",
    "reductible": "re-duc-ti-ble",
    "reducto": "re-duc-to",
    "reductor": "re-duc-tor",
    "reductora": "re-duc-to-ra",
    "redundancia": "re-dun-dan-cia",
    "redundante": "re-dun-dan-te",
    "redundar": "re-dun-dar",
    "reduplicación": "re-du-pli-ca-ción",
    "reduplicar": "re-du-pli-car",
    "reduplicativo": "re-du-pli-ca-ti-vo",
    "reduvio": "re-du-vio",
    "reedición": "re-e-di-ción",
    "reedificación": "re-e-di-fi-ca-ción",
    "reedificador": "re-e-di-fi-ca-dor",
    "reedificadora": "re-e-di-fi-ca-do-ra",
    "reedificar": "re-e-di-fi-car",
    "reeditar": "re-e-di-tar",
    "reeducación": "re-e-du-ca-ción",
    "reeducar": "re-e-du-car",
    "reelaboración": "re-e-la-bo-ra-ción",
    "reelaborar": "re-e-la-bo-rar",
    "reelección": "re-e-lec-ción",
    "reelecta": "re-e-lec-ta",
    "reelecto": "re-e-lec-to",
    "reelegible": "re-e-le-gi-ble",
    "reelegir": "re-e-le-gir",
    "reembarcar": "re-em-bar-car",
    "reembarque": "re-em-bar-que",
    "reembolsable": "re-em-bol-sa-ble",
    "reembolsar": "re-em-bol-sar",
    "reembolso": "re-em-bol-so",
    "reemplazable": "re-em-pla-za-ble",
    "reemplazante": "re-em-pla-zan-te",
    "reemplazar": "re-em-pla-zar",
    "reemplazo": "re-em-pla-zo",
    "reemprender": "re-em-pren-der",
    "reencarnación": "re-en-car-na-ción",
    "reencarnar": "re-en-car-nar",
    "reencauchadora": "re-en-cau-cha-do-ra",
    "reencauchar": "re-en-cau-char",
    "reencauche": "re-en-cau-che",
    "reencontrar": "re-en-con-trar",
    "reencuache": "re-en-cua-che",
    "reencuadernación": "re-en-cua-der-na-ción",
    "reencuadernar": "re-en-cua-der-nar",
    "reencuentro": "re-en-cuen-tro",
    "reenganchamiento": "re-en-gan-cha-mien-to",
    "reenganchar": "re-en-gan-char",
    "reenganche": "re-en-gan-che",
    "reengendrador": "re-en-gen-dra-dor",
    "reengendradora": "re-en-gen-dra-do-ra",
    "reengendrar": "re-en-gen-drar",
    "reensayar": "re-en-sa-yar",
    "reensaye": "re-en-sa-ye",
    "reensayo": "re-en-sa-yo",
    "reentrada": "re-en-tra-da",
    "reenviar": "re-en-viar",
    "reenvidar": "re-en-vi-dar",
    "reenvío": "re-en-ví-o",
    "reenvite": "re-en-vi-te",
    "reescribir": "re-es-cri-bir",
    "reescritura": "re-es-cri-tu-ra",
    "reestrenar": "re-es-tre-nar",
    "reestreno": "re-es-tre-no",
    "reestructuración": "re-es-truc-tu-ra-ción",
    "reestructurar": "re-es-truc-tu-rar",
    "reexaminación": "re-e-xa-mi-na-ción",
    "reexaminar": "re-e-xa-mi-nar",
    "reexpedición": "re-ex-pe-di-ción",
    "reexpedir": "re-ex-pe-dir",
    "reexportar": "re-ex-por-tar",
    "refacción": "re-fac-ción",
    "refaccionar": "re-fac-cio-nar",
    "refaccionaria": "re-fac-cio-na-ria",
    "refaccionario": "re-fac-cio-na-rio",
    "refacer": "re-fa-cer",
    "refajo": "re-fa-jo",
    "refalín": "re-fa-lín",
    "refalines": "re-fa-li-nes",
    "refalosa": "re-fa-lo-sa",
    "refalsada": "re-fal-sa-da",
    "refalsado": "re-fal-sa-do",
    "refanfinflar": "re-fan-fin-flar",
    "refección": "re-fec-ción",
    "refeccionar": "re-fec-cio-nar",
    "refeccionaria": "re-fec-cio-na-ria",
    "refeccionario": "re-fec-cio-na-rio",
    "refectolera": "re-fec-to-le-ra",
    "refectolero": "re-fec-to-le-ro",
    "refectorio": "re-fec-to-rio",
    "referencia": "re-fe-ren-cia",
    "referencial": "re-fe-ren-cial",
    "referendario": "re-fe-ren-da-rio",
    "referendo": "re-fe-ren-do",
    "referéndum": "re-fe-rén-dum",
    "referente": "re-fe-ren-te",
    "referí": "re-fe-rí",
    "réferi": "ré-fe-ri",
    "referible": "re-fe-ri-ble",
    "referimiento": "re-fe-ri-mien-to",
    "referir": "re-fe-rir",
    "refertar": "re-fer-tar",
    "refertera": "re-fer-te-ra",
    "refertero": "re-fer-te-ro",
    "refez": "re-fez",
    "refigurar": "re-fi-gu-rar",
    "refilar": "re-fi-lar",
    "refilón": "re-fi-lón",
    "refina": "re-fi-na",
    "refinación": "re-fi-na-ción",
    "refinada": "re-fi-na-da",
    "refinadera": "re-fi-na-de-ra",
    "refinado": "re-fi-na-do",
    "refinador": "re-fi-na-dor",
    "refinadora": "re-fi-na-do-ra",
    "refinadura": "re-fi-na-du-ra",
    "refinamiento": "re-fi-na-mien-to",
    "refinanciación": "re-fi-nan-cia-ción",
    "refinanciar": "re-fi-nan-ciar",
    "refinar": "re-fi-nar",
    "refinería": "re-fi-ne-rí-a",
    "refino": "re-fi-no",
    "refirmar": "re-fir-mar",
    "refistolero": "re-fis-to-le-ro",
    "refitolear": "re-fi-to-le-ar",
    "refitolera": "re-fi-to-le-ra",
    "refitolería": "re-fi-to-le-rí-a",
    "refitolero": "re-fi-to-le-ro",
    "refitor": "re-fi-tor",
    "refitorio": "re-fi-to-rio",
    "reflectante": "re-flec-tan-te",
    "reflectar": "re-flec-tar",
    "reflector": "re-flec-tor",
    "reflectora": "re-flec-to-ra",
    "refleja": "re-fle-ja",
    "reflejar": "re-fle-jar",
    "reflejo": "re-fle-jo",
    "réflex": "ré-flex",
    "reflexible": "re-fle-xi-ble",
    "reflexión": "re-fle-xión",
    "reflexionar": "re-fle-xio-nar",
    "reflexiva": "re-fle-xi-va",
    "reflexivamente": "re-fle-xi-va-men-te",
    "reflexividad": "re-fle-xi-vi-dad",
    "reflexivo": "re-fle-xi-vo",
    "reflexología": "re-fle-xo-lo-gí-a",
    "reflexoterapia": "re-fle-xo-te-ra-pia",
    "reflorecer": "re-flo-re-cer",
    "reflorecimiento": "re-flo-re-ci-mien-to",
    "reflotación": "re-flo-ta-ción",
    "reflotamiento": "re-flo-ta-mien-to",
    "reflotar": "re-flo-tar",
    "refluir": "re-fluir",
    "reflujo": "re-flu-jo",
    "refocilación": "re-fo-ci-la-ción",
    "refocilar": "re-fo-ci-lar",
    "refocilo": "re-fo-ci-lo",
    "reforestación": "re-fo-res-ta-ción",
    "reforestar": "re-fo-res-tar",
    "reforma": "re-for-ma",
    "reformable": "re-for-ma-ble",
    "reformación": "re-for-ma-ción",
    "reformada": "re-for-ma-da",
    "reformado": "re-for-ma-do",
    "reformador": "re-for-ma-dor",
    "reformadora": "re-for-ma-do-ra",
    "reformar": "re-for-mar",
    "reformativa": "re-for-ma-ti-va",
    "reformativo": "re-for-ma-ti-vo",
    "reformatoria": "re-for-ma-to-ria",
    "reformatorio": "re-for-ma-to-rio",
    "reformismo": "re-for-mis-mo",
    "reformista": "re-for-mis-ta",
    "reforzada": "re-for-za-da",
    "reforzado": "re-for-za-do",
    "reforzador": "re-for-za-dor",
    "reforzadora": "re-for-za-do-ra",
    "reforzamiento": "re-for-za-mien-to",
    "reforzar": "re-for-zar",
    "refracción": "re-frac-ción",
    "refracta": "re-frac-ta",
    "refractante": "re-frac-tan-te",
    "refractar": "re-frac-tar",
    "refractaria": "re-frac-ta-ria",
    "refractario": "re-frac-ta-rio",
    "refractiva": "re-frac-ti-va",
    "refractivo": "re-frac-ti-vo",
    "refracto": "re-frac-to",
    "refractómetro": "re-frac-tó-me-tro",
    "refractor": "re-frac-tor",
    "refrán": "re-frán",
    "refranero": "re-fra-ne-ro",
    "refranesca": "re-fra-nes-ca",
    "refranesco": "re-fra-nes-co",
    "refrangibilidad": "re-fran-gi-bi-li-dad",
    "refrangible": "re-fran-gi-ble",
    "refranista": "re-fra-nis-ta",
    "refregadura": "re-fre-ga-du-ra",
    "refregamiento": "re-fre-ga-mien-to",
    "refregar": "re-fre-gar",
    "refregón": "re-fre-gón",
    "refreír": "re-fre-ír",
    "refrenable": "re-fre-na-ble",
    "refrenada": "re-fre-na-da",
    "refrenamiento": "re-fre-na-mien-to",
    "refrenar": "re-fre-nar",
    "refrendación": "re-fren-da-ción",
    "refrendar": "re-fren-dar",
    "refrendario": "re-fren-da-rio",
    "refrendata": "re-fren-da-ta",
    "refrendo": "re-fren-do",
    "refrescador": "re-fres-ca-dor",
    "refrescadora": "re-fres-ca-do-ra",
    "refrescadura": "re-fres-ca-du-ra",
    "refrescamiento": "re-fres-ca-mien-to",
    "refrescante": "re-fres-can-te",
    "refrescar": "re-fres-car",
    "refresco": "re-fres-co",
    "refresquería": "re-fres-que-rí-a",
    "refriante": "re-frian-te",
    "refriar": "re-friar",
    "refriega": "re-frie-ga",
    "refrigeración": "re-fri-ge-ra-ción",
    "refrigerador": "re-fri-ge-ra-dor",
    "refrigeradora": "re-fri-ge-ra-do-ra",
    "refrigerante": "re-fri-ge-ran-te",
    "refrigerar": "re-fri-ge-rar",
    "refrigerativa": "re-fri-ge-ra-ti-va",
    "refrigerativo": "re-fri-ge-ra-ti-vo",
    "refrigerio": "re-fri-ge-rio",
    "refringencia": "re-frin-gen-cia",
    "refringente": "re-frin-gen-te",
    "refringir": "re-frin-gir",
    "refrito": "re-fri-to",
    "refucilar": "re-fu-ci-lar",
    "refucilo": "re-fu-ci-lo",
    "refuego": "re-fue-go",
    "refuerzo": "re-fuer-zo",
    "refugiada": "re-fu-gia-da",
    "refugiado": "re-fu-gia-do",
    "refugiar": "re-fu-giar",
    "refugio": "re-fu-gio",
    "refulgencia": "re-ful-gen-cia",
    "refulgente": "re-ful-gen-te",
    "refulgir": "re-ful-gir",
    "refundación": "re-fun-da-ción",
    "refundición": "re-fun-di-ción",
    "refundido": "re-fun-di-do",
    "refundidor": "re-fun-di-dor",
    "refundidora": "re-fun-di-do-ra",
    "refundir": "re-fun-dir",
    "refunfuñador": "re-fun-fu-ña-dor",
    "refunfuñadora": "re-fun-fu-ña-do-ra",
    "refunfuñadura": "re-fun-fu-ña-du-ra",
    "refunfuñar": "re-fun-fu-ñar",
    "refunfuño": "re-fun-fu-ño",
    "refunfuñón": "re-fun-fu-ñón",
    "refunfuñona": "re-fun-fu-ño-na",
    "refutable": "re-fu-ta-ble",
    "refutación": "re-fu-ta-ción",
    "refutar": "re-fu-tar",
    "refutatoria": "re-fu-ta-to-ria",
    "refutatorio": "re-fu-ta-to-rio",
    "regabina": "re-ga-bi-na",
    "regabinar": "re-ga-bi-nar",
    "regable": "re-ga-ble",
    "regacear": "re-ga-ce-ar",
    "regada": "re-ga-da",
    "regadera": "re-ga-de-ra",
    "regaderazo": "re-ga-de-ra-zo",
    "regadero": "re-ga-de-ro",
    "regadía": "re-ga-dí-a",
    "regadío": "re-ga-dí-o",
    "regadiza": "re-ga-di-za",
    "regadizo": "re-ga-di-zo",
    "regado": "re-ga-do",
    "regador": "re-ga-dor",
    "regadora": "re-ga-do-ra",
    "regadura": "re-ga-du-ra",
    "regaifa": "re-gai-fa",
    "regajal": "re-ga-jal",
    "regajo": "re-ga-jo",
    "regala": "re-ga-la",
    "regalada": "re-ga-la-da",
    "regaladamente": "re-ga-la-da-men-te",
    "regalado": "re-ga-la-do",
    "regalador": "re-ga-la-dor",
    "regaladora": "re-ga-la-do-ra",
    "regalamiento": "re-ga-la-mien-to",
    "regalar": "re-ga-lar",
    "regalaría": "re-ga-la-rí-a",
    "regalero": "re-ga-le-ro",
    "regalía": "re-ga-lí-a",
    "regalicia": "re-ga-li-cia",
    "regalillo": "re-ga-li-llo",
    "regalismo": "re-ga-lis-mo",
    "regalista": "re-ga-lis-ta",
    "regaliz": "re-ga-liz",
    "regaliza": "re-ga-li-za",
    "regalo": "re-ga-lo",
    "regalón": "re-ga-lón",
    "regalona": "re-ga-lo-na",
    "regalonear": "re-ga-lo-ne-ar",
    "regañada": "re-ga-ña-da",
    "regañadientes": "re-ga-ña-dien-tes",
    "regañado": "re-ga-ña-do",
    "regañamiento": "re-ga-ña-mien-to",
    "regañar": "re-ga-ñar",
    "regañera": "re-ga-ñe-ra",
    "regañina": "re-ga-ñi-na",
    "regañir": "re-ga-ñir",
    "regaño": "re-ga-ño",
    "regañón": "re-ga-ñón",
    "regañona": "re-ga-ño-na",
    "regante": "re-gan-te",
    "regar": "re-gar",
    "regata": "re-ga-ta",
    "regate": "re-ga-te",
    "regatear": "re-ga-te-ar",
    "regateo": "re-ga-te-o",
    "regatera": "re-ga-te-ra",
    "regatería": "re-ga-te-rí-a",
    "regatero": "re-ga-te-ro",
    "regatista": "re-ga-tis-ta",
    "regato": "re-ga-to",
    "regatón": "re-ga-tón",
    "regatona": "re-ga-to-na",
    "regatonear": "re-ga-to-ne-ar",
    "regatonería": "re-ga-to-ne-rí-a",
    "regazar": "re-ga-zar",
    "regazo": "re-ga-zo",
    "regencia": "re-gen-cia",
    "regeneración": "re-ge-ne-ra-ción",
    "regeneracionismo": "re-ge-ne-ra-cio-nis-mo",
    "regeneracionista": "re-ge-ne-ra-cio-nis-ta",
    "regenerado": "re-ge-ne-ra-do",
    "regenerador": "re-ge-ne-ra-dor",
    "regeneradora": "re-ge-ne-ra-do-ra",
    "regenerar": "re-ge-ne-rar",
    "regenerativo": "re-ge-ne-ra-ti-vo",
    "regenta": "re-gen-ta",
    "regentar": "re-gen-tar",
    "regente": "re-gen-te",
    "regentear": "re-gen-te-ar",
    "reggae": "reg-ga-e",
    "regia": "re-gia",
    "regiamente": "re-gia-men-te",
    "regicida": "re-gi-ci-da",
    "regicidio": "re-gi-ci-dio",
    "regido": "re-gi-do",
    "regidor": "re-gi-dor",
    "regidora": "re-gi-do-ra",
    "regidoría": "re-gi-do-rí-a",
    "regiduría": "re-gi-du-rí-a",
    "régimen": "ré-gi-men",
    "regimentación": "re-gi-men-ta-ción",
    "regimentar": "re-gi-men-tar",
    "regimiento": "re-gi-mien-to",
    "regio": "re-gio",
    "regiomontana": "re-gio-mon-ta-na",
    "regiomontano": "re-gio-mon-ta-no",
    "región": "re-gión",
    "regional": "re-gio-nal",
    "regionalismo": "re-gio-na-lis-mo",
    "regionalista": "re-gio-na-lis-ta",
    "regionalización": "re-gio-na-li-za-ción",
    "regionalizar": "re-gio-na-li-zar",
    "regionaria": "re-gio-na-ria",
    "regionario": "re-gio-na-rio",
    "regir": "re-gir",
    "registrado": "re-gis-tra-do",
    "registrador": "re-gis-tra-dor",
    "registradora": "re-gis-tra-do-ra",
    "registral": "re-gis-tral",
    "registrar": "re-gis-trar",
    "registro": "re-gis-tro",
    "regitiva": "re-gi-ti-va",
    "regitivo": "re-gi-ti-vo",
    "regla": "re-gla",
    "reglada": "re-gla-da",
    "regladamente": "re-gla-da-men-te",
    "reglado": "re-gla-do",
    "reglaje": "re-gla-je",
    "reglamentación": "re-gla-men-ta-ción",
    "reglamentar": "re-gla-men-tar",
    "reglamentaria": "re-gla-men-ta-ria",
    "reglamentariamente": "re-gla-men-ta-ria-men-te",
    "reglamentario": "re-gla-men-ta-rio",
    "reglamentista": "re-gla-men-tis-ta",
    "reglamento": "re-gla-men-to",
    "reglar": "re-glar",
    "regleta": "re-gle-ta",
    "regletear": "re-gle-te-ar",
    "reglón": "re-glón",
    "regloscopio": "re-glos-co-pio",
    "regnícola": "reg-ní-co-la",
    "regocijada": "re-go-ci-ja-da",
    "regocijadamente": "re-go-ci-ja-da-men-te",
    "regocijado": "re-go-ci-ja-do",
    "regocijador": "re-go-ci-ja-dor",
    "regocijadora": "re-go-ci-ja-do-ra",
    "regocijar": "re-go-ci-jar",
    "regocijo": "re-go-ci-jo",
    "regodear": "re-go-de-ar",
    "regodearse": "re-go-de-ar-se",
    "regodeo": "re-go-de-o",
    "regodeón": "re-go-de-ón",
    "regojo": "re-go-jo",
    "regolaje": "re-go-la-je",
    "regoldana": "re-gol-da-na",
    "regoldano": "re-gol-da-no",
    "regoldar": "re-gol-dar",
    "regoldo": "re-gol-do",
    "regolfar": "re-gol-far",
    "regolfo": "re-gol-fo",
    "regomello": "re-go-me-llo",
    "regomeyo": "re-go-me-yo",
    "regona": "re-go-na",
    "regordeta": "re-gor-de-ta",
    "regordete": "re-gor-de-te",
    "regordida": "re-gor-di-da",
    "regordido": "re-gor-di-do",
    "regorgalla": "re-gor-ga-lla",
    "regorjar": "re-gor-jar",
    "regorjarse": "re-gor-jar-se",
    "regostar": "re-gos-tar",
    "regostarse": "re-gos-tar-se",
    "regosto": "re-gos-to",
    "regraciar": "re-gra-ciar",
    "regradecer": "re-gra-de-cer",
    "regresar": "re-gre-sar",
    "regresión": "re-gre-sión",
    "regresiva": "re-gre-si-va",
    "regresivo": "re-gre-si-vo",
    "regreso": "re-gre-so",
    "regruñir": "re-gru-ñir",
    "reguarda": "re-guar-da",
    "reguardadamente": "re-guar-da-da-men-te",
    "reguardar": "re-guar-dar",
    "reguardo": "re-guar-do",
    "regüeldo": "re-güel-do",
    "reguera": "re-gue-ra",
    "reguero": "re-gue-ro",
    "reguilar": "re-gui-lar",
    "reguilete": "re-gui-le-te",
    "regulable": "re-gu-la-ble",
    "regulación": "re-gu-la-ción",
    "regulada": "re-gu-la-da",
    "regulado": "re-gu-la-do",
    "regulador": "re-gu-la-dor",
    "reguladora": "re-gu-la-do-ra",
    "regular": "re-gu-lar",
    "regularidad": "re-gu-la-ri-dad",
    "regularización": "re-gu-la-ri-za-ción",
    "regularizador": "re-gu-la-ri-za-dor",
    "regularizadora": "re-gu-la-ri-za-do-ra",
    "regularizar": "re-gu-la-ri-zar",
    "regularmente": "re-gu-lar-men-te",
    "regulativa": "re-gu-la-ti-va",
    "regulativo": "re-gu-la-ti-vo",
    "régulo": "ré-gu-lo",
    "regurgitación": "re-gur-gi-ta-ción",
    "regurgitar": "re-gur-gi-tar",
    "regusto": "re-gus-to",
    "rehabilitación": "re-ha-bi-li-ta-ción",
    "rehabilitador": "re-ha-bi-li-ta-dor",
    "rehabilitadora": "re-ha-bi-li-ta-do-ra",
    "rehabilitar": "re-ha-bi-li-tar",
    "rehacer": "re-ha-cer",
    "rehacimiento": "re-ha-ci-mien-to",
    "rehala": "re-ha-la",
    "rehalero": "re-ha-le-ro",
    "rehalí": "re-ha-lí",
    "reharta": "re-har-ta",
    "rehartar": "re-har-tar",
    "reharto": "re-har-to",
    "rehecho": "re-he-cho",
    "rehelear": "re-he-le-ar",
    "reheleo": "re-he-le-o",
    "rehén": "re-hén",
    "rehenchido": "re-hen-chi-do",
    "rehenchimiento": "re-hen-chi-mien-to",
    "rehenchir": "re-hen-chir",
    "rehendija": "re-hen-di-ja",
    "reherimiento": "re-he-ri-mien-to",
    "reherir": "re-he-rir",
    "reherrar": "re-he-rrar",
    "rehervir": "re-her-vir",
    "rehiladillo": "rehi-la-di-llo",
    "rehilado": "rehi-la-do",
    "rehilamiento": "rehi-la-mien-to",
    "rehilandera": "rehi-lan-de-ra",
    "rehilante": "rehi-lan-te",
    "rehilar": "rehi-lar",
    "rehilero": "rehi-le-ro",
    "rehilete": "rehi-le-te",
    "rehiletero": "rehi-le-te-ro",
    "rehílo": "re-hí-lo",
    "rehinchimiento": "rehin-chi-mien-to",
    "rehinchir": "rehin-chir",
    "rehogar": "re-ho-gar",
    "rehollar": "re-ho-llar",
    "rehoya": "re-ho-ya",
    "rehoyar": "re-ho-yar",
    "rehoyo": "re-ho-yo",
    "rehuida": "re-hui-da",
    "rehuir": "re-huir",
    "rehumedecer": "rehu-me-de-cer",
    "rehundido": "rehun-di-do",
    "rehundir": "rehun-dir",
    "rehurtar": "rehur-tar",
    "rehurtarse": "rehur-tar-se",
    "rehús": "re-hús",
    "rehusar": "rehu-sar",
    "reidera": "rei-de-ra",
    "reidero": "rei-de-ro",
    "reidor": "rei-dor",
    "reidora": "rei-do-ra",
    "reificación": "rei-fi-ca-ción",
    "reiforme": "rei-for-me",
    "reilar": "rei-lar",
    "reilón": "rei-lón",
    "reimplantación": "reim-plan-ta-ción",
    "reimplantar": "reim-plan-tar",
    "reimplante": "reim-plan-te",
    "reimportación": "reim-por-ta-ción",
    "reimportar": "reim-por-tar",
    "reimpresa": "reim-pre-sa",
    "reimpresión": "reim-pre-sión",
    "reimpreso": "reim-pre-so",
    "reimprimir": "reim-pri-mir",
    "reina": "rei-na",
    "reinado": "rei-na-do",
    "reinador": "rei-na-dor",
    "reinadora": "rei-na-do-ra",
    "reinal": "rei-nal",
    "reinante": "rei-nan-te",
    "reinar": "rei-nar",
    "reinauguración": "rei-nau-gu-ra-ción",
    "reincidencia": "rein-ci-den-cia",
    "reincidente": "rein-ci-den-te",
    "reincidir": "rein-ci-dir",
    "reincorporación": "rein-cor-po-ra-ción",
    "reincorporar": "rein-cor-po-rar",
    "reindustrialización": "rein-dus-tria-li-za-ción",
    "reindustrializar": "rein-dus-tria-li-zar",
    "reineta": "rei-ne-ta",
    "reingresar": "rein-gre-sar",
    "reingreso": "rein-gre-so",
    "reinicializar": "rei-ni-cia-li-zar",
    "reiniciar": "rei-ni-ciar",
    "reinicio": "rei-ni-cio",
    "reino": "rei-no",
    "reinona": "rei-no-na",
    "reinosana": "rei-no-sa-na",
    "reinosano": "rei-no-sa-no",
    "reinserción": "rein-ser-ción",
    "reinsertada": "rein-ser-ta-da",
    "reinsertado": "rein-ser-ta-do",
    "reinsertar": "rein-ser-tar",
    "reinstalación": "reins-ta-la-ción",
    "reinstalar": "reins-ta-lar",
    "reinstauración": "reins-tau-ra-ción",
    "reinstaurar": "reins-tau-rar",
    "reintegrable": "rein-te-gra-ble",
    "reintegración": "rein-te-gra-ción",
    "reintegrar": "rein-te-grar",
    "reintegro": "rein-te-gro",
    "reinterpretación": "rein-ter-pre-ta-ción",
    "reinventar": "rein-ven-tar",
    "reinversión": "rein-ver-sión",
    "reinvertir": "rein-ver-tir",
    "reír": "re-ír",
    "reiteración": "rei-te-ra-ción",
    "reiteradamente": "rei-te-ra-da-men-te",
    "reiterado": "rei-te-ra-do",
    "reiterar": "rei-te-rar",
    "reiterativa": "rei-te-ra-ti-va",
    "reiterativo": "rei-te-ra-ti-vo",
    "reitre": "rei-tre",
    "reivindicable": "rei-vin-di-ca-ble",
    "reivindicación": "rei-vin-di-ca-ción",
    "reivindicador": "rei-vin-di-ca-dor",
    "reivindicar": "rei-vin-di-car",
    "reivindicativo": "rei-vin-di-ca-ti-vo",
    "reivindicatoria": "rei-vin-di-ca-to-ria",
    "reivindicatorio": "rei-vin-di-ca-to-rio",
    "reja": "re-ja",
    "rejacar": "re-ja-car",
    "rejada": "re-ja-da",
    "rejado": "re-ja-do",
    "rejal": "re-jal",
    "rejalgar": "re-jal-gar",
    "rejego": "re-je-go",
    "rejera": "re-je-ra",
    "rejería": "re-je-rí-a",
    "rejero": "re-je-ro",
    "rejileta": "re-ji-le-ta",
    "rejileto": "re-ji-le-to",
    "rejilla": "re-ji-lla",
    "rejiñol": "re-ji-ñol",
    "rejitar": "re-ji-tar",
    "rejo": "re-jo",
    "rejón": "re-jón",
    "rejonazo": "re-jo-na-zo",
    "rejoncillo": "re-jon-ci-llo",
    "rejoneador": "re-jo-ne-a-dor",
    "rejoneadora": "re-jo-ne-a-do-ra",
    "rejonear": "re-jo-ne-ar",
    "rejoneo": "re-jo-ne-o",
    "rejuela": "re-jue-la",
    "rejuntar": "re-jun-tar",
    "rejús": "re-jús",
    "rejuvenecedor": "re-ju-ve-ne-ce-dor",
    "rejuvenecer": "re-ju-ve-ne-cer",
    "rejuvenecimiento": "re-ju-ve-ne-ci-mien-to",
    "relabra": "re-la-bra",
    "relabrar": "re-la-brar",
    "relación": "re-la-ción",
    "relacional": "re-la-cio-nal",
    "relacionar": "re-la-cio-nar",
    "relacionero": "re-la-cio-ne-ro",
    "relacionista": "re-la-cio-nis-ta",
    "reláfica": "re-lá-fi-ca",
    "relajación": "re-la-ja-ción",
    "relajada": "re-la-ja-da",
    "relajadamente": "re-la-ja-da-men-te",
    "relajado": "re-la-ja-do",
    "relajador": "re-la-ja-dor",
    "relajadora": "re-la-ja-do-ra",
    "relajamiento": "re-la-ja-mien-to",
    "relajante": "re-la-jan-te",
    "relajar": "re-la-jar",
    "relajear": "re-la-je-ar",
    "relajienta": "re-la-jien-ta",
    "relajiento": "re-la-jien-to",
    "relajo": "re-la-jo",
    "relajón": "re-la-jón",
    "relajona": "re-la-jo-na",
    "relambida": "re-lam-bi-da",
    "relambido": "re-lam-bi-do",
    "relamer": "re-la-mer",
    "relamida": "re-la-mi-da",
    "relamido": "re-la-mi-do",
    "relámpago": "re-lám-pa-go",
    "relampagueante": "re-lam-pa-gue-an-te",
    "relampaguear": "re-lam-pa-gue-ar",
    "relampagueo": "re-lam-pa-gue-o",
    "relance": "re-lan-ce",
    "relanciado": "re-lan-cia-do",
    "relanzamiento": "re-lan-za-mien-to",
    "relanzar": "re-lan-zar",
    "relapsa": "re-lap-sa",
    "relapso": "re-lap-so",
    "relatador": "re-la-ta-dor",
    "relatadora": "re-la-ta-do-ra",
    "relatar": "re-la-tar",
    "relativa": "re-la-ti-va",
    "relativamente": "re-la-ti-va-men-te",
    "relatividad": "re-la-ti-vi-dad",
    "relativismo": "re-la-ti-vis-mo",
    "relativista": "re-la-ti-vis-ta",
    "relativización": "re-la-ti-vi-za-ción",
    "relativizador": "re-la-ti-vi-za-dor",
    "relativizar": "re-la-ti-vi-zar",
    "relativo": "re-la-ti-vo",
    "relato": "re-la-to",
    "relator": "re-la-tor",
    "relatora": "re-la-to-ra",
    "relatoría": "re-la-to-rí-a",
    "relavar": "re-la-var",
    "relave": "re-la-ve",
    "relax": "re-lax",
    "relazar": "re-la-zar",
    "relé": "re-lé",
    "releer": "re-le-er",
    "relegación": "re-le-ga-ción",
    "relegar": "re-le-gar",
    "relej": "re-lej",
    "relejar": "re-le-jar",
    "releje": "re-le-je",
    "relente": "re-len-te",
    "relentecer": "re-len-te-cer",
    "relevación": "re-le-va-ción",
    "relevancia": "re-le-van-cia",
    "relevante": "re-le-van-te",
    "relevar": "re-le-var",
    "relevista": "re-le-vis-ta",
    "relevo": "re-le-vo",
    "relicario": "re-li-ca-rio",
    "relicto": "re-lic-to",
    "relievar": "re-lie-var",
    "relieve": "re-lie-ve",
    "religa": "re-li-ga",
    "religación": "re-li-ga-ción",
    "religar": "re-li-gar",
    "religión": "re-li-gión",
    "religionaria": "re-li-gio-na-ria",
    "religionario": "re-li-gio-na-rio",
    "religiosa": "re-li-gio-sa",
    "religiosamente": "re-li-gio-sa-men-te",
    "religiosidad": "re-li-gio-si-dad",
    "religioso": "re-li-gio-so",
    "relimar": "re-li-mar",
    "relimpia": "re-lim-pia",
    "relimpiar": "re-lim-piar",
    "relimpio": "re-lim-pio",
    "relinchada": "re-lin-cha-da",
    "relinchador": "re-lin-cha-dor",
    "relinchadora": "re-lin-cha-do-ra",
    "relinchar": "re-lin-char",
    "relinchido": "re-lin-chi-do",
    "relincho": "re-lin-cho",
    "relinda": "re-lin-da",
    "relindo": "re-lin-do",
    "relinga": "re-lin-ga",
    "relingar": "re-lin-gar",
    "reliquia": "re-li-quia",
    "reliquiario": "re-li-quia-rio",
    "rellanar": "re-lla-nar",
    "rellano": "re-lla-no",
    "rellena": "re-lle-na",
    "rellenar": "re-lle-nar",
    "rellenito": "re-lle-ni-to",
    "relleno": "re-lle-no",
    "reló": "re-ló",
    "relocho": "re-lo-cho",
    "reloj": "re-loj",
    "relojear": "re-lo-je-ar",
    "relojera": "re-lo-je-ra",
    "relojería": "re-lo-je-rí-a",
    "relojero": "re-lo-je-ro",
    "relsa": "rel-sa",
    "relso": "rel-so",
    "reluchar": "re-lu-char",
    "reluciente": "re-lu-cien-te",
    "relucir": "re-lu-cir",
    "reluctancia": "re-luc-tan-cia",
    "reluctante": "re-luc-tan-te",
    "relumbrar": "re-lum-brar",
    "relumbre": "re-lum-bre",
    "relumbro": "re-lum-bro",
    "relumbrón": "re-lum-brón",
    "relumbrosa": "re-lum-bro-sa",
    "relumbroso": "re-lum-bro-so",
    "relva": "rel-va",
    "relvar": "rel-var",
    "remachada": "re-ma-cha-da",
    "remachado": "re-ma-cha-do",
    "remachador": "re-ma-cha-dor",
    "remachadora": "re-ma-cha-do-ra",
    "remachar": "re-ma-char",
    "remache": "re-ma-che",
    "remachón": "re-ma-chón",
    "remador": "re-ma-dor",
    "remadora": "re-ma-do-ra",
    "remadura": "re-ma-du-ra",
    "remake": "re-ma-ke",
    "remalladora": "re-ma-lla-do-ra",
    "remallar": "re-ma-llar",
    "remamiento": "re-ma-mien-to",
    "remanal": "re-ma-nal",
    "remanar": "re-ma-nar",
    "remandar": "re-man-dar",
    "remanecer": "re-ma-ne-cer",
    "remanente": "re-ma-nen-te",
    "remanga": "re-man-ga",
    "remangado": "re-man-ga-do",
    "remangar": "re-man-gar",
    "remango": "re-man-go",
    "remanir": "re-ma-nir",
    "remanosa": "re-ma-no-sa",
    "remanoso": "re-ma-no-so",
    "remansar": "re-man-sar",
    "remansarse": "re-man-sar-se",
    "remanso": "re-man-so",
    "remar": "re-mar",
    "remarcable": "re-mar-ca-ble",
    "remarcar": "re-mar-car",
    "remasa": "re-ma-sa",
    "rematada": "re-ma-ta-da",
    "rematadamente": "re-ma-ta-da-men-te",
    "rematado": "re-ma-ta-do",
    "rematador": "re-ma-ta-dor",
    "rematadora": "re-ma-ta-do-ra",
    "rematamiento": "re-ma-ta-mien-to",
    "rematante": "re-ma-tan-te",
    "rematar": "re-ma-tar",
    "remate": "re-ma-te",
    "rembolsar": "rem-bol-sar",
    "rembolso": "rem-bol-so",
    "remecedor": "re-me-ce-dor",
    "remecedora": "re-me-ce-do-ra",
    "remecer": "re-me-cer",
    "remedable": "re-me-da-ble",
    "remedador": "re-me-da-dor",
    "remedadora": "re-me-da-do-ra",
    "remedar": "re-me-dar",
    "remediable": "re-me-dia-ble",
    "remediador": "re-me-dia-dor",
    "remediadora": "re-me-dia-do-ra",
    "remediar": "re-me-diar",
    "remediavagos": "re-me-dia-va-gos",
    "remedición": "re-me-di-ción",
    "remedio": "re-me-dio",
    "remedión": "re-me-dión",
    "remedir": "re-me-dir",
    "remedo": "re-me-do",
    "remejer": "re-me-jer",
    "remellada": "re-me-lla-da",
    "remellado": "re-me-lla-do",
    "remellar": "re-me-llar",
    "remellón": "re-me-llón",
    "remellona": "re-me-llo-na",
    "remembranza": "re-mem-bran-za",
    "remembrar": "re-mem-brar",
    "rememoración": "re-me-mo-ra-ción",
    "rememorar": "re-me-mo-rar",
    "rememorativa": "re-me-mo-ra-ti-va",
    "rememorativo": "re-me-mo-ra-ti-vo",
    "remendada": "re-men-da-da",
    "remendado": "re-men-da-do",
    "remendar": "re-men-dar",
    "remendón": "re-men-dón",
    "remendona": "re-men-do-na",
    "remeneo": "re-me-ne-o",
    "remense": "re-men-se",
    "remera": "re-me-ra",
    "remero": "re-me-ro",
    "remesa": "re-me-sa",
    "remesar": "re-me-sar",
    "remesera": "re-me-se-ra",
    "remesero": "re-me-se-ro",
    "remesón": "re-me-són",
    "remeter": "re-me-ter",
    "remezón": "re-me-zón",
    "remiche": "re-mi-che",
    "remiel": "re-miel",
    "remiendo": "re-mien-do",
    "rémige": "ré-mi-ge",
    "remigio": "re-mi-gio",
    "remilgada": "re-mil-ga-da",
    "remilgadamente": "re-mil-ga-da-men-te",
    "remilgado": "re-mil-ga-do",
    "remilgar": "re-mil-gar",
    "remilgarse": "re-mil-gar-se",
    "remilgo": "re-mil-go",
    "remilgosa": "re-mil-go-sa",
    "remilgoso": "re-mil-go-so",
    "remillón": "re-mi-llón",
    "rémington": "ré-ming-ton",
    "reminiscencia": "re-mi-nis-cen-cia",
    "reminiscente": "re-mi-nis-cen-te",
    "remirada": "re-mi-ra-da",
    "remirado": "re-mi-ra-do",
    "remirar": "re-mi-rar",
    "remisa": "re-mi-sa",
    "remisamente": "re-mi-sa-men-te",
    "remise": "re-mi-se",
    "remisera": "re-mi-se-ra",
    "remisería": "re-mi-se-rí-a",
    "remisero": "re-mi-se-ro",
    "remisible": "re-mi-si-ble",
    "remisión": "re-mi-sión",
    "remisiva": "re-mi-si-va",
    "remisivamente": "re-mi-si-va-men-te",
    "remisivo": "re-mi-si-vo",
    "remiso": "re-mi-so",
    "remisoria": "re-mi-so-ria",
    "remisorio": "re-mi-so-rio",
    "remite": "re-mi-te",
    "remitente": "re-mi-ten-te",
    "remitido": "re-mi-ti-do",
    "remitir": "re-mi-tir",
    "remo": "re-mo",
    "remocho": "re-mo-cho",
    "remoción": "re-mo-ción",
    "remodelación": "re-mo-de-la-ción",
    "remodelar": "re-mo-de-lar",
    "remojadero": "re-mo-ja-de-ro",
    "remojar": "re-mo-jar",
    "remojo": "re-mo-jo",
    "remojón": "re-mo-jón",
    "remolacha": "re-mo-la-cha",
    "remolachera": "re-mo-la-che-ra",
    "remolachero": "re-mo-la-che-ro",
    "remolar": "re-mo-lar",
    "remolcador": "re-mol-ca-dor",
    "remolcadora": "re-mol-ca-do-ra",
    "remolcar": "re-mol-car",
    "remolda": "re-mol-da",
    "remoldar": "re-mol-dar",
    "remoler": "re-mo-ler",
    "remolido": "re-mo-li-do",
    "remolienda": "re-mo-lien-da",
    "remolimiento": "re-mo-li-mien-to",
    "remolinar": "re-mo-li-nar",
    "remolinear": "re-mo-li-ne-ar",
    "remolino": "re-mo-li-no",
    "remollero": "re-mo-lle-ro",
    "remolón": "re-mo-lón",
    "remolona": "re-mo-lo-na",
    "remolonear": "re-mo-lo-ne-ar",
    "remolque": "re-mol-que",
    "remondar": "re-mon-dar",
    "remonta": "re-mon-ta",
    "remontada": "re-mon-ta-da",
    "remontado": "re-mon-ta-do",
    "remontamiento": "re-mon-ta-mien-to",
    "remontar": "re-mon-tar",
    "remonte": "re-mon-te",
    "remontista": "re-mon-tis-ta",
    "remoque": "re-mo-que",
    "remoquete": "re-mo-que-te",
    "rémora": "ré-mo-ra",
    "remorar": "re-mo-rar",
    "remordedor": "re-mor-de-dor",
    "remordedora": "re-mor-de-do-ra",
    "remorder": "re-mor-der",
    "remordimiento": "re-mor-di-mien-to",
    "remosquear": "re-mos-que-ar",
    "remosquearse": "re-mos-que-ar-se",
    "remostar": "re-mos-tar",
    "remostecer": "re-mos-te-cer",
    "remostecerse": "re-mos-te-cer-se",
    "remosto": "re-mos-to",
    "remota": "re-mo-ta",
    "remotamente": "re-mo-ta-men-te",
    "remotidad": "re-mo-ti-dad",
    "remoto": "re-mo-to",
    "remover": "re-mo-ver",
    "removible": "re-mo-vi-ble",
    "removimiento": "re-mo-vi-mien-to",
    "remozamiento": "re-mo-za-mien-to",
    "remozar": "re-mo-zar",
    "remplazable": "rem-pla-za-ble",
    "remplazar": "rem-pla-zar",
    "remplazo": "rem-pla-zo",
    "rempujar": "rem-pu-jar",
    "rempujo": "rem-pu-jo",
    "rempujón": "rem-pu-jón",
    "remuda": "re-mu-da",
    "remudamiento": "re-mu-da-mien-to",
    "remudar": "re-mu-dar",
    "remudiar": "re-mu-diar",
    "remugar": "re-mu-gar",
    "remullir": "re-mu-llir",
    "remunerable": "re-mu-ne-ra-ble",
    "remuneración": "re-mu-ne-ra-ción",
    "remunerador": "re-mu-ne-ra-dor",
    "remuneradora": "re-mu-ne-ra-do-ra",
    "remunerar": "re-mu-ne-rar",
    "remunerativa": "re-mu-ne-ra-ti-va",
    "remunerativo": "re-mu-ne-ra-ti-vo",
    "remuneratoria": "re-mu-ne-ra-to-ria",
    "remuneratorio": "re-mu-ne-ra-to-rio",
    "remusgar": "re-mus-gar",
    "remusgo": "re-mus-go",
    "renacentista": "re-na-cen-tis-ta",
    "renacer": "re-na-cer",
    "renacimiento": "re-na-ci-mien-to",
    "renacuajo": "re-na-cua-jo",
    "renadío": "re-na-dí-o",
    "renal": "re-nal",
    "renana": "re-na-na",
    "renano": "re-na-no",
    "renca": "ren-ca",
    "rencallo": "ren-ca-llo",
    "rencauchar": "ren-cau-char",
    "rencilla": "ren-ci-lla",
    "rencillosa": "ren-ci-llo-sa",
    "rencilloso": "ren-ci-llo-so",
    "rencionar": "ren-cio-nar",
    "renco": "ren-co",
    "rencontrar": "ren-con-trar",
    "rencor": "ren-cor",
    "rencorosa": "ren-co-ro-sa",
    "rencorosamente": "ren-co-ro-sa-men-te",
    "rencoroso": "ren-co-ro-so",
    "rencoso": "ren-co-so",
    "rencuentro": "ren-cuen-tro",
    "renculillo": "ren-cu-li-llo",
    "rencura": "ren-cu-ra",
    "rencurar": "ren-cu-rar",
    "rencurarse": "ren-cu-rar-se",
    "rencurosa": "ren-cu-ro-sa",
    "rencuroso": "ren-cu-ro-so",
    "renda": "ren-da",
    "rendaje": "ren-da-je",
    "rendajo": "ren-da-jo",
    "rendar": "ren-dar",
    "render": "ren-der",
    "rendibú": "ren-di-bú",
    "rendición": "ren-di-ción",
    "rendida": "ren-di-da",
    "rendidamente": "ren-di-da-men-te",
    "rendido": "ren-di-do",
    "rendidor": "ren-di-dor",
    "rendija": "ren-di-ja",
    "rendimiento": "ren-di-mien-to",
    "rendir": "ren-dir",
    "rendón": "ren-dón",
    "rene": "re-ne",
    "renegada": "re-ne-ga-da",
    "renegado": "re-ne-ga-do",
    "renegador": "re-ne-ga-dor",
    "renegadora": "re-ne-ga-do-ra",
    "renegar": "re-ne-gar",
    "renegociación": "re-ne-go-cia-ción",
    "renegociar": "re-ne-go-ciar",
    "renegón": "re-ne-gón",
    "renegona": "re-ne-go-na",
    "renegrear": "re-ne-gre-ar",
    "renegrida": "re-ne-gri-da",
    "renegrido": "re-ne-gri-do",
    "reneta": "re-ne-ta",
    "renga": "ren-ga",
    "rengadero": "ren-ga-de-ro",
    "rengar": "ren-gar",
    "rengífero": "ren-gí-fe-ro",
    "rengle": "ren-gle",
    "renglera": "ren-gle-ra",
    "renglón": "ren-glón",
    "renglonadura": "ren-glo-na-du-ra",
    "rengo": "ren-go",
    "renguear": "ren-gue-ar",
    "renguera": "ren-gue-ra",
    "reñida": "re-ñi-da",
    "reñidamente": "re-ñi-da-men-te",
    "reñidero": "re-ñi-de-ro",
    "reñido": "re-ñi-do",
    "reñidor": "re-ñi-dor",
    "reñidora": "re-ñi-do-ra",
    "reñidura": "re-ñi-du-ra",
    "reniego": "re-nie-go",
    "reniforme": "re-ni-for-me",
    "renil": "re-nil",
    "renio": "re-nio",
    "reñir": "re-ñir",
    "renitencia": "re-ni-ten-cia",
    "renitente": "re-ni-ten-te",
    "reno": "re-no",
    "renombrada": "re-nom-bra-da",
    "renombrado": "re-nom-bra-do",
    "renombrar": "re-nom-brar",
    "renombre": "re-nom-bre",
    "renovable": "re-no-va-ble",
    "renovación": "re-no-va-ción",
    "renovador": "re-no-va-dor",
    "renovadora": "re-no-va-do-ra",
    "renoval": "re-no-val",
    "renovamiento": "re-no-va-mien-to",
    "renovar": "re-no-var",
    "renovera": "re-no-ve-ra",
    "renovero": "re-no-ve-ro",
    "renqueante": "ren-que-an-te",
    "renquear": "ren-que-ar",
    "renqueo": "ren-que-o",
    "renquera": "ren-que-ra",
    "renta": "ren-ta",
    "rentabilidad": "ren-ta-bi-li-dad",
    "rentabilización": "ren-ta-bi-li-za-ción",
    "rentabilizar": "ren-ta-bi-li-zar",
    "rentable": "ren-ta-ble",
    "rentada": "ren-ta-da",
    "rentado": "ren-ta-do",
    "rentar": "ren-tar",
    "rentera": "ren-te-ra",
    "rentero": "ren-te-ro",
    "rentilla": "ren-ti-lla",
    "rentista": "ren-tis-ta",
    "rentística": "ren-tís-ti-ca",
    "rentístico": "ren-tís-ti-co",
    "rento": "ren-to",
    "rentosa": "ren-to-sa",
    "rentoso": "ren-to-so",
    "rentoy": "ren-toy",
    "rentrée": "ren-tré-e",
    "renuencia": "re-nuen-cia",
    "renuente": "re-nuen-te",
    "renuevo": "re-nue-vo",
    "renuncia": "re-nun-cia",
    "renunciable": "re-nun-cia-ble",
    "renunciación": "re-nun-cia-ción",
    "renunciamiento": "re-nun-cia-mien-to",
    "renunciante": "re-nun-cian-te",
    "renunciar": "re-nun-ciar",
    "renunciataria": "re-nun-cia-ta-ria",
    "renunciatario": "re-nun-cia-ta-rio",
    "renuncio": "re-nun-cio",
    "renvalsar": "ren-val-sar",
    "renvalso": "ren-val-so",
    "reo": "re-o",
    "reobrar": "re-o-brar",
    "reoctava": "re-oc-ta-va",
    "reoctavar": "re-oc-ta-var",
    "reóforo": "re-ó-fo-ro",
    "reógrafo": "re-ó-gra-fo",
    "reojo": "re-o-jo",
    "reología": "re-o-lo-gí-a",
    "reómetro": "re-ó-me-tro",
    "reordenación": "re-or-de-na-ción",
    "reordenamiento": "re-or-de-na-mien-to",
    "reordenar": "re-or-de-nar",
    "reorganización": "re-or-ga-ni-za-ción",
    "reorganizador": "re-or-ga-ni-za-dor",
    "reorganizadora": "re-or-ga-ni-za-do-ra",
    "reorganizar": "re-or-ga-ni-zar",
    "reorientación": "re-o-rien-ta-ción",
    "reorientar": "re-o-rien-tar",
    "reostato": "re-os-ta-to",
    "reóstato": "re-ós-ta-to",
    "repacer": "re-pa-cer",
    "repagar": "re-pa-gar",
    "repajo": "re-pa-jo",
    "repajolero": "re-pa-jo-le-ro",
    "repanchigar": "re-pan-chi-gar",
    "repanchigarse": "re-pan-chi-gar-se",
    "repanchingar": "re-pan-chin-gar",
    "repantigar": "re-pan-ti-gar",
    "repantigarse": "re-pan-ti-gar-se",
    "repantingar": "re-pan-tin-gar",
    "repápalo": "re-pá-pa-lo",
    "repapilar": "re-pa-pi-lar",
    "repapilarse": "re-pa-pi-lar-se",
    "repapo": "re-pa-po",
    "reparable": "re-pa-ra-ble",
    "reparación": "re-pa-ra-ción",
    "reparada": "re-pa-ra-da",
    "reparado": "re-pa-ra-do",
    "reparador": "re-pa-ra-dor",
    "reparadora": "re-pa-ra-do-ra",
    "reparamiento": "re-pa-ra-mien-to",
    "reparar": "re-pa-rar",
    "reparativa": "re-pa-ra-ti-va",
    "reparativo": "re-pa-ra-ti-vo",
    "reparcelación": "re-par-ce-la-ción",
    "reparo": "re-pa-ro",
    "reparón": "re-pa-rón",
    "reparona": "re-pa-ro-na",
    "repartible": "re-par-ti-ble",
    "repartición": "re-par-ti-ción",
    "repartidamente": "re-par-ti-da-men-te",
    "repartidera": "re-par-ti-de-ra",
    "repartidero": "re-par-ti-de-ro",
    "repartidor": "re-par-ti-dor",
    "repartidora": "re-par-ti-do-ra",
    "repartija": "re-par-ti-ja",
    "repartimiento": "re-par-ti-mien-to",
    "repartir": "re-par-tir",
    "reparto": "re-par-to",
    "repasadera": "re-pa-sa-de-ra",
    "repasador": "re-pa-sa-dor",
    "repasadora": "re-pa-sa-do-ra",
    "repasar": "re-pa-sar",
    "repasata": "re-pa-sa-ta",
    "repaso": "re-pa-so",
    "repastar": "re-pas-tar",
    "repasto": "re-pas-to",
    "repatear": "re-pa-te-ar",
    "repatriación": "re-pa-tria-ción",
    "repatriada": "re-pa-tria-da",
    "repatriado": "re-pa-tria-do",
    "repatriar": "re-pa-triar",
    "repe": "re-pe",
    "repechaje": "re-pe-cha-je",
    "repechar": "re-pe-char",
    "repecho": "re-pe-cho",
    "repeinada": "re-pei-na-da",
    "repeinado": "re-pei-na-do",
    "repeinar": "re-pei-nar",
    "repelada": "re-pe-la-da",
    "repelado": "re-pe-la-do",
    "repeladura": "re-pe-la-du-ra",
    "repelar": "re-pe-lar",
    "repele": "re-pe-le",
    "repelencia": "re-pe-len-cia",
    "repelente": "re-pe-len-te",
    "repeler": "re-pe-ler",
    "repellar": "re-pe-llar",
    "repello": "re-pe-llo",
    "repelo": "re-pe-lo",
    "repelón": "re-pe-lón",
    "repelona": "re-pe-lo-na",
    "repelosa": "re-pe-lo-sa",
    "repeloso": "re-pe-lo-so",
    "repeluco": "re-pe-lu-co",
    "repelús": "re-pe-lús",
    "repeluzno": "re-pe-luz-no",
    "repensar": "re-pen-sar",
    "repente": "re-pen-te",
    "repentina": "re-pen-ti-na",
    "repentinamente": "re-pen-ti-na-men-te",
    "repentino": "re-pen-ti-no",
    "repentir": "re-pen-tir",
    "repentirse": "re-pen-tir-se",
    "repentista": "re-pen-tis-ta",
    "repentización": "re-pen-ti-za-ción",
    "repentizar": "re-pen-ti-zar",
    "repeor": "re-pe-or",
    "repercudida": "re-per-cu-di-da",
    "repercudir": "re-per-cu-dir",
    "repercusión": "re-per-cu-sión",
    "repercusiva": "re-per-cu-si-va",
    "repercusivo": "re-per-cu-si-vo",
    "repercutible": "re-per-cu-ti-ble",
    "repercutir": "re-per-cu-tir",
    "reperpero": "re-per-pe-ro",
    "repertorio": "re-per-to-rio",
    "repesar": "re-pe-sar",
    "repesca": "re-pes-ca",
    "repescar": "re-pes-car",
    "repeso": "re-pe-so",
    "repetibilidad": "re-pe-ti-bi-li-dad",
    "repetible": "re-pe-ti-ble",
    "repetición": "re-pe-ti-ción",
    "repetidamente": "re-pe-ti-da-men-te",
    "repetidor": "re-pe-ti-dor",
    "repetidora": "re-pe-ti-do-ra",
    "repetir": "re-pe-tir",
    "repetitividad": "re-pe-ti-ti-vi-dad",
    "repetitivo": "re-pe-ti-ti-vo",
    "repicar": "re-pi-car",
    "repicoteada": "re-pi-co-te-a-da",
    "repicoteado": "re-pi-co-te-a-do",
    "repicotear": "re-pi-co-te-ar",
    "repinaldo": "re-pi-nal-do",
    "repinar": "re-pi-nar",
    "repinarse": "re-pi-nar-se",
    "repintar": "re-pin-tar",
    "repinte": "re-pin-te",
    "repipi": "re-pi-pi",
    "repipiez": "re-pi-piez",
    "repique": "re-pi-que",
    "repiquete": "re-pi-que-te",
    "repiquetear": "re-pi-que-te-ar",
    "repiqueteo": "re-pi-que-te-o",
    "repisa": "re-pi-sa",
    "repisar": "re-pi-sar",
    "repiso": "re-pi-so",
    "repitente": "re-pi-ten-te",
    "repitiente": "re-pi-tien-te",
    "repizcar": "re-piz-car",
    "repizco": "re-piz-co",
    "replaceta": "re-pla-ce-ta",
    "replana": "re-pla-na",
    "replantación": "re-plan-ta-ción",
    "replantar": "re-plan-tar",
    "replanteamiento": "re-plan-te-a-mien-to",
    "replantear": "re-plan-te-ar",
    "replanteo": "re-plan-te-o",
    "repleción": "re-ple-ción",
    "replegar": "re-ple-gar",
    "repleta": "re-ple-ta",
    "repletar": "re-ple-tar",
    "repleto": "re-ple-to",
    "réplica": "ré-pli-ca",
    "replicación": "re-pli-ca-ción",
    "replicador": "re-pli-ca-dor",
    "replicadora": "re-pli-ca-do-ra",
    "replicar": "re-pli-car",
    "replicato": "re-pli-ca-to",
    "replicón": "re-pli-cón",
    "replicona": "re-pli-co-na",
    "repliegue": "re-plie-gue",
    "repo": "re-po",
    "repoblación": "re-po-bla-ción",
    "repoblador": "re-po-bla-dor",
    "repobladora": "re-po-bla-do-ra",
    "repoblar": "re-po-blar",
    "repodar": "re-po-dar",
    "repodrir": "re-po-drir",
    "repollar": "re-po-llar",
    "repollo": "re-po-llo",
    "repolluda": "re-po-llu-da",
    "repolludo": "re-po-llu-do",
    "reponer": "re-po-ner",
    "reportación": "re-por-ta-ción",
    "reportaje": "re-por-ta-je",
    "reportamiento": "re-por-ta-mien-to",
    "reportar": "re-por-tar",
    "reporte": "re-por-te",
    "reportear": "re-por-te-ar",
    "reportera": "re-por-te-ra",
    "reporteril": "re-por-te-ril",
    "reporterismo": "re-por-te-ris-mo",
    "reportero": "re-por-te-ro",
    "reportista": "re-por-tis-ta",
    "reportorio": "re-por-to-rio",
    "reposabrazos": "re-po-sa-bra-zos",
    "reposacabezas": "re-po-sa-ca-be-zas",
    "reposada": "re-po-sa-da",
    "reposadamente": "re-po-sa-da-men-te",
    "reposadera": "re-po-sa-de-ra",
    "reposadero": "re-po-sa-de-ro",
    "reposado": "re-po-sa-do",
    "reposapiés": "re-po-sa-piés",
    "reposar": "re-po-sar",
    "reposera": "re-po-se-ra",
    "reposero": "re-po-se-ro",
    "reposición": "re-po-si-ción",
    "repositorio": "re-po-si-to-rio",
    "reposo": "re-po-so",
    "repostada": "re-pos-ta-da",
    "repostaje": "re-pos-ta-je",
    "repostar": "re-pos-tar",
    "reposte": "re-pos-te",
    "repostera": "re-pos-te-ra",
    "repostería": "re-pos-te-rí-a",
    "repostero": "re-pos-te-ro",
    "repoyar": "re-po-yar",
    "repoyo": "re-po-yo",
    "repregunta": "re-pre-gun-ta",
    "repreguntar": "re-pre-gun-tar",
    "reprehender": "re-pre-hen-der",
    "reprehensible": "re-pre-hen-si-ble",
    "reprehensión": "re-pre-hen-sión",
    "reprendedor": "re-pren-de-dor",
    "reprendedora": "re-pren-de-do-ra",
    "reprender": "re-pren-der",
    "reprensible": "re-pren-si-ble",
    "reprensión": "re-pren-sión",
    "reprensivo": "re-pren-si-vo",
    "reprensor": "re-pren-sor",
    "reprensora": "re-pren-so-ra",
    "represa": "re-pre-sa",
    "represalia": "re-pre-sa-lia",
    "represaliada": "re-pre-sa-lia-da",
    "represaliado": "re-pre-sa-lia-do",
    "represaliar": "re-pre-sa-liar",
    "represar": "re-pre-sar",
    "representable": "re-pre-sen-ta-ble",
    "representación": "re-pre-sen-ta-ción",
    "representador": "re-pre-sen-ta-dor",
    "representadora": "re-pre-sen-ta-do-ra",
    "representanta": "re-pre-sen-tan-ta",
    "representante": "re-pre-sen-tan-te",
    "representar": "re-pre-sen-tar",
    "representativa": "re-pre-sen-ta-ti-va",
    "representatividad": "re-pre-sen-ta-ti-vi-dad",
    "representativo": "re-pre-sen-ta-ti-vo",
    "represión": "re-pre-sión",
    "represiva": "re-pre-si-va",
    "represivo": "re-pre-si-vo",
    "represor": "re-pre-sor",
    "represora": "re-pre-so-ra",
    "reprimenda": "re-pri-men-da",
    "reprimida": "re-pri-mi-da",
    "reprimido": "re-pri-mi-do",
    "reprimir": "re-pri-mir",
    "reprise": "re-pri-se",
    "reprivatización": "re-pri-va-ti-za-ción",
    "reprivatizar": "re-pri-va-ti-zar",
    "réproba": "ré-pro-ba",
    "reprobable": "re-pro-ba-ble",
    "reprobación": "re-pro-ba-ción",
    "reprobada": "re-pro-ba-da",
    "reprobadamente": "re-pro-ba-da-men-te",
    "reprobado": "re-pro-ba-do",
    "reprobador": "re-pro-ba-dor",
    "reprobadora": "re-pro-ba-do-ra",
    "reprobar": "re-pro-bar",
    "reprobatoria": "re-pro-ba-to-ria",
    "reprobatorio": "re-pro-ba-to-rio",
    "réprobo": "ré-pro-bo",
    "reprocesado": "re-pro-ce-sa-do",
    "reprochable": "re-pro-cha-ble",
    "reprochador": "re-pro-cha-dor",
    "reprochadora": "re-pro-cha-do-ra",
    "reprochar": "re-pro-char",
    "reproche": "re-pro-che",
    "reproducción": "re-pro-duc-ción",
    "reproducibilidad": "re-pro-du-ci-bi-li-dad",
    "reproducir": "re-pro-du-cir",
    "reproductiva": "re-pro-duc-ti-va",
    "reproductivo": "re-pro-duc-ti-vo",
    "reproductor": "re-pro-duc-tor",
    "reproductora": "re-pro-duc-to-ra",
    "reprógrafa": "re-pró-gra-fa",
    "reprografía": "re-pro-gra-fí-a",
    "reprográfico": "re-pro-grá-fi-co",
    "reprógrafo": "re-pró-gra-fo",
    "repromisión": "re-pro-mi-sión",
    "repropia": "re-pro-pia",
    "repropiar": "re-pro-piar",
    "repropiarse": "re-pro-piar-se",
    "repropio": "re-pro-pio",
    "reprueba": "re-prue-ba",
    "reptación": "rep-ta-ción",
    "reptador": "rep-ta-dor",
    "reptadora": "rep-ta-do-ra",
    "reptante": "rep-tan-te",
    "reptar": "rep-tar",
    "reptil": "rep-til",
    "réptil": "rép-til",
    "república": "re-pú-bli-ca",
    "republicana": "re-pu-bli-ca-na",
    "republicanismo": "re-pu-bli-ca-nis-mo",
    "republicano": "re-pu-bli-ca-no",
    "repúblico": "re-pú-bli-co",
    "repuchar": "re-pu-char",
    "repudiable": "re-pu-dia-ble",
    "repudiación": "re-pu-dia-ción",
    "repudiar": "re-pu-diar",
    "repudio": "re-pu-dio",
    "repudrir": "re-pu-drir",
    "repuesta": "re-pues-ta",
    "repuesto": "re-pues-to",
    "repugnancia": "re-pug-nan-cia",
    "repugnante": "re-pug-nan-te",
    "repugnantemente": "re-pug-nan-te-men-te",
    "repugnar": "re-pug-nar",
    "repujado": "re-pu-ja-do",
    "repujador": "re-pu-ja-dor",
    "repujadora": "re-pu-ja-do-ra",
    "repujar": "re-pu-jar",
    "repulgada": "re-pul-ga-da",
    "repulgado": "re-pul-ga-do",
    "repulgar": "re-pul-gar",
    "repulgo": "re-pul-go",
    "repulgue": "re-pul-gue",
    "repulir": "re-pu-lir",
    "repullo": "re-pu-llo",
    "repulsa": "re-pul-sa",
    "repulsar": "re-pul-sar",
    "repulsión": "re-pul-sión",
    "repulsiva": "re-pul-si-va",
    "repulsivo": "re-pul-si-vo",
    "repunta": "re-pun-ta",
    "repuntar": "re-pun-tar",
    "repunte": "re-pun-te",
    "repurgar": "re-pur-gar",
    "reputación": "re-pu-ta-ción",
    "reputado": "re-pu-ta-do",
    "reputar": "re-pu-tar",
    "requebrador": "re-que-bra-dor",
    "requebradora": "re-que-bra-do-ra",
    "requebrajo": "re-que-bra-jo",
    "requebrar": "re-que-brar",
    "requemada": "re-que-ma-da",
    "requemado": "re-que-ma-do",
    "requemamiento": "re-que-ma-mien-to",
    "requemar": "re-que-mar",
    "requemazón": "re-que-ma-zón",
    "requenense": "re-que-nen-se",
    "requeridor": "re-que-ri-dor",
    "requeridora": "re-que-ri-do-ra",
    "requerimiento": "re-que-ri-mien-to",
    "requerir": "re-que-rir",
    "requesón": "re-que-són",
    "requesonera": "re-que-so-ne-ra",
    "requesonero": "re-que-so-ne-ro",
    "requete": "re-que-te",
    "requeté": "re-que-té",
    "requetebién": "re-que-te-bién",
    "requiebro": "re-quie-bro",
    "réquiem": "ré-quiem",
    "requilorio": "re-qui-lo-rio",
    "requintada": "re-quin-ta-da",
    "requintador": "re-quin-ta-dor",
    "requintadora": "re-quin-ta-do-ra",
    "requintar": "re-quin-tar",
    "requintear": "re-quin-te-ar",
    "requinto": "re-quin-to",
    "requirente": "re-qui-ren-te",
    "requisa": "re-qui-sa",
    "requisar": "re-qui-sar",
    "requisición": "re-qui-si-ción",
    "requisito": "re-qui-si-to",
    "requisitoria": "re-qui-si-to-ria",
    "requisitorio": "re-qui-si-to-rio",
    "requive": "re-qui-ve",
    "resaber": "re-sa-ber",
    "resabiado": "re-sa-bia-do",
    "resabiar": "re-sa-biar",
    "resabida": "re-sa-bi-da",
    "resabido": "re-sa-bi-do",
    "resabio": "re-sa-bio",
    "resabioso": "re-sa-bio-so",
    "resaca": "re-sa-ca",
    "resacar": "re-sa-car",
    "resacoso": "re-sa-co-so",
    "resalada": "re-sa-la-da",
    "resalado": "re-sa-la-do",
    "resalga": "re-sal-ga",
    "resalir": "re-sa-lir",
    "resallar": "re-sa-llar",
    "resallo": "re-sa-llo",
    "resaltador": "re-sal-ta-dor",
    "resaltar": "re-sal-tar",
    "resalte": "re-sal-te",
    "resalto": "re-sal-to",
    "resaludar": "re-sa-lu-dar",
    "resalutación": "re-sa-lu-ta-ción",
    "resalvo": "re-sal-vo",
    "resanar": "re-sa-nar",
    "resaque": "re-sa-que",
    "resarcible": "re-sar-ci-ble",
    "resarcimiento": "re-sar-ci-mien-to",
    "resarcir": "re-sar-cir",
    "resayo": "re-sa-yo",
    "resbaladera": "res-ba-la-de-ra",
    "resbaladero": "res-ba-la-de-ro",
    "resbaladilla": "res-ba-la-di-lla",
    "resbaladiza": "res-ba-la-di-za",
    "resbaladizo": "res-ba-la-di-zo",
    "resbalador": "res-ba-la-dor",
    "resbaladora": "res-ba-la-do-ra",
    "resbaladura": "res-ba-la-du-ra",
    "resbalamiento": "res-ba-la-mien-to",
    "resbalar": "res-ba-lar",
    "resbalera": "res-ba-le-ra",
    "resbalín": "res-ba-lín",
    "resbalón": "res-ba-lón",
    "resbalosa": "res-ba-lo-sa",
    "resbaloso": "res-ba-lo-so",
    "rescacio": "res-ca-cio",
    "rescaldar": "res-cal-dar",
    "rescaldo": "res-cal-do",
    "rescaño": "res-ca-ño",
    "rescatado": "res-ca-ta-do",
    "rescatador": "res-ca-ta-dor",
    "rescatadora": "res-ca-ta-do-ra",
    "rescatar": "res-ca-tar",
    "rescate": "res-ca-te",
    "rescaza": "res-ca-za",
    "rescindible": "res-cin-di-ble",
    "rescindir": "res-cin-dir",
    "rescisión": "res-ci-sión",
    "rescisoria": "res-ci-so-ria",
    "rescisorio": "res-ci-so-rio",
    "rescoldar": "res-col-dar",
    "rescoldera": "res-col-de-ra",
    "rescoldo": "res-col-do",
    "rescontrar": "res-con-trar",
    "rescribir": "res-cri-bir",
    "rescripto": "res-crip-to",
    "rescriptoria": "res-crip-to-ria",
    "rescriptorio": "res-crip-to-rio",
    "rescrito": "res-cri-to",
    "rescuentro": "res-cuen-tro",
    "reseca": "re-se-ca",
    "resecación": "re-se-ca-ción",
    "resecamiento": "re-se-ca-mien-to",
    "resecar": "re-se-car",
    "resección": "re-sec-ción",
    "reseco": "re-se-co",
    "reseda": "re-se-da",
    "resedácea": "re-se-dá-ce-a",
    "resedáceo": "re-se-dá-ce-o",
    "resegar": "re-se-gar",
    "reseguir": "re-se-guir",
    "resellar": "re-se-llar",
    "resello": "re-se-llo",
    "resemblar": "re-sem-blar",
    "resembrar": "re-sem-brar",
    "reseña": "re-se-ña",
    "reseñable": "re-se-ña-ble",
    "reseñador": "re-se-ña-dor",
    "reseñadora": "re-se-ña-do-ra",
    "reseñar": "re-se-ñar",
    "resentida": "re-sen-ti-da",
    "resentido": "re-sen-ti-do",
    "resentimiento": "re-sen-ti-mien-to",
    "resentir": "re-sen-tir",
    "resentirse": "re-sen-tir-se",
    "resequida": "re-se-qui-da",
    "resequido": "re-se-qui-do",
    "resera": "re-se-ra",
    "resero": "re-se-ro",
    "reserva": "re-ser-va",
    "reservable": "re-ser-va-ble",
    "reservación": "re-ser-va-ción",
    "reservada": "re-ser-va-da",
    "reservadamente": "re-ser-va-da-men-te",
    "reservado": "re-ser-va-do",
    "reservar": "re-ser-var",
    "reservativa": "re-ser-va-ti-va",
    "reservativo": "re-ser-va-ti-vo",
    "reservista": "re-ser-vis-ta",
    "reservón": "re-ser-vón",
    "reservona": "re-ser-vo-na",
    "reservorio": "re-ser-vo-rio",
    "resetear": "re-se-te-ar",
    "resfalosa": "res-fa-lo-sa",
    "resfriado": "res-fria-do",
    "resfriador": "res-fria-dor",
    "resfriadora": "res-fria-do-ra",
    "resfriadura": "res-fria-du-ra",
    "resfriamiento": "res-fria-mien-to",
    "resfriante": "res-frian-te",
    "resfriar": "res-friar",
    "resfrío": "res-frí-o",
    "resguardar": "res-guar-dar",
    "resguardo": "res-guar-do",
    "residencia": "re-si-den-cia",
    "residencial": "re-si-den-cial",
    "residenciar": "re-si-den-ciar",
    "residente": "re-si-den-te",
    "residentemente": "re-si-den-te-men-te",
    "residir": "re-si-dir",
    "residual": "re-si-dual",
    "residuo": "re-si-duo",
    "resiembra": "re-siem-bra",
    "resigna": "re-sig-na",
    "resignación": "re-sig-na-ción",
    "resignadamente": "re-sig-na-da-men-te",
    "resignar": "re-sig-nar",
    "resignatario": "re-sig-na-ta-rio",
    "resina": "re-si-na",
    "resinación": "re-si-na-ción",
    "resinar": "re-si-nar",
    "resinera": "re-si-ne-ra",
    "resinero": "re-si-ne-ro",
    "resinífera": "re-si-ní-fe-ra",
    "resinífero": "re-si-ní-fe-ro",
    "resinificar": "re-si-ni-fi-car",
    "resinosa": "re-si-no-sa",
    "resinoso": "re-si-no-so",
    "resisa": "re-si-sa",
    "resisar": "re-si-sar",
    "resistencia": "re-sis-ten-cia",
    "resistenciana": "re-sis-ten-cia-na",
    "resistenciano": "re-sis-ten-cia-no",
    "resistente": "re-sis-ten-te",
    "resistero": "re-sis-te-ro",
    "resistible": "re-sis-ti-ble",
    "resistidero": "re-sis-ti-de-ro",
    "resistidor": "re-sis-ti-dor",
    "resistidora": "re-sis-ti-do-ra",
    "resistir": "re-sis-tir",
    "resistiva": "re-sis-ti-va",
    "resistividad": "re-sis-ti-vi-dad",
    "resistivo": "re-sis-ti-vo",
    "resistor": "re-sis-tor",
    "resituar": "re-si-tuar",
    "resma": "res-ma",
    "resmilla": "res-mi-lla",
    "resobada": "re-so-ba-da",
    "resobado": "re-so-ba-do",
    "resobar": "re-so-bar",
    "resobrar": "re-so-brar",
    "resobrina": "re-so-bri-na",
    "resobrino": "re-so-bri-no",
    "resol": "re-sol",
    "resolana": "re-so-la-na",
    "resolano": "re-so-la-no",
    "resolgar": "re-sol-gar",
    "resoli": "re-so-li",
    "resolí": "re-so-lí",
    "resolladero": "re-so-lla-de-ro",
    "resollar": "re-so-llar",
    "resoluble": "re-so-lu-ble",
    "resolución": "re-so-lu-ción",
    "resoluta": "re-so-lu-ta",
    "resolutamente": "re-so-lu-ta-men-te",
    "resolutiva": "re-so-lu-ti-va",
    "resolutivamente": "re-so-lu-ti-va-men-te",
    "resolutivo": "re-so-lu-ti-vo",
    "resoluto": "re-so-lu-to",
    "resolutoria": "re-so-lu-to-ria",
    "resolutoriamente": "re-so-lu-to-ria-men-te",
    "resolutorio": "re-so-lu-to-rio",
    "resolvente": "re-sol-ven-te",
    "resolver": "re-sol-ver",
    "resolviente": "re-sol-vien-te",
    "resonación": "re-so-na-ción",
    "resonador": "re-so-na-dor",
    "resonadora": "re-so-na-do-ra",
    "resonancia": "re-so-nan-cia",
    "resonante": "re-so-nan-te",
    "resonar": "re-so-nar",
    "resondrar": "re-son-drar",
    "resoplar": "re-so-plar",
    "resoplido": "re-so-pli-do",
    "resoplo": "re-so-plo",
    "resorber": "re-sor-ber",
    "resorción": "re-sor-ción",
    "resorte": "re-sor-te",
    "resortera": "re-sor-te-ra",
    "respahilar": "res-pahi-lar",
    "respaldar": "res-pal-dar",
    "respaldo": "res-pal-do",
    "respe": "res-pe",
    "respectar": "res-pec-tar",
    "respectiva": "res-pec-ti-va",
    "respectivamente": "res-pec-ti-va-men-te",
    "respective": "res-pec-ti-ve",
    "respectivo": "res-pec-ti-vo",
    "respecto": "res-pec-to",
    "résped": "rés-ped",
    "réspede": "rés-pe-de",
    "respeluzar": "res-pe-lu-zar",
    "respetabilidad": "res-pe-ta-bi-li-dad",
    "respetable": "res-pe-ta-ble",
    "respetador": "res-pe-ta-dor",
    "respetadora": "res-pe-ta-do-ra",
    "respetar": "res-pe-tar",
    "respetiva": "res-pe-ti-va",
    "respetivo": "res-pe-ti-vo",
    "respeto": "res-pe-to",
    "respetosa": "res-pe-to-sa",
    "respetosamente": "res-pe-to-sa-men-te",
    "respetoso": "res-pe-to-so",
    "respetuosa": "res-pe-tuo-sa",
    "respetuosamente": "res-pe-tuo-sa-men-te",
    "respetuosidad": "res-pe-tuo-si-dad",
    "respetuoso": "res-pe-tuo-so",
    "réspice": "rés-pi-ce",
    "respigador": "res-pi-ga-dor",
    "respigadora": "res-pi-ga-do-ra",
    "respigar": "res-pi-gar",
    "respigo": "res-pi-go",
    "respigón": "res-pi-gón",
    "respingar": "res-pin-gar",
    "respingo": "res-pin-go",
    "respingón": "res-pin-gón",
    "respingona": "res-pin-go-na",
    "respirable": "res-pi-ra-ble",
    "respiración": "res-pi-ra-ción",
    "respiradero": "res-pi-ra-de-ro",
    "respirador": "res-pi-ra-dor",
    "respiradora": "res-pi-ra-do-ra",
    "respirar": "res-pi-rar",
    "respiratoria": "res-pi-ra-to-ria",
    "respiratorio": "res-pi-ra-to-rio",
    "respiro": "res-pi-ro",
    "resplandecer": "res-plan-de-cer",
    "resplandeciente": "res-plan-de-cien-te",
    "resplandecimiento": "res-plan-de-ci-mien-to",
    "resplandina": "res-plan-di-na",
    "resplandor": "res-plan-dor",
    "resplendente": "res-plen-den-te",
    "resplendor": "res-plen-dor",
    "respondedor": "res-pon-de-dor",
    "respondedora": "res-pon-de-do-ra",
    "respondencia": "res-pon-den-cia",
    "responder": "res-pon-der",
    "respondidamente": "res-pon-di-da-men-te",
    "respondón": "res-pon-dón",
    "respondona": "res-pon-do-na",
    "responsabilidad": "res-pon-sa-bi-li-dad",
    "responsabilizar": "res-pon-sa-bi-li-zar",
    "responsable": "res-pon-sa-ble",
    "responsablemente": "res-pon-sa-ble-men-te",
    "responsar": "res-pon-sar",
    "responsear": "res-pon-se-ar",
    "responseo": "res-pon-se-o",
    "responsión": "res-pon-sión",
    "responsiva": "res-pon-si-va",
    "responsivo": "res-pon-si-vo",
    "responso": "res-pon-so",
    "responsorial": "res-pon-so-rial",
    "responsorio": "res-pon-so-rio",
    "respuesta": "res-pues-ta",
    "resquebradura": "res-que-bra-du-ra",
    "resquebrajadiza": "res-que-bra-ja-di-za",
    "resquebrajadizo": "res-que-bra-ja-di-zo",
    "resquebrajadura": "res-que-bra-ja-du-ra",
    "resquebrajamiento": "res-que-bra-ja-mien-to",
    "resquebrajar": "res-que-bra-jar",
    "resquebrajo": "res-que-bra-jo",
    "resquebrajosa": "res-que-bra-jo-sa",
    "resquebrajoso": "res-que-bra-jo-so",
    "resquebrar": "res-que-brar",
    "resquemar": "res-que-mar",
    "resquemazón": "res-que-ma-zón",
    "resquemo": "res-que-mo",
    "resquemor": "res-que-mor",
    "resquicio": "res-qui-cio",
    "resquilar": "res-qui-lar",
    "resquilo": "res-qui-lo",
    "resquitar": "res-qui-tar",
    "resta": "res-ta",
    "restablecer": "res-ta-ble-cer",
    "restablecimiento": "res-ta-ble-ci-mien-to",
    "restada": "res-ta-da",
    "restado": "res-ta-do",
    "restallar": "res-ta-llar",
    "restallido": "res-ta-lli-do",
    "restañadero": "res-ta-ña-de-ro",
    "restañadura": "res-ta-ña-du-ra",
    "restañar": "res-ta-ñar",
    "restañasangre": "res-ta-ña-san-gre",
    "restaño": "res-ta-ño",
    "restante": "res-tan-te",
    "restar": "res-tar",
    "restauración": "res-tau-ra-ción",
    "restaurador": "res-tau-ra-dor",
    "restauradora": "res-tau-ra-do-ra",
    "restaurante": "res-tau-ran-te",
    "restaurantera": "res-tau-ran-te-ra",
    "restaurantero": "res-tau-ran-te-ro",
    "restaurar": "res-tau-rar",
    "restaurativa": "res-tau-ra-ti-va",
    "restaurativo": "res-tau-ra-ti-vo",
    "restauro": "res-tau-ro",
    "restear": "res-te-ar",
    "restinga": "res-tin-ga",
    "restingar": "res-tin-gar",
    "restirador": "res-ti-ra-dor",
    "restitución": "res-ti-tu-ción",
    "restituible": "res-ti-tui-ble",
    "restituidor": "res-ti-tui-dor",
    "restituidora": "res-ti-tui-do-ra",
    "restituir": "res-ti-tuir",
    "restitutoria": "res-ti-tu-to-ria",
    "restitutorio": "res-ti-tu-to-rio",
    "resto": "res-to",
    "restojo": "res-to-jo",
    "restorán": "res-to-rán",
    "restregadura": "res-tre-ga-du-ra",
    "restregamiento": "res-tre-ga-mien-to",
    "restregar": "res-tre-gar",
    "restregón": "res-tre-gón",
    "restreñido": "res-tre-ñi-do",
    "restreñimiento": "res-tre-ñi-mien-to",
    "restreñir": "res-tre-ñir",
    "restribar": "res-tri-bar",
    "restricción": "res-tric-ción",
    "restricta": "res-tric-ta",
    "restrictiva": "res-tric-ti-va",
    "restrictivamente": "res-tric-ti-va-men-te",
    "restrictivo": "res-tric-ti-vo",
    "restricto": "res-tric-to",
    "restringa": "res-trin-ga",
    "restringente": "res-trin-gen-te",
    "restringible": "res-trin-gi-ble",
    "restringido": "res-trin-gi-do",
    "restringir": "res-trin-gir",
    "restriñidor": "res-tri-ñi-dor",
    "restriñidora": "res-tri-ñi-do-ra",
    "restriñimiento": "res-tri-ñi-mien-to",
    "restriñir": "res-tri-ñir",
    "restrojo": "res-tro-jo",
    "resuave": "re-sua-ve",
    "resucitación": "re-su-ci-ta-ción",
    "resucitado": "re-su-ci-ta-do",
    "resucitador": "re-su-ci-ta-dor",
    "resucitadora": "re-su-ci-ta-do-ra",
    "resucitar": "re-su-ci-tar",
    "resudación": "re-su-da-ción",
    "resudar": "re-su-dar",
    "resudor": "re-su-dor",
    "resuello": "re-sue-llo",
    "resuelta": "re-suel-ta",
    "resueltamente": "re-suel-ta-men-te",
    "resuelto": "re-suel-to",
    "resuelve": "re-suel-ve",
    "resulta": "re-sul-ta",
    "resultado": "re-sul-ta-do",
    "resultancia": "re-sul-tan-cia",
    "resultando": "re-sul-tan-do",
    "resultante": "re-sul-tan-te",
    "resultar": "re-sul-tar",
    "resultón": "re-sul-tón",
    "resumbruno": "re-sum-bru-no",
    "resumen": "re-su-men",
    "resumidamente": "re-su-mi-da-men-te",
    "resumidero": "re-su-mi-de-ro",
    "resumir": "re-su-mir",
    "resunta": "re-sun-ta",
    "resurgencia": "re-sur-gen-cia",
    "resurgimiento": "re-sur-gi-mien-to",
    "resurgir": "re-sur-gir",
    "resurrección": "re-su-rrec-ción",
    "resurtida": "re-sur-ti-da",
    "resurtir": "re-sur-tir",
    "resurtiva": "re-sur-ti-va",
    "resurtivo": "re-sur-ti-vo",
    "retablero": "re-ta-ble-ro",
    "retablo": "re-ta-blo",
    "retacar": "re-ta-car",
    "retacear": "re-ta-ce-ar",
    "retaceo": "re-ta-ce-o",
    "retacera": "re-ta-ce-ra",
    "retacería": "re-ta-ce-rí-a",
    "retacero": "re-ta-ce-ro",
    "retachar": "re-ta-char",
    "retache": "re-ta-che",
    "retaco": "re-ta-co",
    "retacón": "re-ta-cón",
    "retador": "re-ta-dor",
    "retadora": "re-ta-do-ra",
    "retaguarda": "re-ta-guar-da",
    "retaguardia": "re-ta-guar-dia",
    "retahíla": "re-ta-hí-la",
    "retajadura": "re-ta-ja-du-ra",
    "retajar": "re-ta-jar",
    "retajo": "re-ta-jo",
    "retal": "re-tal",
    "retaliación": "re-ta-lia-ción",
    "retaliador": "re-ta-lia-dor",
    "retaliadora": "re-ta-lia-do-ra",
    "retaliativo": "re-ta-lia-ti-vo",
    "retallar": "re-ta-llar",
    "retallecer": "re-ta-lle-cer",
    "retallo": "re-ta-llo",
    "retallón": "re-ta-llón",
    "retalteca": "re-tal-te-ca",
    "retalteco": "re-tal-te-co",
    "retama": "re-ta-ma",
    "retamal": "re-ta-mal",
    "retamar": "re-ta-mar",
    "retamera": "re-ta-me-ra",
    "retamero": "re-ta-me-ro",
    "retamilla": "re-ta-mi-lla",
    "retamo": "re-ta-mo",
    "retamón": "re-ta-món",
    "retar": "re-tar",
    "retardación": "re-tar-da-ción",
    "retardada": "re-tar-da-da",
    "retardado": "re-tar-da-do",
    "retardador": "re-tar-da-dor",
    "retardadora": "re-tar-da-do-ra",
    "retardar": "re-tar-dar",
    "retardataria": "re-tar-da-ta-ria",
    "retardatario": "re-tar-da-ta-rio",
    "retardativa": "re-tar-da-ti-va",
    "retardativo": "re-tar-da-ti-vo",
    "retardatoria": "re-tar-da-to-ria",
    "retardatorio": "re-tar-da-to-rio",
    "retardatriz": "re-tar-da-triz",
    "retardo": "re-tar-do",
    "retartalillas": "re-tar-ta-li-llas",
    "retasa": "re-ta-sa",
    "retasación": "re-ta-sa-ción",
    "retasar": "re-ta-sar",
    "retazar": "re-ta-zar",
    "retazo": "re-ta-zo",
    "rete": "re-te",
    "retejado": "re-te-ja-do",
    "retejador": "re-te-ja-dor",
    "retejar": "re-te-jar",
    "retejer": "re-te-jer",
    "retejo": "re-te-jo",
    "retel": "re-tel",
    "retemblar": "re-tem-blar",
    "retén": "re-tén",
    "retención": "re-ten-ción",
    "retenedor": "re-te-ne-dor",
    "retenedora": "re-te-ne-do-ra",
    "retenencia": "re-te-nen-cia",
    "retener": "re-te-ner",
    "retenida": "re-te-ni-da",
    "retenidamente": "re-te-ni-da-men-te",
    "retenimiento": "re-te-ni-mien-to",
    "reteñir": "re-te-ñir",
    "retentar": "re-ten-tar",
    "retentiva": "re-ten-ti-va",
    "retentivo": "re-ten-ti-vo",
    "retesamiento": "re-te-sa-mien-to",
    "retesar": "re-te-sar",
    "reteso": "re-te-so",
    "retestinar": "re-tes-ti-nar",
    "rética": "ré-ti-ca",
    "reticencia": "re-ti-cen-cia",
    "reticente": "re-ti-cen-te",
    "rético": "ré-ti-co",
    "retícula": "re-tí-cu-la",
    "reticulado": "re-ti-cu-la-do",
    "reticular": "re-ti-cu-lar",
    "retículo": "re-tí-cu-lo",
    "retienta": "re-tien-ta",
    "retín": "re-tín",
    "retina": "re-ti-na",
    "retinar": "re-ti-nar",
    "retinglar": "re-tin-glar",
    "retiniana": "re-ti-nia-na",
    "retiniano": "re-ti-nia-no",
    "retínico": "re-tí-ni-co",
    "retiñir": "re-ti-ñir",
    "retinografía": "re-ti-no-gra-fí-a",
    "retinol": "re-ti-nol",
    "retinopatía": "re-ti-no-pa-tí-a",
    "retinta": "re-tin-ta",
    "retinte": "re-tin-te",
    "retintín": "re-tin-tín",
    "retinto": "re-tin-to",
    "retiración": "re-ti-ra-ción",
    "retirada": "re-ti-ra-da",
    "retiradamente": "re-ti-ra-da-men-te",
    "retirado": "re-ti-ra-do",
    "retiramiento": "re-ti-ra-mien-to",
    "retirar": "re-ti-rar",
    "retiro": "re-ti-ro",
    "reto": "re-to",
    "retobada": "re-to-ba-da",
    "retobado": "re-to-ba-do",
    "retobar": "re-to-bar",
    "retobo": "re-to-bo",
    "retobón": "re-to-bón",
    "retocado": "re-to-ca-do",
    "retocador": "re-to-ca-dor",
    "retocadora": "re-to-ca-do-ra",
    "retocar": "re-to-car",
    "retomar": "re-to-mar",
    "retoñar": "re-to-ñar",
    "retoñecer": "re-to-ñe-cer",
    "retoño": "re-to-ño",
    "retoque": "re-to-que",
    "retor": "re-tor",
    "rétor": "ré-tor",
    "retorcedura": "re-tor-ce-du-ra",
    "retorcer": "re-tor-cer",
    "retorcida": "re-tor-ci-da",
    "retorcido": "re-tor-ci-do",
    "retorcijar": "re-tor-ci-jar",
    "retorcijo": "re-tor-ci-jo",
    "retorcijón": "re-tor-ci-jón",
    "retorcimiento": "re-tor-ci-mien-to",
    "retórica": "re-tó-ri-ca",
    "retoricadamente": "re-to-ri-ca-da-men-te",
    "retóricamente": "re-tó-ri-ca-men-te",
    "retoricar": "re-to-ri-car",
    "retoricismo": "re-to-ri-cis-mo",
    "retórico": "re-tó-ri-co",
    "retornable": "re-tor-na-ble",
    "retornamiento": "re-tor-na-mien-to",
    "retornar": "re-tor-nar",
    "retornelo": "re-tor-ne-lo",
    "retorno": "re-tor-no",
    "retorromana": "re-to-rro-ma-na",
    "retorromance": "re-to-rro-man-ce",
    "retorrománico": "re-to-rro-má-ni-co",
    "retorromano": "re-to-rro-ma-no",
    "retorsión": "re-tor-sión",
    "retorsiva": "re-tor-si-va",
    "retorsivo": "re-tor-si-vo",
    "retorta": "re-tor-ta",
    "retortero": "re-tor-te-ro",
    "retortijar": "re-tor-ti-jar",
    "retortijón": "re-tor-ti-jón",
    "retostada": "re-tos-ta-da",
    "retostado": "re-tos-ta-do",
    "retostar": "re-tos-tar",
    "retozador": "re-to-za-dor",
    "retozadora": "re-to-za-do-ra",
    "retozadura": "re-to-za-du-ra",
    "retozar": "re-to-zar",
    "retozo": "re-to-zo",
    "retozón": "re-to-zón",
    "retozona": "re-to-zo-na",
    "retracción": "re-trac-ción",
    "retractable": "re-trac-ta-ble",
    "retractación": "re-trac-ta-ción",
    "retractar": "re-trac-tar",
    "retráctil": "re-trác-til",
    "retractilado": "re-trac-ti-la-do",
    "retractilar": "re-trac-ti-lar",
    "retractilidad": "re-trac-ti-li-dad",
    "retracto": "re-trac-to",
    "retraducir": "re-tra-du-cir",
    "retraer": "re-tra-er",
    "retraher": "re-tra-her",
    "retraída": "re-tra-í-da",
    "retraído": "re-tra-í-do",
    "retraimiento": "re-trai-mien-to",
    "retranca": "re-tran-ca",
    "retrancar": "re-tran-car",
    "retranquear": "re-tran-que-ar",
    "retranqueo": "re-tran-que-o",
    "retranquero": "re-tran-que-ro",
    "retransmisión": "re-trans-mi-sión",
    "retransmisor": "re-trans-mi-sor",
    "retransmitir": "re-trans-mi-tir",
    "retrasada": "re-tra-sa-da",
    "retrasado": "re-tra-sa-do",
    "retrasar": "re-tra-sar",
    "retraso": "re-tra-so",
    "retratable": "re-tra-ta-ble",
    "retratación": "re-tra-ta-ción",
    "retratador": "re-tra-ta-dor",
    "retratadora": "re-tra-ta-do-ra",
    "retratar": "re-tra-tar",
    "retratería": "re-tra-te-rí-a",
    "retratista": "re-tra-tis-ta",
    "retrato": "re-tra-to",
    "retrayente": "re-tra-yen-te",
    "retrechar": "re-tre-char",
    "retrechera": "re-tre-che-ra",
    "retrechería": "re-tre-che-rí-a",
    "retrechero": "re-tre-che-ro",
    "retrepada": "re-tre-pa-da",
    "retrepado": "re-tre-pa-do",
    "retrepar": "re-tre-par",
    "retreparse": "re-tre-par-se",
    "retreta": "re-tre-ta",
    "retrete": "re-tre-te",
    "retribución": "re-tri-bu-ción",
    "retribuir": "re-tri-buir",
    "retributiva": "re-tri-bu-ti-va",
    "retributivo": "re-tri-bu-ti-vo",
    "retriever": "re-trie-ver",
    "retril": "re-tril",
    "retrillar": "re-tri-llar",
    "retro": "re-tro",
    "retroacción": "re-tro-ac-ción",
    "retroactiva": "re-tro-ac-ti-va",
    "retroactividad": "re-tro-ac-ti-vi-dad",
    "retroactivo": "re-tro-ac-ti-vo",
    "retroalimentación": "re-tro-a-li-men-ta-ción",
    "retrocar": "re-tro-car",
    "retrocarga": "re-tro-car-ga",
    "retroceder": "re-tro-ce-der",
    "retrocesión": "re-tro-ce-sión",
    "retroceso": "re-tro-ce-so",
    "retrocuenta": "re-tro-cuen-ta",
    "retrógrada": "re-tró-gra-da",
    "retrogradación": "re-tro-gra-da-ción",
    "retrogradar": "re-tro-gra-dar",
    "retrógrado": "re-tró-gra-do",
    "retroguardia": "re-tro-guar-dia",
    "retronar": "re-tro-nar",
    "retrónica": "re-tró-ni-ca",
    "retropié": "re-tro-pié",
    "retropilastra": "re-tro-pi-las-tra",
    "retropropulsión": "re-tro-pro-pul-sión",
    "retropróximo": "re-tro-pró-xi-mo",
    "retroproyector": "re-tro-pro-yec-tor",
    "retropulsión": "re-tro-pul-sión",
    "retrospección": "re-tros-pec-ción",
    "retrospectiva": "re-tros-pec-ti-va",
    "retrospectivo": "re-tros-pec-ti-vo",
    "retrotracción": "re-tro-trac-ción",
    "retrotraer": "re-tro-tra-er",
    "retrovendendo": "re-tro-ven-den-do",
    "retrovender": "re-tro-ven-der",
    "retrovendición": "re-tro-ven-di-ción",
    "retroventa": "re-tro-ven-ta",
    "retroversión": "re-tro-ver-sión",
    "retrovirus": "re-tro-vi-rus",
    "retrovisor": "re-tro-vi-sor",
    "retrucar": "re-tru-car",
    "retruco": "re-tru-co",
    "retruécano": "re-trué-ca-no",
    "retruque": "re-tru-que",
    "retuelle": "re-tue-lle",
    "retuerta": "re-tuer-ta",
    "retuerto": "re-tuer-to",
    "rétulo": "ré-tu-lo",
    "retumbante": "re-tum-ban-te",
    "retumbar": "re-tum-bar",
    "retumbo": "re-tum-bo",
    "retundir": "re-tun-dir",
    "reucliniana": "reu-cli-nia-na",
    "reucliniano": "reu-cli-nia-no",
    "reúma": "re-ú-ma",
    "reuma": "reu-ma",
    "reumática": "reu-má-ti-ca",
    "reumático": "reu-má-ti-co",
    "reumátide": "reu-má-ti-de",
    "reumatismo": "reu-ma-tis-mo",
    "reumatóloga": "reu-ma-tó-lo-ga",
    "reumatología": "reu-ma-to-lo-gí-a",
    "reumatológico": "reu-ma-to-ló-gi-co",
    "reumatólogo": "reu-ma-tó-lo-go",
    "reundir": "reun-dir",
    "reunificación": "reu-ni-fi-ca-ción",
    "reunificar": "reu-ni-fi-car",
    "reunión": "reu-nión",
    "reunir": "reu-nir",
    "reuntar": "reun-tar",
    "reusense": "reu-sen-se",
    "reutilizable": "reu-ti-li-za-ble",
    "reutilización": "reu-ti-li-za-ción",
    "reutilizar": "reu-ti-li-zar",
    "revacunación": "re-va-cu-na-ción",
    "revacunar": "re-va-cu-nar",
    "reválida": "re-vá-li-da",
    "revalidación": "re-va-li-da-ción",
    "revalidar": "re-va-li-dar",
    "revalorización": "re-va-lo-ri-za-ción",
    "revalorizador": "re-va-lo-ri-za-dor",
    "revalorizar": "re-va-lo-ri-zar",
    "revaluación": "re-va-lua-ción",
    "revaluar": "re-va-luar",
    "revancha": "re-van-cha",
    "revanchismo": "re-van-chis-mo",
    "revanchista": "re-van-chis-ta",
    "revascularización": "re-vas-cu-la-ri-za-ción",
    "revecera": "re-ve-ce-ra",
    "revecero": "re-ve-ce-ro",
    "reveedor": "re-ve-e-dor",
    "revejecer": "re-ve-je-cer",
    "revejida": "re-ve-ji-da",
    "revejido": "re-ve-ji-do",
    "revejuda": "re-ve-ju-da",
    "revejudo": "re-ve-ju-do",
    "revelable": "re-ve-la-ble",
    "revelación": "re-ve-la-ción",
    "revelado": "re-ve-la-do",
    "revelador": "re-ve-la-dor",
    "reveladora": "re-ve-la-do-ra",
    "revelamiento": "re-ve-la-mien-to",
    "revelandera": "re-ve-lan-de-ra",
    "revelandero": "re-ve-lan-de-ro",
    "revelar": "re-ve-lar",
    "reveler": "re-ve-ler",
    "revellín": "re-ve-llín",
    "revenar": "re-ve-nar",
    "revencer": "re-ven-cer",
    "revendedera": "re-ven-de-de-ra",
    "revendedor": "re-ven-de-dor",
    "revendedora": "re-ven-de-do-ra",
    "revender": "re-ven-der",
    "revendón": "re-ven-dón",
    "revendona": "re-ven-do-na",
    "revenido": "re-ve-ni-do",
    "revenimiento": "re-ve-ni-mien-to",
    "revenir": "re-ve-nir",
    "reveno": "re-ve-no",
    "reventa": "re-ven-ta",
    "reventada": "re-ven-ta-da",
    "reventadero": "re-ven-ta-de-ro",
    "reventado": "re-ven-ta-do",
    "reventador": "re-ven-ta-dor",
    "reventadora": "re-ven-ta-do-ra",
    "reventar": "re-ven-tar",
    "reventazón": "re-ven-ta-zón",
    "reventón": "re-ven-tón",
    "rever": "re-ver",
    "reverberación": "re-ver-be-ra-ción",
    "reverberar": "re-ver-be-rar",
    "reverbero": "re-ver-be-ro",
    "reverdecer": "re-ver-de-cer",
    "reverdecimiento": "re-ver-de-ci-mien-to",
    "reverencia": "re-ve-ren-cia",
    "reverenciable": "re-ve-ren-cia-ble",
    "reverenciador": "re-ve-ren-cia-dor",
    "reverenciadora": "re-ve-ren-cia-do-ra",
    "reverencial": "re-ve-ren-cial",
    "reverenciar": "re-ve-ren-ciar",
    "reverencioso": "re-ve-ren-cio-so",
    "reverenda": "re-ve-ren-da",
    "reverendas": "re-ve-ren-das",
    "reverendísima": "re-ve-ren-dí-si-ma",
    "reverendísimo": "re-ve-ren-dí-si-mo",
    "reverendo": "re-ve-ren-do",
    "reverente": "re-ve-ren-te",
    "reversa": "re-ver-sa",
    "reversar": "re-ver-sar",
    "reverse": "re-ver-se",
    "reversibilidad": "re-ver-si-bi-li-dad",
    "reversible": "re-ver-si-ble",
    "reversión": "re-ver-sión",
    "reverso": "re-ver-so",
    "reverter": "re-ver-ter",
    "revertir": "re-ver-tir",
    "revés": "re-vés",
    "revesa": "re-ve-sa",
    "revesada": "re-ve-sa-da",
    "revesado": "re-ve-sa-do",
    "revesar": "re-ve-sar",
    "revesino": "re-ve-si-no",
    "revestido": "re-ves-ti-do",
    "revestimiento": "re-ves-ti-mien-to",
    "revestir": "re-ves-tir",
    "reveza": "re-ve-za",
    "revezar": "re-ve-zar",
    "revezo": "re-ve-zo",
    "revidada": "re-vi-da-da",
    "revidar": "re-vi-dar",
    "revieja": "re-vie-ja",
    "reviejo": "re-vie-jo",
    "revientacaballo": "re-vien-ta-ca-ba-llo",
    "reviernes": "re-vier-nes",
    "revigorizar": "re-vi-go-ri-zar",
    "revinar": "re-vi-nar",
    "revindicar": "re-vin-di-car",
    "revirada": "re-vi-ra-da",
    "revirado": "re-vi-ra-do",
    "revirar": "re-vi-rar",
    "revire": "re-vi-re",
    "reviro": "re-vi-ro",
    "revisable": "re-vi-sa-ble",
    "revisada": "re-vi-sa-da",
    "revisar": "re-vi-sar",
    "revisión": "re-vi-sión",
    "revisionismo": "re-vi-sio-nis-mo",
    "revisionista": "re-vi-sio-nis-ta",
    "revisita": "re-vi-si-ta",
    "revisor": "re-vi-sor",
    "revisora": "re-vi-so-ra",
    "revisoría": "re-vi-so-rí-a",
    "revista": "re-vis-ta",
    "revistar": "re-vis-tar",
    "revistera": "re-vis-te-ra",
    "revistero": "re-vis-te-ro",
    "revisto": "re-vis-to",
    "revitalización": "re-vi-ta-li-za-ción",
    "revitalizante": "re-vi-ta-li-zan-te",
    "revitalizar": "re-vi-ta-li-zar",
    "revival": "re-vi-val",
    "revividero": "re-vi-vi-de-ro",
    "revivificación": "re-vi-vi-fi-ca-ción",
    "revivificar": "re-vi-vi-fi-car",
    "revivir": "re-vi-vir",
    "reviviscencia": "re-vi-vis-cen-cia",
    "revocabilidad": "re-vo-ca-bi-li-dad",
    "revocable": "re-vo-ca-ble",
    "revocablemente": "re-vo-ca-ble-men-te",
    "revocación": "re-vo-ca-ción",
    "revocador": "re-vo-ca-dor",
    "revocadora": "re-vo-ca-do-ra",
    "revocadura": "re-vo-ca-du-ra",
    "revocar": "re-vo-car",
    "revocatoria": "re-vo-ca-to-ria",
    "revocatorio": "re-vo-ca-to-rio",
    "revoco": "re-vo-co",
    "revolar": "re-vo-lar",
    "revolcadero": "re-vol-ca-de-ro",
    "revolcado": "re-vol-ca-do",
    "revolcar": "re-vol-car",
    "revolcón": "re-vol-cón",
    "revolear": "re-vo-le-ar",
    "revoleo": "re-vo-le-o",
    "revolera": "re-vo-le-ra",
    "revolero": "re-vo-le-ro",
    "revolico": "re-vo-li-co",
    "revolotear": "re-vo-lo-te-ar",
    "revoloteo": "re-vo-lo-te-o",
    "revoltijo": "re-vol-ti-jo",
    "revoltillo": "re-vol-ti-llo",
    "revoltón": "re-vol-tón",
    "revoltosa": "re-vol-to-sa",
    "revoltoso": "re-vol-to-so",
    "revoltura": "re-vol-tu-ra",
    "revolú": "re-vo-lú",
    "revoluca": "re-vo-lu-ca",
    "revolución": "re-vo-lu-ción",
    "revolucionar": "re-vo-lu-cio-nar",
    "revolucionaria": "re-vo-lu-cio-na-ria",
    "revolucionario": "re-vo-lu-cio-na-rio",
    "revoluco": "re-vo-lu-co",
    "revoluto": "re-vo-lu-to",
    "revolvedero": "re-vol-ve-de-ro",
    "revolvedor": "re-vol-ve-dor",
    "revolvedora": "re-vol-ve-do-ra",
    "revolver": "re-vol-ver",
    "revólver": "re-vól-ver",
    "revolvimiento": "re-vol-vi-mien-to",
    "revoque": "re-vo-que",
    "revotar": "re-vo-tar",
    "revotarse": "re-vo-tar-se",
    "revuelco": "re-vuel-co",
    "revuelo": "re-vue-lo",
    "revuelta": "re-vuel-ta",
    "revueltamente": "re-vuel-ta-men-te",
    "revuelto": "re-vuel-to",
    "revuelvepiedras": "re-vuel-ve-pie-dras",
    "revulsión": "re-vul-sión",
    "revulsiva": "re-vul-si-va",
    "revulsivo": "re-vul-si-vo",
    "revulsoria": "re-vul-so-ria",
    "revulsorio": "re-vul-so-rio",
    "reyar": "re-yar",
    "reyerta": "re-yer-ta",
    "reyesana": "re-ye-sa-na",
    "reyesano": "re-ye-sa-no",
    "reyezuelo": "re-ye-zue-lo",
    "reykjanés": "reyk-ja-nés",
    "reykjanesa": "reyk-ja-ne-sa",
    "reyuna": "re-yu-na",
    "reyuno": "re-yu-no",
    "rezada": "re-za-da",
    "rezadera": "re-za-de-ra",
    "rezado": "re-za-do",
    "rezador": "re-za-dor",
    "rezadora": "re-za-do-ra",
    "rezaga": "re-za-ga",
    "rezagar": "re-za-gar",
    "rezago": "re-za-go",
    "rezandera": "re-zan-de-ra",
    "rezandero": "re-zan-de-ro",
    "rezar": "re-zar",
    "rezmila": "rez-mi-la",
    "rezno": "rez-no",
    "rezo": "re-zo",
    "rezón": "re-zón",
    "rezongador": "re-zon-ga-dor",
    "rezongadora": "re-zon-ga-do-ra",
    "rezongar": "re-zon-gar",
    "rezonglar": "re-zon-glar",
    "rezonglón": "re-zon-glón",
    "rezonglona": "re-zon-glo-na",
    "rezongo": "re-zon-go",
    "rezongón": "re-zon-gón",
    "rezongona": "re-zon-go-na",
    "rezonguera": "re-zon-gue-ra",
    "rezonguero": "re-zon-gue-ro",
    "rezumadero": "re-zu-ma-de-ro",
    "rezumar": "re-zu-mar",
    "rezura": "re-zu-ra",
    "rezurcir": "re-zur-cir",
    "ría": "rí-a",
    "riacho": "ria-cho",
    "riachuelo": "ria-chue-lo",
    "riada": "ria-da",
    "riata": "ria-ta",
    "riatillo": "ria-ti-llo",
    "riba": "ri-ba",
    "ribacera": "ri-ba-ce-ra",
    "ribadense": "ri-ba-den-se",
    "ribadoquín": "ri-ba-do-quín",
    "ribagorzana": "ri-ba-gor-za-na",
    "ribagorzano": "ri-ba-gor-za-no",
    "ribalda": "ri-bal-da",
    "ribaldería": "ri-bal-de-rí-a",
    "ribaldo": "ri-bal-do",
    "ribazo": "ri-ba-zo",
    "ribazón": "ri-ba-zón",
    "ribeiro": "ri-bei-ro",
    "ribera": "ri-be-ra",
    "riberalteña": "ri-be-ral-te-ña",
    "riberalteño": "ri-be-ral-te-ño",
    "riberana": "ri-be-ra-na",
    "riberano": "ri-be-ra-no",
    "ribereña": "ri-be-re-ña",
    "ribereño": "ri-be-re-ño",
    "riberiega": "ri-be-rie-ga",
    "riberiego": "ri-be-rie-go",
    "ribero": "ri-be-ro",
    "ribete": "ri-be-te",
    "ribeteada": "ri-be-te-a-da",
    "ribeteado": "ri-be-te-a-do",
    "ribeteador": "ri-be-te-a-dor",
    "ribeteadora": "ri-be-te-a-do-ra",
    "ribetear": "ri-be-te-ar",
    "riboflavina": "ri-bo-fla-vi-na",
    "ribonucleico": "ri-bo-nu-clei-co",
    "ribonucleótido": "ri-bo-nu-cle-ó-ti-do",
    "ribosa": "ri-bo-sa",
    "ribosoma": "ri-bo-so-ma",
    "ribosómico": "ri-bo-só-mi-co",
    "rica": "ri-ca",
    "ricacha": "ri-ca-cha",
    "ricacho": "ri-ca-cho",
    "ricachón": "ri-ca-chón",
    "ricachona": "ri-ca-cho-na",
    "ricadueña": "ri-ca-due-ña",
    "ricahembra": "ri-ca-hem-bra",
    "ricahombría": "ri-ca-hom-brí-a",
    "ricamente": "ri-ca-men-te",
    "ricia": "ri-cia",
    "ricial": "ri-cial",
    "ricino": "ri-ci-no",
    "ricio": "ri-cio",
    "rico": "ri-co",
    "ricohombre": "ri-co-hom-bre",
    "ricota": "ri-co-ta",
    "rictus": "ric-tus",
    "ricura": "ri-cu-ra",
    "ridícula": "ri-dí-cu-la",
    "ridículamente": "ri-dí-cu-la-men-te",
    "ridiculez": "ri-di-cu-lez",
    "ridiculización": "ri-di-cu-li-za-ción",
    "ridiculizar": "ri-di-cu-li-zar",
    "ridículo": "ri-dí-cu-lo",
    "ridiculosa": "ri-di-cu-lo-sa",
    "ridiculoso": "ri-di-cu-lo-so",
    "riego": "rie-go",
    "rielar": "rie-lar",
    "rielera": "rie-le-ra",
    "rielero": "rie-le-ro",
    "rienda": "rien-da",
    "riendazo": "rien-da-zo",
    "riente": "rien-te",
    "riepto": "riep-to",
    "riera": "rie-ra",
    "riesgo": "ries-go",
    "riesgoso": "ries-go-so",
    "riestra": "ries-tra",
    "rifa": "ri-fa",
    "rifador": "ri-fa-dor",
    "rifadora": "ri-fa-do-ra",
    "rifadura": "ri-fa-du-ra",
    "rifar": "ri-far",
    "rifarrafa": "ri-fa-rra-fa",
    "rifeña": "ri-fe-ña",
    "rifeño": "ri-fe-ño",
    "rifirrafe": "ri-fi-rra-fe",
    "riflazo": "ri-fla-zo",
    "rifle": "ri-fle",
    "riflera": "ri-fle-ra",
    "riflero": "ri-fle-ro",
    "rigente": "ri-gen-te",
    "rígida": "rí-gi-da",
    "rígidamente": "rí-gi-da-men-te",
    "rigidez": "ri-gi-dez",
    "rígido": "rí-gi-do",
    "rigil": "ri-gil",
    "rigodón": "ri-go-dón",
    "rigor": "ri-gor",
    "rigorismo": "ri-go-ris-mo",
    "rigorista": "ri-go-ris-ta",
    "rigorosa": "ri-go-ro-sa",
    "rigorosamente": "ri-go-ro-sa-men-te",
    "rigoroso": "ri-go-ro-so",
    "rigua": "ri-gua",
    "rigüe": "ri-güe",
    "riguridad": "ri-gu-ri-dad",
    "rigurosa": "ri-gu-ro-sa",
    "rigurosamente": "ri-gu-ro-sa-men-te",
    "rigurosidad": "ri-gu-ro-si-dad",
    "riguroso": "ri-gu-ro-so",
    "rija": "ri-ja",
    "rijador": "ri-ja-dor",
    "rijadora": "ri-ja-do-ra",
    "rijioso": "ri-jio-so",
    "rijo": "ri-jo",
    "rijosa": "ri-jo-sa",
    "rijosidad": "ri-jo-si-dad",
    "rijoso": "ri-jo-so",
    "rila": "ri-la",
    "rilar": "ri-lar",
    "rima": "ri-ma",
    "rimador": "ri-ma-dor",
    "rimadora": "ri-ma-do-ra",
    "rimar": "ri-mar",
    "rimbombancia": "rim-bom-ban-cia",
    "rimbombante": "rim-bom-ban-te",
    "rimbombar": "rim-bom-bar",
    "rimbombe": "rim-bom-be",
    "rimbombo": "rim-bom-bo",
    "rímel": "rí-mel",
    "rimero": "ri-me-ro",
    "rimú": "ri-mú",
    "riña": "ri-ña",
    "rinanto": "ri-nan-to",
    "rincocéfalo": "rin-co-cé-fa-lo",
    "rincón": "rin-cón",
    "rinconada": "rin-co-na-da",
    "rinconera": "rin-co-ne-ra",
    "rinde": "rin-de",
    "ringar": "rin-gar",
    "ringla": "rin-gla",
    "ringle": "rin-gle",
    "ringlera": "rin-gle-ra",
    "ringlero": "rin-gle-ro",
    "ringlete": "rin-gle-te",
    "ringletear": "rin-gle-te-ar",
    "ringorrango": "rin-go-rran-go",
    "rinitis": "ri-ni-tis",
    "rinoceronte": "ri-no-ce-ron-te",
    "rinofaringe": "ri-no-fa-rin-ge",
    "rinóloga": "ri-nó-lo-ga",
    "rinología": "ri-no-lo-gí-a",
    "rinólogo": "ri-nó-lo-go",
    "riñón": "ri-ñón",
    "riñonada": "ri-ño-na-da",
    "riñonera": "ri-ño-ne-ra",
    "rinoplastia": "ri-no-plas-tia",
    "riñosa": "ri-ño-sa",
    "rinoscopia": "ri-nos-co-pia",
    "riñoso": "ri-ño-so",
    "rinrán": "rin-rán",
    "rintel": "rin-tel",
    "río": "rí-o",
    "riobambeña": "rio-bam-be-ña",
    "riobambeño": "rio-bam-be-ño",
    "rioense": "rio-en-se",
    "riohachera": "rio-ha-che-ra",
    "riohachero": "rio-ha-che-ro",
    "rioja": "rio-ja",
    "riojana": "rio-ja-na",
    "riojanismo": "rio-ja-nis-mo",
    "riojano": "rio-ja-no",
    "riolada": "rio-la-da",
    "rionegrense": "rio-ne-gren-se",
    "rionegrina": "rio-ne-gri-na",
    "rionegrino": "rio-ne-gri-no",
    "rioplatense": "rio-pla-ten-se",
    "riosellana": "rio-se-lla-na",
    "riosellano": "rio-se-lla-no",
    "riostra": "rios-tra",
    "riostrar": "rios-trar",
    "ripia": "ri-pia",
    "ripiao": "ri-pia-o",
    "ripiar": "ri-piar",
    "ripícola": "ri-pí-co-la",
    "ripio": "ri-pio",
    "ripiosa": "ri-pio-sa",
    "ripioso": "ri-pio-so",
    "riqueza": "ri-que-za",
    "risa": "ri-sa",
    "risada": "ri-sa-da",
    "risaraldeño": "ri-sa-ral-de-ño",
    "risaraldense": "ri-sa-ral-den-se",
    "risca": "ris-ca",
    "riscal": "ris-cal",
    "riscar": "ris-car",
    "risco": "ris-co",
    "riscosa": "ris-co-sa",
    "riscoso": "ris-co-so",
    "risería": "ri-se-rí-a",
    "risibilidad": "ri-si-bi-li-dad",
    "risible": "ri-si-ble",
    "risiblemente": "ri-si-ble-men-te",
    "risica": "ri-si-ca",
    "risión": "ri-sión",
    "riso": "ri-so",
    "risorio": "ri-so-rio",
    "risotada": "ri-so-ta-da",
    "risotear": "ri-so-te-ar",
    "risoteo": "ri-so-te-o",
    "rispa": "ris-pa",
    "rispar": "ris-par",
    "ríspida": "rís-pi-da",
    "ríspido": "rís-pi-do",
    "rispión": "ris-pión",
    "rispo": "ris-po",
    "risquilo": "ris-qui-lo",
    "ristolera": "ris-to-le-ra",
    "ristolero": "ris-to-le-ro",
    "ristra": "ris-tra",
    "ristre": "ris-tre",
    "ristrel": "ris-trel",
    "ristrón": "ris-trón",
    "risueña": "ri-sue-ña",
    "risueño": "ri-sue-ño",
    "rita": "ri-ta",
    "ritamente": "ri-ta-men-te",
    "ritardando": "ri-tar-dan-do",
    "rite": "ri-te",
    "ritidoma": "ri-ti-do-ma",
    "ritmar": "rit-mar",
    "rítmica": "rít-mi-ca",
    "rítmico": "rít-mi-co",
    "ritmo": "rit-mo",
    "rito": "ri-to",
    "ritón": "ri-tón",
    "ritornelo": "ri-tor-ne-lo",
    "ritual": "ri-tual",
    "ritualidad": "ri-tua-li-dad",
    "ritualismo": "ri-tua-lis-mo",
    "ritualista": "ri-tua-lis-ta",
    "ritualización": "ri-tua-li-za-ción",
    "ritualizar": "ri-tua-li-zar",
    "rival": "ri-val",
    "rivalidad": "ri-va-li-dad",
    "rivalizar": "ri-va-li-zar",
    "rivera": "ri-ve-ra",
    "riverense": "ri-ve-ren-se",
    "riyal": "ri-yal",
    "riza": "ri-za",
    "rizada": "ri-za-da",
    "rizado": "ri-za-do",
    "rizador": "ri-za-dor",
    "rizadora": "ri-za-do-ra",
    "rizal": "ri-zal",
    "rizar": "ri-zar",
    "rizo": "ri-zo",
    "rizófaga": "ri-zó-fa-ga",
    "rizófago": "ri-zó-fa-go",
    "rizófita": "ri-zó-fi-ta",
    "rizófito": "ri-zó-fi-to",
    "rizoforácea": "ri-zo-fo-rá-ce-a",
    "rizoforáceo": "ri-zo-fo-rá-ce-o",
    "rizofórea": "ri-zo-fó-re-a",
    "rizofóreo": "ri-zo-fó-re-o",
    "rizoide": "ri-zoi-de",
    "rizoma": "ri-zo-ma",
    "rizón": "ri-zón",
    "rizópodo": "ri-zó-po-do",
    "rizosa": "ri-zo-sa",
    "rizoso": "ri-zo-so",
    "roa": "ro-a",
    "roana": "ro-a-na",
    "roanés": "ro-a-nés",
    "roanesa": "ro-a-ne-sa",
    "roano": "ro-a-no",
    "roastbeef": "ro-ast-be-ef",
    "roatán": "ro-a-tán",
    "robachicos": "ro-ba-chi-cos",
    "robada": "ro-ba-da",
    "robadera": "ro-ba-de-ra",
    "robadero": "ro-ba-de-ro",
    "robadizo": "ro-ba-di-zo",
    "robado": "ro-ba-do",
    "robador": "ro-ba-dor",
    "robadora": "ro-ba-do-ra",
    "robaliza": "ro-ba-li-za",
    "robalo": "ro-ba-lo",
    "róbalo": "ró-ba-lo",
    "robancina": "ro-ban-ci-na",
    "robapelo": "ro-ba-pe-lo",
    "robar": "ro-bar",
    "robavacas": "ro-ba-va-cas",
    "robda": "rob-da",
    "robe": "ro-be",
    "robeco": "ro-be-co",
    "robellón": "ro-be-llón",
    "robería": "ro-be-rí-a",
    "roberto": "ro-ber-to",
    "robezo": "ro-be-zo",
    "robín": "ro-bín",
    "robiñano": "ro-bi-ña-no",
    "robinia": "ro-bi-nia",
    "robinsón": "ro-bin-són",
    "robinsoniano": "ro-bin-so-nia-no",
    "robinsonismo": "ro-bin-so-nis-mo",
    "robla": "ro-bla",
    "robladera": "ro-bla-de-ra",
    "robladero": "ro-bla-de-ro",
    "robladura": "ro-bla-du-ra",
    "roblar": "ro-blar",
    "roble": "ro-ble",
    "robleda": "ro-ble-da",
    "robledal": "ro-ble-dal",
    "robledo": "ro-ble-do",
    "robliza": "ro-bli-za",
    "roblizo": "ro-bli-zo",
    "roblón": "ro-blón",
    "roblonado": "ro-blo-na-do",
    "roblonar": "ro-blo-nar",
    "robo": "ro-bo",
    "roboración": "ro-bo-ra-ción",
    "roborante": "ro-bo-ran-te",
    "roborar": "ro-bo-rar",
    "roborativa": "ro-bo-ra-ti-va",
    "roborativo": "ro-bo-ra-ti-vo",
    "robot": "ro-bot",
    "robótica": "ro-bó-ti-ca",
    "robotización": "ro-bo-ti-za-ción",
    "robotizado": "ro-bo-ti-za-do",
    "robotizar": "ro-bo-ti-zar",
    "robra": "ro-bra",
    "robramiento": "ro-bra-mien-to",
    "robrar": "ro-brar",
    "robre": "ro-bre",
    "robredal": "ro-bre-dal",
    "robredo": "ro-bre-do",
    "robusta": "ro-bus-ta",
    "robustamente": "ro-bus-ta-men-te",
    "robustecedor": "ro-bus-te-ce-dor",
    "robustecer": "ro-bus-te-cer",
    "robustecimiento": "ro-bus-te-ci-mien-to",
    "robustez": "ro-bus-tez",
    "robusteza": "ro-bus-te-za",
    "robusticidad": "ro-bus-ti-ci-dad",
    "robustidad": "ro-bus-ti-dad",
    "robusto": "ro-bus-to",
    "roca": "ro-ca",
    "rocada": "ro-ca-da",
    "rocadero": "ro-ca-de-ro",
    "rocador": "ro-ca-dor",
    "rocalla": "ro-ca-lla",
    "rocallosa": "ro-ca-llo-sa",
    "rocalloso": "ro-ca-llo-so",
    "rocambola": "ro-cam-bo-la",
    "rocambolesco": "ro-cam-bo-les-co",
    "rocambor": "ro-cam-bor",
    "rocanrol": "ro-can-rol",
    "rocanrolero": "ro-can-ro-le-ro",
    "roce": "ro-ce",
    "rocear": "ro-ce-ar",
    "rocera": "ro-ce-ra",
    "rocería": "ro-ce-rí-a",
    "rocero": "ro-ce-ro",
    "rocha": "ro-cha",
    "rochar": "ro-char",
    "roche": "ro-che",
    "rochela": "ro-che-la",
    "rochelear": "ro-che-le-ar",
    "rochelera": "ro-che-le-ra",
    "rochelero": "ro-che-le-ro",
    "rochelés": "ro-che-lés",
    "rochelesa": "ro-che-le-sa",
    "rochense": "ro-chen-se",
    "rocho": "ro-cho",
    "rochoso": "ro-cho-so",
    "rociada": "ro-cia-da",
    "rociadera": "ro-cia-de-ra",
    "rociador": "ro-cia-dor",
    "rociadura": "ro-cia-du-ra",
    "rociamiento": "ro-cia-mien-to",
    "rociar": "ro-ciar",
    "rociera": "ro-cie-ra",
    "rociero": "ro-cie-ro",
    "rocín": "ro-cín",
    "rocinal": "ro-ci-nal",
    "rocinante": "ro-ci-nan-te",
    "rociniego": "ro-ci-nie-go",
    "rocino": "ro-ci-no",
    "rocío": "ro-cí-o",
    "roción": "ro-ción",
    "rocker": "roc-ker",
    "rockero": "roc-ke-ro",
    "rockódromo": "roc-kó-dro-mo",
    "roco": "ro-co",
    "rococó": "ro-co-có",
    "rocódromo": "ro-có-dro-mo",
    "rocola": "ro-co-la",
    "rocolo": "ro-co-lo",
    "rocosa": "ro-co-sa",
    "rocoso": "ro-co-so",
    "rocoto": "ro-co-to",
    "roda": "ro-da",
    "rodaballo": "ro-da-ba-llo",
    "rodachina": "ro-da-chi-na",
    "rodada": "ro-da-da",
    "rodadera": "ro-da-de-ra",
    "rodadero": "ro-da-de-ro",
    "rodadiza": "ro-da-di-za",
    "rodadizo": "ro-da-di-zo",
    "rodado": "ro-da-do",
    "rodador": "ro-da-dor",
    "rodadora": "ro-da-do-ra",
    "rodadura": "ro-da-du-ra",
    "rodaja": "ro-da-ja",
    "rodaje": "ro-da-je",
    "rodajear": "ro-da-je-ar",
    "rodal": "ro-dal",
    "rodalán": "ro-da-lán",
    "rodamiento": "ro-da-mien-to",
    "rodancha": "ro-dan-cha",
    "rodancho": "ro-dan-cho",
    "rodante": "ro-dan-te",
    "rodao": "ro-da-o",
    "rodapelo": "ro-da-pe-lo",
    "rodapié": "ro-da-pié",
    "rodaplancha": "ro-da-plan-cha",
    "rodar": "ro-dar",
    "rodas": "ro-das",
    "rodea": "ro-de-a",
    "rodeabrazo": "ro-de-a-bra-zo",
    "rodeador": "ro-de-a-dor",
    "rodeadora": "ro-de-a-do-ra",
    "rodear": "ro-de-ar",
    "rodela": "ro-de-la",
    "rodelero": "ro-de-le-ro",
    "rodena": "ro-de-na",
    "rodenal": "ro-de-nal",
    "rodeno": "ro-de-no",
    "rodeo": "ro-de-o",
    "rodeón": "ro-de-ón",
    "rodera": "ro-de-ra",
    "rodericense": "ro-de-ri-cen-se",
    "rodero": "ro-de-ro",
    "roderón": "ro-de-rón",
    "rodete": "ro-de-te",
    "rodezno": "ro-dez-no",
    "rodia": "ro-dia",
    "rodil": "ro-dil",
    "rodilla": "ro-di-lla",
    "rodillada": "ro-di-lla-da",
    "rodillazo": "ro-di-lla-zo",
    "rodillera": "ro-di-lle-ra",
    "rodillero": "ro-di-lle-ro",
    "rodillo": "ro-di-llo",
    "rodilluda": "ro-di-llu-da",
    "rodilludo": "ro-di-llu-do",
    "rodio": "ro-dio",
    "rodiota": "ro-dio-ta",
    "rodo": "ro-do",
    "rododafne": "ro-do-daf-ne",
    "rododendro": "ro-do-den-dro",
    "rodofito": "ro-do-fi-to",
    "rodomiel": "ro-do-miel",
    "rodonita": "ro-do-ni-ta",
    "rodreja": "ro-dre-ja",
    "rodrejo": "ro-dre-jo",
    "rodriga": "ro-dri-ga",
    "rodrigar": "ro-dri-gar",
    "rodrigazón": "ro-dri-ga-zón",
    "rodrigón": "ro-dri-gón",
    "rodríguez": "ro-drí-guez",
    "roedor": "ro-e-dor",
    "roedora": "ro-e-do-ra",
    "roedura": "ro-e-du-ra",
    "roel": "ro-el",
    "roela": "ro-e-la",
    "roentgen": "ro-ent-gen",
    "roentgenio": "ro-ent-ge-nio",
    "roer": "ro-er",
    "roete": "ro-e-te",
    "rogación": "ro-ga-ción",
    "rogada": "ro-ga-da",
    "rogado": "ro-ga-do",
    "rogador": "ro-ga-dor",
    "rogadora": "ro-ga-do-ra",
    "rogar": "ro-gar",
    "rogaria": "ro-ga-ria",
    "rogativa": "ro-ga-ti-va",
    "rogativo": "ro-ga-ti-vo",
    "rogatoria": "ro-ga-to-ria",
    "rogatorio": "ro-ga-to-rio",
    "rogo": "ro-go",
    "rogón": "ro-gón",
    "rogona": "ro-go-na",
    "roída": "ro-í-da",
    "roído": "ro-í-do",
    "roja": "ro-ja",
    "rojal": "ro-jal",
    "rojear": "ro-je-ar",
    "rojerío": "ro-je-rí-o",
    "rojeta": "ro-je-ta",
    "rojete": "ro-je-te",
    "rojeto": "ro-je-to",
    "rojez": "ro-jez",
    "rojiblanca": "ro-ji-blan-ca",
    "rojiblanco": "ro-ji-blan-co",
    "rojiza": "ro-ji-za",
    "rojizo": "ro-ji-zo",
    "rojo": "ro-jo",
    "rojura": "ro-ju-ra",
    "rola": "ro-la",
    "rolar": "ro-lar",
    "rolazo": "ro-la-zo",
    "roldana": "rol-da-na",
    "roldar": "rol-dar",
    "rolde": "rol-de",
    "roldón": "rol-dón",
    "roleo": "ro-le-o",
    "rolla": "ro-lla",
    "rollar": "ro-llar",
    "rolletal": "ro-lle-tal",
    "rollete": "ro-lle-te",
    "rollista": "ro-llis-ta",
    "rollito": "ro-lli-to",
    "rolliza": "ro-lli-za",
    "rollizo": "ro-lli-zo",
    "rollo": "ro-llo",
    "rollón": "ro-llón",
    "rollona": "ro-llo-na",
    "rolo": "ro-lo",
    "roma": "ro-ma",
    "roma": "ro-ma",
    "romadizar": "ro-ma-di-zar",
    "romadizarse": "ro-ma-di-zar-se",
    "romadizo": "ro-ma-di-zo",
    "romaica": "ro-mai-ca",
    "romaico": "ro-mai-co",
    "román": "ro-mán",
    "romana": "ro-ma-na",
    "romanador": "ro-ma-na-dor",
    "romanar": "ro-ma-nar",
    "romanato": "ro-ma-na-to",
    "romance": "ro-man-ce",
    "romanceador": "ro-man-ce-a-dor",
    "romanceadora": "ro-man-ce-a-do-ra",
    "romancear": "ro-man-ce-ar",
    "romancera": "ro-man-ce-ra",
    "romancerista": "ro-man-ce-ris-ta",
    "romancero": "ro-man-ce-ro",
    "romancesca": "ro-man-ces-ca",
    "romancesco": "ro-man-ces-co",
    "romanche": "ro-man-che",
    "romancillo": "ro-man-ci-llo",
    "romancista": "ro-man-cis-ta",
    "romancístico": "ro-man-cís-ti-co",
    "romanear": "ro-ma-ne-ar",
    "romanense": "ro-ma-nen-se",
    "romaneo": "ro-ma-ne-o",
    "romanero": "ro-ma-ne-ro",
    "romanesca": "ro-ma-nes-ca",
    "romanesco": "ro-ma-nes-co",
    "romaní": "ro-ma-ní",
    "romanía": "ro-ma-ní-a",
    "románica": "ro-má-ni-ca",
    "románico": "ro-má-ni-co",
    "romanilla": "ro-ma-ni-lla",
    "romanina": "ro-ma-ni-na",
    "romanismo": "ro-ma-nis-mo",
    "romanista": "ro-ma-nis-ta",
    "romanística": "ro-ma-nís-ti-ca",
    "romanización": "ro-ma-ni-za-ción",
    "romanizar": "ro-ma-ni-zar",
    "romano": "ro-ma-no",
    "romanó": "ro-ma-nó",
    "romántica": "ro-mán-ti-ca",
    "romanticismo": "ro-man-ti-cis-mo",
    "romántico": "ro-mán-ti-co",
    "romanza": "ro-man-za",
    "romanzador": "ro-man-za-dor",
    "romanzadora": "ro-man-za-do-ra",
    "romanzar": "ro-man-zar",
    "romaza": "ro-ma-za",
    "rombal": "rom-bal",
    "rómbico": "róm-bi-co",
    "rombo": "rom-bo",
    "romboédrico": "rom-bo-é-dri-co",
    "romboedro": "rom-bo-e-dro",
    "romboidal": "rom-boi-dal",
    "romboide": "rom-boi-de",
    "romboideo": "rom-boi-de-o",
    "romea": "ro-me-a",
    "romeo": "ro-me-o",
    "romera": "ro-me-ra",
    "romeraje": "ro-me-ra-je",
    "romeral": "ro-me-ral",
    "romería": "ro-me-rí-a",
    "romeriante": "ro-me-rian-te",
    "romeriega": "ro-me-rie-ga",
    "romeriego": "ro-me-rie-go",
    "romerillo": "ro-me-ri-llo",
    "romerito": "ro-me-ri-to",
    "romero": "ro-me-ro",
    "romesco": "ro-mes-co",
    "romí": "ro-mí",
    "romín": "ro-mín",
    "romo": "ro-mo",
    "rompebolas": "rom-pe-bo-las",
    "rompecabezas": "rom-pe-ca-be-zas",
    "rompecoches": "rom-pe-co-ches",
    "rompecorazones": "rom-pe-co-ra-zo-nes",
    "rompedera": "rom-pe-de-ra",
    "rompedero": "rom-pe-de-ro",
    "rompedizo": "rom-pe-di-zo",
    "rompedor": "rom-pe-dor",
    "rompedora": "rom-pe-do-ra",
    "rompedura": "rom-pe-du-ra",
    "rompegalas": "rom-pe-ga-las",
    "rompehielos": "rom-pe-hie-los",
    "rompehuelgas": "rom-pe-huel-gas",
    "rompehuevos": "rom-pe-hue-vos",
    "rompelón": "rom-pe-lón",
    "rompenecios": "rom-pe-ne-cios",
    "rompenueces": "rom-pe-nue-ces",
    "rompeolas": "rom-pe-o-las",
    "rompepiernas": "rom-pe-pier-nas",
    "rompepoyos": "rom-pe-po-yos",
    "romper": "rom-per",
    "rompesacos": "rom-pe-sa-cos",
    "rompesquinas": "rom-pes-qui-nas",
    "rompetechos": "rom-pe-te-chos",
    "rompezaragüelles": "rom-pe-za-ra-güe-lles",
    "rompible": "rom-pi-ble",
    "rompido": "rom-pi-do",
    "rompiente": "rom-pien-te",
    "rompimiento": "rom-pi-mien-to",
    "rompón": "rom-pón",
    "rompope": "rom-po-pe",
    "rompopo": "rom-po-po",
    "roña": "ro-ña",
    "roñal": "ro-ñal",
    "roñar": "ro-ñar",
    "ronca": "ron-ca",
    "roncada": "ron-ca-da",
    "roncadera": "ron-ca-de-ra",
    "roncador": "ron-ca-dor",
    "roncadora": "ron-ca-do-ra",
    "roncal": "ron-cal",
    "roncalés": "ron-ca-lés",
    "roncalesa": "ron-ca-le-sa",
    "roncamente": "ron-ca-men-te",
    "roncar": "ron-car",
    "ronce": "ron-ce",
    "roncear": "ron-ce-ar",
    "roncella": "ron-ce-lla",
    "roncera": "ron-ce-ra",
    "roncería": "ron-ce-rí-a",
    "roncero": "ron-ce-ro",
    "roncha": "ron-cha",
    "ronchadora": "ron-cha-do-ra",
    "ronchar": "ron-char",
    "ronchero": "ron-che-ro",
    "ronchón": "ron-chón",
    "ronco": "ron-co",
    "roncón": "ron-cón",
    "ronda": "ron-da",
    "rondador": "ron-da-dor",
    "rondadora": "ron-da-do-ra",
    "rondalla": "ron-da-lla",
    "rondana": "ron-da-na",
    "rondar": "ron-dar",
    "rondel": "ron-del",
    "rondeña": "ron-de-ña",
    "rondeño": "ron-de-ño",
    "rondín": "ron-dín",
    "rondinear": "ron-di-ne-ar",
    "rondís": "ron-dís",
    "rondiz": "ron-diz",
    "rondó": "ron-dó",
    "rondón": "ron-dón",
    "roñería": "ro-ñe-rí-a",
    "ronfea": "ron-fe-a",
    "rongigata": "ron-gi-ga-ta",
    "roñía": "ro-ñí-a",
    "roñica": "ro-ñi-ca",
    "roñosa": "ro-ño-sa",
    "roñosería": "ro-ño-se-rí-a",
    "roñoso": "ro-ño-so",
    "ronqueador": "ron-que-a-dor",
    "ronquear": "ron-que-ar",
    "ronquedad": "ron-que-dad",
    "ronquera": "ron-que-ra",
    "ronquez": "ron-quez",
    "ronquido": "ron-qui-do",
    "ronrón": "ron-rón",
    "ronronear": "ron-ro-ne-ar",
    "ronroneo": "ron-ro-ne-o",
    "ronza": "ron-za",
    "ronzal": "ron-zal",
    "ronzar": "ron-zar",
    "ronzuela": "ron-zue-la",
    "ronzuella": "ron-zue-lla",
    "ropa": "ro-pa",
    "ropaje": "ro-pa-je",
    "ropálico": "ro-pá-li-co",
    "ropavejera": "ro-pa-ve-je-ra",
    "ropavejería": "ro-pa-ve-je-rí-a",
    "ropavejero": "ro-pa-ve-je-ro",
    "ropavieja": "ro-pa-vie-ja",
    "ropera": "ro-pe-ra",
    "ropería": "ro-pe-rí-a",
    "ropero": "ro-pe-ro",
    "ropeta": "ro-pe-ta",
    "ropilla": "ro-pi-lla",
    "ropón": "ro-pón",
    "roque": "ro-que",
    "roqueda": "ro-que-da",
    "roquedal": "ro-que-dal",
    "roquedo": "ro-que-do",
    "roquefort": "ro-que-fort",
    "roqueña": "ro-que-ña",
    "roqueño": "ro-que-ño",
    "roquera": "ro-que-ra",
    "roquero": "ro-que-ro",
    "roqués": "ro-qués",
    "roqueta": "ro-que-ta",
    "roquete": "ro-que-te",
    "rorante": "ro-ran-te",
    "rorar": "ro-rar",
    "rorcual": "ror-cual",
    "rorro": "ro-rro",
    "rosa": "ro-sa",
    "rosácea": "ro-sá-ce-a",
    "rosáceas": "ro-sá-ce-as",
    "rosáceo": "ro-sá-ce-o",
    "rosacruz": "ro-sa-cruz",
    "rosada": "ro-sa-da",
    "rosadelfa": "ro-sa-del-fa",
    "rosadillo": "ro-sa-di-llo",
    "rosado": "ro-sa-do",
    "rosal": "ro-sal",
    "rosaleda": "ro-sa-le-da",
    "rosalera": "ro-sa-le-ra",
    "rosar": "ro-sar",
    "rosariazo": "ro-sa-ria-zo",
    "rosariera": "ro-sa-rie-ra",
    "rosariero": "ro-sa-rie-ro",
    "rosarina": "ro-sa-ri-na",
    "rosarino": "ro-sa-ri-no",
    "rosario": "ro-sa-rio",
    "rosarse": "ro-sar-se",
    "rosbif": "ros-bif",
    "rosca": "ros-ca",
    "roscada": "ros-ca-da",
    "roscadero": "ros-ca-de-ro",
    "roscado": "ros-ca-do",
    "roscar": "ros-car",
    "rosco": "ros-co",
    "roscón": "ros-cón",
    "rósea": "ró-se-a",
    "rosear": "ro-se-ar",
    "rosedal": "ro-se-dal",
    "rosellonés": "ro-se-llo-nés",
    "rosellonesa": "ro-se-llo-ne-sa",
    "rosense": "ro-sen-se",
    "róseo": "ró-se-o",
    "roséola": "ro-sé-o-la",
    "rosera": "ro-se-ra",
    "rosero": "ro-se-ro",
    "roseta": "ro-se-ta",
    "rosetón": "ro-se-tón",
    "rosicler": "ro-si-cler",
    "rosigar": "ro-si-gar",
    "rosigo": "ro-si-go",
    "rosigón": "ro-si-gón",
    "rosilla": "ro-si-lla",
    "rosillo": "ro-si-llo",
    "rosita": "ro-si-ta",
    "rositas": "ro-si-tas",
    "rosjo": "ros-jo",
    "rosmarina": "ros-ma-ri-na",
    "rosmarino": "ros-ma-ri-no",
    "rosmaro": "ros-ma-ro",
    "roso": "ro-so",
    "rosoca": "ro-so-ca",
    "rosoli": "ro-so-li",
    "rosolí": "ro-so-lí",
    "rosón": "ro-són",
    "rosqueada": "ros-que-a-da",
    "rosqueado": "ros-que-a-do",
    "rosquear": "ros-que-ar",
    "rosquera": "ros-que-ra",
    "rosquero": "ros-que-ro",
    "rosquete": "ros-que-te",
    "rosquilla": "ros-qui-lla",
    "rosquillera": "ros-qui-lle-ra",
    "rosquillero": "ros-qui-lle-ro",
    "rosticería": "ros-ti-ce-rí-a",
    "rostir": "ros-tir",
    "rostizar": "ros-ti-zar",
    "rostrada": "ros-tra-da",
    "rostrado": "ros-tra-do",
    "rostral": "ros-tral",
    "rostrata": "ros-tra-ta",
    "rostrillo": "ros-tri-llo",
    "rostritorcida": "ros-tri-tor-ci-da",
    "rostritorcido": "ros-tri-tor-ci-do",
    "rostrituerta": "ros-tri-tuer-ta",
    "rostrituerto": "ros-tri-tuer-to",
    "rostrizo": "ros-tri-zo",
    "rostro": "ros-tro",
    "rota": "ro-ta",
    "rota": "ro-ta",
    "rotación": "ro-ta-ción",
    "rotacismo": "ro-ta-cis-mo",
    "rotafolio": "ro-ta-fo-lio",
    "rotaje": "ro-ta-je",
    "rotal": "ro-tal",
    "rotamente": "ro-ta-men-te",
    "rotámetro": "ro-tá-me-tro",
    "rotar": "ro-tar",
    "rotaria": "ro-ta-ria",
    "rotario": "ro-ta-rio",
    "rotativa": "ro-ta-ti-va",
    "rotativo": "ro-ta-ti-vo",
    "rotatoria": "ro-ta-to-ria",
    "rotatorio": "ro-ta-to-rio",
    "roten": "ro-ten",
    "rotería": "ro-te-rí-a",
    "roterío": "ro-te-rí-o",
    "roterodamense": "ro-te-ro-da-men-se",
    "rotisería": "ro-ti-se-rí-a",
    "roto": "ro-to",
    "rotonda": "ro-ton-da",
    "rotor": "ro-tor",
    "rotosa": "ro-to-sa",
    "rotoso": "ro-to-so",
    "rotring": "ro-tring",
    "rótula": "ró-tu-la",
    "rotulación": "ro-tu-la-ción",
    "rotulado": "ro-tu-la-do",
    "rotulador": "ro-tu-la-dor",
    "rotuladora": "ro-tu-la-do-ra",
    "rotular": "ro-tu-lar",
    "rotulata": "ro-tu-la-ta",
    "rotuliana": "ro-tu-lia-na",
    "rotuliano": "ro-tu-lia-no",
    "rotulista": "ro-tu-lis-ta",
    "rótulo": "ró-tu-lo",
    "rotunda": "ro-tun-da",
    "rotundamente": "ro-tun-da-men-te",
    "rotundez": "ro-tun-dez",
    "rotundidad": "ro-tun-di-dad",
    "rotundidez": "ro-tun-di-dez",
    "rotundo": "ro-tun-do",
    "rotura": "ro-tu-ra",
    "roturación": "ro-tu-ra-ción",
    "roturador": "ro-tu-ra-dor",
    "roturadora": "ro-tu-ra-do-ra",
    "roturar": "ro-tu-rar",
    "rouge": "rou-ge",
    "roulotte": "rou-lot-te",
    "roya": "ro-ya",
    "royega": "ro-ye-ga",
    "royo": "ro-yo",
    "roza": "ro-za",
    "rozable": "ro-za-ble",
    "rozadera": "ro-za-de-ra",
    "rozadero": "ro-za-de-ro",
    "rozado": "ro-za-do",
    "rozador": "ro-za-dor",
    "rozadora": "ro-za-do-ra",
    "rozadura": "ro-za-du-ra",
    "rozagante": "ro-za-gan-te",
    "rozamiento": "ro-za-mien-to",
    "rozar": "ro-zar",
    "rozavillón": "ro-za-vi-llón",
    "roznar": "roz-nar",
    "roznido": "roz-ni-do",
    "rozno": "roz-no",
    "rozo": "ro-zo",
    "rozón": "ro-zón",
    "rúa": "rú-a",
    "ruana": "rua-na",
    "ruandés": "ruan-dés",
    "ruandesa": "ruan-de-sa",
    "ruanés": "rua-nés",
    "ruanesa": "rua-ne-sa",
    "ruano": "rua-no",
    "ruante": "ruan-te",
    "rubato": "ru-ba-to",
    "rúbea": "rú-be-a",
    "rubefacción": "ru-be-fac-ción",
    "rubefaciente": "ru-be-fa-cien-te",
    "rubeniano": "ru-be-nia-no",
    "rúbeo": "rú-be-o",
    "rubeola": "ru-be-o-la",
    "rubéola": "ru-bé-o-la",
    "rubescente": "ru-bes-cen-te",
    "rubeta": "ru-be-ta",
    "rubí": "ru-bí",
    "rubia": "ru-bia",
    "rubiácea": "ru-biá-ce-a",
    "rubiáceas": "ru-biá-ce-as",
    "rubiáceo": "ru-biá-ce-o",
    "rubial": "ru-bial",
    "rubiales": "ru-bia-les",
    "rubicán": "ru-bi-cán",
    "rubicana": "ru-bi-ca-na",
    "rubicela": "ru-bi-ce-la",
    "rubicón": "ru-bi-cón",
    "rubicunda": "ru-bi-cun-da",
    "rubicundez": "ru-bi-cun-dez",
    "rubicundo": "ru-bi-cun-do",
    "rubidio": "ru-bi-dio",
    "rubiel": "ru-biel",
    "rubiera": "ru-bie-ra",
    "rubificar": "ru-bi-fi-car",
    "rubilla": "ru-bi-lla",
    "rubín": "ru-bín",
    "rubio": "ru-bio",
    "rubiola": "ru-bio-la",
    "rubión": "ru-bión",
    "rublo": "ru-blo",
    "rubo": "ru-bo",
    "rubor": "ru-bor",
    "ruborizar": "ru-bo-ri-zar",
    "ruborosa": "ru-bo-ro-sa",
    "ruborosamente": "ru-bo-ro-sa-men-te",
    "ruboroso": "ru-bo-ro-so",
    "rubra": "ru-bra",
    "rúbrica": "rú-bri-ca",
    "rubricada": "ru-bri-ca-da",
    "rubricado": "ru-bri-ca-do",
    "rubricante": "ru-bri-can-te",
    "rubricar": "ru-bri-car",
    "rubricista": "ru-bri-cis-ta",
    "rubriquista": "ru-bri-quis-ta",
    "rubro": "ru-bro",
    "ruca": "ru-ca",
    "rucar": "ru-car",
    "ruchar": "ru-char",
    "ruche": "ru-che",
    "ruchique": "ru-chi-que",
    "rucho": "ru-cho",
    "rucia": "ru-cia",
    "ruciadera": "ru-cia-de-ra",
    "rucio": "ru-cio",
    "ruco": "ru-co",
    "ruda": "ru-da",
    "rudamente": "ru-da-men-te",
    "ruderal": "ru-de-ral",
    "rudeza": "ru-de-za",
    "rudimental": "ru-di-men-tal",
    "rudimentaria": "ru-di-men-ta-ria",
    "rudimentario": "ru-di-men-ta-rio",
    "rudimento": "ru-di-men-to",
    "rudo": "ru-do",
    "rúe": "rú-e",
    "rueca": "rue-ca",
    "rueda": "rue-da",
    "ruedapelota": "rue-da-pe-lo-ta",
    "ruedero": "rue-de-ro",
    "ruedo": "rue-do",
    "ruego": "rue-go",
    "ruejo": "rue-jo",
    "ruello": "rue-llo",
    "rueño": "rue-ño",
    "ruezno": "ruez-no",
    "rufa": "ru-fa",
    "rufeta": "ru-fe-ta",
    "rufezno": "ru-fez-no",
    "rufián": "ru-fián",
    "rufianear": "ru-fia-ne-ar",
    "rufianería": "ru-fia-ne-rí-a",
    "rufianesca": "ru-fia-nes-ca",
    "rufianesco": "ru-fia-nes-co",
    "rufianismo": "ru-fia-nis-mo",
    "rufo": "ru-fo",
    "rufón": "ru-fón",
    "ruga": "ru-ga",
    "rugar": "ru-gar",
    "rugible": "ru-gi-ble",
    "rugido": "ru-gi-do",
    "rugidor": "ru-gi-dor",
    "rugidora": "ru-gi-do-ra",
    "rugiente": "ru-gien-te",
    "ruginosa": "ru-gi-no-sa",
    "ruginoso": "ru-gi-no-so",
    "rugir": "ru-gir",
    "rugosa": "ru-go-sa",
    "rugosidad": "ru-go-si-dad",
    "rugoso": "ru-go-so",
    "ruibarbo": "rui-bar-bo",
    "ruidal": "rui-dal",
    "ruidero": "rui-de-ro",
    "ruido": "rui-do",
    "ruidosa": "rui-do-sa",
    "ruidosamente": "rui-do-sa-men-te",
    "ruidoso": "rui-do-so",
    "ruina": "rui-na",
    "ruinar": "rui-nar",
    "ruindad": "ruin-dad",
    "ruinera": "rui-ne-ra",
    "ruinmente": "ruin-men-te",
    "ruinosa": "rui-no-sa",
    "ruinoso": "rui-no-so",
    "ruiponce": "rui-pon-ce",
    "ruipóntico": "rui-pón-ti-co",
    "ruiseñor": "rui-se-ñor",
    "rujiada": "ru-jia-da",
    "rujiar": "ru-jiar",
    "rula": "ru-la",
    "rular": "ru-lar",
    "rulé": "ru-lé",
    "rulemán": "ru-le-mán",
    "rulenco": "ru-len-co",
    "rulero": "ru-le-ro",
    "ruleta": "ru-le-ta",
    "ruletear": "ru-le-te-ar",
    "ruleteo": "ru-le-te-o",
    "ruletera": "ru-le-te-ra",
    "ruletero": "ru-le-te-ro",
    "rulo": "ru-lo",
    "ruma": "ru-ma",
    "rumana": "ru-ma-na",
    "rumano": "ru-ma-no",
    "rumazón": "ru-ma-zón",
    "rumba": "rum-ba",
    "rumbada": "rum-ba-da",
    "rumbantela": "rum-ban-te-la",
    "rumbar": "rum-bar",
    "rumbática": "rum-bá-ti-ca",
    "rumbático": "rum-bá-ti-co",
    "rumbeador": "rum-be-a-dor",
    "rumbear": "rum-be-ar",
    "rumbera": "rum-be-ra",
    "rumbero": "rum-be-ro",
    "rumbo": "rum-bo",
    "rumbón": "rum-bón",
    "rumbona": "rum-bo-na",
    "rumbosa": "rum-bo-sa",
    "rumbosamente": "rum-bo-sa-men-te",
    "rumboso": "rum-bo-so",
    "rumeliota": "ru-me-lio-ta",
    "rumí": "ru-mí",
    "rumia": "ru-mia",
    "rumiaco": "ru-mia-co",
    "rumiador": "ru-mia-dor",
    "rumiadora": "ru-mia-do-ra",
    "rumiadura": "ru-mia-du-ra",
    "rumiajo": "ru-mia-jo",
    "rumiante": "ru-mian-te",
    "rumiar": "ru-miar",
    "rumión": "ru-mión",
    "rumiona": "ru-mio-na",
    "rumo": "ru-mo",
    "rumor": "ru-mor",
    "rumorar": "ru-mo-rar",
    "rumorear": "ru-mo-re-ar",
    "rumorología": "ru-mo-ro-lo-gí-a",
    "rumorosa": "ru-mo-ro-sa",
    "rumoroso": "ru-mo-ro-so",
    "rumpiata": "rum-pia-ta",
    "runa": "ru-na",
    "ruñar": "ru-ñar",
    "runcho": "run-cho",
    "rundel": "run-del",
    "runfla": "run-fla",
    "runflada": "run-fla-da",
    "runflante": "run-flan-te",
    "runflar": "run-flar",
    "runga": "run-ga",
    "runges": "run-ges",
    "rungo": "run-go",
    "runguear": "run-gue-ar",
    "rúnica": "rú-ni-ca",
    "rúnico": "rú-ni-co",
    "ruñido": "ru-ñi-do",
    "ruñir": "ru-ñir",
    "runo": "ru-no",
    "runrún": "run-rún",
    "runrunear": "run-ru-ne-ar",
    "runruneo": "run-ru-ne-o",
    "rupestre": "ru-pes-tre",
    "rupia": "ru-pia",
    "rupicabra": "ru-pi-ca-bra",
    "rupicapra": "ru-pi-ca-pra",
    "rupícola": "ru-pí-co-la",
    "ruptor": "rup-tor",
    "ruptura": "rup-tu-ra",
    "ruquear": "ru-que-ar",
    "ruqueta": "ru-que-ta",
    "rural": "ru-ral",
    "ruralismo": "ru-ra-lis-mo",
    "ruralista": "ru-ra-lis-ta",
    "ruralmente": "ru-ral-men-te",
    "rurrú": "ru-rrú",
    "rurrupata": "ru-rru-pa-ta",
    "rusa": "ru-sa",
    "rusalca": "ru-sal-ca",
    "rusco": "rus-co",
    "rusel": "ru-sel",
    "rusentar": "ru-sen-tar",
    "rusia": "ru-sia",
    "rusiente": "ru-sien-te",
    "rusificar": "ru-si-fi-car",
    "ruso": "ru-so",
    "rústica": "rús-ti-ca",
    "rusticación": "rus-ti-ca-ción",
    "rustical": "rus-ti-cal",
    "rústicamente": "rús-ti-ca-men-te",
    "rusticana": "rus-ti-ca-na",
    "rusticano": "rus-ti-ca-no",
    "rusticar": "rus-ti-car",
    "rusticidad": "rus-ti-ci-dad",
    "rústico": "rús-ti-co",
    "rustiquez": "rus-ti-quez",
    "rustiqueza": "rus-ti-que-za",
    "rustir": "rus-tir",
    "rustrir": "rus-trir",
    "rustro": "rus-tro",
    "ruta": "ru-ta",
    "rutácea": "ru-tá-ce-a",
    "rutáceas": "ru-tá-ce-as",
    "rutáceo": "ru-tá-ce-o",
    "rutar": "ru-tar",
    "rutel": "ru-tel",
    "rutena": "ru-te-na",
    "rutenio": "ru-te-nio",
    "ruteno": "ru-te-no",
    "rutero": "ru-te-ro",
    "rutherfordio": "ru-ther-for-dio",
    "rútila": "rú-ti-la",
    "rutilancia": "ru-ti-lan-cia",
    "rutilante": "ru-ti-lan-te",
    "rutilar": "ru-ti-lar",
    "rutilo": "ru-ti-lo",
    "rútilo": "rú-ti-lo",
    "rutina": "ru-ti-na",
    "rutinaria": "ru-ti-na-ria",
    "rutinario": "ru-ti-na-rio",
    "rutinera": "ru-ti-ne-ra",
    "rutinero": "ru-ti-ne-ro",
    "sabadellense": "sa-ba-de-llen-se",
    "sabadeña": "sa-ba-de-ña",
    "sabadeño": "sa-ba-de-ño",
    "sabadiego": "sa-ba-die-go",
    "sábado": "sá-ba-do",
    "sabalar": "sa-ba-lar",
    "sabalera": "sa-ba-le-ra",
    "sabalero": "sa-ba-le-ro",
    "sabaleta": "sa-ba-le-ta",
    "sábalo": "sá-ba-lo",
    "sabana": "sa-ba-na",
    "sábana": "sá-ba-na",
    "sabanal": "sa-ba-nal",
    "sabanalamarina": "sa-ba-na-la-ma-ri-na",
    "sabanalamarino": "sa-ba-na-la-ma-ri-no",
    "sabanazo": "sa-ba-na-zo",
    "sabandeño": "sa-ban-de-ño",
    "sabandija": "sa-ban-di-ja",
    "sabandijuela": "sa-ban-di-jue-la",
    "sabanear": "sa-ba-ne-ar",
    "sabaneo": "sa-ba-ne-o",
    "sabanera": "sa-ba-ne-ra",
    "sabanero": "sa-ba-ne-ro",
    "sabaneta": "sa-ba-ne-ta",
    "sabanilla": "sa-ba-ni-lla",
    "sábano": "sá-ba-no",
    "sabañón": "sa-ba-ñón",
    "sabataria": "sa-ba-ta-ria",
    "sabatario": "sa-ba-ta-rio",
    "sabática": "sa-bá-ti-ca",
    "sabático": "sa-bá-ti-co",
    "sabatina": "sa-ba-ti-na",
    "sabatino": "sa-ba-ti-no",
    "sabatismo": "sa-ba-tis-mo",
    "sabatizar": "sa-ba-ti-zar",
    "sabaya": "sa-ba-ya",
    "sabbat": "sab-bat",
    "sabea": "sa-be-a",
    "sabedor": "sa-be-dor",
    "sabedora": "sa-be-do-ra",
    "sabeísmo": "sa-be-ís-mo",
    "sabela": "sa-be-la",
    "sabelección": "sa-be-lec-ción",
    "sabeliana": "sa-be-lia-na",
    "sabelianismo": "sa-be-lia-nis-mo",
    "sabeliano": "sa-be-lia-no",
    "sabélica": "sa-bé-li-ca",
    "sabélico": "sa-bé-li-co",
    "sabelotodo": "sa-be-lo-to-do",
    "sabencia": "sa-ben-cia",
    "sabeo": "sa-be-o",
    "saber": "sa-ber",
    "sabia": "sa-bia",
    "sabiamente": "sa-bia-men-te",
    "sabichoso": "sa-bi-cho-so",
    "sabicú": "sa-bi-cú",
    "sabida": "sa-bi-da",
    "sabidilla": "sa-bi-di-lla",
    "sabidillo": "sa-bi-di-llo",
    "sabido": "sa-bi-do",
    "sabidor": "sa-bi-dor",
    "sabidora": "sa-bi-do-ra",
    "sabiduría": "sa-bi-du-rí-a",
    "sabiendas": "sa-bien-das",
    "sabihonda": "sa-bihon-da",
    "sabihondez": "sa-bihon-dez",
    "sabihondo": "sa-bihon-do",
    "sábila": "sá-bi-la",
    "sabina": "sa-bi-na",
    "sabinar": "sa-bi-nar",
    "sabinilla": "sa-bi-ni-lla",
    "sabino": "sa-bi-no",
    "sabio": "sa-bio",
    "sabiola": "sa-bio-la",
    "sabionda": "sa-bion-da",
    "sabiondez": "sa-bion-dez",
    "sabiondo": "sa-bion-do",
    "sabir": "sa-bir",
    "sablazo": "sa-bla-zo",
    "sable": "sa-ble",
    "sableada": "sa-ble-a-da",
    "sableador": "sa-ble-a-dor",
    "sableadora": "sa-ble-a-do-ra",
    "sablear": "sa-ble-ar",
    "sableo": "sa-ble-o",
    "sablera": "sa-ble-ra",
    "sablero": "sa-ble-ro",
    "sablista": "sa-blis-ta",
    "sablón": "sa-blón",
    "saboga": "sa-bo-ga",
    "sabogal": "sa-bo-gal",
    "sabonera": "sa-bo-ne-ra",
    "saboneta": "sa-bo-ne-ta",
    "sabor": "sa-bor",
    "saborea": "sa-bo-re-a",
    "saboreador": "sa-bo-re-a-dor",
    "saboreadora": "sa-bo-re-a-do-ra",
    "saboreamiento": "sa-bo-re-a-mien-to",
    "saborear": "sa-bo-re-ar",
    "saboreo": "sa-bo-re-o",
    "saborgar": "sa-bor-gar",
    "saborizante": "sa-bo-ri-zan-te",
    "saborosa": "sa-bo-ro-sa",
    "saboroso": "sa-bo-ro-so",
    "sabotaje": "sa-bo-ta-je",
    "saboteador": "sa-bo-te-a-dor",
    "saboteadora": "sa-bo-te-a-do-ra",
    "sabotear": "sa-bo-te-ar",
    "saboyana": "sa-bo-ya-na",
    "saboyano": "sa-bo-ya-no",
    "sabre": "sa-bre",
    "sabrimiento": "sa-bri-mien-to",
    "sabrosa": "sa-bro-sa",
    "sabrosamente": "sa-bro-sa-men-te",
    "sabrosera": "sa-bro-se-ra",
    "sabroso": "sa-bro-so",
    "sabrosón": "sa-bro-són",
    "sabrosura": "sa-bro-su-ra",
    "sabucal": "sa-bu-cal",
    "sabuco": "sa-bu-co",
    "sabuesa": "sa-bue-sa",
    "sabueso": "sa-bue-so",
    "sabugal": "sa-bu-gal",
    "sabugo": "sa-bu-go",
    "sábulo": "sá-bu-lo",
    "sabulosa": "sa-bu-lo-sa",
    "sabuloso": "sa-bu-lo-so",
    "saburra": "sa-bu-rra",
    "saburral": "sa-bu-rral",
    "saburrar": "sa-bu-rrar",
    "saburrosa": "sa-bu-rro-sa",
    "saburroso": "sa-bu-rro-so",
    "saca": "sa-ca",
    "sacabala": "sa-ca-ba-la",
    "sacabalas": "sa-ca-ba-las",
    "sacabancos": "sa-ca-ban-cos",
    "sacabeña": "sa-ca-be-ña",
    "sacabeño": "sa-ca-be-ño",
    "sacabera": "sa-ca-be-ra",
    "sacabocado": "sa-ca-bo-ca-do",
    "sacabocados": "sa-ca-bo-ca-dos",
    "sacabotas": "sa-ca-bo-tas",
    "sacabrocas": "sa-ca-bro-cas",
    "sacabuche": "sa-ca-bu-che",
    "sacaclavos": "sa-ca-cla-vos",
    "sacacorchos": "sa-ca-cor-chos",
    "sacacuartos": "sa-ca-cuar-tos",
    "sacada": "sa-ca-da",
    "sacadera": "sa-ca-de-ra",
    "sacadientes": "sa-ca-dien-tes",
    "sacadilla": "sa-ca-di-lla",
    "sacadineros": "sa-ca-di-ne-ros",
    "sacado": "sa-ca-do",
    "sacador": "sa-ca-dor",
    "sacadora": "sa-ca-do-ra",
    "sacadura": "sa-ca-du-ra",
    "sacafilásticas": "sa-ca-fi-lás-ti-cas",
    "sacalagua": "sa-ca-la-gua",
    "sácalas": "sá-ca-las",
    "sacaleches": "sa-ca-le-ches",
    "sacaliña": "sa-ca-li-ña",
    "sacalosúchil": "sa-ca-lo-sú-chil",
    "sacamanchas": "sa-ca-man-chas",
    "sacamantas": "sa-ca-man-tas",
    "sacamantecas": "sa-ca-man-te-cas",
    "sacamiento": "sa-ca-mien-to",
    "sacamolero": "sa-ca-mo-le-ro",
    "sacamuelas": "sa-ca-mue-las",
    "sacanabo": "sa-ca-na-bo",
    "sacanete": "sa-ca-ne-te",
    "sacaniguas": "sa-ca-ni-guas",
    "sacapelotas": "sa-ca-pe-lo-tas",
    "sacaperras": "sa-ca-pe-rras",
    "sacapotras": "sa-ca-po-tras",
    "sacapulteca": "sa-ca-pul-te-ca",
    "sacapuntas": "sa-ca-pun-tas",
    "sacar": "sa-car",
    "sacárido": "sa-cá-ri-do",
    "sacarífera": "sa-ca-rí-fe-ra",
    "sacarífero": "sa-ca-rí-fe-ro",
    "sacarificación": "sa-ca-ri-fi-ca-ción",
    "sacarificar": "sa-ca-ri-fi-car",
    "sacarígena": "sa-ca-rí-ge-na",
    "sacarígeno": "sa-ca-rí-ge-no",
    "sacarimetría": "sa-ca-ri-me-trí-a",
    "sacarímetro": "sa-ca-rí-me-tro",
    "sacarina": "sa-ca-ri-na",
    "sacarino": "sa-ca-ri-no",
    "sacaroidea": "sa-ca-roi-de-a",
    "sacaroideo": "sa-ca-roi-de-o",
    "sacarosa": "sa-ca-ro-sa",
    "sacasebo": "sa-ca-se-bo",
    "sacasillas": "sa-ca-si-llas",
    "sacatapón": "sa-ca-ta-pón",
    "sacate": "sa-ca-te",
    "sacatinta": "sa-ca-tin-ta",
    "sacatón": "sa-ca-tón",
    "sacatona": "sa-ca-to-na",
    "sacatrapos": "sa-ca-tra-pos",
    "sacavueltas": "sa-ca-vuel-tas",
    "sacciforme": "sac-ci-for-me",
    "sacerdocio": "sa-cer-do-cio",
    "sacerdotal": "sa-cer-do-tal",
    "sacerdote": "sa-cer-do-te",
    "sacerdotisa": "sa-cer-do-ti-sa",
    "sácere": "sá-ce-re",
    "sachadura": "sa-cha-du-ra",
    "sachaguasca": "sa-cha-guas-ca",
    "sachamédica": "sa-cha-mé-di-ca",
    "sachamédico": "sa-cha-mé-di-co",
    "sachapera": "sa-cha-pe-ra",
    "sachar": "sa-char",
    "sachet": "sa-chet",
    "sacho": "sa-cho",
    "sacia": "sa-cia",
    "saciable": "sa-cia-ble",
    "saciar": "sa-ciar",
    "saciedad": "sa-cie-dad",
    "saciña": "sa-ci-ña",
    "sacio": "sa-cio",
    "saco": "sa-co",
    "sacoleva": "sa-co-le-va",
    "sacolevita": "sa-co-le-vi-ta",
    "sacomano": "sa-co-ma-no",
    "sacón": "sa-cón",
    "sacona": "sa-co-na",
    "saconear": "sa-co-ne-ar",
    "saconería": "sa-co-ne-rí-a",
    "sacra": "sa-cra",
    "sacral": "sa-cral",
    "sacralidad": "sa-cra-li-dad",
    "sacralización": "sa-cra-li-za-ción",
    "sacralizar": "sa-cra-li-zar",
    "sacramentación": "sa-cra-men-ta-ción",
    "sacramentado": "sa-cra-men-ta-do",
    "sacramental": "sa-cra-men-tal",
    "sacramentalmente": "sa-cra-men-tal-men-te",
    "sacramentar": "sa-cra-men-tar",
    "sacramentaria": "sa-cra-men-ta-ria",
    "sacramentario": "sa-cra-men-ta-rio",
    "sacramente": "sa-cra-men-te",
    "sacramentina": "sa-cra-men-ti-na",
    "sacramentino": "sa-cra-men-ti-no",
    "sacramento": "sa-cra-men-to",
    "sacratísima": "sa-cra-tí-si-ma",
    "sacratísimo": "sa-cra-tí-si-mo",
    "sacre": "sa-cre",
    "sacrificadero": "sa-cri-fi-ca-de-ro",
    "sacrificador": "sa-cri-fi-ca-dor",
    "sacrificadora": "sa-cri-fi-ca-do-ra",
    "sacrificar": "sa-cri-fi-car",
    "sacrificial": "sa-cri-fi-cial",
    "sacrificio": "sa-cri-fi-cio",
    "sacrílega": "sa-crí-le-ga",
    "sacrílegamente": "sa-crí-le-ga-men-te",
    "sacrilegio": "sa-cri-le-gio",
    "sacrílego": "sa-crí-le-go",
    "sacris": "sa-cris",
    "sacrismoche": "sa-cris-mo-che",
    "sacrismocho": "sa-cris-mo-cho",
    "sacrista": "sa-cris-ta",
    "sacristán": "sa-cris-tán",
    "sacristana": "sa-cris-ta-na",
    "sacristanesca": "sa-cris-ta-nes-ca",
    "sacristanesco": "sa-cris-ta-nes-co",
    "sacristanía": "sa-cris-ta-ní-a",
    "sacristía": "sa-cris-tí-a",
    "sacro": "sa-cro",
    "sacrosanta": "sa-cro-san-ta",
    "sacrosantamente": "sa-cro-san-ta-men-te",
    "sacrosanto": "sa-cro-san-to",
    "sacuanjoche": "sa-cuan-jo-che",
    "sacuara": "sa-cua-ra",
    "sacudecolchón": "sa-cu-de-col-chón",
    "sacudico": "sa-cu-di-co",
    "sacudida": "sa-cu-di-da",
    "sacudidamente": "sa-cu-di-da-men-te",
    "sacudido": "sa-cu-di-do",
    "sacudidor": "sa-cu-di-dor",
    "sacudidora": "sa-cu-di-do-ra",
    "sacudidura": "sa-cu-di-du-ra",
    "sacudimiento": "sa-cu-di-mien-to",
    "sacudión": "sa-cu-dión",
    "sacudir": "sa-cu-dir",
    "sacudón": "sa-cu-dón",
    "sáculo": "sá-cu-lo",
    "sádica": "sá-di-ca",
    "sádico": "sá-di-co",
    "sadismo": "sa-dis-mo",
    "sadomasoquismo": "sa-do-ma-so-quis-mo",
    "sadomasoquista": "sa-do-ma-so-quis-ta",
    "saducea": "sa-du-ce-a",
    "saduceísmo": "sa-du-ce-ís-mo",
    "saduceo": "sa-du-ce-o",
    "saeta": "sa-e-ta",
    "saetada": "sa-e-ta-da",
    "saetar": "sa-e-tar",
    "saetazo": "sa-e-ta-zo",
    "saetear": "sa-e-te-ar",
    "saetera": "sa-e-te-ra",
    "saetero": "sa-e-te-ro",
    "saetí": "sa-e-tí",
    "saetía": "sa-e-tí-a",
    "saetilla": "sa-e-ti-lla",
    "saetín": "sa-e-tín",
    "saetón": "sa-e-tón",
    "safari": "sa-fa-ri",
    "safena": "sa-fe-na",
    "sáfica": "sá-fi-ca",
    "sáfico": "sá-fi-co",
    "safir": "sa-fir",
    "safrisco": "sa-fris-co",
    "saga": "sa-ga",
    "sagacidad": "sa-ga-ci-dad",
    "sagallino": "sa-ga-lli-no",
    "sagapeno": "sa-ga-pe-no",
    "sagardúa": "sa-gar-dú-a",
    "sagarmín": "sa-gar-mín",
    "sagatí": "sa-ga-tí",
    "sagaz": "sa-gaz",
    "sagazmente": "sa-gaz-men-te",
    "sagita": "sa-gi-ta",
    "sagitado": "sa-gi-ta-do",
    "sagital": "sa-gi-tal",
    "sagitaria": "sa-gi-ta-ria",
    "sagitariana": "sa-gi-ta-ria-na",
    "sagitariano": "sa-gi-ta-ria-no",
    "sagitario": "sa-gi-ta-rio",
    "sago": "sa-go",
    "ságoma": "sá-go-ma",
    "sagrada": "sa-gra-da",
    "sagradamente": "sa-gra-da-men-te",
    "sagrado": "sa-gra-do",
    "sagrario": "sa-gra-rio",
    "sagrativa": "sa-gra-ti-va",
    "sagrativamente": "sa-gra-ti-va-men-te",
    "sagrativo": "sa-gra-ti-vo",
    "sagú": "sa-gú",
    "saguaipé": "sa-guai-pé",
    "saguaro": "sa-gua-ro",
    "saguaypé": "sa-guay-pé",
    "ságula": "sá-gu-la",
    "saguntina": "sa-gun-ti-na",
    "saguntino": "sa-gun-ti-no",
    "saharaui": "sa-ha-raui",
    "sahariana": "sa-ha-ria-na",
    "sahariano": "sa-ha-ria-no",
    "sahárica": "sa-há-ri-ca",
    "sahárico": "sa-há-ri-co",
    "sahína": "sa-hí-na",
    "sahinar": "sahi-nar",
    "sahornar": "sa-hor-nar",
    "sahornarse": "sa-hor-nar-se",
    "sahorno": "sa-hor-no",
    "sahumada": "sahu-ma-da",
    "sahumado": "sahu-ma-do",
    "sahumador": "sahu-ma-dor",
    "sahumadura": "sahu-ma-du-ra",
    "sahumar": "sahu-mar",
    "sahumerio": "sahu-me-rio",
    "sahúmo": "sa-hú-mo",
    "sahurín": "sahu-rín",
    "saiga": "sai-ga",
    "saín": "sa-ín",
    "sainar": "sai-nar",
    "sainete": "sai-ne-te",
    "sainetear": "sai-ne-te-ar",
    "sainetera": "sai-ne-te-ra",
    "sainetero": "sai-ne-te-ro",
    "sainetesca": "sai-ne-tes-ca",
    "sainetesco": "sai-ne-tes-co",
    "sainetista": "sai-ne-tis-ta",
    "saíno": "sa-í-no",
    "saja": "sa-ja",
    "sajada": "sa-ja-da",
    "sajado": "sa-ja-do",
    "sajador": "sa-ja-dor",
    "sajadura": "sa-ja-du-ra",
    "sajar": "sa-jar",
    "sajelar": "sa-je-lar",
    "sajía": "sa-jí-a",
    "sajino": "sa-ji-no",
    "sajón": "sa-jón",
    "sajona": "sa-jo-na",
    "sajonia": "sa-jo-nia",
    "sajumaya": "sa-ju-ma-ya",
    "sajurín": "sa-ju-rín",
    "sake": "sa-ke",
    "sala": "sa-la",
    "salabardear": "sa-la-bar-de-ar",
    "salabardo": "sa-la-bar-do",
    "salabre": "sa-la-bre",
    "salacenca": "sa-la-cen-ca",
    "salacenco": "sa-la-cen-co",
    "salacidad": "sa-la-ci-dad",
    "salación": "sa-la-ción",
    "salacot": "sa-la-cot",
    "salada": "sa-la-da",
    "saladamente": "sa-la-da-men-te",
    "saladar": "sa-la-dar",
    "saladero": "sa-la-de-ro",
    "saladilla": "sa-la-di-lla",
    "saladillo": "sa-la-di-llo",
    "salado": "sa-la-do",
    "salador": "sa-la-dor",
    "saladora": "sa-la-do-ra",
    "saladura": "sa-la-du-ra",
    "salagón": "sa-la-gón",
    "salamanca": "sa-la-man-ca",
    "salamandra": "sa-la-man-dra",
    "salamandria": "sa-la-man-dria",
    "salamandrina": "sa-la-man-dri-na",
    "salamandrino": "sa-la-man-dri-no",
    "salamanqueja": "sa-la-man-que-ja",
    "salamanquera": "sa-la-man-que-ra",
    "salamanquero": "sa-la-man-que-ro",
    "salamanqués": "sa-la-man-qués",
    "salamanquesa": "sa-la-man-que-sa",
    "salamanquina": "sa-la-man-qui-na",
    "salamanquino": "sa-la-man-qui-no",
    "salamántiga": "sa-la-mán-ti-ga",
    "salamateca": "sa-la-ma-te-ca",
    "salamateco": "sa-la-ma-te-co",
    "salame": "sa-la-me",
    "salami": "sa-la-mi",
    "salamín": "sa-la-mín",
    "salamo": "sa-la-mo",
    "salamunda": "sa-la-mun-da",
    "salangana": "sa-lan-ga-na",
    "salar": "sa-lar",
    "salariado": "sa-la-ria-do",
    "salarial": "sa-la-rial",
    "salariar": "sa-la-riar",
    "salario": "sa-la-rio",
    "salaz": "sa-laz",
    "salazón": "sa-la-zón",
    "salazonera": "sa-la-zo-ne-ra",
    "salazonero": "sa-la-zo-ne-ro",
    "salbanda": "sal-ban-da",
    "salbecazo": "sal-be-ca-zo",
    "salbegar": "sal-be-gar",
    "salbeque": "sal-be-que",
    "salbequear": "sal-be-que-ar",
    "salbute": "sal-bu-te",
    "salce": "sal-ce",
    "salceda": "sal-ce-da",
    "salcedense": "sal-ce-den-se",
    "salcedo": "sal-ce-do",
    "salchicha": "sal-chi-cha",
    "salchichera": "sal-chi-che-ra",
    "salchichería": "sal-chi-che-rí-a",
    "salchichero": "sal-chi-che-ro",
    "salchichón": "sal-chi-chón",
    "salchichonería": "sal-chi-cho-ne-rí-a",
    "salchucho": "sal-chu-cho",
    "salciña": "sal-ci-ña",
    "salcinar": "sal-ci-nar",
    "salcochar": "sal-co-char",
    "salcocho": "sal-co-cho",
    "saldar": "sal-dar",
    "salderita": "sal-de-ri-ta",
    "saldista": "sal-dis-ta",
    "saldo": "sal-do",
    "saldorija": "sal-do-ri-ja",
    "saldubense": "sal-du-ben-se",
    "salea": "sa-le-a",
    "salear": "sa-le-ar",
    "salearse": "sa-le-ar-se",
    "salediza": "sa-le-di-za",
    "saledizo": "sa-le-di-zo",
    "salega": "sa-le-ga",
    "salegar": "sa-le-gar",
    "salema": "sa-le-ma",
    "salentina": "sa-len-ti-na",
    "salentino": "sa-len-ti-no",
    "salep": "sa-lep",
    "salera": "sa-le-ra",
    "salernitana": "sa-ler-ni-ta-na",
    "salernitano": "sa-ler-ni-ta-no",
    "salero": "sa-le-ro",
    "salerón": "sa-le-rón",
    "salerosa": "sa-le-ro-sa",
    "saleroso": "sa-le-ro-so",
    "salesa": "sa-le-sa",
    "salesiana": "sa-le-sia-na",
    "salesiano": "sa-le-sia-no",
    "saleta": "sa-le-ta",
    "salga": "sal-ga",
    "salgada": "sal-ga-da",
    "salgadera": "sal-ga-de-ra",
    "salgadura": "sal-ga-du-ra",
    "salgar": "sal-gar",
    "salgareño": "sal-ga-re-ño",
    "salgue": "sal-gue",
    "salguera": "sal-gue-ra",
    "salguero": "sal-gue-ro",
    "salia": "sa-lia",
    "sálica": "sá-li-ca",
    "salicácea": "sa-li-cá-ce-a",
    "salicáceas": "sa-li-cá-ce-as",
    "salicáceo": "sa-li-cá-ce-o",
    "salicaria": "sa-li-ca-ria",
    "salicilato": "sa-li-ci-la-to",
    "salicílico": "sa-li-cí-li-co",
    "salicina": "sa-li-ci-na",
    "salicínea": "sa-li-cí-ne-a",
    "salicíneo": "sa-li-cí-ne-o",
    "sálico": "sá-li-co",
    "salicor": "sa-li-cor",
    "salicornia": "sa-li-cor-nia",
    "salicultura": "sa-li-cul-tu-ra",
    "salida": "sa-li-da",
    "salidera": "sa-li-de-ra",
    "salidero": "sa-li-de-ro",
    "salidizo": "sa-li-di-zo",
    "salido": "sa-li-do",
    "salidor": "sa-li-dor",
    "salidora": "sa-li-do-ra",
    "saliente": "sa-lien-te",
    "salífera": "sa-lí-fe-ra",
    "salífero": "sa-lí-fe-ro",
    "salificable": "sa-li-fi-ca-ble",
    "salificación": "sa-li-fi-ca-ción",
    "salificar": "sa-li-fi-car",
    "salima": "sa-li-ma",
    "salimiento": "sa-li-mien-to",
    "salín": "sa-lín",
    "salina": "sa-li-na",
    "salinera": "sa-li-ne-ra",
    "salinero": "sa-li-ne-ro",
    "salinidad": "sa-li-ni-dad",
    "salino": "sa-li-no",
    "salio": "sa-lio",
    "salipirina": "sa-li-pi-ri-na",
    "salir": "sa-lir",
    "salisipan": "sa-li-si-pan",
    "salitrada": "sa-li-tra-da",
    "salitrado": "sa-li-tra-do",
    "salitral": "sa-li-tral",
    "salitre": "sa-li-tre",
    "salitrera": "sa-li-tre-ra",
    "salitrería": "sa-li-tre-rí-a",
    "salitrero": "sa-li-tre-ro",
    "salitrosa": "sa-li-tro-sa",
    "salitroso": "sa-li-tro-so",
    "saliva": "sa-li-va",
    "salivación": "sa-li-va-ción",
    "salivada": "sa-li-va-da",
    "salivadera": "sa-li-va-de-ra",
    "salivajo": "sa-li-va-jo",
    "salival": "sa-li-val",
    "salivar": "sa-li-var",
    "salivazo": "sa-li-va-zo",
    "salivera": "sa-li-ve-ra",
    "salivosa": "sa-li-vo-sa",
    "salivoso": "sa-li-vo-so",
    "sallador": "sa-lla-dor",
    "salladora": "sa-lla-do-ra",
    "salladura": "sa-lla-du-ra",
    "sallar": "sa-llar",
    "sallete": "sa-lle-te",
    "salma": "sal-ma",
    "salmanticense": "sal-man-ti-cen-se",
    "salmantina": "sal-man-ti-na",
    "salmantino": "sal-man-ti-no",
    "salmar": "sal-mar",
    "salmear": "sal-me-ar",
    "salmer": "sal-mer",
    "salmera": "sal-me-ra",
    "salmerón": "sal-me-rón",
    "salmista": "sal-mis-ta",
    "salmo": "sal-mo",
    "salmodia": "sal-mo-dia",
    "salmodiar": "sal-mo-diar",
    "salmón": "sal-món",
    "salmonada": "sal-mo-na-da",
    "salmonado": "sal-mo-na-do",
    "salmonela": "sal-mo-ne-la",
    "salmonella": "sal-mo-ne-lla",
    "salmonelosis": "sal-mo-ne-lo-sis",
    "salmonera": "sal-mo-ne-ra",
    "salmonete": "sal-mo-ne-te",
    "salmónido": "sal-mó-ni-do",
    "salmorejo": "sal-mo-re-jo",
    "salmuera": "sal-mue-ra",
    "salmuerar": "sal-mue-rar",
    "salmuerarse": "sal-mue-rar-se",
    "salobral": "sa-lo-bral",
    "salobre": "sa-lo-bre",
    "salobreña": "sa-lo-bre-ña",
    "salobreño": "sa-lo-bre-ño",
    "salobridad": "sa-lo-bri-dad",
    "salol": "sa-lol",
    "saloma": "sa-lo-ma",
    "salomar": "sa-lo-mar",
    "salomón": "sa-lo-món",
    "salomonense": "sa-lo-mo-nen-se",
    "salomónica": "sa-lo-mó-ni-ca",
    "salomónico": "sa-lo-mó-ni-co",
    "salón": "sa-lón",
    "saloncillo": "sa-lon-ci-llo",
    "salonera": "sa-lo-ne-ra",
    "salonero": "sa-lo-ne-ro",
    "salpa": "sal-pa",
    "salpicada": "sal-pi-ca-da",
    "salpicadera": "sal-pi-ca-de-ra",
    "salpicadero": "sal-pi-ca-de-ro",
    "salpicadura": "sal-pi-ca-du-ra",
    "salpicar": "sal-pi-car",
    "salpicón": "sal-pi-cón",
    "salpicona": "sal-pi-co-na",
    "salpimentar": "sal-pi-men-tar",
    "salpimienta": "sal-pi-mien-ta",
    "salpique": "sal-pi-que",
    "salpresamiento": "sal-pre-sa-mien-to",
    "salpresar": "sal-pre-sar",
    "salpreso": "sal-pre-so",
    "salpuga": "sal-pu-ga",
    "salpullido": "sal-pu-lli-do",
    "salpullir": "sal-pu-llir",
    "salsa": "sal-sa",
    "salsamentar": "sal-sa-men-tar",
    "salsamentaría": "sal-sa-men-ta-rí-a",
    "salsamento": "sal-sa-men-to",
    "salsear": "sal-se-ar",
    "salsedumbre": "sal-se-dum-bre",
    "salsera": "sal-se-ra",
    "salsereta": "sal-se-re-ta",
    "salserilla": "sal-se-ri-lla",
    "salsero": "sal-se-ro",
    "salserón": "sal-se-rón",
    "salseruela": "sal-se-rue-la",
    "salsifí": "sal-si-fí",
    "salsina": "sal-si-na",
    "salso": "sal-so",
    "salsolácea": "sal-so-lá-ce-a",
    "salsoláceo": "sal-so-lá-ce-o",
    "salsosa": "sal-so-sa",
    "salsoso": "sal-so-so",
    "saltabanco": "sal-ta-ban-co",
    "saltabancos": "sal-ta-ban-cos",
    "saltabardales": "sal-ta-bar-da-les",
    "saltabarrancos": "sal-ta-ba-rran-cos",
    "saltable": "sal-ta-ble",
    "saltacaballo": "sal-ta-ca-ba-llo",
    "saltacharquillos": "sal-ta-char-qui-llos",
    "saltación": "sal-ta-ción",
    "saltada": "sal-ta-da",
    "saltadero": "sal-ta-de-ro",
    "saltadiza": "sal-ta-di-za",
    "saltadizo": "sal-ta-di-zo",
    "saltado": "sal-ta-do",
    "saltador": "sal-ta-dor",
    "saltadora": "sal-ta-do-ra",
    "saltadura": "sal-ta-du-ra",
    "saltaembanco": "sal-ta-em-ban-co",
    "saltaembancos": "sal-ta-em-ban-cos",
    "saltaembarca": "sal-ta-em-bar-ca",
    "saltagatos": "sal-ta-ga-tos",
    "saltambarca": "sal-tam-bar-ca",
    "saltamontes": "sal-ta-mon-tes",
    "saltana": "sal-ta-na",
    "saltaneja": "sal-ta-ne-ja",
    "saltanejal": "sal-ta-ne-jal",
    "saltanejo": "sal-ta-ne-jo",
    "saltanejosa": "sal-ta-ne-jo-sa",
    "saltanejoso": "sal-ta-ne-jo-so",
    "saltante": "sal-tan-te",
    "saltaojos": "sal-ta-o-jos",
    "saltapajas": "sal-ta-pa-jas",
    "saltaparedes": "sal-ta-pa-re-des",
    "saltaperico": "sal-ta-pe-ri-co",
    "saltaprados": "sal-ta-pra-dos",
    "saltar": "sal-tar",
    "saltarel": "sal-ta-rel",
    "saltarelo": "sal-ta-re-lo",
    "saltarén": "sal-ta-rén",
    "saltarilla": "sal-ta-ri-lla",
    "saltarín": "sal-ta-rín",
    "saltarina": "sal-ta-ri-na",
    "saltarregla": "sal-ta-rre-gla",
    "saltarrostro": "sal-ta-rros-tro",
    "saltaterandate": "sal-ta-te-ran-da-te",
    "saltatrás": "sal-ta-trás",
    "saltatriz": "sal-ta-triz",
    "saltatumbas": "sal-ta-tum-bas",
    "salteador": "sal-te-a-dor",
    "salteadora": "sal-te-a-do-ra",
    "salteamiento": "sal-te-a-mien-to",
    "saltear": "sal-te-ar",
    "salteña": "sal-te-ña",
    "salteñada": "sal-te-ña-da",
    "salteño": "sal-te-ño",
    "salteo": "sal-te-o",
    "saltera": "sal-te-ra",
    "salterio": "sal-te-rio",
    "saltero": "sal-te-ro",
    "saltigallo": "sal-ti-ga-llo",
    "saltígrada": "sal-tí-gra-da",
    "saltígrado": "sal-tí-gra-do",
    "saltillense": "sal-ti-llen-se",
    "saltimbanco": "sal-tim-ban-co",
    "saltimbanqui": "sal-tim-ban-qui",
    "salto": "sal-to",
    "saltoguareña": "sal-to-gua-re-ña",
    "saltoguareño": "sal-to-gua-re-ño",
    "saltón": "sal-tón",
    "saltona": "sal-to-na",
    "saltrorrostro": "sal-tro-rros-tro",
    "salubérrima": "sa-lu-bé-rri-ma",
    "salubérrimo": "sa-lu-bé-rri-mo",
    "salubre": "sa-lu-bre",
    "salubridad": "sa-lu-bri-dad",
    "salud": "sa-lud",
    "saluda": "sa-lu-da",
    "saludable": "sa-lu-da-ble",
    "saludablemente": "sa-lu-da-ble-men-te",
    "saludación": "sa-lu-da-ción",
    "saludador": "sa-lu-da-dor",
    "saludadora": "sa-lu-da-do-ra",
    "saludar": "sa-lu-dar",
    "saludes": "sa-lu-des",
    "saludo": "sa-lu-do",
    "salumbre": "sa-lum-bre",
    "salutación": "sa-lu-ta-ción",
    "salute": "sa-lu-te",
    "salutífera": "sa-lu-tí-fe-ra",
    "salutíferamente": "sa-lu-tí-fe-ra-men-te",
    "salutífero": "sa-lu-tí-fe-ro",
    "salva": "sal-va",
    "salvabarros": "sal-va-ba-rros",
    "salvable": "sal-va-ble",
    "salvachia": "sal-va-chia",
    "salvación": "sal-va-ción",
    "salvadera": "sal-va-de-ra",
    "salvado": "sal-va-do",
    "salvador": "sal-va-dor",
    "salvadora": "sal-va-do-ra",
    "salvadoreña": "sal-va-do-re-ña",
    "salvadoreñismo": "sal-va-do-re-ñis-mo",
    "salvadoreño": "sal-va-do-re-ño",
    "salvaguarda": "sal-va-guar-da",
    "salvaguardar": "sal-va-guar-dar",
    "salvaguardia": "sal-va-guar-dia",
    "salvajada": "sal-va-ja-da",
    "salvaje": "sal-va-je",
    "salvajería": "sal-va-je-rí-a",
    "salvajez": "sal-va-jez",
    "salvajina": "sal-va-ji-na",
    "salvajino": "sal-va-ji-no",
    "salvajismo": "sal-va-jis-mo",
    "salvamano": "sal-va-ma-no",
    "salvamanteles": "sal-va-man-te-les",
    "salvamente": "sal-va-men-te",
    "salvamento": "sal-va-men-to",
    "salvamiento": "sal-va-mien-to",
    "salvante": "sal-van-te",
    "salvapantalla": "sal-va-pan-ta-lla",
    "salvapantallas": "sal-va-pan-ta-llas",
    "salvar": "sal-var",
    "salvataje": "sal-va-ta-je",
    "salvaterrana": "sal-va-te-rra-na",
    "salvaterrano": "sal-va-te-rra-no",
    "salvática": "sal-vá-ti-ca",
    "salvático": "sal-vá-ti-co",
    "salvatiqueza": "sal-va-ti-que-za",
    "salvatruche": "sal-va-tru-che",
    "salvaúñas": "sal-va-ú-ñas",
    "salvavida": "sal-va-vi-da",
    "salvavidas": "sal-va-vi-das",
    "salve": "sal-ve",
    "salvedad": "sal-ve-dad",
    "salveque": "sal-ve-que",
    "salvia": "sal-via",
    "salvífico": "sal-ví-fi-co",
    "salvilla": "sal-vi-lla",
    "salvilora": "sal-vi-lo-ra",
    "salvo": "sal-vo",
    "salvoconducto": "sal-vo-con-duc-to",
    "salvohonor": "sal-vo-ho-nor",
    "salzmimbre": "salz-mim-bre",
    "sama": "sa-ma",
    "sámago": "sá-ma-go",
    "samán": "sa-mán",
    "samanés": "sa-ma-nés",
    "samanesa": "sa-ma-ne-sa",
    "samanta": "sa-man-ta",
    "sámara": "sá-ma-ra",
    "samaria": "sa-ma-ria",
    "samarilla": "sa-ma-ri-lla",
    "samario": "sa-ma-rio",
    "samarita": "sa-ma-ri-ta",
    "samaritana": "sa-ma-ri-ta-na",
    "samaritano": "sa-ma-ri-ta-no",
    "samarugo": "sa-ma-ru-go",
    "samaruguera": "sa-ma-ru-gue-ra",
    "samba": "sam-ba",
    "sambate": "sam-ba-te",
    "sambenitar": "sam-be-ni-tar",
    "sambenito": "sam-be-ni-to",
    "sambernardina": "sam-ber-nar-di-na",
    "sambernardino": "sam-ber-nar-di-no",
    "samblaje": "sam-bla-je",
    "samblasina": "sam-bla-si-na",
    "samblasino": "sam-bla-si-no",
    "sambo": "sam-bo",
    "sambuca": "sam-bu-ca",
    "sambumbe": "sam-bum-be",
    "sambumbia": "sam-bum-bia",
    "samia": "sa-mia",
    "samio": "sa-mio",
    "samnita": "sam-ni-ta",
    "samnite": "sam-ni-te",
    "samnítica": "sam-ní-ti-ca",
    "samnítico": "sam-ní-ti-co",
    "samoana": "sa-mo-a-na",
    "samoano": "sa-mo-a-no",
    "samosatena": "sa-mo-sa-te-na",
    "samosateno": "sa-mo-sa-te-no",
    "samosatense": "sa-mo-sa-ten-se",
    "samotana": "sa-mo-ta-na",
    "samotracia": "sa-mo-tra-cia",
    "samotracio": "sa-mo-tra-cio",
    "samovar": "sa-mo-var",
    "samoyeda": "sa-mo-ye-da",
    "samoyedo": "sa-mo-ye-do",
    "sampa": "sam-pa",
    "sampablera": "sam-pa-ble-ra",
    "sampaguita": "sam-pa-gui-ta",
    "sampán": "sam-pán",
    "sampedrada": "sam-pe-dra-da",
    "sampedrana": "sam-pe-dra-na",
    "sampedrano": "sam-pe-dra-no",
    "sampedro": "sam-pe-dro",
    "samplegorio": "sam-ple-go-rio",
    "sámpler": "sám-pler",
    "sampsuco": "samp-su-co",
    "samsara": "sam-sa-ra",
    "samuel": "sa-muel",
    "samueleador": "sa-mue-le-a-dor",
    "samuelear": "sa-mue-le-ar",
    "samuga": "sa-mu-ga",
    "samugo": "sa-mu-go",
    "samuhú": "sa-mu-hú",
    "samurái": "sa-mu-rái",
    "samuray": "sa-mu-ray",
    "samuro": "sa-mu-ro",
    "samurrar": "sa-mu-rrar",
    "sana": "sa-na",
    "saña": "sa-ña",
    "sanable": "sa-na-ble",
    "sanabrés": "sa-na-brés",
    "sanabresa": "sa-na-bre-sa",
    "sanaca": "sa-na-ca",
    "sanación": "sa-na-ción",
    "sanaco": "sa-na-co",
    "sanador": "sa-na-dor",
    "sanadora": "sa-na-do-ra",
    "sanalotodo": "sa-na-lo-to-do",
    "sanamente": "sa-na-men-te",
    "sanamunda": "sa-na-mun-da",
    "sananería": "sa-na-ne-rí-a",
    "sananica": "sa-na-ni-ca",
    "sanano": "sa-na-no",
    "sanantona": "sa-nan-to-na",
    "sanantonina": "sa-nan-to-ni-na",
    "sanantonino": "sa-nan-to-ni-no",
    "sanapudio": "sa-na-pu-dio",
    "sanaquería": "sa-na-que-rí-a",
    "sanar": "sa-nar",
    "sanata": "sa-na-ta",
    "sanate": "sa-na-te",
    "sanativa": "sa-na-ti-va",
    "sanativo": "sa-na-ti-vo",
    "sanatorial": "sa-na-to-rial",
    "sanatorio": "sa-na-to-rio",
    "sanavirón": "sa-na-vi-rón",
    "sanavirona": "sa-na-vi-ro-na",
    "sancarleña": "san-car-le-ña",
    "sancarleño": "san-car-le-ño",
    "sancarlina": "san-car-li-na",
    "sancarlino": "san-car-li-no",
    "sancha": "san-cha",
    "sanchecia": "san-che-cia",
    "sanchete": "san-che-te",
    "sanchina": "san-chi-na",
    "sancho": "san-cho",
    "sanchopancesca": "san-cho-pan-ces-ca",
    "sanchopancesco": "san-cho-pan-ces-co",
    "sanción": "san-ción",
    "sancionable": "san-cio-na-ble",
    "sancionador": "san-cio-na-dor",
    "sancionadora": "san-cio-na-do-ra",
    "sancionar": "san-cio-nar",
    "sancionatorio": "san-cio-na-to-rio",
    "sancirole": "san-ci-ro-le",
    "sanco": "san-co",
    "sancochado": "san-co-cha-do",
    "sancochar": "san-co-char",
    "sancocho": "san-co-cho",
    "sancristobaleña": "san-cris-to-ba-le-ña",
    "sancristobaleño": "san-cris-to-ba-le-ño",
    "sancristobalense": "san-cris-to-ba-len-se",
    "sancristobera": "san-cris-to-be-ra",
    "sancristobero": "san-cris-to-be-ro",
    "sancta": "sanc-ta",
    "sanctasanctórum": "sanc-ta-sanc-tó-rum",
    "sanctórum": "sanc-tó-rum",
    "sanctus": "sanc-tus",
    "sandalia": "san-da-lia",
    "sandalina": "san-da-li-na",
    "sandalino": "san-da-li-no",
    "sándalo": "sán-da-lo",
    "sandáraca": "san-dá-ra-ca",
    "sandez": "san-dez",
    "sandía": "san-dí-a",
    "sandia": "san-dia",
    "sandial": "san-dial",
    "sandialahuén": "san-dia-la-huén",
    "sandiar": "san-diar",
    "sandiego": "san-die-go",
    "sandinismo": "san-di-nis-mo",
    "sandinista": "san-di-nis-ta",
    "sandino": "san-di-no",
    "sandio": "san-dio",
    "sanducera": "san-du-ce-ra",
    "sanducero": "san-du-ce-ro",
    "sandunga": "san-dun-ga",
    "sandunguear": "san-dun-gue-ar",
    "sandunguera": "san-dun-gue-ra",
    "sandunguero": "san-dun-gue-ro",
    "sandwichería": "sand-wi-che-rí-a",
    "saneada": "sa-ne-a-da",
    "saneado": "sa-ne-a-do",
    "saneamiento": "sa-ne-a-mien-to",
    "sanear": "sa-ne-ar",
    "sanedrín": "sa-ne-drín",
    "sanfelipeña": "san-fe-li-pe-ña",
    "sanfelipeño": "san-fe-li-pe-ño",
    "sanfermines": "san-fer-mi-nes",
    "sanfernandina": "san-fer-nan-di-na",
    "sanfernandino": "san-fer-nan-di-no",
    "sanfrancia": "san-fran-cia",
    "sanfrancisco": "san-fran-cis-co",
    "sangacho": "san-ga-cho",
    "sangarro": "san-ga-rro",
    "sangermeña": "san-ger-me-ña",
    "sangermeño": "san-ger-me-ño",
    "sangley": "san-gley",
    "sango": "san-go",
    "sangonera": "san-go-ne-ra",
    "sangradera": "san-gra-de-ra",
    "sangrado": "san-gra-do",
    "sangrador": "san-gra-dor",
    "sangradura": "san-gra-du-ra",
    "sangrante": "san-gran-te",
    "sangrar": "san-grar",
    "sangraza": "san-gra-za",
    "sangre": "san-gre",
    "sangrecristo": "san-gre-cris-to",
    "sangredo": "san-gre-do",
    "sangregorda": "san-gre-gor-da",
    "sangrentar": "san-gren-tar",
    "sangrerío": "san-gre-rí-o",
    "sangrero": "san-gre-ro",
    "sangría": "san-grí-a",
    "sangricio": "san-gri-cio",
    "sangrienta": "san-grien-ta",
    "sangrientamente": "san-grien-ta-men-te",
    "sangriento": "san-grien-to",
    "sangriligera": "san-gri-li-ge-ra",
    "sangriligero": "san-gri-li-ge-ro",
    "sangripesada": "san-gri-pe-sa-da",
    "sangripesado": "san-gri-pe-sa-do",
    "sangrita": "san-gri-ta",
    "sangriza": "san-gri-za",
    "sangrón": "san-grón",
    "sangrona": "san-gro-na",
    "sangronería": "san-gro-ne-rí-a",
    "sanguaraña": "san-gua-ra-ña",
    "sanguaza": "san-gua-za",
    "sangüeño": "san-güe-ño",
    "sangüesa": "san-güe-sa",
    "sangüeso": "san-güe-so",
    "sanguífera": "san-guí-fe-ra",
    "sanguífero": "san-guí-fe-ro",
    "sanguificación": "san-gui-fi-ca-ción",
    "sanguificar": "san-gui-fi-car",
    "sanguijolera": "san-gui-jo-le-ra",
    "sanguijolero": "san-gui-jo-le-ro",
    "sanguijuela": "san-gui-jue-la",
    "sanguijuelera": "san-gui-jue-le-ra",
    "sanguijuelero": "san-gui-jue-le-ro",
    "sanguina": "san-gui-na",
    "sanguinaria": "san-gui-na-ria",
    "sanguinariamente": "san-gui-na-ria-men-te",
    "sanguinario": "san-gui-na-rio",
    "sanguínea": "san-guí-ne-a",
    "sanguíneo": "san-guí-ne-o",
    "sanguino": "san-gui-no",
    "sanguinolencia": "san-gui-no-len-cia",
    "sanguinolenta": "san-gui-no-len-ta",
    "sanguinolento": "san-gui-no-len-to",
    "sanguinosa": "san-gui-no-sa",
    "sanguinoso": "san-gui-no-so",
    "sanguiñuelo": "san-gui-ñue-lo",
    "sanguis": "san-guis",
    "sanguisorba": "san-gui-sor-ba",
    "sanguisuela": "san-gui-sue-la",
    "sanguja": "san-gu-ja",
    "sanícula": "sa-ní-cu-la",
    "sanidad": "sa-ni-dad",
    "sanidina": "sa-ni-di-na",
    "sanie": "sa-nie",
    "sanies": "sa-nies",
    "saniosa": "sa-nio-sa",
    "sanioso": "sa-nio-so",
    "sanitaria": "sa-ni-ta-ria",
    "sanitario": "sa-ni-ta-rio",
    "sanjacado": "san-ja-ca-do",
    "sanjacato": "san-ja-ca-to",
    "sanjaco": "san-ja-co",
    "sanjacobo": "san-ja-co-bo",
    "sanjar": "san-jar",
    "sanjuanada": "san-jua-na-da",
    "sanjuanear": "san-jua-ne-ar",
    "sanjuaneña": "san-jua-ne-ña",
    "sanjuaneño": "san-jua-ne-ño",
    "sanjuanera": "san-jua-ne-ra",
    "sanjuanero": "san-jua-ne-ro",
    "sanjuanina": "san-jua-ni-na",
    "sanjuanino": "san-jua-ni-no",
    "sanjuanista": "san-jua-nis-ta",
    "sanjuanito": "san-jua-ni-to",
    "sanlorenceña": "san-lo-ren-ce-ña",
    "sanlorenceño": "san-lo-ren-ce-ño",
    "sanlorencino": "san-lo-ren-ci-no",
    "sanlorenzana": "san-lo-ren-za-na",
    "sanlorenzano": "san-lo-ren-za-no",
    "sanlucareña": "san-lu-ca-re-ña",
    "sanlucareño": "san-lu-ca-re-ño",
    "sanluiseña": "san-lui-se-ña",
    "sanluiseño": "san-lui-se-ño",
    "sanluisera": "san-lui-se-ra",
    "sanluisero": "san-lui-se-ro",
    "sanluqueña": "san-lu-que-ña",
    "sanluqueño": "san-lu-que-ño",
    "sanmarinense": "san-ma-ri-nen-se",
    "sanmarqueña": "san-mar-que-ña",
    "sanmarqueño": "san-mar-que-ño",
    "sanmarquense": "san-mar-quen-se",
    "sanmartín": "san-mar-tín",
    "sanmartinense": "san-mar-ti-nen-se",
    "sanmartiniana": "san-mar-ti-nia-na",
    "sanmartiniano": "san-mar-ti-nia-no",
    "sanmiguelada": "san-mi-gue-la-da",
    "sanmigueleña": "san-mi-gue-le-ña",
    "sanmigueleño": "san-mi-gue-le-ño",
    "sano": "sa-no",
    "sañosa": "sa-ño-sa",
    "sañosamente": "sa-ño-sa-men-te",
    "sañoso": "sa-ño-so",
    "sanroqueña": "san-ro-que-ña",
    "sanroqueño": "san-ro-que-ño",
    "sansa": "san-sa",
    "sansalvadoreña": "san-sal-va-do-re-ña",
    "sansalvadoreño": "san-sal-va-do-re-ño",
    "sánscrita": "sáns-cri-ta",
    "sanscritista": "sans-cri-tis-ta",
    "sánscrito": "sáns-cri-to",
    "sanseacabó": "san-se-a-ca-bó",
    "sansimoniana": "san-si-mo-nia-na",
    "sansimoniano": "san-si-mo-nia-no",
    "sansimonismo": "san-si-mo-nis-mo",
    "sansirolé": "san-si-ro-lé",
    "sanso": "san-so",
    "sansón": "san-són",
    "santa": "san-ta",
    "santabárbara": "san-ta-bár-ba-ra",
    "santabarbarense": "san-ta-bar-ba-ren-se",
    "santaclareña": "san-ta-cla-re-ña",
    "santaclareño": "san-ta-cla-re-ño",
    "santacruceña": "san-ta-cru-ce-ña",
    "santacruceño": "san-ta-cru-ce-ño",
    "santacrucera": "san-ta-cru-ce-ra",
    "santacrucero": "san-ta-cru-ce-ro",
    "santaelenense": "san-ta-e-le-nen-se",
    "santafecina": "san-ta-fe-ci-na",
    "santafecino": "san-ta-fe-ci-no",
    "santafereña": "san-ta-fe-re-ña",
    "santafereño": "san-ta-fe-re-ño",
    "santafesina": "san-ta-fe-si-na",
    "santafesino": "san-ta-fe-si-no",
    "santalácea": "san-ta-lá-ce-a",
    "santaláceo": "san-ta-lá-ce-o",
    "santalucense": "san-ta-lu-cen-se",
    "santalucía": "san-ta-lu-cí-a",
    "santamente": "san-ta-men-te",
    "santandereana": "san-tan-de-re-a-na",
    "santandereano": "san-tan-de-re-a-no",
    "santanderiense": "san-tan-de-rien-se",
    "santanderina": "san-tan-de-ri-na",
    "santanderino": "san-tan-de-ri-no",
    "santaneca": "san-ta-ne-ca",
    "santaneco": "san-ta-ne-co",
    "santanita": "san-ta-ni-ta",
    "santarrita": "san-ta-rri-ta",
    "santarroseña": "san-ta-rro-se-ña",
    "santarroseño": "san-ta-rro-se-ño",
    "santarrosense": "san-ta-rro-sen-se",
    "santateresa": "san-ta-te-re-sa",
    "santelmo": "san-tel-mo",
    "santeña": "san-te-ña",
    "santeño": "san-te-ño",
    "santera": "san-te-ra",
    "santería": "san-te-rí-a",
    "santero": "san-te-ro",
    "santiago": "san-tia-go",
    "santiagueña": "san-tia-gue-ña",
    "santiagueño": "san-tia-gue-ño",
    "santiaguera": "san-tia-gue-ra",
    "santiaguero": "san-tia-gue-ro",
    "santiagués": "san-tia-gués",
    "santiaguesa": "san-tia-gue-sa",
    "santiaguina": "san-tia-gui-na",
    "santiaguino": "san-tia-gui-no",
    "santiaguista": "san-tia-guis-ta",
    "santiamén": "san-tia-mén",
    "santidad": "san-ti-dad",
    "santificable": "san-ti-fi-ca-ble",
    "santificación": "san-ti-fi-ca-ción",
    "santificador": "san-ti-fi-ca-dor",
    "santificadora": "san-ti-fi-ca-do-ra",
    "santificante": "san-ti-fi-can-te",
    "santificar": "san-ti-fi-car",
    "santificativa": "san-ti-fi-ca-ti-va",
    "santificativo": "san-ti-fi-ca-ti-vo",
    "santiguada": "san-ti-gua-da",
    "santiguadera": "san-ti-gua-de-ra",
    "santiguador": "san-ti-gua-dor",
    "santiguadora": "san-ti-gua-do-ra",
    "santiguamiento": "san-ti-gua-mien-to",
    "santiguar": "san-ti-guar",
    "santiguo": "san-ti-guo",
    "santimonia": "san-ti-mo-nia",
    "santiscario": "san-tis-ca-rio",
    "santísima": "san-tí-si-ma",
    "santísimo": "san-tí-si-mo",
    "santo": "san-to",
    "santol": "san-tol",
    "santolina": "san-to-li-na",
    "santolio": "san-to-lio",
    "santomense": "san-to-men-se",
    "santón": "san-tón",
    "santona": "san-to-na",
    "santoñés": "san-to-ñés",
    "santoñesa": "san-to-ñe-sa",
    "santónica": "san-tó-ni-ca",
    "santónico": "san-tó-ni-co",
    "santonina": "san-to-ni-na",
    "santoral": "san-to-ral",
    "santotomense": "san-to-to-men-se",
    "santrorrostro": "san-tro-rros-tro",
    "santuario": "san-tua-rio",
    "santucha": "san-tu-cha",
    "santucho": "san-tu-cho",
    "santulón": "san-tu-lón",
    "santulona": "san-tu-lo-na",
    "santulonada": "san-tu-lo-na-da",
    "santurrón": "san-tu-rrón",
    "santurrona": "san-tu-rro-na",
    "santurronería": "san-tu-rro-ne-rí-a",
    "sañuda": "sa-ñu-da",
    "sañudamente": "sa-ñu-da-men-te",
    "sañudo": "sa-ñu-do",
    "sanvicentina": "san-vi-cen-ti-na",
    "sanvicentino": "san-vi-cen-ti-no",
    "sao": "sa-o",
    "saó": "sa-ó",
    "sapa": "sa-pa",
    "sapada": "sa-pa-da",
    "sapallo": "sa-pa-llo",
    "sapaneco": "sa-pa-ne-co",
    "sapayolo": "sa-pa-yo-lo",
    "sapear": "sa-pe-ar",
    "sapeli": "sa-pe-li",
    "sapelli": "sa-pe-lli",
    "sapenco": "sa-pen-co",
    "sapera": "sa-pe-ra",
    "sápida": "sá-pi-da",
    "sapidez": "sa-pi-dez",
    "sápido": "sá-pi-do",
    "sapiencia": "sa-pien-cia",
    "sapiencial": "sa-pien-cial",
    "sapiente": "sa-pien-te",
    "sapientísimo": "sa-pien-tí-si-mo",
    "sapillo": "sa-pi-llo",
    "sapina": "sa-pi-na",
    "sapindácea": "sa-pin-dá-ce-a",
    "sapindáceo": "sa-pin-dá-ce-o",
    "sapino": "sa-pi-no",
    "sapirulo": "sa-pi-ru-lo",
    "sapito": "sa-pi-to",
    "sapluco": "sa-plu-co",
    "sapo": "sa-po",
    "sapobuche": "sa-po-bu-che",
    "sapón": "sa-pón",
    "sapona": "sa-po-na",
    "saponácea": "sa-po-ná-ce-a",
    "saponáceo": "sa-po-ná-ce-o",
    "saponaria": "sa-po-na-ria",
    "saponificable": "sa-po-ni-fi-ca-ble",
    "saponificación": "sa-po-ni-fi-ca-ción",
    "saponificar": "sa-po-ni-fi-car",
    "saponita": "sa-po-ni-ta",
    "saporífera": "sa-po-rí-fe-ra",
    "saporífero": "sa-po-rí-fe-ro",
    "saporreta": "sa-po-rre-ta",
    "saporreto": "sa-po-rre-to",
    "sapotácea": "sa-po-tá-ce-a",
    "sapotáceo": "sa-po-tá-ce-o",
    "sapote": "sa-po-te",
    "saprófago": "sa-pró-fa-go",
    "saprofita": "sa-pro-fi-ta",
    "saprofito": "sa-pro-fi-to",
    "sapropel": "sa-pro-pel",
    "saprozoico": "sa-pro-zoi-co",
    "saque": "sa-que",
    "saqueador": "sa-que-a-dor",
    "saqueadora": "sa-que-a-do-ra",
    "saqueamiento": "sa-que-a-mien-to",
    "saquear": "sa-que-ar",
    "saqueo": "sa-que-o",
    "saquera": "sa-que-ra",
    "saquería": "sa-que-rí-a",
    "saquerío": "sa-que-rí-o",
    "saquero": "sa-que-ro",
    "saquete": "sa-que-te",
    "saquilada": "sa-qui-la-da",
    "sarabaíta": "sa-ra-ba-í-ta",
    "saraguate": "sa-ra-gua-te",
    "saraguato": "sa-ra-gua-to",
    "saragüete": "sa-ra-güe-te",
    "sarama": "sa-ra-ma",
    "sarampión": "sa-ram-pión",
    "sarán": "sa-rán",
    "sarandí": "sa-ran-dí",
    "sarao": "sa-ra-o",
    "sarape": "sa-ra-pe",
    "sarapia": "sa-ra-pia",
    "sarapico": "sa-ra-pi-co",
    "sarasa": "sa-ra-sa",
    "saratano": "sa-ra-ta-no",
    "saraveado": "sa-ra-ve-a-do",
    "saraviada": "sa-ra-via-da",
    "saraviado": "sa-ra-via-do",
    "sarazo": "sa-ra-zo",
    "sarcasmo": "sar-cas-mo",
    "sarcástica": "sar-cás-ti-ca",
    "sarcásticamente": "sar-cás-ti-ca-men-te",
    "sarcástico": "sar-cás-ti-co",
    "sarcia": "sar-cia",
    "sarco": "sar-co",
    "sarcocarpio": "sar-co-car-pio",
    "sarcocele": "sar-co-ce-le",
    "sarcocola": "sar-co-co-la",
    "sarcófago": "sar-có-fa-go",
    "sarcolema": "sar-co-le-ma",
    "sarcoma": "sar-co-ma",
    "sarda": "sar-da",
    "sardana": "sar-da-na",
    "sardanés": "sar-da-nés",
    "sardanesa": "sar-da-ne-sa",
    "sardanista": "sar-da-nis-ta",
    "sarde": "sar-de",
    "sardesca": "sar-des-ca",
    "sardesco": "sar-des-co",
    "sardiana": "sar-dia-na",
    "sardiano": "sar-dia-no",
    "sardicense": "sar-di-cen-se",
    "sardina": "sar-di-na",
    "sardinada": "sar-di-na-da",
    "sardinal": "sar-di-nal",
    "sardinel": "sar-di-nel",
    "sardinera": "sar-di-ne-ra",
    "sardinero": "sar-di-ne-ro",
    "sardineta": "sar-di-ne-ta",
    "sardino": "sar-di-no",
    "sardio": "sar-dio",
    "sardo": "sar-do",
    "sardón": "sar-dón",
    "sardonal": "sar-do-nal",
    "sardonia": "sar-do-nia",
    "sardónica": "sar-dó-ni-ca",
    "sardónice": "sar-dó-ni-ce",
    "sardónico": "sar-dó-ni-co",
    "sardonio": "sar-do-nio",
    "sardónique": "sar-dó-ni-que",
    "sarga": "sar-ga",
    "sargada": "sar-ga-da",
    "sargadilla": "sar-ga-di-lla",
    "sargado": "sar-ga-do",
    "sargal": "sar-gal",
    "sargantana": "sar-gan-ta-na",
    "sargantesa": "sar-gan-te-sa",
    "sargatillo": "sar-ga-ti-llo",
    "sargazo": "sar-ga-zo",
    "sargenta": "sar-gen-ta",
    "sargente": "sar-gen-te",
    "sargentear": "sar-gen-te-ar",
    "sargentería": "sar-gen-te-rí-a",
    "sargentía": "sar-gen-tí-a",
    "sargento": "sar-gen-to",
    "sargentona": "sar-gen-to-na",
    "sargo": "sar-go",
    "sarguera": "sar-gue-ra",
    "sarguero": "sar-gue-ro",
    "sari": "sa-ri",
    "sariá": "sa-riá",
    "sariama": "sa-ria-ma",
    "sariga": "sa-ri-ga",
    "sarilla": "sa-ri-lla",
    "sarillo": "sa-ri-llo",
    "sármata": "sár-ma-ta",
    "sarmática": "sar-má-ti-ca",
    "sarmático": "sar-má-ti-co",
    "sarmentador": "sar-men-ta-dor",
    "sarmentadora": "sar-men-ta-do-ra",
    "sarmentar": "sar-men-tar",
    "sarmentazo": "sar-men-ta-zo",
    "sarmentera": "sar-men-te-ra",
    "sarmenticia": "sar-men-ti-cia",
    "sarmenticio": "sar-men-ti-cio",
    "sarmentosa": "sar-men-to-sa",
    "sarmentoso": "sar-men-to-so",
    "sarmiento": "sar-mien-to",
    "sarna": "sar-na",
    "sarnazo": "sar-na-zo",
    "sarniento": "sar-nien-to",
    "sarnilla": "sar-ni-lla",
    "sarnosa": "sar-no-sa",
    "sarnoso": "sar-no-so",
    "sarpullido": "sar-pu-lli-do",
    "sarpullir": "sar-pu-llir",
    "sarracear": "sa-rra-ce-ar",
    "sarracena": "sa-rra-ce-na",
    "sarraceniácea": "sa-rra-ce-niá-ce-a",
    "sarraceniáceas": "sa-rra-ce-niá-ce-as",
    "sarraceniáceo": "sa-rra-ce-niá-ce-o",
    "sarracénica": "sa-rra-cé-ni-ca",
    "sarracénico": "sa-rra-cé-ni-co",
    "sarraceno": "sa-rra-ce-no",
    "sarracín": "sa-rra-cín",
    "sarracina": "sa-rra-ci-na",
    "sarracino": "sa-rra-ci-no",
    "sarrajón": "sa-rra-jón",
    "sarrapia": "sa-rra-pia",
    "sarria": "sa-rria",
    "sarrieta": "sa-rrie-ta",
    "sarrillo": "sa-rri-llo",
    "sarrio": "sa-rrio",
    "sarro": "sa-rro",
    "sarrosa": "sa-rro-sa",
    "sarroso": "sa-rro-so",
    "sarruján": "sa-rru-ján",
    "sarta": "sar-ta",
    "sartal": "sar-tal",
    "sartén": "sar-tén",
    "sartenada": "sar-te-na-da",
    "sartenazo": "sar-te-na-zo",
    "sarteneja": "sar-te-ne-ja",
    "sartenejal": "sar-te-ne-jal",
    "sartenero": "sar-te-ne-ro",
    "sartorial": "sar-to-rial",
    "sartorio": "sar-to-rio",
    "sartriano": "sar-tria-no",
    "sarura": "sa-ru-ra",
    "sarza": "sar-za",
    "sarzo": "sar-zo",
    "sasacayan": "sa-sa-ca-yan",
    "sasafrás": "sa-sa-frás",
    "sasal": "sa-sal",
    "sasánida": "sa-sá-ni-da",
    "sasasa": "sa-sa-sa",
    "sastra": "sas-tra",
    "sastre": "sas-tre",
    "sastrería": "sas-tre-rí-a",
    "satán": "sa-tán",
    "satanás": "sa-ta-nás",
    "satandera": "sa-tan-de-ra",
    "satánica": "sa-tá-ni-ca",
    "satánico": "sa-tá-ni-co",
    "satanismo": "sa-ta-nis-mo",
    "satanización": "sa-ta-ni-za-ción",
    "satanizar": "sa-ta-ni-zar",
    "satelital": "sa-te-li-tal",
    "satélite": "sa-té-li-te",
    "satelización": "sa-te-li-za-ción",
    "satelizar": "sa-te-li-zar",
    "satén": "sa-tén",
    "satín": "sa-tín",
    "satinado": "sa-ti-na-do",
    "satinador": "sa-ti-na-dor",
    "satinadora": "sa-ti-na-do-ra",
    "satinar": "sa-ti-nar",
    "sátira": "sá-ti-ra",
    "satiriasis": "sa-ti-ria-sis",
    "satírica": "sa-tí-ri-ca",
    "satíricamente": "sa-tí-ri-ca-men-te",
    "satírico": "sa-tí-ri-co",
    "satirio": "sa-ti-rio",
    "satirión": "sa-ti-rión",
    "satirizante": "sa-ti-ri-zan-te",
    "satirizar": "sa-ti-ri-zar",
    "sátiro": "sá-ti-ro",
    "satis": "sa-tis",
    "satisdación": "sa-tis-da-ción",
    "satisfacción": "sa-tis-fac-ción",
    "satisfacer": "sa-tis-fa-cer",
    "satisfactoria": "sa-tis-fac-to-ria",
    "satisfactoriamente": "sa-tis-fac-to-ria-men-te",
    "satisfactorio": "sa-tis-fac-to-rio",
    "satisfecha": "sa-tis-fe-cha",
    "satisfecho": "sa-tis-fe-cho",
    "sativa": "sa-ti-va",
    "sativo": "sa-ti-vo",
    "sato": "sa-to",
    "sátrapa": "sá-tra-pa",
    "satrapía": "sa-tra-pí-a",
    "saturable": "sa-tu-ra-ble",
    "saturación": "sa-tu-ra-ción",
    "saturado": "sa-tu-ra-do",
    "saturar": "sa-tu-rar",
    "saturnal": "sa-tur-nal",
    "saturnia": "sa-tur-nia",
    "saturnina": "sa-tur-ni-na",
    "saturnino": "sa-tur-ni-no",
    "saturnio": "sa-tur-nio",
    "saturnismo": "sa-tur-nis-mo",
    "saturno": "sa-tur-no",
    "sauce": "sau-ce",
    "sauceda": "sau-ce-da",
    "saucedal": "sau-ce-dal",
    "saucegatillo": "sau-ce-ga-ti-llo",
    "saucera": "sau-ce-ra",
    "saucillo": "sau-ci-llo",
    "saúco": "sa-ú-co",
    "saudade": "sau-da-de",
    "saudí": "sau-dí",
    "saudoso": "sau-do-so",
    "sauna": "sau-na",
    "sauquillo": "sau-qui-llo",
    "saurio": "sau-rio",
    "sausería": "sau-se-rí-a",
    "sausier": "sau-sier",
    "sautor": "sau-tor",
    "sauzal": "sau-zal",
    "sauzgatillo": "sauz-ga-ti-llo",
    "savia": "sa-via",
    "saxafrax": "sa-xa-frax",
    "saxátil": "sa-xá-til",
    "sáxea": "sá-xe-a",
    "sáxeo": "sá-xe-o",
    "saxífraga": "sa-xí-fra-ga",
    "saxifragácea": "sa-xi-fra-gá-ce-a",
    "saxifragáceo": "sa-xi-fra-gá-ce-o",
    "saxifragia": "sa-xi-fra-gia",
    "saxo": "sa-xo",
    "saxofón": "sa-xo-fón",
    "saxofonista": "sa-xo-fo-nis-ta",
    "saxófono": "sa-xó-fo-no",
    "saxosa": "sa-xo-sa",
    "saxoso": "sa-xo-so",
    "saya": "sa-ya",
    "sayagués": "sa-ya-gués",
    "sayaguesa": "sa-ya-gue-sa",
    "sayal": "sa-yal",
    "sayalera": "sa-ya-le-ra",
    "sayalería": "sa-ya-le-rí-a",
    "sayalero": "sa-ya-le-ro",
    "sayalesca": "sa-ya-les-ca",
    "sayalesco": "sa-ya-les-co",
    "sayalete": "sa-ya-le-te",
    "sayama": "sa-ya-ma",
    "sayo": "sa-yo",
    "sayón": "sa-yón",
    "sayonaras": "sa-yo-na-ras",
    "sayuela": "sa-yue-la",
    "sayuelo": "sa-yue-lo",
    "sayugo": "sa-yu-go",
    "sayuguina": "sa-yu-gui-na",
    "sazón": "sa-zón",
    "sazonada": "sa-zo-na-da",
    "sazonadamente": "sa-zo-na-da-men-te",
    "sazonado": "sa-zo-na-do",
    "sazonador": "sa-zo-na-dor",
    "sazonadora": "sa-zo-na-do-ra",
    "sazonar": "sa-zo-nar",
    "scheelita": "s-che-e-li-ta",
    "scherzo": "s-cher-zo",
    "schnauzer": "sch-nau-zer",
    "seba": "se-ba",
    "sebácea": "se-bá-ce-a",
    "sebáceo": "se-bá-ce-o",
    "sebado": "se-ba-do",
    "sebastiano": "se-bas-tia-no",
    "sebe": "se-be",
    "sebestén": "se-bes-tén",
    "sebiche": "se-bi-che",
    "sebienta": "se-bien-ta",
    "sebiento": "se-bien-to",
    "sebillo": "se-bi-llo",
    "sebiya": "se-bi-ya",
    "sebo": "se-bo",
    "seboro": "se-bo-ro",
    "seborrea": "se-bo-rre-a",
    "seborreico": "se-bo-rrei-co",
    "seboruco": "se-bo-ru-co",
    "sebosa": "se-bo-sa",
    "seboso": "se-bo-so",
    "sebucán": "se-bu-cán",
    "sebuda": "se-bu-da",
    "sebudo": "se-bu-do",
    "seca": "se-ca",
    "secácul": "se-cá-cul",
    "secadal": "se-ca-dal",
    "secadera": "se-ca-de-ra",
    "secadero": "se-ca-de-ro",
    "secadía": "se-ca-dí-a",
    "secadillo": "se-ca-di-llo",
    "secadío": "se-ca-dí-o",
    "secado": "se-ca-do",
    "secador": "se-ca-dor",
    "secadora": "se-ca-do-ra",
    "secafirmas": "se-ca-fir-mas",
    "secaleche": "se-ca-le-che",
    "secamanos": "se-ca-ma-nos",
    "secamente": "se-ca-men-te",
    "secamiento": "se-ca-mien-to",
    "secano": "se-ca-no",
    "secansa": "se-can-sa",
    "secante": "se-can-te",
    "secapelos": "se-ca-pe-los",
    "secar": "se-car",
    "secaral": "se-ca-ral",
    "secarral": "se-ca-rral",
    "secarrón": "se-ca-rrón",
    "secarrona": "se-ca-rro-na",
    "secatón": "se-ca-tón",
    "secatona": "se-ca-to-na",
    "secatura": "se-ca-tu-ra",
    "sección": "sec-ción",
    "seccionador": "sec-cio-na-dor",
    "seccionar": "sec-cio-nar",
    "sece": "se-ce",
    "secena": "se-ce-na",
    "seceno": "se-ce-no",
    "secesión": "se-ce-sión",
    "secesionismo": "se-ce-sio-nis-mo",
    "secesionista": "se-ce-sio-nis-ta",
    "seceso": "se-ce-so",
    "sechurana": "se-chu-ra-na",
    "sechurano": "se-chu-ra-no",
    "seclusa": "se-clu-sa",
    "secluso": "se-clu-so",
    "seco": "se-co",
    "secón": "se-cón",
    "secoya": "se-co-ya",
    "secreción": "se-cre-ción",
    "secrestación": "se-cres-ta-ción",
    "secrestador": "se-cres-ta-dor",
    "secrestar": "se-cres-tar",
    "secresto": "se-cres-to",
    "secreta": "se-cre-ta",
    "secretamente": "se-cre-ta-men-te",
    "secretar": "se-cre-tar",
    "secretaría": "se-cre-ta-rí-a",
    "secretaria": "se-cre-ta-ria",
    "secretariado": "se-cre-ta-ria-do",
    "secretarial": "se-cre-ta-rial",
    "secretario": "se-cre-ta-rio",
    "secretear": "se-cre-te-ar",
    "secreteo": "se-cre-te-o",
    "secreter": "se-cre-ter",
    "secretismo": "se-cre-tis-mo",
    "secretista": "se-cre-tis-ta",
    "secreto": "se-cre-to",
    "secretor": "se-cre-tor",
    "secretora": "se-cre-to-ra",
    "secretoria": "se-cre-to-ria",
    "secretorio": "se-cre-to-rio",
    "secta": "sec-ta",
    "sectador": "sec-ta-dor",
    "sectadora": "sec-ta-do-ra",
    "sectaria": "sec-ta-ria",
    "sectario": "sec-ta-rio",
    "sectarismo": "sec-ta-ris-mo",
    "sector": "sec-tor",
    "sectorial": "sec-to-rial",
    "secua": "se-cua",
    "sécuana": "sé-cua-na",
    "sécuano": "sé-cua-no",
    "secuaz": "se-cuaz",
    "secuela": "se-cue-la",
    "secuencia": "se-cuen-cia",
    "secuenciación": "se-cuen-cia-ción",
    "secuenciador": "se-cuen-cia-dor",
    "secuencial": "se-cuen-cial",
    "secuenciar": "se-cuen-ciar",
    "secuestración": "se-cues-tra-ción",
    "secuestrador": "se-cues-tra-dor",
    "secuestradora": "se-cues-tra-do-ra",
    "secuestrar": "se-cues-trar",
    "secuestraria": "se-cues-tra-ria",
    "secuestrario": "se-cues-tra-rio",
    "secuestro": "se-cues-tro",
    "sécula": "sé-cu-la",
    "secular": "se-cu-lar",
    "secularidad": "se-cu-la-ri-dad",
    "secularización": "se-cu-la-ri-za-ción",
    "secularizado": "se-cu-la-ri-za-do",
    "secularizar": "se-cu-la-ri-zar",
    "secularmente": "se-cu-lar-men-te",
    "secundar": "se-cun-dar",
    "secundaria": "se-cun-da-ria",
    "secundariamente": "se-cun-da-ria-men-te",
    "secundario": "se-cun-da-rio",
    "secundinas": "se-cun-di-nas",
    "secundípara": "se-cun-dí-pa-ra",
    "secuoia": "se-cuoia",
    "secuoya": "se-cuo-ya",
    "secura": "se-cu-ra",
    "secutar": "se-cu-tar",
    "secutor": "se-cu-tor",
    "secutora": "se-cu-to-ra",
    "secutoria": "se-cu-to-ria",
    "seda": "se-da",
    "sedación": "se-da-ción",
    "sedadera": "se-da-de-ra",
    "sedal": "se-dal",
    "sedalina": "se-da-li-na",
    "sedán": "se-dán",
    "sedancia": "se-dan-cia",
    "sedante": "se-dan-te",
    "sedar": "se-dar",
    "sedativa": "se-da-ti-va",
    "sedativo": "se-da-ti-vo",
    "sede": "se-de",
    "sedear": "se-de-ar",
    "sedeña": "se-de-ña",
    "sedeño": "se-de-ño",
    "sedentaria": "se-den-ta-ria",
    "sedentario": "se-den-ta-rio",
    "sedentarismo": "se-den-ta-ris-mo",
    "sedentarización": "se-den-ta-ri-za-ción",
    "sedentarizar": "se-den-ta-ri-zar",
    "sedente": "se-den-te",
    "sedera": "se-de-ra",
    "sedería": "se-de-rí-a",
    "sedero": "se-de-ro",
    "sedicente": "se-di-cen-te",
    "sedición": "se-di-ción",
    "sediciosa": "se-di-cio-sa",
    "sediciosamente": "se-di-cio-sa-men-te",
    "sedicioso": "se-di-cio-so",
    "sedienta": "se-dien-ta",
    "sediente": "se-dien-te",
    "sediento": "se-dien-to",
    "sedimentación": "se-di-men-ta-ción",
    "sedimentar": "se-di-men-tar",
    "sedimentaria": "se-di-men-ta-ria",
    "sedimentario": "se-di-men-ta-rio",
    "sedimento": "se-di-men-to",
    "sedosa": "se-do-sa",
    "sedosidad": "se-do-si-dad",
    "sedoso": "se-do-so",
    "seducción": "se-duc-ción",
    "seducir": "se-du-cir",
    "seductiva": "se-duc-ti-va",
    "seductivo": "se-duc-ti-vo",
    "seductor": "se-duc-tor",
    "seductora": "se-duc-to-ra",
    "seer": "se-er",
    "sefardí": "se-far-dí",
    "sefardita": "se-far-di-ta",
    "sega": "se-ga",
    "segable": "se-ga-ble",
    "segada": "se-ga-da",
    "segadera": "se-ga-de-ra",
    "segadero": "se-ga-de-ro",
    "segador": "se-ga-dor",
    "segadora": "se-ga-do-ra",
    "segallo": "se-ga-llo",
    "segar": "se-gar",
    "segazón": "se-ga-zón",
    "seglar": "se-glar",
    "seglarmente": "se-glar-men-te",
    "segmentación": "seg-men-ta-ción",
    "segmentado": "seg-men-ta-do",
    "segmentar": "seg-men-tar",
    "segmentario": "seg-men-ta-rio",
    "segmento": "seg-men-to",
    "segobricense": "se-go-bri-cen-se",
    "segobrigense": "se-go-bri-gen-se",
    "segorbina": "se-gor-bi-na",
    "segorbino": "se-gor-bi-no",
    "segote": "se-go-te",
    "segoviana": "se-go-via-na",
    "segoviano": "se-go-via-no",
    "segoviense": "se-go-vien-se",
    "segregación": "se-gre-ga-ción",
    "segregacionismo": "se-gre-ga-cio-nis-mo",
    "segregacionista": "se-gre-ga-cio-nis-ta",
    "segregador": "se-gre-ga-dor",
    "segregar": "se-gre-gar",
    "segregativa": "se-gre-ga-ti-va",
    "segregativo": "se-gre-ga-ti-vo",
    "segrí": "se-grí",
    "segudar": "se-gu-dar",
    "segueta": "se-gue-ta",
    "seguetear": "se-gue-te-ar",
    "seguida": "se-gui-da",
    "seguidamente": "se-gui-da-men-te",
    "seguidero": "se-gui-de-ro",
    "seguidilla": "se-gui-di-lla",
    "seguidismo": "se-gui-dis-mo",
    "seguido": "se-gui-do",
    "seguidor": "se-gui-dor",
    "seguidora": "se-gui-do-ra",
    "seguimiento": "se-gui-mien-to",
    "seguir": "se-guir",
    "seguiriya": "se-gui-ri-ya",
    "según": "se-gún",
    "segunda": "se-gun-da",
    "segundamente": "se-gun-da-men-te",
    "segundar": "se-gun-dar",
    "segundaria": "se-gun-da-ria",
    "segundariamente": "se-gun-da-ria-men-te",
    "segundario": "se-gun-da-rio",
    "segundera": "se-gun-de-ra",
    "segundero": "se-gun-de-ro",
    "segundilla": "se-gun-di-lla",
    "segundillo": "se-gun-di-llo",
    "segundino": "se-gun-di-no",
    "segundo": "se-gun-do",
    "segundogénita": "se-gun-do-gé-ni-ta",
    "segundogénito": "se-gun-do-gé-ni-to",
    "segundogenitura": "se-gun-do-ge-ni-tu-ra",
    "segundón": "se-gun-dón",
    "segundona": "se-gun-do-na",
    "seguntina": "se-gun-ti-na",
    "seguntino": "se-gun-ti-no",
    "segur": "se-gur",
    "segura": "se-gu-ra",
    "segurador": "se-gu-ra-dor",
    "seguramente": "se-gu-ra-men-te",
    "seguramiento": "se-gu-ra-mien-to",
    "seguranza": "se-gu-ran-za",
    "segurar": "se-gu-rar",
    "segureja": "se-gu-re-ja",
    "seguridad": "se-gu-ri-dad",
    "seguro": "se-gu-ro",
    "seibana": "sei-ba-na",
    "seibano": "sei-ba-no",
    "seibó": "sei-bó",
    "seico": "sei-co",
    "seisava": "sei-sa-va",
    "seisavar": "sei-sa-var",
    "seisavo": "sei-sa-vo",
    "seiscientas": "seis-cien-tas",
    "seiscientos": "seis-cien-tos",
    "seise": "sei-se",
    "seisén": "sei-sén",
    "seisena": "sei-se-na",
    "seiseno": "sei-se-no",
    "seisillo": "sei-si-llo",
    "seísmo": "se-ís-mo",
    "seje": "se-je",
    "selacia": "se-la-cia",
    "selacio": "se-la-cio",
    "seladiz": "se-la-diz",
    "selección": "se-lec-ción",
    "seleccionado": "se-lec-cio-na-do",
    "seleccionador": "se-lec-cio-na-dor",
    "seleccionadora": "se-lec-cio-na-do-ra",
    "seleccionar": "se-lec-cio-nar",
    "seleccionismo": "se-lec-cio-nis-mo",
    "selecta": "se-lec-ta",
    "selectas": "se-lec-tas",
    "selectiva": "se-lec-ti-va",
    "selectividad": "se-lec-ti-vi-dad",
    "selectivo": "se-lec-ti-vo",
    "selecto": "se-lec-to",
    "selector": "se-lec-tor",
    "selénico": "se-lé-ni-co",
    "selenio": "se-le-nio",
    "selenita": "se-le-ni-ta",
    "selenitosa": "se-le-ni-to-sa",
    "selenitoso": "se-le-ni-to-so",
    "seleniuro": "se-le-niu-ro",
    "selenógrafa": "se-le-nó-gra-fa",
    "selenografía": "se-le-no-gra-fí-a",
    "selenógrafo": "se-le-nó-gra-fo",
    "selenosis": "se-le-no-sis",
    "seleque": "se-le-que",
    "seléucida": "se-léu-ci-da",
    "sellado": "se-lla-do",
    "sellador": "se-lla-dor",
    "selladora": "se-lla-do-ra",
    "selladura": "se-lla-du-ra",
    "sellar": "se-llar",
    "sello": "se-llo",
    "selva": "sel-va",
    "selvaje": "sel-va-je",
    "selvajina": "sel-va-ji-na",
    "selvajino": "sel-va-ji-no",
    "selvática": "sel-vá-ti-ca",
    "selvático": "sel-vá-ti-co",
    "selvatiquez": "sel-va-ti-quez",
    "selvicultura": "sel-vi-cul-tu-ra",
    "selvosa": "sel-vo-sa",
    "selvoso": "sel-vo-so",
    "selyúcida": "sel-yú-ci-da",
    "sema": "se-ma",
    "semafórica": "se-ma-fó-ri-ca",
    "semafórico": "se-ma-fó-ri-co",
    "semáforo": "se-má-fo-ro",
    "semana": "se-ma-na",
    "semanada": "se-ma-na-da",
    "semanal": "se-ma-nal",
    "semanalmente": "se-ma-nal-men-te",
    "semanaria": "se-ma-na-ria",
    "semanario": "se-ma-na-rio",
    "semanera": "se-ma-ne-ra",
    "semanería": "se-ma-ne-rí-a",
    "semanero": "se-ma-ne-ro",
    "semanilla": "se-ma-ni-lla",
    "semanista": "se-ma-nis-ta",
    "semantema": "se-man-te-ma",
    "semántica": "se-mán-ti-ca",
    "semántico": "se-mán-ti-co",
    "semantista": "se-man-tis-ta",
    "semasiología": "se-ma-sio-lo-gí-a",
    "semasiológica": "se-ma-sio-ló-gi-ca",
    "semasiológico": "se-ma-sio-ló-gi-co",
    "semblante": "sem-blan-te",
    "semblantear": "sem-blan-te-ar",
    "semblanza": "sem-blan-za",
    "semblar": "sem-blar",
    "semble": "sem-ble",
    "sembrada": "sem-bra-da",
    "sembradera": "sem-bra-de-ra",
    "sembradero": "sem-bra-de-ro",
    "sembradía": "sem-bra-dí-a",
    "sembradío": "sem-bra-dí-o",
    "sembrado": "sem-bra-do",
    "sembrador": "sem-bra-dor",
    "sembradora": "sem-bra-do-ra",
    "sembradura": "sem-bra-du-ra",
    "sembrar": "sem-brar",
    "sembrío": "sem-brí-o",
    "semeja": "se-me-ja",
    "semejable": "se-me-ja-ble",
    "semejablemente": "se-me-ja-ble-men-te",
    "semejada": "se-me-ja-da",
    "semejado": "se-me-ja-do",
    "semejante": "se-me-jan-te",
    "semejantemente": "se-me-jan-te-men-te",
    "semejanza": "se-me-jan-za",
    "semejar": "se-me-jar",
    "semema": "se-me-ma",
    "semen": "se-men",
    "semencera": "se-men-ce-ra",
    "semencontra": "se-men-con-tra",
    "semental": "se-men-tal",
    "sementar": "se-men-tar",
    "sementera": "se-men-te-ra",
    "sementero": "se-men-te-ro",
    "sementina": "se-men-ti-na",
    "sementino": "se-men-ti-no",
    "semestral": "se-mes-tral",
    "semestralmente": "se-mes-tral-men-te",
    "semestre": "se-mes-tre",
    "semi": "se-mi",
    "semiabierto": "se-mia-bier-to",
    "semianalfabeta": "se-mia-nal-fa-be-ta",
    "semianalfabeto": "se-mia-nal-fa-be-to",
    "semiautomático": "se-miau-to-má-ti-co",
    "semicabrón": "se-mi-ca-brón",
    "semicadencia": "se-mi-ca-den-cia",
    "semicapro": "se-mi-ca-pro",
    "semicilíndrica": "se-mi-ci-lín-dri-ca",
    "semicilíndrico": "se-mi-ci-lín-dri-co",
    "semicilindro": "se-mi-ci-lin-dro",
    "semicircular": "se-mi-cir-cu-lar",
    "semicírculo": "se-mi-cír-cu-lo",
    "semicircunferencia": "se-mi-cir-cun-fe-ren-cia",
    "semiconductor": "se-mi-con-duc-tor",
    "semiconsciente": "se-mi-cons-cien-te",
    "semiconserva": "se-mi-con-ser-va",
    "semiconsonante": "se-mi-con-so-nan-te",
    "semiconsonántico": "se-mi-con-so-nán-ti-co",
    "semicopada": "se-mi-co-pa-da",
    "semicopado": "se-mi-co-pa-do",
    "semicorchea": "se-mi-cor-che-a",
    "semicromática": "se-mi-cro-má-ti-ca",
    "semicromático": "se-mi-cro-má-ti-co",
    "semicultismo": "se-mi-cul-tis-mo",
    "semiculto": "se-mi-cul-to",
    "semicupio": "se-mi-cu-pio",
    "semicursivo": "se-mi-cur-si-vo",
    "semidea": "se-mi-de-a",
    "semideo": "se-mi-de-o",
    "semidescremado": "se-mi-des-cre-ma-do",
    "semidesértico": "se-mi-de-sér-ti-co",
    "semidesnatado": "se-mi-des-na-ta-do",
    "semidesnudo": "se-mi-des-nu-do",
    "semidiámetro": "se-mi-diá-me-tro",
    "semidifunta": "se-mi-di-fun-ta",
    "semidifunto": "se-mi-di-fun-to",
    "semidiós": "se-mi-diós",
    "semidiosa": "se-mi-dio-sa",
    "semidítono": "se-mi-dí-to-no",
    "semidoble": "se-mi-do-ble",
    "semidormida": "se-mi-dor-mi-da",
    "semidormido": "se-mi-dor-mi-do",
    "semidragón": "se-mi-dra-gón",
    "semieje": "se-mie-je",
    "semienterrado": "se-mien-te-rra-do",
    "semiesfera": "se-mies-fe-ra",
    "semiesférica": "se-mies-fé-ri-ca",
    "semiesférico": "se-mies-fé-ri-co",
    "semifinal": "se-mi-fi-nal",
    "semifinalista": "se-mi-fi-na-lis-ta",
    "semiflósculo": "se-mi-flós-cu-lo",
    "semiforme": "se-mi-for-me",
    "semifusa": "se-mi-fu-sa",
    "semigarrapatea": "se-mi-ga-rra-pa-te-a",
    "semigola": "se-mi-go-la",
    "semihilo": "se-mihi-lo",
    "semihombre": "se-mihom-bre",
    "semiinconsciencia": "se-miin-cons-cien-cia",
    "semiinconsciente": "se-miin-cons-cien-te",
    "semiínfero": "se-miín-fe-ro",
    "semilíquido": "se-mi-lí-qui-do",
    "semilla": "se-mi-lla",
    "semillar": "se-mi-llar",
    "semillazo": "se-mi-lla-zo",
    "semillero": "se-mi-lle-ro",
    "semilogarítmico": "se-mi-lo-ga-rít-mi-co",
    "semilunar": "se-mi-lu-nar",
    "semilunio": "se-mi-lu-nio",
    "semimetal": "se-mi-me-tal",
    "semimetálico": "se-mi-me-tá-li-co",
    "seminal": "se-mi-nal",
    "seminaria": "se-mi-na-ria",
    "seminario": "se-mi-na-rio",
    "seminarista": "se-mi-na-ris-ta",
    "seminífera": "se-mi-ní-fe-ra",
    "seminífero": "se-mi-ní-fe-ro",
    "semínima": "se-mí-ni-ma",
    "seminómada": "se-mi-nó-ma-da",
    "seminternado": "se-min-ter-na-do",
    "semióloga": "se-mió-lo-ga",
    "semiología": "se-mio-lo-gí-a",
    "semiológico": "se-mio-ló-gi-co",
    "semiólogo": "se-mió-lo-go",
    "semiotecnia": "se-mio-tec-nia",
    "semiótica": "se-mió-ti-ca",
    "semiótico": "se-mió-ti-co",
    "semiparásito": "se-mi-pa-rá-si-to",
    "semipedal": "se-mi-pe-dal",
    "semipelagiana": "se-mi-pe-la-gia-na",
    "semipelagianismo": "se-mi-pe-la-gia-nis-mo",
    "semipelagiano": "se-mi-pe-la-gia-no",
    "semiperíodo": "se-mi-pe-rí-o-do",
    "semiperiodo": "se-mi-pe-rio-do",
    "semipermeable": "se-mi-per-me-a-ble",
    "semipiso": "se-mi-pi-so",
    "semiplano": "se-mi-pla-no",
    "semiplena": "se-mi-ple-na",
    "semiplenamente": "se-mi-ple-na-men-te",
    "semiprecioso": "se-mi-pre-cio-so",
    "semiproducto": "se-mi-pro-duc-to",
    "semipúblico": "se-mi-pú-bli-co",
    "semirrecta": "se-mi-rrec-ta",
    "semirrecto": "se-mi-rrec-to",
    "semirrefinada": "se-mi-rre-fi-na-da",
    "semirrefinado": "se-mi-rre-fi-na-do",
    "semirrígido": "se-mi-rrí-gi-do",
    "semis": "se-mis",
    "semisalvaje": "se-mi-sal-va-je",
    "semisótano": "se-mi-só-ta-no",
    "semisuma": "se-mi-su-ma",
    "semita": "se-mi-ta",
    "semítica": "se-mí-ti-ca",
    "semítico": "se-mí-ti-co",
    "semitismo": "se-mi-tis-mo",
    "semitista": "se-mi-tis-ta",
    "semitono": "se-mi-to-no",
    "semitransparente": "se-mi-trans-pa-ren-te",
    "semitrasparente": "se-mi-tras-pa-ren-te",
    "semitrino": "se-mi-tri-no",
    "semivacío": "se-mi-va-cí-o",
    "semivida": "se-mi-vi-da",
    "semiviva": "se-mi-vi-va",
    "semivivo": "se-mi-vi-vo",
    "semivocal": "se-mi-vo-cal",
    "semivocálico": "se-mi-vo-cá-li-co",
    "sémola": "sé-mo-la",
    "semoviente": "se-mo-vien-te",
    "sempasúchil": "sem-pa-sú-chil",
    "sempervirente": "sem-per-vi-ren-te",
    "sempiterna": "sem-pi-ter-na",
    "sempiternamente": "sem-pi-ter-na-men-te",
    "sempiterno": "sem-pi-ter-no",
    "sena": "se-na",
    "seña": "se-ña",
    "senada": "se-na-da",
    "senado": "se-na-do",
    "senadoconsulto": "se-na-do-con-sul-to",
    "senador": "se-na-dor",
    "senadora": "se-na-do-ra",
    "senaduría": "se-na-du-rí-a",
    "señal": "se-ñal",
    "señalada": "se-ña-la-da",
    "señaladamente": "se-ña-la-da-men-te",
    "señalado": "se-ña-la-do",
    "señalamiento": "se-ña-la-mien-to",
    "señalar": "se-ña-lar",
    "señalero": "se-ña-le-ro",
    "señalización": "se-ña-li-za-ción",
    "señalizador": "se-ña-li-za-dor",
    "señalizar": "se-ña-li-zar",
    "senara": "se-na-ra",
    "senaria": "se-na-ria",
    "senario": "se-na-rio",
    "senatoria": "se-na-to-ria",
    "senatorial": "se-na-to-rial",
    "senatorio": "se-na-to-rio",
    "sencida": "sen-ci-da",
    "sencido": "sen-ci-do",
    "sencilla": "sen-ci-lla",
    "sencillamente": "sen-ci-lla-men-te",
    "sencillez": "sen-ci-llez",
    "sencillo": "sen-ci-llo",
    "senda": "sen-da",
    "sendas": "sen-das",
    "senderar": "sen-de-rar",
    "senderear": "sen-de-re-ar",
    "senderismo": "sen-de-ris-mo",
    "senderista": "sen-de-ris-ta",
    "sendero": "sen-de-ro",
    "senderuela": "sen-de-rue-la",
    "sendos": "sen-dos",
    "sene": "se-ne",
    "séneca": "sé-ne-ca",
    "senectud": "se-nec-tud",
    "senegalés": "se-ne-ga-lés",
    "senegalesa": "se-ne-ga-le-sa",
    "senequismo": "se-ne-quis-mo",
    "senequista": "se-ne-quis-ta",
    "señera": "se-ñe-ra",
    "señeramente": "se-ñe-ra-men-te",
    "señero": "se-ñe-ro",
    "senescal": "se-nes-cal",
    "senescalado": "se-nes-ca-la-do",
    "senescalía": "se-nes-ca-lí-a",
    "senescencia": "se-nes-cen-cia",
    "senescente": "se-nes-cen-te",
    "senesciente": "se-nes-cien-te",
    "senil": "se-nil",
    "senilidad": "se-ni-li-dad",
    "senior": "se-nior",
    "sénior": "sé-nior",
    "seno": "se-no",
    "senografía": "se-no-gra-fí-a",
    "senojil": "se-no-jil",
    "señolear": "se-ño-le-ar",
    "señor": "se-ñor",
    "señora": "se-ño-ra",
    "señorada": "se-ño-ra-da",
    "señoraje": "se-ño-ra-je",
    "señoreador": "se-ño-re-a-dor",
    "señoreadora": "se-ño-re-a-do-ra",
    "señoreaje": "se-ño-re-a-je",
    "señorear": "se-ño-re-ar",
    "señoría": "se-ño-rí-a",
    "señorial": "se-ño-rial",
    "señoril": "se-ño-ril",
    "señorilmente": "se-ño-ril-men-te",
    "señorío": "se-ño-rí-o",
    "señorita": "se-ño-ri-ta",
    "señoritinga": "se-ño-ri-tin-ga",
    "señoritingo": "se-ño-ri-tin-go",
    "señoritismo": "se-ño-ri-tis-mo",
    "señorito": "se-ño-ri-to",
    "señorón": "se-ño-rón",
    "señorona": "se-ño-ro-na",
    "sensación": "sen-sa-ción",
    "sensacional": "sen-sa-cio-nal",
    "sensacionalismo": "sen-sa-cio-na-lis-mo",
    "sensacionalista": "sen-sa-cio-na-lis-ta",
    "sensata": "sen-sa-ta",
    "sensatamente": "sen-sa-ta-men-te",
    "sensatez": "sen-sa-tez",
    "sensato": "sen-sa-to",
    "senserina": "sen-se-ri-na",
    "sensibilidad": "sen-si-bi-li-dad",
    "sensibilización": "sen-si-bi-li-za-ción",
    "sensibilizado": "sen-si-bi-li-za-do",
    "sensibilizador": "sen-si-bi-li-za-dor",
    "sensibilizar": "sen-si-bi-li-zar",
    "sensible": "sen-si-ble",
    "sensiblemente": "sen-si-ble-men-te",
    "sensiblera": "sen-si-ble-ra",
    "sensiblería": "sen-si-ble-rí-a",
    "sensiblero": "sen-si-ble-ro",
    "sensismo": "sen-sis-mo",
    "sensitiva": "sen-si-ti-va",
    "sensitivo": "sen-si-ti-vo",
    "sensomotor": "sen-so-mo-tor",
    "sensontle": "sen-son-tle",
    "sensor": "sen-sor",
    "sensoria": "sen-so-ria",
    "sensorial": "sen-so-rial",
    "sensorialidad": "sen-so-ria-li-dad",
    "sensorio": "sen-so-rio",
    "sensual": "sen-sual",
    "sensualidad": "sen-sua-li-dad",
    "sensualismo": "sen-sua-lis-mo",
    "sensualista": "sen-sua-lis-ta",
    "sensualmente": "sen-sual-men-te",
    "sensuntepecana": "sen-sun-te-pe-ca-na",
    "sensuntepecano": "sen-sun-te-pe-ca-no",
    "sentada": "sen-ta-da",
    "sentaderas": "sen-ta-de-ras",
    "sentadero": "sen-ta-de-ro",
    "sentadilla": "sen-ta-di-lla",
    "sentadillas": "sen-ta-di-llas",
    "sentado": "sen-ta-do",
    "sentador": "sen-ta-dor",
    "sentamiento": "sen-ta-mien-to",
    "sentar": "sen-tar",
    "sentencia": "sen-ten-cia",
    "sentenciador": "sen-ten-cia-dor",
    "sentenciadora": "sen-ten-cia-do-ra",
    "sentenciar": "sen-ten-ciar",
    "sentención": "sen-ten-ción",
    "sentenciosa": "sen-ten-cio-sa",
    "sentenciosamente": "sen-ten-cio-sa-men-te",
    "sentencioso": "sen-ten-cio-so",
    "sentible": "sen-ti-ble",
    "senticar": "sen-ti-car",
    "sentida": "sen-ti-da",
    "sentidamente": "sen-ti-da-men-te",
    "sentido": "sen-ti-do",
    "sentidor": "sen-ti-dor",
    "sentidora": "sen-ti-do-ra",
    "sentimental": "sen-ti-men-tal",
    "sentimentalidad": "sen-ti-men-ta-li-dad",
    "sentimentalismo": "sen-ti-men-ta-lis-mo",
    "sentimentalmente": "sen-ti-men-tal-men-te",
    "sentimentaloide": "sen-ti-men-ta-loi-de",
    "sentimiento": "sen-ti-mien-to",
    "sentina": "sen-ti-na",
    "sentir": "sen-tir",
    "sentón": "sen-tón",
    "señuelo": "se-ñue-lo",
    "senzonte": "sen-zon-te",
    "seo": "se-o",
    "seó": "se-ó",
    "seor": "se-or",
    "seora": "se-o-ra",
    "sépalo": "sé-pa-lo",
    "sepancuantos": "se-pan-cuan-tos",
    "separabilidad": "se-pa-ra-bi-li-dad",
    "separable": "se-pa-ra-ble",
    "separación": "se-pa-ra-ción",
    "separada": "se-pa-ra-da",
    "separadamente": "se-pa-ra-da-men-te",
    "separado": "se-pa-ra-do",
    "separador": "se-pa-ra-dor",
    "separadora": "se-pa-ra-do-ra",
    "separar": "se-pa-rar",
    "separata": "se-pa-ra-ta",
    "separatismo": "se-pa-ra-tis-mo",
    "separatista": "se-pa-ra-tis-ta",
    "separativa": "se-pa-ra-ti-va",
    "separativo": "se-pa-ra-ti-vo",
    "separo": "se-pa-ro",
    "sepe": "se-pe",
    "sepedón": "se-pe-dón",
    "sepelio": "se-pe-lio",
    "sepelir": "se-pe-lir",
    "sepia": "se-pia",
    "sepiolita": "se-pio-li-ta",
    "sepsis": "sep-sis",
    "septembrina": "sep-tem-bri-na",
    "septembrino": "sep-tem-bri-no",
    "septena": "sep-te-na",
    "septenaria": "sep-te-na-ria",
    "septenario": "sep-te-na-rio",
    "septenio": "sep-te-nio",
    "septeno": "sep-te-no",
    "septentrión": "sep-ten-trión",
    "septentrional": "sep-ten-trio-nal",
    "septeto": "sep-te-to",
    "séptica": "sép-ti-ca",
    "septicemia": "sep-ti-ce-mia",
    "septicémica": "sep-ti-cé-mi-ca",
    "septicémico": "sep-ti-cé-mi-co",
    "séptico": "sép-ti-co",
    "septiembre": "sep-tiem-bre",
    "septilliza": "sep-ti-lli-za",
    "septillizo": "sep-ti-lli-zo",
    "septillo": "sep-ti-llo",
    "séptima": "sép-ti-ma",
    "septimino": "sep-ti-mi-no",
    "séptimo": "sép-ti-mo",
    "septingentésima": "sep-tin-gen-té-si-ma",
    "septingentésimo": "sep-tin-gen-té-si-mo",
    "septisílaba": "sep-ti-sí-la-ba",
    "septisílabo": "sep-ti-sí-la-bo",
    "septo": "sep-to",
    "septuagenaria": "sep-tua-ge-na-ria",
    "septuagenario": "sep-tua-ge-na-rio",
    "septuagésima": "sep-tua-gé-si-ma",
    "septuagésimo": "sep-tua-gé-si-mo",
    "séptupla": "sép-tu-pla",
    "septuplicación": "sep-tu-pli-ca-ción",
    "septuplicar": "sep-tu-pli-car",
    "séptuplo": "sép-tu-plo",
    "sepulcral": "se-pul-cral",
    "sepulcro": "se-pul-cro",
    "sepulta": "se-pul-ta",
    "sepultación": "se-pul-ta-ción",
    "sepultador": "se-pul-ta-dor",
    "sepultadora": "se-pul-ta-do-ra",
    "sepultar": "se-pul-tar",
    "sepulto": "se-pul-to",
    "sepultura": "se-pul-tu-ra",
    "sepulturera": "se-pul-tu-re-ra",
    "sepulturero": "se-pul-tu-re-ro",
    "sequedad": "se-que-dad",
    "sequedal": "se-que-dal",
    "sequeral": "se-que-ral",
    "sequero": "se-que-ro",
    "sequerosa": "se-que-ro-sa",
    "sequeroso": "se-que-ro-so",
    "sequete": "se-que-te",
    "sequía": "se-quí-a",
    "sequillo": "se-qui-llo",
    "sequío": "se-quí-o",
    "séquito": "sé-qui-to",
    "sequiza": "se-qui-za",
    "sequizo": "se-qui-zo",
    "sequoia": "se-quoia",
    "sera": "se-ra",
    "serado": "se-ra-do",
    "seráfica": "se-rá-fi-ca",
    "seráficamente": "se-rá-fi-ca-men-te",
    "seráfico": "se-rá-fi-co",
    "serafín": "se-ra-fín",
    "serafina": "se-ra-fi-na",
    "seraje": "se-ra-je",
    "seranear": "se-ra-ne-ar",
    "serano": "se-ra-no",
    "serapino": "se-ra-pi-no",
    "serasquier": "se-ras-quier",
    "serba": "ser-ba",
    "serbal": "ser-bal",
    "serbia": "ser-bia",
    "serbio": "ser-bio",
    "serbo": "ser-bo",
    "serbocroata": "ser-bo-cro-a-ta",
    "sereguete": "se-re-gue-te",
    "serena": "se-re-na",
    "sereña": "se-re-ña",
    "serenar": "se-re-nar",
    "serenata": "se-re-na-ta",
    "serenatear": "se-re-na-te-ar",
    "serenazgo": "se-re-naz-go",
    "serenense": "se-re-nen-se",
    "serenero": "se-re-ne-ro",
    "serení": "se-re-ní",
    "serenidad": "se-re-ni-dad",
    "serenísima": "se-re-ní-si-ma",
    "serenísimo": "se-re-ní-si-mo",
    "sereno": "se-re-no",
    "seresere": "se-re-se-re",
    "serete": "se-re-te",
    "sergenta": "ser-gen-ta",
    "seria": "se-ria",
    "seriación": "se-ria-ción",
    "serial": "se-rial",
    "serialidad": "se-ria-li-dad",
    "serializar": "se-ria-li-zar",
    "seriamente": "se-ria-men-te",
    "seriar": "se-riar",
    "sérica": "sé-ri-ca",
    "sericícola": "se-ri-cí-co-la",
    "sericicultor": "se-ri-ci-cul-tor",
    "sericicultora": "se-ri-ci-cul-to-ra",
    "sericicultura": "se-ri-ci-cul-tu-ra",
    "sérico": "sé-ri-co",
    "sericultor": "se-ri-cul-tor",
    "sericultora": "se-ri-cul-to-ra",
    "sericultura": "se-ri-cul-tu-ra",
    "serie": "se-rie",
    "seriedad": "se-rie-dad",
    "serifia": "se-ri-fia",
    "serifio": "se-ri-fio",
    "serigrafía": "se-ri-gra-fí-a",
    "serigráfico": "se-ri-grá-fi-co",
    "serijo": "se-ri-jo",
    "serillo": "se-ri-llo",
    "seringa": "se-rin-ga",
    "serio": "se-rio",
    "sermocinal": "ser-mo-ci-nal",
    "sermón": "ser-món",
    "sermonar": "ser-mo-nar",
    "sermonaria": "ser-mo-na-ria",
    "sermonario": "ser-mo-na-rio",
    "sermoneador": "ser-mo-ne-a-dor",
    "sermoneadora": "ser-mo-ne-a-do-ra",
    "sermonear": "ser-mo-ne-ar",
    "sermoneo": "ser-mo-ne-o",
    "sermonero": "ser-mo-ne-ro",
    "serna": "ser-na",
    "serodiagnóstico": "se-ro-diag-nós-ti-co",
    "seroja": "se-ro-ja",
    "serojo": "se-ro-jo",
    "serología": "se-ro-lo-gí-a",
    "serológico": "se-ro-ló-gi-co",
    "serón": "se-rón",
    "seronda": "se-ron-da",
    "serondo": "se-ron-do",
    "seronegativa": "se-ro-ne-ga-ti-va",
    "seronegativo": "se-ro-ne-ga-ti-vo",
    "seronera": "se-ro-ne-ra",
    "seronero": "se-ro-ne-ro",
    "seropositiva": "se-ro-po-si-ti-va",
    "seropositivo": "se-ro-po-si-ti-vo",
    "serosa": "se-ro-sa",
    "serosidad": "se-ro-si-dad",
    "seroso": "se-ro-so",
    "seroterapia": "se-ro-te-ra-pia",
    "serótina": "se-ró-ti-na",
    "serótino": "se-ró-ti-no",
    "serotonina": "se-ro-to-ni-na",
    "serpa": "ser-pa",
    "serpear": "ser-pe-ar",
    "serpentaria": "ser-pen-ta-ria",
    "serpentario": "ser-pen-ta-rio",
    "serpenteada": "ser-pen-te-a-da",
    "serpenteado": "ser-pen-te-a-do",
    "serpenteante": "ser-pen-te-an-te",
    "serpentear": "ser-pen-te-ar",
    "serpenteo": "ser-pen-te-o",
    "serpentígera": "ser-pen-tí-ge-ra",
    "serpentígero": "ser-pen-tí-ge-ro",
    "serpentín": "ser-pen-tín",
    "serpentina": "ser-pen-ti-na",
    "serpentinamente": "ser-pen-ti-na-men-te",
    "serpentino": "ser-pen-ti-no",
    "serpentón": "ser-pen-tón",
    "serpiente": "ser-pien-te",
    "serpiginosa": "ser-pi-gi-no-sa",
    "serpiginoso": "ser-pi-gi-no-so",
    "serpigo": "ser-pi-go",
    "serpol": "ser-pol",
    "serpollar": "ser-po-llar",
    "serpollo": "ser-po-llo",
    "serrada": "se-rra-da",
    "serradiza": "se-rra-di-za",
    "serradizo": "se-rra-di-zo",
    "serrado": "se-rra-do",
    "serrador": "se-rra-dor",
    "serradora": "se-rra-do-ra",
    "serraduras": "se-rra-du-ras",
    "serragatina": "se-rra-ga-ti-na",
    "serragatino": "se-rra-ga-ti-no",
    "serraja": "se-rra-ja",
    "serrallo": "se-rra-llo",
    "serrana": "se-rra-na",
    "serranía": "se-rra-ní-a",
    "serraniega": "se-rra-nie-ga",
    "serraniego": "se-rra-nie-go",
    "serranil": "se-rra-nil",
    "serranilla": "se-rra-ni-lla",
    "serrano": "se-rra-no",
    "serrar": "se-rrar",
    "serrasuelo": "se-rra-sue-lo",
    "serrátil": "se-rrá-til",
    "serrato": "se-rra-to",
    "serrería": "se-rre-rí-a",
    "serreta": "se-rre-ta",
    "serretazo": "se-rre-ta-zo",
    "serrezuela": "se-rre-zue-la",
    "serrijón": "se-rri-jón",
    "serrín": "se-rrín",
    "serrina": "se-rri-na",
    "serrino": "se-rri-no",
    "serrón": "se-rrón",
    "serrote": "se-rro-te",
    "serrucha": "se-rru-cha",
    "serruchar": "se-rru-char",
    "serrucho": "se-rru-cho",
    "seruenda": "se-ruen-da",
    "seruendo": "se-ruen-do",
    "servador": "ser-va-dor",
    "serval": "ser-val",
    "servar": "ser-var",
    "servato": "ser-va-to",
    "serventesio": "ser-ven-te-sio",
    "serventía": "ser-ven-tí-a",
    "servia": "ser-via",
    "servible": "ser-vi-ble",
    "serviciador": "ser-vi-cia-dor",
    "servicial": "ser-vi-cial",
    "servicialmente": "ser-vi-cial-men-te",
    "serviciar": "ser-vi-ciar",
    "servicio": "ser-vi-cio",
    "servidera": "ser-vi-de-ra",
    "servidero": "ser-vi-de-ro",
    "servidor": "ser-vi-dor",
    "servidora": "ser-vi-do-ra",
    "servidumbre": "ser-vi-dum-bre",
    "servil": "ser-vil",
    "servilismo": "ser-vi-lis-mo",
    "servilla": "ser-vi-lla",
    "servilleta": "ser-vi-lle-ta",
    "servilletera": "ser-vi-lle-te-ra",
    "servilletero": "ser-vi-lle-te-ro",
    "servilmente": "ser-vil-men-te",
    "servilón": "ser-vi-lón",
    "servio": "ser-vio",
    "serviola": "ser-vio-la",
    "servir": "ser-vir",
    "servita": "ser-vi-ta",
    "servitud": "ser-vi-tud",
    "servo": "ser-vo",
    "servocroata": "ser-vo-cro-a-ta",
    "servodirección": "ser-vo-di-rec-ción",
    "servofreno": "ser-vo-fre-no",
    "servomecanismo": "ser-vo-me-ca-nis-mo",
    "servomotor": "ser-vo-mo-tor",
    "sesada": "se-sa-da",
    "sesámea": "se-sá-me-a",
    "sesámeo": "se-sá-me-o",
    "sésamo": "sé-sa-mo",
    "sesamoidea": "se-sa-moi-de-a",
    "sesamoideo": "se-sa-moi-de-o",
    "sescuncia": "ses-cun-cia",
    "seseante": "se-se-an-te",
    "sesear": "se-se-ar",
    "sesén": "se-sén",
    "sesena": "se-se-na",
    "sesenta": "se-sen-ta",
    "sesentava": "se-sen-ta-va",
    "sesentavo": "se-sen-ta-vo",
    "sesentén": "se-sen-tén",
    "sesentón": "se-sen-tón",
    "sesentona": "se-sen-to-na",
    "seseo": "se-se-o",
    "sesera": "se-se-ra",
    "sesereque": "se-se-re-que",
    "sesga": "ses-ga",
    "sesgada": "ses-ga-da",
    "sesgadamente": "ses-ga-da-men-te",
    "sesgado": "ses-ga-do",
    "sesgadura": "ses-ga-du-ra",
    "sesgamente": "ses-ga-men-te",
    "sesgar": "ses-gar",
    "sesgo": "ses-go",
    "sesí": "se-sí",
    "sésil": "sé-sil",
    "sesión": "se-sión",
    "sesionar": "se-sio-nar",
    "sesma": "ses-ma",
    "sesmero": "ses-me-ro",
    "sesmo": "ses-mo",
    "seso": "se-so",
    "sesqui": "ses-qui",
    "sesquiáltera": "ses-quiál-te-ra",
    "sesquiáltero": "ses-quiál-te-ro",
    "sesquicentenario": "ses-qui-cen-te-na-rio",
    "sesquimodio": "ses-qui-mo-dio",
    "sesquióxido": "ses-quió-xi-do",
    "sesquipedal": "ses-qui-pe-dal",
    "sesquiplano": "ses-qui-pla-no",
    "sestar": "ses-tar",
    "sesteadero": "ses-te-a-de-ro",
    "sestear": "ses-te-ar",
    "sesteo": "ses-te-o",
    "sestercio": "ses-ter-cio",
    "sestero": "ses-te-ro",
    "sestil": "ses-til",
    "sesuda": "se-su-da",
    "sesudamente": "se-su-da-men-te",
    "sesudez": "se-su-dez",
    "sesudo": "se-su-do",
    "seta": "se-ta",
    "setabense": "se-ta-ben-se",
    "setabitana": "se-ta-bi-ta-na",
    "setabitano": "se-ta-bi-ta-no",
    "setal": "se-tal",
    "sete": "se-te",
    "setecientas": "se-te-cien-tas",
    "setecientos": "se-te-cien-tos",
    "setena": "se-te-na",
    "setenada": "se-te-na-da",
    "setenado": "se-te-na-do",
    "setenar": "se-te-nar",
    "setenario": "se-te-na-rio",
    "seteno": "se-te-no",
    "setenta": "se-ten-ta",
    "setentava": "se-ten-ta-va",
    "setentavo": "se-ten-ta-vo",
    "setentón": "se-ten-tón",
    "setentona": "se-ten-to-na",
    "setero": "se-te-ro",
    "setico": "se-ti-co",
    "setiembre": "se-tiem-bre",
    "sétima": "sé-ti-ma",
    "sétimo": "sé-ti-mo",
    "seto": "se-to",
    "setuní": "se-tu-ní",
    "setura": "se-tu-ra",
    "seudo": "seu-do",
    "seudocientífico": "seu-do-cien-tí-fi-co",
    "seudohermafrodita": "seu-do-her-ma-fro-di-ta",
    "seudohermafroditismo": "seu-do-her-ma-fro-di-tis-mo",
    "seudología": "seu-do-lo-gí-a",
    "seudónima": "seu-dó-ni-ma",
    "seudónimo": "seu-dó-ni-mo",
    "seudópodo": "seu-dó-po-do",
    "severa": "se-ve-ra",
    "severamente": "se-ve-ra-men-te",
    "severidad": "se-ve-ri-dad",
    "severo": "se-ve-ro",
    "seviche": "se-vi-che",
    "sevicia": "se-vi-cia",
    "sevillana": "se-vi-lla-na",
    "sevillanas": "se-vi-lla-nas",
    "sevillano": "se-vi-lla-no",
    "séviro": "sé-vi-ro",
    "sexado": "se-xa-do",
    "sexador": "se-xa-dor",
    "sexadora": "se-xa-do-ra",
    "sexagenaria": "se-xa-ge-na-ria",
    "sexagenario": "se-xa-ge-na-rio",
    "sexagésima": "se-xa-gé-si-ma",
    "sexagesimal": "se-xa-ge-si-mal",
    "sexagésimo": "se-xa-gé-si-mo",
    "sexagonal": "se-xa-go-nal",
    "sexángula": "se-xán-gu-la",
    "sexángulo": "se-xán-gu-lo",
    "sexar": "se-xar",
    "sexcentésima": "sex-cen-té-si-ma",
    "sexcentésimo": "sex-cen-té-si-mo",
    "sexenal": "se-xe-nal",
    "sexenio": "se-xe-nio",
    "sexi": "se-xi",
    "sexismo": "se-xis-mo",
    "sexista": "se-xis-ta",
    "sexma": "sex-ma",
    "sexmero": "sex-me-ro",
    "sexmo": "sex-mo",
    "sexo": "se-xo",
    "sexóloga": "se-xó-lo-ga",
    "sexología": "se-xo-lo-gí-a",
    "sexológico": "se-xo-ló-gi-co",
    "sexólogo": "se-xó-lo-go",
    "sexta": "sex-ta",
    "sextaferia": "sex-ta-fe-ria",
    "sextantaria": "sex-tan-ta-ria",
    "sextantario": "sex-tan-ta-rio",
    "sextante": "sex-tan-te",
    "sextario": "sex-ta-rio",
    "sextavada": "sex-ta-va-da",
    "sextavado": "sex-ta-va-do",
    "sextavar": "sex-ta-var",
    "sexteto": "sex-te-to",
    "sextil": "sex-til",
    "sextilla": "sex-ti-lla",
    "sextilliza": "sex-ti-lli-za",
    "sextillizo": "sex-ti-lli-zo",
    "sextillo": "sex-ti-llo",
    "sextina": "sex-ti-na",
    "sexto": "sex-to",
    "séxtula": "séx-tu-la",
    "séxtupla": "séx-tu-pla",
    "sextuplicación": "sex-tu-pli-ca-ción",
    "sextuplicar": "sex-tu-pli-car",
    "séxtuplo": "séx-tu-plo",
    "sexuada": "se-xua-da",
    "sexuado": "se-xua-do",
    "sexual": "se-xual",
    "sexualidad": "se-xua-li-dad",
    "sexualización": "se-xua-li-za-ción",
    "sexualizar": "se-xua-li-zar",
    "sexualmente": "se-xual-men-te",
    "seychellense": "sey-che-llen-se",
    "shakesperiano": "sha-kes-pe-ria-no",
    "shapra": "sha-pra",
    "shaurire": "shau-ri-re",
    "shekel": "she-kel",
    "sherpa": "sher-pa",
    "shute": "shu-te",
    "sialismo": "sia-lis-mo",
    "sialorrea": "sia-lo-rre-a",
    "siamés": "sia-més",
    "siamesa": "sia-me-sa",
    "sibarita": "si-ba-ri-ta",
    "sibarítica": "si-ba-rí-ti-ca",
    "sibarítico": "si-ba-rí-ti-co",
    "sibaritismo": "si-ba-ri-tis-mo",
    "siberiana": "si-be-ria-na",
    "siberiano": "si-be-ria-no",
    "sibil": "si-bil",
    "sibila": "si-bi-la",
    "sibilante": "si-bi-lan-te",
    "sibilina": "si-bi-li-na",
    "sibilino": "si-bi-li-no",
    "sibilítica": "si-bi-lí-ti-ca",
    "sibilítico": "si-bi-lí-ti-co",
    "siboney": "si-bo-ney",
    "sicalipsis": "si-ca-lip-sis",
    "sicalíptico": "si-ca-líp-ti-co",
    "sicambra": "si-cam-bra",
    "sicambro": "si-cam-bro",
    "sicamor": "si-ca-mor",
    "sicana": "si-ca-na",
    "sicano": "si-ca-no",
    "sicario": "si-ca-rio",
    "siciliana": "si-ci-lia-na",
    "siciliano": "si-ci-lia-no",
    "sicionia": "si-cio-nia",
    "sicionio": "si-cio-nio",
    "siclo": "si-clo",
    "sicoactivo": "si-co-ac-ti-vo",
    "sicoanálisis": "si-co-a-ná-li-sis",
    "sicoanalítico": "si-co-a-na-lí-ti-co",
    "sicodélico": "si-co-dé-li-co",
    "sicofanta": "si-co-fan-ta",
    "sicofante": "si-co-fan-te",
    "sicofísica": "si-co-fí-si-ca",
    "sicofísico": "si-co-fí-si-co",
    "sicogénico": "si-co-gé-ni-co",
    "sicógeno": "si-có-ge-no",
    "sicolingüístico": "si-co-lin-güís-ti-co",
    "sicóloga": "si-có-lo-ga",
    "sicología": "si-co-lo-gí-a",
    "sicológica": "si-co-ló-gi-ca",
    "sicológico": "si-co-ló-gi-co",
    "sicólogo": "si-có-lo-go",
    "sicomoro": "si-co-mo-ro",
    "sicómoro": "si-có-mo-ro",
    "sicono": "si-co-no",
    "sicópata": "si-có-pa-ta",
    "sicopatía": "si-co-pa-tí-a",
    "sicopática": "si-co-pá-ti-ca",
    "sicopático": "si-co-pá-ti-co",
    "sicopatológico": "si-co-pa-to-ló-gi-co",
    "sicopedagoga": "si-co-pe-da-go-ga",
    "sicopedagogo": "si-co-pe-da-go-go",
    "sicosis": "si-co-sis",
    "sicosomático": "si-co-so-má-ti-co",
    "sicote": "si-co-te",
    "sicotécnico": "si-co-téc-ni-co",
    "sicoterapéutico": "si-co-te-ra-péu-ti-co",
    "sicoterapia": "si-co-te-ra-pia",
    "sicótica": "si-có-ti-ca",
    "sicótico": "si-có-ti-co",
    "sicotrópico": "si-co-tró-pi-co",
    "sicótropo": "si-có-tro-po",
    "sicrómetro": "si-cró-me-tro",
    "sicu": "si-cu",
    "sícula": "sí-cu-la",
    "sículo": "sí-cu-lo",
    "sicuri": "si-cu-ri",
    "sida": "si-da",
    "sidafobia": "si-da-fo-bia",
    "sidecar": "si-de-car",
    "sideral": "si-de-ral",
    "sidérea": "si-dé-re-a",
    "sidéreo": "si-dé-re-o",
    "siderita": "si-de-ri-ta",
    "siderometalúrgico": "si-de-ro-me-ta-lúr-gi-co",
    "siderosa": "si-de-ro-sa",
    "siderosis": "si-de-ro-sis",
    "siderurgia": "si-de-rur-gia",
    "siderúrgica": "si-de-rúr-gi-ca",
    "siderúrgico": "si-de-rúr-gi-co",
    "sidonia": "si-do-nia",
    "sidonio": "si-do-nio",
    "sidosa": "si-do-sa",
    "sidoso": "si-do-so",
    "sidra": "si-dra",
    "sidrera": "si-dre-ra",
    "sidrería": "si-dre-rí-a",
    "sidrero": "si-dre-ro",
    "sidrificación": "si-dri-fi-ca-ción",
    "siega": "sie-ga",
    "siembra": "siem-bra",
    "siembro": "siem-bro",
    "siemens": "sie-mens",
    "siemensio": "sie-men-sio",
    "siempre": "siem-pre",
    "siempretieso": "siem-pre-tie-so",
    "siempreviva": "siem-pre-vi-va",
    "siena": "sie-na",
    "sienés": "sie-nés",
    "sienesa": "sie-ne-sa",
    "sienita": "sie-ni-ta",
    "sierpa": "sier-pa",
    "sierpe": "sier-pe",
    "sierra": "sie-rra",
    "sierraleonés": "sie-rra-le-o-nés",
    "sierraleonesa": "sie-rra-le-o-ne-sa",
    "sierro": "sie-rro",
    "sierva": "sier-va",
    "siervo": "sier-vo",
    "sieso": "sie-so",
    "siesta": "sies-ta",
    "siete": "sie-te",
    "sietecallero": "sie-te-ca-lle-ro",
    "sietecolores": "sie-te-co-lo-res",
    "sietecueros": "sie-te-cue-ros",
    "sieteenrama": "sie-te-en-ra-ma",
    "sietelevar": "sie-te-le-var",
    "sietemesina": "sie-te-me-si-na",
    "sietemesino": "sie-te-me-si-no",
    "sieteñal": "sie-te-ñal",
    "sietenrama": "sie-ten-ra-ma",
    "sietepellejos": "sie-te-pe-lle-jos",
    "sietesangrías": "sie-te-san-grí-as",
    "sietillo": "sie-ti-llo",
    "sievert": "sie-vert",
    "sifilazo": "si-fi-la-zo",
    "sifilicomio": "si-fi-li-co-mio",
    "sifílide": "si-fí-li-de",
    "sífilis": "sí-fi-lis",
    "sifilítica": "si-fi-lí-ti-ca",
    "sifilítico": "si-fi-lí-ti-co",
    "sifilógrafa": "si-fi-ló-gra-fa",
    "sifilografía": "si-fi-lo-gra-fí-a",
    "sifilográfica": "si-fi-lo-grá-fi-ca",
    "sifilográfico": "si-fi-lo-grá-fi-co",
    "sifilógrafo": "si-fi-ló-gra-fo",
    "sifiloma": "si-fi-lo-ma",
    "sifón": "si-fón",
    "sifonáptero": "si-fo-náp-te-ro",
    "sifonero": "si-fo-ne-ro",
    "sifosis": "si-fo-sis",
    "sifué": "si-fué",
    "sigatoga": "si-ga-to-ga",
    "sigatoka": "si-ga-to-ka",
    "sigilación": "si-gi-la-ción",
    "sigilar": "si-gi-lar",
    "sigilo": "si-gi-lo",
    "sigilografía": "si-gi-lo-gra-fí-a",
    "sigilosa": "si-gi-lo-sa",
    "sigilosamente": "si-gi-lo-sa-men-te",
    "sigiloso": "si-gi-lo-so",
    "sigla": "si-gla",
    "siglalón": "si-gla-lón",
    "siglario": "si-gla-rio",
    "siglo": "si-glo",
    "sigma": "sig-ma",
    "sigmoidea": "sig-moi-de-a",
    "sigmoideo": "sig-moi-de-o",
    "signáculo": "sig-ná-cu-lo",
    "signar": "sig-nar",
    "signataria": "sig-na-ta-ria",
    "signatario": "sig-na-ta-rio",
    "signatura": "sig-na-tu-ra",
    "sígnico": "síg-ni-co",
    "signífera": "sig-ní-fe-ra",
    "signífero": "sig-ní-fe-ro",
    "significación": "sig-ni-fi-ca-ción",
    "significada": "sig-ni-fi-ca-da",
    "significado": "sig-ni-fi-ca-do",
    "significador": "sig-ni-fi-ca-dor",
    "significadora": "sig-ni-fi-ca-do-ra",
    "significante": "sig-ni-fi-can-te",
    "significar": "sig-ni-fi-car",
    "significativa": "sig-ni-fi-ca-ti-va",
    "significativamente": "sig-ni-fi-ca-ti-va-men-te",
    "significatividad": "sig-ni-fi-ca-ti-vi-dad",
    "significativo": "sig-ni-fi-ca-ti-vo",
    "signo": "sig-no",
    "sigua": "si-gua",
    "siguabana": "si-gua-ba-na",
    "sigualepa": "si-gua-le-pa",
    "siguampero": "si-guam-pe-ro",
    "siguanaba": "si-gua-na-ba",
    "siguapa": "si-gua-pa",
    "siguemepollo": "si-gue-me-po-llo",
    "siguiente": "si-guien-te",
    "siguiriya": "si-gui-ri-ya",
    "sijismo": "si-jis-mo",
    "sijú": "si-jú",
    "sílaba": "sí-la-ba",
    "silabación": "si-la-ba-ción",
    "silabar": "si-la-bar",
    "silabario": "si-la-ba-rio",
    "silabear": "si-la-be-ar",
    "silabeo": "si-la-be-o",
    "silábica": "si-lá-bi-ca",
    "silábico": "si-lá-bi-co",
    "silabizar": "si-la-bi-zar",
    "sílabo": "sí-la-bo",
    "silampa": "si-lam-pa",
    "silanga": "si-lan-ga",
    "silba": "sil-ba",
    "silbada": "sil-ba-da",
    "silbador": "sil-ba-dor",
    "silbadora": "sil-ba-do-ra",
    "silbante": "sil-ban-te",
    "silbar": "sil-bar",
    "silbatina": "sil-ba-ti-na",
    "silbato": "sil-ba-to",
    "silbido": "sil-bi-do",
    "silbín": "sil-bín",
    "silbo": "sil-bo",
    "silbón": "sil-bón",
    "silbosa": "sil-bo-sa",
    "silboso": "sil-bo-so",
    "silenciador": "si-len-cia-dor",
    "silenciamiento": "si-len-cia-mien-to",
    "silenciar": "si-len-ciar",
    "silenciaria": "si-len-cia-ria",
    "silenciario": "si-len-cia-rio",
    "silenciera": "si-len-cie-ra",
    "silenciero": "si-len-cie-ro",
    "silencio": "si-len-cio",
    "silenciosa": "si-len-cio-sa",
    "silenciosamente": "si-len-cio-sa-men-te",
    "silencioso": "si-len-cio-so",
    "silense": "si-len-se",
    "silente": "si-len-te",
    "silepsis": "si-lep-sis",
    "silería": "si-le-rí-a",
    "silero": "si-le-ro",
    "silesia": "si-le-sia",
    "silesiana": "si-le-sia-na",
    "silesiano": "si-le-sia-no",
    "silesio": "si-le-sio",
    "sílex": "sí-lex",
    "sílfide": "síl-fi-de",
    "silfo": "sil-fo",
    "silga": "sil-ga",
    "silgado": "sil-ga-do",
    "silgar": "sil-gar",
    "silguero": "sil-gue-ro",
    "silicato": "si-li-ca-to",
    "sílice": "sí-li-ce",
    "silícea": "si-lí-ce-a",
    "silíceo": "si-lí-ce-o",
    "silícica": "si-lí-ci-ca",
    "silícico": "si-lí-ci-co",
    "silicio": "si-li-cio",
    "silicona": "si-li-co-na",
    "silicosis": "si-li-co-sis",
    "silicótica": "si-li-có-ti-ca",
    "silicótico": "si-li-có-ti-co",
    "silicua": "si-li-cua",
    "silícula": "si-lí-cu-la",
    "silinga": "si-lin-ga",
    "silingo": "si-lin-go",
    "silla": "si-lla",
    "sillada": "si-lla-da",
    "sillar": "si-llar",
    "sillarejo": "si-lla-re-jo",
    "sillera": "si-lle-ra",
    "sillería": "si-lle-rí-a",
    "sillero": "si-lle-ro",
    "silleta": "si-lle-ta",
    "silletazo": "si-lle-ta-zo",
    "sillete": "si-lle-te",
    "silletero": "si-lle-te-ro",
    "silletín": "si-lle-tín",
    "sillico": "si-lli-co",
    "sillín": "si-llín",
    "sillón": "si-llón",
    "silo": "si-lo",
    "silogismo": "si-lo-gis-mo",
    "silogística": "si-lo-gís-ti-ca",
    "silogístico": "si-lo-gís-ti-co",
    "silogizar": "si-lo-gi-zar",
    "silonia": "si-lo-nia",
    "silueta": "si-lue-ta",
    "siluetar": "si-lue-tar",
    "siluetear": "si-lue-te-ar",
    "siluriana": "si-lu-ria-na",
    "siluriano": "si-lu-ria-no",
    "silúrica": "si-lú-ri-ca",
    "silúrico": "si-lú-ri-co",
    "siluro": "si-lu-ro",
    "silva": "sil-va",
    "silvano": "sil-va-no",
    "silvática": "sil-vá-ti-ca",
    "silvático": "sil-vá-ti-co",
    "silvestre": "sil-ves-tre",
    "silvícola": "sil-ví-co-la",
    "silvicultor": "sil-vi-cul-tor",
    "silvicultora": "sil-vi-cul-to-ra",
    "silvicultura": "sil-vi-cul-tu-ra",
    "silvina": "sil-vi-na",
    "silvosa": "sil-vo-sa",
    "silvoso": "sil-vo-so",
    "sima": "si-ma",
    "simada": "si-ma-da",
    "simado": "si-ma-do",
    "simarruba": "si-ma-rru-ba",
    "simarrubácea": "si-ma-rru-bá-ce-a",
    "simarrubáceo": "si-ma-rru-bá-ce-o",
    "simaruba": "si-ma-ru-ba",
    "simarubácea": "si-ma-ru-bá-ce-a",
    "simarubáceo": "si-ma-ru-bá-ce-o",
    "simba": "sim-ba",
    "simbionte": "sim-bion-te",
    "simbiosis": "sim-bio-sis",
    "simbiótica": "sim-bió-ti-ca",
    "simbiótico": "sim-bió-ti-co",
    "simbol": "sim-bol",
    "simbolar": "sim-bo-lar",
    "simbólica": "sim-bó-li-ca",
    "simbólicamente": "sim-bó-li-ca-men-te",
    "simbólico": "sim-bó-li-co",
    "simbolismo": "sim-bo-lis-mo",
    "simbolista": "sim-bo-lis-ta",
    "simbolizable": "sim-bo-li-za-ble",
    "simbolización": "sim-bo-li-za-ción",
    "simbolizar": "sim-bo-li-zar",
    "símbolo": "sím-bo-lo",
    "simbología": "sim-bo-lo-gí-a",
    "simetría": "si-me-trí-a",
    "simétrica": "si-mé-tri-ca",
    "simétricamente": "si-mé-tri-ca-men-te",
    "simétrico": "si-mé-tri-co",
    "simia": "si-mia",
    "símica": "sí-mi-ca",
    "símico": "sí-mi-co",
    "simiente": "si-mien-te",
    "simienza": "si-mien-za",
    "simiesca": "si-mies-ca",
    "simiesco": "si-mies-co",
    "símil": "sí-mil",
    "similar": "si-mi-lar",
    "similaridad": "si-mi-la-ri-dad",
    "similicadencia": "si-mi-li-ca-den-cia",
    "similitud": "si-mi-li-tud",
    "similitudinaria": "si-mi-li-tu-di-na-ria",
    "similitudinario": "si-mi-li-tu-di-na-rio",
    "similor": "si-mi-lor",
    "simio": "si-mio",
    "simón": "si-món",
    "simonía": "si-mo-ní-a",
    "simoníaca": "si-mo-ní-a-ca",
    "simoniaca": "si-mo-nia-ca",
    "simoniacamente": "si-mo-nia-ca-men-te",
    "simoniaco": "si-mo-nia-co",
    "simoniática": "si-mo-niá-ti-ca",
    "simoniático": "si-mo-niá-ti-co",
    "simpa": "sim-pa",
    "simpar": "sim-par",
    "simpatético": "sim-pa-té-ti-co",
    "simpatía": "sim-pa-tí-a",
    "simpática": "sim-pá-ti-ca",
    "simpáticamente": "sim-pá-ti-ca-men-te",
    "simpático": "sim-pá-ti-co",
    "simpaticón": "sim-pa-ti-cón",
    "simpaticona": "sim-pa-ti-co-na",
    "simpatizador": "sim-pa-ti-za-dor",
    "simpatizadora": "sim-pa-ti-za-do-ra",
    "simpatizante": "sim-pa-ti-zan-te",
    "simpatizar": "sim-pa-ti-zar",
    "simpecado": "sim-pe-ca-do",
    "simpétalo": "sim-pé-ta-lo",
    "simple": "sim-ple",
    "simplemente": "sim-ple-men-te",
    "simpleza": "sim-ple-za",
    "simplicidad": "sim-pli-ci-dad",
    "simplicísima": "sim-pli-cí-si-ma",
    "simplicísimo": "sim-pli-cí-si-mo",
    "simplicista": "sim-pli-cis-ta",
    "simplificable": "sim-pli-fi-ca-ble",
    "simplificación": "sim-pli-fi-ca-ción",
    "simplificador": "sim-pli-fi-ca-dor",
    "simplificadora": "sim-pli-fi-ca-do-ra",
    "simplificar": "sim-pli-fi-car",
    "simplismo": "sim-plis-mo",
    "simplista": "sim-plis-ta",
    "simplón": "sim-plón",
    "simplona": "sim-plo-na",
    "simposio": "sim-po-sio",
    "simulación": "si-mu-la-ción",
    "simulacro": "si-mu-la-cro",
    "simuladamente": "si-mu-la-da-men-te",
    "simulador": "si-mu-la-dor",
    "simuladora": "si-mu-la-do-ra",
    "simular": "si-mu-lar",
    "simultánea": "si-mul-tá-ne-a",
    "simultáneamente": "si-mul-tá-ne-a-men-te",
    "simultanear": "si-mul-ta-ne-ar",
    "simultaneidad": "si-mul-ta-nei-dad",
    "simultáneo": "si-mul-tá-ne-o",
    "simún": "si-mún",
    "sinabafa": "si-na-ba-fa",
    "sinagoga": "si-na-go-ga",
    "sinalagmático": "si-na-lag-má-ti-co",
    "sinalefa": "si-na-le-fa",
    "sinalefar": "si-na-le-far",
    "sinalgia": "si-nal-gia",
    "sinaloense": "si-na-lo-en-se",
    "sinamay": "si-na-may",
    "sinamayera": "si-na-ma-ye-ra",
    "sinapismo": "si-na-pis-mo",
    "sinapsis": "si-nap-sis",
    "sináptico": "si-náp-ti-co",
    "sinarca": "si-nar-ca",
    "sinario": "si-na-rio",
    "sinarquía": "si-nar-quí-a",
    "sinárquico": "si-nár-qui-co",
    "sinartrosis": "si-nar-tro-sis",
    "sincategoremático": "sin-ca-te-go-re-má-ti-co",
    "sincera": "sin-ce-ra",
    "sincerador": "sin-ce-ra-dor",
    "sinceradora": "sin-ce-ra-do-ra",
    "sinceramente": "sin-ce-ra-men-te",
    "sincerar": "sin-ce-rar",
    "sinceridad": "sin-ce-ri-dad",
    "sincero": "sin-ce-ro",
    "sinclinal": "sin-cli-nal",
    "síncopa": "sín-co-pa",
    "sincopación": "sin-co-pa-ción",
    "sincopada": "sin-co-pa-da",
    "sincopadamente": "sin-co-pa-da-men-te",
    "sincopado": "sin-co-pa-do",
    "sincopal": "sin-co-pal",
    "sincopar": "sin-co-par",
    "síncope": "sín-co-pe",
    "sincopizar": "sin-co-pi-zar",
    "sincrética": "sin-cré-ti-ca",
    "sincrético": "sin-cré-ti-co",
    "sincretismo": "sin-cre-tis-mo",
    "sincretista": "sin-cre-tis-ta",
    "sincretizar": "sin-cre-ti-zar",
    "sincro": "sin-cro",
    "sincronía": "sin-cro-ní-a",
    "sincrónica": "sin-cró-ni-ca",
    "sincrónicamente": "sin-cró-ni-ca-men-te",
    "sincrónico": "sin-cró-ni-co",
    "sincronismo": "sin-cro-nis-mo",
    "sincronización": "sin-cro-ni-za-ción",
    "sincronizar": "sin-cro-ni-zar",
    "sincrotón": "sin-cro-tón",
    "sincrotrón": "sin-cro-trón",
    "sincuate": "sin-cua-te",
    "sincuya": "sin-cu-ya",
    "sindactilia": "sin-dac-ti-lia",
    "sindáctilo": "sin-dác-ti-lo",
    "sindéresis": "sin-dé-re-sis",
    "síndica": "sín-di-ca",
    "sindicable": "sin-di-ca-ble",
    "sindicación": "sin-di-ca-ción",
    "sindicada": "sin-di-ca-da",
    "sindicado": "sin-di-ca-do",
    "sindicador": "sin-di-ca-dor",
    "sindicadora": "sin-di-ca-do-ra",
    "sindical": "sin-di-cal",
    "sindicalismo": "sin-di-ca-lis-mo",
    "sindicalista": "sin-di-ca-lis-ta",
    "sindicalizar": "sin-di-ca-li-zar",
    "sindicar": "sin-di-car",
    "sindicato": "sin-di-ca-to",
    "sindicatura": "sin-di-ca-tu-ra",
    "síndico": "sín-di-co",
    "síndrome": "sín-dro-me",
    "sinécdoque": "si-néc-do-que",
    "sinecura": "si-ne-cu-ra",
    "sinedrio": "si-ne-drio",
    "sinéresis": "si-né-re-sis",
    "sinergia": "si-ner-gia",
    "sinérgico": "si-nér-gi-co",
    "sinestesia": "si-nes-te-sia",
    "sínfilo": "sín-fi-lo",
    "sinfín": "sin-fín",
    "sinfisandrios": "sin-fi-san-drios",
    "sínfisis": "sín-fi-sis",
    "sínfito": "sín-fi-to",
    "sinfonía": "sin-fo-ní-a",
    "sinfónica": "sin-fó-ni-ca",
    "sinfónico": "sin-fó-ni-co",
    "sinfonismo": "sin-fo-nis-mo",
    "sinfonista": "sin-fo-nis-ta",
    "singa": "sin-ga",
    "singalés": "sin-ga-lés",
    "singaporense": "sin-ga-po-ren-se",
    "singapurense": "sin-ga-pu-ren-se",
    "singapurés": "sin-ga-pu-rés",
    "singapuresa": "sin-ga-pu-re-sa",
    "singar": "sin-gar",
    "singenésicos": "sin-ge-né-si-cos",
    "singladura": "sin-gla-du-ra",
    "singlar": "sin-glar",
    "single": "sin-gle",
    "singlón": "sin-glón",
    "singular": "sin-gu-lar",
    "singularidad": "sin-gu-la-ri-dad",
    "singularización": "sin-gu-la-ri-za-ción",
    "singularizar": "sin-gu-la-ri-zar",
    "singularmente": "sin-gu-lar-men-te",
    "singulto": "sin-gul-to",
    "sinhueso": "sin-hue-so",
    "sínica": "sí-ni-ca",
    "sínico": "sí-ni-co",
    "siniestra": "si-nies-tra",
    "siniestrado": "si-nies-tra-do",
    "siniestralidad": "si-nies-tra-li-dad",
    "siniestramente": "si-nies-tra-men-te",
    "siniestro": "si-nies-tro",
    "sinistrorso": "si-nis-tror-so",
    "sinjusticia": "sin-jus-ti-cia",
    "sinnúmero": "sin-nú-me-ro",
    "sino": "si-no",
    "sinoble": "si-no-ble",
    "sínoca": "sí-no-ca",
    "sinocal": "si-no-cal",
    "sinodal": "si-no-dal",
    "sinodático": "si-no-dá-ti-co",
    "sinódica": "si-nó-di-ca",
    "sinódico": "si-nó-di-co",
    "sínodo": "sí-no-do",
    "sinóloga": "si-nó-lo-ga",
    "sinología": "si-no-lo-gí-a",
    "sinólogo": "si-nó-lo-go",
    "sinónima": "si-nó-ni-ma",
    "sinonimia": "si-no-ni-mia",
    "sinonímico": "si-no-ní-mi-co",
    "sinónimo": "si-nó-ni-mo",
    "sinopense": "si-no-pen-se",
    "sinopia": "si-no-pia",
    "sinópica": "si-nó-pi-ca",
    "sinópico": "si-nó-pi-co",
    "sinople": "si-no-ple",
    "sinopsis": "si-nop-sis",
    "sinóptica": "si-nóp-ti-ca",
    "sinóptico": "si-nóp-ti-co",
    "sinoptóforo": "si-nop-tó-fo-ro",
    "sinovia": "si-no-via",
    "sinovial": "si-no-vial",
    "sinovitis": "si-no-vi-tis",
    "sinrazón": "sin-ra-zón",
    "sinsabor": "sin-sa-bor",
    "sinsentido": "sin-sen-ti-do",
    "sinsépalo": "sin-sé-pa-lo",
    "sinsonte": "sin-son-te",
    "sínsoras": "sín-so-ras",
    "sinsorga": "sin-sor-ga",
    "sinsorgo": "sin-sor-go",
    "sinsubstancia": "sin-subs-tan-cia",
    "sinsustancia": "sin-sus-tan-cia",
    "sintáctica": "sin-tác-ti-ca",
    "sintácticamente": "sin-tác-ti-ca-men-te",
    "sintáctico": "sin-tác-ti-co",
    "sintagma": "sin-tag-ma",
    "sintagmático": "sin-tag-má-ti-co",
    "sintasol": "sin-ta-sol",
    "sintaxis": "sin-ta-xis",
    "sinterización": "sin-te-ri-za-ción",
    "sinterizar": "sin-te-ri-zar",
    "síntesis": "sín-te-sis",
    "sintética": "sin-té-ti-ca",
    "sintéticamente": "sin-té-ti-ca-men-te",
    "sintético": "sin-té-ti-co",
    "sintetizable": "sin-te-ti-za-ble",
    "sintetizador": "sin-te-ti-za-dor",
    "sintetizadora": "sin-te-ti-za-do-ra",
    "sintetizar": "sin-te-ti-zar",
    "sintoísmo": "sin-to-ís-mo",
    "sintoísta": "sin-to-ís-ta",
    "síntoma": "sín-to-ma",
    "sintomática": "sin-to-má-ti-ca",
    "sintomáticamente": "sin-to-má-ti-ca-men-te",
    "sintomático": "sin-to-má-ti-co",
    "sintomatología": "sin-to-ma-to-lo-gí-a",
    "sintomatológico": "sin-to-ma-to-ló-gi-co",
    "sintonía": "sin-to-ní-a",
    "sintónica": "sin-tó-ni-ca",
    "sintónico": "sin-tó-ni-co",
    "sintonismo": "sin-to-nis-mo",
    "sintonización": "sin-to-ni-za-ción",
    "sintonizador": "sin-to-ni-za-dor",
    "sintonizar": "sin-to-ni-zar",
    "sinuosa": "si-nuo-sa",
    "sinuosidad": "si-nuo-si-dad",
    "sinuoso": "si-nuo-so",
    "sinusal": "si-nu-sal",
    "sinusitis": "si-nu-si-tis",
    "sinusoidal": "si-nu-soi-dal",
    "sinusoide": "si-nu-soi-de",
    "sinventura": "sin-ven-tu-ra",
    "sinvergonzón": "sin-ver-gon-zón",
    "sinvergonzonada": "sin-ver-gon-zo-na-da",
    "sinvergonzonería": "sin-ver-gon-zo-ne-rí-a",
    "sinvergüencería": "sin-ver-güen-ce-rí-a",
    "sinvergüenza": "sin-ver-güen-za",
    "sinvergüenzada": "sin-ver-güen-za-da",
    "sinvergüenzón": "sin-ver-güen-zón",
    "sinvergüenzura": "sin-ver-güen-zu-ra",
    "sinvivir": "sin-vi-vir",
    "sinzonte": "sin-zon-te",
    "sionismo": "sio-nis-mo",
    "sionista": "sio-nis-ta",
    "sipacapense": "si-pa-ca-pen-se",
    "sipe": "si-pe",
    "sipedón": "si-pe-dón",
    "siquiatra": "si-quia-tra",
    "siquiatría": "si-quia-trí-a",
    "siquiátrico": "si-quiá-tri-co",
    "síquica": "sí-qui-ca",
    "síquico": "sí-qui-co",
    "siquier": "si-quier",
    "siquiera": "si-quie-ra",
    "siquitraque": "si-qui-tra-que",
    "siquitrillar": "si-qui-tri-llar",
    "sira": "si-ra",
    "siracusana": "si-ra-cu-sa-na",
    "siracusano": "si-ra-cu-sa-no",
    "siraguo": "si-ra-guo",
    "sire": "si-re",
    "sirena": "si-re-na",
    "sirénido": "si-ré-ni-do",
    "sirenio": "si-re-nio",
    "sírfido": "sír-fi-do",
    "sirga": "sir-ga",
    "sirgar": "sir-gar",
    "sirgo": "sir-go",
    "sirguero": "sir-gue-ro",
    "siria": "si-ria",
    "siriaca": "si-ria-ca",
    "siríaco": "si-rí-a-co",
    "siriaco": "si-ria-co",
    "siriana": "si-ria-na",
    "siriano": "si-ria-no",
    "siricote": "si-ri-co-te",
    "sirifico": "si-ri-fi-co",
    "sirifique": "si-ri-fi-que",
    "sirimiri": "si-ri-mi-ri",
    "sirindanga": "si-rin-dan-ga",
    "siringa": "si-rin-ga",
    "siringe": "si-rin-ge",
    "siringuero": "si-rin-gue-ro",
    "sirio": "si-rio",
    "siripita": "si-ri-pi-ta",
    "sirirí": "si-ri-rí",
    "sirla": "sir-la",
    "sirle": "sir-le",
    "sirmiense": "sir-mien-se",
    "siro": "si-ro",
    "siroco": "si-ro-co",
    "sirope": "si-ro-pe",
    "sirria": "si-rria",
    "sirtaki": "sir-ta-ki",
    "sirte": "sir-te",
    "sirventés": "sir-ven-tés",
    "sirvienta": "sir-vien-ta",
    "sirviente": "sir-vien-te",
    "sisa": "si-sa",
    "sisador": "si-sa-dor",
    "sisadora": "si-sa-do-ra",
    "sisal": "si-sal",
    "sisalera": "si-sa-le-ra",
    "sisalero": "si-sa-le-ro",
    "sisallo": "si-sa-llo",
    "sisar": "si-sar",
    "sisardo": "si-sar-do",
    "sisca": "sis-ca",
    "sisear": "si-se-ar",
    "sisella": "si-se-lla",
    "siseo": "si-se-o",
    "sisero": "si-se-ro",
    "sisiflís": "si-si-flís",
    "sisimbrio": "si-sim-brio",
    "sisimico": "si-si-mi-co",
    "sisimite": "si-si-mi-te",
    "sísmica": "sís-mi-ca",
    "sismicidad": "sis-mi-ci-dad",
    "sísmico": "sís-mi-co",
    "sismo": "sis-mo",
    "sismógrafo": "sis-mó-gra-fo",
    "sismóloga": "sis-mó-lo-ga",
    "sismología": "sis-mo-lo-gí-a",
    "sismológica": "sis-mo-ló-gi-ca",
    "sismológico": "sis-mo-ló-gi-co",
    "sismólogo": "sis-mó-lo-go",
    "sismómetro": "sis-mó-me-tro",
    "sismorresistente": "sis-mo-rre-sis-ten-te",
    "sisón": "si-són",
    "sisona": "si-so-na",
    "sistema": "sis-te-ma",
    "sistemática": "sis-te-má-ti-ca",
    "sistemáticamente": "sis-te-má-ti-ca-men-te",
    "sistemático": "sis-te-má-ti-co",
    "sistematización": "sis-te-ma-ti-za-ción",
    "sistematizado": "sis-te-ma-ti-za-do",
    "sistematizar": "sis-te-ma-ti-zar",
    "sistémico": "sis-té-mi-co",
    "sístilo": "sís-ti-lo",
    "sístole": "sís-to-le",
    "sistólica": "sis-tó-li-ca",
    "sistólico": "sis-tó-li-co",
    "sistro": "sis-tro",
    "sita": "si-ta",
    "sitácida": "si-tá-ci-da",
    "sitacismo": "si-ta-cis-mo",
    "sitacosis": "si-ta-co-sis",
    "sitiada": "si-tia-da",
    "sitiado": "si-tia-do",
    "sitiador": "si-tia-dor",
    "sitiadora": "si-tia-do-ra",
    "sitial": "si-tial",
    "sitiar": "si-tiar",
    "sitibunda": "si-ti-bun-da",
    "sitibundo": "si-ti-bun-do",
    "sitiera": "si-tie-ra",
    "sitiero": "si-tie-ro",
    "sitio": "si-tio",
    "sito": "si-to",
    "situación": "si-tua-ción",
    "situacional": "si-tua-cio-nal",
    "situado": "si-tua-do",
    "situar": "si-tuar",
    "siútica": "siú-ti-ca",
    "siútico": "siú-ti-co",
    "siutiquería": "siu-ti-que-rí-a",
    "sizigia": "si-zi-gia",
    "smoking": "s-mo-king",
    "snobismo": "s-no-bis-mo",
    "snorkel": "s-nor-kel",
    "soalzar": "so-al-zar",
    "soasar": "so-a-sar",
    "soba": "so-ba",
    "sobacal": "so-ba-cal",
    "sobachetos": "so-ba-che-tos",
    "sobaco": "so-ba-co",
    "sobacuno": "so-ba-cu-no",
    "sobada": "so-ba-da",
    "sobadera": "so-ba-de-ra",
    "sobadero": "so-ba-de-ro",
    "sobadita": "so-ba-di-ta",
    "sobado": "so-ba-do",
    "sobador": "so-ba-dor",
    "sobadora": "so-ba-do-ra",
    "sobadura": "so-ba-du-ra",
    "sobajadura": "so-ba-ja-du-ra",
    "sobajamiento": "so-ba-ja-mien-to",
    "sobajanero": "so-ba-ja-ne-ro",
    "sobajar": "so-ba-jar",
    "sobajear": "so-ba-je-ar",
    "sobajeo": "so-ba-je-o",
    "sobalera": "so-ba-le-ra",
    "sobaleras": "so-ba-le-ras",
    "sobalero": "so-ba-le-ro",
    "sobalevas": "so-ba-le-vas",
    "sobalevismo": "so-ba-le-vis-mo",
    "sobanda": "so-ban-da",
    "sobandero": "so-ban-de-ro",
    "sobao": "so-ba-o",
    "sobaqueado": "so-ba-que-a-do",
    "sobaquera": "so-ba-que-ra",
    "sobaquillo": "so-ba-qui-llo",
    "sobaquina": "so-ba-qui-na",
    "sobar": "so-bar",
    "sobarba": "so-bar-ba",
    "sobarbada": "so-bar-ba-da",
    "sobarbo": "so-bar-bo",
    "sobarcar": "so-bar-car",
    "sobe": "so-be",
    "sobeja": "so-be-ja",
    "sobejana": "so-be-ja-na",
    "sobejanía": "so-be-ja-ní-a",
    "sobejano": "so-be-ja-no",
    "sobejo": "so-be-jo",
    "sobeo": "so-be-o",
    "soberado": "so-be-ra-do",
    "soberana": "so-be-ra-na",
    "soberanamente": "so-be-ra-na-men-te",
    "soberanear": "so-be-ra-ne-ar",
    "soberanía": "so-be-ra-ní-a",
    "soberano": "so-be-ra-no",
    "soberbia": "so-ber-bia",
    "soberbiamente": "so-ber-bia-men-te",
    "soberbiar": "so-ber-biar",
    "soberbio": "so-ber-bio",
    "soberbiosa": "so-ber-bio-sa",
    "soberbiosamente": "so-ber-bio-sa-men-te",
    "soberbioso": "so-ber-bio-so",
    "sobermeja": "so-ber-me-ja",
    "sobermejo": "so-ber-me-jo",
    "sobetear": "so-be-te-ar",
    "sobeteo": "so-be-te-o",
    "sobijada": "so-bi-ja-da",
    "sobijar": "so-bi-jar",
    "sobijeo": "so-bi-je-o",
    "sobijón": "so-bi-jón",
    "sobijona": "so-bi-jo-na",
    "sobina": "so-bi-na",
    "sobo": "so-bo",
    "sobón": "so-bón",
    "sobona": "so-bo-na",
    "sobordo": "so-bor-do",
    "sobornable": "so-bor-na-ble",
    "sobornación": "so-bor-na-ción",
    "sobornado": "so-bor-na-do",
    "sobornador": "so-bor-na-dor",
    "sobornadora": "so-bor-na-do-ra",
    "sobornal": "so-bor-nal",
    "sobornar": "so-bor-nar",
    "soborno": "so-bor-no",
    "sobra": "so-bra",
    "sobrada": "so-bra-da",
    "sobradamente": "so-bra-da-men-te",
    "sobradar": "so-bra-dar",
    "sobradero": "so-bra-de-ro",
    "sobradillo": "so-bra-di-llo",
    "sobrado": "so-bra-do",
    "sobrador": "so-bra-dor",
    "sobradora": "so-bra-do-ra",
    "sobrancera": "so-bran-ce-ra",
    "sobrancero": "so-bran-ce-ro",
    "sobrante": "so-bran-te",
    "sobrar": "so-brar",
    "sobrasada": "so-bra-sa-da",
    "sobrasar": "so-bra-sar",
    "sobrazana": "so-bra-za-na",
    "sobrazano": "so-bra-za-no",
    "sobrazar": "so-bra-zar",
    "sobre": "so-bre",
    "sobreabundancia": "so-bre-a-bun-dan-cia",
    "sobreabundantemente": "so-bre-a-bun-dan-te-men-te",
    "sobreabundar": "so-bre-a-bun-dar",
    "sobreactuación": "so-bre-ac-tua-ción",
    "sobreactuar": "so-bre-ac-tuar",
    "sobreaguar": "so-bre-a-guar",
    "sobreaguda": "so-bre-a-gu-da",
    "sobreagudo": "so-bre-a-gu-do",
    "sobrealiento": "so-bre-a-lien-to",
    "sobrealimentación": "so-bre-a-li-men-ta-ción",
    "sobrealimentador": "so-bre-a-li-men-ta-dor",
    "sobrealimentadora": "so-bre-a-li-men-ta-do-ra",
    "sobrealimentar": "so-bre-a-li-men-tar",
    "sobrealzar": "so-bre-al-zar",
    "sobreañadir": "so-bre-a-ña-dir",
    "sobreañal": "so-bre-a-ñal",
    "sobrearar": "so-bre-a-rar",
    "sobrearco": "so-bre-ar-co",
    "sobreasada": "so-bre-a-sa-da",
    "sobreasar": "so-bre-a-sar",
    "sobreático": "so-bre-á-ti-co",
    "sobrebarata": "so-bre-ba-ra-ta",
    "sobrebarato": "so-bre-ba-ra-to",
    "sobrebarrer": "so-bre-ba-rrer",
    "sobrebeber": "so-bre-be-ber",
    "sobrebota": "so-bre-bo-ta",
    "sobrecalentamiento": "so-bre-ca-len-ta-mien-to",
    "sobrecalza": "so-bre-cal-za",
    "sobrecama": "so-bre-ca-ma",
    "sobrecamisa": "so-bre-ca-mi-sa",
    "sobrecaña": "so-bre-ca-ña",
    "sobrecara": "so-bre-ca-ra",
    "sobrecarga": "so-bre-car-ga",
    "sobrecargar": "so-bre-car-gar",
    "sobrecargo": "so-bre-car-go",
    "sobrecaro": "so-bre-ca-ro",
    "sobrecédula": "so-bre-cé-du-la",
    "sobreceja": "so-bre-ce-ja",
    "sobrecejo": "so-bre-ce-jo",
    "sobrecelestial": "so-bre-ce-les-tial",
    "sobrecenar": "so-bre-ce-nar",
    "sobreceño": "so-bre-ce-ño",
    "sobrecerco": "so-bre-cer-co",
    "sobrecerrada": "so-bre-ce-rra-da",
    "sobrecerrado": "so-bre-ce-rra-do",
    "sobrecielo": "so-bre-cie-lo",
    "sobrecincha": "so-bre-cin-cha",
    "sobrecincho": "so-bre-cin-cho",
    "sobreclaustra": "so-bre-claus-tra",
    "sobreclaustro": "so-bre-claus-tro",
    "sobrecogedor": "so-bre-co-ge-dor",
    "sobrecoger": "so-bre-co-ger",
    "sobrecogimiento": "so-bre-co-gi-mien-to",
    "sobrecomida": "so-bre-co-mi-da",
    "sobrecopa": "so-bre-co-pa",
    "sobrecostilla": "so-bre-cos-ti-lla",
    "sobrecostura": "so-bre-cos-tu-ra",
    "sobrecrecer": "so-bre-cre-cer",
    "sobrecruz": "so-bre-cruz",
    "sobrecubierta": "so-bre-cu-bier-ta",
    "sobrecuello": "so-bre-cue-llo",
    "sobrecurar": "so-bre-cu-rar",
    "sobredezmero": "so-bre-dez-me-ro",
    "sobredicha": "so-bre-di-cha",
    "sobredicho": "so-bre-di-cho",
    "sobrediente": "so-bre-dien-te",
    "sobredimensionar": "so-bre-di-men-sio-nar",
    "sobredorar": "so-bre-do-rar",
    "sobredosis": "so-bre-do-sis",
    "sobreedificar": "so-bre-e-di-fi-car",
    "sobreempeine": "so-bre-em-pei-ne",
    "sobreentender": "so-bre-en-ten-der",
    "sobreentendido": "so-bre-en-ten-di-do",
    "sobreentrenamiento": "so-bre-en-tre-na-mien-to",
    "sobreesdrújula": "so-bre-es-drú-ju-la",
    "sobreesdrújulo": "so-bre-es-drú-ju-lo",
    "sobreesfuerzo": "so-bre-es-fuer-zo",
    "sobreestimación": "so-bre-es-ti-ma-ción",
    "sobreestimar": "so-bre-es-ti-mar",
    "sobreexceder": "so-bre-ex-ce-der",
    "sobreexcitación": "so-bre-ex-ci-ta-ción",
    "sobreexcitar": "so-bre-ex-ci-tar",
    "sobreexplotación": "so-bre-ex-plo-ta-ción",
    "sobreexplotar": "so-bre-ex-plo-tar",
    "sobrefalda": "so-bre-fal-da",
    "sobrefaz": "so-bre-faz",
    "sobreflor": "so-bre-flor",
    "sobrefrenada": "so-bre-fre-na-da",
    "sobrefunda": "so-bre-fun-da",
    "sobrefusión": "so-bre-fu-sión",
    "sobreganar": "so-bre-ga-nar",
    "sobregirar": "so-bre-gi-rar",
    "sobregiro": "so-bre-gi-ro",
    "sobreguarda": "so-bre-guar-da",
    "sobrehaz": "so-bre-haz",
    "sobreherida": "so-bre-he-ri-da",
    "sobreherido": "so-bre-he-ri-do",
    "sobrehilado": "so-brehi-la-do",
    "sobrehilar": "so-brehi-lar",
    "sobrehílo": "so-bre-hí-lo",
    "sobrehora": "so-bre-ho-ra",
    "sobrehueso": "so-bre-hue-so",
    "sobrehumana": "so-brehu-ma-na",
    "sobrehumano": "so-brehu-ma-no",
    "sobrehúsa": "so-bre-hú-sa",
    "sobreimpresión": "so-breim-pre-sión",
    "sobreimpreso": "so-breim-pre-so",
    "sobreimprimir": "so-breim-pri-mir",
    "sobreintendencia": "so-brein-ten-den-cia",
    "sobrejalma": "so-bre-jal-ma",
    "sobrejuanete": "so-bre-jua-ne-te",
    "sobrejuez": "so-bre-juez",
    "sobrelecho": "so-bre-le-cho",
    "sobrellavar": "so-bre-lla-var",
    "sobrellave": "so-bre-lla-ve",
    "sobrellena": "so-bre-lle-na",
    "sobrellenar": "so-bre-lle-nar",
    "sobrelleno": "so-bre-lle-no",
    "sobrellevar": "so-bre-lle-var",
    "sobreltado": "so-brel-ta-do",
    "sobremanera": "so-bre-ma-ne-ra",
    "sobremano": "so-bre-ma-no",
    "sobremesa": "so-bre-me-sa",
    "sobremesana": "so-bre-me-sa-na",
    "sobremodo": "so-bre-mo-do",
    "sobremuñonera": "so-bre-mu-ño-ne-ra",
    "sobreña": "so-bre-ña",
    "sobrenadante": "so-bre-na-dan-te",
    "sobrenadar": "so-bre-na-dar",
    "sobrenatural": "so-bre-na-tu-ral",
    "sobrenaturalmente": "so-bre-na-tu-ral-men-te",
    "sobrenjalma": "so-bren-jal-ma",
    "sobreño": "so-bre-ño",
    "sobrenoche": "so-bre-no-che",
    "sobrenombre": "so-bre-nom-bre",
    "sobrentender": "so-bren-ten-der",
    "sobrentendido": "so-bren-ten-di-do",
    "sobrepaga": "so-bre-pa-ga",
    "sobrepalo": "so-bre-pa-lo",
    "sobrepaño": "so-bre-pa-ño",
    "sobreparto": "so-bre-par-to",
    "sobrepasar": "so-bre-pa-sar",
    "sobrepeine": "so-bre-pei-ne",
    "sobrepelliz": "so-bre-pe-lliz",
    "sobrepelo": "so-bre-pe-lo",
    "sobrepeso": "so-bre-pe-so",
    "sobrepié": "so-bre-pié",
    "sobrepintar": "so-bre-pin-tar",
    "sobrepintarse": "so-bre-pin-tar-se",
    "sobreplán": "so-bre-plán",
    "sobreponer": "so-bre-po-ner",
    "sobreprecio": "so-bre-pre-cio",
    "sobrepresión": "so-bre-pre-sión",
    "sobreprimada": "so-bre-pri-ma-da",
    "sobreprimado": "so-bre-pri-ma-do",
    "sobreproducción": "so-bre-pro-duc-ción",
    "sobrepuerta": "so-bre-puer-ta",
    "sobrepuesto": "so-bre-pues-to",
    "sobrepujamiento": "so-bre-pu-ja-mien-to",
    "sobrepujanza": "so-bre-pu-jan-za",
    "sobrepujar": "so-bre-pu-jar",
    "sobrequilla": "so-bre-qui-lla",
    "sobrera": "so-bre-ra",
    "sobrero": "so-bre-ro",
    "sobrerrealismo": "so-bre-rre-a-lis-mo",
    "sobrerrienda": "so-bre-rrien-da",
    "sobrerronda": "so-bre-rron-da",
    "sobrerropa": "so-bre-rro-pa",
    "sobresabida": "so-bre-sa-bi-da",
    "sobresabido": "so-bre-sa-bi-do",
    "sobresalienta": "so-bre-sa-lien-ta",
    "sobresaliente": "so-bre-sa-lien-te",
    "sobresalir": "so-bre-sa-lir",
    "sobresaltar": "so-bre-sal-tar",
    "sobresalto": "so-bre-sal-to",
    "sobresanar": "so-bre-sa-nar",
    "sobresano": "so-bre-sa-no",
    "sobresaturación": "so-bre-sa-tu-ra-ción",
    "sobrescribir": "so-bres-cri-bir",
    "sobrescripta": "so-bres-crip-ta",
    "sobrescripto": "so-bres-crip-to",
    "sobrescrito": "so-bres-cri-to",
    "sobresdrújula": "so-bres-drú-ju-la",
    "sobresdrújulo": "so-bres-drú-ju-lo",
    "sobreseer": "so-bre-se-er",
    "sobreseguro": "so-bre-se-gu-ro",
    "sobreseimiento": "so-bre-sei-mien-to",
    "sobresello": "so-bre-se-llo",
    "sobresembrar": "so-bre-sem-brar",
    "sobreseñal": "so-bre-se-ñal",
    "sobresolar": "so-bre-so-lar",
    "sobrestadía": "so-bres-ta-dí-a",
    "sobrestante": "so-bres-tan-te",
    "sobrestantía": "so-bres-tan-tí-a",
    "sobrestimación": "so-bres-ti-ma-ción",
    "sobrestimar": "so-bres-ti-mar",
    "sobresueldo": "so-bre-suel-do",
    "sobresuelo": "so-bre-sue-lo",
    "sobretarde": "so-bre-tar-de",
    "sobretasa": "so-bre-ta-sa",
    "sobretendón": "so-bre-ten-dón",
    "sobretensión": "so-bre-ten-sión",
    "sobretercero": "so-bre-ter-ce-ro",
    "sobretiro": "so-bre-ti-ro",
    "sobretítulo": "so-bre-tí-tu-lo",
    "sobretodo": "so-bre-to-do",
    "sobrevaloración": "so-bre-va-lo-ra-ción",
    "sobrevalorar": "so-bre-va-lo-rar",
    "sobreveedor": "so-bre-ve-e-dor",
    "sobrevenida": "so-bre-ve-ni-da",
    "sobrevenir": "so-bre-ve-nir",
    "sobreventa": "so-bre-ven-ta",
    "sobreverter": "so-bre-ver-ter",
    "sobreverterse": "so-bre-ver-ter-se",
    "sobrevesta": "so-bre-ves-ta",
    "sobreveste": "so-bre-ves-te",
    "sobrevestir": "so-bre-ves-tir",
    "sobrevidriera": "so-bre-vi-drie-ra",
    "sobrevienta": "so-bre-vien-ta",
    "sobreviento": "so-bre-vien-to",
    "sobrevista": "so-bre-vis-ta",
    "sobreviviente": "so-bre-vi-vien-te",
    "sobrevivir": "so-bre-vi-vir",
    "sobrevolar": "so-bre-vo-lar",
    "sobrexceder": "so-brex-ce-der",
    "sobrexcitación": "so-brex-ci-ta-ción",
    "sobrexcitar": "so-brex-ci-tar",
    "sobria": "so-bria",
    "sobriamente": "so-bria-men-te",
    "sobriedad": "so-brie-dad",
    "sobrina": "so-bri-na",
    "sobrinazgo": "so-bri-naz-go",
    "sobrino": "so-bri-no",
    "sobrio": "so-brio",
    "soca": "so-ca",
    "socaire": "so-cai-re",
    "socairero": "so-cai-re-ro",
    "socaliña": "so-ca-li-ña",
    "socaliñar": "so-ca-li-ñar",
    "socaliñera": "so-ca-li-ñe-ra",
    "socaliñero": "so-ca-li-ñe-ro",
    "socalzar": "so-cal-zar",
    "socapa": "so-ca-pa",
    "socapar": "so-ca-par",
    "socapiscol": "so-ca-pis-col",
    "socar": "so-car",
    "socarra": "so-ca-rra",
    "socarrar": "so-ca-rrar",
    "socarrén": "so-ca-rrén",
    "socarrena": "so-ca-rre-na",
    "socarrina": "so-ca-rri-na",
    "socarro": "so-ca-rro",
    "socarrón": "so-ca-rrón",
    "socarrona": "so-ca-rro-na",
    "socarronamente": "so-ca-rro-na-men-te",
    "socarronería": "so-ca-rro-ne-rí-a",
    "sócate": "só-ca-te",
    "socava": "so-ca-va",
    "socavación": "so-ca-va-ción",
    "socavar": "so-ca-var",
    "socavón": "so-ca-vón",
    "socaz": "so-caz",
    "sochantre": "so-chan-tre",
    "soche": "so-che",
    "socia": "so-cia",
    "sociabilidad": "so-cia-bi-li-dad",
    "sociabilización": "so-cia-bi-li-za-ción",
    "sociabilizar": "so-cia-bi-li-zar",
    "sociable": "so-cia-ble",
    "social": "so-cial",
    "socialcristiano": "so-cial-cris-tia-no",
    "socialdemocracia": "so-cial-de-mo-cra-cia",
    "socialdemócrata": "so-cial-de-mó-cra-ta",
    "socialismo": "so-cia-lis-mo",
    "socialista": "so-cia-lis-ta",
    "socialización": "so-cia-li-za-ción",
    "socializador": "so-cia-li-za-dor",
    "socializadora": "so-cia-li-za-do-ra",
    "socializante": "so-cia-li-zan-te",
    "socializar": "so-cia-li-zar",
    "sociata": "so-cia-ta",
    "sociativo": "so-cia-ti-vo",
    "sociedad": "so-cie-dad",
    "societaria": "so-cie-ta-ria",
    "societario": "so-cie-ta-rio",
    "sociniana": "so-ci-nia-na",
    "socinianismo": "so-ci-nia-nis-mo",
    "sociniano": "so-ci-nia-no",
    "socio": "so-cio",
    "sociobiología": "so-cio-bio-lo-gí-a",
    "sociocultural": "so-cio-cul-tu-ral",
    "socioeconómico": "so-cio-e-co-nó-mi-co",
    "sociolaboral": "so-cio-la-bo-ral",
    "sociolecto": "so-cio-lec-to",
    "sociolingüista": "so-cio-lin-güis-ta",
    "sociolingüística": "so-cio-lin-güís-ti-ca",
    "sociolingüístico": "so-cio-lin-güís-ti-co",
    "socióloga": "so-ció-lo-ga",
    "sociología": "so-cio-lo-gí-a",
    "sociológica": "so-cio-ló-gi-ca",
    "sociológico": "so-cio-ló-gi-co",
    "sociólogo": "so-ció-lo-go",
    "sociometría": "so-cio-me-trí-a",
    "sociométrico": "so-cio-mé-tri-co",
    "sociopatología": "so-cio-pa-to-lo-gí-a",
    "sociopolítico": "so-cio-po-lí-ti-co",
    "socioterapia": "so-cio-te-ra-pia",
    "socket": "soc-ket",
    "soco": "so-co",
    "socol": "so-col",
    "socola": "so-co-la",
    "socolar": "so-co-lar",
    "socollada": "so-co-lla-da",
    "socollar": "so-co-llar",
    "socollón": "so-co-llón",
    "socollonear": "so-co-llo-ne-ar",
    "socolor": "so-co-lor",
    "soconusco": "so-co-nus-co",
    "socoro": "so-co-ro",
    "socorredor": "so-co-rre-dor",
    "socorredora": "so-co-rre-do-ra",
    "socorrer": "so-co-rrer",
    "socorrida": "so-co-rri-da",
    "socorrido": "so-co-rri-do",
    "socorrismo": "so-co-rris-mo",
    "socorrista": "so-co-rris-ta",
    "socorro": "so-co-rro",
    "socotroco": "so-co-tro-co",
    "socoyote": "so-co-yo-te",
    "socrática": "so-crá-ti-ca",
    "socrático": "so-crá-ti-co",
    "socrocio": "so-cro-cio",
    "socucho": "so-cu-cho",
    "soda": "so-da",
    "sodalita": "so-da-li-ta",
    "sodero": "so-de-ro",
    "sódica": "só-di-ca",
    "sódico": "só-di-co",
    "sodio": "so-dio",
    "sodomía": "so-do-mí-a",
    "sodomita": "so-do-mi-ta",
    "sodomítica": "so-do-mí-ti-ca",
    "sodomítico": "so-do-mí-ti-co",
    "sodomizar": "so-do-mi-zar",
    "soez": "so-ez",
    "soeza": "so-e-za",
    "sofá": "so-fá",
    "sofaldar": "so-fal-dar",
    "sofaldo": "so-fal-do",
    "sofero": "so-fe-ro",
    "sofí": "so-fí",
    "sofía": "so-fí-a",
    "sofiana": "so-fia-na",
    "sofiano": "so-fia-no",
    "sofión": "so-fión",
    "sofisma": "so-fis-ma",
    "sofismo": "so-fis-mo",
    "sofista": "so-fis-ta",
    "sofistería": "so-fis-te-rí-a",
    "sofística": "so-fís-ti-ca",
    "sofisticación": "so-fis-ti-ca-ción",
    "sofisticado": "so-fis-ti-ca-do",
    "sofísticamente": "so-fís-ti-ca-men-te",
    "sofisticar": "so-fis-ti-car",
    "sofístico": "so-fís-ti-co",
    "sofistiquez": "so-fis-ti-quez",
    "sofito": "so-fi-to",
    "soflama": "so-fla-ma",
    "soflamar": "so-fla-mar",
    "soflamera": "so-fla-me-ra",
    "soflamero": "so-fla-me-ro",
    "sofocación": "so-fo-ca-ción",
    "sofocado": "so-fo-ca-do",
    "sofocador": "so-fo-ca-dor",
    "sofocadora": "so-fo-ca-do-ra",
    "sofocamiento": "so-fo-ca-mien-to",
    "sofocante": "so-fo-can-te",
    "sofocar": "so-fo-car",
    "sofoclea": "so-fo-cle-a",
    "sofocleo": "so-fo-cle-o",
    "sofoco": "so-fo-co",
    "sofocón": "so-fo-cón",
    "sofoquina": "so-fo-qui-na",
    "sófora": "só-fo-ra",
    "sofreír": "so-fre-ír",
    "sofrenada": "so-fre-na-da",
    "sofrenar": "so-fre-nar",
    "sofridera": "so-fri-de-ra",
    "sofridero": "so-fri-de-ro",
    "sofrito": "so-fri-to",
    "sofróloga": "so-fró-lo-ga",
    "sofrología": "so-fro-lo-gí-a",
    "sofrólogo": "so-fró-lo-go",
    "soga": "so-ga",
    "sogdiana": "sog-dia-na",
    "sogdiano": "sog-dia-no",
    "sogüé": "so-güé",
    "soguear": "so-gue-ar",
    "soguería": "so-gue-rí-a",
    "soguero": "so-gue-ro",
    "soguilla": "so-gui-lla",
    "soguillo": "so-gui-llo",
    "sogún": "so-gún",
    "soirée": "soi-ré-e",
    "soja": "so-ja",
    "sojuzgador": "so-juz-ga-dor",
    "sojuzgadora": "so-juz-ga-do-ra",
    "sojuzgar": "so-juz-gar",
    "sola": "so-la",
    "solacear": "so-la-ce-ar",
    "solacio": "so-la-cio",
    "solada": "so-la-da",
    "solado": "so-la-do",
    "solador": "so-la-dor",
    "soladura": "so-la-du-ra",
    "solamente": "so-la-men-te",
    "solana": "so-la-na",
    "solanácea": "so-la-ná-ce-a",
    "solanáceas": "so-la-ná-ce-as",
    "solanáceo": "so-la-ná-ce-o",
    "solanar": "so-la-nar",
    "solanera": "so-la-ne-ra",
    "solanina": "so-la-ni-na",
    "solano": "so-la-no",
    "solapa": "so-la-pa",
    "solapada": "so-la-pa-da",
    "solapadamente": "so-la-pa-da-men-te",
    "solapado": "so-la-pa-do",
    "solapamiento": "so-la-pa-mien-to",
    "solapar": "so-la-par",
    "solape": "so-la-pe",
    "solapear": "so-la-pe-ar",
    "solapo": "so-la-po",
    "solaque": "so-la-que",
    "solaquear": "so-la-que-ar",
    "solar": "so-lar",
    "solariega": "so-la-rie-ga",
    "solariego": "so-la-rie-go",
    "solario": "so-la-rio",
    "solárium": "so-lá-rium",
    "solaz": "so-laz",
    "solazar": "so-la-zar",
    "solazo": "so-la-zo",
    "solazosa": "so-la-zo-sa",
    "solazoso": "so-la-zo-so",
    "soldada": "sol-da-da",
    "soldadera": "sol-da-de-ra",
    "soldadero": "sol-da-de-ro",
    "soldadesca": "sol-da-des-ca",
    "soldadesco": "sol-da-des-co",
    "soldadito": "sol-da-di-to",
    "soldado": "sol-da-do",
    "soldador": "sol-da-dor",
    "soldadote": "sol-da-do-te",
    "soldadura": "sol-da-du-ra",
    "soldán": "sol-dán",
    "soldar": "sol-dar",
    "soldeo": "sol-de-o",
    "soleá": "so-le-á",
    "soleado": "so-le-a-do",
    "soleamiento": "so-le-a-mien-to",
    "solear": "so-le-ar",
    "solecismo": "so-le-cis-mo",
    "soledad": "so-le-dad",
    "soledosa": "so-le-do-sa",
    "soledoso": "so-le-do-so",
    "soledumbre": "so-le-dum-bre",
    "solejar": "so-le-jar",
    "solejo": "so-le-jo",
    "solemne": "so-lem-ne",
    "solemnemente": "so-lem-ne-men-te",
    "solemnidad": "so-lem-ni-dad",
    "solemnizador": "so-lem-ni-za-dor",
    "solemnizadora": "so-lem-ni-za-do-ra",
    "solemnizar": "so-lem-ni-zar",
    "solén": "so-lén",
    "solenoide": "so-le-noi-de",
    "soleo": "so-le-o",
    "sóleo": "só-le-o",
    "soler": "so-ler",
    "solera": "so-le-ra",
    "solercia": "so-ler-cia",
    "solería": "so-le-rí-a",
    "solero": "so-le-ro",
    "solerte": "so-ler-te",
    "soleta": "so-le-ta",
    "soletar": "so-le-tar",
    "soletear": "so-le-te-ar",
    "soletera": "so-le-te-ra",
    "soletero": "so-le-te-ro",
    "soletilla": "so-le-ti-lla",
    "solevación": "so-le-va-ción",
    "solevamiento": "so-le-va-mien-to",
    "solevantada": "so-le-van-ta-da",
    "solevantado": "so-le-van-ta-do",
    "solevantamiento": "so-le-van-ta-mien-to",
    "solevantar": "so-le-van-tar",
    "solevanto": "so-le-van-to",
    "solevar": "so-le-var",
    "solfa": "sol-fa",
    "solfatara": "sol-fa-ta-ra",
    "solfeador": "sol-fe-a-dor",
    "solfeadora": "sol-fe-a-do-ra",
    "solfear": "sol-fe-ar",
    "solfeo": "sol-fe-o",
    "solferina": "sol-fe-ri-na",
    "solferino": "sol-fe-ri-no",
    "solfista": "sol-fis-ta",
    "solícita": "so-lí-ci-ta",
    "solicitación": "so-li-ci-ta-ción",
    "solicitada": "so-li-ci-ta-da",
    "solicitador": "so-li-ci-ta-dor",
    "solicitadora": "so-li-ci-ta-do-ra",
    "solícitamente": "so-lí-ci-ta-men-te",
    "solicitante": "so-li-ci-tan-te",
    "solicitar": "so-li-ci-tar",
    "solícito": "so-lí-ci-to",
    "solicitud": "so-li-ci-tud",
    "sólida": "só-li-da",
    "sólidamente": "só-li-da-men-te",
    "solidar": "so-li-dar",
    "solidaria": "so-li-da-ria",
    "solidariamente": "so-li-da-ria-men-te",
    "solidaridad": "so-li-da-ri-dad",
    "solidario": "so-li-da-rio",
    "solidarizar": "so-li-da-ri-zar",
    "solideo": "so-li-de-o",
    "solidez": "so-li-dez",
    "solidificación": "so-li-di-fi-ca-ción",
    "solidificar": "so-li-di-fi-car",
    "sólido": "só-li-do",
    "soliloquiar": "so-li-lo-quiar",
    "soliloquio": "so-li-lo-quio",
    "solimán": "so-li-mán",
    "solimitana": "so-li-mi-ta-na",
    "solimitano": "so-li-mi-ta-no",
    "solio": "so-lio",
    "solípedo": "so-lí-pe-do",
    "solipsismo": "so-lip-sis-mo",
    "solista": "so-lis-ta",
    "sólita": "só-li-ta",
    "solitaria": "so-li-ta-ria",
    "solitariamente": "so-li-ta-ria-men-te",
    "solitario": "so-li-ta-rio",
    "sólito": "só-li-to",
    "solitud": "so-li-tud",
    "soliviadura": "so-li-via-du-ra",
    "soliviantada": "so-li-vian-ta-da",
    "soliviantado": "so-li-vian-ta-do",
    "soliviantar": "so-li-vian-tar",
    "solivianto": "so-li-vian-to",
    "soliviar": "so-li-viar",
    "solivio": "so-li-vio",
    "solivión": "so-li-vión",
    "solivo": "so-li-vo",
    "solla": "so-lla",
    "sollado": "so-lla-do",
    "sollador": "so-lla-dor",
    "sollamar": "so-lla-mar",
    "sollar": "so-llar",
    "sollastre": "so-llas-tre",
    "sollastría": "so-llas-trí-a",
    "sollispar": "so-llis-par",
    "sollisparse": "so-llis-par-se",
    "sollo": "so-llo",
    "sollozante": "so-llo-zan-te",
    "sollozar": "so-llo-zar",
    "sollozo": "so-llo-zo",
    "solmenar": "sol-me-nar",
    "solo": "so-lo",
    "sólo": "só-lo",
    "sololateca": "so-lo-la-te-ca",
    "sololateco": "so-lo-la-te-co",
    "solombra": "so-lom-bra",
    "solombría": "so-lom-brí-a",
    "solomillo": "so-lo-mi-llo",
    "solomo": "so-lo-mo",
    "solsonense": "sol-so-nen-se",
    "solsticial": "sols-ti-cial",
    "solsticio": "sols-ti-cio",
    "soltadiza": "sol-ta-di-za",
    "soltadizo": "sol-ta-di-zo",
    "soltador": "sol-ta-dor",
    "soltadora": "sol-ta-do-ra",
    "soltaní": "sol-ta-ní",
    "soltar": "sol-tar",
    "soltera": "sol-te-ra",
    "soltería": "sol-te-rí-a",
    "soltero": "sol-te-ro",
    "solterón": "sol-te-rón",
    "solterona": "sol-te-ro-na",
    "soltura": "sol-tu-ra",
    "solubilidad": "so-lu-bi-li-dad",
    "soluble": "so-lu-ble",
    "solución": "so-lu-ción",
    "solucionar": "so-lu-cio-nar",
    "solutiva": "so-lu-ti-va",
    "solutivo": "so-lu-ti-vo",
    "soluto": "so-lu-to",
    "solutrense": "so-lu-tren-se",
    "solvencia": "sol-ven-cia",
    "solventar": "sol-ven-tar",
    "solvente": "sol-ven-te",
    "solver": "sol-ver",
    "soma": "so-ma",
    "somalí": "so-ma-lí",
    "somanta": "so-man-ta",
    "somarrar": "so-ma-rrar",
    "somarro": "so-ma-rro",
    "somatada": "so-ma-ta-da",
    "somatar": "so-ma-tar",
    "somatén": "so-ma-tén",
    "somatenista": "so-ma-te-nis-ta",
    "somática": "so-má-ti-ca",
    "somático": "so-má-ti-co",
    "somatización": "so-ma-ti-za-ción",
    "somatizado": "so-ma-ti-za-do",
    "somatizar": "so-ma-ti-zar",
    "somatología": "so-ma-to-lo-gí-a",
    "somatón": "so-ma-tón",
    "sombra": "som-bra",
    "sombraje": "som-bra-je",
    "sombrajo": "som-bra-jo",
    "sombrar": "som-brar",
    "sombreado": "som-bre-a-do",
    "sombreador": "som-bre-a-dor",
    "sombreadora": "som-bre-a-do-ra",
    "sombrear": "som-bre-ar",
    "sombrera": "som-bre-ra",
    "sombrerada": "som-bre-ra-da",
    "sombrerazo": "som-bre-ra-zo",
    "sombrerear": "som-bre-re-ar",
    "sombrerera": "som-bre-re-ra",
    "sombrerería": "som-bre-re-rí-a",
    "sombrerero": "som-bre-re-ro",
    "sombrerete": "som-bre-re-te",
    "sombrerillo": "som-bre-ri-llo",
    "sombrero": "som-bre-ro",
    "sombreruda": "som-bre-ru-da",
    "sombrerudo": "som-bre-ru-do",
    "sombría": "som-brí-a",
    "sombrilla": "som-bri-lla",
    "sombrillazo": "som-bri-lla-zo",
    "sombrío": "som-brí-o",
    "sombrosa": "som-bro-sa",
    "sombroso": "som-bro-so",
    "somera": "so-me-ra",
    "someramente": "so-me-ra-men-te",
    "somero": "so-me-ro",
    "someter": "so-me-ter",
    "somética": "so-mé-ti-ca",
    "somético": "so-mé-ti-co",
    "sometimiento": "so-me-ti-mien-to",
    "somier": "so-mier",
    "somnámbula": "som-nám-bu-la",
    "somnambulismo": "som-nam-bu-lis-mo",
    "somnámbulo": "som-nám-bu-lo",
    "somnífera": "som-ní-fe-ra",
    "somnífero": "som-ní-fe-ro",
    "somnílocua": "som-ní-lo-cua",
    "somnílocuo": "som-ní-lo-cuo",
    "somnolencia": "som-no-len-cia",
    "somnoliento": "som-no-lien-to",
    "somo": "so-mo",
    "somocismo": "so-mo-cis-mo",
    "somocista": "so-mo-cis-ta",
    "somontana": "so-mon-ta-na",
    "somontano": "so-mon-ta-no",
    "somonte": "so-mon-te",
    "somorgujador": "so-mor-gu-ja-dor",
    "somorgujar": "so-mor-gu-jar",
    "somorgujo": "so-mor-gu-jo",
    "somorgujón": "so-mor-gu-jón",
    "somormujar": "so-mor-mu-jar",
    "somormujo": "so-mor-mu-jo",
    "somoteña": "so-mo-te-ña",
    "somoteño": "so-mo-te-ño",
    "sompantle": "som-pan-tle",
    "sompesar": "som-pe-sar",
    "sompopera": "som-po-pe-ra",
    "sompopo": "som-po-po",
    "sonable": "so-na-ble",
    "soñación": "so-ña-ción",
    "sonada": "so-na-da",
    "sonadera": "so-na-de-ra",
    "sonadero": "so-na-de-ro",
    "sonado": "so-na-do",
    "sonador": "so-na-dor",
    "soñador": "so-ña-dor",
    "sonadora": "so-na-do-ra",
    "soñadora": "so-ña-do-ra",
    "sonaja": "so-na-ja",
    "sonajear": "so-na-je-ar",
    "sonajera": "so-na-je-ra",
    "sonajero": "so-na-je-ro",
    "sonámbula": "so-nám-bu-la",
    "sonambulismo": "so-nam-bu-lis-mo",
    "sonámbulo": "so-nám-bu-lo",
    "sonante": "so-nan-te",
    "sonántico": "so-nán-ti-co",
    "sonar": "so-nar",
    "soñar": "so-ñar",
    "soñarrera": "so-ña-rre-ra",
    "sonata": "so-na-ta",
    "sonatina": "so-na-ti-na",
    "soncera": "son-ce-ra",
    "sonchiche": "son-chi-che",
    "soncle": "son-cle",
    "sonda": "son-da",
    "sondable": "son-da-ble",
    "sondaleza": "son-da-le-za",
    "sondar": "son-dar",
    "sondeable": "son-de-a-ble",
    "sondear": "son-de-ar",
    "sondeo": "son-de-o",
    "sonecillo": "so-ne-ci-llo",
    "soñera": "so-ñe-ra",
    "sonería": "so-ne-rí-a",
    "sonetear": "so-ne-te-ar",
    "sonetico": "so-ne-ti-co",
    "sonetillo": "so-ne-ti-llo",
    "sonetista": "so-ne-tis-ta",
    "sonetizar": "so-ne-ti-zar",
    "soneto": "so-ne-to",
    "songo": "son-go",
    "soniche": "so-ni-che",
    "sónico": "só-ni-co",
    "sonido": "so-ni-do",
    "sonio": "so-nio",
    "sonique": "so-ni-que",
    "soniquete": "so-ni-que-te",
    "sonlocada": "son-lo-ca-da",
    "sonlocado": "son-lo-ca-do",
    "sonochada": "so-no-cha-da",
    "sonochar": "so-no-char",
    "soñolencia": "so-ño-len-cia",
    "soñolenta": "so-ño-len-ta",
    "soñolento": "so-ño-len-to",
    "soñolienta": "so-ño-lien-ta",
    "soñolientamente": "so-ño-lien-ta-men-te",
    "soñoliento": "so-ño-lien-to",
    "sonómetro": "so-nó-me-tro",
    "sonora": "so-no-ra",
    "sonoramente": "so-no-ra-men-te",
    "sonorense": "so-no-ren-se",
    "sonoridad": "so-no-ri-dad",
    "sonorización": "so-no-ri-za-ción",
    "sonorizador": "so-no-ri-za-dor",
    "sonorizadora": "so-no-ri-za-do-ra",
    "sonorizar": "so-no-ri-zar",
    "sonoro": "so-no-ro",
    "sonorosa": "so-no-ro-sa",
    "sonoroso": "so-no-ro-so",
    "sonotone": "so-no-to-ne",
    "sonreír": "son-re-ír",
    "sonriente": "son-rien-te",
    "sonrisa": "son-ri-sa",
    "sonriso": "son-ri-so",
    "sonrisueña": "son-ri-sue-ña",
    "sonrisueño": "son-ri-sue-ño",
    "sonrodar": "son-ro-dar",
    "sonrodarse": "son-ro-dar-se",
    "sonrojar": "son-ro-jar",
    "sonrojear": "son-ro-je-ar",
    "sonrojo": "son-ro-jo",
    "sonrosado": "son-ro-sa-do",
    "sonrosar": "son-ro-sar",
    "sonrosear": "son-ro-se-ar",
    "sonroseo": "son-ro-se-o",
    "sonrugir": "son-ru-gir",
    "sonrugirse": "son-ru-gir-se",
    "sonsa": "son-sa",
    "sonsaca": "son-sa-ca",
    "sonsacador": "son-sa-ca-dor",
    "sonsacadora": "son-sa-ca-do-ra",
    "sonsacamiento": "son-sa-ca-mien-to",
    "sonsacar": "son-sa-car",
    "sonsañar": "son-sa-ñar",
    "sonsaque": "son-sa-que",
    "sonsear": "son-se-ar",
    "sonsera": "son-se-ra",
    "sonso": "son-so",
    "sonsonateca": "son-so-na-te-ca",
    "sonsonateco": "son-so-na-te-co",
    "sonsonete": "son-so-ne-te",
    "sonta": "son-ta",
    "sonto": "son-to",
    "sonzapote": "son-za-po-te",
    "sopa": "so-pa",
    "sopaipa": "so-pai-pa",
    "sopaipilla": "so-pai-pi-lla",
    "sopalancar": "so-pa-lan-car",
    "sopalanda": "so-pa-lan-da",
    "sopanda": "so-pan-da",
    "sopapear": "so-pa-pe-ar",
    "sopapina": "so-pa-pi-na",
    "sopapo": "so-pa-po",
    "sopar": "so-par",
    "sope": "so-pe",
    "sopear": "so-pe-ar",
    "sopeña": "so-pe-ña",
    "sopera": "so-pe-ra",
    "sopero": "so-pe-ro",
    "sopesar": "so-pe-sar",
    "sopete": "so-pe-te",
    "sopetear": "so-pe-te-ar",
    "sopeteo": "so-pe-te-o",
    "sopetón": "so-pe-tón",
    "sopicaldo": "so-pi-cal-do",
    "sopié": "so-pié",
    "sopilote": "so-pi-lo-te",
    "sopista": "so-pis-ta",
    "sopitipando": "so-pi-ti-pan-do",
    "soplada": "so-pla-da",
    "sopladero": "so-pla-de-ro",
    "soplado": "so-pla-do",
    "soplador": "so-pla-dor",
    "sopladora": "so-pla-do-ra",
    "sopladura": "so-pla-du-ra",
    "soplagaitas": "so-pla-gai-tas",
    "soplamocos": "so-pla-mo-cos",
    "soplante": "so-plan-te",
    "soplapollas": "so-pla-po-llas",
    "soplar": "so-plar",
    "soplas": "so-plas",
    "soplavivo": "so-pla-vi-vo",
    "soplazón": "so-pla-zón",
    "soplete": "so-ple-te",
    "soplido": "so-pli-do",
    "soplillo": "so-pli-llo",
    "soplo": "so-plo",
    "soplón": "so-plón",
    "soplona": "so-plo-na",
    "soplonaje": "so-plo-na-je",
    "soplonear": "so-plo-ne-ar",
    "soplonería": "so-plo-ne-rí-a",
    "sopón": "so-pón",
    "soponcio": "so-pon-cio",
    "sopor": "so-por",
    "soporífera": "so-po-rí-fe-ra",
    "soporífero": "so-po-rí-fe-ro",
    "soporosa": "so-po-ro-sa",
    "soporoso": "so-po-ro-so",
    "soportable": "so-por-ta-ble",
    "soportador": "so-por-ta-dor",
    "soportadora": "so-por-ta-do-ra",
    "soportal": "so-por-tal",
    "soportar": "so-por-tar",
    "soporte": "so-por-te",
    "sopórtico": "so-pór-ti-co",
    "soprano": "so-pra-no",
    "sopuntar": "so-pun-tar",
    "soquear": "so-que-ar",
    "sóquet": "só-quet",
    "soquete": "so-que-te",
    "sora": "so-ra",
    "sorateña": "so-ra-te-ña",
    "sorateño": "so-ra-te-ño",
    "sorba": "sor-ba",
    "sorbedor": "sor-be-dor",
    "sorbedora": "sor-be-do-ra",
    "sorber": "sor-ber",
    "sorbete": "sor-be-te",
    "sorbeto": "sor-be-to",
    "sorbible": "sor-bi-ble",
    "sorbición": "sor-bi-ción",
    "sorbo": "sor-bo",
    "sorce": "sor-ce",
    "sorche": "sor-che",
    "sorchi": "sor-chi",
    "sorda": "sor-da",
    "sordamente": "sor-da-men-te",
    "sordedad": "sor-de-dad",
    "sordera": "sor-de-ra",
    "sordez": "sor-dez",
    "sórdida": "sór-di-da",
    "sórdidamente": "sór-di-da-men-te",
    "sordidez": "sor-di-dez",
    "sórdido": "sór-di-do",
    "sordilla": "sor-di-lla",
    "sordina": "sor-di-na",
    "sordino": "sor-di-no",
    "sordo": "sor-do",
    "sordomuda": "sor-do-mu-da",
    "sordomudez": "sor-do-mu-dez",
    "sordomudo": "sor-do-mu-do",
    "sordón": "sor-dón",
    "sorgo": "sor-go",
    "sorguicultor": "sor-gui-cul-tor",
    "sorguicultora": "sor-gui-cul-to-ra",
    "soria": "so-ria",
    "soriana": "so-ria-na",
    "sorianense": "so-ria-nen-se",
    "soriano": "so-ria-no",
    "sorites": "so-ri-tes",
    "sorna": "sor-na",
    "sornaguear": "sor-na-gue-ar",
    "sornar": "sor-nar",
    "sornijear": "sor-ni-je-ar",
    "soro": "so-ro",
    "soroche": "so-ro-che",
    "sorocho": "so-ro-cho",
    "sorococo": "so-ro-co-co",
    "soroconti": "so-ro-con-ti",
    "sorojchi": "so-roj-chi",
    "soropete": "so-ro-pe-te",
    "sóror": "só-ror",
    "sororal": "so-ro-ral",
    "sorprendente": "sor-pren-den-te",
    "sorprender": "sor-pren-der",
    "sorpresa": "sor-pre-sa",
    "sorpresivo": "sor-pre-si-vo",
    "sorra": "so-rra",
    "sorrabar": "so-rra-bar",
    "sorrapar": "so-rra-par",
    "sorrapear": "so-rra-pe-ar",
    "sorregar": "so-rre-gar",
    "sorriego": "so-rrie-go",
    "sorripiar": "so-rri-piar",
    "sorrostrada": "so-rros-tra-da",
    "sortario": "sor-ta-rio",
    "sorteable": "sor-te-a-ble",
    "sorteador": "sor-te-a-dor",
    "sorteadora": "sor-te-a-do-ra",
    "sorteamiento": "sor-te-a-mien-to",
    "sortear": "sor-te-ar",
    "sorteo": "sor-te-o",
    "sortera": "sor-te-ra",
    "sortería": "sor-te-rí-a",
    "sortero": "sor-te-ro",
    "sortiaria": "sor-tia-ria",
    "sortija": "sor-ti-ja",
    "sortijero": "sor-ti-je-ro",
    "sortijilla": "sor-ti-ji-lla",
    "sortijón": "sor-ti-jón",
    "sortílega": "sor-tí-le-ga",
    "sortilegio": "sor-ti-le-gio",
    "sortílego": "sor-tí-le-go",
    "sorullo": "so-ru-llo",
    "sosa": "so-sa",
    "sosacador": "so-sa-ca-dor",
    "sosacadora": "so-sa-ca-do-ra",
    "sosacar": "so-sa-car",
    "sosaina": "so-sai-na",
    "sosal": "so-sal",
    "sosamente": "so-sa-men-te",
    "sosañar": "so-sa-ñar",
    "sosaño": "so-sa-ño",
    "sosar": "so-sar",
    "sosedad": "so-se-dad",
    "sosegada": "so-se-ga-da",
    "sosegadamente": "so-se-ga-da-men-te",
    "sosegado": "so-se-ga-do",
    "sosegador": "so-se-ga-dor",
    "sosegadora": "so-se-ga-do-ra",
    "sosegar": "so-se-gar",
    "sosegate": "so-se-ga-te",
    "sosera": "so-se-ra",
    "soseras": "so-se-ras",
    "sosería": "so-se-rí-a",
    "sosero": "so-se-ro",
    "sosia": "so-sia",
    "sosias": "so-sias",
    "sosiega": "so-sie-ga",
    "sosiego": "so-sie-go",
    "soslaya": "sos-la-ya",
    "soslayar": "sos-la-yar",
    "soslayo": "sos-la-yo",
    "soso": "so-so",
    "sospecha": "sos-pe-cha",
    "sospechable": "sos-pe-cha-ble",
    "sospechar": "sos-pe-char",
    "sospechosa": "sos-pe-cho-sa",
    "sospechosamente": "sos-pe-cho-sa-men-te",
    "sospechoso": "sos-pe-cho-so",
    "sospesar": "sos-pe-sar",
    "sosquín": "sos-quín",
    "sostén": "sos-tén",
    "sostenedor": "sos-te-ne-dor",
    "sostenedora": "sos-te-ne-do-ra",
    "sostener": "sos-te-ner",
    "sostenible": "sos-te-ni-ble",
    "sostenida": "sos-te-ni-da",
    "sostenido": "sos-te-ni-do",
    "sostenimiento": "sos-te-ni-mien-to",
    "sostituir": "sos-ti-tuir",
    "sota": "so-ta",
    "sotabanco": "so-ta-ban-co",
    "sotabarba": "so-ta-bar-ba",
    "sotacola": "so-ta-co-la",
    "sotacoro": "so-ta-co-ro",
    "sotacura": "so-ta-cu-ra",
    "sotalugo": "so-ta-lu-go",
    "sotaministro": "so-ta-mi-nis-tro",
    "sotamontero": "so-ta-mon-te-ro",
    "sotana": "so-ta-na",
    "sotanear": "so-ta-ne-ar",
    "sotaní": "so-ta-ní",
    "sotanilla": "so-ta-ni-lla",
    "sótano": "só-ta-no",
    "sotar": "so-tar",
    "sotaventar": "so-ta-ven-tar",
    "sotaventarse": "so-ta-ven-tar-se",
    "sotaventeado": "so-ta-ven-te-a-do",
    "sotaventear": "so-ta-ven-te-ar",
    "sotaventearse": "so-ta-ven-te-ar-se",
    "sotavento": "so-ta-ven-to",
    "sotayuda": "so-ta-yu-da",
    "sote": "so-te",
    "sotechado": "so-te-cha-do",
    "soteña": "so-te-ña",
    "soteño": "so-te-ño",
    "sotera": "so-te-ra",
    "soteriología": "so-te-rio-lo-gí-a",
    "soteriológico": "so-te-rio-ló-gi-co",
    "soterramiento": "so-te-rra-mien-to",
    "soterraña": "so-te-rra-ña",
    "soterránea": "so-te-rrá-ne-a",
    "soterráneo": "so-te-rrá-ne-o",
    "soterrano": "so-te-rra-no",
    "soterraño": "so-te-rra-ño",
    "soterrar": "so-te-rrar",
    "sotil": "so-til",
    "sotileza": "so-ti-le-za",
    "sotilidad": "so-ti-li-dad",
    "soto": "so-to",
    "sotobosque": "so-to-bos-que",
    "sotol": "so-tol",
    "sotoministro": "so-to-mi-nis-tro",
    "sotorrey": "so-to-rrey",
    "sotreta": "so-tre-ta",
    "sotrozo": "so-tro-zo",
    "sottovoce": "sot-to-vo-ce",
    "sotuer": "so-tuer",
    "soturna": "so-tur-na",
    "soturno": "so-tur-no",
    "soufflé": "souf-flé",
    "sousafón": "sou-sa-fón",
    "soutien": "sou-tien",
    "soviet": "so-viet",
    "sóviet": "só-viet",
    "soviética": "so-vié-ti-ca",
    "soviético": "so-vié-ti-co",
    "sovietización": "so-vie-ti-za-ción",
    "sovietizar": "so-vie-ti-zar",
    "sovietología": "so-vie-to-lo-gí-a",
    "sovjós": "sov-jós",
    "sovoz": "so-voz",
    "soya": "so-ya",
    "spaghetti": "s-pa-ghe-ti",
    "spanglish": "s-pan-glish",
    "spaniel": "s-pa-niel",
    "sparring": "s-pa-rring",
    "spinning": "s-pi-nning",
    "stoa": "s-to-a",
    "stradivarius": "s-tra-di-va-rius",
    "suaba": "sua-ba",
    "suabo": "sua-bo",
    "suaca": "sua-ca",
    "suadir": "sua-dir",
    "suajili": "sua-ji-li",
    "suarda": "suar-da",
    "suarismo": "sua-ris-mo",
    "suarista": "sua-ris-ta",
    "suasible": "sua-si-ble",
    "suasoria": "sua-so-ria",
    "suasorio": "sua-so-rio",
    "suata": "sua-ta",
    "suato": "sua-to",
    "suave": "sua-ve",
    "suavemente": "sua-ve-men-te",
    "suavena": "sua-ve-na",
    "suavidad": "sua-vi-dad",
    "suavización": "sua-vi-za-ción",
    "suavizador": "sua-vi-za-dor",
    "suavizadora": "sua-vi-za-do-ra",
    "suavizante": "sua-vi-zan-te",
    "suavizar": "sua-vi-zar",
    "suazi": "sua-zi",
    "suba": "su-ba",
    "subacetato": "su-ba-ce-ta-to",
    "subacuático": "su-ba-cuá-ti-co",
    "subafluente": "su-ba-fluen-te",
    "subalcaide": "su-bal-cai-de",
    "subalimentar": "su-ba-li-men-tar",
    "subalpino": "su-bal-pi-no",
    "subalterna": "su-bal-ter-na",
    "subalternar": "su-bal-ter-nar",
    "subalterno": "su-bal-ter-no",
    "subálvea": "su-bál-ve-a",
    "subálveo": "su-bál-ve-o",
    "subarrendador": "su-ba-rren-da-dor",
    "subarrendadora": "su-ba-rren-da-do-ra",
    "subarrendamiento": "su-ba-rren-da-mien-to",
    "subarrendar": "su-ba-rren-dar",
    "subarrendataria": "su-ba-rren-da-ta-ria",
    "subarrendatario": "su-ba-rren-da-ta-rio",
    "subarriendo": "su-ba-rrien-do",
    "subártico": "su-bár-ti-co",
    "subasta": "su-bas-ta",
    "subastación": "su-bas-ta-ción",
    "subastador": "su-bas-ta-dor",
    "subastadora": "su-bas-ta-do-ra",
    "subastar": "su-bas-tar",
    "subastera": "su-bas-te-ra",
    "subastero": "su-bas-te-ro",
    "subatómico": "su-ba-tó-mi-co",
    "subcampeón": "sub-cam-pe-ón",
    "subcampeona": "sub-cam-pe-o-na",
    "subcampeonato": "sub-cam-pe-o-na-to",
    "subcategoría": "sub-ca-te-go-rí-a",
    "subcelular": "sub-ce-lu-lar",
    "subcinericio": "sub-ci-ne-ri-cio",
    "subclase": "sub-cla-se",
    "subclavero": "sub-cla-ve-ro",
    "subclavia": "sub-cla-via",
    "subclavio": "sub-cla-vio",
    "subcolector": "sub-co-lec-tor",
    "subcomandante": "sub-co-man-dan-te",
    "subcomendador": "sub-co-men-da-dor",
    "subcomisaria": "sub-co-mi-sa-ria",
    "subcomisario": "sub-co-mi-sa-rio",
    "subcomisión": "sub-co-mi-sión",
    "subconciencia": "sub-con-cien-cia",
    "subconjunto": "sub-con-jun-to",
    "subconsciencia": "sub-cons-cien-cia",
    "subconsciente": "sub-cons-cien-te",
    "subconservador": "sub-con-ser-va-dor",
    "subcontinente": "sub-con-ti-nen-te",
    "subcontrata": "sub-con-tra-ta",
    "subcontratación": "sub-con-tra-ta-ción",
    "subcontratar": "sub-con-tra-tar",
    "subcontratista": "sub-con-tra-tis-ta",
    "subcostal": "sub-cos-tal",
    "subcultura": "sub-cul-tu-ra",
    "subcutánea": "sub-cu-tá-ne-a",
    "subcutáneo": "sub-cu-tá-ne-o",
    "subdelegable": "sub-de-le-ga-ble",
    "subdelegación": "sub-de-le-ga-ción",
    "subdelegada": "sub-de-le-ga-da",
    "subdelegado": "sub-de-le-ga-do",
    "subdelegar": "sub-de-le-gar",
    "subdelirio": "sub-de-li-rio",
    "subdesarrollado": "sub-de-sa-rro-lla-do",
    "subdesarrollo": "sub-de-sa-rro-llo",
    "subdesértico": "sub-de-sér-ti-co",
    "subdiaconado": "sub-dia-co-na-do",
    "subdiaconal": "sub-dia-co-nal",
    "subdiaconato": "sub-dia-co-na-to",
    "subdiácono": "sub-diá-co-no",
    "subdirección": "sub-di-rec-ción",
    "subdirector": "sub-di-rec-tor",
    "subdirectora": "sub-di-rec-to-ra",
    "subdirectorio": "sub-di-rec-to-rio",
    "subdistinción": "sub-dis-tin-ción",
    "subdistinguir": "sub-dis-tin-guir",
    "súbdita": "súb-di-ta",
    "súbdito": "súb-di-to",
    "subdividir": "sub-di-vi-dir",
    "subdivisión": "sub-di-vi-sión",
    "subdominante": "sub-do-mi-nan-te",
    "subducción": "sub-duc-ción",
    "subdupla": "sub-du-pla",
    "subduplo": "sub-du-plo",
    "subeibaja": "su-bei-ba-ja",
    "subejecutor": "su-be-je-cu-tor",
    "subemplear": "su-bem-ple-ar",
    "subempleo": "su-bem-ple-o",
    "subentender": "su-ben-ten-der",
    "subeo": "su-be-o",
    "suberificación": "su-be-ri-fi-ca-ción",
    "suberificar": "su-be-ri-fi-car",
    "suberina": "su-be-ri-na",
    "suberosa": "su-be-ro-sa",
    "suberoso": "su-be-ro-so",
    "subespecie": "su-bes-pe-cie",
    "subestación": "su-bes-ta-ción",
    "subestimación": "su-bes-ti-ma-ción",
    "subestimar": "su-bes-ti-mar",
    "subfamilia": "sub-fa-mi-lia",
    "subfebril": "sub-fe-bril",
    "subfiador": "sub-fia-dor",
    "subfiadora": "sub-fia-do-ra",
    "subfilo": "sub-fi-lo",
    "subforo": "sub-fo-ro",
    "subfusil": "sub-fu-sil",
    "subgénero": "sub-gé-ne-ro",
    "subgobernador": "sub-go-ber-na-dor",
    "subgobernadora": "sub-go-ber-na-do-ra",
    "subgrupo": "sub-gru-po",
    "subibaja": "su-bi-ba-ja",
    "subida": "su-bi-da",
    "subidamente": "su-bi-da-men-te",
    "subidera": "su-bi-de-ra",
    "subidero": "su-bi-de-ro",
    "subido": "su-bi-do",
    "subidón": "su-bi-dón",
    "subidor": "su-bi-dor",
    "subienda": "su-bien-da",
    "subiente": "su-bien-te",
    "subigüela": "su-bi-güe-la",
    "subilla": "su-bi-lla",
    "subimiento": "su-bi-mien-to",
    "subíndice": "su-bín-di-ce",
    "subinspección": "su-bins-pec-ción",
    "subinspector": "su-bins-pec-tor",
    "subinspectora": "su-bins-pec-to-ra",
    "subintendencia": "su-bin-ten-den-cia",
    "subintendente": "su-bin-ten-den-te",
    "subintración": "su-bin-tra-ción",
    "subintrante": "su-bin-tran-te",
    "subintrar": "su-bin-trar",
    "subir": "su-bir",
    "súbita": "sú-bi-ta",
    "súbitamente": "sú-bi-ta-men-te",
    "subitánea": "su-bi-tá-ne-a",
    "subitáneamente": "su-bi-tá-ne-a-men-te",
    "subitáneo": "su-bi-tá-ne-o",
    "súbito": "sú-bi-to",
    "subjectar": "sub-jec-tar",
    "subjefa": "sub-je-fa",
    "subjefe": "sub-je-fe",
    "subjetiva": "sub-je-ti-va",
    "subjetividad": "sub-je-ti-vi-dad",
    "subjetivismo": "sub-je-ti-vis-mo",
    "subjetivista": "sub-je-ti-vis-ta",
    "subjetivo": "sub-je-ti-vo",
    "subjeto": "sub-je-to",
    "subjuntivo": "sub-jun-ti-vo",
    "subjuzgar": "sub-juz-gar",
    "sublevación": "su-ble-va-ción",
    "sublevamiento": "su-ble-va-mien-to",
    "sublevar": "su-ble-var",
    "sublimable": "su-bli-ma-ble",
    "sublimación": "su-bli-ma-ción",
    "sublimado": "su-bli-ma-do",
    "sublimar": "su-bli-mar",
    "sublimatoria": "su-bli-ma-to-ria",
    "sublimatorio": "su-bli-ma-to-rio",
    "sublime": "su-bli-me",
    "sublimemente": "su-bli-me-men-te",
    "sublimidad": "su-bli-mi-dad",
    "subliminal": "su-bli-mi-nal",
    "sublingual": "su-blin-gual",
    "sublunar": "su-blu-nar",
    "submarina": "sub-ma-ri-na",
    "submarinismo": "sub-ma-ri-nis-mo",
    "submarinista": "sub-ma-ri-nis-ta",
    "submarino": "sub-ma-ri-no",
    "submaxilar": "sub-ma-xi-lar",
    "subministración": "sub-mi-nis-tra-ción",
    "subministrador": "sub-mi-nis-tra-dor",
    "subministradora": "sub-mi-nis-tra-do-ra",
    "subministrar": "sub-mi-nis-trar",
    "submúltipla": "sub-múl-ti-pla",
    "submúltiplo": "sub-múl-ti-plo",
    "submundo": "sub-mun-do",
    "subnitrato": "sub-ni-tra-to",
    "subnormal": "sub-nor-mal",
    "subnormalidad": "sub-nor-ma-li-dad",
    "subnota": "sub-no-ta",
    "suboficial": "su-bo-fi-cial",
    "suborden": "su-bor-den",
    "subordinación": "su-bor-di-na-ción",
    "subordinada": "su-bor-di-na-da",
    "subordinadamente": "su-bor-di-na-da-men-te",
    "subordinado": "su-bor-di-na-do",
    "subordinante": "su-bor-di-nan-te",
    "subordinar": "su-bor-di-nar",
    "subprefecto": "sub-pre-fec-to",
    "subprefectura": "sub-pre-fec-tu-ra",
    "subproducto": "sub-pro-duc-to",
    "subranquial": "su-bran-quial",
    "subrayable": "su-bra-ya-ble",
    "subrayada": "su-bra-ya-da",
    "subrayado": "su-bra-ya-do",
    "subrayar": "su-bra-yar",
    "subregión": "su-bre-gión",
    "subreino": "su-brei-no",
    "subrepción": "su-brep-ción",
    "subrepticia": "su-brep-ti-cia",
    "subrepticiamente": "su-brep-ti-cia-men-te",
    "subrepticio": "su-brep-ti-cio",
    "subrigadier": "su-bri-ga-dier",
    "subrogación": "su-bro-ga-ción",
    "subrogar": "su-bro-gar",
    "subsahariana": "sub-sa-ha-ria-na",
    "subsahariano": "sub-sa-ha-ria-no",
    "subsanable": "sub-sa-na-ble",
    "subsanación": "sub-sa-na-ción",
    "subsanar": "sub-sa-nar",
    "subscapular": "subs-ca-pu-lar",
    "subscribir": "subs-cri-bir",
    "subscripción": "subs-crip-ción",
    "subscripta": "subs-crip-ta",
    "subscripto": "subs-crip-to",
    "subscriptor": "subs-crip-tor",
    "subscriptora": "subs-crip-to-ra",
    "subscrita": "subs-cri-ta",
    "subscrito": "subs-cri-to",
    "subscritor": "subs-cri-tor",
    "subscritora": "subs-cri-to-ra",
    "subsecretaría": "sub-se-cre-ta-rí-a",
    "subsecretaria": "sub-se-cre-ta-ria",
    "subsecretario": "sub-se-cre-ta-rio",
    "subsector": "sub-sec-tor",
    "subsecuente": "sub-se-cuen-te",
    "subseguir": "sub-se-guir",
    "subseyente": "sub-se-yen-te",
    "subsidencia": "sub-si-den-cia",
    "subsidiar": "sub-si-diar",
    "subsidiaria": "sub-si-dia-ria",
    "subsidiariamente": "sub-si-dia-ria-men-te",
    "subsidiaridad": "sub-si-dia-ri-dad",
    "subsidiariedad": "sub-si-dia-rie-dad",
    "subsidiario": "sub-si-dia-rio",
    "subsidio": "sub-si-dio",
    "subsiguiente": "sub-si-guien-te",
    "subsistencia": "sub-sis-ten-cia",
    "subsistente": "sub-sis-ten-te",
    "subsistir": "sub-sis-tir",
    "subsolador": "sub-so-la-dor",
    "subsolano": "sub-so-la-no",
    "subsolar": "sub-so-lar",
    "subsónico": "sub-só-ni-co",
    "substancia": "subs-tan-cia",
    "substanciación": "subs-tan-cia-ción",
    "substancial": "subs-tan-cial",
    "substancialismo": "subs-tan-cia-lis-mo",
    "substancialmente": "subs-tan-cial-men-te",
    "substanciar": "subs-tan-ciar",
    "substanciosa": "subs-tan-cio-sa",
    "substancioso": "subs-tan-cio-so",
    "substantiva": "subs-tan-ti-va",
    "substantivación": "subs-tan-ti-va-ción",
    "substantivamente": "subs-tan-ti-va-men-te",
    "substantivar": "subs-tan-ti-var",
    "substantividad": "subs-tan-ti-vi-dad",
    "substantivo": "subs-tan-ti-vo",
    "substitución": "subs-ti-tu-ción",
    "substituible": "subs-ti-tui-ble",
    "substituidor": "subs-ti-tui-dor",
    "substituidora": "subs-ti-tui-do-ra",
    "substituir": "subs-ti-tuir",
    "substituta": "subs-ti-tu-ta",
    "substitutivo": "subs-ti-tu-ti-vo",
    "substituto": "subs-ti-tu-to",
    "substitutorio": "subs-ti-tu-to-rio",
    "substracción": "subs-trac-ción",
    "substractivo": "subs-trac-ti-vo",
    "substraendo": "subs-tra-en-do",
    "substraer": "subs-tra-er",
    "substrato": "subs-tra-to",
    "subsuelo": "sub-sue-lo",
    "subsumir": "sub-su-mir",
    "subsunción": "sub-sun-ción",
    "subte": "sub-te",
    "subtender": "sub-ten-der",
    "subtenencia": "sub-te-nen-cia",
    "subtenienta": "sub-te-nien-ta",
    "subteniente": "sub-te-nien-te",
    "subtensa": "sub-ten-sa",
    "subterfugio": "sub-ter-fu-gio",
    "subterránea": "sub-te-rrá-ne-a",
    "subterráneamente": "sub-te-rrá-ne-a-men-te",
    "subterráneo": "sub-te-rrá-ne-o",
    "subtilizar": "sub-ti-li-zar",
    "subtipo": "sub-ti-po",
    "subtitulado": "sub-ti-tu-la-do",
    "subtitular": "sub-ti-tu-lar",
    "subtítulo": "sub-tí-tu-lo",
    "subtropical": "sub-tro-pi-cal",
    "suburbana": "su-bur-ba-na",
    "suburbano": "su-bur-ba-no",
    "suburbial": "su-bur-bial",
    "suburbicaria": "su-bur-bi-ca-ria",
    "suburbicario": "su-bur-bi-ca-rio",
    "suburbio": "su-bur-bio",
    "suburense": "su-bu-ren-se",
    "subvalorar": "sub-va-lo-rar",
    "subvención": "sub-ven-ción",
    "subvencionar": "sub-ven-cio-nar",
    "subvenio": "sub-ve-nio",
    "subvenir": "sub-ve-nir",
    "subversión": "sub-ver-sión",
    "subversiva": "sub-ver-si-va",
    "subversivo": "sub-ver-si-vo",
    "subversor": "sub-ver-sor",
    "subversora": "sub-ver-so-ra",
    "subvertir": "sub-ver-tir",
    "subyacente": "sub-ya-cen-te",
    "subyacer": "sub-ya-cer",
    "subyugable": "sub-yu-ga-ble",
    "subyugación": "sub-yu-ga-ción",
    "subyugador": "sub-yu-ga-dor",
    "subyugadora": "sub-yu-ga-do-ra",
    "subyugante": "sub-yu-gan-te",
    "subyugar": "sub-yu-gar",
    "suca": "su-ca",
    "succenturiado": "suc-cen-tu-ria-do",
    "succino": "suc-ci-no",
    "succión": "suc-ción",
    "succionar": "suc-cio-nar",
    "sucedánea": "su-ce-dá-ne-a",
    "sucedáneo": "su-ce-dá-ne-o",
    "suceder": "su-ce-der",
    "sucedido": "su-ce-di-do",
    "sucentor": "su-cen-tor",
    "sucesible": "su-ce-si-ble",
    "sucesión": "su-ce-sión",
    "sucesiva": "su-ce-si-va",
    "sucesivamente": "su-ce-si-va-men-te",
    "sucesivo": "su-ce-si-vo",
    "suceso": "su-ce-so",
    "sucesor": "su-ce-sor",
    "sucesora": "su-ce-so-ra",
    "sucesoria": "su-ce-so-ria",
    "sucesorio": "su-ce-so-rio",
    "suche": "su-che",
    "súchel": "sú-chel",
    "súchil": "sú-chil",
    "sucia": "su-cia",
    "suciamente": "su-cia-men-te",
    "suciedad": "su-cie-dad",
    "sucierna": "su-cier-na",
    "sucinda": "su-cin-da",
    "sucinta": "su-cin-ta",
    "sucintamente": "su-cin-ta-men-te",
    "sucintar": "su-cin-tar",
    "sucintarse": "su-cin-tar-se",
    "sucinto": "su-cin-to",
    "sucio": "su-cio",
    "suco": "su-co",
    "sucosa": "su-co-sa",
    "sucoso": "su-co-so",
    "sucotrino": "su-co-tri-no",
    "sucre": "su-cre",
    "sucreña": "su-cre-ña",
    "sucreño": "su-cre-ño",
    "sucrense": "su-cren-se",
    "sucu": "su-cu",
    "súcubo": "sú-cu-bo",
    "sucucho": "su-cu-cho",
    "súcula": "sú-cu-la",
    "suculencia": "su-cu-len-cia",
    "suculenta": "su-cu-len-ta",
    "suculentamente": "su-cu-len-ta-men-te",
    "suculento": "su-cu-len-to",
    "sucumbir": "su-cum-bir",
    "sucumbisense": "su-cum-bi-sen-se",
    "sucunán": "su-cu-nán",
    "sucunango": "su-cu-nan-go",
    "sucursal": "su-cur-sal",
    "sudaca": "su-da-ca",
    "sudación": "su-da-ción",
    "sudadera": "su-da-de-ra",
    "sudadero": "su-da-de-ro",
    "sudador": "su-da-dor",
    "sudafricana": "su-da-fri-ca-na",
    "sudafricano": "su-da-fri-ca-no",
    "sudamericana": "su-da-me-ri-ca-na",
    "sudamericano": "su-da-me-ri-ca-no",
    "sudamina": "su-da-mi-na",
    "sudanés": "su-da-nés",
    "sudanesa": "su-da-ne-sa",
    "sudante": "su-dan-te",
    "sudar": "su-dar",
    "sudario": "su-da-rio",
    "sudatoria": "su-da-to-ria",
    "sudatorio": "su-da-to-rio",
    "sudcoreano": "sud-co-re-a-no",
    "sudestada": "su-des-ta-da",
    "sudeste": "su-des-te",
    "sudista": "su-dis-ta",
    "sudoccidental": "su-doc-ci-den-tal",
    "sudoeste": "su-do-es-te",
    "sudoku": "su-do-ku",
    "sudor": "su-dor",
    "sudoración": "su-do-ra-ción",
    "sudoral": "su-do-ral",
    "sudorienta": "su-do-rien-ta",
    "sudoriental": "su-do-rien-tal",
    "sudoriento": "su-do-rien-to",
    "sudorífera": "su-do-rí-fe-ra",
    "sudorífero": "su-do-rí-fe-ro",
    "sudorífica": "su-do-rí-fi-ca",
    "sudorífico": "su-do-rí-fi-co",
    "sudorípara": "su-do-rí-pa-ra",
    "sudoríparo": "su-do-rí-pa-ro",
    "sudorosa": "su-do-ro-sa",
    "sudoroso": "su-do-ro-so",
    "sudosa": "su-do-sa",
    "sudoso": "su-do-so",
    "sudsudeste": "sud-su-des-te",
    "sudsudoeste": "sud-su-do-es-te",
    "sudueste": "su-dues-te",
    "sueca": "sue-ca",
    "suecana": "sue-ca-na",
    "suecano": "sue-ca-no",
    "suecia": "sue-cia",
    "sueco": "sue-co",
    "suegra": "sue-gra",
    "suegro": "sue-gro",
    "suela": "sue-la",
    "suelada": "sue-la-da",
    "suelazo": "sue-la-zo",
    "suelda": "suel-da",
    "sueldacostilla": "suel-da-cos-ti-lla",
    "sueldo": "suel-do",
    "suelo": "sue-lo",
    "suelta": "suel-ta",
    "sueltamente": "suel-ta-men-te",
    "suelto": "suel-to",
    "sueñista": "sue-ñis-ta",
    "sueno": "sue-no",
    "sueño": "sue-ño",
    "suero": "sue-ro",
    "suerosa": "sue-ro-sa",
    "sueroso": "sue-ro-so",
    "sueroterapia": "sue-ro-te-ra-pia",
    "suerte": "suer-te",
    "suertera": "suer-te-ra",
    "suertero": "suer-te-ro",
    "suertuda": "suer-tu-da",
    "suertudo": "suer-tu-do",
    "sueste": "sues-te",
    "suéter": "sué-ter",
    "sueva": "sue-va",
    "suévica": "sué-vi-ca",
    "suévico": "sué-vi-co",
    "suevo": "sue-vo",
    "sufete": "su-fe-te",
    "sufí": "su-fí",
    "suficiencia": "su-fi-cien-cia",
    "suficiente": "su-fi-cien-te",
    "suficientemente": "su-fi-cien-te-men-te",
    "sufija": "su-fi-ja",
    "sufijación": "su-fi-ja-ción",
    "sufijal": "su-fi-jal",
    "sufijar": "su-fi-jar",
    "sufijo": "su-fi-jo",
    "sufismo": "su-fis-mo",
    "sufista": "su-fis-ta",
    "suflación": "su-fla-ción",
    "suflar": "su-flar",
    "suflé": "su-flé",
    "sufocación": "su-fo-ca-ción",
    "sufocador": "su-fo-ca-dor",
    "sufocadora": "su-fo-ca-do-ra",
    "sufocar": "su-fo-car",
    "sufra": "su-fra",
    "sufragana": "su-fra-ga-na",
    "sufragánea": "su-fra-gá-ne-a",
    "sufragáneo": "su-fra-gá-ne-o",
    "sufragano": "su-fra-ga-no",
    "sufragar": "su-fra-gar",
    "sufragio": "su-fra-gio",
    "sufragismo": "su-fra-gis-mo",
    "sufragista": "su-fra-gis-ta",
    "sufrible": "su-fri-ble",
    "sufrida": "su-fri-da",
    "sufridera": "su-fri-de-ra",
    "sufridero": "su-fri-de-ro",
    "sufrido": "su-fri-do",
    "sufridor": "su-fri-dor",
    "sufridora": "su-fri-do-ra",
    "sufrimiento": "su-fri-mien-to",
    "sufrir": "su-frir",
    "sufumigación": "su-fu-mi-ga-ción",
    "sufusión": "su-fu-sión",
    "sugerencia": "su-ge-ren-cia",
    "sugerente": "su-ge-ren-te",
    "sugeridor": "su-ge-ri-dor",
    "sugeridora": "su-ge-ri-do-ra",
    "sugerir": "su-ge-rir",
    "sugestión": "su-ges-tión",
    "sugestionable": "su-ges-tio-na-ble",
    "sugestionador": "su-ges-tio-na-dor",
    "sugestionadora": "su-ges-tio-na-do-ra",
    "sugestionar": "su-ges-tio-nar",
    "sugestiva": "su-ges-ti-va",
    "sugestivo": "su-ges-ti-vo",
    "sugesto": "su-ges-to",
    "suicida": "sui-ci-da",
    "suicidar": "sui-ci-dar",
    "suicidarse": "sui-ci-dar-se",
    "suicidio": "sui-ci-dio",
    "suido": "sui-do",
    "suindá": "suin-dá",
    "suirirí": "sui-ri-rí",
    "suita": "sui-ta",
    "suite": "sui-te",
    "suiza": "sui-za",
    "suízara": "suí-za-ra",
    "suízaro": "suí-za-ro",
    "suizo": "sui-zo",
    "suizón": "sui-zón",
    "sujeción": "su-je-ción",
    "sujeta": "su-je-ta",
    "sujetador": "su-je-ta-dor",
    "sujetadora": "su-je-ta-do-ra",
    "sujetapapeles": "su-je-ta-pa-pe-les",
    "sujetar": "su-je-tar",
    "sujeto": "su-je-to",
    "sula": "su-la",
    "sulcar": "sul-car",
    "sulco": "sul-co",
    "suletino": "su-le-ti-no",
    "sulfamida": "sul-fa-mi-da",
    "sulfatación": "sul-fa-ta-ción",
    "sulfatado": "sul-fa-ta-do",
    "sulfatador": "sul-fa-ta-dor",
    "sulfatadora": "sul-fa-ta-do-ra",
    "sulfatar": "sul-fa-tar",
    "sulfatillo": "sul-fa-ti-llo",
    "sulfato": "sul-fa-to",
    "sulfhídrica": "sul-fhí-dri-ca",
    "sulfhídrico": "sul-fhí-dri-co",
    "sulfito": "sul-fi-to",
    "sulfonal": "sul-fo-nal",
    "sulfonamida": "sul-fo-na-mi-da",
    "sulfonete": "sul-fo-ne-te",
    "sulfurado": "sul-fu-ra-do",
    "sulfurar": "sul-fu-rar",
    "sulfúrea": "sul-fú-re-a",
    "sulfúreo": "sul-fú-re-o",
    "sulfúrica": "sul-fú-ri-ca",
    "sulfúrico": "sul-fú-ri-co",
    "sulfuro": "sul-fu-ro",
    "sulfurosa": "sul-fu-ro-sa",
    "sulfuroso": "sul-fu-ro-so",
    "sulla": "su-lla",
    "sulpiciana": "sul-pi-cia-na",
    "sulpiciano": "sul-pi-cia-no",
    "sultán": "sul-tán",
    "sultana": "sul-ta-na",
    "sultanato": "sul-ta-na-to",
    "sultanía": "sul-ta-ní-a",
    "sultánica": "sul-tá-ni-ca",
    "sultánico": "sul-tá-ni-co",
    "suma": "su-ma",
    "sumaca": "su-ma-ca",
    "sumado": "su-ma-do",
    "sumador": "su-ma-dor",
    "sumadora": "su-ma-do-ra",
    "sumamente": "su-ma-men-te",
    "sumando": "su-man-do",
    "sumar": "su-mar",
    "sumaria": "su-ma-ria",
    "sumarial": "su-ma-rial",
    "sumariamente": "su-ma-ria-men-te",
    "sumario": "su-ma-rio",
    "sumarísima": "su-ma-rí-si-ma",
    "sumarísimo": "su-ma-rí-si-mo",
    "sumarro": "su-ma-rro",
    "sumatorio": "su-ma-to-rio",
    "sumergible": "su-mer-gi-ble",
    "sumergido": "su-mer-gi-do",
    "sumergimiento": "su-mer-gi-mien-to",
    "sumergir": "su-mer-gir",
    "sumeria": "su-me-ria",
    "sumerio": "su-me-rio",
    "sumersión": "su-mer-sión",
    "sumidad": "su-mi-dad",
    "sumidero": "su-mi-de-ro",
    "sumidor": "su-mi-dor",
    "sumidora": "su-mi-do-ra",
    "sumiller": "su-mi-ller",
    "sumillería": "su-mi-lle-rí-a",
    "suministrable": "su-mi-nis-tra-ble",
    "suministración": "su-mi-nis-tra-ción",
    "suministrador": "su-mi-nis-tra-dor",
    "suministradora": "su-mi-nis-tra-do-ra",
    "suministrar": "su-mi-nis-trar",
    "suministro": "su-mi-nis-tro",
    "sumir": "su-mir",
    "sumisa": "su-mi-sa",
    "sumisamente": "su-mi-sa-men-te",
    "sumisión": "su-mi-sión",
    "sumiso": "su-mi-so",
    "sumista": "su-mis-ta",
    "súmmum": "súm-mum",
    "sumo": "su-mo",
    "sumonte": "su-mon-te",
    "sumoscapo": "su-mos-ca-po",
    "sumu": "su-mu",
    "súmulas": "sú-mu-las",
    "sumulista": "su-mu-lis-ta",
    "sumulística": "su-mu-lís-ti-ca",
    "sumulístico": "su-mu-lís-ti-co",
    "suna": "su-na",
    "sunca": "sun-ca",
    "suncho": "sun-cho",
    "sunción": "sun-ción",
    "sunco": "sun-co",
    "suncuán": "sun-cuán",
    "sungo": "sun-go",
    "suní": "su-ní",
    "sunicho": "su-ni-cho",
    "sunita": "su-ni-ta",
    "sunna": "sun-na",
    "sunní": "sun-ní",
    "sunnita": "sun-ni-ta",
    "suntuaria": "sun-tua-ria",
    "suntuario": "sun-tua-rio",
    "suntuosa": "sun-tuo-sa",
    "suntuosamente": "sun-tuo-sa-men-te",
    "suntuosidad": "sun-tuo-si-dad",
    "suntuoso": "sun-tuo-so",
    "sunzapote": "sun-za-po-te",
    "supedáneo": "su-pe-dá-ne-o",
    "supeditación": "su-pe-di-ta-ción",
    "supeditar": "su-pe-di-tar",
    "súper": "sú-per",
    "superable": "su-pe-ra-ble",
    "superabundancia": "su-pe-ra-bun-dan-cia",
    "superabundante": "su-pe-ra-bun-dan-te",
    "superabundantemente": "su-pe-ra-bun-dan-te-men-te",
    "superabundar": "su-pe-ra-bun-dar",
    "superación": "su-pe-ra-ción",
    "superádita": "su-pe-rá-di-ta",
    "superádito": "su-pe-rá-di-to",
    "superador": "su-pe-ra-dor",
    "superalimentar": "su-pe-ra-li-men-tar",
    "superante": "su-pe-ran-te",
    "superar": "su-pe-rar",
    "superávit": "su-pe-rá-vit",
    "superba": "su-per-ba",
    "superbamente": "su-per-ba-men-te",
    "superbia": "su-per-bia",
    "superbo": "su-per-bo",
    "superbombardero": "su-per-bom-bar-de-ro",
    "supercarburante": "su-per-car-bu-ran-te",
    "superchera": "su-per-che-ra",
    "superchería": "su-per-che-rí-a",
    "superchero": "su-per-che-ro",
    "superciliar": "su-per-ci-liar",
    "superclase": "su-per-cla-se",
    "superconductividad": "su-per-con-duc-ti-vi-dad",
    "superconductor": "su-per-con-duc-tor",
    "superdominante": "su-per-do-mi-nan-te",
    "superdotada": "su-per-do-ta-da",
    "superdotado": "su-per-do-ta-do",
    "superego": "su-pe-re-go",
    "supereminencia": "su-pe-re-mi-nen-cia",
    "supereminente": "su-pe-re-mi-nen-te",
    "superentender": "su-pe-ren-ten-der",
    "supererogación": "su-pe-re-ro-ga-ción",
    "supererogatoria": "su-pe-re-ro-ga-to-ria",
    "supererogatorio": "su-pe-re-ro-ga-to-rio",
    "superestrato": "su-pe-res-tra-to",
    "superestructura": "su-pe-res-truc-tu-ra",
    "superferolítica": "su-per-fe-ro-lí-ti-ca",
    "superferolítico": "su-per-fe-ro-lí-ti-co",
    "superfetación": "su-per-fe-ta-ción",
    "superficial": "su-per-fi-cial",
    "superficialidad": "su-per-fi-cia-li-dad",
    "superficialmente": "su-per-fi-cial-men-te",
    "superficiaria": "su-per-fi-cia-ria",
    "superficiario": "su-per-fi-cia-rio",
    "superficie": "su-per-fi-cie",
    "superfina": "su-per-fi-na",
    "superfino": "su-per-fi-no",
    "superflua": "su-per-flua",
    "superfluamente": "su-per-flua-men-te",
    "superfluencia": "su-per-fluen-cia",
    "superfluidad": "su-per-flui-dad",
    "superfluo": "su-per-fluo",
    "superfosfato": "su-per-fos-fa-to",
    "supergigante": "su-per-gi-gan-te",
    "superheterodino": "su-pe-rhe-te-ro-di-no",
    "superhombre": "su-pe-rhom-bre",
    "superhumeral": "su-pe-rhu-me-ral",
    "superíndice": "su-pe-rín-di-ce",
    "superintendencia": "su-pe-rin-ten-den-cia",
    "superintendente": "su-pe-rin-ten-den-te",
    "superior": "su-pe-rior",
    "superiora": "su-pe-rio-ra",
    "superiorato": "su-pe-rio-ra-to",
    "superioridad": "su-pe-rio-ri-dad",
    "superiormente": "su-pe-rior-men-te",
    "superlación": "su-per-la-ción",
    "superlativa": "su-per-la-ti-va",
    "superlativamente": "su-per-la-ti-va-men-te",
    "superlativo": "su-per-la-ti-vo",
    "superligero": "su-per-li-ge-ro",
    "supermán": "su-per-mán",
    "supermercado": "su-per-mer-ca-do",
    "superministra": "su-per-mi-nis-tra",
    "superministro": "su-per-mi-nis-tro",
    "superna": "su-per-na",
    "superno": "su-per-no",
    "supernova": "su-per-no-va",
    "supernumeraria": "su-per-nu-me-ra-ria",
    "supernumerario": "su-per-nu-me-ra-rio",
    "súpero": "sú-pe-ro",
    "superpoblación": "su-per-po-bla-ción",
    "superpoblado": "su-per-po-bla-do",
    "superpoblar": "su-per-po-blar",
    "superponer": "su-per-po-ner",
    "superponible": "su-per-po-ni-ble",
    "superposición": "su-per-po-si-ción",
    "superpotencia": "su-per-po-ten-cia",
    "superproducción": "su-per-pro-duc-ción",
    "superproparoxítona": "su-per-pro-pa-ro-xí-to-na",
    "superproparoxítono": "su-per-pro-pa-ro-xí-to-no",
    "superpuesto": "su-per-pues-to",
    "superrealismo": "su-pe-rre-a-lis-mo",
    "superrealista": "su-pe-rre-a-lis-ta",
    "supersónica": "su-per-só-ni-ca",
    "supersónico": "su-per-só-ni-co",
    "superstición": "su-pers-ti-ción",
    "supersticiosa": "su-pers-ti-cio-sa",
    "supersticiosamente": "su-pers-ti-cio-sa-men-te",
    "supersticioso": "su-pers-ti-cio-so",
    "supérstite": "su-pérs-ti-te",
    "supersubstancial": "su-per-subs-tan-cial",
    "supervacánea": "su-per-va-cá-ne-a",
    "supervacáneo": "su-per-va-cá-ne-o",
    "supervaloración": "su-per-va-lo-ra-ción",
    "supervalorar": "su-per-va-lo-rar",
    "supervención": "su-per-ven-ción",
    "superveniencia": "su-per-ve-nien-cia",
    "supervenir": "su-per-ve-nir",
    "superventas": "su-per-ven-tas",
    "supervisar": "su-per-vi-sar",
    "supervisión": "su-per-vi-sión",
    "supervisor": "su-per-vi-sor",
    "supervisora": "su-per-vi-so-ra",
    "supervivencia": "su-per-vi-ven-cia",
    "superviviente": "su-per-vi-vien-te",
    "supervivir": "su-per-vi-vir",
    "superyó": "su-per-yó",
    "supia": "su-pia",
    "supina": "su-pi-na",
    "supinación": "su-pi-na-ción",
    "supinador": "su-pi-na-dor",
    "supino": "su-pi-no",
    "supiritado": "su-pi-ri-ta-do",
    "súpita": "sú-pi-ta",
    "supitaña": "su-pi-ta-ña",
    "supitaño": "su-pi-ta-ño",
    "súpito": "sú-pi-to",
    "suplantable": "su-plan-ta-ble",
    "suplantación": "su-plan-ta-ción",
    "suplantador": "su-plan-ta-dor",
    "suplantadora": "su-plan-ta-do-ra",
    "suplantar": "su-plan-tar",
    "supleción": "su-ple-ción",
    "suplefaltas": "su-ple-fal-tas",
    "suplemental": "su-ple-men-tal",
    "suplementaria": "su-ple-men-ta-ria",
    "suplementario": "su-ple-men-ta-rio",
    "suplementera": "su-ple-men-te-ra",
    "suplementero": "su-ple-men-te-ro",
    "suplemento": "su-ple-men-to",
    "suplencia": "su-plen-cia",
    "suplente": "su-plen-te",
    "supletismo": "su-ple-tis-mo",
    "supletoria": "su-ple-to-ria",
    "supletoriedad": "su-ple-to-rie-dad",
    "supletorio": "su-ple-to-rio",
    "súplica": "sú-pli-ca",
    "suplicación": "su-pli-ca-ción",
    "suplicacionera": "su-pli-ca-cio-ne-ra",
    "suplicacionero": "su-pli-ca-cio-ne-ro",
    "suplicante": "su-pli-can-te",
    "suplicar": "su-pli-car",
    "suplicatoria": "su-pli-ca-to-ria",
    "suplicatorio": "su-pli-ca-to-rio",
    "suplicio": "su-pli-cio",
    "suplido": "su-pli-do",
    "suplidor": "su-pli-dor",
    "suplidora": "su-pli-do-ra",
    "suplir": "su-plir",
    "suponedor": "su-po-ne-dor",
    "suponedora": "su-po-ne-do-ra",
    "suponer": "su-po-ner",
    "suportación": "su-por-ta-ción",
    "suportar": "su-por-tar",
    "suposición": "su-po-si-ción",
    "supositicia": "su-po-si-ti-cia",
    "supositicio": "su-po-si-ti-cio",
    "supositiva": "su-po-si-ti-va",
    "supositivo": "su-po-si-ti-vo",
    "supositorio": "su-po-si-to-rio",
    "supra": "su-pra",
    "supraclavicular": "su-pra-cla-vi-cu-lar",
    "supranacional": "su-pra-na-cio-nal",
    "suprarrealismo": "su-pra-rre-a-lis-mo",
    "suprarrenal": "su-pra-rre-nal",
    "suprasegmental": "su-pra-seg-men-tal",
    "supraspina": "su-pras-pi-na",
    "suprema": "su-pre-ma",
    "supremacía": "su-pre-ma-cí-a",
    "supremamente": "su-pre-ma-men-te",
    "supremo": "su-pre-mo",
    "supresión": "su-pre-sión",
    "supresor": "su-pre-sor",
    "supresora": "su-pre-so-ra",
    "suprimir": "su-pri-mir",
    "suprior": "su-prior",
    "supriora": "su-prio-ra",
    "supriorato": "su-prio-ra-to",
    "supuesto": "su-pues-to",
    "supuración": "su-pu-ra-ción",
    "supurar": "su-pu-rar",
    "supurativa": "su-pu-ra-ti-va",
    "supurativo": "su-pu-ra-ti-vo",
    "supuratoria": "su-pu-ra-to-ria",
    "supuratorio": "su-pu-ra-to-rio",
    "suputación": "su-pu-ta-ción",
    "suputar": "su-pu-tar",
    "suque": "su-que",
    "suquinay": "su-qui-nay",
    "sura": "su-ra",
    "surá": "su-rá",
    "surada": "su-ra-da",
    "surafricana": "su-ra-fri-ca-na",
    "surafricano": "su-ra-fri-ca-no",
    "sural": "su-ral",
    "suramericana": "su-ra-me-ri-ca-na",
    "suramericano": "su-ra-me-ri-ca-no",
    "surazo": "su-ra-zo",
    "surbajacaliforniana": "sur-ba-ja-ca-li-for-nia-na",
    "surbajacaliforniano": "sur-ba-ja-ca-li-for-nia-no",
    "súrbana": "súr-ba-na",
    "surcador": "sur-ca-dor",
    "surcadora": "sur-ca-do-ra",
    "surcaño": "sur-ca-ño",
    "surcar": "sur-car",
    "surcir": "sur-cir",
    "surco": "sur-co",
    "surcoreana": "sur-co-re-a-na",
    "surcoreano": "sur-co-re-a-no",
    "surculada": "sur-cu-la-da",
    "surculado": "sur-cu-la-do",
    "súrculo": "súr-cu-lo",
    "surculosa": "sur-cu-lo-sa",
    "surculoso": "sur-cu-lo-so",
    "surdir": "sur-dir",
    "sureña": "su-re-ña",
    "sureño": "su-re-ño",
    "sureste": "su-res-te",
    "surfactante": "sur-fac-tan-te",
    "surfilar": "sur-fi-lar",
    "surfing": "sur-fing",
    "surfista": "sur-fis-ta",
    "surgidero": "sur-gi-de-ro",
    "surgidor": "sur-gi-dor",
    "surgidora": "sur-gi-do-ra",
    "surgimiento": "sur-gi-mien-to",
    "surgir": "sur-gir",
    "suri": "su-ri",
    "suriana": "su-ria-na",
    "suriano": "su-ria-no",
    "suricata": "su-ri-ca-ta",
    "suricato": "su-ri-ca-to",
    "surimba": "su-rim-ba",
    "surimbo": "su-rim-bo",
    "surinamés": "su-ri-na-més",
    "surinamesa": "su-ri-na-me-sa",
    "suripanta": "su-ri-pan-ta",
    "suroccidental": "su-roc-ci-den-tal",
    "suroeste": "su-ro-es-te",
    "suroriental": "su-ro-rien-tal",
    "surquero": "sur-que-ro",
    "surradero": "su-rra-de-ro",
    "surrealismo": "su-rre-a-lis-mo",
    "surrealista": "su-rre-a-lis-ta",
    "surrupia": "su-rru-pia",
    "surrupio": "su-rru-pio",
    "sursudoeste": "sur-su-do-es-te",
    "sursuncorda": "sur-sun-cor-da",
    "sursureste": "sur-su-res-te",
    "sursuroeste": "sur-su-ro-es-te",
    "surta": "sur-ta",
    "surtida": "sur-ti-da",
    "surtidero": "sur-ti-de-ro",
    "surtido": "sur-ti-do",
    "surtidor": "sur-ti-dor",
    "surtidora": "sur-ti-do-ra",
    "surtimiento": "sur-ti-mien-to",
    "surtir": "sur-tir",
    "surto": "sur-to",
    "súrtuba": "súr-tu-ba",
    "surubí": "su-ru-bí",
    "surumba": "su-rum-ba",
    "surumbo": "su-rum-bo",
    "surumpe": "su-rum-pe",
    "suruví": "su-ru-ví",
    "survietnamita": "sur-viet-na-mi-ta",
    "susana": "su-sa-na",
    "susano": "su-sa-no",
    "suscepción": "sus-cep-ción",
    "susceptancia": "sus-cep-tan-cia",
    "susceptibilidad": "sus-cep-ti-bi-li-dad",
    "susceptible": "sus-cep-ti-ble",
    "susceptiva": "sus-cep-ti-va",
    "susceptivo": "sus-cep-ti-vo",
    "suscitación": "sus-ci-ta-ción",
    "suscitar": "sus-ci-tar",
    "suscribir": "sus-cri-bir",
    "suscripción": "sus-crip-ción",
    "suscripta": "sus-crip-ta",
    "suscripto": "sus-crip-to",
    "suscriptor": "sus-crip-tor",
    "suscriptora": "sus-crip-to-ra",
    "suscrita": "sus-cri-ta",
    "suscrito": "sus-cri-to",
    "suscritor": "sus-cri-tor",
    "suscritora": "sus-cri-to-ra",
    "susera": "su-se-ra",
    "susero": "su-se-ro",
    "sushi": "sus-hi",
    "susidio": "su-si-dio",
    "suso": "su-so",
    "susodicha": "su-so-di-cha",
    "susodicho": "su-so-di-cho",
    "suspecta": "sus-pec-ta",
    "suspecto": "sus-pec-to",
    "suspendedor": "sus-pen-de-dor",
    "suspendedora": "sus-pen-de-do-ra",
    "suspender": "sus-pen-der",
    "suspendimiento": "sus-pen-di-mien-to",
    "suspensa": "sus-pen-sa",
    "suspense": "sus-pen-se",
    "suspensión": "sus-pen-sión",
    "suspensiva": "sus-pen-si-va",
    "suspensivo": "sus-pen-si-vo",
    "suspenso": "sus-pen-so",
    "suspensores": "sus-pen-so-res",
    "suspensoria": "sus-pen-so-ria",
    "suspensorio": "sus-pen-so-rio",
    "suspicacia": "sus-pi-ca-cia",
    "suspicaz": "sus-pi-caz",
    "suspicazmente": "sus-pi-caz-men-te",
    "suspición": "sus-pi-ción",
    "suspirado": "sus-pi-ra-do",
    "suspirar": "sus-pi-rar",
    "suspiro": "sus-pi-ro",
    "suspirón": "sus-pi-rón",
    "suspirona": "sus-pi-ro-na",
    "suspirosa": "sus-pi-ro-sa",
    "suspiroso": "sus-pi-ro-so",
    "sustancia": "sus-tan-cia",
    "sustanciación": "sus-tan-cia-ción",
    "sustancial": "sus-tan-cial",
    "sustancialidad": "sus-tan-cia-li-dad",
    "sustancialismo": "sus-tan-cia-lis-mo",
    "sustancialmente": "sus-tan-cial-men-te",
    "sustanciar": "sus-tan-ciar",
    "sustanciosa": "sus-tan-cio-sa",
    "sustancioso": "sus-tan-cio-so",
    "sustantiva": "sus-tan-ti-va",
    "sustantivación": "sus-tan-ti-va-ción",
    "sustantivamente": "sus-tan-ti-va-men-te",
    "sustantivar": "sus-tan-ti-var",
    "sustantividad": "sus-tan-ti-vi-dad",
    "sustantivo": "sus-tan-ti-vo",
    "sustenida": "sus-te-ni-da",
    "sustenido": "sus-te-ni-do",
    "sustentable": "sus-ten-ta-ble",
    "sustentación": "sus-ten-ta-ción",
    "sustentáculo": "sus-ten-tá-cu-lo",
    "sustentador": "sus-ten-ta-dor",
    "sustentadora": "sus-ten-ta-do-ra",
    "sustentamiento": "sus-ten-ta-mien-to",
    "sustentante": "sus-ten-tan-te",
    "sustentar": "sus-ten-tar",
    "sustento": "sus-ten-to",
    "sustitución": "sus-ti-tu-ción",
    "sustituible": "sus-ti-tui-ble",
    "sustituidor": "sus-ti-tui-dor",
    "sustituidora": "sus-ti-tui-do-ra",
    "sustituir": "sus-ti-tuir",
    "sustituta": "sus-ti-tu-ta",
    "sustitutiva": "sus-ti-tu-ti-va",
    "sustitutivo": "sus-ti-tu-ti-vo",
    "sustituto": "sus-ti-tu-to",
    "sustitutorio": "sus-ti-tu-to-rio",
    "susto": "sus-to",
    "sustracción": "sus-trac-ción",
    "sustractivo": "sus-trac-ti-vo",
    "sustraendo": "sus-tra-en-do",
    "sustraer": "sus-tra-er",
    "sustrato": "sus-tra-to",
    "susurración": "su-su-rra-ción",
    "susurrador": "su-su-rra-dor",
    "susurradora": "su-su-rra-do-ra",
    "susurrante": "su-su-rran-te",
    "susurrar": "su-su-rrar",
    "susurrido": "su-su-rri-do",
    "susurro": "su-su-rro",
    "susurrón": "su-su-rrón",
    "susurrona": "su-su-rro-na",
    "sutás": "su-tás",
    "sute": "su-te",
    "sutil": "su-til",
    "sutileza": "su-ti-le-za",
    "sutilidad": "su-ti-li-dad",
    "sutilizador": "su-ti-li-za-dor",
    "sutilizadora": "su-ti-li-za-do-ra",
    "sutilizar": "su-ti-li-zar",
    "sutilmente": "su-til-men-te",
    "sutoria": "su-to-ria",
    "sutorio": "su-to-rio",
    "sutura": "su-tu-ra",
    "suturar": "su-tu-rar",
    "suversión": "su-ver-sión",
    "suya": "su-ya",
    "suyate": "su-ya-te",
    "suyo": "su-yo",
    "suzón": "su-zón",
    "taba": "ta-ba",
    "tabacal": "ta-ba-cal",
    "tabacalera": "ta-ba-ca-le-ra",
    "tabacalero": "ta-ba-ca-le-ro",
    "tabacazo": "ta-ba-ca-zo",
    "tabachín": "ta-ba-chín",
    "tabaco": "ta-ba-co",
    "tabacón": "ta-ba-cón",
    "tabacosa": "ta-ba-co-sa",
    "tabacoso": "ta-ba-co-so",
    "tabaiba": "ta-bai-ba",
    "tabaibal": "ta-bai-bal",
    "tabal": "ta-bal",
    "tabalada": "ta-ba-la-da",
    "tabalario": "ta-ba-la-rio",
    "tabalear": "ta-ba-le-ar",
    "tabaleo": "ta-ba-le-o",
    "tabanazo": "ta-ba-na-zo",
    "tabanco": "ta-ban-co",
    "tabanera": "ta-ba-ne-ra",
    "tábano": "tá-ba-no",
    "tabanque": "ta-ban-que",
    "tabaola": "ta-ba-o-la",
    "tabaque": "ta-ba-que",
    "tabaquear": "ta-ba-que-ar",
    "tabaquera": "ta-ba-que-ra",
    "tabaquería": "ta-ba-que-rí-a",
    "tabaquero": "ta-ba-que-ro",
    "tabaquillo": "ta-ba-qui-llo",
    "tabaquismo": "ta-ba-quis-mo",
    "tabaquista": "ta-ba-quis-ta",
    "tabardete": "ta-bar-de-te",
    "tabardillo": "ta-bar-di-llo",
    "tabardo": "ta-bar-do",
    "tabarra": "ta-ba-rra",
    "tabarrera": "ta-ba-rre-ra",
    "tabarro": "ta-ba-rro",
    "tábarro": "tá-ba-rro",
    "tabasco": "ta-bas-co",
    "tabasqueña": "ta-bas-que-ña",
    "tabasqueño": "ta-bas-que-ño",
    "tabea": "ta-be-a",
    "tabefe": "ta-be-fe",
    "tabelión": "ta-be-lión",
    "tabelladura": "ta-be-lla-du-ra",
    "tabellar": "ta-be-llar",
    "taberna": "ta-ber-na",
    "tabernáculo": "ta-ber-ná-cu-lo",
    "tabernaria": "ta-ber-na-ria",
    "tabernario": "ta-ber-na-rio",
    "tabernera": "ta-ber-ne-ra",
    "tabernería": "ta-ber-ne-rí-a",
    "tabernero": "ta-ber-ne-ro",
    "tabernizada": "ta-ber-ni-za-da",
    "tabernizado": "ta-ber-ni-za-do",
    "tabernucha": "ta-ber-nu-cha",
    "tabes": "ta-bes",
    "tabí": "ta-bí",
    "tabica": "ta-bi-ca",
    "tabicado": "ta-bi-ca-do",
    "tabicar": "ta-bi-car",
    "tabicón": "ta-bi-cón",
    "tábida": "tá-bi-da",
    "tábido": "tá-bi-do",
    "tabífica": "ta-bí-fi-ca",
    "tabífico": "ta-bí-fi-co",
    "tabilla": "ta-bi-lla",
    "tabina": "ta-bi-na",
    "tabinete": "ta-bi-ne-te",
    "tabique": "ta-bi-que",
    "tabiquería": "ta-bi-que-rí-a",
    "tabiquero": "ta-bi-que-ro",
    "tabla": "ta-bla",
    "tablachero": "ta-bla-che-ro",
    "tablachina": "ta-bla-chi-na",
    "tablacho": "ta-bla-cho",
    "tablada": "ta-bla-da",
    "tablado": "ta-bla-do",
    "tablaje": "ta-bla-je",
    "tablajera": "ta-bla-je-ra",
    "tablajería": "ta-bla-je-rí-a",
    "tablajero": "ta-bla-je-ro",
    "tablao": "ta-bla-o",
    "tablar": "ta-blar",
    "tablazo": "ta-bla-zo",
    "tablazón": "ta-bla-zón",
    "tableado": "ta-ble-a-do",
    "tablear": "ta-ble-ar",
    "tableña": "ta-ble-ña",
    "tableño": "ta-ble-ño",
    "tableo": "ta-ble-o",
    "tablera": "ta-ble-ra",
    "tablería": "ta-ble-rí-a",
    "tablero": "ta-ble-ro",
    "tablestaca": "ta-bles-ta-ca",
    "tablestacado": "ta-bles-ta-ca-do",
    "tableta": "ta-ble-ta",
    "tableteado": "ta-ble-te-a-do",
    "tabletear": "ta-ble-te-ar",
    "tableteo": "ta-ble-te-o",
    "tablilla": "ta-bli-lla",
    "tablizo": "ta-bli-zo",
    "tabloide": "ta-bloi-de",
    "tablón": "ta-blón",
    "tablonaje": "ta-blo-na-je",
    "tabloncillo": "ta-blon-ci-llo",
    "tabloza": "ta-blo-za",
    "tabo": "ta-bo",
    "tabolango": "ta-bo-lan-go",
    "tabón": "ta-bón",
    "tabonuco": "ta-bo-nu-co",
    "tabor": "ta-bor",
    "tabú": "ta-bú",
    "tabuco": "ta-bu-co",
    "tabulación": "ta-bu-la-ción",
    "tabulador": "ta-bu-la-dor",
    "tabuladora": "ta-bu-la-do-ra",
    "tabular": "ta-bu-lar",
    "taburete": "ta-bu-re-te",
    "taca": "ta-ca",
    "tacaco": "ta-ca-co",
    "tacada": "ta-ca-da",
    "tacamaca": "ta-ca-ma-ca",
    "tacamacha": "ta-ca-ma-cha",
    "tacamahaca": "ta-ca-ma-ha-ca",
    "tacamajaca": "ta-ca-ma-ja-ca",
    "tacana": "ta-ca-na",
    "tacaña": "ta-ca-ña",
    "tacañamente": "ta-ca-ña-men-te",
    "tacañear": "ta-ca-ñe-ar",
    "tacañería": "ta-ca-ñe-rí-a",
    "tacaño": "ta-ca-ño",
    "tacar": "ta-car",
    "tacatá": "ta-ca-tá",
    "tacataca": "ta-ca-ta-ca",
    "tacazo": "ta-ca-zo",
    "tácet": "tá-cet",
    "taceta": "ta-ce-ta",
    "tacha": "ta-cha",
    "tachable": "ta-cha-ble",
    "tachador": "ta-cha-dor",
    "tachadora": "ta-cha-do-ra",
    "tachadura": "ta-cha-du-ra",
    "tachar": "ta-char",
    "tache": "ta-che",
    "tachera": "ta-che-ra",
    "tachero": "ta-che-ro",
    "tachigual": "ta-chi-gual",
    "tachirense": "ta-chi-ren-se",
    "tachismo": "ta-chis-mo",
    "tacho": "ta-cho",
    "tachón": "ta-chón",
    "tachonado": "ta-cho-na-do",
    "tachonar": "ta-cho-nar",
    "tachonería": "ta-cho-ne-rí-a",
    "tachosa": "ta-cho-sa",
    "tachoso": "ta-cho-so",
    "tachuela": "ta-chue-la",
    "tácita": "tá-ci-ta",
    "tácitamente": "tá-ci-ta-men-te",
    "tácito": "tá-ci-to",
    "taciturna": "ta-ci-tur-na",
    "taciturnidad": "ta-ci-tur-ni-dad",
    "taciturno": "ta-ci-tur-no",
    "tacizo": "ta-ci-zo",
    "taclobo": "ta-clo-bo",
    "tacneña": "tac-ne-ña",
    "tacneño": "tac-ne-ño",
    "taco": "ta-co",
    "tacógrafo": "ta-có-gra-fo",
    "tacómetro": "ta-có-me-tro",
    "tacón": "ta-cón",
    "taconazo": "ta-co-na-zo",
    "taconear": "ta-co-ne-ar",
    "taconeo": "ta-co-ne-o",
    "tacopaste": "ta-co-pas-te",
    "tacopatle": "ta-co-pa-tle",
    "tacotal": "ta-co-tal",
    "tactación": "tac-ta-ción",
    "táctica": "tác-ti-ca",
    "tácticamente": "tác-ti-ca-men-te",
    "táctico": "tác-ti-co",
    "táctil": "tác-til",
    "tactismo": "tac-tis-mo",
    "tacto": "tac-to",
    "tacuaca": "ta-cua-ca",
    "tacuache": "ta-cua-che",
    "tacuacín": "ta-cua-cín",
    "tacuaco": "ta-cua-co",
    "tacuara": "ta-cua-ra",
    "tacuaral": "ta-cua-ral",
    "tacuaremboense": "ta-cua-rem-bo-en-se",
    "tacuche": "ta-cu-che",
    "tacurú": "ta-cu-rú",
    "tadorna": "ta-dor-na",
    "tadyka": "tady-ka",
    "tadyko": "tady-ko",
    "tael": "ta-el",
    "tafanario": "ta-fa-na-rio",
    "tafeta": "ta-fe-ta",
    "tafetán": "ta-fe-tán",
    "tafia": "ta-fia",
    "tafilete": "ta-fi-le-te",
    "tafiletear": "ta-fi-le-te-ar",
    "tafiletería": "ta-fi-le-te-rí-a",
    "tafistes": "ta-fis-tes",
    "tafo": "ta-fo",
    "tafón": "ta-fón",
    "tafur": "ta-fur",
    "tafurea": "ta-fu-re-a",
    "tagala": "ta-ga-la",
    "tagalo": "ta-ga-lo",
    "tagarina": "ta-ga-ri-na",
    "tagarino": "ta-ga-ri-no",
    "tagarnina": "ta-gar-ni-na",
    "tagarote": "ta-ga-ro-te",
    "tagarotear": "ta-ga-ro-te-ar",
    "tagasaste": "ta-ga-sas-te",
    "tagua": "ta-gua",
    "taguán": "ta-guán",
    "taguara": "ta-gua-ra",
    "taha": "ta-ha",
    "tahalí": "ta-ha-lí",
    "taharal": "ta-ha-ral",
    "tahelí": "ta-he-lí",
    "taheña": "ta-he-ña",
    "taheño": "ta-he-ño",
    "tahitiana": "tahi-tia-na",
    "tahitiano": "tahi-tia-no",
    "tahona": "ta-ho-na",
    "tahonera": "ta-ho-ne-ra",
    "tahonero": "ta-ho-ne-ro",
    "tahúlla": "ta-hú-lla",
    "tahúr": "ta-húr",
    "tahúra": "ta-hú-ra",
    "tahurería": "tahu-re-rí-a",
    "tahuresca": "tahu-res-ca",
    "tahuresco": "tahu-res-co",
    "taichi": "tai-chi",
    "taichino": "tai-chi-no",
    "taifa": "tai-fa",
    "taiga": "tai-ga",
    "tailandés": "tai-lan-dés",
    "tailandesa": "tai-lan-de-sa",
    "taima": "tai-ma",
    "taimada": "tai-ma-da",
    "taimado": "tai-ma-do",
    "taimar": "tai-mar",
    "taimarse": "tai-mar-se",
    "taimería": "tai-me-rí-a",
    "taina": "tai-na",
    "taíno": "ta-í-no",
    "taira": "tai-ra",
    "taire": "tai-re",
    "taita": "tai-ta",
    "taiwanés": "tai-wa-nés",
    "taiwanesa": "tai-wa-ne-sa",
    "taja": "ta-ja",
    "tajá": "ta-já",
    "tajada": "ta-ja-da",
    "tajadera": "ta-ja-de-ra",
    "tajadero": "ta-ja-de-ro",
    "tajadilla": "ta-ja-di-lla",
    "tajado": "ta-ja-do",
    "tajador": "ta-ja-dor",
    "tajadora": "ta-ja-do-ra",
    "tajadura": "ta-ja-du-ra",
    "tajalápices": "ta-ja-lá-pi-ces",
    "tajamar": "ta-ja-mar",
    "tajamiento": "ta-ja-mien-to",
    "tajante": "ta-jan-te",
    "tajaplumas": "ta-ja-plu-mas",
    "tajar": "ta-jar",
    "tajaraste": "ta-ja-ras-te",
    "tajarrazo": "ta-ja-rra-zo",
    "tajea": "ta-je-a",
    "tajear": "ta-je-ar",
    "tajero": "ta-je-ro",
    "tajín": "ta-jín",
    "tajo": "ta-jo",
    "tajón": "ta-jón",
    "tajú": "ta-jú",
    "tajuela": "ta-jue-la",
    "tajuelo": "ta-jue-lo",
    "tajugo": "ta-ju-go",
    "tala": "ta-la",
    "talabarte": "ta-la-bar-te",
    "talabartera": "ta-la-bar-te-ra",
    "talabartería": "ta-la-bar-te-rí-a",
    "talabartero": "ta-la-bar-te-ro",
    "talabricense": "ta-la-bri-cen-se",
    "talacha": "ta-la-cha",
    "talacho": "ta-la-cho",
    "talador": "ta-la-dor",
    "taladora": "ta-la-do-ra",
    "taladrado": "ta-la-dra-do",
    "taladrador": "ta-la-dra-dor",
    "taladradora": "ta-la-dra-do-ra",
    "taladrar": "ta-la-drar",
    "taladrilla": "ta-la-dri-lla",
    "taladro": "ta-la-dro",
    "talagantina": "ta-la-gan-ti-na",
    "talagantino": "ta-la-gan-ti-no",
    "talaje": "ta-la-je",
    "talamera": "ta-la-me-ra",
    "talamete": "ta-la-me-te",
    "talamiflora": "ta-la-mi-flo-ra",
    "talamite": "ta-la-mi-te",
    "tálamo": "tá-la-mo",
    "talamoco": "ta-la-mo-co",
    "talán": "ta-lán",
    "talangueña": "ta-lan-gue-ña",
    "talangueño": "ta-lan-gue-ño",
    "talanquera": "ta-lan-que-ra",
    "talante": "ta-lan-te",
    "talantosa": "ta-lan-to-sa",
    "talantoso": "ta-lan-to-so",
    "talar": "ta-lar",
    "talareña": "ta-la-re-ña",
    "talareño": "ta-la-re-ño",
    "talasemia": "ta-la-se-mia",
    "talasocracia": "ta-la-so-cra-cia",
    "talasoterapia": "ta-la-so-te-ra-pia",
    "talaverana": "ta-la-ve-ra-na",
    "talaverano": "ta-la-ve-ra-no",
    "talaya": "ta-la-ya",
    "talayot": "ta-la-yot",
    "talayote": "ta-la-yo-te",
    "talchocote": "tal-cho-co-te",
    "talco": "tal-co",
    "talcosa": "tal-co-sa",
    "talcoso": "tal-co-so",
    "talcualilla": "tal-cua-li-lla",
    "talcualillo": "tal-cua-li-llo",
    "tálea": "tá-le-a",
    "taled": "ta-led",
    "talega": "ta-le-ga",
    "talegada": "ta-le-ga-da",
    "talegazo": "ta-le-ga-zo",
    "talego": "ta-le-go",
    "taleguilla": "ta-le-gui-lla",
    "talente": "ta-len-te",
    "talento": "ta-len-to",
    "talentosa": "ta-len-to-sa",
    "talentoso": "ta-len-to-so",
    "talentuda": "ta-len-tu-da",
    "talentudo": "ta-len-tu-do",
    "talepate": "ta-le-pa-te",
    "talero": "ta-le-ro",
    "tálero": "tá-le-ro",
    "talete": "ta-le-te",
    "talgo": "tal-go",
    "talguate": "tal-gua-te",
    "talguatoso": "tal-gua-to-so",
    "talibán": "ta-li-bán",
    "talicón": "ta-li-cón",
    "talidad": "ta-li-dad",
    "talín": "ta-lín",
    "talinera": "ta-li-ne-ra",
    "talio": "ta-lio",
    "talión": "ta-lión",
    "talionar": "ta-lio-nar",
    "talismán": "ta-lis-mán",
    "taliste": "ta-lis-te",
    "talla": "ta-lla",
    "tallada": "ta-lla-da",
    "tallado": "ta-lla-do",
    "tallador": "ta-lla-dor",
    "talladora": "ta-lla-do-ra",
    "talladura": "ta-lla-du-ra",
    "tallar": "ta-llar",
    "tallarín": "ta-lla-rín",
    "tallarola": "ta-lla-ro-la",
    "talle": "ta-lle",
    "tallecer": "ta-lle-cer",
    "taller": "ta-ller",
    "táller": "tá-ller",
    "tallerina": "ta-lle-ri-na",
    "tallero": "ta-lle-ro",
    "tallista": "ta-llis-ta",
    "tallo": "ta-llo",
    "tallón": "ta-llón",
    "talluda": "ta-llu-da",
    "talludo": "ta-llu-do",
    "tallullo": "ta-llu-llo",
    "talma": "tal-ma",
    "talmente": "tal-men-te",
    "talmotocle": "tal-mo-to-cle",
    "talmúdica": "tal-mú-di-ca",
    "talmúdico": "tal-mú-di-co",
    "talmudista": "tal-mu-dis-ta",
    "talnete": "tal-ne-te",
    "talo": "ta-lo",
    "talofita": "ta-lo-fi-ta",
    "talofítico": "ta-lo-fí-ti-co",
    "talofito": "ta-lo-fi-to",
    "talón": "ta-lón",
    "talonada": "ta-lo-na-da",
    "talonaria": "ta-lo-na-ria",
    "talonario": "ta-lo-na-rio",
    "talonazo": "ta-lo-na-zo",
    "taloneada": "ta-lo-ne-a-da",
    "taloneador": "ta-lo-ne-a-dor",
    "talonear": "ta-lo-ne-ar",
    "talonera": "ta-lo-ne-ra",
    "talonero": "ta-lo-ne-ro",
    "talpa": "tal-pa",
    "talparia": "tal-pa-ria",
    "talpetate": "tal-pe-ta-te",
    "talpetatoso": "tal-pe-ta-to-so",
    "talpuja": "tal-pu-ja",
    "talque": "tal-que",
    "talqueza": "tal-que-za",
    "talquina": "tal-qui-na",
    "talquino": "tal-qui-no",
    "talquita": "tal-qui-ta",
    "taltuza": "tal-tu-za",
    "talud": "ta-lud",
    "taludín": "ta-lu-dín",
    "talvez": "tal-vez",
    "talvina": "tal-vi-na",
    "tamagás": "ta-ma-gás",
    "tamagasero": "ta-ma-ga-se-ro",
    "tamal": "ta-mal",
    "tamalada": "ta-ma-la-da",
    "tamaleada": "ta-ma-le-a-da",
    "tamalear": "ta-ma-le-ar",
    "tamalera": "ta-ma-le-ra",
    "tamalería": "ta-ma-le-rí-a",
    "tamalero": "ta-ma-le-ro",
    "tamaña": "ta-ma-ña",
    "tamanaca": "ta-ma-na-ca",
    "tamanaco": "ta-ma-na-co",
    "tamañamente": "ta-ma-ña-men-te",
    "tamanduá": "ta-man-duá",
    "tamango": "ta-man-go",
    "tamangudo": "ta-man-gu-do",
    "tamañita": "ta-ma-ñi-ta",
    "tamañito": "ta-ma-ñi-to",
    "tamaño": "ta-ma-ño",
    "támara": "tá-ma-ra",
    "tamaral": "ta-ma-ral",
    "tamarao": "ta-ma-ra-o",
    "tamaricácea": "ta-ma-ri-cá-ce-a",
    "tamaricáceo": "ta-ma-ri-cá-ce-o",
    "tamarigal": "ta-ma-ri-gal",
    "tamarilla": "ta-ma-ri-lla",
    "tamarindo": "ta-ma-rin-do",
    "tamariscínea": "ta-ma-ris-cí-ne-a",
    "tamariscíneo": "ta-ma-ris-cí-ne-o",
    "tamarisco": "ta-ma-ris-co",
    "tamaritana": "ta-ma-ri-ta-na",
    "tamaritano": "ta-ma-ri-ta-no",
    "tamariz": "ta-ma-riz",
    "tamarrizquita": "ta-ma-rriz-qui-ta",
    "tamarrizquito": "ta-ma-rriz-qui-to",
    "tamarrusquita": "ta-ma-rrus-qui-ta",
    "tamarrusquito": "ta-ma-rrus-qui-to",
    "tamarugal": "ta-ma-ru-gal",
    "tamarugo": "ta-ma-ru-go",
    "tamaulipeca": "ta-mau-li-pe-ca",
    "tamaulipeco": "ta-mau-li-pe-co",
    "tamba": "tam-ba",
    "tambache": "tam-ba-che",
    "tambaleante": "tam-ba-le-an-te",
    "tambalear": "tam-ba-le-ar",
    "tambaleo": "tam-ba-le-o",
    "tambalisa": "tam-ba-li-sa",
    "tambanillo": "tam-ba-ni-llo",
    "tambar": "tam-bar",
    "támbara": "tám-ba-ra",
    "tambarillo": "tam-ba-ri-llo",
    "tambarimba": "tam-ba-rim-ba",
    "tambarria": "tam-ba-rria",
    "tambembe": "tam-bem-be",
    "tambera": "tam-be-ra",
    "tambero": "tam-be-ro",
    "tambesco": "tam-bes-co",
    "también": "tam-bién",
    "tambo": "tam-bo",
    "tambocha": "tam-bo-cha",
    "tambopateña": "tam-bo-pa-te-ña",
    "tambopateño": "tam-bo-pa-te-ño",
    "tambor": "tam-bor",
    "tambora": "tam-bo-ra",
    "tamborada": "tam-bo-ra-da",
    "tamborear": "tam-bo-re-ar",
    "tamboreo": "tam-bo-re-o",
    "tamborera": "tam-bo-re-ra",
    "tamborero": "tam-bo-re-ro",
    "tamborete": "tam-bo-re-te",
    "tamboril": "tam-bo-ril",
    "tamborilada": "tam-bo-ri-la-da",
    "tamborilazo": "tam-bo-ri-la-zo",
    "tamborilear": "tam-bo-ri-le-ar",
    "tamborileo": "tam-bo-ri-le-o",
    "tamborilera": "tam-bo-ri-le-ra",
    "tamborilero": "tam-bo-ri-le-ro",
    "tamborilete": "tam-bo-ri-le-te",
    "tamborín": "tam-bo-rín",
    "tamborino": "tam-bo-ri-no",
    "tamborista": "tam-bo-ris-ta",
    "tamboritear": "tam-bo-ri-te-ar",
    "tamboritero": "tam-bo-ri-te-ro",
    "tamborito": "tam-bo-ri-to",
    "tamborón": "tam-bo-rón",
    "tamborrada": "tam-bo-rra-da",
    "tambre": "tam-bre",
    "tambuche": "tam-bu-che",
    "tambucho": "tam-bu-cho",
    "tameme": "ta-me-me",
    "tamil": "ta-mil",
    "tamínea": "ta-mí-ne-a",
    "taminia": "ta-mi-nia",
    "tamiz": "ta-miz",
    "tamización": "ta-mi-za-ción",
    "tamizar": "ta-mi-zar",
    "tamo": "ta-mo",
    "tamojal": "ta-mo-jal",
    "tamojo": "ta-mo-jo",
    "támpax": "tám-pax",
    "tampiqueña": "tam-pi-que-ña",
    "tampiqueño": "tam-pi-que-ño",
    "tampoco": "tam-po-co",
    "tampón": "tam-pón",
    "tamtan": "tam-tan",
    "tamuga": "ta-mu-ga",
    "tamuja": "ta-mu-ja",
    "tamujal": "ta-mu-jal",
    "tamujo": "ta-mu-jo",
    "tamul": "ta-mul",
    "tana": "ta-na",
    "tanaceto": "ta-na-ce-to",
    "tanador": "ta-na-dor",
    "tanagra": "ta-na-gra",
    "tañar": "ta-ñar",
    "tanate": "ta-na-te",
    "tanateada": "ta-na-te-a-da",
    "tanatear": "ta-na-te-ar",
    "tanatofobia": "ta-na-to-fo-bia",
    "tanatología": "ta-na-to-lo-gí-a",
    "tanatológico": "ta-na-to-ló-gi-co",
    "tanatopraxia": "ta-na-to-pra-xia",
    "tanatorio": "ta-na-to-rio",
    "tancal": "tan-cal",
    "tancar": "tan-car",
    "tancasangre": "tan-ca-san-gre",
    "tancredismo": "tan-cre-dis-mo",
    "tanda": "tan-da",
    "tandear": "tan-de-ar",
    "tándem": "tán-dem",
    "tandeo": "tan-de-o",
    "tandera": "tan-de-ra",
    "tandero": "tan-de-ro",
    "tandista": "tan-dis-ta",
    "tañedor": "ta-ñe-dor",
    "tañedora": "ta-ñe-do-ra",
    "tanela": "ta-ne-la",
    "tañer": "ta-ñer",
    "tanga": "tan-ga",
    "tangada": "tan-ga-da",
    "tangado": "tan-ga-do",
    "tangalear": "tan-ga-le-ar",
    "tangán": "tan-gán",
    "tangana": "tan-ga-na",
    "tángana": "tán-ga-na",
    "tanganazo": "tan-ga-na-zo",
    "tanganillas": "tan-ga-ni-llas",
    "tanganillo": "tan-ga-ni-llo",
    "tángano": "tán-ga-no",
    "tangar": "tan-gar",
    "tángara": "tán-ga-ra",
    "tangencia": "tan-gen-cia",
    "tangencial": "tan-gen-cial",
    "tangente": "tan-gen-te",
    "tangerina": "tan-ge-ri-na",
    "tangerino": "tan-ge-ri-no",
    "tangible": "tan-gi-ble",
    "tangidera": "tan-gi-de-ra",
    "tangir": "tan-gir",
    "tango": "tan-go",
    "tangón": "tan-gón",
    "tangue": "tan-gue",
    "tanguear": "tan-gue-ar",
    "tanguera": "tan-gue-ra",
    "tanguería": "tan-gue-rí-a",
    "tanguero": "tan-gue-ro",
    "tanguillo": "tan-gui-llo",
    "tanguista": "tan-guis-ta",
    "tánica": "tá-ni-ca",
    "tánico": "tá-ni-co",
    "tañido": "ta-ñi-do",
    "tanilla": "ta-ni-lla",
    "tañimiento": "ta-ñi-mien-to",
    "tanino": "ta-ni-no",
    "tanjarina": "tan-ja-ri-na",
    "tanka": "tan-ka",
    "tano": "ta-no",
    "taño": "ta-ño",
    "tanobia": "ta-no-bia",
    "tanor": "ta-nor",
    "tanora": "ta-no-ra",
    "tanoría": "ta-no-rí-a",
    "tanque": "tan-que",
    "tanquero": "tan-que-ro",
    "tanqueta": "tan-que-ta",
    "tanquilla": "tan-qui-lla",
    "tanta": "tan-ta",
    "tantalio": "tan-ta-lio",
    "tántalo": "tán-ta-lo",
    "tantán": "tan-tán",
    "tantarán": "tan-ta-rán",
    "tantarantán": "tan-ta-ran-tán",
    "tanteada": "tan-te-a-da",
    "tanteador": "tan-te-a-dor",
    "tanteadora": "tan-te-a-do-ra",
    "tantear": "tan-te-ar",
    "tanteo": "tan-te-o",
    "tantico": "tan-ti-co",
    "tanto": "tan-to",
    "tantra": "tan-tra",
    "tántrico": "tán-tri-co",
    "tantrismo": "tan-tris-mo",
    "tanza": "tan-za",
    "tanzana": "tan-za-na",
    "tanzano": "tan-za-no",
    "tao": "ta-o",
    "taoísmo": "ta-o-ís-mo",
    "taoísta": "ta-o-ís-ta",
    "tapa": "ta-pa",
    "tapabalazo": "ta-pa-ba-la-zo",
    "tapabarriga": "ta-pa-ba-rri-ga",
    "tapabarro": "ta-pa-ba-rro",
    "tapaboca": "ta-pa-bo-ca",
    "tapabocas": "ta-pa-bo-cas",
    "tapacaminos": "ta-pa-ca-mi-nos",
    "tapacete": "ta-pa-ce-te",
    "tapachiche": "ta-pa-chi-che",
    "tapachichi": "ta-pa-chi-chi",
    "tapacosturas": "ta-pa-cos-tu-ras",
    "tapacubo": "ta-pa-cu-bo",
    "tapacubos": "ta-pa-cu-bos",
    "tapaculo": "ta-pa-cu-lo",
    "tapaculos": "ta-pa-cu-los",
    "tapada": "ta-pa-da",
    "tapadera": "ta-pa-de-ra",
    "tapadero": "ta-pa-de-ro",
    "tapadillo": "ta-pa-di-llo",
    "tapado": "ta-pa-do",
    "tapador": "ta-pa-dor",
    "tapadora": "ta-pa-do-ra",
    "tapadura": "ta-pa-du-ra",
    "tapafunda": "ta-pa-fun-da",
    "tapajuntas": "ta-pa-jun-tas",
    "tápalo": "tá-pa-lo",
    "tapamiento": "ta-pa-mien-to",
    "tapanco": "ta-pan-co",
    "tapaojos": "ta-pa-o-jos",
    "tapapecho": "ta-pa-pe-cho",
    "tapapiés": "ta-pa-piés",
    "tapar": "ta-par",
    "tapara": "ta-pa-ra",
    "tápara": "tá-pa-ra",
    "taparear": "ta-pa-re-ar",
    "taparo": "ta-pa-ro",
    "taparote": "ta-pa-ro-te",
    "taparrabo": "ta-pa-rra-bo",
    "taparrabos": "ta-pa-rra-bos",
    "tapasol": "ta-pa-sol",
    "tapate": "ta-pa-te",
    "tapatía": "ta-pa-tí-a",
    "tapatío": "ta-pa-tí-o",
    "tapayagua": "ta-pa-ya-gua",
    "tapazo": "ta-pa-zo",
    "tape": "ta-pe",
    "tapeada": "ta-pe-a-da",
    "tapear": "ta-pe-ar",
    "tapegua": "ta-pe-gua",
    "tápena": "tá-pe-na",
    "tapeo": "ta-pe-o",
    "tapera": "ta-pe-ra",
    "taperujar": "ta-pe-ru-jar",
    "taperujarse": "ta-pe-ru-jar-se",
    "taperujo": "ta-pe-ru-jo",
    "tapesco": "ta-pes-co",
    "tapesquillo": "ta-pes-qui-llo",
    "tapetada": "ta-pe-ta-da",
    "tapetado": "ta-pe-ta-do",
    "tapete": "ta-pe-te",
    "tapia": "ta-pia",
    "tapiado": "ta-pia-do",
    "tapiador": "ta-pia-dor",
    "tapial": "ta-pial",
    "tapialar": "ta-pia-lar",
    "tapiar": "ta-piar",
    "tapicera": "ta-pi-ce-ra",
    "tapicería": "ta-pi-ce-rí-a",
    "tapicero": "ta-pi-ce-ro",
    "tapida": "ta-pi-da",
    "tapido": "ta-pi-do",
    "tapiería": "ta-pie-rí-a",
    "tapilla": "ta-pi-lla",
    "tapín": "ta-pín",
    "tapina": "ta-pi-na",
    "tapinear": "ta-pi-ne-ar",
    "tapioca": "ta-pio-ca",
    "tapir": "ta-pir",
    "tapirujar": "ta-pi-ru-jar",
    "tapirujarse": "ta-pi-ru-jar-se",
    "tapirujo": "ta-pi-ru-jo",
    "tapis": "ta-pis",
    "tapisca": "ta-pis-ca",
    "tapiscar": "ta-pis-car",
    "tapiz": "ta-piz",
    "tapizado": "ta-pi-za-do",
    "tapizar": "ta-pi-zar",
    "tapón": "ta-pón",
    "taponador": "ta-po-na-dor",
    "taponadora": "ta-po-na-do-ra",
    "taponamiento": "ta-po-na-mien-to",
    "taponar": "ta-po-nar",
    "taponazo": "ta-po-na-zo",
    "taponear": "ta-po-ne-ar",
    "taponera": "ta-po-ne-ra",
    "taponería": "ta-po-ne-rí-a",
    "taponero": "ta-po-ne-ro",
    "tapsia": "tap-sia",
    "tapudo": "ta-pu-do",
    "tapujar": "ta-pu-jar",
    "tapujarse": "ta-pu-jar-se",
    "tapujo": "ta-pu-jo",
    "tapuya": "ta-pu-ya",
    "taque": "ta-que",
    "taqué": "ta-qué",
    "taqueado": "ta-que-a-do",
    "taquear": "ta-que-ar",
    "taqueo": "ta-que-o",
    "taquera": "ta-que-ra",
    "taquería": "ta-que-rí-a",
    "taquero": "ta-que-ro",
    "taquicardia": "ta-qui-car-dia",
    "taquichuela": "ta-qui-chue-la",
    "taquígrafa": "ta-quí-gra-fa",
    "taquigrafía": "ta-qui-gra-fí-a",
    "taquigrafiar": "ta-qui-gra-fiar",
    "taquigráfica": "ta-qui-grá-fi-ca",
    "taquigráficamente": "ta-qui-grá-fi-ca-men-te",
    "taquigráfico": "ta-qui-grá-fi-co",
    "taquígrafo": "ta-quí-gra-fo",
    "taquilla": "ta-qui-lla",
    "taquillaje": "ta-qui-lla-je",
    "taquillar": "ta-qui-llar",
    "taquillera": "ta-qui-lle-ra",
    "taquillero": "ta-qui-lle-ro",
    "taquillón": "ta-qui-llón",
    "taquimeca": "ta-qui-me-ca",
    "taquimecanógrafa": "ta-qui-me-ca-nó-gra-fa",
    "taquimecanografía": "ta-qui-me-ca-no-gra-fí-a",
    "taquimecanógrafo": "ta-qui-me-ca-nó-gra-fo",
    "taquimetría": "ta-qui-me-trí-a",
    "taquimétrica": "ta-qui-mé-tri-ca",
    "taquimétrico": "ta-qui-mé-tri-co",
    "taquímetro": "ta-quí-me-tro",
    "taquín": "ta-quín",
    "taquipnea": "ta-quip-ne-a",
    "taquirari": "ta-qui-ra-ri",
    "tara": "ta-ra",
    "tarabilla": "ta-ra-bi-lla",
    "tarabita": "ta-ra-bi-ta",
    "tarabuqueña": "ta-ra-bu-que-ña",
    "tarabuqueño": "ta-ra-bu-que-ño",
    "taracea": "ta-ra-ce-a",
    "taraceador": "ta-ra-ce-a-dor",
    "taraceadora": "ta-ra-ce-a-do-ra",
    "taracear": "ta-ra-ce-ar",
    "taracol": "ta-ra-col",
    "tarada": "ta-ra-da",
    "taradez": "ta-ra-dez",
    "tarado": "ta-ra-do",
    "tarafada": "ta-ra-fa-da",
    "tarafana": "ta-ra-fa-na",
    "tarafe": "ta-ra-fe",
    "taragallo": "ta-ra-ga-llo",
    "taragón": "ta-ra-gón",
    "taragontía": "ta-ra-gon-tí-a",
    "taragoza": "ta-ra-go-za",
    "taragozajida": "ta-ra-go-za-ji-da",
    "tarahumara": "ta-rahu-ma-ra",
    "tarajalla": "ta-ra-ja-lla",
    "tarajallo": "ta-ra-ja-llo",
    "tarajalluda": "ta-ra-ja-llu-da",
    "tarajalludo": "ta-ra-ja-llu-do",
    "taraje": "ta-ra-je",
    "taraletes": "ta-ra-le-tes",
    "tarama": "ta-ra-ma",
    "tarambana": "ta-ram-ba-na",
    "taramela": "ta-ra-me-la",
    "tarando": "ta-ran-do",
    "tarangallo": "ta-ran-ga-llo",
    "tarángana": "ta-rán-ga-na",
    "taranta": "ta-ran-ta",
    "tarantela": "ta-ran-te-la",
    "tarantera": "ta-ran-te-ra",
    "tarantín": "ta-ran-tín",
    "tarántula": "ta-rán-tu-la",
    "tarantulada": "ta-ran-tu-la-da",
    "tarantulado": "ta-ran-tu-la-do",
    "tarapaqueña": "ta-ra-pa-que-ña",
    "tarapaqueño": "ta-ra-pa-que-ño",
    "tarar": "ta-rar",
    "tarara": "ta-ra-ra",
    "tarará": "ta-ra-rá",
    "tararaco": "ta-ra-ra-co",
    "tararear": "ta-ra-re-ar",
    "tarareo": "ta-ra-re-o",
    "tararí": "ta-ra-rí",
    "tararira": "ta-ra-ri-ra",
    "tarasa": "ta-ra-sa",
    "tarasca": "ta-ras-ca",
    "tarascada": "ta-ras-ca-da",
    "tarascar": "ta-ras-car",
    "tarasco": "ta-ras-co",
    "tarascón": "ta-ras-cón",
    "tarasí": "ta-ra-sí",
    "tarasquear": "ta-ras-que-ar",
    "taratántara": "ta-ra-tán-ta-ra",
    "tarateña": "ta-ra-te-ña",
    "tarateño": "ta-ra-te-ño",
    "taray": "ta-ray",
    "tarayal": "ta-ra-yal",
    "taraza": "ta-ra-za",
    "tarazana": "ta-ra-za-na",
    "tarazanal": "ta-ra-za-nal",
    "tarazar": "ta-ra-zar",
    "tarazón": "ta-ra-zón",
    "tarbea": "tar-be-a",
    "tarca": "tar-ca",
    "tarco": "tar-co",
    "tarda": "tar-da",
    "tardador": "tar-da-dor",
    "tardadora": "tar-da-do-ra",
    "tardana": "tar-da-na",
    "tardanaos": "tar-da-na-os",
    "tardano": "tar-da-no",
    "tardanza": "tar-dan-za",
    "tardar": "tar-dar",
    "tarde": "tar-de",
    "tardeada": "tar-de-a-da",
    "tardear": "tar-de-ar",
    "tardecer": "tar-de-cer",
    "tardecica": "tar-de-ci-ca",
    "tardecita": "tar-de-ci-ta",
    "tardía": "tar-dí-a",
    "tardíamente": "tar-dí-a-men-te",
    "tardígrada": "tar-dí-gra-da",
    "tardígrado": "tar-dí-gra-do",
    "tardinera": "tar-di-ne-ra",
    "tardinero": "tar-di-ne-ro",
    "tardío": "tar-dí-o",
    "tardísimo": "tar-dí-si-mo",
    "tardo": "tar-do",
    "tardofranquismo": "tar-do-fran-quis-mo",
    "tardomedieval": "tar-do-me-die-val",
    "tardomedievo": "tar-do-me-die-vo",
    "tardón": "tar-dón",
    "tardona": "tar-do-na",
    "tarea": "ta-re-a",
    "tarechi": "ta-re-chi",
    "tareco": "ta-re-co",
    "tareero": "ta-re-e-ro",
    "tarentina": "ta-ren-ti-na",
    "tarentino": "ta-ren-ti-no",
    "target": "tar-get",
    "targuá": "tar-guá",
    "tárgum": "tár-gum",
    "tarhui": "tar-hui",
    "tarida": "ta-ri-da",
    "tarifa": "ta-ri-fa",
    "tarifación": "ta-ri-fa-ción",
    "tarifador": "ta-ri-fa-dor",
    "tarifar": "ta-ri-far",
    "tarifario": "ta-ri-fa-rio",
    "tarifeña": "ta-ri-fe-ña",
    "tarifeño": "ta-ri-fe-ño",
    "tarificación": "ta-ri-fi-ca-ción",
    "tarificador": "ta-ri-fi-ca-dor",
    "tarificar": "ta-ri-fi-car",
    "tarijeña": "ta-ri-je-ña",
    "tarijeño": "ta-ri-je-ño",
    "tarima": "ta-ri-ma",
    "tarimón": "ta-ri-món",
    "tarín": "ta-rín",
    "tarina": "ta-ri-na",
    "tarja": "tar-ja",
    "tarjador": "tar-ja-dor",
    "tarjadora": "tar-ja-do-ra",
    "tarjar": "tar-jar",
    "tarjera": "tar-je-ra",
    "tarjero": "tar-je-ro",
    "tarjeta": "tar-je-ta",
    "tarjetahabiente": "tar-je-ta-ha-bien-te",
    "tarjetear": "tar-je-te-ar",
    "tarjeteo": "tar-je-te-o",
    "tarjetero": "tar-je-te-ro",
    "tarjetón": "tar-je-tón",
    "tarlatana": "tar-la-ta-na",
    "tarma": "tar-ma",
    "tarmeña": "tar-me-ña",
    "tarmeño": "tar-me-ño",
    "taropé": "ta-ro-pé",
    "tarot": "ta-rot",
    "tarquia": "tar-quia",
    "tarquín": "tar-quín",
    "tarquina": "tar-qui-na",
    "tarquinada": "tar-qui-na-da",
    "tarra": "ta-rra",
    "tarraconense": "ta-rra-co-nen-se",
    "tárraga": "tá-rra-ga",
    "tarrago": "ta-rra-go",
    "tarragona": "ta-rra-go-na",
    "tarraja": "ta-rra-ja",
    "tarrajear": "ta-rra-je-ar",
    "tarralí": "ta-rra-lí",
    "tarrañuela": "ta-rra-ñue-la",
    "tarrascar": "ta-rras-car",
    "tarrasense": "ta-rra-sen-se",
    "tarraya": "ta-rra-ya",
    "tarraza": "ta-rra-za",
    "tarrear": "ta-rre-ar",
    "tarrecer": "ta-rre-cer",
    "tarreña": "ta-rre-ña",
    "tarrico": "ta-rri-co",
    "tarrina": "ta-rri-na",
    "tarriza": "ta-rri-za",
    "tarro": "ta-rro",
    "tarruda": "ta-rru-da",
    "tarrudo": "ta-rru-do",
    "tarsana": "tar-sa-na",
    "tarsero": "tar-se-ro",
    "tarso": "tar-so",
    "tarta": "tar-ta",
    "tártago": "tár-ta-go",
    "tartaja": "tar-ta-ja",
    "tartajear": "tar-ta-je-ar",
    "tartajeo": "tar-ta-je-o",
    "tartajo": "tar-ta-jo",
    "tartajosa": "tar-ta-jo-sa",
    "tartajoso": "tar-ta-jo-so",
    "tartalear": "tar-ta-le-ar",
    "tartaleta": "tar-ta-le-ta",
    "tartamuda": "tar-ta-mu-da",
    "tartamudear": "tar-ta-mu-de-ar",
    "tartamudeo": "tar-ta-mu-de-o",
    "tartamudez": "tar-ta-mu-dez",
    "tartamudo": "tar-ta-mu-do",
    "tartán": "tar-tán",
    "tartana": "tar-ta-na",
    "tartanero": "tar-ta-ne-ro",
    "tártano": "tár-ta-no",
    "tártara": "tár-ta-ra",
    "tartárea": "tar-tá-re-a",
    "tartáreo": "tar-tá-re-o",
    "tartarí": "tar-ta-rí",
    "tartárica": "tar-tá-ri-ca",
    "tartárico": "tar-tá-ri-co",
    "tartarita": "tar-ta-ri-ta",
    "tartarizar": "tar-ta-ri-zar",
    "tártaro": "tár-ta-ro",
    "tartera": "tar-te-ra",
    "tartesia": "tar-te-sia",
    "tartesio": "tar-te-sio",
    "tartrato": "tar-tra-to",
    "tártrica": "tár-tri-ca",
    "tártrico": "tár-tri-co",
    "tartufismo": "tar-tu-fis-mo",
    "tartufo": "tar-tu-fo",
    "taruga": "ta-ru-ga",
    "tarugada": "ta-ru-ga-da",
    "tarugo": "ta-ru-go",
    "tarumá": "ta-ru-má",
    "tarumba": "ta-rum-ba",
    "tarúpida": "ta-rú-pi-da",
    "tarúpido": "ta-rú-pi-do",
    "tarusa": "ta-ru-sa",
    "tasa": "ta-sa",
    "tasación": "ta-sa-ción",
    "tasadamente": "ta-sa-da-men-te",
    "tasado": "ta-sa-do",
    "tasador": "ta-sa-dor",
    "tasadora": "ta-sa-do-ra",
    "tasajear": "ta-sa-je-ar",
    "tasajeo": "ta-sa-je-o",
    "tasajera": "ta-sa-je-ra",
    "tasajero": "ta-sa-je-ro",
    "tasajo": "ta-sa-jo",
    "tasar": "ta-sar",
    "tasarte": "ta-sar-te",
    "tasca": "tas-ca",
    "tascador": "tas-ca-dor",
    "tascar": "tas-car",
    "tasco": "tas-co",
    "tasconio": "tas-co-nio",
    "tascucia": "tas-cu-cia",
    "tascucio": "tas-cu-cio",
    "tasele": "ta-se-le",
    "tasi": "ta-si",
    "tasia": "ta-sia",
    "tasio": "ta-sio",
    "tasmana": "tas-ma-na",
    "tasmano": "tas-ma-no",
    "tasquear": "tas-que-ar",
    "tasqueo": "tas-que-o",
    "tasquera": "tas-que-ra",
    "tasquil": "tas-quil",
    "tastana": "tas-ta-na",
    "tastar": "tas-tar",
    "tastaz": "tas-taz",
    "tasto": "tas-to",
    "tasugo": "ta-su-go",
    "tata": "ta-ta",
    "tatabro": "ta-ta-bro",
    "tatagua": "ta-ta-gua",
    "tatami": "ta-ta-mi",
    "tatané": "ta-ta-né",
    "tatarabuela": "ta-ta-ra-bue-la",
    "tatarabuelo": "ta-ta-ra-bue-lo",
    "tataradeuda": "ta-ta-ra-deu-da",
    "tataradeudo": "ta-ta-ra-deu-do",
    "tataranieta": "ta-ta-ra-nie-ta",
    "tataranieto": "ta-ta-ra-nie-to",
    "tatarata": "ta-ta-ra-ta",
    "tatarate": "ta-ta-ra-te",
    "tataratear": "ta-ta-ra-te-ar",
    "tataré": "ta-ta-ré",
    "tatarear": "ta-ta-re-ar",
    "tataretas": "ta-ta-re-tas",
    "tatareto": "ta-ta-re-to",
    "tatas": "ta-tas",
    "tatay": "ta-tay",
    "tate": "ta-te",
    "tatema": "ta-te-ma",
    "tatemada": "ta-te-ma-da",
    "tatemado": "ta-te-ma-do",
    "tatemar": "ta-te-mar",
    "tatetí": "ta-te-tí",
    "tatita": "ta-ti-ta",
    "tato": "ta-to",
    "tatú": "ta-tú",
    "tatuador": "ta-tua-dor",
    "tatuadora": "ta-tua-do-ra",
    "tatuaje": "ta-tua-je",
    "tatuar": "ta-tuar",
    "tatuejo": "ta-tue-jo",
    "tauca": "tau-ca",
    "taucar": "tau-car",
    "taujel": "tau-jel",
    "taujía": "tau-jí-a",
    "taula": "tau-la",
    "taumaturga": "tau-ma-tur-ga",
    "taumaturgia": "tau-ma-tur-gia",
    "taumatúrgica": "tau-ma-túr-gi-ca",
    "taumatúrgico": "tau-ma-túr-gi-co",
    "taumaturgo": "tau-ma-tur-go",
    "taunachi": "tau-na-chi",
    "taurete": "tau-re-te",
    "táurico": "táu-ri-co",
    "taurina": "tau-ri-na",
    "taurino": "tau-ri-no",
    "taurios": "tau-rios",
    "tauro": "tau-ro",
    "taurófila": "tau-ró-fi-la",
    "taurófilo": "tau-ró-fi-lo",
    "taurófobo": "tau-ró-fo-bo",
    "taurómaca": "tau-ró-ma-ca",
    "taurómaco": "tau-ró-ma-co",
    "tauromaquia": "tau-ro-ma-quia",
    "tauromáquica": "tau-ro-má-qui-ca",
    "tauromáquico": "tau-ro-má-qui-co",
    "tauteo": "tau-te-o",
    "tautología": "tau-to-lo-gí-a",
    "tautológica": "tau-to-ló-gi-ca",
    "tautológico": "tau-to-ló-gi-co",
    "tawahka": "ta-wah-ka",
    "taxácea": "ta-xá-ce-a",
    "taxáceo": "ta-xá-ce-o",
    "taxativa": "ta-xa-ti-va",
    "taxativamente": "ta-xa-ti-va-men-te",
    "taxativo": "ta-xa-ti-vo",
    "taxcal": "tax-cal",
    "taxi": "ta-xi",
    "taxia": "ta-xia",
    "taxidermia": "ta-xi-der-mia",
    "taxidermista": "ta-xi-der-mis-ta",
    "taxiflet": "ta-xi-flet",
    "taxímetro": "ta-xí-me-tro",
    "taxista": "ta-xis-ta",
    "taxodiácea": "ta-xo-diá-ce-a",
    "taxodiáceo": "ta-xo-diá-ce-o",
    "taxon": "ta-xon",
    "taxón": "ta-xón",
    "taxónoma": "ta-xó-no-ma",
    "taxonomía": "ta-xo-no-mí-a",
    "taxonómica": "ta-xo-nó-mi-ca",
    "taxonómico": "ta-xo-nó-mi-co",
    "taxonomista": "ta-xo-no-mis-ta",
    "taxónomo": "ta-xó-no-mo",
    "taxqueña": "tax-que-ña",
    "taxqueño": "tax-que-ño",
    "taya": "ta-ya",
    "tayacán": "ta-ya-cán",
    "tayacanear": "ta-ya-ca-ne-ar",
    "tayika": "ta-yi-ka",
    "tayiko": "ta-yi-ko",
    "tayo": "ta-yo",
    "tayul": "ta-yul",
    "tayuyá": "ta-yu-yá",
    "tayuyo": "ta-yu-yo",
    "taza": "ta-za",
    "tazaña": "ta-za-ña",
    "tazar": "ta-zar",
    "tazmía": "taz-mí-a",
    "tazón": "ta-zón",
    "tea": "te-a",
    "teácea": "te-á-ce-a",
    "teáceo": "te-á-ce-o",
    "teame": "te-a-me",
    "teamide": "te-a-mi-de",
    "teatina": "te-a-ti-na",
    "teatino": "te-a-ti-no",
    "teatral": "te-a-tral",
    "teatralidad": "te-a-tra-li-dad",
    "teatralización": "te-a-tra-li-za-ción",
    "teatralizar": "te-a-tra-li-zar",
    "teatralmente": "te-a-tral-men-te",
    "teatrera": "te-a-tre-ra",
    "teatrero": "te-a-tre-ro",
    "teátrica": "te-á-tri-ca",
    "teátrico": "te-á-tri-co",
    "teatro": "te-a-tro",
    "tebaica": "te-bai-ca",
    "tebaico": "te-bai-co",
    "tebana": "te-ba-na",
    "tebano": "te-ba-no",
    "tebea": "te-be-a",
    "tebenque": "te-ben-que",
    "tebeo": "te-be-o",
    "teca": "te-ca",
    "tecali": "te-ca-li",
    "techado": "te-cha-do",
    "techador": "te-cha-dor",
    "techadora": "te-cha-do-ra",
    "techar": "te-char",
    "techichi": "te-chi-chi",
    "techo": "te-cho",
    "techomite": "te-cho-mi-te",
    "techumbre": "te-chum-bre",
    "tecina": "te-ci-na",
    "teckel": "tec-kel",
    "tecla": "te-cla",
    "tecladista": "te-cla-dis-ta",
    "teclado": "te-cla-do",
    "tecle": "te-cle",
    "tecleado": "te-cle-a-do",
    "teclear": "te-cle-ar",
    "tecleña": "te-cle-ña",
    "tecleño": "te-cle-ño",
    "tecleo": "te-cle-o",
    "teclista": "te-clis-ta",
    "teclo": "te-clo",
    "tecnecio": "tec-ne-cio",
    "técnica": "téc-ni-ca",
    "técnicamente": "téc-ni-ca-men-te",
    "tecnicatura": "tec-ni-ca-tu-ra",
    "tecnicidad": "tec-ni-ci-dad",
    "tecnicismo": "tec-ni-cis-mo",
    "técnico": "téc-ni-co",
    "tecnicolor": "tec-ni-co-lor",
    "tecnificación": "tec-ni-fi-ca-ción",
    "tecnificar": "tec-ni-fi-car",
    "tecno": "tec-no",
    "tecnocracia": "tec-no-cra-cia",
    "tecnócrata": "tec-nó-cra-ta",
    "tecnocrático": "tec-no-crá-ti-co",
    "tecnografía": "tec-no-gra-fí-a",
    "tecnóloga": "tec-nó-lo-ga",
    "tecnología": "tec-no-lo-gí-a",
    "tecnológica": "tec-no-ló-gi-ca",
    "tecnológicamente": "tec-no-ló-gi-ca-men-te",
    "tecnológico": "tec-no-ló-gi-co",
    "tecnólogo": "tec-nó-lo-go",
    "tecol": "te-col",
    "tecolero": "te-co-le-ro",
    "tecolía": "te-co-lí-a",
    "tecolilla": "te-co-li-lla",
    "tecolote": "te-co-lo-te",
    "tecomajuche": "te-co-ma-ju-che",
    "tecomasuche": "te-co-ma-su-che",
    "tecomate": "te-co-ma-te",
    "tectiteca": "tec-ti-te-ca",
    "tectónica": "tec-tó-ni-ca",
    "tectónico": "tec-tó-ni-co",
    "tecuán": "te-cuán",
    "tecuín": "te-cuín",
    "tecuino": "te-cui-no",
    "teda": "te-da",
    "tedero": "te-de-ro",
    "tedeum": "te-deum",
    "tediar": "te-diar",
    "tedio": "te-dio",
    "tediosa": "te-dio-sa",
    "tedioso": "te-dio-so",
    "tee": "te-e",
    "tefe": "te-fe",
    "teflón": "te-flón",
    "tegea": "te-ge-a",
    "tegeo": "te-ge-o",
    "tegua": "te-gua",
    "tegual": "te-gual",
    "tegucigalpense": "te-gu-ci-gal-pen-se",
    "tegüe": "te-güe",
    "teguillo": "te-gui-llo",
    "tegumentaria": "te-gu-men-ta-ria",
    "tegumentario": "te-gu-men-ta-rio",
    "tegumento": "te-gu-men-to",
    "tehuana": "te-hua-na",
    "tehuano": "te-hua-no",
    "tehuelche": "te-huel-che",
    "tehúl": "te-húl",
    "teína": "te-í-na",
    "teinada": "tei-na-da",
    "teísmo": "te-ís-mo",
    "teísta": "te-ís-ta",
    "teitral": "tei-tral",
    "teja": "te-ja",
    "tejabán": "te-ja-bán",
    "tejadillo": "te-ja-di-llo",
    "tejado": "te-ja-do",
    "tejamaní": "te-ja-ma-ní",
    "tejamanil": "te-ja-ma-nil",
    "tejana": "te-ja-na",
    "tejano": "te-ja-no",
    "tejar": "te-jar",
    "tejaroz": "te-ja-roz",
    "tejaván": "te-ja-ván",
    "tejavana": "te-ja-va-na",
    "tejedera": "te-je-de-ra",
    "tejedor": "te-je-dor",
    "tejedora": "te-je-do-ra",
    "tejedura": "te-je-du-ra",
    "tejeduría": "te-je-du-rí-a",
    "tejemaneje": "te-je-ma-ne-je",
    "tejer": "te-jer",
    "tejera": "te-je-ra",
    "tejería": "te-je-rí-a",
    "tejeringo": "te-je-rin-go",
    "tejero": "te-je-ro",
    "tejida": "te-ji-da",
    "tejido": "te-ji-do",
    "tejillo": "te-ji-llo",
    "tejimiento": "te-ji-mien-to",
    "tejo": "te-jo",
    "tejocotal": "te-jo-co-tal",
    "tejocote": "te-jo-co-te",
    "tejoleta": "te-jo-le-ta",
    "tejolote": "te-jo-lo-te",
    "tejolotear": "te-jo-lo-te-ar",
    "tejón": "te-jón",
    "tejonera": "te-jo-ne-ra",
    "tejuela": "te-jue-la",
    "tejuelo": "te-jue-lo",
    "tejuino": "te-jui-no",
    "tela": "te-la",
    "telamón": "te-la-món",
    "telar": "te-lar",
    "telaraña": "te-la-ra-ña",
    "telarañosa": "te-la-ra-ño-sa",
    "telarañoso": "te-la-ra-ño-so",
    "tele": "te-le",
    "teleadicta": "te-le-a-dic-ta",
    "teleadicto": "te-le-a-dic-to",
    "telebanca": "te-le-ban-ca",
    "telebanco": "te-le-ban-co",
    "telebasura": "te-le-ba-su-ra",
    "telecabina": "te-le-ca-bi-na",
    "telecinematógrafo": "te-le-ci-ne-ma-tó-gra-fo",
    "teleclinómetro": "te-le-cli-nó-me-tro",
    "teleclub": "te-le-club",
    "telecomedia": "te-le-co-me-dia",
    "telecompra": "te-le-com-pra",
    "telecomunicación": "te-le-co-mu-ni-ca-ción",
    "telecontrol": "te-le-con-trol",
    "teledetección": "te-le-de-tec-ción",
    "telediario": "te-le-dia-rio",
    "teledifusión": "te-le-di-fu-sión",
    "teledirección": "te-le-di-rec-ción",
    "teledirigido": "te-le-di-ri-gi-do",
    "teledirigir": "te-le-di-ri-gir",
    "telefacsímil": "te-le-fac-sí-mil",
    "telefax": "te-le-fax",
    "teleférica": "te-le-fé-ri-ca",
    "teleférico": "te-le-fé-ri-co",
    "telefilm": "te-le-film",
    "telefilme": "te-le-fil-me",
    "telefio": "te-le-fio",
    "telefonazo": "te-le-fo-na-zo",
    "telefonear": "te-le-fo-ne-ar",
    "telefonema": "te-le-fo-ne-ma",
    "telefonía": "te-le-fo-ní-a",
    "telefónica": "te-le-fó-ni-ca",
    "telefónicamente": "te-le-fó-ni-ca-men-te",
    "telefónico": "te-le-fó-ni-co",
    "telefonillo": "te-le-fo-ni-llo",
    "telefonista": "te-le-fo-nis-ta",
    "teléfono": "te-lé-fo-no",
    "telefonómetro": "te-le-fo-nó-me-tro",
    "telefoto": "te-le-fo-to",
    "telefotografía": "te-le-fo-to-gra-fí-a",
    "telega": "te-le-ga",
    "telegenia": "te-le-ge-nia",
    "telegénico": "te-le-gé-ni-co",
    "telegrafía": "te-le-gra-fí-a",
    "telegrafiar": "te-le-gra-fiar",
    "telegráfica": "te-le-grá-fi-ca",
    "telegráficamente": "te-le-grá-fi-ca-men-te",
    "telegráfico": "te-le-grá-fi-co",
    "telegrafista": "te-le-gra-fis-ta",
    "telégrafo": "te-lé-gra-fo",
    "telegrama": "te-le-gra-ma",
    "teleguiado": "te-le-guia-do",
    "teleimpresor": "te-leim-pre-sor",
    "teleindicador": "te-lein-di-ca-dor",
    "telekinesia": "te-le-ki-ne-sia",
    "telele": "te-le-le",
    "telemando": "te-le-man-do",
    "telemarketing": "te-le-mar-ke-ting",
    "telemática": "te-le-má-ti-ca",
    "telemático": "te-le-má-ti-co",
    "telemedicina": "te-le-me-di-ci-na",
    "telemetría": "te-le-me-trí-a",
    "telemétrica": "te-le-mé-tri-ca",
    "telemétrico": "te-le-mé-tri-co",
    "telémetro": "te-lé-me-tro",
    "teleña": "te-le-ña",
    "telencéfalo": "te-len-cé-fa-lo",
    "telenda": "te-len-da",
    "telendo": "te-len-do",
    "telengues": "te-len-gues",
    "teleño": "te-le-ño",
    "telenoticiero": "te-le-no-ti-cie-ro",
    "telenovela": "te-le-no-ve-la",
    "telenque": "te-len-que",
    "teleobjetivo": "te-le-ob-je-ti-vo",
    "teleología": "te-le-o-lo-gí-a",
    "teleológico": "te-le-o-ló-gi-co",
    "teleoperador": "te-le-o-pe-ra-dor",
    "teleoperadora": "te-le-o-pe-ra-do-ra",
    "teleósteo": "te-le-ós-te-o",
    "telepate": "te-le-pa-te",
    "telepatía": "te-le-pa-tí-a",
    "telepática": "te-le-pá-ti-ca",
    "telepático": "te-le-pá-ti-co",
    "telepedido": "te-le-pe-di-do",
    "telepredicador": "te-le-pre-di-ca-dor",
    "teleprocesar": "te-le-pro-ce-sar",
    "teleproceso": "te-le-pro-ce-so",
    "telequinesia": "te-le-qui-ne-sia",
    "telera": "te-le-ra",
    "telerín": "te-le-rín",
    "telero": "te-le-ro",
    "telerón": "te-le-rón",
    "telerruta": "te-le-rru-ta",
    "telescópica": "te-les-có-pi-ca",
    "telescópico": "te-les-có-pi-co",
    "telescopio": "te-les-co-pio",
    "teleserie": "te-le-se-rie",
    "telesilla": "te-le-si-lla",
    "telespectador": "te-les-pec-ta-dor",
    "telespectadora": "te-les-pec-ta-do-ra",
    "telesquí": "te-les-quí",
    "teleta": "te-le-ta",
    "teleteatro": "te-le-te-a-tro",
    "teletexto": "te-le-tex-to",
    "teletienda": "te-le-tien-da",
    "teletipo": "te-le-ti-po",
    "teletón": "te-le-tón",
    "teletrabajador": "te-le-tra-ba-ja-dor",
    "teletrabajadora": "te-le-tra-ba-ja-do-ra",
    "teletrabajo": "te-le-tra-ba-jo",
    "televendedor": "te-le-ven-de-dor",
    "televendedora": "te-le-ven-de-do-ra",
    "televenta": "te-le-ven-ta",
    "televidencia": "te-le-vi-den-cia",
    "televidente": "te-le-vi-den-te",
    "televisado": "te-le-vi-sa-do",
    "televisar": "te-le-vi-sar",
    "televisión": "te-le-vi-sión",
    "televisivamente": "te-le-vi-si-va-men-te",
    "televisivo": "te-le-vi-si-vo",
    "televisor": "te-le-vi-sor",
    "televisual": "te-le-vi-sual",
    "télex": "té-lex",
    "telilla": "te-li-lla",
    "telina": "te-li-na",
    "tellina": "te-lli-na",
    "telliz": "te-lliz",
    "telliza": "te-lli-za",
    "telofase": "te-lo-fa-se",
    "telón": "te-lón",
    "telonera": "te-lo-ne-ra",
    "telonero": "te-lo-ne-ro",
    "telonio": "te-lo-nio",
    "telson": "tel-son",
    "telúrica": "te-lú-ri-ca",
    "telúrico": "te-lú-ri-co",
    "telurio": "te-lu-rio",
    "telurismo": "te-lu-ris-mo",
    "teluro": "te-lu-ro",
    "tema": "te-ma",
    "temar": "te-mar",
    "temario": "te-ma-rio",
    "temascal": "te-mas-cal",
    "temática": "te-má-ti-ca",
    "temáticamente": "te-má-ti-ca-men-te",
    "temático": "te-má-ti-co",
    "tematización": "te-ma-ti-za-ción",
    "tematizar": "te-ma-ti-zar",
    "temazate": "te-ma-za-te",
    "temazcal": "te-maz-cal",
    "tembeleque": "tem-be-le-que",
    "tembladal": "tem-bla-dal",
    "tembladera": "tem-bla-de-ra",
    "tembladeral": "tem-bla-de-ral",
    "tembladerilla": "tem-bla-de-ri-lla",
    "tembladero": "tem-bla-de-ro",
    "temblador": "tem-bla-dor",
    "tembladora": "tem-bla-do-ra",
    "temblante": "tem-blan-te",
    "temblar": "tem-blar",
    "tembleque": "tem-ble-que",
    "temblequear": "tem-ble-que-ar",
    "temblequeo": "tem-ble-que-o",
    "temblequera": "tem-ble-que-ra",
    "temblequeteo": "tem-ble-que-te-o",
    "tembletear": "tem-ble-te-ar",
    "tembliquear": "tem-bli-que-ar",
    "temblón": "tem-blón",
    "temblona": "tem-blo-na",
    "temblor": "tem-blor",
    "temblorina": "tem-blo-ri-na",
    "temblorosa": "tem-blo-ro-sa",
    "tembloroso": "tem-blo-ro-so",
    "temblosa": "tem-blo-sa",
    "tembloso": "tem-blo-so",
    "tembloteo": "tem-blo-te-o",
    "temedera": "te-me-de-ra",
    "temedero": "te-me-de-ro",
    "temedor": "te-me-dor",
    "temedora": "te-me-do-ra",
    "temer": "te-mer",
    "temeraria": "te-me-ra-ria",
    "temerariamente": "te-me-ra-ria-men-te",
    "temerario": "te-me-ra-rio",
    "temeridad": "te-me-ri-dad",
    "temerón": "te-me-rón",
    "temerona": "te-me-ro-na",
    "temerosa": "te-me-ro-sa",
    "temerosamente": "te-me-ro-sa-men-te",
    "temeroso": "te-me-ro-so",
    "temible": "te-mi-ble",
    "temor": "te-mor",
    "temorizar": "te-mo-ri-zar",
    "temosa": "te-mo-sa",
    "temoso": "te-mo-so",
    "tempanador": "tem-pa-na-dor",
    "tempanar": "tem-pa-nar",
    "tempanil": "tem-pa-nil",
    "tempanilla": "tem-pa-ni-lla",
    "tempanillo": "tem-pa-ni-llo",
    "témpano": "tém-pa-no",
    "tempate": "tem-pa-te",
    "témpera": "tém-pe-ra",
    "temperación": "tem-pe-ra-ción",
    "temperada": "tem-pe-ra-da",
    "temperadamente": "tem-pe-ra-da-men-te",
    "temperado": "tem-pe-ra-do",
    "temperamental": "tem-pe-ra-men-tal",
    "temperamento": "tem-pe-ra-men-to",
    "temperancia": "tem-pe-ran-cia",
    "temperante": "tem-pe-ran-te",
    "temperar": "tem-pe-rar",
    "temperatura": "tem-pe-ra-tu-ra",
    "temperie": "tem-pe-rie",
    "tempero": "tem-pe-ro",
    "tempestad": "tem-pes-tad",
    "tempestar": "tem-pes-tar",
    "tempestear": "tem-pes-te-ar",
    "tempestiva": "tem-pes-ti-va",
    "tempestivamente": "tem-pes-ti-va-men-te",
    "tempestividad": "tem-pes-ti-vi-dad",
    "tempestivo": "tem-pes-ti-vo",
    "tempestuosa": "tem-pes-tuo-sa",
    "tempestuosamente": "tem-pes-tuo-sa-men-te",
    "tempestuoso": "tem-pes-tuo-so",
    "tempisque": "tem-pis-que",
    "templa": "tem-pla",
    "templación": "tem-pla-ción",
    "templada": "tem-pla-da",
    "templadamente": "tem-pla-da-men-te",
    "templadera": "tem-pla-de-ra",
    "templadero": "tem-pla-de-ro",
    "templado": "tem-pla-do",
    "templador": "tem-pla-dor",
    "templadora": "tem-pla-do-ra",
    "templadura": "tem-pla-du-ra",
    "templamiento": "tem-pla-mien-to",
    "templanza": "tem-plan-za",
    "templar": "tem-plar",
    "templario": "tem-pla-rio",
    "templazón": "tem-pla-zón",
    "temple": "tem-ple",
    "templén": "tem-plén",
    "templete": "tem-ple-te",
    "templista": "tem-plis-ta",
    "templo": "tem-plo",
    "tempo": "tem-po",
    "témpora": "tém-po-ra",
    "temporada": "tem-po-ra-da",
    "temporal": "tem-po-ral",
    "temporalidad": "tem-po-ra-li-dad",
    "temporalizar": "tem-po-ra-li-zar",
    "temporalmente": "tem-po-ral-men-te",
    "temporánea": "tem-po-rá-ne-a",
    "temporáneo": "tem-po-rá-ne-o",
    "temporaria": "tem-po-ra-ria",
    "temporario": "tem-po-ra-rio",
    "temporejar": "tem-po-re-jar",
    "temporera": "tem-po-re-ra",
    "temporero": "tem-po-re-ro",
    "temporil": "tem-po-ril",
    "temporizador": "tem-po-ri-za-dor",
    "temporizar": "tem-po-ri-zar",
    "temprana": "tem-pra-na",
    "tempranal": "tem-pra-nal",
    "tempranamente": "tem-pra-na-men-te",
    "tempranear": "tem-pra-ne-ar",
    "tempranera": "tem-pra-ne-ra",
    "tempranero": "tem-pra-ne-ro",
    "tempranilla": "tem-pra-ni-lla",
    "tempranillo": "tem-pra-ni-llo",
    "tempranito": "tem-pra-ni-to",
    "temprano": "tem-pra-no",
    "tempura": "tem-pu-ra",
    "temu": "te-mu",
    "temucana": "te-mu-ca-na",
    "temucano": "te-mu-ca-no",
    "temulenta": "te-mu-len-ta",
    "temulento": "te-mu-len-to",
    "tena": "te-na",
    "teña": "te-ña",
    "tenace": "te-na-ce",
    "tenacear": "te-na-ce-ar",
    "tenacera": "te-na-ce-ra",
    "tenacero": "te-na-ce-ro",
    "tenacidad": "te-na-ci-dad",
    "tenacillas": "te-na-ci-llas",
    "tenáculo": "te-ná-cu-lo",
    "tenada": "te-na-da",
    "tenallón": "te-na-llón",
    "tenamaste": "te-na-mas-te",
    "tenanche": "te-nan-che",
    "tenante": "te-nan-te",
    "tenate": "te-na-te",
    "tenaz": "te-naz",
    "tenaza": "te-na-za",
    "tenazada": "te-na-za-da",
    "tenazazo": "te-na-za-zo",
    "tenazón": "te-na-zón",
    "tenazuelas": "te-na-zue-las",
    "tenca": "ten-ca",
    "tencal": "ten-cal",
    "tención": "ten-ción",
    "tencua": "ten-cua",
    "tendajo": "ten-da-jo",
    "tendal": "ten-dal",
    "tendalada": "ten-da-la-da",
    "tendalera": "ten-da-le-ra",
    "tendalero": "ten-da-le-ro",
    "tendear": "ten-de-ar",
    "tendedera": "ten-de-de-ra",
    "tendedero": "ten-de-de-ro",
    "tendedor": "ten-de-dor",
    "tendedora": "ten-de-do-ra",
    "tendedura": "ten-de-du-ra",
    "tendejón": "ten-de-jón",
    "tendel": "ten-del",
    "tendencia": "ten-den-cia",
    "tendencial": "ten-den-cial",
    "tendenciosa": "ten-den-cio-sa",
    "tendenciosidad": "ten-den-cio-si-dad",
    "tendencioso": "ten-den-cio-so",
    "tendente": "ten-den-te",
    "tender": "ten-der",
    "ténder": "tén-der",
    "tendera": "ten-de-ra",
    "tenderete": "ten-de-re-te",
    "tendero": "ten-de-ro",
    "tendida": "ten-di-da",
    "tendidamente": "ten-di-da-men-te",
    "tendido": "ten-di-do",
    "tendiente": "ten-dien-te",
    "tendinitis": "ten-di-ni-tis",
    "tendinosa": "ten-di-no-sa",
    "tendinoso": "ten-di-no-so",
    "tendón": "ten-dón",
    "tenducha": "ten-du-cha",
    "tenducho": "ten-du-cho",
    "tenebrario": "te-ne-bra-rio",
    "tenebregosa": "te-ne-bre-go-sa",
    "tenebregoso": "te-ne-bre-go-so",
    "tenebregura": "te-ne-bre-gu-ra",
    "tenebrismo": "te-ne-bris-mo",
    "tenebrista": "te-ne-bris-ta",
    "tenebrosa": "te-ne-bro-sa",
    "tenebrosamente": "te-ne-bro-sa-men-te",
    "tenebrosidad": "te-ne-bro-si-dad",
    "tenebroso": "te-ne-bro-so",
    "tenedero": "te-ne-de-ro",
    "tenedor": "te-ne-dor",
    "tenedora": "te-ne-do-ra",
    "tenedorcillo": "te-ne-dor-ci-llo",
    "teneduría": "te-ne-du-rí-a",
    "tenejal": "te-ne-jal",
    "tenencia": "te-nen-cia",
    "tener": "te-ner",
    "teneres": "te-ne-res",
    "tenería": "te-ne-rí-a",
    "tenesmo": "te-nes-mo",
    "tengue": "ten-gue",
    "tenguerengue": "ten-gue-ren-gue",
    "tenia": "te-nia",
    "teniasis": "te-nia-sis",
    "teñible": "te-ñi-ble",
    "tenida": "te-ni-da",
    "teñido": "te-ñi-do",
    "teñidura": "te-ñi-du-ra",
    "tenienta": "te-nien-ta",
    "tenientazgo": "te-nien-taz-go",
    "teniente": "te-nien-te",
    "tenífuga": "te-ní-fu-ga",
    "tenífugo": "te-ní-fu-go",
    "tenío": "te-ní-o",
    "tenique": "te-ni-que",
    "teñir": "te-ñir",
    "tenis": "te-nis",
    "tenista": "te-nis-ta",
    "tenístico": "te-nís-ti-co",
    "tenobia": "te-no-bia",
    "tenor": "te-nor",
    "tenora": "te-no-ra",
    "tenorino": "te-no-ri-no",
    "tenorio": "te-no-rio",
    "tensa": "ten-sa",
    "tensar": "ten-sar",
    "tensina": "ten-si-na",
    "tensino": "ten-si-no",
    "tensiómetro": "ten-sió-me-tro",
    "tensión": "ten-sión",
    "tensionar": "ten-sio-nar",
    "tenso": "ten-so",
    "tensón": "ten-són",
    "tensor": "ten-sor",
    "tensora": "ten-so-ra",
    "tensorial": "ten-so-rial",
    "tentabuey": "ten-ta-buey",
    "tentación": "ten-ta-ción",
    "tentacular": "ten-ta-cu-lar",
    "tentáculo": "ten-tá-cu-lo",
    "tentadero": "ten-ta-de-ro",
    "tentado": "ten-ta-do",
    "tentador": "ten-ta-dor",
    "tentadora": "ten-ta-do-ra",
    "tentadura": "ten-ta-du-ra",
    "tentalear": "ten-ta-le-ar",
    "tentar": "ten-tar",
    "tentaruja": "ten-ta-ru-ja",
    "tentativa": "ten-ta-ti-va",
    "tentativamente": "ten-ta-ti-va-men-te",
    "tentativo": "ten-ta-ti-vo",
    "tentemozo": "ten-te-mo-zo",
    "tentempié": "ten-tem-pié",
    "tentenelaire": "ten-te-ne-lai-re",
    "tentetieso": "ten-te-tie-so",
    "tentón": "ten-tón",
    "tenue": "te-nue",
    "tenuidad": "te-nui-dad",
    "tenuirrostro": "te-nui-rros-tro",
    "tenuta": "te-nu-ta",
    "tenutaria": "te-nu-ta-ria",
    "tenutario": "te-nu-ta-rio",
    "tenzón": "ten-zón",
    "teobroma": "te-o-bro-ma",
    "teobromina": "te-o-bro-mi-na",
    "teocali": "te-o-ca-li",
    "teocalli": "te-o-ca-lli",
    "teocentrismo": "te-o-cen-tris-mo",
    "teocinte": "te-o-cin-te",
    "teocomite": "te-o-co-mi-te",
    "teocracia": "te-o-cra-cia",
    "teocrática": "te-o-crá-ti-ca",
    "teocrático": "te-o-crá-ti-co",
    "teodicea": "te-o-di-ce-a",
    "teodolito": "te-o-do-li-to",
    "teodosiana": "te-o-do-sia-na",
    "teodosiano": "te-o-do-sia-no",
    "teofanía": "te-o-fa-ní-a",
    "teogonía": "te-o-go-ní-a",
    "teogónica": "te-o-gó-ni-ca",
    "teogónico": "te-o-gó-ni-co",
    "teóloga": "te-ó-lo-ga",
    "teologal": "te-o-lo-gal",
    "teología": "te-o-lo-gí-a",
    "teológica": "te-o-ló-gi-ca",
    "teológicamente": "te-o-ló-gi-ca-men-te",
    "teológico": "te-o-ló-gi-co",
    "teologizar": "te-o-lo-gi-zar",
    "teólogo": "te-ó-lo-go",
    "teomanía": "te-o-ma-ní-a",
    "teónimo": "te-ó-ni-mo",
    "teorema": "te-o-re-ma",
    "teorética": "te-o-ré-ti-ca",
    "teorético": "te-o-ré-ti-co",
    "teoría": "te-o-rí-a",
    "teórica": "te-ó-ri-ca",
    "teóricamente": "te-ó-ri-ca-men-te",
    "teórico": "te-ó-ri-co",
    "teorizador": "te-o-ri-za-dor",
    "teorizante": "te-o-ri-zan-te",
    "teorizar": "te-o-ri-zar",
    "teosa": "te-o-sa",
    "teosinte": "te-o-sin-te",
    "teoso": "te-o-so",
    "teósofa": "te-ó-so-fa",
    "teosofía": "te-o-so-fí-a",
    "teosófica": "te-o-só-fi-ca",
    "teosófico": "te-o-só-fi-co",
    "teósofo": "te-ó-so-fo",
    "teotihuacana": "te-o-ti-hua-ca-na",
    "teotihuacano": "te-o-ti-hua-ca-no",
    "tepache": "te-pa-che",
    "tepachera": "te-pa-che-ra",
    "tepachería": "te-pa-che-rí-a",
    "tepachero": "te-pa-che-ro",
    "tepalcate": "te-pal-ca-te",
    "tépalo": "té-pa-lo",
    "tepe": "te-pe",
    "tepeaqués": "te-pe-a-qués",
    "tepeaquesa": "te-pe-a-que-sa",
    "tepeizcuinte": "te-peiz-cuin-te",
    "tepemechín": "te-pe-me-chín",
    "tepescuincle": "te-pes-cuin-cle",
    "tepestate": "te-pes-ta-te",
    "tepetal": "te-pe-tal",
    "tepetate": "te-pe-ta-te",
    "tepetatoso": "te-pe-ta-to-so",
    "tepetomate": "te-pe-to-ma-te",
    "tepezcuinte": "te-pez-cuin-te",
    "tepezcuintle": "te-pez-cuin-tle",
    "tepiqueña": "te-pi-que-ña",
    "tepiqueño": "te-pi-que-ño",
    "teponastle": "te-po-nas-tle",
    "teponaztle": "te-po-naz-tle",
    "teporocha": "te-po-ro-cha",
    "teporocho": "te-po-ro-cho",
    "tepotzo": "te-pot-zo",
    "tepozán": "te-po-zán",
    "tepozteca": "te-poz-te-ca",
    "tepozteco": "te-poz-te-co",
    "tepú": "te-pú",
    "tepuy": "te-puy",
    "teque": "te-que",
    "tequeña": "te-que-ña",
    "tequeño": "te-que-ño",
    "tequesquital": "te-ques-qui-tal",
    "tequesquite": "te-ques-qui-te",
    "tequeteque": "te-que-te-que",
    "tequiar": "te-quiar",
    "tequichazo": "te-qui-cha-zo",
    "tequiche": "te-qui-che",
    "tequila": "te-qui-la",
    "tequilazo": "te-qui-la-zo",
    "tequilear": "te-qui-le-ar",
    "tequilería": "te-qui-le-rí-a",
    "tequilero": "te-qui-le-ro",
    "tequio": "te-quio",
    "tequioso": "te-quio-so",
    "teragramo": "te-ra-gra-mo",
    "terapeada": "te-ra-pe-a-da",
    "terapear": "te-ra-pe-ar",
    "terapeuta": "te-ra-peu-ta",
    "terapéutica": "te-ra-péu-ti-ca",
    "terapéuticamente": "te-ra-péu-ti-ca-men-te",
    "terapéutico": "te-ra-péu-ti-co",
    "terapia": "te-ra-pia",
    "terapiar": "te-ra-piar",
    "teratogénico": "te-ra-to-gé-ni-co",
    "teratógeno": "te-ra-tó-ge-no",
    "teratología": "te-ra-to-lo-gí-a",
    "teratológica": "te-ra-to-ló-gi-ca",
    "teratológico": "te-ra-to-ló-gi-co",
    "teratoma": "te-ra-to-ma",
    "terbio": "ter-bio",
    "terca": "ter-ca",
    "tercamente": "ter-ca-men-te",
    "tercelete": "ter-ce-le-te",
    "tercena": "ter-ce-na",
    "tercenca": "ter-cen-ca",
    "tercenco": "ter-cen-co",
    "tercenista": "ter-ce-nis-ta",
    "tercer": "ter-cer",
    "tercera": "ter-ce-ra",
    "terceramente": "ter-ce-ra-men-te",
    "tercerear": "ter-ce-re-ar",
    "tercería": "ter-ce-rí-a",
    "tercerilla": "ter-ce-ri-lla",
    "tercerista": "ter-ce-ris-ta",
    "tercermundismo": "ter-cer-mun-dis-mo",
    "tercermundista": "ter-cer-mun-dis-ta",
    "tercero": "ter-ce-ro",
    "tercerol": "ter-ce-rol",
    "tercerola": "ter-ce-ro-la",
    "terceto": "ter-ce-to",
    "tercia": "ter-cia",
    "terciada": "ter-cia-da",
    "terciado": "ter-cia-do",
    "terciador": "ter-cia-dor",
    "terciadora": "ter-cia-do-ra",
    "terciana": "ter-cia-na",
    "tercianaria": "ter-cia-na-ria",
    "tercianario": "ter-cia-na-rio",
    "tercianela": "ter-cia-ne-la",
    "terciar": "ter-ciar",
    "terciaria": "ter-cia-ria",
    "terciario": "ter-cia-rio",
    "terciaza": "ter-cia-za",
    "terciazo": "ter-cia-zo",
    "terciazón": "ter-cia-zón",
    "tercio": "ter-cio",
    "terciodécupla": "ter-cio-dé-cu-pla",
    "terciodécuplo": "ter-cio-dé-cu-plo",
    "terciopelada": "ter-cio-pe-la-da",
    "terciopelado": "ter-cio-pe-la-do",
    "terciopelera": "ter-cio-pe-le-ra",
    "terciopelero": "ter-cio-pe-le-ro",
    "terciopelo": "ter-cio-pe-lo",
    "terco": "ter-co",
    "terebeca": "te-re-be-ca",
    "terebeco": "te-re-be-co",
    "terebequear": "te-re-be-que-ar",
    "terebintácea": "te-re-bin-tá-ce-a",
    "terebintáceo": "te-re-bin-tá-ce-o",
    "terebintina": "te-re-bin-ti-na",
    "terebinto": "te-re-bin-to",
    "terebrante": "te-re-bran-te",
    "terebrátula": "te-re-brá-tu-la",
    "terédine": "te-ré-di-ne",
    "teredo": "te-re-do",
    "teredón": "te-re-dón",
    "terenciana": "te-ren-cia-na",
    "terenciano": "te-ren-cia-no",
    "terenco": "te-ren-co",
    "terengo": "te-ren-go",
    "tereniabín": "te-re-nia-bín",
    "tereque": "te-re-que",
    "tereré": "te-re-ré",
    "teresa": "te-re-sa",
    "teresiana": "te-re-sia-na",
    "teresiano": "te-re-sia-no",
    "terete": "te-re-te",
    "tergal": "ter-gal",
    "tergiversable": "ter-gi-ver-sa-ble",
    "tergiversación": "ter-gi-ver-sa-ción",
    "tergiversador": "ter-gi-ver-sa-dor",
    "tergiversadora": "ter-gi-ver-sa-do-ra",
    "tergiversar": "ter-gi-ver-sar",
    "teriaca": "te-ria-ca",
    "teriacal": "te-ria-cal",
    "teridofita": "te-ri-do-fi-ta",
    "teridofitas": "te-ri-do-fi-tas",
    "teridofito": "te-ri-do-fi-to",
    "terigüela": "te-ri-güe-la",
    "teristro": "te-ris-tro",
    "terliz": "ter-liz",
    "terma": "ter-ma",
    "termal": "ter-mal",
    "termalismo": "ter-ma-lis-mo",
    "termas": "ter-mas",
    "termes": "ter-mes",
    "termia": "ter-mia",
    "térmica": "tér-mi-ca",
    "térmico": "tér-mi-co",
    "termidor": "ter-mi-dor",
    "terminable": "ter-mi-na-ble",
    "terminacho": "ter-mi-na-cho",
    "terminación": "ter-mi-na-ción",
    "terminador": "ter-mi-na-dor",
    "terminadora": "ter-mi-na-do-ra",
    "terminajo": "ter-mi-na-jo",
    "terminal": "ter-mi-nal",
    "terminante": "ter-mi-nan-te",
    "terminantemente": "ter-mi-nan-te-men-te",
    "terminar": "ter-mi-nar",
    "terminativa": "ter-mi-na-ti-va",
    "terminativo": "ter-mi-na-ti-vo",
    "terminista": "ter-mi-nis-ta",
    "término": "tér-mi-no",
    "terminóloga": "ter-mi-nó-lo-ga",
    "terminología": "ter-mi-no-lo-gí-a",
    "terminológico": "ter-mi-no-ló-gi-co",
    "terminólogo": "ter-mi-nó-lo-go",
    "terminote": "ter-mi-no-te",
    "termiónico": "ter-mió-ni-co",
    "termita": "ter-mi-ta",
    "térmite": "tér-mi-te",
    "termitera": "ter-mi-te-ra",
    "termitero": "ter-mi-te-ro",
    "termo": "ter-mo",
    "termocauterio": "ter-mo-cau-te-rio",
    "termocéfalo": "ter-mo-cé-fa-lo",
    "termoclina": "ter-mo-cli-na",
    "termodinámica": "ter-mo-di-ná-mi-ca",
    "termodinámico": "ter-mo-di-ná-mi-co",
    "termoeléctrica": "ter-mo-e-léc-tri-ca",
    "termoelectricidad": "ter-mo-e-lec-tri-ci-dad",
    "termoeléctrico": "ter-mo-e-léc-tri-co",
    "termoestable": "ter-mo-es-ta-ble",
    "termófilo": "ter-mó-fi-lo",
    "termofón": "ter-mo-fón",
    "termografía": "ter-mo-gra-fí-a",
    "termógrafo": "ter-mó-gra-fo",
    "termograma": "ter-mo-gra-ma",
    "termogravimetría": "ter-mo-gra-vi-me-trí-a",
    "termoiónico": "ter-moió-ni-co",
    "termolábil": "ter-mo-lá-bil",
    "termología": "ter-mo-lo-gí-a",
    "termometría": "ter-mo-me-trí-a",
    "termométrica": "ter-mo-mé-tri-ca",
    "termométrico": "ter-mo-mé-tri-co",
    "termómetro": "ter-mó-me-tro",
    "termonuclear": "ter-mo-nu-cle-ar",
    "termopar": "ter-mo-par",
    "termopausa": "ter-mo-pau-sa",
    "termopila": "ter-mo-pi-la",
    "termoplástico": "ter-mo-plás-ti-co",
    "termoquímica": "ter-mo-quí-mi-ca",
    "termoquímico": "ter-mo-quí-mi-co",
    "termorregulación": "ter-mo-rre-gu-la-ción",
    "termorregulador": "ter-mo-rre-gu-la-dor",
    "termorresistente": "ter-mo-rre-sis-ten-te",
    "termoscopio": "ter-mos-co-pio",
    "termosfera": "ter-mos-fe-ra",
    "termósfera": "ter-mós-fe-ra",
    "termosifón": "ter-mo-si-fón",
    "termostato": "ter-mos-ta-to",
    "termotaxia": "ter-mo-ta-xia",
    "termotecnia": "ter-mo-tec-nia",
    "termoterapia": "ter-mo-te-ra-pia",
    "termovisión": "ter-mo-vi-sión",
    "terna": "ter-na",
    "ternada": "ter-na-da",
    "ternaria": "ter-na-ria",
    "ternario": "ter-na-rio",
    "ternasco": "ter-nas-co",
    "terne": "ter-ne",
    "ternejal": "ter-ne-jal",
    "ternejo": "ter-ne-jo",
    "ternejón": "ter-ne-jón",
    "ternejona": "ter-ne-jo-na",
    "ternera": "ter-ne-ra",
    "ternero": "ter-ne-ro",
    "ternerón": "ter-ne-rón",
    "ternerona": "ter-ne-ro-na",
    "ternez": "ter-nez",
    "terneza": "ter-ne-za",
    "ternilla": "ter-ni-lla",
    "ternillosa": "ter-ni-llo-sa",
    "ternilloso": "ter-ni-llo-so",
    "terno": "ter-no",
    "ternura": "ter-nu-ra",
    "tero": "te-ro",
    "terpeno": "ter-pe-no",
    "terpina": "ter-pi-na",
    "terpinol": "ter-pi-nol",
    "terquear": "ter-que-ar",
    "terquedad": "ter-que-dad",
    "terquería": "ter-que-rí-a",
    "terqueza": "ter-que-za",
    "térraba": "té-rra-ba",
    "terracear": "te-rra-ce-ar",
    "terracería": "te-rra-ce-rí-a",
    "terracota": "te-rra-co-ta",
    "terrada": "te-rra-da",
    "terrado": "te-rra-do",
    "terraguero": "te-rra-gue-ro",
    "terraja": "te-rra-ja",
    "terraje": "te-rra-je",
    "terrajero": "te-rra-je-ro",
    "terral": "te-rral",
    "terramicina": "te-rra-mi-ci-na",
    "terranova": "te-rra-no-va",
    "terraplén": "te-rra-plén",
    "terraplenar": "te-rra-ple-nar",
    "terrapleno": "te-rra-ple-no",
    "terráquea": "te-rrá-que-a",
    "terráqueo": "te-rrá-que-o",
    "terrario": "te-rra-rio",
    "terrateniente": "te-rra-te-nien-te",
    "terraza": "te-rra-za",
    "terrazgo": "te-rraz-go",
    "terrazguero": "te-rraz-gue-ro",
    "terrazo": "te-rra-zo",
    "térrea": "té-rre-a",
    "terrear": "te-rre-ar",
    "terrecer": "te-rre-cer",
    "terregal": "te-rre-gal",
    "terregosa": "te-rre-go-sa",
    "terregoso": "te-rre-go-so",
    "terremotear": "te-rre-mo-te-ar",
    "terremoto": "te-rre-mo-to",
    "terreña": "te-rre-ña",
    "terrenal": "te-rre-nal",
    "terrenidad": "te-rre-ni-dad",
    "terreno": "te-rre-no",
    "terreño": "te-rre-ño",
    "térreo": "té-rre-o",
    "terrera": "te-rre-ra",
    "terrería": "te-rre-rí-a",
    "terrero": "te-rre-ro",
    "terrestre": "te-rres-tre",
    "terrezuela": "te-rre-zue-la",
    "terribilidad": "te-rri-bi-li-dad",
    "terrible": "te-rri-ble",
    "terriblemente": "te-rri-ble-men-te",
    "terriblez": "te-rri-blez",
    "terribleza": "te-rri-ble-za",
    "terrícola": "te-rrí-co-la",
    "terrier": "te-rrier",
    "terrífica": "te-rrí-fi-ca",
    "terrífico": "te-rrí-fi-co",
    "terrígena": "te-rrí-ge-na",
    "terrígeno": "te-rrí-ge-no",
    "terrina": "te-rri-na",
    "terrino": "te-rri-no",
    "territorial": "te-rri-to-rial",
    "territorialidad": "te-rri-to-ria-li-dad",
    "territorialismo": "te-rri-to-ria-lis-mo",
    "territorialización": "te-rri-to-ria-li-za-ción",
    "territorializar": "te-rri-to-ria-li-zar",
    "territorialmente": "te-rri-to-rial-men-te",
    "territorio": "te-rri-to-rio",
    "terriza": "te-rri-za",
    "terrizo": "te-rri-zo",
    "terrollo": "te-rro-llo",
    "terromontero": "te-rro-mon-te-ro",
    "terrón": "te-rrón",
    "terronazo": "te-rro-na-zo",
    "terronera": "te-rro-ne-ra",
    "terror": "te-rror",
    "terrorífica": "te-rro-rí-fi-ca",
    "terrorífico": "te-rro-rí-fi-co",
    "terrorismo": "te-rro-ris-mo",
    "terrorista": "te-rro-ris-ta",
    "terrosa": "te-rro-sa",
    "terrosidad": "te-rro-si-dad",
    "terroso": "te-rro-so",
    "terruñero": "te-rru-ñe-ro",
    "terruño": "te-rru-ño",
    "tersa": "ter-sa",
    "tersar": "ter-sar",
    "tersidad": "ter-si-dad",
    "terso": "ter-so",
    "tersura": "ter-su-ra",
    "terteca": "ter-te-ca",
    "tertil": "ter-til",
    "tertulia": "ter-tu-lia",
    "tertuliana": "ter-tu-lia-na",
    "tertuliano": "ter-tu-lia-no",
    "tertuliante": "ter-tu-lian-te",
    "tertuliar": "ter-tu-liar",
    "tertulio": "ter-tu-lio",
    "teruncio": "te-run-cio",
    "teruteru": "te-ru-te-ru",
    "teruvela": "te-ru-ve-la",
    "terzón": "ter-zón",
    "terzona": "ter-zo-na",
    "terzuela": "ter-zue-la",
    "terzuelo": "ter-zue-lo",
    "tesa": "te-sa",
    "tésala": "té-sa-la",
    "tesalia": "te-sa-lia",
    "tesaliana": "te-sa-lia-na",
    "tesaliano": "te-sa-lia-no",
    "tesálica": "te-sá-li-ca",
    "tesálico": "te-sá-li-co",
    "tesaliense": "te-sa-lien-se",
    "tesalio": "te-sa-lio",
    "tésalo": "té-sa-lo",
    "tesalónica": "te-sa-ló-ni-ca",
    "tesalonicense": "te-sa-lo-ni-cen-se",
    "tesalónico": "te-sa-ló-ni-co",
    "tesar": "te-sar",
    "tesaurizar": "te-sau-ri-zar",
    "tesauro": "te-sau-ro",
    "tesbita": "tes-bi-ta",
    "tescal": "tes-cal",
    "tescalamate": "tes-ca-la-ma-te",
    "tesela": "te-se-la",
    "teselada": "te-se-la-da",
    "teselado": "te-se-la-do",
    "tésera": "té-se-ra",
    "tesgüino": "tes-güi-no",
    "tesina": "te-si-na",
    "tesis": "te-sis",
    "tesitura": "te-si-tu-ra",
    "tesla": "tes-la",
    "teso": "te-so",
    "tesón": "te-són",
    "tesonera": "te-so-ne-ra",
    "tesonería": "te-so-ne-rí-a",
    "tesonero": "te-so-ne-ro",
    "tesonía": "te-so-ní-a",
    "tesoquite": "te-so-qui-te",
    "tesorera": "te-so-re-ra",
    "tesorería": "te-so-re-rí-a",
    "tesorero": "te-so-re-ro",
    "tesorizar": "te-so-ri-zar",
    "tesoro": "te-so-ro",
    "tespíades": "tes-pí-a-des",
    "testa": "tes-ta",
    "testácea": "tes-tá-ce-a",
    "testáceo": "tes-tá-ce-o",
    "testación": "tes-ta-ción",
    "testada": "tes-ta-da",
    "testado": "tes-ta-do",
    "testador": "tes-ta-dor",
    "testadora": "tes-ta-do-ra",
    "testadura": "tes-ta-du-ra",
    "testaférrea": "tes-ta-fé-rre-a",
    "testaferro": "tes-ta-fe-rro",
    "testamentaría": "tes-ta-men-ta-rí-a",
    "testamentaria": "tes-ta-men-ta-ria",
    "testamentario": "tes-ta-men-ta-rio",
    "testamentifacción": "tes-ta-men-ti-fac-ción",
    "testamento": "tes-ta-men-to",
    "testar": "tes-tar",
    "testarada": "tes-ta-ra-da",
    "testarazo": "tes-ta-ra-zo",
    "testarrón": "tes-ta-rrón",
    "testarrona": "tes-ta-rro-na",
    "testarronería": "tes-ta-rro-ne-rí-a",
    "testarruco": "tes-ta-rru-co",
    "testaruda": "tes-ta-ru-da",
    "testarudez": "tes-ta-ru-dez",
    "testarudo": "tes-ta-ru-do",
    "teste": "tes-te",
    "testear": "tes-te-ar",
    "testera": "tes-te-ra",
    "testerada": "tes-te-ra-da",
    "testerazo": "tes-te-ra-zo",
    "testerilla": "tes-te-ri-lla",
    "testerillo": "tes-te-ri-llo",
    "testero": "tes-te-ro",
    "testicular": "tes-ti-cu-lar",
    "testículo": "tes-tí-cu-lo",
    "testificación": "tes-ti-fi-ca-ción",
    "testifical": "tes-ti-fi-cal",
    "testificar": "tes-ti-fi-car",
    "testificativa": "tes-ti-fi-ca-ti-va",
    "testificativo": "tes-ti-fi-ca-ti-vo",
    "testigo": "tes-ti-go",
    "testiguar": "tes-ti-guar",
    "testimoñera": "tes-ti-mo-ñe-ra",
    "testimoñero": "tes-ti-mo-ñe-ro",
    "testimonial": "tes-ti-mo-nial",
    "testimoniar": "tes-ti-mo-niar",
    "testimoniera": "tes-ti-mo-nie-ra",
    "testimoniero": "tes-ti-mo-nie-ro",
    "testimonio": "tes-ti-mo-nio",
    "testón": "tes-tón",
    "testosterona": "tes-tos-te-ro-na",
    "testudínea": "tes-tu-dí-ne-a",
    "testudíneo": "tes-tu-dí-ne-o",
    "testudo": "tes-tu-do",
    "testuz": "tes-tuz",
    "testuzo": "tes-tu-zo",
    "tesura": "te-su-ra",
    "teta": "te-ta",
    "tetada": "te-ta-da",
    "tetamen": "te-ta-men",
    "tetania": "te-ta-nia",
    "tetánica": "te-tá-ni-ca",
    "tetánico": "te-tá-ni-co",
    "tétano": "té-ta-no",
    "tétanos": "té-ta-nos",
    "tetar": "te-tar",
    "tete": "te-te",
    "tetelque": "te-tel-que",
    "tetera": "te-te-ra",
    "tetero": "te-te-ro",
    "teticiega": "te-ti-cie-ga",
    "teticoja": "te-ti-co-ja",
    "tetilla": "te-ti-lla",
    "tetina": "te-ti-na",
    "tetón": "te-tón",
    "tetona": "te-to-na",
    "tetra": "te-tra",
    "tetrabranquial": "te-tra-bran-quial",
    "tetrabrik": "te-tra-brik",
    "tetracampeón": "te-tra-cam-pe-ón",
    "tetraciclina": "te-tra-ci-cli-na",
    "tetracordio": "te-tra-cor-dio",
    "tetracordo": "te-tra-cor-do",
    "tétrada": "té-tra-da",
    "tetradracma": "te-tra-drac-ma",
    "tetraédrico": "te-tra-é-dri-co",
    "tetraedro": "te-tra-e-dro",
    "tetragésimo": "te-tra-gé-si-mo",
    "tetragonal": "te-tra-go-nal",
    "tetrágono": "te-trá-go-no",
    "tetragrama": "te-tra-gra-ma",
    "tetragrámaton": "te-tra-grá-ma-ton",
    "tetralogía": "te-tra-lo-gí-a",
    "tetrámera": "te-trá-me-ra",
    "tetrámero": "te-trá-me-ro",
    "tetramorfos": "te-tra-mor-fos",
    "tetramotor": "te-tra-mo-tor",
    "tetraplejía": "te-tra-ple-jí-a",
    "tetraplejia": "te-tra-ple-jia",
    "tetrapléjica": "te-tra-plé-ji-ca",
    "tetrapléjico": "te-tra-plé-ji-co",
    "tetrápodo": "te-trá-po-do",
    "tetrarca": "te-trar-ca",
    "tetrarquía": "te-trar-quí-a",
    "tetrasílaba": "te-tra-sí-la-ba",
    "tetrasílabo": "te-tra-sí-la-bo",
    "tetrástica": "te-trás-ti-ca",
    "tetrástico": "te-trás-ti-co",
    "tetrástilo": "te-trás-ti-lo",
    "tetrástrofa": "te-trás-tro-fa",
    "tetrástrofo": "te-trás-tro-fo",
    "tetravalente": "te-tra-va-len-te",
    "tétrica": "té-tri-ca",
    "tétrico": "té-tri-co",
    "tetro": "te-tro",
    "tetuán": "te-tuán",
    "tetuaní": "te-tua-ní",
    "tetuda": "te-tu-da",
    "tetudo": "te-tu-do",
    "tetunta": "te-tun-ta",
    "tetuntazo": "te-tun-ta-zo",
    "tetunte": "te-tun-te",
    "teucali": "teu-ca-li",
    "teucra": "teu-cra",
    "teucrio": "teu-crio",
    "teucro": "teu-cro",
    "teúrgia": "te-úr-gia",
    "teúrgica": "te-úr-gi-ca",
    "teúrgico": "te-úr-gi-co",
    "teúrgo": "te-úr-go",
    "teutón": "teu-tón",
    "teutona": "teu-to-na",
    "teutónica": "teu-tó-ni-ca",
    "teutónico": "teu-tó-ni-co",
    "texana": "te-xa-na",
    "texano": "te-xa-no",
    "texcocana": "tex-co-ca-na",
    "texcocano": "tex-co-ca-no",
    "textal": "tex-tal",
    "textil": "tex-til",
    "texto": "tex-to",
    "textoria": "tex-to-ria",
    "textorio": "tex-to-rio",
    "textual": "tex-tual",
    "textualidad": "tex-tua-li-dad",
    "textualista": "tex-tua-lis-ta",
    "textura": "tex-tu-ra",
    "texturizar": "tex-tu-ri-zar",
    "teya": "te-ya",
    "teyo": "te-yo",
    "teyolote": "te-yo-lo-te",
    "teyú": "te-yú",
    "tezada": "te-za-da",
    "tezado": "te-za-do",
    "tezcucana": "tez-cu-ca-na",
    "tezcucano": "tez-cu-ca-no",
    "tezontle": "te-zon-tle",
    "theta": "the-ta",
    "tía": "tí-a",
    "tiaca": "tia-ca",
    "tiahuanacota": "tia-hua-na-co-ta",
    "tialina": "tia-li-na",
    "tialismo": "tia-lis-mo",
    "tiamina": "tia-mi-na",
    "tiangue": "tian-gue",
    "tianguera": "tian-gue-ra",
    "tianguero": "tian-gue-ro",
    "tianguis": "tian-guis",
    "tiara": "tia-ra",
    "tiarrón": "tia-rrón",
    "tiarrona": "tia-rro-na",
    "tíbar": "tí-bar",
    "tibe": "ti-be",
    "tiberina": "ti-be-ri-na",
    "tiberino": "ti-be-ri-no",
    "tiberio": "ti-be-rio",
    "tibetana": "ti-be-ta-na",
    "tibetano": "ti-be-ta-no",
    "tibetobirmano": "ti-be-to-bir-ma-no",
    "tibia": "ti-bia",
    "tibial": "ti-bial",
    "tibiamente": "ti-bia-men-te",
    "tibiar": "ti-biar",
    "tibieza": "ti-bie-za",
    "tibio": "ti-bio",
    "tibisí": "ti-bi-sí",
    "tibombo": "ti-bom-bo",
    "tibor": "ti-bor",
    "tiburón": "ti-bu-rón",
    "tiburoneo": "ti-bu-ro-ne-o",
    "tiburtina": "ti-bur-ti-na",
    "tiburtino": "ti-bur-ti-no",
    "ticera": "ti-ce-ra",
    "ticero": "ti-ce-ro",
    "ticholo": "ti-cho-lo",
    "ticinense": "ti-ci-nen-se",
    "ticket": "tic-ket",
    "tico": "ti-co",
    "ticónica": "ti-có-ni-ca",
    "ticónico": "ti-có-ni-co",
    "tictac": "tic-tac",
    "ticuco": "ti-cu-co",
    "ticuriche": "ti-cu-ri-che",
    "tiemblo": "tiem-blo",
    "tiempal": "tiem-pal",
    "tiempo": "tiem-po",
    "tienda": "tien-da",
    "tiendera": "tien-de-ra",
    "tiendero": "tien-de-ro",
    "tienta": "tien-ta",
    "tientaguja": "tien-ta-gu-ja",
    "tientaparedes": "tien-ta-pa-re-des",
    "tiento": "tien-to",
    "tierna": "tier-na",
    "tierno": "tier-no",
    "tierra": "tie-rra",
    "tierracalentana": "tie-rra-ca-len-ta-na",
    "tierracalentano": "tie-rra-ca-len-ta-no",
    "tierracalenteño": "tie-rra-ca-len-te-ño",
    "tierral": "tie-rral",
    "tierrero": "tie-rre-ro",
    "tierroso": "tie-rro-so",
    "tierrudo": "tie-rru-do",
    "tiesa": "tie-sa",
    "tieso": "tie-so",
    "tiesta": "ties-ta",
    "tiesto": "ties-to",
    "tiesura": "tie-su-ra",
    "tifa": "ti-fa",
    "tifácea": "ti-fá-ce-a",
    "tifáceas": "ti-fá-ce-as",
    "tifáceo": "ti-fá-ce-o",
    "tífica": "tí-fi-ca",
    "tífico": "tí-fi-co",
    "tiflóloga": "ti-fló-lo-ga",
    "tiflología": "ti-flo-lo-gí-a",
    "tiflológico": "ti-flo-ló-gi-co",
    "tiflólogo": "ti-fló-lo-go",
    "tiflotécnica": "ti-flo-téc-ni-ca",
    "tiflotécnico": "ti-flo-téc-ni-co",
    "tiflotecnología": "ti-flo-tec-no-lo-gí-a",
    "tifo": "ti-fo",
    "tifoidea": "ti-foi-de-a",
    "tifoideo": "ti-foi-de-o",
    "tifón": "ti-fón",
    "tifosi": "ti-fo-si",
    "tifus": "ti-fus",
    "tigana": "ti-ga-na",
    "tigmotropismo": "tig-mo-tro-pis-mo",
    "tigra": "ti-gra",
    "tigre": "ti-gre",
    "tigresa": "ti-gre-sa",
    "tigrillo": "ti-gri-llo",
    "tigrito": "ti-gri-to",
    "tigüe": "ti-güe",
    "tigüilote": "ti-güi-lo-te",
    "tija": "ti-ja",
    "tijera": "ti-je-ra",
    "tijerada": "ti-je-ra-da",
    "tijeral": "ti-je-ral",
    "tijerazo": "ti-je-ra-zo",
    "tijerear": "ti-je-re-ar",
    "tijereta": "ti-je-re-ta",
    "tijeretada": "ti-je-re-ta-da",
    "tijeretazo": "ti-je-re-ta-zo",
    "tijeretear": "ti-je-re-te-ar",
    "tijereteo": "ti-je-re-te-o",
    "tijerilla": "ti-je-ri-lla",
    "tijeruela": "ti-je-rue-la",
    "tijo": "ti-jo",
    "tijuil": "ti-juil",
    "tijul": "ti-jul",
    "tila": "ti-la",
    "tilapia": "ti-la-pia",
    "tílburi": "tíl-bu-ri",
    "tilcoate": "til-co-a-te",
    "tilcuate": "til-cua-te",
    "tildar": "til-dar",
    "tilde": "til-de",
    "tildón": "til-dón",
    "tile": "ti-le",
    "tilia": "ti-lia",
    "tiliácea": "ti-liá-ce-a",
    "tiliáceo": "ti-liá-ce-o",
    "tilica": "ti-li-ca",
    "tiliche": "ti-li-che",
    "tilichento": "ti-li-chen-to",
    "tilichera": "ti-li-che-ra",
    "tilichero": "ti-li-che-ro",
    "tilico": "ti-li-co",
    "tilila": "ti-li-la",
    "tilín": "ti-lín",
    "tilinga": "ti-lin-ga",
    "tilingo": "ti-lin-go",
    "tilinte": "ti-lin-te",
    "tilintear": "ti-lin-te-ar",
    "tilla": "ti-lla",
    "tillado": "ti-lla-do",
    "tillar": "ti-llar",
    "tillo": "ti-llo",
    "tilma": "til-ma",
    "tilo": "ti-lo",
    "tiloso": "ti-lo-so",
    "timador": "ti-ma-dor",
    "timadora": "ti-ma-do-ra",
    "tímalo": "tí-ma-lo",
    "timar": "ti-mar",
    "timba": "tim-ba",
    "timbal": "tim-bal",
    "timbalera": "tim-ba-le-ra",
    "timbalero": "tim-ba-le-ro",
    "timbear": "tim-be-ar",
    "timbiriche": "tim-bi-ri-che",
    "timbirimba": "tim-bi-rim-ba",
    "timbo": "tim-bo",
    "timbó": "tim-bó",
    "timbón": "tim-bón",
    "timbona": "tim-bo-na",
    "timboy": "tim-boy",
    "timbrado": "tim-bra-do",
    "timbrador": "tim-bra-dor",
    "timbradora": "tim-bra-do-ra",
    "timbrar": "tim-brar",
    "timbrazo": "tim-bra-zo",
    "timbre": "tim-bre",
    "timbrea": "tim-bre-a",
    "timbreo": "tim-bre-o",
    "tímbrico": "tím-bri-co",
    "timbrófila": "tim-bró-fi-la",
    "timbrofilia": "tim-bro-fi-lia",
    "timbrófilo": "tim-bró-fi-lo",
    "timbróloga": "tim-bró-lo-ga",
    "timbrología": "tim-bro-lo-gí-a",
    "timbrólogo": "tim-bró-lo-go",
    "timeleácea": "ti-me-le-á-ce-a",
    "timeleáceo": "ti-me-le-á-ce-o",
    "timiama": "ti-mia-ma",
    "tímida": "tí-mi-da",
    "tímidamente": "tí-mi-da-men-te",
    "timidez": "ti-mi-dez",
    "tímido": "tí-mi-do",
    "timina": "ti-mi-na",
    "timo": "ti-mo",
    "timocracia": "ti-mo-cra-cia",
    "timócrata": "ti-mó-cra-ta",
    "timocrática": "ti-mo-crá-ti-ca",
    "timocrático": "ti-mo-crá-ti-co",
    "timol": "ti-mol",
    "timón": "ti-món",
    "timonear": "ti-mo-ne-ar",
    "timonel": "ti-mo-nel",
    "timonera": "ti-mo-ne-ra",
    "timonero": "ti-mo-ne-ro",
    "timorata": "ti-mo-ra-ta",
    "timorato": "ti-mo-ra-to",
    "timorés": "ti-mo-rés",
    "timoresa": "ti-mo-re-sa",
    "timote": "ti-mo-te",
    "timpa": "tim-pa",
    "timpánica": "tim-pá-ni-ca",
    "timpánico": "tim-pá-ni-co",
    "timpanillo": "tim-pa-ni-llo",
    "timpanítica": "tim-pa-ní-ti-ca",
    "timpanítico": "tim-pa-ní-ti-co",
    "timpanitis": "tim-pa-ni-tis",
    "timpanización": "tim-pa-ni-za-ción",
    "timpanizar": "tim-pa-ni-zar",
    "timpanizarse": "tim-pa-ni-zar-se",
    "tímpano": "tím-pa-no",
    "timpiriche": "tim-pi-ri-che",
    "timple": "tim-ple",
    "tina": "ti-na",
    "tiña": "ti-ña",
    "tinaco": "ti-na-co",
    "tinada": "ti-na-da",
    "tinado": "ti-na-do",
    "tinador": "ti-na-dor",
    "tinaja": "ti-na-ja",
    "tinajera": "ti-na-je-ra",
    "tinajería": "ti-na-je-rí-a",
    "tinajero": "ti-na-je-ro",
    "tinajón": "ti-na-jón",
    "tinamaste": "ti-na-mas-te",
    "tinapá": "ti-na-pá",
    "tinca": "tin-ca",
    "tincada": "tin-ca-da",
    "tincanque": "tin-can-que",
    "tincar": "tin-car",
    "tincazo": "tin-ca-zo",
    "tinción": "tin-ción",
    "tincudo": "tin-cu-do",
    "tincunaco": "tin-cu-na-co",
    "tindalización": "tin-da-li-za-ción",
    "tindalizar": "tin-da-li-zar",
    "tíndalo": "tín-da-lo",
    "tindío": "tin-dí-o",
    "tínea": "tí-ne-a",
    "tinelar": "ti-ne-lar",
    "tinelera": "ti-ne-le-ra",
    "tinelero": "ti-ne-le-ro",
    "tinelo": "ti-ne-lo",
    "tineo": "ti-ne-o",
    "tinerfeña": "ti-ner-fe-ña",
    "tinerfeño": "ti-ner-fe-ño",
    "tiñería": "ti-ñe-rí-a",
    "tinga": "tin-ga",
    "tinge": "tin-ge",
    "tingible": "tin-gi-ble",
    "tingitana": "tin-gi-ta-na",
    "tingitano": "tin-gi-ta-no",
    "tingladillo": "tin-gla-di-llo",
    "tinglado": "tin-gla-do",
    "tingle": "tin-gle",
    "tinguro": "tin-gu-ro",
    "tinicla": "ti-ni-cla",
    "tiniebla": "ti-nie-bla",
    "tinillo": "ti-ni-llo",
    "tino": "ti-no",
    "tinola": "ti-no-la",
    "tiñosa": "ti-ño-sa",
    "tiñoso": "ti-ño-so",
    "tinta": "tin-ta",
    "tintar": "tin-tar",
    "tinte": "tin-te",
    "tinterazo": "tin-te-ra-zo",
    "tinterillada": "tin-te-ri-lla-da",
    "tinterillo": "tin-te-ri-llo",
    "tintero": "tin-te-ro",
    "tintilla": "tin-ti-lla",
    "tintillo": "tin-ti-llo",
    "tintín": "tin-tín",
    "tintinar": "tin-ti-nar",
    "tintineante": "tin-ti-ne-an-te",
    "tintinear": "tin-ti-ne-ar",
    "tintineo": "tin-ti-ne-o",
    "tintirintín": "tin-ti-rin-tín",
    "tinto": "tin-to",
    "tintoco": "tin-to-co",
    "tintolio": "tin-to-lio",
    "tintor": "tin-tor",
    "tintórea": "tin-tó-re-a",
    "tintorear": "tin-to-re-ar",
    "tintóreo": "tin-tó-re-o",
    "tintorera": "tin-to-re-ra",
    "tintorería": "tin-to-re-rí-a",
    "tintorero": "tin-to-re-ro",
    "tintorro": "tin-to-rro",
    "tintura": "tin-tu-ra",
    "tinturar": "tin-tu-rar",
    "tiñuela": "ti-ñue-la",
    "tío": "tí-o",
    "tioneo": "tio-ne-o",
    "tiorba": "tior-ba",
    "tiovivo": "tio-vi-vo",
    "tipa": "ti-pa",
    "tipache": "ti-pa-che",
    "tiparraca": "ti-pa-rra-ca",
    "tiparraco": "ti-pa-rra-co",
    "tipazo": "ti-pa-zo",
    "tipear": "ti-pe-ar",
    "tipeja": "ti-pe-ja",
    "tipejo": "ti-pe-jo",
    "tipería": "ti-pe-rí-a",
    "tipi": "ti-pi",
    "tipiadora": "ti-pia-do-ra",
    "típica": "tí-pi-ca",
    "típicamente": "tí-pi-ca-men-te",
    "tipicidad": "ti-pi-ci-dad",
    "tipicismo": "ti-pi-cis-mo",
    "típico": "tí-pi-co",
    "tipificable": "ti-pi-fi-ca-ble",
    "tipificación": "ti-pi-fi-ca-ción",
    "tipificar": "ti-pi-fi-car",
    "tipiquil": "ti-pi-quil",
    "tipismo": "ti-pis-mo",
    "tiple": "ti-ple",
    "tiplisonante": "ti-pli-so-nan-te",
    "tipo": "ti-po",
    "tipógrafa": "ti-pó-gra-fa",
    "tipografía": "ti-po-gra-fí-a",
    "tipográfica": "ti-po-grá-fi-ca",
    "tipográfico": "ti-po-grá-fi-co",
    "tipógrafo": "ti-pó-gra-fo",
    "tipoi": "ti-poi",
    "tipología": "ti-po-lo-gí-a",
    "tipológico": "ti-po-ló-gi-co",
    "tipometría": "ti-po-me-trí-a",
    "tipómetro": "ti-pó-me-tro",
    "tipoy": "ti-poy",
    "tipuaneña": "ti-pua-ne-ña",
    "tipuaneño": "ti-pua-ne-ño",
    "típula": "tí-pu-la",
    "tipúlido": "ti-pú-li-do",
    "tipunte": "ti-pun-te",
    "tique": "ti-que",
    "tiquear": "ti-que-ar",
    "tíquet": "tí-quet",
    "tiquete": "ti-que-te",
    "tiquí": "ti-quí",
    "tiquis": "ti-quis",
    "tiquismiquis": "ti-quis-mi-quis",
    "tiquizque": "ti-quiz-que",
    "tira": "ti-ra",
    "tirabala": "ti-ra-ba-la",
    "tirabeque": "ti-ra-be-que",
    "tirabotas": "ti-ra-bo-tas",
    "tirabraguero": "ti-ra-bra-gue-ro",
    "tirabrasas": "ti-ra-bra-sas",
    "tirabuzón": "ti-ra-bu-zón",
    "tiracantos": "ti-ra-can-tos",
    "tirachinas": "ti-ra-chi-nas",
    "tirachinos": "ti-ra-chi-nos",
    "tiracol": "ti-ra-col",
    "tiracuello": "ti-ra-cue-llo",
    "tiracuero": "ti-ra-cue-ro",
    "tirada": "ti-ra-da",
    "tiradera": "ti-ra-de-ra",
    "tiradero": "ti-ra-de-ro",
    "tiradillas": "ti-ra-di-llas",
    "tirado": "ti-ra-do",
    "tirador": "ti-ra-dor",
    "tiradora": "ti-ra-do-ra",
    "tiraflechas": "ti-ra-fle-chas",
    "tirafondo": "ti-ra-fon-do",
    "tirafuera": "ti-ra-fue-ra",
    "tiragomas": "ti-ra-go-mas",
    "tiraje": "ti-ra-je",
    "tirajo": "ti-ra-jo",
    "tiraleche": "ti-ra-le-che",
    "tiralevitas": "ti-ra-le-vi-tas",
    "tiralíneas": "ti-ra-lí-ne-as",
    "tiramiento": "ti-ra-mien-to",
    "tiramillas": "ti-ra-mi-llas",
    "tiramira": "ti-ra-mi-ra",
    "tiramisú": "ti-ra-mi-sú",
    "tiramollar": "ti-ra-mo-llar",
    "tirana": "ti-ra-na",
    "tiranía": "ti-ra-ní-a",
    "tiránica": "ti-rá-ni-ca",
    "tiránicamente": "ti-rá-ni-ca-men-te",
    "tiranicida": "ti-ra-ni-ci-da",
    "tiranicidio": "ti-ra-ni-ci-dio",
    "tiránico": "ti-rá-ni-co",
    "tiranización": "ti-ra-ni-za-ción",
    "tiranizar": "ti-ra-ni-zar",
    "tirano": "ti-ra-no",
    "tiranosaurio": "ti-ra-no-sau-rio",
    "tiranta": "ti-ran-ta",
    "tirantas": "ti-ran-tas",
    "tirante": "ti-ran-te",
    "tirantear": "ti-ran-te-ar",
    "tirantez": "ti-ran-tez",
    "tirantillo": "ti-ran-ti-llo",
    "tirapié": "ti-ra-pié",
    "tirapiedras": "ti-ra-pie-dras",
    "tirar": "ti-rar",
    "tiratacos": "ti-ra-ta-cos",
    "tiratiros": "ti-ra-ti-ros",
    "tiratrillo": "ti-ra-tri-llo",
    "tirela": "ti-re-la",
    "tireta": "ti-re-ta",
    "tiria": "ti-ria",
    "tiricia": "ti-ri-cia",
    "tiriciento": "ti-ri-cien-to",
    "tirilla": "ti-ri-lla",
    "tirillas": "ti-ri-llas",
    "tirintia": "ti-rin-tia",
    "tirintio": "ti-rin-tio",
    "tirio": "ti-rio",
    "tirita": "ti-ri-ta",
    "tiritaña": "ti-ri-ta-ña",
    "tiritaño": "ti-ri-ta-ño",
    "tiritar": "ti-ri-tar",
    "tiritera": "ti-ri-te-ra",
    "tiritón": "ti-ri-tón",
    "tiritona": "ti-ri-to-na",
    "tiro": "ti-ro",
    "tirocinio": "ti-ro-ci-nio",
    "tiroidea": "ti-roi-de-a",
    "tiroideo": "ti-roi-de-o",
    "tiroides": "ti-roi-des",
    "tirol": "ti-rol",
    "tirolés": "ti-ro-lés",
    "tirolesa": "ti-ro-le-sa",
    "tirón": "ti-rón",
    "tirona": "ti-ro-na",
    "tironear": "ti-ro-ne-ar",
    "tironera": "ti-ro-ne-ra",
    "tironero": "ti-ro-ne-ro",
    "tironiano": "ti-ro-nia-no",
    "tiroriro": "ti-ro-ri-ro",
    "tirosina": "ti-ro-si-na",
    "tirotear": "ti-ro-te-ar",
    "tiroteo": "ti-ro-te-o",
    "tiroxina": "ti-ro-xi-na",
    "tirrena": "ti-rre-na",
    "tirreno": "ti-rre-no",
    "tirria": "ti-rria",
    "tirrioso": "ti-rrio-so",
    "tirro": "ti-rro",
    "tirso": "tir-so",
    "tirte": "tir-te",
    "tirulata": "ti-ru-la-ta",
    "tirulato": "ti-ru-la-to",
    "tirulo": "ti-ru-lo",
    "tisana": "ti-sa-na",
    "tisanuro": "ti-sa-nu-ro",
    "tisera": "ti-se-ra",
    "tísica": "tí-si-ca",
    "tísico": "tí-si-co",
    "tisióloga": "ti-sió-lo-ga",
    "tisiología": "ti-sio-lo-gí-a",
    "tisiológico": "ti-sio-ló-gi-co",
    "tisiólogo": "ti-sió-lo-go",
    "tisis": "ti-sis",
    "tiste": "tis-te",
    "tistear": "tis-te-ar",
    "tisú": "ti-sú",
    "tisular": "ti-su-lar",
    "tisuria": "ti-su-ria",
    "tita": "ti-ta",
    "titán": "ti-tán",
    "titánica": "ti-tá-ni-ca",
    "titánico": "ti-tá-ni-co",
    "titanio": "ti-ta-nio",
    "titar": "ti-tar",
    "titear": "ti-te-ar",
    "titeo": "ti-te-o",
    "títere": "tí-te-re",
    "titerera": "ti-te-re-ra",
    "titerero": "ti-te-re-ro",
    "titeretada": "ti-te-re-ta-da",
    "titerista": "ti-te-ris-ta",
    "titi": "ti-ti",
    "tití": "ti-tí",
    "titiaro": "ti-tia-ro",
    "titil": "ti-til",
    "titilación": "ti-ti-la-ción",
    "titilador": "ti-ti-la-dor",
    "titiladora": "ti-ti-la-do-ra",
    "titilar": "ti-ti-lar",
    "titileo": "ti-ti-le-o",
    "titímalo": "ti-tí-ma-lo",
    "titingó": "ti-tin-gó",
    "titipuchal": "ti-ti-pu-chal",
    "titirimundi": "ti-ti-ri-mun-di",
    "titiritaina": "ti-ti-ri-tai-na",
    "titiritar": "ti-ti-ri-tar",
    "titiritear": "ti-ti-ri-te-ar",
    "titiritera": "ti-ti-ri-te-ra",
    "titiritero": "ti-ti-ri-te-ro",
    "titís": "ti-tís",
    "tito": "ti-to",
    "titubar": "ti-tu-bar",
    "titubeante": "ti-tu-be-an-te",
    "titubear": "ti-tu-be-ar",
    "titubeo": "ti-tu-be-o",
    "titulación": "ti-tu-la-ción",
    "titulada": "ti-tu-la-da",
    "titulado": "ti-tu-la-do",
    "titular": "ti-tu-lar",
    "titularidad": "ti-tu-la-ri-dad",
    "titularización": "ti-tu-la-ri-za-ción",
    "titularizar": "ti-tu-la-ri-zar",
    "titulatura": "ti-tu-la-tu-ra",
    "titulillo": "ti-tu-li-llo",
    "titulitis": "ti-tu-li-tis",
    "titulización": "ti-tu-li-za-ción",
    "titulizar": "ti-tu-li-zar",
    "título": "tí-tu-lo",
    "tiufado": "tiu-fa-do",
    "tiuque": "tiu-que",
    "tiza": "ti-za",
    "tizana": "ti-za-na",
    "tizate": "ti-za-te",
    "tizna": "tiz-na",
    "tiznada": "tiz-na-da",
    "tiznado": "tiz-na-do",
    "tiznadura": "tiz-na-du-ra",
    "tiznajo": "tiz-na-jo",
    "tiznar": "tiz-nar",
    "tizne": "tiz-ne",
    "tiznera": "tiz-ne-ra",
    "tiznero": "tiz-ne-ro",
    "tiznón": "tiz-nón",
    "tizo": "ti-zo",
    "tizón": "ti-zón",
    "tizona": "ti-zo-na",
    "tizonada": "ti-zo-na-da",
    "tizonazo": "ti-zo-na-zo",
    "tizoncillo": "ti-zon-ci-llo",
    "tizonear": "ti-zo-ne-ar",
    "tizonera": "ti-zo-ne-ra",
    "tlacatillo": "tla-ca-ti-llo",
    "tlachique": "tla-chi-que",
    "tlachiquera": "tla-chi-que-ra",
    "tlachiquero": "tla-chi-que-ro",
    "tlaco": "tla-co",
    "tlacoache": "tla-co-a-che",
    "tlaconete": "tla-co-ne-te",
    "tlacote": "tla-co-te",
    "tlacoyo": "tla-co-yo",
    "tlacuache": "tla-cua-che",
    "tlacuachi": "tla-cua-chi",
    "tlacual": "tla-cual",
    "tlacualera": "tla-cua-le-ra",
    "tlacualero": "tla-cua-le-ro",
    "tlacuilo": "tla-cui-lo",
    "tlalayote": "tla-la-yo-te",
    "tlalchichi": "tlal-chi-chi",
    "tlalcoyote": "tlal-co-yo-te",
    "tlameme": "tla-me-me",
    "tlapalera": "tla-pa-le-ra",
    "tlapalería": "tla-pa-le-rí-a",
    "tlapalero": "tla-pa-le-ro",
    "tlapaneco": "tla-pa-ne-co",
    "tlaxcalteca": "tlax-cal-te-ca",
    "tlazol": "tla-zol",
    "toa": "to-a",
    "toalla": "to-a-lla",
    "toallero": "to-a-lle-ro",
    "toalleta": "to-a-lle-ta",
    "toallita": "to-a-lli-ta",
    "toar": "to-ar",
    "toba": "to-ba",
    "tobaja": "to-ba-ja",
    "toballa": "to-ba-lla",
    "toballeta": "to-ba-lle-ta",
    "tobar": "to-bar",
    "tobelleta": "to-be-lle-ta",
    "tobera": "to-be-ra",
    "tobiana": "to-bia-na",
    "tobiano": "to-bia-no",
    "tobillera": "to-bi-lle-ra",
    "tobillero": "to-bi-lle-ro",
    "tobillo": "to-bi-llo",
    "tobo": "to-bo",
    "toboba": "to-bo-ba",
    "tobogán": "to-bo-gán",
    "toborochi": "to-bo-ro-chi",
    "tobosa": "to-bo-sa",
    "toboseña": "to-bo-se-ña",
    "toboseño": "to-bo-se-ño",
    "tobosesca": "to-bo-ses-ca",
    "tobosesco": "to-bo-ses-co",
    "tobosina": "to-bo-si-na",
    "tobosino": "to-bo-si-no",
    "toboso": "to-bo-so",
    "toca": "to-ca",
    "tocable": "to-ca-ble",
    "tocada": "to-ca-da",
    "tocadiscos": "to-ca-dis-cos",
    "tocado": "to-ca-do",
    "tocador": "to-ca-dor",
    "tocadora": "to-ca-do-ra",
    "tocadura": "to-ca-du-ra",
    "tocamiento": "to-ca-mien-to",
    "tocante": "to-can-te",
    "tocapito": "to-ca-pi-to",
    "tocar": "to-car",
    "tocario": "to-ca-rio",
    "tocasalva": "to-ca-sal-va",
    "tocata": "to-ca-ta",
    "tocateja": "to-ca-te-ja",
    "tocatorre": "to-ca-to-rre",
    "tocaya": "to-ca-ya",
    "tocayo": "to-ca-yo",
    "toccata": "toc-ca-ta",
    "tocha": "to-cha",
    "toche": "to-che",
    "tochedad": "to-che-dad",
    "tochi": "to-chi",
    "tochibí": "to-chi-bí",
    "tochimbo": "to-chim-bo",
    "tocho": "to-cho",
    "tochuelo": "to-chue-lo",
    "tochura": "to-chu-ra",
    "tocía": "to-cí-a",
    "tocinera": "to-ci-ne-ra",
    "tocinería": "to-ci-ne-rí-a",
    "tocinero": "to-ci-ne-ro",
    "tocineta": "to-ci-ne-ta",
    "tocinillo": "to-ci-ni-llo",
    "tocino": "to-ci-no",
    "tocio": "to-cio",
    "toco": "to-co",
    "tococo": "to-co-co",
    "tocoginecóloga": "to-co-gi-ne-có-lo-ga",
    "tocoginecología": "to-co-gi-ne-co-lo-gí-a",
    "tocoginecólogo": "to-co-gi-ne-có-lo-go",
    "tocóloga": "to-có-lo-ga",
    "tocología": "to-co-lo-gí-a",
    "tocológico": "to-co-ló-gi-co",
    "tocólogo": "to-có-lo-go",
    "tocoloro": "to-co-lo-ro",
    "tocomate": "to-co-ma-te",
    "tocomocho": "to-co-mo-cho",
    "tocón": "to-cón",
    "tocona": "to-co-na",
    "toconal": "to-co-nal",
    "tocopillana": "to-co-pi-lla-na",
    "tocopillano": "to-co-pi-lla-no",
    "tocorno": "to-cor-no",
    "tocororo": "to-co-ro-ro",
    "tocotín": "to-co-tín",
    "tocoyal": "to-co-yal",
    "tocte": "toc-te",
    "tocuyo": "to-cu-yo",
    "toda": "to-da",
    "todabuena": "to-da-bue-na",
    "todasana": "to-da-sa-na",
    "todavía": "to-da-ví-a",
    "todero": "to-de-ro",
    "todía": "to-dí-a",
    "todo": "to-do",
    "todóloga": "to-dó-lo-ga",
    "todólogo": "to-dó-lo-go",
    "todopoderosa": "to-do-po-de-ro-sa",
    "todopoderoso": "to-do-po-de-ro-so",
    "todoterreno": "to-do-te-rre-no",
    "toesa": "to-e-sa",
    "tofana": "to-fa-na",
    "tofo": "to-fo",
    "tofu": "to-fu",
    "toga": "to-ga",
    "togada": "to-ga-da",
    "togado": "to-ga-do",
    "togar": "to-gar",
    "togolés": "to-go-lés",
    "togolesa": "to-go-le-sa",
    "toilette": "toi-let-te",
    "toisón": "toi-són",
    "tojal": "to-jal",
    "tojarra": "to-ja-rra",
    "tojarro": "to-ja-rro",
    "tojino": "to-ji-no",
    "tojo": "to-jo",
    "tojosita": "to-jo-si-ta",
    "tokamak": "to-ka-mak",
    "tola": "to-la",
    "tolano": "to-la-no",
    "tolda": "tol-da",
    "toldadura": "tol-da-du-ra",
    "toldar": "tol-dar",
    "toldera": "tol-de-ra",
    "toldería": "tol-de-rí-a",
    "toldero": "tol-de-ro",
    "toldilla": "tol-di-lla",
    "toldillo": "tol-di-llo",
    "toldo": "tol-do",
    "tole": "to-le",
    "toledana": "to-le-da-na",
    "toledano": "to-le-da-no",
    "toledo": "to-le-do",
    "tolemaica": "to-le-mai-ca",
    "tolemaico": "to-le-mai-co",
    "tolena": "to-le-na",
    "tolenda": "to-len-da",
    "tolerabilidad": "to-le-ra-bi-li-dad",
    "tolerable": "to-le-ra-ble",
    "tolerablemente": "to-le-ra-ble-men-te",
    "tolerado": "to-le-ra-do",
    "tolerancia": "to-le-ran-cia",
    "tolerante": "to-le-ran-te",
    "tolerantismo": "to-le-ran-tis-mo",
    "tolerar": "to-le-rar",
    "toletazo": "to-le-ta-zo",
    "tolete": "to-le-te",
    "toletear": "to-le-te-ar",
    "tolimense": "to-li-men-se",
    "tolla": "to-lla",
    "tolladar": "to-lla-dar",
    "tollecer": "to-lle-cer",
    "toller": "to-ller",
    "tollimiento": "to-lli-mien-to",
    "tollina": "to-lli-na",
    "tollir": "to-llir",
    "tollo": "to-llo",
    "tollón": "to-llón",
    "tolmera": "tol-me-ra",
    "tolmo": "tol-mo",
    "toloache": "to-lo-a-che",
    "tolobojo": "to-lo-bo-jo",
    "tololoche": "to-lo-lo-che",
    "tolomuco": "to-lo-mu-co",
    "tolón": "to-lón",
    "tolonca": "to-lon-ca",
    "toloncón": "to-lon-cón",
    "tolondra": "to-lon-dra",
    "tolondro": "to-lon-dro",
    "tolondrón": "to-lon-drón",
    "tolondrona": "to-lon-dro-na",
    "tolonés": "to-lo-nés",
    "tolonesa": "to-lo-ne-sa",
    "tolonguear": "to-lon-gue-ar",
    "tolosana": "to-lo-sa-na",
    "tolosano": "to-lo-sa-no",
    "tolteca": "tol-te-ca",
    "tolú": "to-lú",
    "tolueno": "to-lue-no",
    "tolupán": "to-lu-pán",
    "toluqueña": "to-lu-que-ña",
    "toluqueño": "to-lu-que-ño",
    "tolva": "tol-va",
    "tolvanera": "tol-va-ne-ra",
    "toma": "to-ma",
    "tomacorriente": "to-ma-co-rrien-te",
    "tomada": "to-ma-da",
    "tomadero": "to-ma-de-ro",
    "tomado": "to-ma-do",
    "tomador": "to-ma-dor",
    "tomadora": "to-ma-do-ra",
    "tomadura": "to-ma-du-ra",
    "tomahawk": "to-ma-hawk",
    "tomaína": "to-ma-í-na",
    "tomajón": "to-ma-jón",
    "tomajona": "to-ma-jo-na",
    "tomamiento": "to-ma-mien-to",
    "tomar": "to-mar",
    "tomatada": "to-ma-ta-da",
    "tomatal": "to-ma-tal",
    "tomatazo": "to-ma-ta-zo",
    "tomate": "to-ma-te",
    "tomatera": "to-ma-te-ra",
    "tomatero": "to-ma-te-ro",
    "tomaticán": "to-ma-ti-cán",
    "tomatillo": "to-ma-ti-llo",
    "tomavistas": "to-ma-vis-tas",
    "tomaza": "to-ma-za",
    "tombo": "tom-bo",
    "tómbola": "tóm-bo-la",
    "tómbolo": "tóm-bo-lo",
    "tomeguín": "to-me-guín",
    "tomento": "to-men-to",
    "tomentosa": "to-men-to-sa",
    "tomentoso": "to-men-to-so",
    "tomillar": "to-mi-llar",
    "tomillo": "to-mi-llo",
    "tomín": "to-mín",
    "tomineja": "to-mi-ne-ja",
    "tominejo": "to-mi-ne-jo",
    "tomismo": "to-mis-mo",
    "tomista": "to-mis-ta",
    "tomiza": "to-mi-za",
    "tomo": "to-mo",
    "tomografía": "to-mo-gra-fí-a",
    "tomón": "to-món",
    "tomona": "to-mo-na",
    "tona": "to-na",
    "toña": "to-ña",
    "tonada": "to-na-da",
    "tonadilla": "to-na-di-lla",
    "tonadillera": "to-na-di-lle-ra",
    "tonadillero": "to-na-di-lle-ro",
    "tonal": "to-nal",
    "tonalidad": "to-na-li-dad",
    "tonante": "to-nan-te",
    "tonar": "to-nar",
    "tonario": "to-na-rio",
    "tonca": "ton-ca",
    "tondero": "ton-de-ro",
    "tondino": "ton-di-no",
    "tondiz": "ton-diz",
    "tondo": "ton-do",
    "tonel": "to-nel",
    "tonelada": "to-ne-la-da",
    "tonelaje": "to-ne-la-je",
    "tonelera": "to-ne-le-ra",
    "tonelería": "to-ne-le-rí-a",
    "tonelero": "to-ne-le-ro",
    "tonelete": "to-ne-le-te",
    "tonema": "to-ne-ma",
    "tóner": "tó-ner",
    "tonga": "ton-ga",
    "tongada": "ton-ga-da",
    "tongana": "ton-ga-na",
    "tongano": "ton-ga-no",
    "tongo": "ton-go",
    "tongonear": "ton-go-ne-ar",
    "tongoneo": "ton-go-ne-o",
    "tónica": "tó-ni-ca",
    "tonicidad": "to-ni-ci-dad",
    "tónico": "tó-ni-co",
    "tonificación": "to-ni-fi-ca-ción",
    "tonificador": "to-ni-fi-ca-dor",
    "tonificadora": "to-ni-fi-ca-do-ra",
    "tonificante": "to-ni-fi-can-te",
    "tonificar": "to-ni-fi-car",
    "toñil": "to-ñil",
    "tonillo": "to-ni-llo",
    "tonina": "to-ni-na",
    "toñina": "to-ñi-na",
    "tonino": "to-ni-no",
    "tono": "to-no",
    "tonó": "to-nó",
    "tonocoté": "to-no-co-té",
    "tonsila": "ton-si-la",
    "tonsilar": "ton-si-lar",
    "tonsura": "ton-su-ra",
    "tonsurado": "ton-su-ra-do",
    "tonsurando": "ton-su-ran-do",
    "tonsurar": "ton-su-rar",
    "tonta": "ton-ta",
    "tontada": "ton-ta-da",
    "tontaina": "ton-tai-na",
    "tontamente": "ton-ta-men-te",
    "tontarrón": "ton-ta-rrón",
    "tontarrona": "ton-ta-rro-na",
    "tontear": "ton-te-ar",
    "tontedad": "ton-te-dad",
    "tonteo": "ton-te-o",
    "tontera": "ton-te-ra",
    "tontería": "ton-te-rí-a",
    "tontillo": "ton-ti-llo",
    "tontiloca": "ton-ti-lo-ca",
    "tontiloco": "ton-ti-lo-co",
    "tontina": "ton-ti-na",
    "tontito": "ton-ti-to",
    "tontivana": "ton-ti-va-na",
    "tontivano": "ton-ti-va-no",
    "tonto": "ton-to",
    "tontorrón": "ton-to-rrón",
    "tontucia": "ton-tu-cia",
    "tontucio": "ton-tu-cio",
    "tontuna": "ton-tu-na",
    "topa": "to-pa",
    "topacio": "to-pa-cio",
    "topada": "to-pa-da",
    "topadiza": "to-pa-di-za",
    "topadizo": "to-pa-di-zo",
    "topado": "to-pa-do",
    "topador": "to-pa-dor",
    "topadora": "to-pa-do-ra",
    "topamiento": "to-pa-mien-to",
    "topar": "to-par",
    "toparca": "to-par-ca",
    "toparquía": "to-par-quí-a",
    "toparra": "to-pa-rra",
    "topatopa": "to-pa-to-pa",
    "tope": "to-pe",
    "topeadura": "to-pe-a-du-ra",
    "topear": "to-pe-ar",
    "topera": "to-pe-ra",
    "topero": "to-pe-ro",
    "toperol": "to-pe-rol",
    "topetada": "to-pe-ta-da",
    "topetar": "to-pe-tar",
    "topetazo": "to-pe-ta-zo",
    "topetear": "to-pe-te-ar",
    "topetera": "to-pe-te-ra",
    "topetero": "to-pe-te-ro",
    "topetón": "to-pe-tón",
    "topetuda": "to-pe-tu-da",
    "topetudo": "to-pe-tu-do",
    "topia": "to-pia",
    "tópica": "tó-pi-ca",
    "tópico": "tó-pi-co",
    "topil": "to-pil",
    "topillo": "to-pi-llo",
    "topina": "to-pi-na",
    "topinada": "to-pi-na-da",
    "topinaria": "to-pi-na-ria",
    "topinera": "to-pi-ne-ra",
    "topino": "to-pi-no",
    "topiquera": "to-pi-que-ra",
    "topiquero": "to-pi-que-ro",
    "topista": "to-pis-ta",
    "toples": "to-ples",
    "topless": "to-pless",
    "topo": "to-po",
    "topocha": "to-po-cha",
    "topocho": "to-po-cho",
    "topógrafa": "to-pó-gra-fa",
    "topografía": "to-po-gra-fí-a",
    "topográfica": "to-po-grá-fi-ca",
    "topográficamente": "to-po-grá-fi-ca-men-te",
    "topográfico": "to-po-grá-fi-co",
    "topógrafo": "to-pó-gra-fo",
    "topolino": "to-po-li-no",
    "topología": "to-po-lo-gí-a",
    "topológico": "to-po-ló-gi-co",
    "topón": "to-pón",
    "toponear": "to-po-ne-ar",
    "toponimia": "to-po-ni-mia",
    "toponímica": "to-po-ní-mi-ca",
    "toponímico": "to-po-ní-mi-co",
    "topónimo": "to-pó-ni-mo",
    "toque": "to-que",
    "toqueado": "to-que-a-do",
    "toquera": "to-que-ra",
    "toquería": "to-que-rí-a",
    "toquero": "to-que-ro",
    "toquetear": "to-que-te-ar",
    "toqueteo": "to-que-te-o",
    "toqui": "to-qui",
    "toquido": "to-qui-do",
    "toquilla": "to-qui-lla",
    "tora": "to-ra",
    "torácica": "to-rá-ci-ca",
    "torácico": "to-rá-ci-co",
    "toracoplastia": "to-ra-co-plas-tia",
    "torada": "to-ra-da",
    "toral": "to-ral",
    "tórax": "tó-rax",
    "torbellino": "tor-be-lli-no",
    "torca": "tor-ca",
    "torcal": "tor-cal",
    "torcaz": "tor-caz",
    "torcaza": "tor-ca-za",
    "torce": "tor-ce",
    "torcecuello": "tor-ce-cue-llo",
    "torcecuellos": "tor-ce-cue-llos",
    "torcedera": "tor-ce-de-ra",
    "torcedero": "tor-ce-de-ro",
    "torcedor": "tor-ce-dor",
    "torcedora": "tor-ce-do-ra",
    "torcedura": "tor-ce-du-ra",
    "torcer": "tor-cer",
    "torcho": "tor-cho",
    "torchuelo": "tor-chue-lo",
    "torcida": "tor-ci-da",
    "torcidamente": "tor-ci-da-men-te",
    "torcido": "tor-ci-do",
    "torcijón": "tor-ci-jón",
    "torcimiento": "tor-ci-mien-to",
    "torción": "tor-ción",
    "torco": "tor-co",
    "torculada": "tor-cu-la-da",
    "torculado": "tor-cu-la-do",
    "tórculo": "tór-cu-lo",
    "torda": "tor-da",
    "tordella": "tor-de-lla",
    "tórdiga": "tór-di-ga",
    "tordilla": "tor-di-lla",
    "tordillo": "tor-di-llo",
    "tordo": "tor-do",
    "toreador": "to-re-a-dor",
    "torear": "to-re-ar",
    "toreo": "to-re-o",
    "torera": "to-re-ra",
    "torería": "to-re-rí-a",
    "torerista": "to-re-ris-ta",
    "torero": "to-re-ro",
    "torés": "to-rés",
    "toresana": "to-re-sa-na",
    "toresano": "to-re-sa-no",
    "torete": "to-re-te",
    "torga": "tor-ga",
    "torgada": "tor-ga-da",
    "torgado": "tor-ga-do",
    "torgo": "tor-go",
    "tórico": "tó-ri-co",
    "toril": "to-ril",
    "torillo": "to-ri-llo",
    "torio": "to-rio",
    "torionda": "to-rion-da",
    "toriondez": "to-rion-dez",
    "toriondo": "to-rion-do",
    "torista": "to-ris-ta",
    "torito": "to-ri-to",
    "torloroto": "tor-lo-ro-to",
    "tormagal": "tor-ma-gal",
    "tormellera": "tor-me-lle-ra",
    "tormenta": "tor-men-ta",
    "tormentar": "tor-men-tar",
    "tormentaria": "tor-men-ta-ria",
    "tormentario": "tor-men-ta-rio",
    "tormentila": "tor-men-ti-la",
    "tormentín": "tor-men-tín",
    "tormento": "tor-men-to",
    "tormentosa": "tor-men-to-sa",
    "tormentoso": "tor-men-to-so",
    "tormera": "tor-me-ra",
    "tormo": "tor-mo",
    "torna": "tor-na",
    "tornaboda": "tor-na-bo-da",
    "tornachile": "tor-na-chi-le",
    "tornada": "tor-na-da",
    "tornadera": "tor-na-de-ra",
    "tornadero": "tor-na-de-ro",
    "tornadiza": "tor-na-di-za",
    "tornadizo": "tor-na-di-zo",
    "tornado": "tor-na-do",
    "tornadura": "tor-na-du-ra",
    "tornagallos": "tor-na-ga-llos",
    "tornaguía": "tor-na-guí-a",
    "tornalecho": "tor-na-le-cho",
    "tornamesa": "tor-na-me-sa",
    "tornamiento": "tor-na-mien-to",
    "tornapeón": "tor-na-pe-ón",
    "tornapunta": "tor-na-pun-ta",
    "tornar": "tor-nar",
    "tornasol": "tor-na-sol",
    "tornasolada": "tor-na-so-la-da",
    "tornasolado": "tor-na-so-la-do",
    "tornasolar": "tor-na-so-lar",
    "tornátil": "tor-ná-til",
    "tornatrás": "tor-na-trás",
    "tornaviaje": "tor-na-via-je",
    "tornavirón": "tor-na-vi-rón",
    "tornavoz": "tor-na-voz",
    "torneado": "tor-ne-a-do",
    "torneador": "tor-ne-a-dor",
    "torneadora": "tor-ne-a-do-ra",
    "torneadura": "tor-ne-a-du-ra",
    "tornear": "tor-ne-ar",
    "torneo": "tor-ne-o",
    "tornera": "tor-ne-ra",
    "tornería": "tor-ne-rí-a",
    "tornero": "tor-ne-ro",
    "tornés": "tor-nés",
    "tornesa": "tor-ne-sa",
    "tornija": "tor-ni-ja",
    "tornillería": "tor-ni-lle-rí-a",
    "tornillero": "tor-ni-lle-ro",
    "tornillo": "tor-ni-llo",
    "torniquete": "tor-ni-que-te",
    "torniscón": "tor-nis-cón",
    "torno": "tor-no",
    "toro": "to-ro",
    "torogoz": "to-ro-goz",
    "toroidal": "to-roi-dal",
    "toroide": "to-roi-de",
    "toromiro": "to-ro-mi-ro",
    "torón": "to-rón",
    "torondo": "to-ron-do",
    "torondón": "to-ron-dón",
    "toronja": "to-ron-ja",
    "toronjil": "to-ron-jil",
    "toronjina": "to-ron-ji-na",
    "toronjo": "to-ron-jo",
    "torosa": "to-ro-sa",
    "toroso": "to-ro-so",
    "torozón": "to-ro-zón",
    "torpe": "tor-pe",
    "torpecer": "tor-pe-cer",
    "torpedad": "tor-pe-dad",
    "torpedeamiento": "tor-pe-de-a-mien-to",
    "torpedear": "tor-pe-de-ar",
    "torpedeo": "tor-pe-de-o",
    "torpedera": "tor-pe-de-ra",
    "torpedero": "tor-pe-de-ro",
    "torpedista": "tor-pe-dis-ta",
    "torpedo": "tor-pe-do",
    "torpemente": "tor-pe-men-te",
    "torpeza": "tor-pe-za",
    "tórpida": "tór-pi-da",
    "tórpido": "tór-pi-do",
    "torpón": "tor-pón",
    "torpor": "tor-por",
    "torques": "tor-ques",
    "torrado": "to-rra-do",
    "torrancés": "to-rran-cés",
    "torrancesa": "to-rran-ce-sa",
    "torrar": "to-rrar",
    "torre": "to-rre",
    "torreado": "to-rre-a-do",
    "torrear": "to-rre-ar",
    "torrefacción": "to-rre-fac-ción",
    "torrefacta": "to-rre-fac-ta",
    "torrefacto": "to-rre-fac-to",
    "torreja": "to-rre-ja",
    "torrejón": "to-rre-jón",
    "torrencial": "to-rren-cial",
    "torrencialmente": "to-rren-cial-men-te",
    "torrente": "to-rren-te",
    "torrentera": "to-rren-te-ra",
    "torrentoso": "to-rren-to-so",
    "torreón": "to-rre-ón",
    "torrera": "to-rre-ra",
    "torrero": "to-rre-ro",
    "torreta": "to-rre-ta",
    "torreznada": "to-rrez-na-da",
    "torreznera": "to-rrez-ne-ra",
    "torreznero": "to-rrez-ne-ro",
    "torrezno": "to-rrez-no",
    "tórrida": "tó-rri-da",
    "tórrido": "tó-rri-do",
    "torrija": "to-rri-ja",
    "torrontera": "to-rron-te-ra",
    "torrontero": "to-rron-te-ro",
    "torrontés": "to-rron-tés",
    "torrotito": "to-rro-ti-to",
    "torrupán": "to-rru-pán",
    "tórsalo": "tór-sa-lo",
    "torsión": "tor-sión",
    "torso": "tor-so",
    "torta": "tor-ta",
    "tortada": "tor-ta-da",
    "tortazo": "tor-ta-zo",
    "tortear": "tor-te-ar",
    "tortedad": "tor-te-dad",
    "tortel": "tor-tel",
    "tortellini": "tor-te-lli-ni",
    "tortera": "tor-te-ra",
    "tortería": "tor-te-rí-a",
    "tortero": "tor-te-ro",
    "torteruelo": "tor-te-rue-lo",
    "torticera": "tor-ti-ce-ra",
    "torticeramente": "tor-ti-ce-ra-men-te",
    "torticero": "tor-ti-ce-ro",
    "torticolis": "tor-ti-co-lis",
    "tortícolis": "tor-tí-co-lis",
    "tortilla": "tor-ti-lla",
    "tortilladora": "tor-ti-lla-do-ra",
    "tortillera": "tor-ti-lle-ra",
    "tortillería": "tor-ti-lle-rí-a",
    "tortillero": "tor-ti-lle-ro",
    "tortillo": "tor-ti-llo",
    "tortis": "tor-tis",
    "tortita": "tor-ti-ta",
    "tortol": "tor-tol",
    "tórtola": "tór-to-la",
    "tortoleo": "tor-to-le-o",
    "tortolita": "tor-to-li-ta",
    "tortolito": "tor-to-li-to",
    "tortolo": "tor-to-lo",
    "tórtolo": "tór-to-lo",
    "tortor": "tor-tor",
    "tortosina": "tor-to-si-na",
    "tortosino": "tor-to-si-no",
    "tortozón": "tor-to-zón",
    "tortuga": "tor-tu-ga",
    "tortuguilla": "tor-tu-gui-lla",
    "tortuosa": "tor-tuo-sa",
    "tortuosamente": "tor-tuo-sa-men-te",
    "tortuosidad": "tor-tuo-si-dad",
    "tortuoso": "tor-tuo-so",
    "tortura": "tor-tu-ra",
    "torturador": "tor-tu-ra-dor",
    "torturadora": "tor-tu-ra-do-ra",
    "torturar": "tor-tu-rar",
    "torunda": "to-run-da",
    "toruno": "to-ru-no",
    "torva": "tor-va",
    "torvisca": "tor-vis-ca",
    "torviscal": "tor-vis-cal",
    "torvisco": "tor-vis-co",
    "torvo": "tor-vo",
    "torzadillo": "tor-za-di-llo",
    "torzal": "tor-zal",
    "torzón": "tor-zón",
    "torzonada": "tor-zo-na-da",
    "torzonado": "tor-zo-na-do",
    "torzuelo": "tor-zue-lo",
    "tosa": "to-sa",
    "tosca": "tos-ca",
    "toscamente": "tos-ca-men-te",
    "toscana": "tos-ca-na",
    "toscano": "tos-ca-no",
    "tosco": "tos-co",
    "tose": "to-se",
    "tosedera": "to-se-de-ra",
    "tosedor": "to-se-dor",
    "tosedora": "to-se-do-ra",
    "tosegosa": "to-se-go-sa",
    "tosegoso": "to-se-go-so",
    "toser": "to-ser",
    "tosida": "to-si-da",
    "tosidura": "to-si-du-ra",
    "tosiento": "to-sien-to",
    "tosigar": "to-si-gar",
    "tósigo": "tó-si-go",
    "tosigosa": "to-si-go-sa",
    "tosigoso": "to-si-go-so",
    "tosiguera": "to-si-gue-ra",
    "tosijoso": "to-si-jo-so",
    "tosquedad": "tos-que-dad",
    "tostación": "tos-ta-ción",
    "tostada": "tos-ta-da",
    "tostadera": "tos-ta-de-ra",
    "tostadero": "tos-ta-de-ro",
    "tostadillo": "tos-ta-di-llo",
    "tostado": "tos-ta-do",
    "tostador": "tos-ta-dor",
    "tostadora": "tos-ta-do-ra",
    "tostadura": "tos-ta-du-ra",
    "tostar": "tos-tar",
    "tostón": "tos-tón",
    "tostoncillo": "tos-ton-ci-llo",
    "total": "to-tal",
    "totalidad": "to-ta-li-dad",
    "totalitaria": "to-ta-li-ta-ria",
    "totalitariamente": "to-ta-li-ta-ria-men-te",
    "totalitario": "to-ta-li-ta-rio",
    "totalitarismo": "to-ta-li-ta-ris-mo",
    "totalitarista": "to-ta-li-ta-ris-ta",
    "totalización": "to-ta-li-za-ción",
    "totalizador": "to-ta-li-za-dor",
    "totalizar": "to-ta-li-zar",
    "totalmente": "to-tal-men-te",
    "totanera": "to-ta-ne-ra",
    "totanero": "to-ta-ne-ro",
    "tote": "to-te",
    "tótem": "tó-tem",
    "totémico": "to-té-mi-co",
    "totemismo": "to-te-mis-mo",
    "totí": "to-tí",
    "totilimundi": "to-ti-li-mun-di",
    "totol": "to-tol",
    "totola": "to-to-la",
    "totolate": "to-to-la-te",
    "totolear": "to-to-le-ar",
    "totoloque": "to-to-lo-que",
    "totomochtle": "to-to-moch-tle",
    "totonaco": "to-to-na-co",
    "totonicapense": "to-to-ni-ca-pen-se",
    "totopo": "to-to-po",
    "totoposte": "to-to-pos-te",
    "totora": "to-to-ra",
    "totoral": "to-to-ral",
    "totoreco": "to-to-re-co",
    "totoreña": "to-to-re-ña",
    "totoreño": "to-to-re-ño",
    "totorero": "to-to-re-ro",
    "totovía": "to-to-ví-a",
    "totuma": "to-tu-ma",
    "totumo": "to-tu-mo",
    "totumpote": "to-tum-po-te",
    "tournedos": "tour-ne-dos",
    "tournée": "tour-né-e",
    "touroperador": "tou-ro-pe-ra-dor",
    "touroperadora": "tou-ro-pe-ra-do-ra",
    "tova": "to-va",
    "toxemia": "to-xe-mia",
    "tóxica": "tó-xi-ca",
    "toxicar": "to-xi-car",
    "toxicidad": "to-xi-ci-dad",
    "tóxico": "tó-xi-co",
    "toxicogénesis": "to-xi-co-gé-ne-sis",
    "toxicóloga": "to-xi-có-lo-ga",
    "toxicología": "to-xi-co-lo-gí-a",
    "toxicológica": "to-xi-co-ló-gi-ca",
    "toxicológico": "to-xi-co-ló-gi-co",
    "toxicólogo": "to-xi-có-lo-go",
    "toxicómana": "to-xi-có-ma-na",
    "toxicomanía": "to-xi-co-ma-ní-a",
    "toxicómano": "to-xi-có-ma-no",
    "toxicosis": "to-xi-co-sis",
    "toxígeno": "to-xí-ge-no",
    "toxiinfección": "to-xiin-fec-ción",
    "toxina": "to-xi-na",
    "toxoplasmosis": "to-xo-plas-mo-sis",
    "toza": "to-za",
    "tozal": "to-zal",
    "tozalba": "to-zal-ba",
    "tozalbo": "to-zal-bo",
    "tozar": "to-zar",
    "tozo": "to-zo",
    "tozolada": "to-zo-la-da",
    "tozolón": "to-zo-lón",
    "tozuda": "to-zu-da",
    "tozudamente": "to-zu-da-men-te",
    "tozudez": "to-zu-dez",
    "tozudo": "to-zu-do",
    "tozuelo": "to-zue-lo",
    "traba": "tra-ba",
    "trabacuenta": "tra-ba-cuen-ta",
    "trabada": "tra-ba-da",
    "trabadero": "tra-ba-de-ro",
    "trabado": "tra-ba-do",
    "trabador": "tra-ba-dor",
    "trabadura": "tra-ba-du-ra",
    "trabajada": "tra-ba-ja-da",
    "trabajadamente": "tra-ba-ja-da-men-te",
    "trabajadero": "tra-ba-ja-de-ro",
    "trabajado": "tra-ba-ja-do",
    "trabajador": "tra-ba-ja-dor",
    "trabajadora": "tra-ba-ja-do-ra",
    "trabajante": "tra-ba-jan-te",
    "trabajar": "tra-ba-jar",
    "trabajera": "tra-ba-je-ra",
    "trabajito": "tra-ba-ji-to",
    "trabajo": "tra-ba-jo",
    "trabajólica": "tra-ba-jó-li-ca",
    "trabajólico": "tra-ba-jó-li-co",
    "trabajosa": "tra-ba-jo-sa",
    "trabajosamente": "tra-ba-jo-sa-men-te",
    "trabajoso": "tra-ba-jo-so",
    "trabal": "tra-bal",
    "trabalenguas": "tra-ba-len-guas",
    "trabamiento": "tra-ba-mien-to",
    "trabanca": "tra-ban-ca",
    "trabanco": "tra-ban-co",
    "trabar": "tra-bar",
    "trabazón": "tra-ba-zón",
    "trabe": "tra-be",
    "trábea": "trá-be-a",
    "trabilla": "tra-bi-lla",
    "trabina": "tra-bi-na",
    "trabón": "tra-bón",
    "trabuca": "tra-bu-ca",
    "trabucación": "tra-bu-ca-ción",
    "trabucador": "tra-bu-ca-dor",
    "trabucadora": "tra-bu-ca-do-ra",
    "trabucaire": "tra-bu-cai-re",
    "trabucar": "tra-bu-car",
    "trabucazo": "tra-bu-ca-zo",
    "trabuco": "tra-bu-co",
    "trabuquete": "tra-bu-que-te",
    "traca": "tra-ca",
    "trácala": "trá-ca-la",
    "tracalada": "tra-ca-la-da",
    "tracalear": "tra-ca-le-ar",
    "tracalera": "tra-ca-le-ra",
    "tracalería": "tra-ca-le-rí-a",
    "tracalero": "tra-ca-le-ro",
    "tracamundana": "tra-ca-mun-da-na",
    "tracatear": "tra-ca-te-ar",
    "tracateo": "tra-ca-te-o",
    "tracción": "trac-ción",
    "trace": "tra-ce",
    "tracería": "tra-ce-rí-a",
    "tracia": "tra-cia",
    "traciana": "tra-cia-na",
    "traciano": "tra-cia-no",
    "tracias": "tra-cias",
    "tracio": "tra-cio",
    "tracista": "tra-cis-ta",
    "tracoma": "tra-co-ma",
    "tracomatosa": "tra-co-ma-to-sa",
    "tracomatoso": "tra-co-ma-to-so",
    "tractar": "trac-tar",
    "tracto": "trac-to",
    "tractocarril": "trac-to-ca-rril",
    "tractor": "trac-tor",
    "tractorar": "trac-to-rar",
    "tractorear": "trac-to-re-ar",
    "tractoreo": "trac-to-re-o",
    "tractorista": "trac-to-ris-ta",
    "tradescantia": "tra-des-can-tia",
    "tradición": "tra-di-ción",
    "tradicional": "tra-di-cio-nal",
    "tradicionalismo": "tra-di-cio-na-lis-mo",
    "tradicionalista": "tra-di-cio-na-lis-ta",
    "tradicionalmente": "tra-di-cio-nal-men-te",
    "tradicionista": "tra-di-cio-nis-ta",
    "traducción": "tra-duc-ción",
    "traducibilidad": "tra-du-ci-bi-li-dad",
    "traducible": "tra-du-ci-ble",
    "traducionismo": "tra-du-cio-nis-mo",
    "traducir": "tra-du-cir",
    "traductor": "tra-duc-tor",
    "traductora": "tra-duc-to-ra",
    "traediza": "tra-e-di-za",
    "traedizo": "tra-e-di-zo",
    "traedor": "tra-e-dor",
    "traedora": "tra-e-do-ra",
    "traedura": "tra-e-du-ra",
    "traer": "tra-er",
    "traeres": "tra-e-res",
    "trafa": "tra-fa",
    "trafagador": "tra-fa-ga-dor",
    "trafagadora": "tra-fa-ga-do-ra",
    "trafagar": "tra-fa-gar",
    "tráfago": "trá-fa-go",
    "trafagón": "tra-fa-gón",
    "trafagona": "tra-fa-go-na",
    "trafalgar": "tra-fal-gar",
    "trafallón": "tra-fa-llón",
    "trafalmeja": "tra-fal-me-ja",
    "trafalmejas": "tra-fal-me-jas",
    "traficación": "tra-fi-ca-ción",
    "traficante": "tra-fi-can-te",
    "traficar": "tra-fi-car",
    "tráfico": "trá-fi-co",
    "trafique": "tra-fi-que",
    "trafulcar": "tra-ful-car",
    "traga": "tra-ga",
    "tragaavemarías": "tra-ga-a-ve-ma-rí-as",
    "tragable": "tra-ga-ble",
    "tragabolas": "tra-ga-bo-las",
    "tragacanta": "tra-ga-can-ta",
    "tragacanto": "tra-ga-can-to",
    "tragacete": "tra-ga-ce-te",
    "tragaderas": "tra-ga-de-ras",
    "tragadero": "tra-ga-de-ro",
    "tragadieces": "tra-ga-die-ces",
    "tragador": "tra-ga-dor",
    "tragadora": "tra-ga-do-ra",
    "tragafees": "tra-ga-fe-es",
    "tragahombres": "tra-ga-hom-bres",
    "trágala": "trá-ga-la",
    "tragaldabas": "tra-gal-da-bas",
    "tragaleguas": "tra-ga-le-guas",
    "tragallón": "tra-ga-llón",
    "tragallona": "tra-ga-llo-na",
    "tragaluz": "tra-ga-luz",
    "tragamallas": "tra-ga-ma-llas",
    "tragamillas": "tra-ga-mi-llas",
    "tragamonedas": "tra-ga-mo-ne-das",
    "traganíquel": "tra-ga-ní-quel",
    "tragantada": "tra-gan-ta-da",
    "tragante": "tra-gan-te",
    "tragantón": "tra-gan-tón",
    "tragantona": "tra-gan-to-na",
    "tragaperras": "tra-ga-pe-rras",
    "tragar": "tra-gar",
    "tragasables": "tra-ga-sa-bles",
    "tragasantos": "tra-ga-san-tos",
    "tragavenado": "tra-ga-ve-na-do",
    "tragavino": "tra-ga-vi-no",
    "tragavirotes": "tra-ga-vi-ro-tes",
    "tragaz": "tra-gaz",
    "tragazón": "tra-ga-zón",
    "tragedia": "tra-ge-dia",
    "trágica": "trá-gi-ca",
    "trágicamente": "trá-gi-ca-men-te",
    "trágico": "trá-gi-co",
    "tragicomedia": "tra-gi-co-me-dia",
    "tragicómica": "tra-gi-có-mi-ca",
    "tragicómicamente": "tra-gi-có-mi-ca-men-te",
    "tragicómico": "tra-gi-có-mi-co",
    "trago": "tra-go",
    "tragón": "tra-gón",
    "tragona": "tra-go-na",
    "tragonear": "tra-go-ne-ar",
    "tragonería": "tra-go-ne-rí-a",
    "tragonía": "tra-go-ní-a",
    "tragontina": "tra-gon-ti-na",
    "traguear": "tra-gue-ar",
    "traguilla": "tra-gui-lla",
    "traición": "trai-ción",
    "traicionar": "trai-cio-nar",
    "traicionera": "trai-cio-ne-ra",
    "traicioneramente": "trai-cio-ne-ra-men-te",
    "traicionero": "trai-cio-ne-ro",
    "traída": "tra-í-da",
    "traído": "tra-í-do",
    "traidor": "trai-dor",
    "traidora": "trai-do-ra",
    "traidoramente": "trai-do-ra-men-te",
    "tráiler": "trái-ler",
    "trailera": "trai-le-ra",
    "trailero": "trai-le-ro",
    "traílla": "tra-í-lla",
    "traillar": "trai-llar",
    "traína": "tra-í-na",
    "traíña": "tra-í-ña",
    "trainera": "trai-ne-ra",
    "traite": "trai-te",
    "trajana": "tra-ja-na",
    "trajano": "tra-ja-no",
    "traje": "tra-je",
    "trajeada": "tra-je-a-da",
    "trajeado": "tra-je-a-do",
    "trajear": "tra-je-ar",
    "trajelar": "tra-je-lar",
    "trajín": "tra-jín",
    "trajinante": "tra-ji-nan-te",
    "trajinar": "tra-ji-nar",
    "trajinera": "tra-ji-ne-ra",
    "trajinería": "tra-ji-ne-rí-a",
    "trajinero": "tra-ji-ne-ro",
    "trajino": "tra-ji-no",
    "tralhuén": "tral-huén",
    "tralla": "tra-lla",
    "trallazo": "tra-lla-zo",
    "trama": "tra-ma",
    "tramador": "tra-ma-dor",
    "tramadora": "tra-ma-do-ra",
    "tramar": "tra-mar",
    "tramilla": "tra-mi-lla",
    "tramitación": "tra-mi-ta-ción",
    "tramitador": "tra-mi-ta-dor",
    "tramitadora": "tra-mi-ta-do-ra",
    "tramitar": "tra-mi-tar",
    "trámite": "trá-mi-te",
    "tramitología": "tra-mi-to-lo-gí-a",
    "tramitomanía": "tra-mi-to-ma-ní-a",
    "tramo": "tra-mo",
    "tramojo": "tra-mo-jo",
    "tramontana": "tra-mon-ta-na",
    "tramontano": "tra-mon-ta-no",
    "tramontar": "tra-mon-tar",
    "tramoya": "tra-mo-ya",
    "tramoyista": "tra-mo-yis-ta",
    "tramoyón": "tra-mo-yón",
    "tramoyona": "tra-mo-yo-na",
    "trampa": "tram-pa",
    "trampal": "tram-pal",
    "trampantojo": "tram-pan-to-jo",
    "trampazo": "tram-pa-zo",
    "trampeador": "tram-pe-a-dor",
    "trampeadora": "tram-pe-a-do-ra",
    "trampear": "tram-pe-ar",
    "trampera": "tram-pe-ra",
    "trampería": "tram-pe-rí-a",
    "trampero": "tram-pe-ro",
    "trampilla": "tram-pi-lla",
    "trampista": "tram-pis-ta",
    "trampolín": "tram-po-lín",
    "tramposa": "tram-po-sa",
    "tramposamente": "tram-po-sa-men-te",
    "tramposo": "tram-po-so",
    "trampucheta": "tram-pu-che-ta",
    "tranca": "tran-ca",
    "trancada": "tran-ca-da",
    "trancadera": "tran-ca-de-ra",
    "trancador": "tran-ca-dor",
    "trancahílo": "tran-ca-hí-lo",
    "trancanil": "tran-ca-nil",
    "trancar": "tran-car",
    "trancazo": "tran-ca-zo",
    "trance": "tran-ce",
    "trancelín": "tran-ce-lín",
    "trancha": "tran-cha",
    "tranchea": "tran-che-a",
    "tranchete": "tran-che-te",
    "trancho": "tran-cho",
    "tranco": "tran-co",
    "trancón": "tran-cón",
    "trangallo": "tran-ga-llo",
    "tranque": "tran-que",
    "tranquear": "tran-que-ar",
    "tranquera": "tran-que-ra",
    "tranquero": "tran-que-ro",
    "tranquil": "tran-quil",
    "tranquila": "tran-qui-la",
    "tranquilamente": "tran-qui-la-men-te",
    "tranquilar": "tran-qui-lar",
    "tranquilidad": "tran-qui-li-dad",
    "tranquilización": "tran-qui-li-za-ción",
    "tranquilizador": "tran-qui-li-za-dor",
    "tranquilizadora": "tran-qui-li-za-do-ra",
    "tranquilizante": "tran-qui-li-zan-te",
    "tranquilizar": "tran-qui-li-zar",
    "tranquilla": "tran-qui-lla",
    "tranquillo": "tran-qui-llo",
    "tranquillón": "tran-qui-llón",
    "tranquilo": "tran-qui-lo",
    "tranquiza": "tran-qui-za",
    "transa": "tran-sa",
    "transacción": "tran-sac-ción",
    "transaccional": "tran-sac-cio-nal",
    "transalpina": "tran-sal-pi-na",
    "transalpino": "tran-sal-pi-no",
    "transaminasa": "tran-sa-mi-na-sa",
    "transandina": "tran-san-di-na",
    "transandino": "tran-san-di-no",
    "transar": "tran-sar",
    "transatlántica": "tran-sa-tlán-ti-ca",
    "transatlántico": "tran-sa-tlán-ti-co",
    "transbordador": "trans-bor-da-dor",
    "transbordadora": "trans-bor-da-do-ra",
    "transbordar": "trans-bor-dar",
    "transbordo": "trans-bor-do",
    "transcendencia": "trans-cen-den-cia",
    "transcendental": "trans-cen-den-tal",
    "transcendentalismo": "trans-cen-den-ta-lis-mo",
    "transcender": "trans-cen-der",
    "transcontinental": "trans-con-ti-nen-tal",
    "transcribir": "trans-cri-bir",
    "transcripción": "trans-crip-ción",
    "transcripta": "trans-crip-ta",
    "transcripto": "trans-crip-to",
    "transcriptor": "trans-crip-tor",
    "transcriptora": "trans-crip-to-ra",
    "transcrita": "trans-cri-ta",
    "transcrito": "trans-cri-to",
    "transculturación": "trans-cul-tu-ra-ción",
    "transcultural": "trans-cul-tu-ral",
    "transculturización": "trans-cul-tu-ri-za-ción",
    "transcurrir": "trans-cu-rrir",
    "transcurso": "trans-cur-so",
    "transducción": "trans-duc-ción",
    "transductor": "trans-duc-tor",
    "tránseat": "trán-se-at",
    "transepto": "tran-sep-to",
    "transeúnte": "tran-se-ún-te",
    "transexual": "tran-se-xual",
    "transexualidad": "tran-se-xua-li-dad",
    "transexualismo": "tran-se-xua-lis-mo",
    "transferencia": "trans-fe-ren-cia",
    "transferencial": "trans-fe-ren-cial",
    "transferente": "trans-fe-ren-te",
    "transferible": "trans-fe-ri-ble",
    "transferidor": "trans-fe-ri-dor",
    "transferidora": "trans-fe-ri-do-ra",
    "transferir": "trans-fe-rir",
    "transfigurable": "trans-fi-gu-ra-ble",
    "transfiguración": "trans-fi-gu-ra-ción",
    "transfigurar": "trans-fi-gu-rar",
    "transfija": "trans-fi-ja",
    "transfijo": "trans-fi-jo",
    "transfixión": "trans-fi-xión",
    "transflor": "trans-flor",
    "transflorar": "trans-flo-rar",
    "transflorear": "trans-flo-re-ar",
    "transfocador": "trans-fo-ca-dor",
    "transformable": "trans-for-ma-ble",
    "transformación": "trans-for-ma-ción",
    "transformacional": "trans-for-ma-cio-nal",
    "transformador": "trans-for-ma-dor",
    "transformadora": "trans-for-ma-do-ra",
    "transformamiento": "trans-for-ma-mien-to",
    "transformar": "trans-for-mar",
    "transformativa": "trans-for-ma-ti-va",
    "transformativo": "trans-for-ma-ti-vo",
    "transformismo": "trans-for-mis-mo",
    "transformista": "trans-for-mis-ta",
    "transfregar": "trans-fre-gar",
    "transfretana": "trans-fre-ta-na",
    "transfretano": "trans-fre-ta-no",
    "transfretar": "trans-fre-tar",
    "transfronterizo": "trans-fron-te-ri-zo",
    "tránsfuga": "tráns-fu-ga",
    "tránsfugo": "tráns-fu-go",
    "transfuguismo": "trans-fu-guis-mo",
    "transfundición": "trans-fun-di-ción",
    "transfundir": "trans-fun-dir",
    "transfusible": "trans-fu-si-ble",
    "transfusión": "trans-fu-sión",
    "transfusor": "trans-fu-sor",
    "transfusora": "trans-fu-so-ra",
    "transgangética": "trans-gan-gé-ti-ca",
    "transgangético": "trans-gan-gé-ti-co",
    "transgénico": "trans-gé-ni-co",
    "transgredir": "trans-gre-dir",
    "transgresión": "trans-gre-sión",
    "transgresivo": "trans-gre-si-vo",
    "transgresor": "trans-gre-sor",
    "transgresora": "trans-gre-so-ra",
    "transiberiana": "tran-si-be-ria-na",
    "transiberiano": "tran-si-be-ria-no",
    "transición": "tran-si-ción",
    "transicional": "tran-si-cio-nal",
    "transida": "tran-si-da",
    "transido": "tran-si-do",
    "transigencia": "tran-si-gen-cia",
    "transigente": "tran-si-gen-te",
    "transigir": "tran-si-gir",
    "transilvana": "tran-sil-va-na",
    "transilvano": "tran-sil-va-no",
    "transir": "tran-sir",
    "transistor": "tran-sis-tor",
    "transitable": "tran-si-ta-ble",
    "transitar": "tran-si-tar",
    "transitario": "tran-si-ta-rio",
    "transitiva": "tran-si-ti-va",
    "transitividad": "tran-si-ti-vi-dad",
    "transitivo": "tran-si-ti-vo",
    "tránsito": "trán-si-to",
    "transitoria": "tran-si-to-ria",
    "transitoriamente": "tran-si-to-ria-men-te",
    "transitoriedad": "tran-si-to-rie-dad",
    "transitorio": "tran-si-to-rio",
    "translación": "trans-la-ción",
    "translaticia": "trans-la-ti-cia",
    "translaticiamente": "trans-la-ti-cia-men-te",
    "translaticio": "trans-la-ti-cio",
    "translativa": "trans-la-ti-va",
    "translativo": "trans-la-ti-vo",
    "translimitación": "trans-li-mi-ta-ción",
    "translimitar": "trans-li-mi-tar",
    "transliteración": "trans-li-te-ra-ción",
    "transliterar": "trans-li-te-rar",
    "translúcida": "trans-lú-ci-da",
    "translucidez": "trans-lu-ci-dez",
    "translúcido": "trans-lú-ci-do",
    "transluciente": "trans-lu-cien-te",
    "translucir": "trans-lu-cir",
    "transmarina": "trans-ma-ri-na",
    "transmarino": "trans-ma-ri-no",
    "transmediterráneo": "trans-me-di-te-rrá-ne-o",
    "transmigración": "trans-mi-gra-ción",
    "transmigrar": "trans-mi-grar",
    "transmigratoria": "trans-mi-gra-to-ria",
    "transmigratorio": "trans-mi-gra-to-rio",
    "transmisibilidad": "trans-mi-si-bi-li-dad",
    "transmisible": "trans-mi-si-ble",
    "transmisión": "trans-mi-sión",
    "transmisor": "trans-mi-sor",
    "transmisora": "trans-mi-so-ra",
    "transmitir": "trans-mi-tir",
    "transmontana": "trans-mon-ta-na",
    "transmontano": "trans-mon-ta-no",
    "transmontar": "trans-mon-tar",
    "transmonte": "trans-mon-te",
    "transmortal": "trans-mor-tal",
    "transmudación": "trans-mu-da-ción",
    "transmudamiento": "trans-mu-da-mien-to",
    "transmudar": "trans-mu-dar",
    "transmundana": "trans-mun-da-na",
    "transmundano": "trans-mun-da-no",
    "transmundo": "trans-mun-do",
    "transmutable": "trans-mu-ta-ble",
    "transmutación": "trans-mu-ta-ción",
    "transmutar": "trans-mu-tar",
    "transmutativa": "trans-mu-ta-ti-va",
    "transmutativo": "trans-mu-ta-ti-vo",
    "transmutatoria": "trans-mu-ta-to-ria",
    "transmutatorio": "trans-mu-ta-to-rio",
    "transnacional": "trans-na-cio-nal",
    "transoceánico": "tran-so-ce-á-ni-co",
    "transpacífica": "trans-pa-cí-fi-ca",
    "transpacífico": "trans-pa-cí-fi-co",
    "transpadana": "trans-pa-da-na",
    "transpadano": "trans-pa-da-no",
    "transparencia": "trans-pa-ren-cia",
    "transparentar": "trans-pa-ren-tar",
    "transparente": "trans-pa-ren-te",
    "transparentemente": "trans-pa-ren-te-men-te",
    "transpirable": "trans-pi-ra-ble",
    "transpiración": "trans-pi-ra-ción",
    "transpirar": "trans-pi-rar",
    "transpirenaica": "trans-pi-re-nai-ca",
    "transpirenaico": "trans-pi-re-nai-co",
    "transpolar": "trans-po-lar",
    "transpondedor": "trans-pon-de-dor",
    "transponedor": "trans-po-ne-dor",
    "transponedora": "trans-po-ne-do-ra",
    "transponer": "trans-po-ner",
    "transportable": "trans-por-ta-ble",
    "transportación": "trans-por-ta-ción",
    "transportador": "trans-por-ta-dor",
    "transportadora": "trans-por-ta-do-ra",
    "transportamiento": "trans-por-ta-mien-to",
    "transportar": "trans-por-tar",
    "transporte": "trans-por-te",
    "transportista": "trans-por-tis-ta",
    "transposición": "trans-po-si-ción",
    "transpositiva": "trans-po-si-ti-va",
    "transpositivo": "trans-po-si-ti-vo",
    "transpuesta": "trans-pues-ta",
    "transpuesto": "trans-pues-to",
    "transtiberina": "trans-ti-be-ri-na",
    "transtiberino": "trans-ti-be-ri-no",
    "transubstanciación": "tran-subs-tan-cia-ción",
    "transubstancial": "tran-subs-tan-cial",
    "transubstanciar": "tran-subs-tan-ciar",
    "transuránico": "tran-su-rá-ni-co",
    "transustanciación": "tran-sus-tan-cia-ción",
    "transustancial": "tran-sus-tan-cial",
    "transustanciar": "tran-sus-tan-ciar",
    "transvasar": "trans-va-sar",
    "transvase": "trans-va-se",
    "transverberación": "trans-ver-be-ra-ción",
    "transversa": "trans-ver-sa",
    "transversal": "trans-ver-sal",
    "transversalmente": "trans-ver-sal-men-te",
    "transverso": "trans-ver-so",
    "tranvía": "tran-ví-a",
    "tranviaria": "tran-via-ria",
    "tranviario": "tran-via-rio",
    "tranviero": "tran-vie-ro",
    "tranza": "tran-za",
    "tranzadera": "tran-za-de-ra",
    "tranzado": "tran-za-do",
    "tranzar": "tran-zar",
    "tranzón": "tran-zón",
    "trapa": "tra-pa",
    "trapacear": "tra-pa-ce-ar",
    "trapacera": "tra-pa-ce-ra",
    "trapaceramente": "tra-pa-ce-ra-men-te",
    "trapacería": "tra-pa-ce-rí-a",
    "trapacero": "tra-pa-ce-ro",
    "trapacete": "tra-pa-ce-te",
    "trapacista": "tra-pa-cis-ta",
    "trapajosa": "tra-pa-jo-sa",
    "trapajoso": "tra-pa-jo-so",
    "trápala": "trá-pa-la",
    "trapalear": "tra-pa-le-ar",
    "trapalón": "tra-pa-lón",
    "trapalona": "tra-pa-lo-na",
    "trapatiesta": "tra-pa-ties-ta",
    "trapaza": "tra-pa-za",
    "trapazar": "tra-pa-zar",
    "trape": "tra-pe",
    "trapeada": "tra-pe-a-da",
    "trapeador": "tra-pe-a-dor",
    "trapeadora": "tra-pe-a-do-ra",
    "trapear": "tra-pe-ar",
    "trapecial": "tra-pe-cial",
    "trapecio": "tra-pe-cio",
    "trapecista": "tra-pe-cis-ta",
    "trapense": "tra-pen-se",
    "trapera": "tra-pe-ra",
    "trapería": "tra-pe-rí-a",
    "trapero": "tra-pe-ro",
    "trapezoedro": "tra-pe-zo-e-dro",
    "trapezoidal": "tra-pe-zoi-dal",
    "trapezoide": "tra-pe-zoi-de",
    "trapicar": "tra-pi-car",
    "trapiche": "tra-pi-che",
    "trapichear": "tra-pi-che-ar",
    "trapicheo": "tra-pi-che-o",
    "trapichera": "tra-pi-che-ra",
    "trapichero": "tra-pi-che-ro",
    "trapienta": "tra-pien-ta",
    "trapiento": "tra-pien-to",
    "trapillo": "tra-pi-llo",
    "trapío": "tra-pí-o",
    "trapisonda": "tra-pi-son-da",
    "trapisondear": "tra-pi-son-de-ar",
    "trapisondista": "tra-pi-son-dis-ta",
    "trapitos": "tra-pi-tos",
    "trapo": "tra-po",
    "traque": "tra-que",
    "tráquea": "trá-que-a",
    "traqueal": "tra-que-al",
    "traquear": "tra-que-ar",
    "traqueo": "tra-que-o",
    "traqueotomía": "tra-que-o-to-mí-a",
    "traquetear": "tra-que-te-ar",
    "traqueteo": "tra-que-te-o",
    "traquidazo": "tra-qui-da-zo",
    "traquido": "tra-qui-do",
    "traquínido": "tra-quí-ni-do",
    "traquita": "tra-qui-ta",
    "trarigüe": "tra-ri-güe",
    "traro": "tra-ro",
    "trasabuela": "tra-sa-bue-la",
    "trasabuelo": "tra-sa-bue-lo",
    "trasalcoba": "tra-sal-co-ba",
    "trasalpina": "tra-sal-pi-na",
    "trasalpino": "tra-sal-pi-no",
    "trasaltar": "tra-sal-tar",
    "trasandina": "tra-san-di-na",
    "trasandino": "tra-san-di-no",
    "trasandosca": "tra-san-dos-ca",
    "trasandosco": "tra-san-dos-co",
    "trasañeja": "tra-sa-ñe-ja",
    "trasañejo": "tra-sa-ñe-jo",
    "trasanteanoche": "tra-san-te-a-no-che",
    "trasanteayer": "tra-san-te-a-yer",
    "trasantier": "tra-san-tier",
    "trasatlántica": "tra-sa-tlán-ti-ca",
    "trasatlántico": "tra-sa-tlán-ti-co",
    "trasbarrás": "tras-ba-rrás",
    "trasbocar": "tras-bo-car",
    "trasbordador": "tras-bor-da-dor",
    "trasbordadora": "tras-bor-da-do-ra",
    "trasbordar": "tras-bor-dar",
    "trasbordo": "tras-bor-do",
    "trasca": "tras-ca",
    "trascabo": "tras-ca-bo",
    "trascacho": "tras-ca-cho",
    "trascantón": "tras-can-tón",
    "trascantonada": "tras-can-to-na-da",
    "trascartar": "tras-car-tar",
    "trascartarse": "tras-car-tar-se",
    "trascartón": "tras-car-tón",
    "trascendencia": "tras-cen-den-cia",
    "trascendental": "tras-cen-den-tal",
    "trascendentalismo": "tras-cen-den-ta-lis-mo",
    "trascendentalmente": "tras-cen-den-tal-men-te",
    "trascendente": "tras-cen-den-te",
    "trascender": "tras-cen-der",
    "trascendida": "tras-cen-di-da",
    "trascendido": "tras-cen-di-do",
    "trascocina": "tras-co-ci-na",
    "trascoda": "tras-co-da",
    "trascol": "tras-col",
    "trascolar": "tras-co-lar",
    "trasconejar": "tras-co-ne-jar",
    "trasconejarse": "tras-co-ne-jar-se",
    "trascordar": "tras-cor-dar",
    "trascordarse": "tras-cor-dar-se",
    "trascoro": "tras-co-ro",
    "trascorral": "tras-co-rral",
    "trascorva": "tras-cor-va",
    "trascorvo": "tras-cor-vo",
    "trascribir": "tras-cri-bir",
    "trascripción": "tras-crip-ción",
    "trascripta": "tras-crip-ta",
    "trascripto": "tras-crip-to",
    "trascriptor": "tras-crip-tor",
    "trascriptora": "tras-crip-to-ra",
    "trascrita": "tras-cri-ta",
    "trascrito": "tras-cri-to",
    "trascuarto": "tras-cuar-to",
    "trascuenta": "tras-cuen-ta",
    "trascurrir": "tras-cu-rrir",
    "trascurso": "tras-cur-so",
    "trasdobladura": "tras-do-bla-du-ra",
    "trasdoblar": "tras-do-blar",
    "trasdoblo": "tras-do-blo",
    "trasdós": "tras-dós",
    "trasdosar": "tras-do-sar",
    "trasdosear": "tras-do-se-ar",
    "trasechador": "tra-se-cha-dor",
    "trasechadora": "tra-se-cha-do-ra",
    "trasechar": "tra-se-char",
    "trasegador": "tra-se-ga-dor",
    "trasegadora": "tra-se-ga-do-ra",
    "trasegar": "tra-se-gar",
    "traseñalador": "tra-se-ña-la-dor",
    "traseñaladora": "tra-se-ña-la-do-ra",
    "traseñalar": "tra-se-ña-lar",
    "trasera": "tra-se-ra",
    "trasero": "tra-se-ro",
    "trasferencia": "tras-fe-ren-cia",
    "trasferible": "tras-fe-ri-ble",
    "trasferidor": "tras-fe-ri-dor",
    "trasferidora": "tras-fe-ri-do-ra",
    "trasferir": "tras-fe-rir",
    "trasfigurable": "tras-fi-gu-ra-ble",
    "trasfiguración": "tras-fi-gu-ra-ción",
    "trasfigurar": "tras-fi-gu-rar",
    "trasfija": "tras-fi-ja",
    "trasfijo": "tras-fi-jo",
    "trasfixión": "tras-fi-xión",
    "trasflor": "tras-flor",
    "trasflorar": "tras-flo-rar",
    "trasflorear": "tras-flo-re-ar",
    "trasfollada": "tras-fo-lla-da",
    "trasfollado": "tras-fo-lla-do",
    "trasfollo": "tras-fo-llo",
    "trasfondo": "tras-fon-do",
    "trasformación": "tras-for-ma-ción",
    "trasformador": "tras-for-ma-dor",
    "trasformadora": "tras-for-ma-do-ra",
    "trasformamiento": "tras-for-ma-mien-to",
    "trasformar": "tras-for-mar",
    "trasformativa": "tras-for-ma-ti-va",
    "trasformativo": "tras-for-ma-ti-vo",
    "trasfregar": "tras-fre-gar",
    "trasfretana": "tras-fre-ta-na",
    "trasfretano": "tras-fre-ta-no",
    "trasfretar": "tras-fre-tar",
    "trasfuego": "tras-fue-go",
    "trásfuga": "trás-fu-ga",
    "trásfugo": "trás-fu-go",
    "trasfuguismo": "tras-fu-guis-mo",
    "trasfundición": "tras-fun-di-ción",
    "trasfundir": "tras-fun-dir",
    "trasfusión": "tras-fu-sión",
    "trasfusor": "tras-fu-sor",
    "trasfusora": "tras-fu-so-ra",
    "trasga": "tras-ga",
    "trasgo": "tras-go",
    "trasgredir": "tras-gre-dir",
    "trasgresión": "tras-gre-sión",
    "trasgresivo": "tras-gre-si-vo",
    "trasgresor": "tras-gre-sor",
    "trasgresora": "tras-gre-so-ra",
    "trasguear": "tras-gue-ar",
    "trasguera": "tras-gue-ra",
    "trasguero": "tras-gue-ro",
    "trashoguera": "tras-ho-gue-ra",
    "trashoguero": "tras-ho-gue-ro",
    "trashojar": "tras-ho-jar",
    "trashumación": "tras-hu-ma-ción",
    "trashumancia": "tras-hu-man-cia",
    "trashumante": "tras-hu-man-te",
    "trashumar": "tras-hu-mar",
    "trasiego": "tra-sie-go",
    "trasijada": "tra-si-ja-da",
    "trasijado": "tra-si-ja-do",
    "traslación": "tras-la-ción",
    "trasladable": "tras-la-da-ble",
    "trasladación": "tras-la-da-ción",
    "trasladador": "tras-la-da-dor",
    "trasladadora": "tras-la-da-do-ra",
    "trasladar": "tras-la-dar",
    "traslado": "tras-la-do",
    "traslapar": "tras-la-par",
    "traslapo": "tras-la-po",
    "traslata": "tras-la-ta",
    "traslaticia": "tras-la-ti-cia",
    "traslaticiamente": "tras-la-ti-cia-men-te",
    "traslaticio": "tras-la-ti-cio",
    "traslativa": "tras-la-ti-va",
    "traslativo": "tras-la-ti-vo",
    "traslato": "tras-la-to",
    "trasloar": "tras-lo-ar",
    "traslúcida": "tras-lú-ci-da",
    "traslúcido": "tras-lú-ci-do",
    "trasluciente": "tras-lu-cien-te",
    "traslucimiento": "tras-lu-ci-mien-to",
    "traslucir": "tras-lu-cir",
    "traslumbramiento": "tras-lum-bra-mien-to",
    "traslumbrar": "tras-lum-brar",
    "trasluz": "tras-luz",
    "trasmallo": "tras-ma-llo",
    "trasmañana": "tras-ma-ña-na",
    "trasmañanar": "tras-ma-ña-nar",
    "trasmano": "tras-ma-no",
    "trasmarina": "tras-ma-ri-na",
    "trasmarino": "tras-ma-ri-no",
    "trasmatar": "tras-ma-tar",
    "trasmediterráneo": "tras-me-di-te-rrá-ne-o",
    "trasmerana": "tras-me-ra-na",
    "trasmerano": "tras-me-ra-no",
    "trasmigración": "tras-mi-gra-ción",
    "trasmigrar": "tras-mi-grar",
    "trasminar": "tras-mi-nar",
    "trasmisible": "tras-mi-si-ble",
    "trasmisión": "tras-mi-sión",
    "trasmisor": "tras-mi-sor",
    "trasmisora": "tras-mi-so-ra",
    "trasmitir": "tras-mi-tir",
    "trasmochar": "tras-mo-char",
    "trasmocho": "tras-mo-cho",
    "trasmontana": "tras-mon-ta-na",
    "trasmontano": "tras-mon-ta-no",
    "trasmontar": "tras-mon-tar",
    "trasmudación": "tras-mu-da-ción",
    "trasmudamiento": "tras-mu-da-mien-to",
    "trasmudar": "tras-mu-dar",
    "trasmundano": "tras-mun-da-no",
    "trasmundo": "tras-mun-do",
    "trasmutable": "tras-mu-ta-ble",
    "trasmutación": "tras-mu-ta-ción",
    "trasmutar": "tras-mu-tar",
    "trasmutativa": "tras-mu-ta-ti-va",
    "trasmutativo": "tras-mu-ta-ti-vo",
    "trasmutatoria": "tras-mu-ta-to-ria",
    "trasmutatorio": "tras-mu-ta-to-rio",
    "trasnacional": "tras-na-cio-nal",
    "trasnochada": "tras-no-cha-da",
    "trasnochado": "tras-no-cha-do",
    "trasnochador": "tras-no-cha-dor",
    "trasnochadora": "tras-no-cha-do-ra",
    "trasnochar": "tras-no-char",
    "trasnoche": "tras-no-che",
    "trasnocho": "tras-no-cho",
    "trasnombrar": "tras-nom-brar",
    "trasnominación": "tras-no-mi-na-ción",
    "trasoceánico": "tra-so-ce-á-ni-co",
    "trasoír": "tra-so-ír",
    "trasojada": "tra-so-ja-da",
    "trasojado": "tra-so-ja-do",
    "trasoñar": "tra-so-ñar",
    "trasordinaria": "tra-sor-di-na-ria",
    "trasordinario": "tra-sor-di-na-rio",
    "trasovada": "tra-so-va-da",
    "trasovado": "tra-so-va-do",
    "traspacífico": "tras-pa-cí-fi-co",
    "traspadana": "tras-pa-da-na",
    "traspadano": "tras-pa-da-no",
    "traspalar": "tras-pa-lar",
    "traspalear": "tras-pa-le-ar",
    "traspaleo": "tras-pa-le-o",
    "traspanar": "tras-pa-nar",
    "traspapelar": "tras-pa-pe-lar",
    "trasparecer": "tras-pa-re-cer",
    "trasparencia": "tras-pa-ren-cia",
    "trasparentar": "tras-pa-ren-tar",
    "trasparentarse": "tras-pa-ren-tar-se",
    "trasparente": "tras-pa-ren-te",
    "traspasable": "tras-pa-sa-ble",
    "traspasación": "tras-pa-sa-ción",
    "traspasador": "tras-pa-sa-dor",
    "traspasadora": "tras-pa-sa-do-ra",
    "traspasamiento": "tras-pa-sa-mien-to",
    "traspasar": "tras-pa-sar",
    "traspaso": "tras-pa-so",
    "traspatio": "tras-pa-tio",
    "traspecho": "tras-pe-cho",
    "traspeinar": "tras-pei-nar",
    "traspellar": "tras-pe-llar",
    "traspié": "tras-pié",
    "traspiés": "tras-piés",
    "traspilastra": "tras-pi-las-tra",
    "traspillada": "tras-pi-lla-da",
    "traspillado": "tras-pi-lla-do",
    "traspillar": "tras-pi-llar",
    "traspintar": "tras-pin-tar",
    "traspintarse": "tras-pin-tar-se",
    "traspirable": "tras-pi-ra-ble",
    "traspiración": "tras-pi-ra-ción",
    "traspirar": "tras-pi-rar",
    "traspirenaica": "tras-pi-re-nai-ca",
    "traspirenaico": "tras-pi-re-nai-co",
    "trasplantable": "tras-plan-ta-ble",
    "trasplantación": "tras-plan-ta-ción",
    "trasplantada": "tras-plan-ta-da",
    "trasplantado": "tras-plan-ta-do",
    "trasplantador": "tras-plan-ta-dor",
    "trasplantadora": "tras-plan-ta-do-ra",
    "trasplantar": "tras-plan-tar",
    "trasplante": "tras-plan-te",
    "trasponedor": "tras-po-ne-dor",
    "trasponedora": "tras-po-ne-do-ra",
    "trasponer": "tras-po-ner",
    "traspontín": "tras-pon-tín",
    "trasportación": "tras-por-ta-ción",
    "trasportador": "tras-por-ta-dor",
    "trasportadora": "tras-por-ta-do-ra",
    "trasportamiento": "tras-por-ta-mien-to",
    "trasportar": "tras-por-tar",
    "trasporte": "tras-por-te",
    "trasportín": "tras-por-tín",
    "trasposición": "tras-po-si-ción",
    "traspositiva": "tras-po-si-ti-va",
    "traspositivo": "tras-po-si-ti-vo",
    "traspuesta": "tras-pues-ta",
    "traspuesto": "tras-pues-to",
    "traspuntar": "tras-pun-tar",
    "traspunte": "tras-pun-te",
    "traspuntín": "tras-pun-tín",
    "trasquero": "tras-que-ro",
    "trasquila": "tras-qui-la",
    "trasquilada": "tras-qui-la-da",
    "trasquilado": "tras-qui-la-do",
    "trasquilador": "tras-qui-la-dor",
    "trasquiladura": "tras-qui-la-du-ra",
    "trasquilar": "tras-qui-lar",
    "trasquilimocha": "tras-qui-li-mo-cha",
    "trasquilimocho": "tras-qui-li-mo-cho",
    "trasquilón": "tras-qui-lón",
    "trasroscar": "tras-ros-car",
    "trasroscarse": "tras-ros-car-se",
    "trastabillante": "tras-ta-bi-llan-te",
    "trastabillar": "tras-ta-bi-llar",
    "trastabillón": "tras-ta-bi-llón",
    "trastada": "tras-ta-da",
    "trastajo": "tras-ta-jo",
    "trastamenta": "tras-ta-men-ta",
    "trastazo": "tras-ta-zo",
    "traste": "tras-te",
    "trasteado": "tras-te-a-do",
    "trasteador": "tras-te-a-dor",
    "trasteadora": "tras-te-a-do-ra",
    "trastear": "tras-te-ar",
    "trastejador": "tras-te-ja-dor",
    "trastejadora": "tras-te-ja-do-ra",
    "trastejadura": "tras-te-ja-du-ra",
    "trastejar": "tras-te-jar",
    "trastejo": "tras-te-jo",
    "trasteo": "tras-te-o",
    "trastera": "tras-te-ra",
    "trastería": "tras-te-rí-a",
    "trastero": "tras-te-ro",
    "trastesada": "tras-te-sa-da",
    "trastesado": "tras-te-sa-do",
    "trastesar": "tras-te-sar",
    "trastesón": "tras-te-són",
    "trastiberina": "tras-ti-be-ri-na",
    "trastiberino": "tras-ti-be-ri-no",
    "trastienda": "tras-tien-da",
    "trasto": "tras-to",
    "trastocar": "tras-to-car",
    "trastornable": "tras-tor-na-ble",
    "trastornador": "tras-tor-na-dor",
    "trastornadora": "tras-tor-na-do-ra",
    "trastornadura": "tras-tor-na-du-ra",
    "trastornamiento": "tras-tor-na-mien-to",
    "trastornar": "tras-tor-nar",
    "trastorno": "tras-tor-no",
    "trastrabada": "tras-tra-ba-da",
    "trastrabado": "tras-tra-ba-do",
    "trastrabar": "tras-tra-bar",
    "trastrabarse": "tras-tra-bar-se",
    "trastrabillar": "tras-tra-bi-llar",
    "trastrás": "tras-trás",
    "trastrocamiento": "tras-tro-ca-mien-to",
    "trastrocar": "tras-tro-car",
    "trastrueco": "tras-true-co",
    "trastrueque": "tras-true-que",
    "trastulo": "tras-tu-lo",
    "trastumbar": "tras-tum-bar",
    "trasudación": "tra-su-da-ción",
    "trasudadamente": "tra-su-da-da-men-te",
    "trasudado": "tra-su-da-do",
    "trasudar": "tra-su-dar",
    "trasudor": "tra-su-dor",
    "trasuntar": "tra-sun-tar",
    "trasuntivamente": "tra-sun-ti-va-men-te",
    "trasunto": "tra-sun-to",
    "trasvasar": "tras-va-sar",
    "trasvase": "tras-va-se",
    "trasvasijo": "tras-va-si-jo",
    "trasvenar": "tras-ve-nar",
    "trasvenarse": "tras-ve-nar-se",
    "trasver": "tras-ver",
    "trasverberación": "tras-ver-be-ra-ción",
    "trasversa": "tras-ver-sa",
    "trasversal": "tras-ver-sal",
    "trasverso": "tras-ver-so",
    "trasverter": "tras-ver-ter",
    "trasvinar": "tras-vi-nar",
    "trasvinarse": "tras-vi-nar-se",
    "trasvolar": "tras-vo-lar",
    "trata": "tra-ta",
    "tratable": "tra-ta-ble",
    "tratada": "tra-ta-da",
    "tratadista": "tra-ta-dis-ta",
    "tratadística": "tra-ta-dís-ti-ca",
    "tratado": "tra-ta-do",
    "tratador": "tra-ta-dor",
    "tratadora": "tra-ta-do-ra",
    "tratamiento": "tra-ta-mien-to",
    "tratante": "tra-tan-te",
    "tratar": "tra-tar",
    "tratativa": "tra-ta-ti-va",
    "trato": "tra-to",
    "trattoria": "trat-to-ria",
    "trauco": "trau-co",
    "trauma": "trau-ma",
    "traumada": "trau-ma-da",
    "traumado": "trau-ma-do",
    "traumar": "trau-mar",
    "traumática": "trau-má-ti-ca",
    "traumáticamente": "trau-má-ti-ca-men-te",
    "traumático": "trau-má-ti-co",
    "traumatismo": "trau-ma-tis-mo",
    "traumatizada": "trau-ma-ti-za-da",
    "traumatizado": "trau-ma-ti-za-do",
    "traumatizante": "trau-ma-ti-zan-te",
    "traumatizar": "trau-ma-ti-zar",
    "traumatóloga": "trau-ma-tó-lo-ga",
    "traumatología": "trau-ma-to-lo-gí-a",
    "traumatológico": "trau-ma-to-ló-gi-co",
    "traumatólogo": "trau-ma-tó-lo-go",
    "travelín": "tra-ve-lín",
    "traversa": "tra-ver-sa",
    "través": "tra-vés",
    "travesaña": "tra-ve-sa-ña",
    "travesaño": "tra-ve-sa-ño",
    "travesar": "tra-ve-sar",
    "travesear": "tra-ve-se-ar",
    "travesera": "tra-ve-se-ra",
    "travesero": "tra-ve-se-ro",
    "travesía": "tra-ve-sí-a",
    "travesío": "tra-ve-sí-o",
    "travesti": "tra-ves-ti",
    "travestí": "tra-ves-tí",
    "travestida": "tra-ves-ti-da",
    "travestido": "tra-ves-ti-do",
    "travestir": "tra-ves-tir",
    "travestismo": "tra-ves-tis-mo",
    "travestista": "tra-ves-tis-ta",
    "travesura": "tra-ve-su-ra",
    "traviesa": "tra-vie-sa",
    "traviesamente": "tra-vie-sa-men-te",
    "travieso": "tra-vie-so",
    "travo": "tra-vo",
    "trayecto": "tra-yec-to",
    "trayectoria": "tra-yec-to-ria",
    "traza": "tra-za",
    "trazable": "tra-za-ble",
    "trazada": "tra-za-da",
    "trazado": "tra-za-do",
    "trazador": "tra-za-dor",
    "trazadora": "tra-za-do-ra",
    "trazar": "tra-zar",
    "trazo": "tra-zo",
    "trazumar": "tra-zu-mar",
    "treballa": "tre-ba-lla",
    "trébede": "tré-be-de",
    "trébedes": "tré-be-des",
    "trebejar": "tre-be-jar",
    "trebejo": "tre-be-jo",
    "trebeliánica": "tre-be-liá-ni-ca",
    "trebentina": "tre-ben-ti-na",
    "trebo": "tre-bo",
    "trébol": "tré-bol",
    "trebolar": "tre-bo-lar",
    "trece": "tre-ce",
    "treceavo": "tre-ce-a-vo",
    "trecemesina": "tre-ce-me-si-na",
    "trecemesino": "tre-ce-me-si-no",
    "trecén": "tre-cén",
    "trecena": "tre-ce-na",
    "trecenario": "tre-ce-na-rio",
    "trecenato": "tre-ce-na-to",
    "trecenazgo": "tre-ce-naz-go",
    "treceno": "tre-ce-no",
    "trecentista": "tre-cen-tis-ta",
    "trecésima": "tre-cé-si-ma",
    "trecésimo": "tre-cé-si-mo",
    "trecha": "tre-cha",
    "trecheador": "tre-che-a-dor",
    "trechear": "tre-che-ar",
    "trechel": "tre-chel",
    "trecheo": "tre-che-o",
    "trecho": "tre-cho",
    "trechor": "tre-chor",
    "trecientas": "tre-cien-tas",
    "trecientos": "tre-cien-tos",
    "tredécima": "tre-dé-ci-ma",
    "tredécimo": "tre-dé-ci-mo",
    "trefe": "tre-fe",
    "trefedad": "tre-fe-dad",
    "trefilado": "tre-fi-la-do",
    "trefilar": "tre-fi-lar",
    "trefilería": "tre-fi-le-rí-a",
    "tregua": "tre-gua",
    "treílla": "tre-í-lla",
    "treinta": "trein-ta",
    "treintaidosava": "trein-tai-do-sa-va",
    "treintaidosavo": "trein-tai-do-sa-vo",
    "treintaidosena": "trein-tai-do-se-na",
    "treintaidoseno": "trein-tai-do-se-no",
    "treintaitresino": "trein-tai-tre-si-no",
    "treintañal": "trein-ta-ñal",
    "treintanario": "trein-ta-na-rio",
    "treintañera": "trein-ta-ñe-ra",
    "treintañero": "trein-ta-ñe-ro",
    "treintava": "trein-ta-va",
    "treintavo": "trein-ta-vo",
    "treintena": "trein-te-na",
    "treintenario": "trein-te-na-rio",
    "treinteno": "trein-te-no",
    "treintón": "trein-tón",
    "treintona": "trein-to-na",
    "treja": "tre-ja",
    "trekking": "trek-king",
    "tremadal": "tre-ma-dal",
    "tremar": "tre-mar",
    "trematodo": "tre-ma-to-do",
    "tremble": "trem-ble",
    "tremebunda": "tre-me-bun-da",
    "tremebundo": "tre-me-bun-do",
    "tremedal": "tre-me-dal",
    "tremenda": "tre-men-da",
    "tremendamente": "tre-men-da-men-te",
    "tremendismo": "tre-men-dis-mo",
    "tremendista": "tre-men-dis-ta",
    "tremendo": "tre-men-do",
    "trementina": "tre-men-ti-na",
    "tremer": "tre-mer",
    "tremés": "tre-més",
    "tremesina": "tre-me-si-na",
    "tremesino": "tre-me-si-no",
    "tremielga": "tre-miel-ga",
    "tremís": "tre-mís",
    "tremó": "tre-mó",
    "tremol": "tre-mol",
    "trémol": "tré-mol",
    "tremolante": "tre-mo-lan-te",
    "tremolar": "tre-mo-lar",
    "tremolín": "tre-mo-lín",
    "tremolina": "tre-mo-li-na",
    "trémolo": "tré-mo-lo",
    "tremor": "tre-mor",
    "tremosa": "tre-mo-sa",
    "tremoso": "tre-mo-so",
    "trémula": "tré-mu-la",
    "trémulamente": "tré-mu-la-men-te",
    "tremulante": "tre-mu-lan-te",
    "tremulenta": "tre-mu-len-ta",
    "tremulento": "tre-mu-len-to",
    "trémulo": "tré-mu-lo",
    "tremulosa": "tre-mu-lo-sa",
    "tremuloso": "tre-mu-lo-so",
    "trena": "tre-na",
    "trenada": "tre-na-da",
    "trenado": "tre-na-do",
    "trenca": "tren-ca",
    "trencellín": "tren-ce-llín",
    "trencilla": "tren-ci-lla",
    "trencillar": "tren-ci-llar",
    "trencillo": "tren-ci-llo",
    "trencito": "tren-ci-to",
    "trenista": "tre-nis-ta",
    "treno": "tre-no",
    "trenque": "tren-que",
    "trente": "tren-te",
    "trentena": "tren-te-na",
    "trenteno": "tren-te-no",
    "trentino": "tren-ti-no",
    "trenza": "tren-za",
    "trenzadera": "tren-za-de-ra",
    "trenzado": "tren-za-do",
    "trenzar": "tren-zar",
    "treo": "tre-o",
    "trepa": "tre-pa",
    "trepada": "tre-pa-da",
    "trepadera": "tre-pa-de-ra",
    "trepado": "tre-pa-do",
    "trepador": "tre-pa-dor",
    "trepadora": "tre-pa-do-ra",
    "trepajuncos": "tre-pa-jun-cos",
    "trepanación": "tre-pa-na-ción",
    "trepanar": "tre-pa-nar",
    "trépano": "tré-pa-no",
    "trepante": "tre-pan-te",
    "trepar": "tre-par",
    "treparriscos": "tre-pa-rris-cos",
    "treparse": "tre-par-se",
    "trepatroncos": "tre-pa-tron-cos",
    "trepe": "tre-pe",
    "trépida": "tré-pi-da",
    "trepidación": "tre-pi-da-ción",
    "trepidante": "tre-pi-dan-te",
    "trepidar": "tre-pi-dar",
    "trépido": "tré-pi-do",
    "trepolina": "tre-po-li-na",
    "treponema": "tre-po-ne-ma",
    "tresalba": "tre-sal-ba",
    "tresalbo": "tre-sal-bo",
    "tresañal": "tre-sa-ñal",
    "tresañeja": "tre-sa-ñe-ja",
    "tresañejo": "tre-sa-ñe-jo",
    "tresbolillo": "tres-bo-li-llo",
    "trescientas": "tres-cien-tas",
    "trescientos": "tres-cien-tos",
    "tresdoblar": "tres-do-blar",
    "tresdoble": "tres-do-ble",
    "tresillista": "tre-si-llis-ta",
    "tresillo": "tre-si-llo",
    "tresmesina": "tres-me-si-na",
    "tresmesino": "tres-me-si-no",
    "tresna": "tres-na",
    "tresnal": "tres-nal",
    "tresnar": "tres-nar",
    "trespuños": "tres-pu-ños",
    "tresquilón": "tres-qui-lón",
    "trestanto": "tres-tan-to",
    "trestiga": "tres-ti-ga",
    "treta": "tre-ta",
    "tretera": "tre-te-ra",
    "tretero": "tre-te-ro",
    "trezava": "tre-za-va",
    "trezavo": "tre-za-vo",
    "trezna": "trez-na",
    "tría": "trí-a",
    "triaca": "tria-ca",
    "triacal": "tria-cal",
    "triache": "tria-che",
    "tríada": "trí-a-da",
    "tríade": "trí-a-de",
    "triádico": "triá-di-co",
    "trianera": "tria-ne-ra",
    "trianero": "tria-ne-ro",
    "triangulación": "trian-gu-la-ción",
    "triangular": "trian-gu-lar",
    "triangularmente": "trian-gu-lar-men-te",
    "triángulo": "trián-gu-lo",
    "triaquera": "tria-que-ra",
    "triaquero": "tria-que-ro",
    "triario": "tria-rio",
    "triásica": "triá-si-ca",
    "triásico": "triá-si-co",
    "triate": "tria-te",
    "triatleta": "tria-tle-ta",
    "triatlón": "tria-tlón",
    "tribada": "tri-ba-da",
    "tríbada": "trí-ba-da",
    "tríbade": "trí-ba-de",
    "tribadismo": "tri-ba-dis-mo",
    "tribal": "tri-bal",
    "tribalismo": "tri-ba-lis-mo",
    "tribalmente": "tri-bal-men-te",
    "triboelectricidad": "tri-bo-e-lec-tri-ci-dad",
    "tribología": "tri-bo-lo-gí-a",
    "triboluminiscencia": "tri-bo-lu-mi-nis-cen-cia",
    "tribómetro": "tri-bó-me-tro",
    "tribraquio": "tri-bra-quio",
    "tribu": "tri-bu",
    "tribual": "tri-bual",
    "tribuir": "tri-buir",
    "tribulación": "tri-bu-la-ción",
    "tribulanza": "tri-bu-lan-za",
    "tribular": "tri-bu-lar",
    "tríbulo": "trí-bu-lo",
    "tribuna": "tri-bu-na",
    "tribunado": "tri-bu-na-do",
    "tribunal": "tri-bu-nal",
    "tribúnica": "tri-bú-ni-ca",
    "tribunicia": "tri-bu-ni-cia",
    "tribunicio": "tri-bu-ni-cio",
    "tribúnico": "tri-bú-ni-co",
    "tribuno": "tri-bu-no",
    "tributable": "tri-bu-ta-ble",
    "tributación": "tri-bu-ta-ción",
    "tributante": "tri-bu-tan-te",
    "tributar": "tri-bu-tar",
    "tributaria": "tri-bu-ta-ria",
    "tributario": "tri-bu-ta-rio",
    "tributo": "tri-bu-to",
    "tricahue": "tri-ca-hue",
    "tricampeón": "tri-cam-pe-ón",
    "tricampeona": "tri-cam-pe-o-na",
    "tricefalia": "tri-ce-fa-lia",
    "tricéfalo": "tri-cé-fa-lo",
    "tricenal": "tri-ce-nal",
    "tricentenario": "tri-cen-te-na-rio",
    "tricentésima": "tri-cen-té-si-ma",
    "tricentésimo": "tri-cen-té-si-mo",
    "tríceps": "trí-ceps",
    "triceratops": "tri-ce-ra-tops",
    "tricésima": "tri-cé-si-ma",
    "tricésimo": "tri-cé-si-mo",
    "triciclo": "tri-ci-clo",
    "tricípite": "tri-cí-pi-te",
    "triclínico": "tri-clí-ni-co",
    "triclinio": "tri-cli-nio",
    "tricloruro": "tri-clo-ru-ro",
    "tricocéfalo": "tri-co-cé-fa-lo",
    "tricolor": "tri-co-lor",
    "tricorne": "tri-cor-ne",
    "tricornio": "tri-cor-nio",
    "tricos": "tri-cos",
    "tricot": "tri-cot",
    "tricota": "tri-co-ta",
    "tricotadora": "tri-co-ta-do-ra",
    "tricotar": "tri-co-tar",
    "tricótoma": "tri-có-to-ma",
    "tricotomía": "tri-co-to-mí-a",
    "tricotómica": "tri-co-tó-mi-ca",
    "tricotómico": "tri-co-tó-mi-co",
    "tricótomo": "tri-có-to-mo",
    "tricotosa": "tri-co-to-sa",
    "tricromía": "tri-cro-mí-a",
    "tricúspide": "tri-cús-pi-de",
    "tridacio": "tri-da-cio",
    "tridente": "tri-den-te",
    "tridentífera": "tri-den-tí-fe-ra",
    "tridentífero": "tri-den-tí-fe-ro",
    "tridentina": "tri-den-ti-na",
    "tridentinamente": "tri-den-ti-na-men-te",
    "tridentino": "tri-den-ti-no",
    "tridimensional": "tri-di-men-sio-nal",
    "tridimensionalidad": "tri-di-men-sio-na-li-dad",
    "tridimensionalmente": "tri-di-men-sio-nal-men-te",
    "triduana": "tri-dua-na",
    "triduano": "tri-dua-no",
    "triduo": "tri-duo",
    "triedro": "trie-dro",
    "trienal": "trie-nal",
    "trieñal": "trie-ñal",
    "trienio": "trie-nio",
    "triente": "trien-te",
    "triestina": "tries-ti-na",
    "triestino": "tries-ti-no",
    "trifásica": "tri-fá-si-ca",
    "trifásico": "tri-fá-si-co",
    "trifauce": "tri-fau-ce",
    "trífida": "trí-fi-da",
    "trífido": "trí-fi-do",
    "trifinio": "tri-fi-nio",
    "triflora": "tri-flo-ra",
    "trifloro": "tri-flo-ro",
    "trifoliada": "tri-fo-lia-da",
    "trifoliado": "tri-fo-lia-do",
    "trifolio": "tri-fo-lio",
    "triforio": "tri-fo-rio",
    "triforme": "tri-for-me",
    "trifulca": "tri-ful-ca",
    "trifurcación": "tri-fur-ca-ción",
    "trifurcada": "tri-fur-ca-da",
    "trifurcado": "tri-fur-ca-do",
    "trifurcar": "tri-fur-car",
    "trifurcarse": "tri-fur-car-se",
    "triga": "tri-ga",
    "trigal": "tri-gal",
    "trigaza": "tri-ga-za",
    "trigémino": "tri-gé-mi-no",
    "trigésima": "tri-gé-si-ma",
    "trigésimo": "tri-gé-si-mo",
    "trigla": "tri-gla",
    "triglicérido": "tri-gli-cé-ri-do",
    "triglifo": "tri-gli-fo",
    "tríglifo": "trí-gli-fo",
    "trigo": "tri-go",
    "trigón": "tri-gón",
    "trigonal": "tri-go-nal",
    "trígono": "trí-go-no",
    "trigonometría": "tri-go-no-me-trí-a",
    "trigonométrica": "tri-go-no-mé-tri-ca",
    "trigonométrico": "tri-go-no-mé-tri-co",
    "trigueña": "tri-gue-ña",
    "trigueño": "tri-gue-ño",
    "triguera": "tri-gue-ra",
    "triguero": "tri-gue-ro",
    "triguillo": "tri-gui-llo",
    "trilátera": "tri-lá-te-ra",
    "trilateral": "tri-la-te-ral",
    "trilátero": "tri-lá-te-ro",
    "trile": "tri-le",
    "trilera": "tri-le-ra",
    "trilero": "tri-le-ro",
    "triles": "tri-les",
    "trilingüe": "tri-lin-güe",
    "trilita": "tri-li-ta",
    "trilítera": "tri-lí-te-ra",
    "trilítero": "tri-lí-te-ro",
    "trilito": "tri-li-to",
    "trilla": "tri-lla",
    "trillada": "tri-lla-da",
    "trilladera": "tri-lla-de-ra",
    "trillado": "tri-lla-do",
    "trillador": "tri-lla-dor",
    "trilladora": "tri-lla-do-ra",
    "trilladura": "tri-lla-du-ra",
    "trillar": "tri-llar",
    "trillique": "tri-lli-que",
    "trilliza": "tri-lli-za",
    "trillizo": "tri-lli-zo",
    "trillo": "tri-llo",
    "trillón": "tri-llón",
    "trillonésima": "tri-llo-né-si-ma",
    "trillonésimo": "tri-llo-né-si-mo",
    "trilobites": "tri-lo-bi-tes",
    "trilobulada": "tri-lo-bu-la-da",
    "trilobulado": "tri-lo-bu-la-do",
    "trilocular": "tri-lo-cu-lar",
    "trilogía": "tri-lo-gí-a",
    "trimarán": "tri-ma-rán",
    "trimembre": "tri-mem-bre",
    "trimensual": "tri-men-sual",
    "trímero": "trí-me-ro",
    "trimestral": "tri-mes-tral",
    "trimestralmente": "tri-mes-tral-men-te",
    "trimestre": "tri-mes-tre",
    "trímetro": "trí-me-tro",
    "trimielga": "tri-miel-ga",
    "trimotor": "tri-mo-tor",
    "trimurti": "tri-mur-ti",
    "trina": "tri-na",
    "trinacria": "tri-na-cria",
    "trinacrio": "tri-na-crio",
    "trinado": "tri-na-do",
    "trinar": "tri-nar",
    "trinca": "trin-ca",
    "trincado": "trin-ca-do",
    "trincadura": "trin-ca-du-ra",
    "trincaesquinas": "trin-ca-es-qui-nas",
    "trincafía": "trin-ca-fí-a",
    "trincapiñones": "trin-ca-pi-ño-nes",
    "trincar": "trin-car",
    "trincha": "trin-cha",
    "trinchador": "trin-cha-dor",
    "trinchadora": "trin-cha-do-ra",
    "trinchante": "trin-chan-te",
    "trinchar": "trin-char",
    "trinche": "trin-che",
    "trinchea": "trin-che-a",
    "trincheo": "trin-che-o",
    "trinchera": "trin-che-ra",
    "trinchero": "trin-che-ro",
    "trincheta": "trin-che-ta",
    "trinchete": "trin-che-te",
    "trineo": "tri-ne-o",
    "trinidad": "tri-ni-dad",
    "trinitaria": "tri-ni-ta-ria",
    "trinitario": "tri-ni-ta-rio",
    "trinitense": "tri-ni-ten-se",
    "trinitrotolueno": "tri-ni-tro-to-lue-no",
    "trino": "tri-no",
    "trinomio": "tri-no-mio",
    "trinquetada": "trin-que-ta-da",
    "trinquete": "trin-que-te",
    "trinquetero": "trin-que-te-ro",
    "trinquetilla": "trin-que-ti-lla",
    "trinquis": "trin-quis",
    "trío": "trí-o",
    "triodo": "trio-do",
    "trióxido": "trió-xi-do",
    "tripa": "tri-pa",
    "tripada": "tri-pa-da",
    "tripanosoma": "tri-pa-no-so-ma",
    "tripanosomiasis": "tri-pa-no-so-mia-sis",
    "tripartición": "tri-par-ti-ción",
    "tripartir": "tri-par-tir",
    "tripartita": "tri-par-ti-ta",
    "tripartitamente": "tri-par-ti-ta-men-te",
    "tripartito": "tri-par-ti-to",
    "tripastos": "tri-pas-tos",
    "tripe": "tri-pe",
    "tripear": "tri-pe-ar",
    "tripera": "tri-pe-ra",
    "tripería": "tri-pe-rí-a",
    "tripero": "tri-pe-ro",
    "tripi": "tri-pi",
    "tripicallera": "tri-pi-ca-lle-ra",
    "tripicallero": "tri-pi-ca-lle-ro",
    "tripicallos": "tri-pi-ca-llos",
    "tripicario": "tri-pi-ca-rio",
    "tripié": "tri-pié",
    "trípili": "trí-pi-li",
    "tripitas": "tri-pi-tas",
    "tripla": "tri-pla",
    "triplano": "tri-pla-no",
    "triple": "tri-ple",
    "triplemente": "tri-ple-men-te",
    "tripleta": "tri-ple-ta",
    "triplete": "tri-ple-te",
    "tríplex": "trí-plex",
    "triplicación": "tri-pli-ca-ción",
    "triplicado": "tri-pli-ca-do",
    "triplicar": "tri-pli-car",
    "tríplice": "trí-pli-ce",
    "triplicidad": "tri-pli-ci-dad",
    "triplo": "tri-plo",
    "trípode": "trí-po-de",
    "trípol": "trí-pol",
    "trípoli": "trí-po-li",
    "tripolina": "tri-po-li-na",
    "tripolino": "tri-po-li-no",
    "tripolitana": "tri-po-li-ta-na",
    "tripolitano": "tri-po-li-ta-no",
    "tripollas": "tri-po-llas",
    "tripón": "tri-pón",
    "tripona": "tri-po-na",
    "tripsina": "trip-si-na",
    "tríptico": "tríp-ti-co",
    "triptófano": "trip-tó-fa-no",
    "triptongar": "trip-ton-gar",
    "triptongo": "trip-ton-go",
    "tripuda": "tri-pu-da",
    "tripudiar": "tri-pu-diar",
    "tripudio": "tri-pu-dio",
    "tripudo": "tri-pu-do",
    "tripulación": "tri-pu-la-ción",
    "tripulante": "tri-pu-lan-te",
    "tripular": "tri-pu-lar",
    "tripulina": "tri-pu-li-na",
    "trique": "tri-que",
    "triquete": "tri-que-te",
    "triquina": "tri-qui-na",
    "triquinosis": "tri-qui-no-sis",
    "triquiñuela": "tri-qui-ñue-la",
    "triquis": "tri-quis",
    "triquitraque": "tri-qui-tra-que",
    "triquitraqui": "tri-qui-tra-qui",
    "trirrectángulo": "tri-rrec-tán-gu-lo",
    "trirreme": "tri-rre-me",
    "trisa": "tri-sa",
    "trisagio": "tri-sa-gio",
    "trisar": "tri-sar",
    "trisca": "tris-ca",
    "triscado": "tris-ca-do",
    "triscador": "tris-ca-dor",
    "triscadora": "tris-ca-do-ra",
    "triscar": "tris-car",
    "trisecar": "tri-se-car",
    "trisección": "tri-sec-ción",
    "trisemanal": "tri-se-ma-nal",
    "trisílaba": "tri-sí-la-ba",
    "trisilábico": "tri-si-lá-bi-co",
    "trisílabo": "tri-sí-la-bo",
    "trismo": "tris-mo",
    "trisomía": "tri-so-mí-a",
    "trispasto": "tris-pas-to",
    "trisque": "tris-que",
    "triste": "tris-te",
    "tristemente": "tris-te-men-te",
    "tristeza": "tris-te-za",
    "tristón": "tris-tón",
    "tristona": "tris-to-na",
    "tristor": "tris-tor",
    "tristura": "tris-tu-ra",
    "trisulca": "tri-sul-ca",
    "trisulco": "tri-sul-co",
    "tritícea": "tri-tí-ce-a",
    "tritíceo": "tri-tí-ce-o",
    "tritio": "tri-tio",
    "tritón": "tri-tón",
    "trítono": "trí-to-no",
    "tritóxido": "tri-tó-xi-do",
    "triturable": "tri-tu-ra-ble",
    "trituración": "tri-tu-ra-ción",
    "triturador": "tri-tu-ra-dor",
    "trituradora": "tri-tu-ra-do-ra",
    "triturar": "tri-tu-rar",
    "triunfador": "triun-fa-dor",
    "triunfadora": "triun-fa-do-ra",
    "triunfal": "triun-fal",
    "triunfalismo": "triun-fa-lis-mo",
    "triunfalista": "triun-fa-lis-ta",
    "triunfalmente": "triun-fal-men-te",
    "triunfante": "triun-fan-te",
    "triunfantemente": "triun-fan-te-men-te",
    "triunfar": "triun-far",
    "triunfo": "triun-fo",
    "triunviral": "triun-vi-ral",
    "triunvirato": "triun-vi-ra-to",
    "triunviro": "triun-vi-ro",
    "trivalente": "tri-va-len-te",
    "trivial": "tri-vial",
    "trivialidad": "tri-via-li-dad",
    "trivialización": "tri-via-li-za-ción",
    "trivializar": "tri-via-li-zar",
    "trivialmente": "tri-vial-men-te",
    "trivio": "tri-vio",
    "trívium": "trí-vium",
    "triza": "tri-za",
    "trizar": "tri-zar",
    "troca": "tro-ca",
    "trocable": "tro-ca-ble",
    "trocada": "tro-ca-da",
    "trocadamente": "tro-ca-da-men-te",
    "trocadilla": "tro-ca-di-lla",
    "trocado": "tro-ca-do",
    "trocador": "tro-ca-dor",
    "trocadora": "tro-ca-do-ra",
    "trocaica": "tro-cai-ca",
    "trocaico": "tro-cai-co",
    "trocamiento": "tro-ca-mien-to",
    "trocánter": "tro-cán-ter",
    "trocar": "tro-car",
    "trocatinta": "tro-ca-tin-ta",
    "trocatinte": "tro-ca-tin-te",
    "troceado": "tro-ce-a-do",
    "trocear": "tro-ce-ar",
    "troceo": "tro-ce-o",
    "trocha": "tro-cha",
    "trochemoche": "tro-che-mo-che",
    "trocir": "tro-cir",
    "trociscar": "tro-cis-car",
    "trocisco": "tro-cis-co",
    "trocla": "tro-cla",
    "tróclea": "tró-cle-a",
    "troco": "tro-co",
    "trocoide": "tro-coi-de",
    "trócola": "tró-co-la",
    "trofeo": "tro-fe-o",
    "trófica": "tró-fi-ca",
    "trófico": "tró-fi-co",
    "trofoblasto": "tro-fo-blas-to",
    "trofóloga": "tro-fó-lo-ga",
    "trofología": "tro-fo-lo-gí-a",
    "trofólogo": "tro-fó-lo-go",
    "troglodita": "tro-glo-di-ta",
    "troglodítica": "tro-glo-dí-ti-ca",
    "troglodítico": "tro-glo-dí-ti-co",
    "troica": "troi-ca",
    "troika": "troi-ka",
    "troja": "tro-ja",
    "trojada": "tro-ja-da",
    "trojado": "tro-ja-do",
    "troje": "tro-je",
    "trojel": "tro-jel",
    "trojera": "tro-je-ra",
    "trojero": "tro-je-ro",
    "trojezada": "tro-je-za-da",
    "trojezado": "tro-je-za-do",
    "trola": "tro-la",
    "trole": "tro-le",
    "troleada": "tro-le-a-da",
    "trolebús": "tro-le-bús",
    "trolera": "tro-le-ra",
    "trolero": "tro-le-ro",
    "trolla": "tro-lla",
    "trolo": "tro-lo",
    "tromba": "trom-ba",
    "trombina": "trom-bi-na",
    "trombo": "trom-bo",
    "tromboangitis": "trom-bo-an-gi-tis",
    "trombocito": "trom-bo-ci-to",
    "tromboflebitis": "trom-bo-fle-bi-tis",
    "trombón": "trom-bón",
    "trombonista": "trom-bo-nis-ta",
    "tromboplastina": "trom-bo-plas-ti-na",
    "trombosis": "trom-bo-sis",
    "trompa": "trom-pa",
    "trompabulario": "trom-pa-bu-la-rio",
    "trompada": "trom-pa-da",
    "trompar": "trom-par",
    "trompazo": "trom-pa-zo",
    "trompeada": "trom-pe-a-da",
    "trompear": "trom-pe-ar",
    "trompera": "trom-pe-ra",
    "trompero": "trom-pe-ro",
    "trompeta": "trom-pe-ta",
    "trompetada": "trom-pe-ta-da",
    "trompetazo": "trom-pe-ta-zo",
    "trompetear": "trom-pe-te-ar",
    "trompeteo": "trom-pe-te-o",
    "trompetera": "trom-pe-te-ra",
    "trompetería": "trom-pe-te-rí-a",
    "trompetero": "trom-pe-te-ro",
    "trompetilla": "trom-pe-ti-lla",
    "trompetista": "trom-pe-tis-ta",
    "trompeto": "trom-pe-to",
    "trompicadero": "trom-pi-ca-de-ro",
    "trompicar": "trom-pi-car",
    "trompico": "trom-pi-co",
    "trompicón": "trom-pi-cón",
    "trompilla": "trom-pi-lla",
    "trompilladura": "trom-pi-lla-du-ra",
    "trompillar": "trom-pi-llar",
    "trompillo": "trom-pi-llo",
    "trompillón": "trom-pi-llón",
    "trompis": "trom-pis",
    "trompiza": "trom-pi-za",
    "trompo": "trom-po",
    "trompón": "trom-pón",
    "trompuda": "trom-pu-da",
    "trompudo": "trom-pu-do",
    "trona": "tro-na",
    "tronada": "tro-na-da",
    "tronadera": "tro-na-de-ra",
    "tronado": "tro-na-do",
    "tronador": "tro-na-dor",
    "tronadora": "tro-na-do-ra",
    "tronadura": "tro-na-du-ra",
    "tronancina": "tro-nan-ci-na",
    "tronar": "tro-nar",
    "tronca": "tron-ca",
    "troncal": "tron-cal",
    "troncalidad": "tron-ca-li-dad",
    "troncar": "tron-car",
    "troncha": "tron-cha",
    "tronchado": "tron-cha-do",
    "tronchante": "tron-chan-te",
    "tronchar": "tron-char",
    "tronchazo": "tron-cha-zo",
    "troncho": "tron-cho",
    "tronchón": "tron-chón",
    "tronchuda": "tron-chu-da",
    "tronchudo": "tron-chu-do",
    "tronco": "tron-co",
    "troncocónico": "tron-co-có-ni-co",
    "troncón": "tron-cón",
    "tronera": "tro-ne-ra",
    "tronerar": "tro-ne-rar",
    "tronero": "tro-ne-ro",
    "tronga": "tron-ga",
    "trónica": "tró-ni-ca",
    "tronido": "tro-ni-do",
    "tronío": "tro-ní-o",
    "tronitosa": "tro-ni-to-sa",
    "tronitoso": "tro-ni-to-so",
    "trono": "tro-no",
    "tronquear": "tron-que-ar",
    "tronquista": "tron-quis-ta",
    "tronza": "tron-za",
    "tronzadera": "tron-za-de-ra",
    "tronzado": "tron-za-do",
    "tronzador": "tron-za-dor",
    "tronzar": "tron-zar",
    "tronzo": "tron-zo",
    "tropa": "tro-pa",
    "tropear": "tro-pe-ar",
    "tropecientos": "tro-pe-cien-tos",
    "tropel": "tro-pel",
    "tropelía": "tro-pe-lí-a",
    "tropelista": "tro-pe-lis-ta",
    "tropellar": "tro-pe-llar",
    "tropeolácea": "tro-pe-o-lá-ce-a",
    "tropeoláceo": "tro-pe-o-lá-ce-o",
    "tropeolea": "tro-pe-o-le-a",
    "tropeoleo": "tro-pe-o-le-o",
    "tropero": "tro-pe-ro",
    "tropezadero": "tro-pe-za-de-ro",
    "tropezador": "tro-pe-za-dor",
    "tropezadora": "tro-pe-za-do-ra",
    "tropezadura": "tro-pe-za-du-ra",
    "tropezar": "tro-pe-zar",
    "tropezón": "tro-pe-zón",
    "tropezona": "tro-pe-zo-na",
    "tropezosa": "tro-pe-zo-sa",
    "tropezoso": "tro-pe-zo-so",
    "trópica": "tró-pi-ca",
    "tropical": "tro-pi-cal",
    "trópico": "tró-pi-co",
    "tropiezo": "tro-pie-zo",
    "tropilla": "tro-pi-lla",
    "tropismo": "tro-pis-mo",
    "tropo": "tro-po",
    "tropología": "tro-po-lo-gí-a",
    "tropológica": "tro-po-ló-gi-ca",
    "tropológico": "tro-po-ló-gi-co",
    "tropopausa": "tro-po-pau-sa",
    "troposfera": "tro-pos-fe-ra",
    "tropósfera": "tro-pós-fe-ra",
    "troposférico": "tro-pos-fé-ri-co",
    "troque": "tro-que",
    "troquel": "tro-quel",
    "troquelado": "tro-que-la-do",
    "troquelar": "tro-que-lar",
    "troqueo": "tro-que-o",
    "troquilo": "tro-qui-lo",
    "trosas": "tro-sas",
    "trotacalles": "tro-ta-ca-lles",
    "trotaconventos": "tro-ta-con-ven-tos",
    "trotador": "tro-ta-dor",
    "trotadora": "tro-ta-do-ra",
    "trotamundos": "tro-ta-mun-dos",
    "trotar": "tro-tar",
    "trote": "tro-te",
    "trotero": "tro-te-ro",
    "trotón": "tro-tón",
    "trotona": "tro-to-na",
    "trotonería": "tro-to-ne-rí-a",
    "trotskismo": "trots-kis-mo",
    "trotskista": "trots-kis-ta",
    "trova": "tro-va",
    "trovador": "tro-va-dor",
    "trovadora": "tro-va-do-ra",
    "trovadoresca": "tro-va-do-res-ca",
    "trovadoresco": "tro-va-do-res-co",
    "trovar": "tro-var",
    "trovera": "tro-ve-ra",
    "trovero": "tro-ve-ro",
    "trovista": "tro-vis-ta",
    "trovo": "tro-vo",
    "troya": "tro-ya",
    "troyana": "tro-ya-na",
    "troyano": "tro-ya-no",
    "troza": "tro-za",
    "trozada": "tro-za-da",
    "trozar": "tro-zar",
    "trozo": "tro-zo",
    "truca": "tru-ca",
    "trucaje": "tru-ca-je",
    "trucar": "tru-car",
    "trucha": "tru-cha",
    "truchera": "tru-che-ra",
    "truchero": "tru-che-ro",
    "truchimán": "tru-chi-mán",
    "truchimana": "tru-chi-ma-na",
    "trucho": "tru-cho",
    "truchuela": "tru-chue-la",
    "trucidar": "tru-ci-dar",
    "truco": "tru-co",
    "truculencia": "tru-cu-len-cia",
    "truculenta": "tru-cu-len-ta",
    "truculento": "tru-cu-len-to",
    "trueco": "true-co",
    "trueno": "true-no",
    "trueque": "true-que",
    "trufa": "tru-fa",
    "trufador": "tru-fa-dor",
    "trufadora": "tru-fa-do-ra",
    "trufaldín": "tru-fal-dín",
    "trufaldina": "tru-fal-di-na",
    "trufar": "tru-far",
    "truhan": "truhan",
    "truhán": "truhán",
    "truhana": "truha-na",
    "truhanada": "truha-na-da",
    "truhanamente": "truha-na-men-te",
    "truhanear": "truha-ne-ar",
    "truhanería": "truha-ne-rí-a",
    "truhanesca": "truha-nes-ca",
    "truhanesco": "truha-nes-co",
    "truismo": "truis-mo",
    "truja": "tru-ja",
    "trujal": "tru-jal",
    "trujaleta": "tru-ja-le-ta",
    "trujamán": "tru-ja-mán",
    "trujamana": "tru-ja-ma-na",
    "trujamanear": "tru-ja-ma-ne-ar",
    "trujamanía": "tru-ja-ma-ní-a",
    "trujillana": "tru-ji-lla-na",
    "trujillano": "tru-ji-lla-no",
    "trujimán": "tru-ji-mán",
    "trujimana": "tru-ji-ma-na",
    "trulla": "tru-lla",
    "trullar": "tru-llar",
    "trullo": "tru-llo",
    "trumao": "tru-ma-o",
    "trunca": "trun-ca",
    "truncada": "trun-ca-da",
    "truncadamente": "trun-ca-da-men-te",
    "truncado": "trun-ca-do",
    "truncamiento": "trun-ca-mien-to",
    "truncar": "trun-car",
    "trunco": "trun-co",
    "trupial": "tru-pial",
    "truque": "tru-que",
    "truquero": "tru-que-ro",
    "truquiflor": "tru-qui-flor",
    "trusa": "tru-sa",
    "trutro": "tru-tro",
    "trutuca": "tru-tu-ca",
    "tuani": "tua-ni",
    "tuanis": "tua-nis",
    "tuareg": "tua-reg",
    "tuatara": "tua-ta-ra",
    "tuatúa": "tua-tú-a",
    "tuáutem": "tuáu-tem",
    "tuba": "tu-ba",
    "túbano": "tú-ba-no",
    "tuberculina": "tu-ber-cu-li-na",
    "tuberculización": "tu-ber-cu-li-za-ción",
    "tubérculo": "tu-bér-cu-lo",
    "tuberculosa": "tu-ber-cu-lo-sa",
    "tuberculosis": "tu-ber-cu-lo-sis",
    "tuberculoso": "tu-ber-cu-lo-so",
    "tubería": "tu-be-rí-a",
    "tuberosa": "tu-be-ro-sa",
    "tuberosidad": "tu-be-ro-si-dad",
    "tuberoso": "tu-be-ro-so",
    "tubiana": "tu-bia-na",
    "tubiano": "tu-bia-no",
    "tubo": "tu-bo",
    "tubular": "tu-bu-lar",
    "tubulidentado": "tu-bu-li-den-ta-do",
    "tubuliforme": "tu-bu-li-for-me",
    "túbulo": "tú-bu-lo",
    "tubulosa": "tu-bu-lo-sa",
    "tubuloso": "tu-bu-lo-so",
    "tuca": "tu-ca",
    "tucada": "tu-ca-da",
    "tucán": "tu-cán",
    "tucha": "tu-cha",
    "tuche": "tu-che",
    "tucho": "tu-cho",
    "tucía": "tu-cí-a",
    "tucinte": "tu-cin-te",
    "tuciorismo": "tu-cio-ris-mo",
    "tuciorista": "tu-cio-ris-ta",
    "tuco": "tu-co",
    "tucumana": "tu-cu-ma-na",
    "tucumano": "tu-cu-ma-no",
    "tucún": "tu-cún",
    "tucupitano": "tu-cu-pi-ta-no",
    "tucupiteña": "tu-cu-pi-te-ña",
    "tucupiteño": "tu-cu-pi-te-ño",
    "tucúquere": "tu-cú-que-re",
    "tucura": "tu-cu-ra",
    "tucurpilla": "tu-cur-pi-lla",
    "tucusito": "tu-cu-si-to",
    "tucuso": "tu-cu-so",
    "tucutuzal": "tu-cu-tu-zal",
    "tuda": "tu-da",
    "tudanca": "tu-dan-ca",
    "tudanco": "tu-dan-co",
    "tudel": "tu-del",
    "tudelana": "tu-de-la-na",
    "tudelano": "tu-de-la-no",
    "tudense": "tu-den-se",
    "tudesca": "tu-des-ca",
    "tudesco": "tu-des-co",
    "tueca": "tue-ca",
    "tueco": "tue-co",
    "tuera": "tue-ra",
    "tuerca": "tuer-ca",
    "tuerce": "tuer-ce",
    "tuero": "tue-ro",
    "tuerta": "tuer-ta",
    "tuerto": "tuer-to",
    "tueste": "tues-te",
    "tuétano": "tué-ta-no",
    "tufancina": "tu-fan-ci-na",
    "tufarada": "tu-fa-ra-da",
    "tufear": "tu-fe-ar",
    "tufillas": "tu-fi-llas",
    "tufillo": "tu-fi-llo",
    "tufo": "tu-fo",
    "tufoso": "tu-fo-so",
    "tugiense": "tu-gien-se",
    "tugurio": "tu-gu-rio",
    "tuición": "tui-ción",
    "tuina": "tui-na",
    "tuitiva": "tui-ti-va",
    "tuitivo": "tui-ti-vo",
    "tular": "tu-lar",
    "tulcaneña": "tul-ca-ne-ña",
    "tulcaneño": "tul-ca-ne-ño",
    "tule": "tu-le",
    "tulenco": "tu-len-co",
    "tulio": "tu-lio",
    "tulipa": "tu-li-pa",
    "tulipán": "tu-li-pán",
    "tulipanero": "tu-li-pa-ne-ro",
    "tulivieja": "tu-li-vie-ja",
    "tullecer": "tu-lle-cer",
    "tullida": "tu-lli-da",
    "tullidez": "tu-lli-dez",
    "tullido": "tu-lli-do",
    "tullidura": "tu-lli-du-ra",
    "tullimiento": "tu-lli-mien-to",
    "tullir": "tu-llir",
    "tulpa": "tul-pa",
    "tulumuco": "tu-lu-mu-co",
    "tumba": "tum-ba",
    "tumbaburros": "tum-ba-bu-rros",
    "tumbacuartillos": "tum-ba-cuar-ti-llos",
    "tumbada": "tum-ba-da",
    "tumbadero": "tum-ba-de-ro",
    "tumbadillo": "tum-ba-di-llo",
    "tumbado": "tum-ba-do",
    "tumbador": "tum-ba-dor",
    "tumbaga": "tum-ba-ga",
    "tumbagobierno": "tum-ba-go-bier-no",
    "tumbagón": "tum-ba-gón",
    "tumbal": "tum-bal",
    "tumbaollas": "tum-ba-o-llas",
    "tumbapolvo": "tum-ba-pol-vo",
    "tumbar": "tum-bar",
    "tumbarrancho": "tum-ba-rran-cho",
    "tumbazón": "tum-ba-zón",
    "tumbesina": "tum-be-si-na",
    "tumbesino": "tum-be-si-no",
    "tumbilla": "tum-bi-lla",
    "tumbillo": "tum-bi-llo",
    "tumbo": "tum-bo",
    "tumbón": "tum-bón",
    "tumbona": "tum-bo-na",
    "tumefacción": "tu-me-fac-ción",
    "tumefacta": "tu-me-fac-ta",
    "tumefacto": "tu-me-fac-to",
    "tumi": "tu-mi",
    "túmida": "tú-mi-da",
    "túmido": "tú-mi-do",
    "tumo": "tu-mo",
    "tumor": "tu-mor",
    "tumoración": "tu-mo-ra-ción",
    "tumoral": "tu-mo-ral",
    "tumorosa": "tu-mo-ro-sa",
    "tumoroso": "tu-mo-ro-so",
    "tumularia": "tu-mu-la-ria",
    "tumulario": "tu-mu-la-rio",
    "túmulo": "tú-mu-lo",
    "tumulto": "tu-mul-to",
    "tumultuar": "tu-mul-tuar",
    "tumultuaria": "tu-mul-tua-ria",
    "tumultuariamente": "tu-mul-tua-ria-men-te",
    "tumultuario": "tu-mul-tua-rio",
    "tumultuosa": "tu-mul-tuo-sa",
    "tumultuosamente": "tu-mul-tuo-sa-men-te",
    "tumultuoso": "tu-mul-tuo-so",
    "tuna": "tu-na",
    "tunal": "tu-nal",
    "tunalmil": "tu-nal-mil",
    "tunanta": "tu-nan-ta",
    "tunantada": "tu-nan-ta-da",
    "tunante": "tu-nan-te",
    "tunantear": "tu-nan-te-ar",
    "tunantería": "tu-nan-te-rí-a",
    "tunar": "tu-nar",
    "tunarra": "tu-na-rra",
    "tunca": "tun-ca",
    "tunco": "tun-co",
    "tuncul": "tun-cul",
    "tunda": "tun-da",
    "tundear": "tun-de-ar",
    "tundente": "tun-den-te",
    "tundición": "tun-di-ción",
    "tundido": "tun-di-do",
    "tundidor": "tun-di-dor",
    "tundidora": "tun-di-do-ra",
    "tundidura": "tun-di-du-ra",
    "tundir": "tun-dir",
    "tundizno": "tun-diz-no",
    "tundra": "tun-dra",
    "tunduque": "tun-du-que",
    "tunear": "tu-ne-ar",
    "tunecí": "tu-ne-cí",
    "tunecina": "tu-ne-ci-na",
    "tunecino": "tu-ne-ci-no",
    "túnel": "tú-nel",
    "tuneladora": "tu-ne-la-do-ra",
    "tunera": "tu-ne-ra",
    "tunería": "tu-ne-rí-a",
    "tunero": "tu-ne-ro",
    "túnez": "tú-nez",
    "tungra": "tun-gra",
    "tungro": "tun-gro",
    "tungsteno": "tungs-te-no",
    "tungurahuense": "tun-gu-ra-huen-se",
    "tungús": "tun-gús",
    "túnica": "tú-ni-ca",
    "tunicada": "tu-ni-ca-da",
    "tunicado": "tu-ni-ca-do",
    "tunicela": "tu-ni-ce-la",
    "túnico": "tú-ni-co",
    "tuning": "tu-ning",
    "tunjana": "tun-ja-na",
    "tunjano": "tun-ja-no",
    "tunjo": "tun-jo",
    "tuno": "tu-no",
    "tunta": "tun-ta",
    "tunteco": "tun-te-co",
    "tuntún": "tun-tún",
    "tununa": "tu-nu-na",
    "tupa": "tu-pa",
    "tupamara": "tu-pa-ma-ra",
    "tupamaro": "tu-pa-ma-ro",
    "tupaya": "tu-pa-ya",
    "tupé": "tu-pé",
    "tupí": "tu-pí",
    "tupiceña": "tu-pi-ce-ña",
    "tupiceño": "tu-pi-ce-ño",
    "tupición": "tu-pi-ción",
    "tupida": "tu-pi-da",
    "tupidez": "tu-pi-dez",
    "tupido": "tu-pi-do",
    "tupín": "tu-pín",
    "tupinambo": "tu-pi-nam-bo",
    "tupir": "tu-pir",
    "tupitaina": "tu-pi-tai-na",
    "tupitina": "tu-pi-ti-na",
    "tupo": "tu-po",
    "tura": "tu-ra",
    "turable": "tu-ra-ble",
    "turación": "tu-ra-ción",
    "turania": "tu-ra-nia",
    "turanio": "tu-ra-nio",
    "turar": "tu-rar",
    "turba": "tur-ba",
    "turbación": "tur-ba-ción",
    "turbadamente": "tur-ba-da-men-te",
    "turbador": "tur-ba-dor",
    "turbadora": "tur-ba-do-ra",
    "turbal": "tur-bal",
    "turbamiento": "tur-ba-mien-to",
    "turbamulta": "tur-ba-mul-ta",
    "turbante": "tur-ban-te",
    "turbar": "tur-bar",
    "turbativa": "tur-ba-ti-va",
    "turbativo": "tur-ba-ti-vo",
    "turbelario": "tur-be-la-rio",
    "turbera": "tur-be-ra",
    "turbia": "tur-bia",
    "turbiamente": "tur-bia-men-te",
    "túrbida": "túr-bi-da",
    "turbidez": "tur-bi-dez",
    "túrbido": "túr-bi-do",
    "turbiedad": "tur-bie-dad",
    "turbieza": "tur-bie-za",
    "turbina": "tur-bi-na",
    "turbino": "tur-bi-no",
    "turbinto": "tur-bin-to",
    "turbio": "tur-bio",
    "turbión": "tur-bión",
    "turbios": "tur-bios",
    "turbiosa": "tur-bio-sa",
    "turbioso": "tur-bio-so",
    "turbit": "tur-bit",
    "turbo": "tur-bo",
    "turboalternador": "tur-bo-al-ter-na-dor",
    "turbobomba": "tur-bo-bom-ba",
    "turbocompresor": "tur-bo-com-pre-sor",
    "turbodiésel": "tur-bo-dié-sel",
    "turbogenerador": "tur-bo-ge-ne-ra-dor",
    "turbohélice": "tur-bo-hé-li-ce",
    "turbón": "tur-bón",
    "turbonada": "tur-bo-na-da",
    "turbopropulsión": "tur-bo-pro-pul-sión",
    "turbopropulsor": "tur-bo-pro-pul-sor",
    "turborreactor": "tur-bo-rre-ac-tor",
    "turbulencia": "tur-bu-len-cia",
    "turbulenta": "tur-bu-len-ta",
    "turbulentamente": "tur-bu-len-ta-men-te",
    "turbulento": "tur-bu-len-to",
    "turca": "tur-ca",
    "turco": "tur-co",
    "turcomana": "tur-co-ma-na",
    "turcomano": "tur-co-ma-no",
    "turcople": "tur-co-ple",
    "turdetana": "tur-de-ta-na",
    "turdetano": "tur-de-ta-no",
    "túrdiga": "túr-di-ga",
    "turdión": "tur-dión",
    "túrdula": "túr-du-la",
    "túrdulo": "túr-du-lo",
    "tureca": "tu-re-ca",
    "turgencia": "tur-gen-cia",
    "turgente": "tur-gen-te",
    "túrgida": "túr-gi-da",
    "túrgido": "túr-gi-do",
    "turibular": "tu-ri-bu-lar",
    "turibulario": "tu-ri-bu-la-rio",
    "turíbulo": "tu-rí-bu-lo",
    "turífera": "tu-rí-fe-ra",
    "turiferaria": "tu-ri-fe-ra-ria",
    "turiferario": "tu-ri-fe-ra-rio",
    "turífero": "tu-rí-fe-ro",
    "turificación": "tu-ri-fi-ca-ción",
    "turificar": "tu-ri-fi-car",
    "turinés": "tu-ri-nés",
    "turinesa": "tu-ri-ne-sa",
    "turión": "tu-rión",
    "turismo": "tu-ris-mo",
    "turista": "tu-ris-ta",
    "turística": "tu-rís-ti-ca",
    "turísticamente": "tu-rís-ti-ca-men-te",
    "turístico": "tu-rís-ti-co",
    "turlerín": "tur-le-rín",
    "turma": "tur-ma",
    "turmalina": "tur-ma-li-na",
    "turmenia": "tur-me-nia",
    "turmenio": "tur-me-nio",
    "turmequé": "tur-me-qué",
    "túrmix": "túr-mix",
    "turmódiga": "tur-mó-di-ga",
    "turmódigo": "tur-mó-di-go",
    "turnar": "tur-nar",
    "turnedó": "tur-ne-dó",
    "turnia": "tur-nia",
    "turnio": "tur-nio",
    "turno": "tur-no",
    "turolense": "tu-ro-len-se",
    "turón": "tu-rón",
    "turonense": "tu-ro-nen-se",
    "turpial": "tur-pial",
    "turpitud": "tur-pi-tud",
    "turquear": "tur-que-ar",
    "turqués": "tur-qués",
    "turquesa": "tur-que-sa",
    "turquesada": "tur-que-sa-da",
    "turquesado": "tur-que-sa-do",
    "turquesca": "tur-ques-ca",
    "turquesco": "tur-ques-co",
    "turquí": "tur-quí",
    "turquina": "tur-qui-na",
    "turquino": "tur-qui-no",
    "turquita": "tur-qui-ta",
    "turra": "tu-rra",
    "turrar": "tu-rrar",
    "turril": "tu-rril",
    "turro": "tu-rro",
    "turrón": "tu-rrón",
    "turronada": "tu-rro-na-da",
    "turronera": "tu-rro-ne-ra",
    "turronería": "tu-rro-ne-rí-a",
    "turronero": "tu-rro-ne-ro",
    "turugón": "tu-ru-gón",
    "turulata": "tu-ru-la-ta",
    "turulato": "tu-ru-la-to",
    "turuleco": "tu-ru-le-co",
    "turulés": "tu-ru-lés",
    "turullo": "tu-ru-llo",
    "turulo": "tu-ru-lo",
    "turumbón": "tu-rum-bón",
    "turunca": "tu-run-ca",
    "turupial": "tu-ru-pial",
    "tururú": "tu-ru-rú",
    "turuta": "tu-ru-ta",
    "tusa": "tu-sa",
    "tusar": "tu-sar",
    "tusca": "tus-ca",
    "tuscal": "tus-cal",
    "tusco": "tus-co",
    "tusculana": "tus-cu-la-na",
    "tusculano": "tus-cu-la-no",
    "tuse": "tu-se",
    "tusígeno": "tu-sí-ge-no",
    "tusilago": "tu-si-la-go",
    "tuso": "tu-so",
    "tusón": "tu-són",
    "tusona": "tu-so-na",
    "tustaca": "tus-ta-ca",
    "tusturrar": "tus-tu-rrar",
    "tusunco": "tu-sun-co",
    "tuta": "tu-ta",
    "tútano": "tú-ta-no",
    "tute": "tu-te",
    "tutear": "tu-te-ar",
    "tutela": "tu-te-la",
    "tutelaje": "tu-te-la-je",
    "tutelar": "tu-te-lar",
    "tuteo": "tu-te-o",
    "tutía": "tu-tí-a",
    "tutifruti": "tu-ti-fru-ti",
    "tutilimundi": "tu-ti-li-mun-di",
    "tutiplén": "tu-ti-plén",
    "tuto": "tu-to",
    "tutor": "tu-tor",
    "tutora": "tu-to-ra",
    "tutorar": "tu-to-rar",
    "tutoría": "tu-to-rí-a",
    "tutorial": "tu-to-rial",
    "tutriz": "tu-triz",
    "tutsi": "tut-si",
    "tutti": "tut-ti",
    "tutú": "tu-tú",
    "tutuma": "tu-tu-ma",
    "tutumilpate": "tu-tu-mil-pa-te",
    "tutumo": "tu-tu-mo",
    "tutumpote": "tu-tum-po-te",
    "tuturuta": "tu-tu-ru-ta",
    "tuturuto": "tu-tu-ru-to",
    "tuturutú": "tu-tu-ru-tú",
    "tuvaluana": "tu-va-lua-na",
    "tuvaluano": "tu-va-lua-no",
    "tuya": "tu-ya",
    "tuyo": "tu-yo",
    "tuyuyo": "tu-yu-yo",
    "tuza": "tu-za",
    "twahka": "twah-ka",
    "twinset": "twin-set",
    "uapití": "ua-pi-tí",
    "ubajay": "u-ba-jay",
    "ube": "u-be",
    "ubérrima": "u-bé-rri-ma",
    "ubérrimo": "u-bé-rri-mo",
    "ubetense": "u-be-ten-se",
    "ubí": "u-bí",
    "ubicable": "u-bi-ca-ble",
    "ubicación": "u-bi-ca-ción",
    "ubicado": "u-bi-ca-do",
    "ubicar": "u-bi-car",
    "ubicua": "u-bi-cua",
    "ubicuamente": "u-bi-cua-men-te",
    "ubicuidad": "u-bi-cui-dad",
    "ubicuo": "u-bi-cuo",
    "ubio": "u-bio",
    "ubiquidad": "u-bi-qui-dad",
    "ubiquitaria": "u-bi-qui-ta-ria",
    "ubiquitario": "u-bi-qui-ta-rio",
    "ubre": "u-bre",
    "ubrera": "u-bre-ra",
    "ucase": "u-ca-se",
    "ucayalina": "u-ca-ya-li-na",
    "ucayalino": "u-ca-ya-li-no",
    "ucé": "u-cé",
    "uced": "u-ced",
    "ucencia": "u-cen-cia",
    "uchu": "u-chu",
    "uchuva": "u-chu-va",
    "uchuvo": "u-chu-vo",
    "uci": "u-ci",
    "ucrania": "u-cra-nia",
    "ucraniana": "u-cra-nia-na",
    "ucraniano": "u-cra-nia-no",
    "ucranio": "u-cra-nio",
    "ucronía": "u-cro-ní-a",
    "ucrónico": "u-cró-ni-co",
    "ucubitana": "u-cu-bi-ta-na",
    "ucubitano": "u-cu-bi-ta-no",
    "udómetro": "u-dó-me-tro",
    "uebos": "ue-bos",
    "ufa": "u-fa",
    "ufana": "u-fa-na",
    "ufanamente": "u-fa-na-men-te",
    "ufanar": "u-fa-nar",
    "ufanarse": "u-fa-nar-se",
    "ufanera": "u-fa-ne-ra",
    "ufanero": "u-fa-ne-ro",
    "ufaneza": "u-fa-ne-za",
    "ufanía": "u-fa-ní-a",
    "ufanidad": "u-fa-ni-dad",
    "ufano": "u-fa-no",
    "ufo": "u-fo",
    "ufóloga": "u-fó-lo-ga",
    "ufología": "u-fo-lo-gí-a",
    "ufológico": "u-fo-ló-gi-co",
    "ufólogo": "u-fó-lo-go",
    "ugandés": "u-gan-dés",
    "ugandesa": "u-gan-de-sa",
    "ugetista": "u-ge-tis-ta",
    "ugre": "u-gre",
    "ugro": "u-gro",
    "ugrofinés": "u-gro-fi-nés",
    "ugrofinesa": "u-gro-fi-ne-sa",
    "ujier": "u-jier",
    "ujú": "u-jú",
    "újule": "ú-ju-le",
    "ukelele": "u-ke-le-le",
    "ulaga": "u-la-ga",
    "ulala": "u-la-la",
    "ulama": "u-la-ma",
    "ulano": "u-la-no",
    "úlcera": "úl-ce-ra",
    "ulceración": "ul-ce-ra-ción",
    "ulcerar": "ul-ce-rar",
    "ulcerativa": "ul-ce-ra-ti-va",
    "ulcerativo": "ul-ce-ra-ti-vo",
    "ulcerosa": "ul-ce-ro-sa",
    "ulceroso": "ul-ce-ro-so",
    "ulcoate": "ul-co-a-te",
    "ulema": "u-le-ma",
    "ulfilana": "ul-fi-la-na",
    "ulfilano": "ul-fi-la-no",
    "uliginoso": "u-li-gi-no-so",
    "ulluco": "u-llu-co",
    "ulmácea": "ul-má-ce-a",
    "ulmáceo": "ul-má-ce-o",
    "ulmaria": "ul-ma-ria",
    "ulmo": "ul-mo",
    "ulpada": "ul-pa-da",
    "ulpo": "ul-po",
    "ulterior": "ul-te-rior",
    "ulteriormente": "ul-te-rior-men-te",
    "ultílogo": "ul-tí-lo-go",
    "última": "úl-ti-ma",
    "ultimación": "ul-ti-ma-ción",
    "ultimada": "ul-ti-ma-da",
    "ultimadamente": "ul-ti-ma-da-men-te",
    "ultimado": "ul-ti-ma-do",
    "ultimador": "ul-ti-ma-dor",
    "ultimadora": "ul-ti-ma-do-ra",
    "últimamente": "úl-ti-ma-men-te",
    "ultimar": "ul-ti-mar",
    "ultimato": "ul-ti-ma-to",
    "ultimátum": "ul-ti-má-tum",
    "ultimidad": "ul-ti-mi-dad",
    "último": "úl-ti-mo",
    "ultra": "ul-tra",
    "ultraconservador": "ul-tra-con-ser-va-dor",
    "ultraconservadora": "ul-tra-con-ser-va-do-ra",
    "ultracorrección": "ul-tra-co-rrec-ción",
    "ultraderecha": "ul-tra-de-re-cha",
    "ultraderechista": "ul-tra-de-re-chis-ta",
    "ultraísmo": "ul-tra-ís-mo",
    "ultraísta": "ul-tra-ís-ta",
    "ultraizquierda": "ul-traiz-quier-da",
    "ultraizquierdista": "ul-traiz-quier-dis-ta",
    "ultrajador": "ul-tra-ja-dor",
    "ultrajadora": "ul-tra-ja-do-ra",
    "ultrajante": "ul-tra-jan-te",
    "ultrajar": "ul-tra-jar",
    "ultraje": "ul-tra-je",
    "ultrajosa": "ul-tra-jo-sa",
    "ultrajoso": "ul-tra-jo-so",
    "ultraligero": "ul-tra-li-ge-ro",
    "ultraliviano": "ul-tra-li-via-no",
    "ultramar": "ul-tra-mar",
    "ultramarina": "ul-tra-ma-ri-na",
    "ultramarino": "ul-tra-ma-ri-no",
    "ultramarinos": "ul-tra-ma-ri-nos",
    "ultramaro": "ul-tra-ma-ro",
    "ultramicroscópica": "ul-tra-mi-cros-có-pi-ca",
    "ultramicroscópico": "ul-tra-mi-cros-có-pi-co",
    "ultramicroscopio": "ul-tra-mi-cros-co-pio",
    "ultramoderno": "ul-tra-mo-der-no",
    "ultramontana": "ul-tra-mon-ta-na",
    "ultramontanismo": "ul-tra-mon-ta-nis-mo",
    "ultramontano": "ul-tra-mon-ta-no",
    "ultramundana": "ul-tra-mun-da-na",
    "ultramundano": "ul-tra-mun-da-no",
    "ultranza": "ul-tran-za",
    "ultrapuertos": "ul-tra-puer-tos",
    "ultrarrápido": "ul-tra-rrá-pi-do",
    "ultrarrojo": "ul-tra-rro-jo",
    "ultrasensible": "ul-tra-sen-si-ble",
    "ultrasónico": "ul-tra-só-ni-co",
    "ultrasonido": "ul-tra-so-ni-do",
    "ultraterrenal": "ul-tra-te-rre-nal",
    "ultraterreno": "ul-tra-te-rre-no",
    "ultratumba": "ul-tra-tum-ba",
    "ultraviolada": "ul-tra-vio-la-da",
    "ultraviolado": "ul-tra-vio-la-do",
    "ultravioleta": "ul-tra-vio-le-ta",
    "ultriz": "ul-triz",
    "ulua": "u-lua",
    "úlula": "ú-lu-la",
    "ulular": "u-lu-lar",
    "ululato": "u-lu-la-to",
    "ulva": "ul-va",
    "umbela": "um-be-la",
    "umbelífera": "um-be-lí-fe-ra",
    "umbelíferas": "um-be-lí-fe-ras",
    "umbelífero": "um-be-lí-fe-ro",
    "umbilicada": "um-bi-li-ca-da",
    "umbilicado": "um-bi-li-ca-do",
    "umbilical": "um-bi-li-cal",
    "umbra": "um-bra",
    "umbráculo": "um-brá-cu-lo",
    "umbral": "um-bral",
    "umbralado": "um-bra-la-do",
    "umbralar": "um-bra-lar",
    "umbrática": "um-brá-ti-ca",
    "umbrático": "um-brá-ti-co",
    "umbrátil": "um-brá-til",
    "umbrela": "um-bre-la",
    "umbría": "um-brí-a",
    "umbrío": "um-brí-o",
    "umbro": "um-bro",
    "umbrófilo": "um-bró-fi-lo",
    "umbrosa": "um-bro-sa",
    "umbroso": "um-bro-so",
    "umero": "u-me-ro",
    "umjú": "um-jú",
    "una": "u-na",
    "uña": "u-ña",
    "uñada": "u-ña-da",
    "uñado": "u-ña-do",
    "unalba": "u-nal-ba",
    "unalbo": "u-nal-bo",
    "unamuniano": "u-na-mu-nia-no",
    "unánime": "u-ná-ni-me",
    "unánimemente": "u-ná-ni-me-men-te",
    "unanimidad": "u-na-ni-mi-dad",
    "uñarada": "u-ña-ra-da",
    "uñate": "u-ña-te",
    "uncia": "un-cia",
    "uncial": "un-cial",
    "uncidor": "un-ci-dor",
    "uncidora": "un-ci-do-ra",
    "unciforme": "un-ci-for-me",
    "unción": "un-ción",
    "uncionaria": "un-cio-na-ria",
    "uncionario": "un-cio-na-rio",
    "uncir": "un-cir",
    "undante": "un-dan-te",
    "undecágona": "un-de-cá-go-na",
    "undecágono": "un-de-cá-go-no",
    "undécima": "un-dé-ci-ma",
    "undécimo": "un-dé-ci-mo",
    "undécupla": "un-dé-cu-pla",
    "undécuplo": "un-dé-cu-plo",
    "undísona": "un-dí-so-na",
    "undísono": "un-dí-so-no",
    "undívaga": "un-dí-va-ga",
    "undívago": "un-dí-va-go",
    "undosa": "un-do-sa",
    "undoso": "un-do-so",
    "undulación": "un-du-la-ción",
    "undular": "un-du-lar",
    "undulatoria": "un-du-la-to-ria",
    "undulatorio": "un-du-la-to-rio",
    "uñero": "u-ñe-ro",
    "uñeta": "u-ñe-ta",
    "uñetas": "u-ñe-tas",
    "uñetazo": "u-ñe-ta-zo",
    "ungido": "un-gi-do",
    "ungimiento": "un-gi-mien-to",
    "ungir": "un-gir",
    "ungüentaria": "un-güen-ta-ria",
    "ungüentario": "un-güen-ta-rio",
    "ungüento": "un-güen-to",
    "unguiculada": "un-gui-cu-la-da",
    "unguiculado": "un-gui-cu-la-do",
    "unguis": "un-guis",
    "ungulada": "un-gu-la-da",
    "ungulado": "un-gu-la-do",
    "ungular": "un-gu-lar",
    "uñi": "u-ñi",
    "uniata": "u-nia-ta",
    "unible": "u-ni-ble",
    "única": "ú-ni-ca",
    "únicamente": "ú-ni-ca-men-te",
    "unicameral": "u-ni-ca-me-ral",
    "unicaule": "u-ni-cau-le",
    "unicelular": "u-ni-ce-lu-lar",
    "unicidad": "u-ni-ci-dad",
    "único": "ú-ni-co",
    "unicolor": "u-ni-co-lor",
    "unicornio": "u-ni-cor-nio",
    "unidad": "u-ni-dad",
    "unidamente": "u-ni-da-men-te",
    "unidimensional": "u-ni-di-men-sio-nal",
    "unidireccional": "u-ni-di-rec-cio-nal",
    "unido": "u-ni-do",
    "unidor": "u-ni-dor",
    "unidora": "u-ni-do-ra",
    "uñidura": "u-ñi-du-ra",
    "unifamiliar": "u-ni-fa-mi-liar",
    "unificación": "u-ni-fi-ca-ción",
    "unificado": "u-ni-fi-ca-do",
    "unificador": "u-ni-fi-ca-dor",
    "unificar": "u-ni-fi-car",
    "unifoliada": "u-ni-fo-lia-da",
    "unifoliado": "u-ni-fo-lia-do",
    "uniformado": "u-ni-for-ma-do",
    "uniformador": "u-ni-for-ma-dor",
    "uniformadora": "u-ni-for-ma-do-ra",
    "uniformar": "u-ni-for-mar",
    "uniforme": "u-ni-for-me",
    "uniformemente": "u-ni-for-me-men-te",
    "uniformidad": "u-ni-for-mi-dad",
    "uniformizar": "u-ni-for-mi-zar",
    "unigénita": "u-ni-gé-ni-ta",
    "unigénito": "u-ni-gé-ni-to",
    "uñilarga": "u-ñi-lar-ga",
    "uñilargo": "u-ñi-lar-go",
    "unilateral": "u-ni-la-te-ral",
    "unilateralidad": "u-ni-la-te-ra-li-dad",
    "unilateralmente": "u-ni-la-te-ral-men-te",
    "unimembre": "u-ni-mem-bre",
    "unimismar": "u-ni-mis-mar",
    "unión": "u-nión",
    "unionense": "u-nio-nen-se",
    "unionismo": "u-nio-nis-mo",
    "unionista": "u-nio-nis-ta",
    "uníparo": "u-ní-pa-ro",
    "unípede": "u-ní-pe-de",
    "unipersonal": "u-ni-per-so-nal",
    "unir": "u-nir",
    "uñir": "u-ñir",
    "unisex": "u-ni-sex",
    "unisexual": "u-ni-se-xual",
    "unisón": "u-ni-són",
    "unísona": "u-ní-so-na",
    "unisonancia": "u-ni-so-nan-cia",
    "unisonar": "u-ni-so-nar",
    "unísono": "u-ní-so-no",
    "unitaria": "u-ni-ta-ria",
    "unitariamente": "u-ni-ta-ria-men-te",
    "unitario": "u-ni-ta-rio",
    "unitarismo": "u-ni-ta-ris-mo",
    "unitiva": "u-ni-ti-va",
    "unitivo": "u-ni-ti-vo",
    "univalva": "u-ni-val-va",
    "univalvo": "u-ni-val-vo",
    "universa": "u-ni-ver-sa",
    "universal": "u-ni-ver-sal",
    "universalidad": "u-ni-ver-sa-li-dad",
    "universalísimo": "u-ni-ver-sa-lí-si-mo",
    "universalismo": "u-ni-ver-sa-lis-mo",
    "universalista": "u-ni-ver-sa-lis-ta",
    "universalización": "u-ni-ver-sa-li-za-ción",
    "universalizar": "u-ni-ver-sa-li-zar",
    "universalmente": "u-ni-ver-sal-men-te",
    "universiada": "u-ni-ver-sia-da",
    "universidad": "u-ni-ver-si-dad",
    "universitaria": "u-ni-ver-si-ta-ria",
    "universitario": "u-ni-ver-si-ta-rio",
    "universo": "u-ni-ver-so",
    "univitelino": "u-ni-vi-te-li-no",
    "unívoca": "u-ní-vo-ca",
    "univocación": "u-ni-vo-ca-ción",
    "unívocamente": "u-ní-vo-ca-men-te",
    "univocar": "u-ni-vo-car",
    "univocarse": "u-ni-vo-car-se",
    "univocidad": "u-ni-vo-ci-dad",
    "unívoco": "u-ní-vo-co",
    "unjú": "un-jú",
    "uno": "u-no",
    "uñoperquén": "u-ño-per-quén",
    "uñosa": "u-ño-sa",
    "uñoso": "u-ño-so",
    "untable": "un-ta-ble",
    "untada": "un-ta-da",
    "untador": "un-ta-dor",
    "untadora": "un-ta-do-ra",
    "untadura": "un-ta-du-ra",
    "untamiento": "un-ta-mien-to",
    "untar": "un-tar",
    "untaza": "un-ta-za",
    "unte": "un-te",
    "unto": "un-to",
    "untosa": "un-to-sa",
    "untoso": "un-to-so",
    "untuosa": "un-tuo-sa",
    "untuosamente": "un-tuo-sa-men-te",
    "untuosidad": "un-tuo-si-dad",
    "untuoso": "un-tuo-so",
    "untura": "un-tu-ra",
    "uñudo": "u-ñu-do",
    "upa": "u-pa",
    "upar": "u-par",
    "uperisación": "u-pe-ri-sa-ción",
    "uperisar": "u-pe-ri-sar",
    "uperización": "u-pe-ri-za-ción",
    "uperizar": "u-pe-ri-zar",
    "upupa": "u-pu-pa",
    "ura": "u-ra",
    "uracho": "u-ra-cho",
    "uracilo": "u-ra-ci-lo",
    "urajear": "u-ra-je-ar",
    "uralaltaica": "u-ra-lal-tai-ca",
    "uralaltaico": "u-ra-lal-tai-co",
    "urálico": "u-rá-li-co",
    "uralita": "u-ra-li-ta",
    "uraloaltaico": "u-ra-lo-al-tai-co",
    "urania": "u-ra-nia",
    "uranio": "u-ra-nio",
    "urano": "u-ra-no",
    "uranógrafa": "u-ra-nó-gra-fa",
    "uranografía": "u-ra-no-gra-fí-a",
    "uranógrafo": "u-ra-nó-gra-fo",
    "uranolito": "u-ra-no-li-to",
    "uranometría": "u-ra-no-me-trí-a",
    "urao": "u-ra-o",
    "urape": "u-ra-pe",
    "urato": "u-ra-to",
    "urbana": "ur-ba-na",
    "urbanamente": "ur-ba-na-men-te",
    "urbanícola": "ur-ba-ní-co-la",
    "urbanidad": "ur-ba-ni-dad",
    "urbanismo": "ur-ba-nis-mo",
    "urbanista": "ur-ba-nis-ta",
    "urbanística": "ur-ba-nís-ti-ca",
    "urbanístico": "ur-ba-nís-ti-co",
    "urbanita": "ur-ba-ni-ta",
    "urbanizable": "ur-ba-ni-za-ble",
    "urbanización": "ur-ba-ni-za-ción",
    "urbanizador": "ur-ba-ni-za-dor",
    "urbanizadora": "ur-ba-ni-za-do-ra",
    "urbanizar": "ur-ba-ni-zar",
    "urbano": "ur-ba-no",
    "urbe": "ur-be",
    "urca": "ur-ca",
    "urce": "ur-ce",
    "urchilla": "ur-chi-lla",
    "urcitana": "ur-ci-ta-na",
    "urcitano": "ur-ci-ta-no",
    "urdidera": "ur-di-de-ra",
    "urdidor": "ur-di-dor",
    "urdidora": "ur-di-do-ra",
    "urdidura": "ur-di-du-ra",
    "urdiembre": "ur-diem-bre",
    "urdimbre": "ur-dim-bre",
    "urdir": "ur-dir",
    "urdu": "ur-du",
    "urea": "u-re-a",
    "uremia": "u-re-mia",
    "urémica": "u-ré-mi-ca",
    "urémico": "u-ré-mi-co",
    "urente": "u-ren-te",
    "ureotélico": "u-re-o-té-li-co",
    "uréter": "u-ré-ter",
    "urétera": "u-ré-te-ra",
    "urética": "u-ré-ti-ca",
    "urético": "u-ré-ti-co",
    "uretra": "u-re-tra",
    "uretral": "u-re-tral",
    "uretritis": "u-re-tri-tis",
    "urgabonense": "ur-ga-bo-nen-se",
    "urgencia": "ur-gen-cia",
    "urgente": "ur-gen-te",
    "urgentemente": "ur-gen-te-men-te",
    "urgir": "ur-gir",
    "urías": "u-rí-as",
    "úrica": "ú-ri-ca",
    "úrico": "ú-ri-co",
    "uricotélico": "u-ri-co-té-li-co",
    "urinal": "u-ri-nal",
    "urinaria": "u-ri-na-ria",
    "urinario": "u-ri-na-rio",
    "urna": "ur-na",
    "urnición": "ur-ni-ción",
    "uro": "u-ro",
    "urocordado": "u-ro-cor-da-do",
    "urodelo": "u-ro-de-lo",
    "urogallo": "u-ro-ga-llo",
    "urogenital": "u-ro-ge-ni-tal",
    "urografía": "u-ro-gra-fí-a",
    "uróloga": "u-ró-lo-ga",
    "urología": "u-ro-lo-gí-a",
    "urológico": "u-ro-ló-gi-co",
    "urólogo": "u-ró-lo-go",
    "uromancía": "u-ro-man-cí-a",
    "uromancia": "u-ro-man-cia",
    "uroscopia": "u-ros-co-pia",
    "urpila": "ur-pi-la",
    "urque": "ur-que",
    "urraca": "u-rra-ca",
    "ursa": "ur-sa",
    "ursaonense": "ur-sa-o-nen-se",
    "úrsido": "úr-si-do",
    "ursina": "ur-si-na",
    "urso": "ur-so",
    "ursulina": "ur-su-li-na",
    "urta": "ur-ta",
    "urticácea": "ur-ti-cá-ce-a",
    "urticáceas": "ur-ti-cá-ce-as",
    "urticáceo": "ur-ti-cá-ce-o",
    "urticación": "ur-ti-ca-ción",
    "urticante": "ur-ti-can-te",
    "urticaria": "ur-ti-ca-ria",
    "urubambina": "u-ru-bam-bi-na",
    "urubambino": "u-ru-bam-bi-no",
    "urubú": "u-ru-bú",
    "urucú": "u-ru-cú",
    "uruga": "u-ru-ga",
    "uruguaya": "u-ru-gua-ya",
    "uruguayismo": "u-ru-gua-yis-mo",
    "uruguayo": "u-ru-gua-yo",
    "urunday": "u-run-day",
    "urundey": "u-run-dey",
    "urutaú": "u-ru-ta-ú",
    "usada": "u-sa-da",
    "usadamente": "u-sa-da-men-te",
    "usado": "u-sa-do",
    "usador": "u-sa-dor",
    "usadora": "u-sa-do-ra",
    "usagre": "u-sa-gre",
    "usaje": "u-sa-je",
    "usanza": "u-san-za",
    "usapuca": "u-sa-pu-ca",
    "usar": "u-sar",
    "usarcé": "u-sar-cé",
    "usarced": "u-sar-ced",
    "uscoque": "us-co-que",
    "usencia": "u-sen-cia",
    "useñoría": "u-se-ño-rí-a",
    "usgo": "us-go",
    "ushuaiense": "us-huaien-se",
    "usía": "u-sí-a",
    "usier": "u-sier",
    "usillo": "u-si-llo",
    "usina": "u-si-na",
    "usiría": "u-si-rí-a",
    "usitada": "u-si-ta-da",
    "usitado": "u-si-ta-do",
    "uslero": "us-le-ro",
    "uso": "u-so",
    "uspanteca": "us-pan-te-ca",
    "ustaga": "us-ta-ga",
    "uste": "us-te",
    "usted": "us-ted",
    "ustible": "us-ti-ble",
    "ustión": "us-tión",
    "ustorio": "us-to-rio",
    "usual": "u-sual",
    "usualmente": "u-sual-men-te",
    "usuaria": "u-sua-ria",
    "usuario": "u-sua-rio",
    "usucapión": "u-su-ca-pión",
    "usucapir": "u-su-ca-pir",
    "usufructo": "u-su-fruc-to",
    "usufructuar": "u-su-fruc-tuar",
    "usufructuaria": "u-su-fruc-tua-ria",
    "usufructuario": "u-su-fruc-tua-rio",
    "usufruto": "u-su-fru-to",
    "usufrutuaria": "u-su-fru-tua-ria",
    "usufrutuario": "u-su-fru-tua-rio",
    "usuluteca": "u-su-lu-te-ca",
    "usuluteco": "u-su-lu-te-co",
    "usupuca": "u-su-pu-ca",
    "usura": "u-su-ra",
    "usurar": "u-su-rar",
    "usuraria": "u-su-ra-ria",
    "usurariamente": "u-su-ra-ria-men-te",
    "usurario": "u-su-ra-rio",
    "usurear": "u-su-re-ar",
    "usurera": "u-su-re-ra",
    "usurero": "u-su-re-ro",
    "usurpación": "u-sur-pa-ción",
    "usurpador": "u-sur-pa-dor",
    "usurpadora": "u-sur-pa-do-ra",
    "usurpar": "u-sur-par",
    "usuta": "u-su-ta",
    "uta": "u-ta",
    "utensilio": "u-ten-si-lio",
    "uterina": "u-te-ri-na",
    "uterino": "u-te-ri-no",
    "útero": "ú-te-ro",
    "uticense": "u-ti-cen-se",
    "útil": "ú-til",
    "utilera": "u-ti-le-ra",
    "utilería": "u-ti-le-rí-a",
    "utilero": "u-ti-le-ro",
    "utilidad": "u-ti-li-dad",
    "utilitaria": "u-ti-li-ta-ria",
    "utilitario": "u-ti-li-ta-rio",
    "utilitarismo": "u-ti-li-ta-ris-mo",
    "utilitarista": "u-ti-li-ta-ris-ta",
    "utilizable": "u-ti-li-za-ble",
    "utilización": "u-ti-li-za-ción",
    "utilizar": "u-ti-li-zar",
    "utillaje": "u-ti-lla-je",
    "utillera": "u-ti-lle-ra",
    "utillero": "u-ti-lle-ro",
    "útilmente": "ú-til-men-te",
    "utopía": "u-to-pí-a",
    "utopia": "u-to-pia",
    "utópica": "u-tó-pi-ca",
    "utópicamente": "u-tó-pi-ca-men-te",
    "utópico": "u-tó-pi-co",
    "utopismo": "u-to-pis-mo",
    "utopista": "u-to-pis-ta",
    "utrera": "u-tre-ra",
    "utrerana": "u-tre-ra-na",
    "utrerano": "u-tre-ra-no",
    "utrero": "u-tre-ro",
    "utrículo": "u-trí-cu-lo",
    "uva": "u-va",
    "uvada": "u-va-da",
    "uvaduz": "u-va-duz",
    "uvaguemaestre": "u-va-gue-ma-es-tre",
    "uval": "u-val",
    "uvate": "u-va-te",
    "uvayema": "u-va-ye-ma",
    "uve": "u-ve",
    "úvea": "ú-ve-a",
    "uveítis": "u-ve-í-tis",
    "uvera": "u-ve-ra",
    "uveral": "u-ve-ral",
    "uvero": "u-ve-ro",
    "uvi": "u-vi",
    "uviar": "u-viar",
    "uvilla": "u-vi-lla",
    "uvillo": "u-vi-llo",
    "úvula": "ú-vu-la",
    "uvular": "u-vu-lar",
    "uxoricida": "u-xo-ri-ci-da",
    "uxoricidio": "u-xo-ri-ci-dio",
    "uyunense": "u-yu-nen-se",
    "uyunza": "u-yun-za",
    "uzbeca": "uz-be-ca",
    "uzbeco": "uz-be-co",
    "uzbega": "uz-be-ga",
    "uzbego": "uz-be-go",
    "uzbeka": "uz-be-ka",
    "uzbeko": "uz-be-ko",
    "uzo": "u-zo",
    "vaca": "va-ca",
    "vacabuey": "va-ca-buey",
    "vacaburra": "va-ca-bu-rra",
    "vacación": "va-ca-ción",
    "vacacional": "va-ca-cio-nal",
    "vacacionar": "va-ca-cio-nar",
    "vacacionista": "va-ca-cio-nis-ta",
    "vacada": "va-ca-da",
    "vacaje": "va-ca-je",
    "vacancia": "va-can-cia",
    "vacante": "va-can-te",
    "vacar": "va-car",
    "vacaraí": "va-ca-ra-í",
    "vacaray": "va-ca-ray",
    "vacarí": "va-ca-rí",
    "vacatura": "va-ca-tu-ra",
    "vaccea": "vac-ce-a",
    "vacceo": "vac-ce-o",
    "vacciniea": "vac-ci-nie-a",
    "vaccinieo": "vac-ci-nie-o",
    "vaciada": "va-cia-da",
    "vaciadero": "va-cia-de-ro",
    "vaciadiza": "va-cia-di-za",
    "vaciadizo": "va-cia-di-zo",
    "vaciado": "va-cia-do",
    "vaciador": "va-cia-dor",
    "vaciadora": "va-cia-do-ra",
    "vaciamiento": "va-cia-mien-to",
    "vaciante": "va-cian-te",
    "vaciar": "va-ciar",
    "vaciedad": "va-cie-dad",
    "vaciero": "va-cie-ro",
    "vacilación": "va-ci-la-ción",
    "vacilada": "va-ci-la-da",
    "vaciladera": "va-ci-la-de-ra",
    "vacilador": "va-ci-la-dor",
    "vacilante": "va-ci-lan-te",
    "vacilantemente": "va-ci-lan-te-men-te",
    "vacilar": "va-ci-lar",
    "vacile": "va-ci-le",
    "vacilón": "va-ci-lón",
    "vacilona": "va-ci-lo-na",
    "vacío": "va-cí-o",
    "vaco": "va-co",
    "vacua": "va-cua",
    "vacuidad": "va-cui-dad",
    "vacuna": "va-cu-na",
    "vacunación": "va-cu-na-ción",
    "vacunada": "va-cu-na-da",
    "vacunador": "va-cu-na-dor",
    "vacunadora": "va-cu-na-do-ra",
    "vacunar": "va-cu-nar",
    "vacuno": "va-cu-no",
    "vacunoterapia": "va-cu-no-te-ra-pia",
    "vacuo": "va-cuo",
    "vacuola": "va-cuo-la",
    "vade": "va-de",
    "vadeable": "va-de-a-ble",
    "vadeador": "va-de-a-dor",
    "vadear": "va-de-ar",
    "vademécum": "va-de-mé-cum",
    "vadera": "va-de-ra",
    "vadiana": "va-dia-na",
    "vadiano": "va-dia-no",
    "vado": "va-do",
    "vadosa": "va-do-sa",
    "vadoso": "va-do-so",
    "vafear": "va-fe-ar",
    "vafo": "va-fo",
    "vafosa": "va-fo-sa",
    "vafoso": "va-fo-so",
    "vaga": "va-ga",
    "vagabunda": "va-ga-bun-da",
    "vagabundeaje": "va-ga-bun-de-a-je",
    "vagabundear": "va-ga-bun-de-ar",
    "vagabundeo": "va-ga-bun-de-o",
    "vagabundería": "va-ga-bun-de-rí-a",
    "vagabundo": "va-ga-bun-do",
    "vagamente": "va-ga-men-te",
    "vagamunda": "va-ga-mun-da",
    "vagamundear": "va-ga-mun-de-ar",
    "vagamundo": "va-ga-mun-do",
    "vagancia": "va-gan-cia",
    "vagante": "va-gan-te",
    "vagar": "va-gar",
    "vagarosa": "va-ga-ro-sa",
    "vagarosamente": "va-ga-ro-sa-men-te",
    "vagarosidad": "va-ga-ro-si-dad",
    "vagaroso": "va-ga-ro-so",
    "vagido": "va-gi-do",
    "vagina": "va-gi-na",
    "vaginal": "va-gi-nal",
    "vaginismo": "va-gi-nis-mo",
    "vaginitis": "va-gi-ni-tis",
    "vago": "va-go",
    "vagón": "va-gón",
    "vagoneta": "va-go-ne-ta",
    "vagotonía": "va-go-to-ní-a",
    "vaguada": "va-gua-da",
    "vagueación": "va-gue-a-ción",
    "vaguear": "va-gue-ar",
    "vaguedad": "va-gue-dad",
    "vaguemaestre": "va-gue-ma-es-tre",
    "vaguería": "va-gue-rí-a",
    "vaguida": "va-gui-da",
    "vaguido": "va-gui-do",
    "váguido": "vá-gui-do",
    "vahaje": "va-ha-je",
    "vahar": "va-har",
    "vaharada": "va-ha-ra-da",
    "vaharera": "va-ha-re-ra",
    "vaharina": "va-ha-ri-na",
    "vahear": "va-he-ar",
    "vahído": "va-hí-do",
    "vaho": "va-ho",
    "vaída": "va-í-da",
    "vaina": "vai-na",
    "vainazas": "vai-na-zas",
    "vainazo": "vai-na-zo",
    "vainero": "vai-ne-ro",
    "vainica": "vai-ni-ca",
    "vainilla": "vai-ni-lla",
    "vainiquera": "vai-ni-que-ra",
    "vaivén": "vai-vén",
    "vaivenear": "vai-ve-ne-ar",
    "vaivoda": "vai-vo-da",
    "vajear": "va-je-ar",
    "vajilla": "va-ji-lla",
    "vajillo": "va-ji-llo",
    "valaca": "va-la-ca",
    "valaco": "va-la-co",
    "valais": "va-lais",
    "valar": "va-lar",
    "valdense": "val-den-se",
    "valdepeñas": "val-de-pe-ñas",
    "valdepeñera": "val-de-pe-ñe-ra",
    "valdepeñero": "val-de-pe-ñe-ro",
    "valdivia": "val-di-via",
    "valdiviana": "val-di-via-na",
    "valdiviano": "val-di-via-no",
    "vale": "va-le",
    "valedera": "va-le-de-ra",
    "valedero": "va-le-de-ro",
    "valedor": "va-le-dor",
    "valedora": "va-le-do-ra",
    "valedura": "va-le-du-ra",
    "valencia": "va-len-cia",
    "valenciana": "va-len-cia-na",
    "valencianidad": "va-len-cia-ni-dad",
    "valencianismo": "va-len-cia-nis-mo",
    "valenciano": "va-len-cia-no",
    "valentía": "va-len-tí-a",
    "valentina": "va-len-ti-na",
    "valentiniana": "va-len-ti-nia-na",
    "valentiniano": "va-len-ti-nia-no",
    "valentino": "va-len-ti-no",
    "valentísima": "va-len-tí-si-ma",
    "valentísimo": "va-len-tí-si-mo",
    "valentón": "va-len-tón",
    "valentona": "va-len-to-na",
    "valentonada": "va-len-to-na-da",
    "valenza": "va-len-za",
    "valer": "va-ler",
    "valerana": "va-le-ra-na",
    "valerano": "va-le-ra-no",
    "valeriana": "va-le-ria-na",
    "valerianácea": "va-le-ria-ná-ce-a",
    "valerianáceo": "va-le-ria-ná-ce-o",
    "valerianato": "va-le-ria-na-to",
    "valeriánico": "va-le-riá-ni-co",
    "valeriense": "va-le-rien-se",
    "valerosa": "va-le-ro-sa",
    "valerosamente": "va-le-ro-sa-men-te",
    "valerosidad": "va-le-ro-si-dad",
    "valeroso": "va-le-ro-so",
    "valet": "va-let",
    "valetudinaria": "va-le-tu-di-na-ria",
    "valetudinario": "va-le-tu-di-na-rio",
    "valeverguista": "va-le-ver-guis-ta",
    "valgo": "val-go",
    "valí": "va-lí",
    "valía": "va-lí-a",
    "valiato": "va-lia-to",
    "válida": "vá-li-da",
    "validación": "va-li-da-ción",
    "validador": "va-li-da-dor",
    "válidamente": "vá-li-da-men-te",
    "validar": "va-li-dar",
    "validez": "va-li-dez",
    "valido": "va-li-do",
    "válido": "vá-li-do",
    "valiente": "va-lien-te",
    "valientemente": "va-lien-te-men-te",
    "valija": "va-li-ja",
    "valijero": "va-li-je-ro",
    "valimiento": "va-li-mien-to",
    "valiosa": "va-lio-sa",
    "valioso": "va-lio-so",
    "valkiria": "val-ki-ria",
    "valla": "va-lla",
    "valladar": "va-lla-dar",
    "valladear": "va-lla-de-ar",
    "vallado": "va-lla-do",
    "vallar": "va-llar",
    "valle": "va-lle",
    "vallecaucana": "va-lle-cau-ca-na",
    "vallecaucano": "va-lle-cau-ca-no",
    "vallegrandina": "va-lle-gran-di-na",
    "vallegrandino": "va-lle-gran-di-no",
    "valleinclanesco": "va-llein-cla-nes-co",
    "vallenarina": "va-lle-na-ri-na",
    "vallenarino": "va-lle-na-ri-no",
    "vallenato": "va-lle-na-to",
    "valleño": "va-lle-ño",
    "vallense": "va-llen-se",
    "vallico": "va-lli-co",
    "vallisoletana": "va-lli-so-le-ta-na",
    "vallisoletano": "va-lli-so-le-ta-no",
    "vallista": "va-llis-ta",
    "vallisto": "va-llis-to",
    "valluna": "va-llu-na",
    "valluno": "va-llu-no",
    "valón": "va-lón",
    "valona": "va-lo-na",
    "valor": "va-lor",
    "valoración": "va-lo-ra-ción",
    "valorar": "va-lo-rar",
    "valorativo": "va-lo-ra-ti-vo",
    "valorear": "va-lo-re-ar",
    "valoría": "va-lo-rí-a",
    "valorización": "va-lo-ri-za-ción",
    "valorizador": "va-lo-ri-za-dor",
    "valorizar": "va-lo-ri-zar",
    "valquiria": "val-qui-ria",
    "valsar": "val-sar",
    "valse": "val-se",
    "valuación": "va-lua-ción",
    "valuador": "va-lua-dor",
    "valuadora": "va-lua-do-ra",
    "valuar": "va-luar",
    "valva": "val-va",
    "valvar": "val-var",
    "válvula": "vál-vu-la",
    "valvular": "val-vu-lar",
    "valvulina": "val-vu-li-na",
    "vampiresa": "vam-pi-re-sa",
    "vampírico": "vam-pí-ri-co",
    "vampirismo": "vam-pi-ris-mo",
    "vampirización": "vam-pi-ri-za-ción",
    "vampirizar": "vam-pi-ri-zar",
    "vampiro": "vam-pi-ro",
    "vana": "va-na",
    "vanadio": "va-na-dio",
    "vanagloria": "va-na-glo-ria",
    "vanagloriar": "va-na-glo-riar",
    "vanagloriarse": "va-na-glo-riar-se",
    "vanagloriosa": "va-na-glo-rio-sa",
    "vanagloriosamente": "va-na-glo-rio-sa-men-te",
    "vanaglorioso": "va-na-glo-rio-so",
    "vanamente": "va-na-men-te",
    "vándala": "ván-da-la",
    "vandalaje": "van-da-la-je",
    "vandálica": "van-dá-li-ca",
    "vandálicamente": "van-dá-li-ca-men-te",
    "vandálico": "van-dá-li-co",
    "vandalismo": "van-da-lis-mo",
    "vandalizar": "van-da-li-zar",
    "vándalo": "ván-da-lo",
    "vandeana": "van-de-a-na",
    "vandeano": "van-de-a-no",
    "vanear": "va-ne-ar",
    "vanesa": "va-ne-sa",
    "vanguarda": "van-guar-da",
    "vanguardia": "van-guar-dia",
    "vanguardismo": "van-guar-dis-mo",
    "vanguardista": "van-guar-dis-ta",
    "vanidad": "va-ni-dad",
    "vanidosa": "va-ni-do-sa",
    "vanidosamente": "va-ni-do-sa-men-te",
    "vanidoso": "va-ni-do-so",
    "vanílocua": "va-ní-lo-cua",
    "vanilocuencia": "va-ni-lo-cuen-cia",
    "vanilocuente": "va-ni-lo-cuen-te",
    "vanílocuo": "va-ní-lo-cuo",
    "vaniloquio": "va-ni-lo-quio",
    "vanistorio": "va-nis-to-rio",
    "vano": "va-no",
    "vánova": "vá-no-va",
    "vanuatuense": "va-nua-tuen-se",
    "vapor": "va-por",
    "vapora": "va-po-ra",
    "vaporable": "va-po-ra-ble",
    "vaporación": "va-po-ra-ción",
    "vaporar": "va-po-rar",
    "vaporario": "va-po-ra-rio",
    "vaporcito": "va-por-ci-to",
    "vaporear": "va-po-re-ar",
    "vaporeta": "va-po-re-ta",
    "vaporización": "va-po-ri-za-ción",
    "vaporizador": "va-po-ri-za-dor",
    "vaporizar": "va-po-ri-zar",
    "vaporosa": "va-po-ro-sa",
    "vaporosamente": "va-po-ro-sa-men-te",
    "vaporoso": "va-po-ro-so",
    "vapulación": "va-pu-la-ción",
    "vapulamiento": "va-pu-la-mien-to",
    "vapular": "va-pu-lar",
    "vapuleador": "va-pu-le-a-dor",
    "vapuleadora": "va-pu-le-a-do-ra",
    "vapuleamiento": "va-pu-le-a-mien-to",
    "vapulear": "va-pu-le-ar",
    "vapuleo": "va-pu-le-o",
    "vápulo": "vá-pu-lo",
    "vaquear": "va-que-ar",
    "vaqueiro": "va-quei-ro",
    "vaquera": "va-que-ra",
    "vaquería": "va-que-rí-a",
    "vaquerillo": "va-que-ri-llo",
    "vaqueriza": "va-que-ri-za",
    "vaquerizo": "va-que-ri-zo",
    "vaquero": "va-que-ro",
    "vaqueta": "va-que-ta",
    "vaquetón": "va-que-tón",
    "vaquetona": "va-que-to-na",
    "vaquilla": "va-qui-lla",
    "vaquillona": "va-qui-llo-na",
    "váquira": "vá-qui-ra",
    "váquiro": "vá-qui-ro",
    "vaquiruela": "va-qui-rue-la",
    "vara": "va-ra",
    "varada": "va-ra-da",
    "varadera": "va-ra-de-ra",
    "varadero": "va-ra-de-ro",
    "varado": "va-ra-do",
    "varadura": "va-ra-du-ra",
    "varal": "va-ral",
    "varamiento": "va-ra-mien-to",
    "varano": "va-ra-no",
    "varapalo": "va-ra-pa-lo",
    "varaplata": "va-ra-pla-ta",
    "varar": "va-rar",
    "varaseto": "va-ra-se-to",
    "varazo": "va-ra-zo",
    "varazón": "va-ra-zón",
    "varbasco": "var-bas-co",
    "vardasca": "var-das-ca",
    "vardascazo": "var-das-ca-zo",
    "várdula": "vár-du-la",
    "várdulo": "vár-du-lo",
    "varea": "va-re-a",
    "vareador": "va-re-a-dor",
    "vareadora": "va-re-a-do-ra",
    "vareaje": "va-re-a-je",
    "varear": "va-re-ar",
    "varejón": "va-re-jón",
    "varejonazo": "va-re-jo-na-zo",
    "varenga": "va-ren-ga",
    "vareo": "va-re-o",
    "vareta": "va-re-ta",
    "varetazo": "va-re-ta-zo",
    "varetear": "va-re-te-ar",
    "varetón": "va-re-tón",
    "varga": "var-ga",
    "varganal": "var-ga-nal",
    "várgano": "vár-ga-no",
    "vargueño": "var-gue-ño",
    "varguense": "var-guen-se",
    "varí": "va-rí",
    "varia": "va-ria",
    "variabilidad": "va-ria-bi-li-dad",
    "variable": "va-ria-ble",
    "variablemente": "va-ria-ble-men-te",
    "variación": "va-ria-ción",
    "variada": "va-ria-da",
    "variadamente": "va-ria-da-men-te",
    "variado": "va-ria-do",
    "variamente": "va-ria-men-te",
    "variamiento": "va-ria-mien-to",
    "variancia": "va-rian-cia",
    "variante": "va-rian-te",
    "varianza": "va-rian-za",
    "variar": "va-riar",
    "varice": "va-ri-ce",
    "várice": "vá-ri-ce",
    "varicela": "va-ri-ce-la",
    "varicocele": "va-ri-co-ce-le",
    "varicosa": "va-ri-co-sa",
    "varicoso": "va-ri-co-so",
    "variedad": "va-rie-dad",
    "variegación": "va-rie-ga-ción",
    "variegado": "va-rie-ga-do",
    "varietal": "va-rie-tal",
    "varietés": "va-rie-tés",
    "varilarguero": "va-ri-lar-gue-ro",
    "varilla": "va-ri-lla",
    "varillaje": "va-ri-lla-je",
    "varillera": "va-ri-lle-ra",
    "varillero": "va-ri-lle-ro",
    "vario": "va-rio",
    "variólica": "va-rió-li-ca",
    "variólico": "va-rió-li-co",
    "varioloide": "va-rio-loi-de",
    "variolosa": "va-rio-lo-sa",
    "varioloso": "va-rio-lo-so",
    "variopinto": "va-rio-pin-to",
    "varita": "va-ri-ta",
    "varitero": "va-ri-te-ro",
    "variz": "va-riz",
    "varizo": "va-ri-zo",
    "varo": "va-ro",
    "varolio": "va-ro-lio",
    "varón": "va-rón",
    "varona": "va-ro-na",
    "varonesa": "va-ro-ne-sa",
    "varonía": "va-ro-ní-a",
    "varonil": "va-ro-nil",
    "varonilmente": "va-ro-nil-men-te",
    "varraco": "va-rra-co",
    "varraquear": "va-rra-que-ar",
    "varraquera": "va-rra-que-ra",
    "varsoviana": "var-so-via-na",
    "varsoviano": "var-so-via-no",
    "vasa": "va-sa",
    "vasado": "va-sa-do",
    "vasadura": "va-sa-du-ra",
    "vasalla": "va-sa-lla",
    "vasallaje": "va-sa-lla-je",
    "vasallo": "va-sa-llo",
    "vasar": "va-sar",
    "vasca": "vas-ca",
    "vasco": "vas-co",
    "vascófila": "vas-có-fi-la",
    "vascófilo": "vas-có-fi-lo",
    "vascofrancés": "vas-co-fran-cés",
    "vascofrancesa": "vas-co-fran-ce-sa",
    "vascohablante": "vas-co-ha-blan-te",
    "vascóloga": "vas-có-lo-ga",
    "vascólogo": "vas-có-lo-go",
    "vascón": "vas-cón",
    "vascona": "vas-co-na",
    "vascongada": "vas-con-ga-da",
    "vascongado": "vas-con-ga-do",
    "vascónica": "vas-có-ni-ca",
    "vascónico": "vas-có-ni-co",
    "vascoparlante": "vas-co-par-lan-te",
    "vascuence": "vas-cuen-ce",
    "vascular": "vas-cu-lar",
    "vascularización": "vas-cu-la-ri-za-ción",
    "vasculosa": "vas-cu-lo-sa",
    "vasculoso": "vas-cu-lo-so",
    "vasectomía": "va-sec-to-mí-a",
    "vasectomizar": "va-sec-to-mi-zar",
    "vaselina": "va-se-li-na",
    "vasera": "va-se-ra",
    "vasija": "va-si-ja",
    "vasillo": "va-si-llo",
    "vasito": "va-si-to",
    "vaso": "va-so",
    "vasoconstricción": "va-so-cons-tric-ción",
    "vasoconstrictor": "va-so-cons-tric-tor",
    "vasodilatación": "va-so-di-la-ta-ción",
    "vasodilatador": "va-so-di-la-ta-dor",
    "vasomotor": "va-so-mo-tor",
    "vasquismo": "vas-quis-mo",
    "vasta": "vas-ta",
    "vastación": "vas-ta-ción",
    "vástago": "vás-ta-go",
    "vastaguera": "vas-ta-gue-ra",
    "vastamente": "vas-ta-men-te",
    "vastedad": "vas-te-dad",
    "vástiga": "vás-ti-ga",
    "vasto": "vas-to",
    "vataje": "va-ta-je",
    "vate": "va-te",
    "váter": "vá-ter",
    "vaticana": "va-ti-ca-na",
    "vaticanista": "va-ti-ca-nis-ta",
    "vaticano": "va-ti-ca-no",
    "vaticinador": "va-ti-ci-na-dor",
    "vaticinadora": "va-ti-ci-na-do-ra",
    "vaticinar": "va-ti-ci-nar",
    "vaticinio": "va-ti-ci-nio",
    "vatídica": "va-tí-di-ca",
    "vatídico": "va-tí-di-co",
    "vatímetro": "va-tí-me-tro",
    "vatio": "va-tio",
    "vaudeville": "vau-de-vi-lle",
    "vaupense": "vau-pen-se",
    "vaya": "va-ya",
    "vecera": "ve-ce-ra",
    "vecería": "ve-ce-rí-a",
    "vecero": "ve-ce-ro",
    "vecina": "ve-ci-na",
    "vecinal": "ve-ci-nal",
    "vecinamente": "ve-ci-na-men-te",
    "vecindad": "ve-cin-dad",
    "vecindado": "ve-cin-da-do",
    "vecindar": "ve-cin-dar",
    "vecindario": "ve-cin-da-rio",
    "vecindona": "ve-cin-do-na",
    "vecino": "ve-ci-no",
    "vectación": "vec-ta-ción",
    "vector": "vec-tor",
    "vectorial": "vec-to-rial",
    "vectorialmente": "vec-to-rial-men-te",
    "veda": "ve-da",
    "vedado": "ve-da-do",
    "vedamiento": "ve-da-mien-to",
    "vedar": "ve-dar",
    "vedegambre": "ve-de-gam-bre",
    "vedeja": "ve-de-ja",
    "vedetismo": "ve-de-tis-mo",
    "vedette": "ve-det-te",
    "vedettismo": "ve-det-tis-mo",
    "védico": "vé-di-co",
    "vedija": "ve-di-ja",
    "vedijera": "ve-di-je-ra",
    "vedijero": "ve-di-je-ro",
    "vedijosa": "ve-di-jo-sa",
    "vedijoso": "ve-di-jo-so",
    "vedijuda": "ve-di-ju-da",
    "vedijudo": "ve-di-ju-do",
    "vedismo": "ve-dis-mo",
    "veduño": "ve-du-ño",
    "veedor": "ve-e-dor",
    "veedora": "ve-e-do-ra",
    "veeduría": "ve-e-du-rí-a",
    "veer": "ve-er",
    "vega": "ve-ga",
    "vegada": "ve-ga-da",
    "vegana": "ve-ga-na",
    "vegano": "ve-ga-no",
    "vegetabilidad": "ve-ge-ta-bi-li-dad",
    "vegetable": "ve-ge-ta-ble",
    "vegetación": "ve-ge-ta-ción",
    "vegetal": "ve-ge-tal",
    "vegetalismo": "ve-ge-ta-lis-mo",
    "vegetalista": "ve-ge-ta-lis-ta",
    "vegetalmente": "ve-ge-tal-men-te",
    "vegetar": "ve-ge-tar",
    "vegetariana": "ve-ge-ta-ria-na",
    "vegetarianismo": "ve-ge-ta-ria-nis-mo",
    "vegetariano": "ve-ge-ta-ria-no",
    "vegetativa": "ve-ge-ta-ti-va",
    "vegetativamente": "ve-ge-ta-ti-va-men-te",
    "vegetativo": "ve-ge-ta-ti-vo",
    "vegosa": "ve-go-sa",
    "vegoso": "ve-go-so",
    "veguer": "ve-guer",
    "veguera": "ve-gue-ra",
    "veguería": "ve-gue-rí-a",
    "veguerío": "ve-gue-rí-o",
    "veguero": "ve-gue-ro",
    "vehemencia": "ve-he-men-cia",
    "vehemente": "ve-he-men-te",
    "vehementemente": "ve-he-men-te-men-te",
    "vehicular": "vehi-cu-lar",
    "vehículo": "ve-hí-cu-lo",
    "veimarés": "vei-ma-rés",
    "veimaresa": "vei-ma-re-sa",
    "veintava": "vein-ta-va",
    "veintavo": "vein-ta-vo",
    "veinte": "vein-te",
    "veinteañera": "vein-te-a-ñe-ra",
    "veinteañero": "vein-te-a-ñe-ro",
    "veinteavo": "vein-te-a-vo",
    "veintén": "vein-tén",
    "veintena": "vein-te-na",
    "veinteñal": "vein-te-ñal",
    "veintenar": "vein-te-nar",
    "veintenaria": "vein-te-na-ria",
    "veintenario": "vein-te-na-rio",
    "veintenero": "vein-te-ne-ro",
    "veinteno": "vein-te-no",
    "veinteochena": "vein-te-o-che-na",
    "veinteocheno": "vein-te-o-che-no",
    "veinteseisena": "vein-te-sei-se-na",
    "veinteseiseno": "vein-te-sei-se-no",
    "veintésima": "vein-té-si-ma",
    "veintésimo": "vein-té-si-mo",
    "veinticinco": "vein-ti-cin-co",
    "veinticuatrén": "vein-ti-cua-trén",
    "veinticuatrena": "vein-ti-cua-tre-na",
    "veinticuatreno": "vein-ti-cua-tre-no",
    "veinticuatría": "vein-ti-cua-trí-a",
    "veinticuatro": "vein-ti-cua-tro",
    "veintidós": "vein-ti-dós",
    "veintidosena": "vein-ti-do-se-na",
    "veintidoseno": "vein-ti-do-se-no",
    "veintinueve": "vein-ti-nue-ve",
    "veintiochena": "vein-tio-che-na",
    "veintiocheno": "vein-tio-che-no",
    "veintiocho": "vein-tio-cho",
    "veintiséis": "vein-ti-séis",
    "veintiseisena": "vein-ti-sei-se-na",
    "veintiseiseno": "vein-ti-sei-se-no",
    "veintisiete": "vein-ti-sie-te",
    "veintitantos": "vein-ti-tan-tos",
    "veintitrés": "vein-ti-trés",
    "veintiún": "vein-tiún",
    "veintiuna": "vein-tiu-na",
    "veintiuno": "vein-tiu-no",
    "vejación": "ve-ja-ción",
    "vejador": "ve-ja-dor",
    "vejadora": "ve-ja-do-ra",
    "vejamen": "ve-ja-men",
    "vejaminista": "ve-ja-mi-nis-ta",
    "vejancón": "ve-jan-cón",
    "vejancona": "ve-jan-co-na",
    "vejar": "ve-jar",
    "vejarrón": "ve-ja-rrón",
    "vejarrona": "ve-ja-rro-na",
    "vejatoria": "ve-ja-to-ria",
    "vejatoriamente": "ve-ja-to-ria-men-te",
    "vejatorio": "ve-ja-to-rio",
    "vejecer": "ve-je-cer",
    "vejedad": "ve-je-dad",
    "vejentud": "ve-jen-tud",
    "vejera": "ve-je-ra",
    "vejestorio": "ve-jes-to-rio",
    "vejeta": "ve-je-ta",
    "vejete": "ve-je-te",
    "vejez": "ve-jez",
    "vejezuela": "ve-je-zue-la",
    "vejezuelo": "ve-je-zue-lo",
    "vejiga": "ve-ji-ga",
    "vejigatoria": "ve-ji-ga-to-ria",
    "vejigatorio": "ve-ji-ga-to-rio",
    "vejigazo": "ve-ji-ga-zo",
    "vejigón": "ve-ji-gón",
    "vejigona": "ve-ji-go-na",
    "vejigosa": "ve-ji-go-sa",
    "vejigoso": "ve-ji-go-so",
    "vejiguilla": "ve-ji-gui-lla",
    "vejuca": "ve-ju-ca",
    "vejuco": "ve-ju-co",
    "vela": "ve-la",
    "velacho": "ve-la-cho",
    "velación": "ve-la-ción",
    "velada": "ve-la-da",
    "veladamente": "ve-la-da-men-te",
    "velado": "ve-la-do",
    "velador": "ve-la-dor",
    "veladora": "ve-la-do-ra",
    "veladura": "ve-la-du-ra",
    "velahí": "ve-la-hí",
    "velaje": "ve-la-je",
    "velambre": "ve-lam-bre",
    "velamen": "ve-la-men",
    "velar": "ve-lar",
    "velarización": "ve-la-ri-za-ción",
    "velarizar": "ve-la-ri-zar",
    "velarte": "ve-lar-te",
    "velatorio": "ve-la-to-rio",
    "velay": "ve-lay",
    "velazqueña": "ve-laz-que-ña",
    "velazqueño": "ve-laz-que-ño",
    "velcro": "vel-cro",
    "veleidad": "ve-lei-dad",
    "veleidosa": "ve-lei-do-sa",
    "veleidoso": "ve-lei-do-so",
    "velejar": "ve-le-jar",
    "velera": "ve-le-ra",
    "velería": "ve-le-rí-a",
    "velero": "ve-le-ro",
    "veleta": "ve-le-ta",
    "velete": "ve-le-te",
    "velicación": "ve-li-ca-ción",
    "velicar": "ve-li-car",
    "velicomen": "ve-li-co-men",
    "velilla": "ve-li-lla",
    "velillo": "ve-li-llo",
    "velintonia": "ve-lin-to-nia",
    "velís": "ve-lís",
    "vélite": "vé-li-te",
    "velívola": "ve-lí-vo-la",
    "velívolo": "ve-lí-vo-lo",
    "veliz": "ve-liz",
    "vellera": "ve-lle-ra",
    "vellida": "ve-lli-da",
    "vellido": "ve-lli-do",
    "vello": "ve-llo",
    "vellocino": "ve-llo-ci-no",
    "vellón": "ve-llón",
    "vellonero": "ve-llo-ne-ro",
    "véllora": "vé-llo-ra",
    "vellorí": "ve-llo-rí",
    "velloria": "ve-llo-ria",
    "vellorín": "ve-llo-rín",
    "vellorio": "ve-llo-rio",
    "vellorita": "ve-llo-ri-ta",
    "vellosa": "ve-llo-sa",
    "vellosidad": "ve-llo-si-dad",
    "vellosilla": "ve-llo-si-lla",
    "velloso": "ve-llo-so",
    "vellotado": "ve-llo-ta-do",
    "velluda": "ve-llu-da",
    "velludillo": "ve-llu-di-llo",
    "velludo": "ve-llu-do",
    "vellutera": "ve-llu-te-ra",
    "vellutero": "ve-llu-te-ro",
    "velmez": "vel-mez",
    "velo": "ve-lo",
    "veloce": "ve-lo-ce",
    "velocidad": "ve-lo-ci-dad",
    "velocímetro": "ve-lo-cí-me-tro",
    "velocipédica": "ve-lo-ci-pé-di-ca",
    "velocipédico": "ve-lo-ci-pé-di-co",
    "velocipedismo": "ve-lo-ci-pe-dis-mo",
    "velocipedista": "ve-lo-ci-pe-dis-ta",
    "velocípedo": "ve-lo-cí-pe-do",
    "velocirráptor": "ve-lo-ci-rráp-tor",
    "velocista": "ve-lo-cis-ta",
    "velódromo": "ve-ló-dro-mo",
    "velomotor": "ve-lo-mo-tor",
    "velón": "ve-lón",
    "velonera": "ve-lo-ne-ra",
    "velonero": "ve-lo-ne-ro",
    "velorio": "ve-lo-rio",
    "velorta": "ve-lor-ta",
    "velorto": "ve-lor-to",
    "veloz": "ve-loz",
    "velozmente": "ve-loz-men-te",
    "veludillo": "ve-lu-di-llo",
    "veludo": "ve-lu-do",
    "vena": "ve-na",
    "venable": "ve-na-ble",
    "venablo": "ve-na-blo",
    "venación": "ve-na-ción",
    "venada": "ve-na-da",
    "venadear": "ve-na-de-ar",
    "venadero": "ve-na-de-ro",
    "venado": "ve-na-do",
    "venador": "ve-na-dor",
    "venadriz": "ve-na-driz",
    "venaje": "ve-na-je",
    "venal": "ve-nal",
    "venalidad": "ve-na-li-dad",
    "venática": "ve-ná-ti-ca",
    "venático": "ve-ná-ti-co",
    "venatoria": "ve-na-to-ria",
    "venatorio": "ve-na-to-rio",
    "vencedera": "ven-ce-de-ra",
    "vencedero": "ven-ce-de-ro",
    "vencedor": "ven-ce-dor",
    "vencedora": "ven-ce-do-ra",
    "vencejera": "ven-ce-je-ra",
    "vencejo": "ven-ce-jo",
    "vencer": "ven-cer",
    "vencetósigo": "ven-ce-tó-si-go",
    "vencible": "ven-ci-ble",
    "vencida": "ven-ci-da",
    "vencimiento": "ven-ci-mien-to",
    "venda": "ven-da",
    "vendaje": "ven-da-je",
    "vendal": "ven-dal",
    "vendar": "ven-dar",
    "vendaval": "ven-da-val",
    "vendedera": "ven-de-de-ra",
    "vendedor": "ven-de-dor",
    "vendedora": "ven-de-do-ra",
    "vendehúmos": "ven-de-hú-mos",
    "vendeja": "ven-de-ja",
    "vender": "ven-der",
    "vendetta": "ven-det-ta",
    "vendí": "ven-dí",
    "vendible": "ven-di-ble",
    "vendición": "ven-di-ción",
    "véndida": "vén-di-da",
    "vendimia": "ven-di-mia",
    "vendimiador": "ven-di-mia-dor",
    "vendimiadora": "ven-di-mia-do-ra",
    "vendimiar": "ven-di-miar",
    "vendimiario": "ven-di-mia-rio",
    "vendo": "ven-do",
    "venduta": "ven-du-ta",
    "venecia": "ve-ne-cia",
    "veneciana": "ve-ne-cia-na",
    "veneciano": "ve-ne-cia-no",
    "venéfica": "ve-né-fi-ca",
    "veneficiar": "ve-ne-fi-ciar",
    "veneficio": "ve-ne-fi-cio",
    "venéfico": "ve-né-fi-co",
    "venencia": "ve-nen-cia",
    "venenífera": "ve-ne-ní-fe-ra",
    "venenífero": "ve-ne-ní-fe-ro",
    "veneno": "ve-ne-no",
    "venenosa": "ve-ne-no-sa",
    "venenosidad": "ve-ne-no-si-dad",
    "venenoso": "ve-ne-no-so",
    "venera": "ve-ne-ra",
    "venerable": "ve-ne-ra-ble",
    "venerablemente": "ve-ne-ra-ble-men-te",
    "veneración": "ve-ne-ra-ción",
    "venerador": "ve-ne-ra-dor",
    "veneradora": "ve-ne-ra-do-ra",
    "veneranda": "ve-ne-ran-da",
    "venerando": "ve-ne-ran-do",
    "venerar": "ve-ne-rar",
    "venérea": "ve-né-re-a",
    "venéreo": "ve-né-re-o",
    "venereóloga": "ve-ne-re-ó-lo-ga",
    "venereología": "ve-ne-re-o-lo-gí-a",
    "venereológico": "ve-ne-re-o-ló-gi-co",
    "venereólogo": "ve-ne-re-ó-lo-go",
    "venero": "ve-ne-ro",
    "véneta": "vé-ne-ta",
    "véneto": "vé-ne-to",
    "venezolana": "ve-ne-zo-la-na",
    "venezolanismo": "ve-ne-zo-la-nis-mo",
    "venezolanizar": "ve-ne-zo-la-ni-zar",
    "venezolano": "ve-ne-zo-la-no",
    "venezuela": "ve-ne-zue-la",
    "vengable": "ven-ga-ble",
    "vengador": "ven-ga-dor",
    "vengadora": "ven-ga-do-ra",
    "venganza": "ven-gan-za",
    "vengar": "ven-gar",
    "vengativa": "ven-ga-ti-va",
    "vengativamente": "ven-ga-ti-va-men-te",
    "vengativo": "ven-ga-ti-vo",
    "venia": "ve-nia",
    "venial": "ve-nial",
    "venialidad": "ve-nia-li-dad",
    "venialmente": "ve-nial-men-te",
    "venida": "ve-ni-da",
    "venidera": "ve-ni-de-ra",
    "venidero": "ve-ni-de-ro",
    "venimécum": "ve-ni-mé-cum",
    "venina": "ve-ni-na",
    "venino": "ve-ni-no",
    "venir": "ve-nir",
    "venopunción": "ve-no-pun-ción",
    "venosa": "ve-no-sa",
    "venosidad": "ve-no-si-dad",
    "venoso": "ve-no-so",
    "venta": "ven-ta",
    "ventada": "ven-ta-da",
    "ventador": "ven-ta-dor",
    "ventaja": "ven-ta-ja",
    "ventaje": "ven-ta-je",
    "ventajear": "ven-ta-je-ar",
    "ventajera": "ven-ta-je-ra",
    "ventajero": "ven-ta-je-ro",
    "ventajista": "ven-ta-jis-ta",
    "ventajosa": "ven-ta-jo-sa",
    "ventajosamente": "ven-ta-jo-sa-men-te",
    "ventajoso": "ven-ta-jo-so",
    "ventalla": "ven-ta-lla",
    "ventalle": "ven-ta-lle",
    "ventana": "ven-ta-na",
    "ventanaje": "ven-ta-na-je",
    "ventanal": "ven-ta-nal",
    "ventanazo": "ven-ta-na-zo",
    "ventanear": "ven-ta-ne-ar",
    "ventaneo": "ven-ta-ne-o",
    "ventanera": "ven-ta-ne-ra",
    "ventanero": "ven-ta-ne-ro",
    "ventanico": "ven-ta-ni-co",
    "ventanilla": "ven-ta-ni-lla",
    "ventanillo": "ven-ta-ni-llo",
    "ventano": "ven-ta-no",
    "ventanuco": "ven-ta-nu-co",
    "ventar": "ven-tar",
    "ventarrón": "ven-ta-rrón",
    "venteadura": "ven-te-a-du-ra",
    "ventear": "ven-te-ar",
    "ventera": "ven-te-ra",
    "venteril": "ven-te-ril",
    "venternera": "ven-ter-ne-ra",
    "venternero": "ven-ter-ne-ro",
    "venternía": "ven-ter-ní-a",
    "ventero": "ven-te-ro",
    "ventifarel": "ven-ti-fa-rel",
    "ventila": "ven-ti-la",
    "ventilación": "ven-ti-la-ción",
    "ventilador": "ven-ti-la-dor",
    "ventilar": "ven-ti-lar",
    "ventisca": "ven-tis-ca",
    "ventiscar": "ven-tis-car",
    "ventisco": "ven-tis-co",
    "ventiscosa": "ven-tis-co-sa",
    "ventiscoso": "ven-tis-co-so",
    "ventisquear": "ven-tis-que-ar",
    "ventisquero": "ven-tis-que-ro",
    "ventola": "ven-to-la",
    "ventolera": "ven-to-le-ra",
    "ventolín": "ven-to-lín",
    "ventolina": "ven-to-li-na",
    "ventor": "ven-tor",
    "ventora": "ven-to-ra",
    "ventorrero": "ven-to-rre-ro",
    "ventorrillo": "ven-to-rri-llo",
    "ventorro": "ven-to-rro",
    "ventosa": "ven-to-sa",
    "ventosear": "ven-to-se-ar",
    "ventosidad": "ven-to-si-dad",
    "ventoso": "ven-to-so",
    "ventrada": "ven-tra-da",
    "ventral": "ven-tral",
    "ventrecha": "ven-tre-cha",
    "ventregada": "ven-tre-ga-da",
    "ventrera": "ven-tre-ra",
    "ventresca": "ven-tres-ca",
    "ventricular": "ven-tri-cu-lar",
    "ventrículo": "ven-trí-cu-lo",
    "ventriculografía": "ven-tri-cu-lo-gra-fí-a",
    "ventril": "ven-tril",
    "ventrílocua": "ven-trí-lo-cua",
    "ventrílocuo": "ven-trí-lo-cuo",
    "ventriloquia": "ven-tri-lo-quia",
    "ventrisca": "ven-tris-ca",
    "ventrón": "ven-trón",
    "ventrosa": "ven-tro-sa",
    "ventroso": "ven-tro-so",
    "ventruda": "ven-tru-da",
    "ventrudo": "ven-tru-do",
    "ventura": "ven-tu-ra",
    "venturada": "ven-tu-ra-da",
    "venturado": "ven-tu-ra-do",
    "venturanza": "ven-tu-ran-za",
    "venturera": "ven-tu-re-ra",
    "venturero": "ven-tu-re-ro",
    "venturina": "ven-tu-ri-na",
    "venturo": "ven-tu-ro",
    "venturosa": "ven-tu-ro-sa",
    "venturosamente": "ven-tu-ro-sa-men-te",
    "venturoso": "ven-tu-ro-so",
    "vénula": "vé-nu-la",
    "venus": "ve-nus",
    "venusiano": "ve-nu-sia-no",
    "venusina": "ve-nu-si-na",
    "venusino": "ve-nu-si-no",
    "venusta": "ve-nus-ta",
    "venusterio": "ve-nus-te-rio",
    "venustez": "ve-nus-tez",
    "venustidad": "ve-nus-ti-dad",
    "venusto": "ve-nus-to",
    "vera": "ve-ra",
    "veracidad": "ve-ra-ci-dad",
    "veracruzana": "ve-ra-cru-za-na",
    "veracruzano": "ve-ra-cru-za-no",
    "veragüense": "ve-ra-güen-se",
    "veramente": "ve-ra-men-te",
    "veranada": "ve-ra-na-da",
    "veranadero": "ve-ra-na-de-ro",
    "veranar": "ve-ra-nar",
    "veranda": "ve-ran-da",
    "veraneante": "ve-ra-ne-an-te",
    "veranear": "ve-ra-ne-ar",
    "veraneo": "ve-ra-ne-o",
    "veranera": "ve-ra-ne-ra",
    "veranero": "ve-ra-ne-ro",
    "veraniega": "ve-ra-nie-ga",
    "veraniego": "ve-ra-nie-go",
    "veranillo": "ve-ra-ni-llo",
    "verano": "ve-ra-no",
    "veras": "ve-ras",
    "verascopio": "ve-ras-co-pio",
    "verata": "ve-ra-ta",
    "verato": "ve-ra-to",
    "veratrina": "ve-ra-tri-na",
    "veraz": "ve-raz",
    "verazmente": "ve-raz-men-te",
    "verba": "ver-ba",
    "verbal": "ver-bal",
    "verbalismo": "ver-ba-lis-mo",
    "verbalista": "ver-ba-lis-ta",
    "verbalistamente": "ver-ba-lis-ta-men-te",
    "verbalización": "ver-ba-li-za-ción",
    "verbalizar": "ver-ba-li-zar",
    "verbalmente": "ver-bal-men-te",
    "verbasco": "ver-bas-co",
    "verbena": "ver-be-na",
    "verbenácea": "ver-be-ná-ce-a",
    "verbenáceo": "ver-be-ná-ce-o",
    "verbenear": "ver-be-ne-ar",
    "verbenera": "ver-be-ne-ra",
    "verbenero": "ver-be-ne-ro",
    "verberación": "ver-be-ra-ción",
    "verberar": "ver-be-rar",
    "verbigracia": "ver-bi-gra-cia",
    "verbo": "ver-bo",
    "verborragia": "ver-bo-rra-gia",
    "verborrea": "ver-bo-rre-a",
    "verbosa": "ver-bo-sa",
    "verbosidad": "ver-bo-si-dad",
    "verboso": "ver-bo-so",
    "verdacho": "ver-da-cho",
    "verdad": "ver-dad",
    "verdadera": "ver-da-de-ra",
    "verdaderamente": "ver-da-de-ra-men-te",
    "verdadero": "ver-da-de-ro",
    "verdal": "ver-dal",
    "verdasca": "ver-das-ca",
    "verdascazo": "ver-das-ca-zo",
    "verde": "ver-de",
    "verdea": "ver-de-a",
    "verdear": "ver-de-ar",
    "verdeceladón": "ver-de-ce-la-dón",
    "verdeceledón": "ver-de-ce-le-dón",
    "verdecer": "ver-de-cer",
    "verdecillo": "ver-de-ci-llo",
    "verdegal": "ver-de-gal",
    "verdegay": "ver-de-gay",
    "verdeguear": "ver-de-gue-ar",
    "verdeja": "ver-de-ja",
    "verdejo": "ver-de-jo",
    "verdel": "ver-del",
    "verdemar": "ver-de-mar",
    "verdemontaña": "ver-de-mon-ta-ña",
    "verdeo": "ver-de-o",
    "verderol": "ver-de-rol",
    "verderón": "ver-de-rón",
    "verderona": "ver-de-ro-na",
    "verdete": "ver-de-te",
    "verdevejiga": "ver-de-ve-ji-ga",
    "verdezuela": "ver-de-zue-la",
    "verdezuelo": "ver-de-zue-lo",
    "verdial": "ver-dial",
    "verdiana": "ver-dia-na",
    "verdiano": "ver-dia-no",
    "verdigón": "ver-di-gón",
    "verdín": "ver-dín",
    "verdina": "ver-di-na",
    "verdinal": "ver-di-nal",
    "verdiñal": "ver-di-ñal",
    "verdinegra": "ver-di-ne-gra",
    "verdinegro": "ver-di-ne-gro",
    "verdino": "ver-di-no",
    "verdinosa": "ver-di-no-sa",
    "verdinoso": "ver-di-no-so",
    "verdiseca": "ver-di-se-ca",
    "verdiseco": "ver-di-se-co",
    "verdó": "ver-dó",
    "verdolaga": "ver-do-la-ga",
    "verdón": "ver-dón",
    "verdor": "ver-dor",
    "verdosa": "ver-do-sa",
    "verdoso": "ver-do-so",
    "verdoyo": "ver-do-yo",
    "verdugada": "ver-du-ga-da",
    "verdugado": "ver-du-ga-do",
    "verdugal": "ver-du-gal",
    "verdugazo": "ver-du-ga-zo",
    "verdugo": "ver-du-go",
    "verdugón": "ver-du-gón",
    "verduguear": "ver-du-gue-ar",
    "verduguillo": "ver-du-gui-llo",
    "verdulera": "ver-du-le-ra",
    "verdulería": "ver-du-le-rí-a",
    "verdulero": "ver-du-le-ro",
    "verdura": "ver-du-ra",
    "verdusca": "ver-dus-ca",
    "verdusco": "ver-dus-co",
    "verduzco": "ver-duz-co",
    "verecunda": "ve-re-cun-da",
    "verecundia": "ve-re-cun-dia",
    "verecundo": "ve-re-cun-do",
    "vereda": "ve-re-da",
    "veredaria": "ve-re-da-ria",
    "veredario": "ve-re-da-rio",
    "veredero": "ve-re-de-ro",
    "veredicto": "ve-re-dic-to",
    "verga": "ver-ga",
    "vergaceo": "ver-ga-ce-o",
    "vergajazo": "ver-ga-ja-zo",
    "vergajo": "ver-ga-jo",
    "vergatario": "ver-ga-ta-rio",
    "vergazal": "ver-ga-zal",
    "vergazo": "ver-ga-zo",
    "vergé": "ver-gé",
    "vergel": "ver-gel",
    "vergelero": "ver-ge-le-ro",
    "vergeta": "ver-ge-ta",
    "vergeteado": "ver-ge-te-a-do",
    "vergoloteo": "ver-go-lo-te-o",
    "vergón": "ver-gón",
    "vergona": "ver-go-na",
    "vergoña": "ver-go-ña",
    "vergoñosa": "ver-go-ño-sa",
    "vergoñoso": "ver-go-ño-so",
    "vergonzante": "ver-gon-zan-te",
    "vergonzantemente": "ver-gon-zan-te-men-te",
    "vergonzosa": "ver-gon-zo-sa",
    "vergonzosamente": "ver-gon-zo-sa-men-te",
    "vergonzoso": "ver-gon-zo-so",
    "vergueada": "ver-gue-a-da",
    "vergueador": "ver-gue-a-dor",
    "vergueadora": "ver-gue-a-do-ra",
    "verguear": "ver-gue-ar",
    "vergüeña": "ver-güe-ña",
    "vergüenza": "ver-güen-za",
    "vergueo": "ver-gue-o",
    "vergueta": "ver-gue-ta",
    "vergueteado": "ver-gue-te-a-do",
    "verguía": "ver-guí-a",
    "verguío": "ver-guí-o",
    "vericueto": "ve-ri-cue-to",
    "verídica": "ve-rí-di-ca",
    "verídicamente": "ve-rí-di-ca-men-te",
    "verídico": "ve-rí-di-co",
    "verificabilidad": "ve-ri-fi-ca-bi-li-dad",
    "verificable": "ve-ri-fi-ca-ble",
    "verificación": "ve-ri-fi-ca-ción",
    "verificador": "ve-ri-fi-ca-dor",
    "verificadora": "ve-ri-fi-ca-do-ra",
    "verificar": "ve-ri-fi-car",
    "verificativa": "ve-ri-fi-ca-ti-va",
    "verificativo": "ve-ri-fi-ca-ti-vo",
    "verífico": "ve-rí-fi-co",
    "verigüeto": "ve-ri-güe-to",
    "verija": "ve-ri-ja",
    "veril": "ve-ril",
    "verilear": "ve-ri-le-ar",
    "verisímil": "ve-ri-sí-mil",
    "verisimilitud": "ve-ri-si-mi-li-tud",
    "verisímilmente": "ve-ri-sí-mil-men-te",
    "verismo": "ve-ris-mo",
    "verista": "ve-ris-ta",
    "verja": "ver-ja",
    "verjurado": "ver-ju-ra-do",
    "verme": "ver-me",
    "vermicida": "ver-mi-ci-da",
    "vermicular": "ver-mi-cu-lar",
    "vermiculita": "ver-mi-cu-li-ta",
    "vermiforme": "ver-mi-for-me",
    "vermífuga": "ver-mí-fu-ga",
    "vermífugo": "ver-mí-fu-go",
    "verminosa": "ver-mi-no-sa",
    "verminoso": "ver-mi-no-so",
    "vermú": "ver-mú",
    "vermut": "ver-mut",
    "vernácula": "ver-ná-cu-la",
    "vernáculo": "ver-ná-cu-lo",
    "vernal": "ver-nal",
    "vernalizar": "ver-na-li-zar",
    "vernissage": "ver-nis-sa-ge",
    "vero": "ve-ro",
    "verolís": "ve-ro-lís",
    "veronal": "ve-ro-nal",
    "veronense": "ve-ro-nen-se",
    "veronés": "ve-ro-nés",
    "veronesa": "ve-ro-ne-sa",
    "verónica": "ve-ró-ni-ca",
    "veroniquear": "ve-ro-ni-que-ar",
    "verosímil": "ve-ro-sí-mil",
    "verosimilitud": "ve-ro-si-mi-li-tud",
    "verosímilmente": "ve-ro-sí-mil-men-te",
    "verraca": "ve-rra-ca",
    "verraco": "ve-rra-co",
    "verraquear": "ve-rra-que-ar",
    "verraquera": "ve-rra-que-ra",
    "verrionda": "ve-rrion-da",
    "verriondez": "ve-rrion-dez",
    "verriondo": "ve-rrion-do",
    "verroja": "ve-rro-ja",
    "verrojazo": "ve-rro-ja-zo",
    "verrojo": "ve-rro-jo",
    "verrón": "ve-rrón",
    "verrucaria": "ve-rru-ca-ria",
    "verruga": "ve-rru-ga",
    "verrugo": "ve-rru-go",
    "verrugosa": "ve-rru-go-sa",
    "verrugoso": "ve-rru-go-so",
    "verrugueta": "ve-rru-gue-ta",
    "verruguetar": "ve-rru-gue-tar",
    "versación": "ver-sa-ción",
    "versada": "ver-sa-da",
    "versado": "ver-sa-do",
    "versal": "ver-sal",
    "versalilla": "ver-sa-li-lla",
    "versalita": "ver-sa-li-ta",
    "versallesca": "ver-sa-lles-ca",
    "versallescamente": "ver-sa-lles-ca-men-te",
    "versallesco": "ver-sa-lles-co",
    "versar": "ver-sar",
    "versátil": "ver-sá-til",
    "versatilidad": "ver-sa-ti-li-dad",
    "versear": "ver-se-ar",
    "versería": "ver-se-rí-a",
    "versícula": "ver-sí-cu-la",
    "versicularia": "ver-si-cu-la-ria",
    "versiculario": "ver-si-cu-la-rio",
    "versículo": "ver-sí-cu-lo",
    "versificación": "ver-si-fi-ca-ción",
    "versificador": "ver-si-fi-ca-dor",
    "versificadora": "ver-si-fi-ca-do-ra",
    "versificar": "ver-si-fi-car",
    "versión": "ver-sión",
    "versionar": "ver-sio-nar",
    "versista": "ver-sis-ta",
    "verso": "ver-so",
    "versolari": "ver-so-la-ri",
    "versta": "vers-ta",
    "versucia": "ver-su-cia",
    "versus": "ver-sus",
    "versuta": "ver-su-ta",
    "versuto": "ver-su-to",
    "vértebra": "vér-te-bra",
    "vertebración": "ver-te-bra-ción",
    "vertebrado": "ver-te-bra-do",
    "vertebrador": "ver-te-bra-dor",
    "vertebral": "ver-te-bral",
    "vertebrar": "ver-te-brar",
    "vertedera": "ver-te-de-ra",
    "vertedero": "ver-te-de-ro",
    "vertedor": "ver-te-dor",
    "vertedora": "ver-te-do-ra",
    "vertello": "ver-te-llo",
    "verter": "ver-ter",
    "vertibilidad": "ver-ti-bi-li-dad",
    "vertible": "ver-ti-ble",
    "vertical": "ver-ti-cal",
    "verticalazo": "ver-ti-ca-la-zo",
    "verticalidad": "ver-ti-ca-li-dad",
    "verticalismo": "ver-ti-ca-lis-mo",
    "verticalista": "ver-ti-ca-lis-ta",
    "verticalizar": "ver-ti-ca-li-zar",
    "verticalmente": "ver-ti-cal-men-te",
    "vértice": "vér-ti-ce",
    "verticidad": "ver-ti-ci-dad",
    "verticilada": "ver-ti-ci-la-da",
    "verticilado": "ver-ti-ci-la-do",
    "verticilo": "ver-ti-ci-lo",
    "vertido": "ver-ti-do",
    "vertidos": "ver-ti-dos",
    "vertiente": "ver-tien-te",
    "vertiginosa": "ver-ti-gi-no-sa",
    "vertiginosamente": "ver-ti-gi-no-sa-men-te",
    "vertiginosidad": "ver-ti-gi-no-si-dad",
    "vertiginoso": "ver-ti-gi-no-so",
    "vértigo": "vér-ti-go",
    "vertimiento": "ver-ti-mien-to",
    "vesania": "ve-sa-nia",
    "vesánica": "ve-sá-ni-ca",
    "vesánicamente": "ve-sá-ni-ca-men-te",
    "vesánico": "ve-sá-ni-co",
    "vesical": "ve-si-cal",
    "vesicante": "ve-si-can-te",
    "vesicatorio": "ve-si-ca-to-rio",
    "vesícula": "ve-sí-cu-la",
    "vesicular": "ve-si-cu-lar",
    "vesiculosa": "ve-si-cu-lo-sa",
    "vesiculoso": "ve-si-cu-lo-so",
    "vesivilo": "ve-si-vi-lo",
    "vesor": "ve-sor",
    "vespa": "ves-pa",
    "vespasiana": "ves-pa-sia-na",
    "vesperal": "ves-pe-ral",
    "véspero": "vés-pe-ro",
    "vespertilio": "ves-per-ti-lio",
    "vespertina": "ves-per-ti-na",
    "vespertino": "ves-per-ti-no",
    "vespino": "ves-pi-no",
    "vesque": "ves-que",
    "vesta": "ves-ta",
    "vestal": "ves-tal",
    "veste": "ves-te",
    "vestecha": "ves-te-cha",
    "vestfaliana": "vest-fa-lia-na",
    "vestfaliano": "vest-fa-lia-no",
    "vestíbulo": "ves-tí-bu-lo",
    "vestido": "ves-ti-do",
    "vestidor": "ves-ti-dor",
    "vestidura": "ves-ti-du-ra",
    "vestigial": "ves-ti-gial",
    "vestigio": "ves-ti-gio",
    "vestiglo": "ves-ti-glo",
    "vestimenta": "ves-ti-men-ta",
    "vestimento": "ves-ti-men-to",
    "vestir": "ves-tir",
    "vestón": "ves-tón",
    "vestuario": "ves-tua-rio",
    "vestugo": "ves-tu-go",
    "veta": "ve-ta",
    "vetada": "ve-ta-da",
    "vetado": "ve-ta-do",
    "vetar": "ve-tar",
    "vetarra": "ve-ta-rra",
    "vetarro": "ve-ta-rro",
    "vetazo": "ve-ta-zo",
    "veteada": "ve-te-a-da",
    "veteado": "ve-te-a-do",
    "vetear": "ve-te-ar",
    "veterana": "ve-te-ra-na",
    "veteranía": "ve-te-ra-ní-a",
    "veterano": "ve-te-ra-no",
    "veterinaria": "ve-te-ri-na-ria",
    "veterinario": "ve-te-ri-na-rio",
    "veterotestamentario": "ve-te-ro-tes-ta-men-ta-rio",
    "vetisesgada": "ve-ti-ses-ga-da",
    "vetisesgado": "ve-ti-ses-ga-do",
    "vetiver": "ve-ti-ver",
    "veto": "ve-to",
    "vetón": "ve-tón",
    "vetona": "ve-to-na",
    "vetusta": "ve-tus-ta",
    "vetustez": "ve-tus-tez",
    "vetusto": "ve-tus-to",
    "vexilóloga": "ve-xi-ló-lo-ga",
    "vexilología": "ve-xi-lo-lo-gí-a",
    "vexilólogo": "ve-xi-ló-lo-go",
    "veza": "ve-za",
    "vezar": "ve-zar",
    "vezo": "ve-zo",
    "vía": "ví-a",
    "viabilidad": "via-bi-li-dad",
    "viabilizar": "via-bi-li-zar",
    "viable": "via-ble",
    "viacheña": "via-che-ña",
    "viacheño": "via-che-ño",
    "viada": "via-da",
    "viadera": "via-de-ra",
    "viador": "via-dor",
    "viaducto": "via-duc-to",
    "viagra": "via-gra",
    "viajadera": "via-ja-de-ra",
    "viajador": "via-ja-dor",
    "viajadora": "via-ja-do-ra",
    "viajante": "via-jan-te",
    "viajar": "via-jar",
    "viajata": "via-ja-ta",
    "viaje": "via-je",
    "viajera": "via-je-ra",
    "viajero": "via-je-ro",
    "vialidad": "via-li-dad",
    "vianda": "vian-da",
    "viandante": "vian-dan-te",
    "viandera": "vian-de-ra",
    "viandero": "vian-de-ro",
    "viaraza": "via-ra-za",
    "viario": "via-rio",
    "viaticar": "via-ti-car",
    "viático": "viá-ti-co",
    "víbora": "ví-bo-ra",
    "viborán": "vi-bo-rán",
    "viborear": "vi-bo-re-ar",
    "viborezno": "vi-bo-rez-no",
    "vibración": "vi-bra-ción",
    "vibrador": "vi-bra-dor",
    "vibrafonista": "vi-bra-fo-nis-ta",
    "vibráfono": "vi-brá-fo-no",
    "vibrante": "vi-bran-te",
    "vibrantemente": "vi-bran-te-men-te",
    "vibrar": "vi-brar",
    "vibrátil": "vi-brá-til",
    "vibrato": "vi-bra-to",
    "vibratorio": "vi-bra-to-rio",
    "vibrión": "vi-brión",
    "vibrisas": "vi-bri-sas",
    "viburno": "vi-bur-no",
    "vicaría": "vi-ca-rí-a",
    "vicaria": "vi-ca-ria",
    "vicarial": "vi-ca-rial",
    "vicariamente": "vi-ca-ria-men-te",
    "vicariante": "vi-ca-rian-te",
    "vicariato": "vi-ca-ria-to",
    "vicario": "vi-ca-rio",
    "vice": "vi-ce",
    "vicealmiranta": "vi-ce-al-mi-ran-ta",
    "vicealmirantazgo": "vi-ce-al-mi-ran-taz-go",
    "vicealmirante": "vi-ce-al-mi-ran-te",
    "vicecanciller": "vi-ce-can-ci-ller",
    "vicecancillería": "vi-ce-can-ci-lle-rí-a",
    "viceconsiliaria": "vi-ce-con-si-lia-ria",
    "viceconsiliario": "vi-ce-con-si-lia-rio",
    "vicecónsul": "vi-ce-cón-sul",
    "viceconsulado": "vi-ce-con-su-la-do",
    "vicecristo": "vi-ce-cris-to",
    "vicedecana": "vi-ce-de-ca-na",
    "vicedecanato": "vi-ce-de-ca-na-to",
    "vicedecano": "vi-ce-de-ca-no",
    "vicediós": "vi-ce-diós",
    "vicedirector": "vi-ce-di-rec-tor",
    "vicedirectora": "vi-ce-di-rec-to-ra",
    "vicegerencia": "vi-ce-ge-ren-cia",
    "vicegerente": "vi-ce-ge-ren-te",
    "vicegobernador": "vi-ce-go-ber-na-dor",
    "vicegobernadora": "vi-ce-go-ber-na-do-ra",
    "vicejefa": "vi-ce-je-fa",
    "vicejefe": "vi-ce-je-fe",
    "viceministra": "vi-ce-mi-nis-tra",
    "viceministro": "vi-ce-mi-nis-tro",
    "vicenal": "vi-ce-nal",
    "vicense": "vi-cen-se",
    "vicente": "vi-cen-te",
    "vicentina": "vi-cen-ti-na",
    "vicentino": "vi-cen-ti-no",
    "vicepresidencia": "vi-ce-pre-si-den-cia",
    "vicepresidencial": "vi-ce-pre-si-den-cial",
    "vicepresidenta": "vi-ce-pre-si-den-ta",
    "vicepresidente": "vi-ce-pre-si-den-te",
    "viceprovincia": "vi-ce-pro-vin-cia",
    "viceprovincial": "vi-ce-pro-vin-cial",
    "vicerrector": "vi-ce-rrec-tor",
    "vicerrectora": "vi-ce-rrec-to-ra",
    "vicesecretaría": "vi-ce-se-cre-ta-rí-a",
    "vicesecretaria": "vi-ce-se-cre-ta-ria",
    "vicesecretario": "vi-ce-se-cre-ta-rio",
    "vicésima": "vi-cé-si-ma",
    "vicesimario": "vi-ce-si-ma-rio",
    "vicésimo": "vi-cé-si-mo",
    "vicetesorera": "vi-ce-te-so-re-ra",
    "vicetesorero": "vi-ce-te-so-re-ro",
    "vicetiple": "vi-ce-ti-ple",
    "viceversa": "vi-ce-ver-sa",
    "vichadense": "vi-cha-den-se",
    "vichar": "vi-char",
    "vichear": "vi-che-ar",
    "vichyssoise": "vichys-soi-se",
    "vicia": "vi-cia",
    "viciar": "vi-ciar",
    "vicio": "vi-cio",
    "viciosa": "vi-cio-sa",
    "viciosamente": "vi-cio-sa-men-te",
    "vicioso": "vi-cio-so",
    "vicisitud": "vi-ci-si-tud",
    "vicisitudinario": "vi-ci-si-tu-di-na-rio",
    "vico": "vi-co",
    "víctima": "víc-ti-ma",
    "victimar": "vic-ti-mar",
    "victimaria": "vic-ti-ma-ria",
    "victimario": "vic-ti-ma-rio",
    "victimismo": "vic-ti-mis-mo",
    "victimista": "vic-ti-mis-ta",
    "victimización": "vic-ti-mi-za-ción",
    "victimizar": "vic-ti-mi-zar",
    "victo": "vic-to",
    "víctor": "víc-tor",
    "victorear": "vic-to-re-ar",
    "victoria": "vic-to-ria",
    "victoriano": "vic-to-ria-no",
    "victoriato": "vic-to-ria-to",
    "victoriosa": "vic-to-rio-sa",
    "victoriosamente": "vic-to-rio-sa-men-te",
    "victorioso": "vic-to-rio-so",
    "vicuña": "vi-cu-ña",
    "vida": "vi-da",
    "vidajena": "vi-da-je-na",
    "vidajenear": "vi-da-je-ne-ar",
    "vidala": "vi-da-la",
    "vidalita": "vi-da-li-ta",
    "vidarra": "vi-da-rra",
    "vide": "vi-de",
    "videncia": "vi-den-cia",
    "vidente": "vi-den-te",
    "video": "vi-de-o",
    "vídeo": "ví-de-o",
    "videoaficionada": "vi-de-o-a-fi-cio-na-da",
    "videoaficionado": "vi-de-o-a-fi-cio-na-do",
    "videocámara": "vi-de-o-cá-ma-ra",
    "videocasete": "vi-de-o-ca-se-te",
    "videocinta": "vi-de-o-cin-ta",
    "videoclip": "vi-de-o-clip",
    "videoclub": "vi-de-o-club",
    "videocomunicación": "vi-de-o-co-mu-ni-ca-ción",
    "videoconferencia": "vi-de-o-con-fe-ren-cia",
    "videoconsola": "vi-de-o-con-so-la",
    "videodisco": "vi-de-o-dis-co",
    "videofilmadora": "vi-de-o-fil-ma-do-ra",
    "videófono": "vi-de-ó-fo-no",
    "videofrecuencia": "vi-de-o-fre-cuen-cia",
    "videograbación": "vi-de-o-gra-ba-ción",
    "videograbador": "vi-de-o-gra-ba-dor",
    "videograbadora": "vi-de-o-gra-ba-do-ra",
    "videograbar": "vi-de-o-gra-bar",
    "videográfico": "vi-de-o-grá-fi-co",
    "videoimpresora": "vi-de-oim-pre-so-ra",
    "videoinformador": "vi-de-oin-for-ma-dor",
    "videoinformadora": "vi-de-oin-for-ma-do-ra",
    "videojuego": "vi-de-o-jue-go",
    "videolibro": "vi-de-o-li-bro",
    "videomarcador": "vi-de-o-mar-ca-dor",
    "videomensaje": "vi-de-o-men-sa-je",
    "videopirata": "vi-de-o-pi-ra-ta",
    "videoteca": "vi-de-o-te-ca",
    "videoteléfono": "vi-de-o-te-lé-fo-no",
    "videotex": "vi-de-o-tex",
    "videovigilancia": "vi-de-o-vi-gi-lan-cia",
    "vidia": "vi-dia",
    "vidón": "vi-dón",
    "vidorra": "vi-do-rra",
    "vidorria": "vi-do-rria",
    "vidriado": "vi-dria-do",
    "vidriar": "vi-driar",
    "vidriera": "vi-drie-ra",
    "vidriería": "vi-drie-rí-a",
    "vidrierista": "vi-drie-ris-ta",
    "vidriero": "vi-drie-ro",
    "vidrio": "vi-drio",
    "vidriosamente": "vi-drio-sa-men-te",
    "vidriosidad": "vi-drio-si-dad",
    "vidrioso": "vi-drio-so",
    "vidro": "vi-dro",
    "vidual": "vi-dual",
    "vidueño": "vi-due-ño",
    "viduño": "vi-du-ño",
    "vidurria": "vi-du-rria",
    "viedmense": "vied-men-se",
    "vieira": "viei-ra",
    "vieja": "vie-ja",
    "viejales": "vie-ja-les",
    "viejarrón": "vie-ja-rrón",
    "viejarrona": "vie-ja-rro-na",
    "viejera": "vie-je-ra",
    "viejita": "vie-ji-ta",
    "viejo": "vie-jo",
    "viejorrón": "vie-jo-rrón",
    "viejurga": "vie-jur-ga",
    "viejurgo": "vie-jur-go",
    "vienense": "vie-nen-se",
    "vienés": "vie-nés",
    "vienesa": "vie-ne-sa",
    "viento": "vien-to",
    "vientre": "vien-tre",
    "viequensa": "vie-quen-sa",
    "viequense": "vie-quen-se",
    "viernes": "vier-nes",
    "vierteaguas": "vier-te-a-guas",
    "viesa": "vie-sa",
    "viéspera": "viés-pe-ra",
    "vietnamita": "viet-na-mi-ta",
    "viga": "vi-ga",
    "vigencia": "vi-gen-cia",
    "vigente": "vi-gen-te",
    "vigesimal": "vi-ge-si-mal",
    "vigésimo": "vi-gé-si-mo",
    "vigía": "vi-gí-a",
    "vigiar": "vi-giar",
    "vigilancia": "vi-gi-lan-cia",
    "vigilante": "vi-gi-lan-te",
    "vigilantemente": "vi-gi-lan-te-men-te",
    "vigilar": "vi-gi-lar",
    "vigilativo": "vi-gi-la-ti-vo",
    "vigilia": "vi-gi-lia",
    "vigión": "vi-gión",
    "vigiona": "vi-gio-na",
    "vigitana": "vi-gi-ta-na",
    "vigitano": "vi-gi-ta-no",
    "vigo": "vi-go",
    "vigolero": "vi-go-le-ro",
    "vigor": "vi-gor",
    "vigorar": "vi-go-rar",
    "vigorizador": "vi-go-ri-za-dor",
    "vigorizante": "vi-go-ri-zan-te",
    "vigorizar": "vi-go-ri-zar",
    "vigorosamente": "vi-go-ro-sa-men-te",
    "vigorosidad": "vi-go-ro-si-dad",
    "vigoroso": "vi-go-ro-so",
    "vigota": "vi-go-ta",
    "viguería": "vi-gue-rí-a",
    "vigués": "vi-gués",
    "viguesa": "vi-gue-sa",
    "vigueta": "vi-gue-ta",
    "vihuela": "vi-hue-la",
    "vihuelista": "vi-hue-lis-ta",
    "vikingo": "vi-kin-go",
    "vilano": "vi-la-no",
    "vilera": "vi-le-ra",
    "vileza": "vi-le-za",
    "vílico": "ví-li-co",
    "vilipendiador": "vi-li-pen-dia-dor",
    "vilipendiadora": "vi-li-pen-dia-do-ra",
    "vilipendiar": "vi-li-pen-diar",
    "vilipendio": "vi-li-pen-dio",
    "vilipendioso": "vi-li-pen-dio-so",
    "villa": "vi-lla",
    "villabarquín": "vi-lla-bar-quín",
    "villaclareña": "vi-lla-cla-re-ña",
    "villaclareño": "vi-lla-cla-re-ño",
    "villadiego": "vi-lla-die-go",
    "villagodio": "vi-lla-go-dio",
    "villaje": "vi-lla-je",
    "villalón": "vi-lla-lón",
    "villamonteña": "vi-lla-mon-te-ña",
    "villamonteño": "vi-lla-mon-te-ño",
    "villana": "vi-lla-na",
    "villanada": "vi-lla-na-da",
    "villanaje": "vi-lla-na-je",
    "villanamente": "vi-lla-na-men-te",
    "villancejo": "vi-llan-ce-jo",
    "villancete": "vi-llan-ce-te",
    "villanchón": "vi-llan-chón",
    "villanchona": "vi-llan-cho-na",
    "villancico": "vi-llan-ci-co",
    "villanciquera": "vi-llan-ci-que-ra",
    "villanciquero": "vi-llan-ci-que-ro",
    "villanería": "vi-lla-ne-rí-a",
    "villanesca": "vi-lla-nes-ca",
    "villanesco": "vi-lla-nes-co",
    "villanía": "vi-lla-ní-a",
    "villano": "vi-lla-no",
    "villanovense": "vi-lla-no-ven-se",
    "villar": "vi-llar",
    "villarriqueña": "vi-lla-rri-que-ña",
    "villarriqueño": "vi-lla-rri-que-ño",
    "villavicenciuna": "vi-lla-vi-cen-ciu-na",
    "villavicenciuno": "vi-lla-vi-cen-ciu-no",
    "villavicense": "vi-lla-vi-cen-se",
    "villazgo": "vi-llaz-go",
    "villenense": "vi-lle-nen-se",
    "villera": "vi-lle-ra",
    "villería": "vi-lle-rí-a",
    "villero": "vi-lle-ro",
    "villismo": "vi-llis-mo",
    "villista": "vi-llis-ta",
    "villoría": "vi-llo-rí-a",
    "villorín": "vi-llo-rín",
    "villorrio": "vi-llo-rrio",
    "vilmente": "vil-men-te",
    "vilo": "vi-lo",
    "vilordo": "vi-lor-do",
    "vilorta": "vi-lor-ta",
    "vilorto": "vi-lor-to",
    "vilos": "vi-los",
    "vilote": "vi-lo-te",
    "viltrotear": "vil-tro-te-ar",
    "viltrotera": "vil-tro-te-ra",
    "vimbre": "vim-bre",
    "vimbrera": "vim-bre-ra",
    "viña": "vi-ña",
    "viñadera": "vi-ña-de-ra",
    "viñadero": "vi-ña-de-ro",
    "viñador": "vi-ña-dor",
    "viñadora": "vi-ña-do-ra",
    "vinagrada": "vi-na-gra-da",
    "vinagre": "vi-na-gre",
    "vinagrera": "vi-na-gre-ra",
    "vinagrero": "vi-na-gre-ro",
    "vinagreta": "vi-na-gre-ta",
    "vinagrillo": "vi-na-gri-llo",
    "vinagrón": "vi-na-grón",
    "vinagroso": "vi-na-gro-so",
    "vinajera": "vi-na-je-ra",
    "vinal": "vi-nal",
    "viñamarina": "vi-ña-ma-ri-na",
    "viñamarino": "vi-ña-ma-ri-no",
    "vinar": "vi-nar",
    "vinariego": "vi-na-rie-go",
    "vinario": "vi-na-rio",
    "vinatera": "vi-na-te-ra",
    "viñatera": "vi-ña-te-ra",
    "vinatería": "vi-na-te-rí-a",
    "vinatero": "vi-na-te-ro",
    "viñatero": "vi-ña-te-ro",
    "vinático": "vi-ná-ti-co",
    "vinaza": "vi-na-za",
    "vinazo": "vi-na-zo",
    "vinca": "vin-ca",
    "vincapervinca": "vin-ca-per-vin-ca",
    "vincha": "vin-cha",
    "vinchuca": "vin-chu-ca",
    "vinco": "vin-co",
    "vinculable": "vin-cu-la-ble",
    "vinculación": "vin-cu-la-ción",
    "vinculante": "vin-cu-lan-te",
    "vincular": "vin-cu-lar",
    "vínculo": "vín-cu-lo",
    "vindicación": "vin-di-ca-ción",
    "vindicador": "vin-di-ca-dor",
    "vindicadora": "vin-di-ca-do-ra",
    "vindicar": "vin-di-car",
    "vindicativamente": "vin-di-ca-ti-va-men-te",
    "vindicativo": "vin-di-ca-ti-vo",
    "vindicatorio": "vin-di-ca-to-rio",
    "vindicta": "vin-dic-ta",
    "viñedo": "vi-ñe-do",
    "viñera": "vi-ñe-ra",
    "viñero": "vi-ñe-ro",
    "viñeta": "vi-ñe-ta",
    "viñetero": "vi-ñe-te-ro",
    "vínica": "ví-ni-ca",
    "vínico": "ví-ni-co",
    "vinícola": "vi-ní-co-la",
    "vinicultor": "vi-ni-cul-tor",
    "vinicultora": "vi-ni-cul-to-ra",
    "vinicultura": "vi-ni-cul-tu-ra",
    "viniebla": "vi-nie-bla",
    "viniente": "vi-nien-te",
    "vinífero": "vi-ní-fe-ro",
    "vinificación": "vi-ni-fi-ca-ción",
    "vinílico": "vi-ní-li-co",
    "vinillo": "vi-ni-llo",
    "vinilo": "vi-ni-lo",
    "vino": "vi-no",
    "vinolencia": "vi-no-len-cia",
    "vinolento": "vi-no-len-to",
    "vinosidad": "vi-no-si-dad",
    "vinoso": "vi-no-so",
    "vinote": "vi-no-te",
    "vinotera": "vi-no-te-ra",
    "vinta": "vin-ta",
    "vintén": "vin-tén",
    "vintenera": "vin-te-ne-ra",
    "vintenero": "vin-te-ne-ro",
    "vintenes": "vin-te-nes",
    "viola": "vio-la",
    "violácea": "vio-lá-ce-a",
    "violáceo": "vio-lá-ce-o",
    "violación": "vio-la-ción",
    "violado": "vio-la-do",
    "violador": "vio-la-dor",
    "violadora": "vio-la-do-ra",
    "violar": "vio-lar",
    "violatorio": "vio-la-to-rio",
    "violencia": "vio-len-cia",
    "violentamente": "vio-len-ta-men-te",
    "violentar": "vio-len-tar",
    "violento": "vio-len-to",
    "violera": "vio-le-ra",
    "violero": "vio-le-ro",
    "violeta": "vio-le-ta",
    "violetera": "vio-le-te-ra",
    "violetero": "vio-le-te-ro",
    "violeto": "vio-le-to",
    "violía": "vio-lí-a",
    "violín": "vio-lín",
    "violineta": "vio-li-ne-ta",
    "violinista": "vio-li-nis-ta",
    "violón": "vio-lón",
    "violoncelista": "vio-lon-ce-lis-ta",
    "violoncello": "vio-lon-ce-llo",
    "violoncelo": "vio-lon-ce-lo",
    "violonchelista": "vio-lon-che-lis-ta",
    "violonchelo": "vio-lon-che-lo",
    "vipéreo": "vi-pé-re-o",
    "vipérido": "vi-pé-ri-do",
    "viperino": "vi-pe-ri-no",
    "vira": "vi-ra",
    "viracocha": "vi-ra-co-cha",
    "virada": "vi-ra-da",
    "virado": "vi-ra-do",
    "virador": "vi-ra-dor",
    "virago": "vi-ra-go",
    "viraje": "vi-ra-je",
    "viral": "vi-ral",
    "virar": "vi-rar",
    "viratón": "vi-ra-tón",
    "viravira": "vi-ra-vi-ra",
    "virazón": "vi-ra-zón",
    "vireco": "vi-re-co",
    "virelai": "vi-re-lai",
    "víreo": "ví-re-o",
    "virgaza": "vir-ga-za",
    "virgen": "vir-gen",
    "virgiliano": "vir-gi-lia-no",
    "virginal": "vir-gi-nal",
    "virginalero": "vir-gi-na-le-ro",
    "virginalmente": "vir-gi-nal-men-te",
    "virgíneo": "vir-gí-ne-o",
    "virginia": "vir-gi-nia",
    "virginiana": "vir-gi-nia-na",
    "virginiano": "vir-gi-nia-no",
    "virginidad": "vir-gi-ni-dad",
    "virgo": "vir-go",
    "virguera": "vir-gue-ra",
    "virguería": "vir-gue-rí-a",
    "virguero": "vir-gue-ro",
    "vírgula": "vír-gu-la",
    "virgulilla": "vir-gu-li-lla",
    "vírico": "ví-ri-co",
    "virigaza": "vi-ri-ga-za",
    "viril": "vi-ril",
    "virilidad": "vi-ri-li-dad",
    "virilismo": "vi-ri-lis-mo",
    "virilización": "vi-ri-li-za-ción",
    "virilizar": "vi-ri-li-zar",
    "virilmente": "vi-ril-men-te",
    "virina": "vi-ri-na",
    "viringo": "vi-rin-go",
    "virio": "vi-rio",
    "viripotencia": "vi-ri-po-ten-cia",
    "viripotente": "vi-ri-po-ten-te",
    "virol": "vi-rol",
    "virola": "vi-ro-la",
    "viroleño": "vi-ro-le-ño",
    "virolenta": "vi-ro-len-ta",
    "virolento": "vi-ro-len-to",
    "virolo": "vi-ro-lo",
    "viróloga": "vi-ró-lo-ga",
    "virología": "vi-ro-lo-gí-a",
    "virólogo": "vi-ró-lo-go",
    "virón": "vi-rón",
    "virósico": "vi-ró-si-co",
    "virosis": "vi-ro-sis",
    "virotazo": "vi-ro-ta-zo",
    "virote": "vi-ro-te",
    "virotillo": "vi-ro-ti-llo",
    "virotismo": "vi-ro-tis-mo",
    "virreina": "vi-rrei-na",
    "virreinal": "vi-rrei-nal",
    "virreinato": "vi-rrei-na-to",
    "virreino": "vi-rrei-no",
    "virrey": "vi-rrey",
    "virtual": "vir-tual",
    "virtualidad": "vir-tua-li-dad",
    "virtualmente": "vir-tual-men-te",
    "virtud": "vir-tud",
    "virtuosa": "vir-tuo-sa",
    "virtuosamente": "vir-tuo-sa-men-te",
    "virtuosidad": "vir-tuo-si-dad",
    "virtuosismo": "vir-tuo-sis-mo",
    "virtuosista": "vir-tuo-sis-ta",
    "virtuosístico": "vir-tuo-sís-ti-co",
    "virtuoso": "vir-tuo-so",
    "viruela": "vi-rue-la",
    "virulé": "vi-ru-lé",
    "virulencia": "vi-ru-len-cia",
    "virulentamente": "vi-ru-len-ta-men-te",
    "virulento": "vi-ru-len-to",
    "virus": "vi-rus",
    "viruta": "vi-ru-ta",
    "virutilla": "vi-ru-ti-lla",
    "visa": "vi-sa",
    "visado": "vi-sa-do",
    "visaje": "vi-sa-je",
    "visajero": "vi-sa-je-ro",
    "visar": "vi-sar",
    "viscacha": "vis-ca-cha",
    "víscera": "vís-ce-ra",
    "visceral": "vis-ce-ral",
    "visceralidad": "vis-ce-ra-li-dad",
    "visceralmente": "vis-ce-ral-men-te",
    "visco": "vis-co",
    "viscosa": "vis-co-sa",
    "viscosamente": "vis-co-sa-men-te",
    "viscosidad": "vis-co-si-dad",
    "viscosilla": "vis-co-si-lla",
    "viscosimetría": "vis-co-si-me-trí-a",
    "viscosímetro": "vis-co-sí-me-tro",
    "viscoso": "vis-co-so",
    "visear": "vi-se-ar",
    "visera": "vi-se-ra",
    "visibilidad": "vi-si-bi-li-dad",
    "visibilizar": "vi-si-bi-li-zar",
    "visible": "vi-si-ble",
    "visiblemente": "vi-si-ble-men-te",
    "visigoda": "vi-si-go-da",
    "visigodo": "vi-si-go-do",
    "visigótico": "vi-si-gó-ti-co",
    "visillo": "vi-si-llo",
    "visión": "vi-sión",
    "visionado": "vi-sio-na-do",
    "visionar": "vi-sio-nar",
    "visionaria": "vi-sio-na-ria",
    "visionario": "vi-sio-na-rio",
    "visionuda": "vi-sio-nu-da",
    "visionudo": "vi-sio-nu-do",
    "visir": "vi-sir",
    "visirato": "vi-si-ra-to",
    "visita": "vi-si-ta",
    "visitable": "vi-si-ta-ble",
    "visitación": "vi-si-ta-ción",
    "visitador": "vi-si-ta-dor",
    "visitadora": "vi-si-ta-do-ra",
    "visitante": "vi-si-tan-te",
    "visitar": "vi-si-tar",
    "visiteo": "vi-si-te-o",
    "visitero": "vi-si-te-ro",
    "visitón": "vi-si-tón",
    "visivo": "vi-si-vo",
    "vislumbrar": "vis-lum-brar",
    "vislumbre": "vis-lum-bre",
    "viso": "vi-so",
    "visogodo": "vi-so-go-do",
    "visón": "vi-són",
    "visontina": "vi-son-ti-na",
    "visontino": "vi-son-ti-no",
    "visor": "vi-sor",
    "visorio": "vi-so-rio",
    "visorreinado": "vi-so-rrei-na-do",
    "visorrey": "vi-so-rrey",
    "víspera": "vís-pe-ra",
    "vista": "vis-ta",
    "vistada": "vis-ta-da",
    "vistazo": "vis-ta-zo",
    "vistear": "vis-te-ar",
    "vistilla": "vis-ti-lla",
    "vistillas": "vis-ti-llas",
    "visto": "vis-to",
    "vistosamente": "vis-to-sa-men-te",
    "vistosidad": "vis-to-si-dad",
    "vistoso": "vis-to-so",
    "visual": "vi-sual",
    "visualidad": "vi-sua-li-dad",
    "visualización": "vi-sua-li-za-ción",
    "visualizador": "vi-sua-li-za-dor",
    "visualizar": "vi-sua-li-zar",
    "visualmente": "vi-sual-men-te",
    "visura": "vi-su-ra",
    "vitácea": "vi-tá-ce-a",
    "vitáceo": "vi-tá-ce-o",
    "vital": "vi-tal",
    "vitaliciamente": "vi-ta-li-cia-men-te",
    "vitalicio": "vi-ta-li-cio",
    "vitalicista": "vi-ta-li-cis-ta",
    "vitalidad": "vi-ta-li-dad",
    "vitalismo": "vi-ta-lis-mo",
    "vitalista": "vi-ta-lis-ta",
    "vitalización": "vi-ta-li-za-ción",
    "vitalizar": "vi-ta-li-zar",
    "vitalmente": "vi-tal-men-te",
    "vitamina": "vi-ta-mi-na",
    "vitaminado": "vi-ta-mi-na-do",
    "vitaminar": "vi-ta-mi-nar",
    "vitamínico": "vi-ta-mí-ni-co",
    "vitando": "vi-tan-do",
    "vitar": "vi-tar",
    "vitela": "vi-te-la",
    "vitelina": "vi-te-li-na",
    "vitelino": "vi-te-li-no",
    "vitelo": "vi-te-lo",
    "vitícola": "vi-tí-co-la",
    "viticultor": "vi-ti-cul-tor",
    "viticultora": "vi-ti-cul-to-ra",
    "viticultura": "vi-ti-cul-tu-ra",
    "vitivinícola": "vi-ti-vi-ní-co-la",
    "vitivinicultor": "vi-ti-vi-ni-cul-tor",
    "vitivinicultora": "vi-ti-vi-ni-cul-to-ra",
    "vitivinicultura": "vi-ti-vi-ni-cul-tu-ra",
    "vito": "vi-to",
    "vitola": "vi-to-la",
    "vitoqueada": "vi-to-que-a-da",
    "vitoqueado": "vi-to-que-a-do",
    "vitoquear": "vi-to-que-ar",
    "vítor": "ví-tor",
    "vitorear": "vi-to-re-ar",
    "vitoria": "vi-to-ria",
    "vitoriana": "vi-to-ria-na",
    "vitoriano": "vi-to-ria-no",
    "vitorioso": "vi-to-rio-so",
    "vitral": "vi-tral",
    "vitre": "vi-tre",
    "vítrea": "ví-tre-a",
    "vítreo": "ví-tre-o",
    "vitrificable": "vi-tri-fi-ca-ble",
    "vitrificación": "vi-tri-fi-ca-ción",
    "vitrificar": "vi-tri-fi-car",
    "vitrina": "vi-tri-na",
    "vitrinear": "vi-tri-ne-ar",
    "vitriólico": "vi-trió-li-co",
    "vitriolo": "vi-trio-lo",
    "vitrocerámica": "vi-tro-ce-rá-mi-ca",
    "vitrocerámico": "vi-tro-ce-rá-mi-co",
    "vitrola": "vi-tro-la",
    "vitualla": "vi-tua-lla",
    "vituallar": "vi-tua-llar",
    "vítulo": "ví-tu-lo",
    "vituperable": "vi-tu-pe-ra-ble",
    "vituperación": "vi-tu-pe-ra-ción",
    "vituperador": "vi-tu-pe-ra-dor",
    "vituperadora": "vi-tu-pe-ra-do-ra",
    "vituperante": "vi-tu-pe-ran-te",
    "vituperar": "vi-tu-pe-rar",
    "vituperio": "vi-tu-pe-rio",
    "vituperiosamente": "vi-tu-pe-rio-sa-men-te",
    "vituperioso": "vi-tu-pe-rio-so",
    "vituperosamente": "vi-tu-pe-ro-sa-men-te",
    "vituperoso": "vi-tu-pe-ro-so",
    "viuda": "viu-da",
    "viudal": "viu-dal",
    "viudedad": "viu-de-dad",
    "viudez": "viu-dez",
    "viudita": "viu-di-ta",
    "viudo": "viu-do",
    "viura": "viu-ra",
    "vivac": "vi-vac",
    "vivace": "vi-va-ce",
    "vivacidad": "vi-va-ci-dad",
    "vivalavirgen": "vi-va-la-vir-gen",
    "vivaldiano": "vi-val-dia-no",
    "vivales": "vi-va-les",
    "vivamente": "vi-va-men-te",
    "vivandera": "vi-van-de-ra",
    "vivandero": "vi-van-de-ro",
    "vivaque": "vi-va-que",
    "vivaquear": "vi-va-que-ar",
    "vivar": "vi-var",
    "vivaracho": "vi-va-ra-cho",
    "vivariense": "vi-va-rien-se",
    "vivario": "vi-va-rio",
    "vivaz": "vi-vaz",
    "vivazmente": "vi-vaz-men-te",
    "vivencia": "vi-ven-cia",
    "vivencial": "vi-ven-cial",
    "vivera": "vi-ve-ra",
    "viveral": "vi-ve-ral",
    "víveres": "ví-ve-res",
    "viverista": "vi-ve-ris-ta",
    "vivero": "vi-ve-ro",
    "vivérrido": "vi-vé-rri-do",
    "vivez": "vi-vez",
    "viveza": "vi-ve-za",
    "vivián": "vi-vián",
    "vívida": "ví-vi-da",
    "vívidamente": "ví-vi-da-men-te",
    "vividero": "vi-vi-de-ro",
    "vivido": "vi-vi-do",
    "vívido": "ví-vi-do",
    "vividor": "vi-vi-dor",
    "vividora": "vi-vi-do-ra",
    "vivienda": "vi-vien-da",
    "viviente": "vi-vien-te",
    "vivificación": "vi-vi-fi-ca-ción",
    "vivificador": "vi-vi-fi-ca-dor",
    "vivificante": "vi-vi-fi-can-te",
    "vivificar": "vi-vi-fi-car",
    "vivificativo": "vi-vi-fi-ca-ti-vo",
    "vivífico": "vi-ví-fi-co",
    "vivijagua": "vi-vi-ja-gua",
    "vivípara": "vi-ví-pa-ra",
    "vivíparo": "vi-ví-pa-ro",
    "vivir": "vi-vir",
    "vivisección": "vi-vi-sec-ción",
    "vivismo": "vi-vis-mo",
    "vivista": "vi-vis-ta",
    "vivo": "vi-vo",
    "vivón": "vi-vón",
    "vivona": "vi-vo-na",
    "viyela": "vi-ye-la",
    "vizcacha": "viz-ca-cha",
    "vizcachera": "viz-ca-che-ra",
    "vizcaina": "viz-cai-na",
    "vizcainada": "viz-cai-na-da",
    "vizcaíno": "viz-ca-í-no",
    "vizcaitarra": "viz-cai-ta-rra",
    "vizcondado": "viz-con-da-do",
    "vizconde": "viz-con-de",
    "vizcondesa": "viz-con-de-sa",
    "voacé": "vo-a-cé",
    "vocablo": "vo-ca-blo",
    "vocabulario": "vo-ca-bu-la-rio",
    "vocabulista": "vo-ca-bu-lis-ta",
    "vocación": "vo-ca-ción",
    "vocacional": "vo-ca-cio-nal",
    "vocacionalmente": "vo-ca-cio-nal-men-te",
    "vocal": "vo-cal",
    "vocálico": "vo-cá-li-co",
    "vocalismo": "vo-ca-lis-mo",
    "vocalista": "vo-ca-lis-ta",
    "vocalización": "vo-ca-li-za-ción",
    "vocalizador": "vo-ca-li-za-dor",
    "vocalizar": "vo-ca-li-zar",
    "vocalmente": "vo-cal-men-te",
    "vocativo": "vo-ca-ti-vo",
    "voceador": "vo-ce-a-dor",
    "voceadora": "vo-ce-a-do-ra",
    "vocear": "vo-ce-ar",
    "vocejón": "vo-ce-jón",
    "voceo": "vo-ce-o",
    "vocera": "vo-ce-ra",
    "voceras": "vo-ce-ras",
    "vocería": "vo-ce-rí-a",
    "vocerío": "vo-ce-rí-o",
    "vocero": "vo-ce-ro",
    "vocerón": "vo-ce-rón",
    "vocerrón": "vo-ce-rrón",
    "vociferación": "vo-ci-fe-ra-ción",
    "vociferador": "vo-ci-fe-ra-dor",
    "vociferadora": "vo-ci-fe-ra-do-ra",
    "vociferante": "vo-ci-fe-ran-te",
    "vociferar": "vo-ci-fe-rar",
    "vocinglera": "vo-cin-gle-ra",
    "vocinglería": "vo-cin-gle-rí-a",
    "vocinglero": "vo-cin-gle-ro",
    "vodca": "vod-ca",
    "vodevil": "vo-de-vil",
    "vodevilesco": "vo-de-vi-les-co",
    "vodka": "vod-ka",
    "vodú": "vo-dú",
    "voduismo": "vo-duis-mo",
    "voila": "voi-la",
    "volada": "vo-la-da",
    "voladera": "vo-la-de-ra",
    "voladero": "vo-la-de-ro",
    "voladito": "vo-la-di-to",
    "voladizo": "vo-la-di-zo",
    "volado": "vo-la-do",
    "volador": "vo-la-dor",
    "voladora": "vo-la-do-ra",
    "voladura": "vo-la-du-ra",
    "volandas": "vo-lan-das",
    "volandera": "vo-lan-de-ra",
    "volanderamente": "vo-lan-de-ra-men-te",
    "volandero": "vo-lan-de-ro",
    "volandillas": "vo-lan-di-llas",
    "volando": "vo-lan-do",
    "volanta": "vo-lan-ta",
    "volantazo": "vo-lan-ta-zo",
    "volante": "vo-lan-te",
    "volantear": "vo-lan-te-ar",
    "volantín": "vo-lan-tín",
    "volantinero": "vo-lan-ti-ne-ro",
    "volantón": "vo-lan-tón",
    "volantona": "vo-lan-to-na",
    "volapié": "vo-la-pié",
    "volapuk": "vo-la-puk",
    "volar": "vo-lar",
    "volateo": "vo-la-te-o",
    "volatería": "vo-la-te-rí-a",
    "volatero": "vo-la-te-ro",
    "volátil": "vo-lá-til",
    "volatilidad": "vo-la-ti-li-dad",
    "volatilizable": "vo-la-ti-li-za-ble",
    "volatilización": "vo-la-ti-li-za-ción",
    "volatilizar": "vo-la-ti-li-zar",
    "volatilla": "vo-la-ti-lla",
    "volatín": "vo-la-tín",
    "volatinera": "vo-la-ti-ne-ra",
    "volatinero": "vo-la-ti-ne-ro",
    "volatizar": "vo-la-ti-zar",
    "volavérunt": "vo-la-vé-runt",
    "volcán": "vol-cán",
    "volcánicamente": "vol-cá-ni-ca-men-te",
    "volcánico": "vol-cá-ni-co",
    "volcanismo": "vol-ca-nis-mo",
    "volcanóloga": "vol-ca-nó-lo-ga",
    "volcanología": "vol-ca-no-lo-gí-a",
    "volcanólogo": "vol-ca-nó-lo-go",
    "volcar": "vol-car",
    "volea": "vo-le-a",
    "volear": "vo-le-ar",
    "voleibol": "vo-lei-bol",
    "voleo": "vo-le-o",
    "voley": "vo-ley",
    "volframio": "vol-fra-mio",
    "volición": "vo-li-ción",
    "volido": "vo-li-do",
    "volitar": "vo-li-tar",
    "volitivamente": "vo-li-ti-va-men-te",
    "volitivo": "vo-li-ti-vo",
    "volón": "vo-lón",
    "volován": "vo-lo-ván",
    "volquear": "vol-que-ar",
    "volqueta": "vol-que-ta",
    "volquetazo": "vol-que-ta-zo",
    "volquete": "vol-que-te",
    "volquetero": "vol-que-te-ro",
    "volsca": "vols-ca",
    "volsco": "vols-co",
    "volta": "vol-ta",
    "voltaico": "vol-tai-co",
    "voltaje": "vol-ta-je",
    "voltámetro": "vol-tá-me-tro",
    "voltariedad": "vol-ta-rie-dad",
    "voltario": "vol-ta-rio",
    "volteada": "vol-te-a-da",
    "volteado": "vol-te-a-do",
    "volteador": "vol-te-a-dor",
    "volteadora": "vol-te-a-do-ra",
    "volteante": "vol-te-an-te",
    "voltear": "vol-te-ar",
    "voltejar": "vol-te-jar",
    "voltejear": "vol-te-je-ar",
    "volteleta": "vol-te-le-ta",
    "volteo": "vol-te-o",
    "voltereta": "vol-te-re-ta",
    "volteriana": "vol-te-ria-na",
    "volterianamente": "vol-te-ria-na-men-te",
    "volterianismo": "vol-te-ria-nis-mo",
    "volteriano": "vol-te-ria-no",
    "volteta": "vol-te-ta",
    "voltímetro": "vol-tí-me-tro",
    "voltio": "vol-tio",
    "voltizo": "vol-ti-zo",
    "voltura": "vol-tu-ra",
    "volubilidad": "vo-lu-bi-li-dad",
    "voluble": "vo-lu-ble",
    "volumen": "vo-lu-men",
    "volumetría": "vo-lu-me-trí-a",
    "volumétrico": "vo-lu-mé-tri-co",
    "volúmine": "vo-lú-mi-ne",
    "voluminoso": "vo-lu-mi-no-so",
    "voluntad": "vo-lun-tad",
    "voluntaria": "vo-lun-ta-ria",
    "voluntariado": "vo-lun-ta-ria-do",
    "voluntariamente": "vo-lun-ta-ria-men-te",
    "voluntariedad": "vo-lun-ta-rie-dad",
    "voluntario": "vo-lun-ta-rio",
    "voluntariosamente": "vo-lun-ta-rio-sa-men-te",
    "voluntarioso": "vo-lun-ta-rio-so",
    "voluntarismo": "vo-lun-ta-ris-mo",
    "voluntarista": "vo-lun-ta-ris-ta",
    "voluptuosa": "vo-lup-tuo-sa",
    "voluptuosamente": "vo-lup-tuo-sa-men-te",
    "voluptuosidad": "vo-lup-tuo-si-dad",
    "voluptuoso": "vo-lup-tuo-so",
    "voluta": "vo-lu-ta",
    "volva": "vol-va",
    "volvedera": "vol-ve-de-ra",
    "volvedor": "vol-ve-dor",
    "volver": "vol-ver",
    "volvible": "vol-vi-ble",
    "volvo": "vol-vo",
    "volvox": "vol-vox",
    "vólvulo": "vól-vu-lo",
    "vómer": "vó-mer",
    "vómica": "vó-mi-ca",
    "vómico": "vó-mi-co",
    "vomipurgante": "vo-mi-pur-gan-te",
    "vomipurgativo": "vo-mi-pur-ga-ti-vo",
    "vomitadera": "vo-mi-ta-de-ra",
    "vomitado": "vo-mi-ta-do",
    "vomitador": "vo-mi-ta-dor",
    "vomitadora": "vo-mi-ta-do-ra",
    "vomitar": "vo-mi-tar",
    "vomitel": "vo-mi-tel",
    "vomitera": "vo-mi-te-ra",
    "vomitivo": "vo-mi-ti-vo",
    "vómito": "vó-mi-to",
    "vomitón": "vo-mi-tón",
    "vomitona": "vo-mi-to-na",
    "vomitoria": "vo-mi-to-ria",
    "vomitorio": "vo-mi-to-rio",
    "voquible": "vo-qui-ble",
    "vorace": "vo-ra-ce",
    "voracidad": "vo-ra-ci-dad",
    "vorágine": "vo-rá-gi-ne",
    "voraginoso": "vo-ra-gi-no-so",
    "vorahúnda": "vo-ra-hún-da",
    "voraz": "vo-raz",
    "vorazmente": "vo-raz-men-te",
    "vormela": "vor-me-la",
    "vórtice": "vór-ti-ce",
    "vorticela": "vor-ti-ce-la",
    "vorticismo": "vor-ti-cis-mo",
    "vortiginoso": "vor-ti-gi-no-so",
    "vosear": "vo-se-ar",
    "voseo": "vo-se-o",
    "voso": "vo-so",
    "vosotros": "vo-so-tros",
    "votación": "vo-ta-ción",
    "votada": "vo-ta-da",
    "votador": "vo-ta-dor",
    "votadora": "vo-ta-do-ra",
    "votante": "vo-tan-te",
    "votar": "vo-tar",
    "votivo": "vo-ti-vo",
    "voto": "vo-to",
    "votri": "vo-tri",
    "voyerismo": "vo-ye-ris-mo",
    "voyerista": "vo-ye-ris-ta",
    "voyeur": "vo-yeur",
    "voyeurismo": "vo-yeu-ris-mo",
    "vozarrón": "vo-za-rrón",
    "vozarrona": "vo-za-rro-na",
    "voznar": "voz-nar",
    "vudú": "vu-dú",
    "vuduismo": "vu-duis-mo",
    "vuduista": "vu-duis-ta",
    "vuecelencia": "vue-ce-len-cia",
    "vuecencia": "vue-cen-cia",
    "vuelacerca": "vue-la-cer-ca",
    "vuelacercas": "vue-la-cer-cas",
    "vuelapié": "vue-la-pié",
    "vuelapluma": "vue-la-plu-ma",
    "vuelco": "vuel-co",
    "vuelillo": "vue-li-llo",
    "vuelo": "vue-lo",
    "vuelta": "vuel-ta",
    "vuelto": "vuel-to",
    "vueludo": "vue-lu-do",
    "vuelvepiedras": "vuel-ve-pie-dras",
    "vuesarced": "vue-sar-ced",
    "vueseñoría": "vue-se-ño-rí-a",
    "vueso": "vue-so",
    "vuestro": "vues-tro",
    "vulcaniano": "vul-ca-nia-no",
    "vulcanio": "vul-ca-nio",
    "vulcanismo": "vul-ca-nis-mo",
    "vulcanista": "vul-ca-nis-ta",
    "vulcanita": "vul-ca-ni-ta",
    "vulcanización": "vul-ca-ni-za-ción",
    "vulcanizadora": "vul-ca-ni-za-do-ra",
    "vulcanizar": "vul-ca-ni-zar",
    "vulcanóloga": "vul-ca-nó-lo-ga",
    "vulcanología": "vul-ca-no-lo-gí-a",
    "vulcanológico": "vul-ca-no-ló-gi-co",
    "vulcanólogo": "vul-ca-nó-lo-go",
    "vulgacho": "vul-ga-cho",
    "vulgado": "vul-ga-do",
    "vulgar": "vul-gar",
    "vulgaridad": "vul-ga-ri-dad",
    "vulgarismo": "vul-ga-ris-mo",
    "vulgarización": "vul-ga-ri-za-ción",
    "vulgarizador": "vul-ga-ri-za-dor",
    "vulgarizadora": "vul-ga-ri-za-do-ra",
    "vulgarizar": "vul-ga-ri-zar",
    "vulgarmente": "vul-gar-men-te",
    "vulgata": "vul-ga-ta",
    "vulgo": "vul-go",
    "vulnerabilidad": "vul-ne-ra-bi-li-dad",
    "vulnerable": "vul-ne-ra-ble",
    "vulneración": "vul-ne-ra-ción",
    "vulnerar": "vul-ne-rar",
    "vulnerario": "vul-ne-ra-rio",
    "vulpécula": "vul-pé-cu-la",
    "vulpeja": "vul-pe-ja",
    "vulpino": "vul-pi-no",
    "vulto": "vul-to",
    "vultuoso": "vul-tuo-so",
    "vulturín": "vul-tu-rín",
    "vulturno": "vul-tur-no",
    "vulva": "vul-va",
    "vusco": "vus-co",
    "vusted": "vus-ted",
    "wagneriana": "wag-ne-ria-na",
    "wagneriano": "wag-ne-ria-no",
    "wahabita": "wa-ha-bi-ta",
    "walkiria": "wal-ki-ria",
    "wampum": "wam-pum",
    "wapití": "wa-pi-tí",
    "warao": "wa-ra-o",
    "washingtoniana": "was-hing-to-nia-na",
    "washingtoniano": "was-hing-to-nia-no",
    "wáter": "wá-ter",
    "waterpolista": "wa-ter-po-lis-ta",
    "waterpolo": "wa-ter-po-lo",
    "wéber": "wé-ber",
    "weberio": "we-be-rio",
    "weblog": "we-blog",
    "weimarés": "wei-ma-rés",
    "weimaresa": "wei-ma-re-sa",
    "wellingtonia": "we-lling-to-nia",
    "wéstern": "wés-tern",
    "westfaliana": "west-fa-lia-na",
    "westfaliano": "west-fa-lia-no",
    "wetex": "we-tex",
    "whippet": "whip-pet",
    "whiskería": "whis-ke-rí-a",
    "wincha": "win-cha",
    "windsurf": "wind-surf",
    "windsurfista": "wind-sur-fis-ta",
    "wólfram": "wól-fram",
    "wolframio": "wol-fra-mio",
    "xantoma": "xan-to-ma",
    "xeca": "xe-ca",
    "xecudo": "xe-cu-do",
    "xeneise": "xe-nei-se",
    "xeneize": "xe-nei-ze",
    "xenismo": "xe-nis-mo",
    "xenófila": "xe-nó-fi-la",
    "xenófilo": "xe-nó-fi-lo",
    "xenofobia": "xe-no-fo-bia",
    "xenófobo": "xe-nó-fo-bo",
    "xenoglosia": "xe-no-glo-sia",
    "xenolito": "xe-no-li-to",
    "xenón": "xe-nón",
    "xerocopia": "xe-ro-co-pia",
    "xerocopiar": "xe-ro-co-piar",
    "xerófilo": "xe-ró-fi-lo",
    "xerofítico": "xe-ro-fí-ti-co",
    "xerófito": "xe-ró-fi-to",
    "xeroftalmía": "xe-rof-tal-mí-a",
    "xeroftalmia": "xe-rof-tal-mia",
    "xerógrafa": "xe-ró-gra-fa",
    "xerografía": "xe-ro-gra-fí-a",
    "xerografiar": "xe-ro-gra-fiar",
    "xerográfico": "xe-ro-grá-fi-co",
    "xerógrafo": "xe-ró-gra-fo",
    "xeroteca": "xe-ro-te-ca",
    "xeto": "xe-to",
    "xicaque": "xi-ca-que",
    "xifoideo": "xi-foi-de-o",
    "xifoides": "xi-foi-des",
    "xilema": "xi-le-ma",
    "xilófaga": "xi-ló-fa-ga",
    "xilófago": "xi-ló-fa-go",
    "xilofón": "xi-lo-fón",
    "xilofonista": "xi-lo-fo-nis-ta",
    "xilófono": "xi-ló-fo-no",
    "xilógrafa": "xi-ló-gra-fa",
    "xilografía": "xi-lo-gra-fí-a",
    "xilográfico": "xi-lo-grá-fi-co",
    "xilógrafo": "xi-ló-gra-fo",
    "xiloprotector": "xi-lo-pro-tec-tor",
    "xiloprotectora": "xi-lo-pro-tec-to-ra",
    "xilórgano": "xi-lór-ga-no",
    "xilotila": "xi-lo-ti-la",
    "xinca": "xin-ca",
    "xiote": "xio-te",
    "xóchil": "xó-chil",
    "xochimilca": "xo-chi-mil-ca",
    "xocoatole": "xo-co-a-to-le",
    "xocol": "xo-col",
    "xoconostle": "xo-co-nos-tle",
    "xoconoxtle": "xo-co-nox-tle",
    "xocoyote": "xo-co-yo-te",
    "xola": "xo-la",
    "xolo": "xo-lo",
    "xoxalera": "xo-xa-le-ra",
    "xoxalero": "xo-xa-le-ro",
    "yaacabó": "ya-a-ca-bó",
    "yaba": "ya-ba",
    "yabuna": "ya-bu-na",
    "yabunal": "ya-bu-nal",
    "yaca": "ya-ca",
    "yacal": "ya-cal",
    "yacaré": "ya-ca-ré",
    "yácata": "yá-ca-ta",
    "yacedor": "ya-ce-dor",
    "yacente": "ya-cen-te",
    "yacer": "ya-cer",
    "yachting": "yach-ting",
    "yaciente": "ya-cien-te",
    "yacija": "ya-ci-ja",
    "yacimiento": "ya-ci-mien-to",
    "yacio": "ya-cio",
    "yacón": "ya-cón",
    "yactura": "yac-tu-ra",
    "yacuibeña": "ya-cui-be-ña",
    "yacuibeño": "ya-cui-be-ño",
    "yacumeña": "ya-cu-me-ña",
    "yacumeño": "ya-cu-me-ño",
    "yacuzzi": "ya-cuz-zi",
    "yagatay": "ya-ga-tay",
    "yagé": "ya-gé",
    "yagruma": "ya-gru-ma",
    "yagrumo": "ya-gru-mo",
    "yagua": "ya-gua",
    "yagual": "ya-gual",
    "yaguané": "ya-gua-né",
    "yaguar": "ya-guar",
    "yaguaré": "ya-gua-ré",
    "yaguareté": "ya-gua-re-té",
    "yaguarundi": "ya-gua-run-di",
    "yaguasa": "ya-gua-sa",
    "yaguré": "ya-gu-ré",
    "yagurt": "ya-gurt",
    "yaichihue": "yai-chi-hue",
    "yaicuaje": "yai-cua-je",
    "yaití": "yai-tí",
    "yale": "ya-le",
    "yámana": "yá-ma-na",
    "yamao": "ya-ma-o",
    "yámbico": "yám-bi-co",
    "yambo": "yam-bo",
    "yana": "ya-na",
    "yanacón": "ya-na-cón",
    "yanacona": "ya-na-co-na",
    "yangüés": "yan-güés",
    "yangüesa": "yan-güe-sa",
    "yanilla": "ya-ni-lla",
    "yanomami": "ya-no-ma-mi",
    "yanqui": "yan-qui",
    "yanta": "yan-ta",
    "yantar": "yan-tar",
    "yapa": "ya-pa",
    "yapar": "ya-par",
    "yapú": "ya-pú",
    "yaqué": "ya-qué",
    "yaqui": "ya-qui",
    "yáquil": "yá-quil",
    "yaracuyano": "ya-ra-cu-ya-no",
    "yarará": "ya-ra-rá",
    "yaraví": "ya-ra-ví",
    "yarda": "yar-da",
    "yardero": "yar-de-ro",
    "yare": "ya-re",
    "yareta": "ya-re-ta",
    "yarey": "ya-rey",
    "yaro": "ya-ro",
    "yarura": "ya-ru-ra",
    "yaruro": "ya-ru-ro",
    "yatagán": "ya-ta-gán",
    "yataí": "ya-ta-í",
    "yátaro": "yá-ta-ro",
    "yatay": "ya-tay",
    "yate": "ya-te",
    "yautía": "yau-tí-a",
    "yauyina": "yau-yi-na",
    "yauyino": "yau-yi-no",
    "yaxché": "yax-ché",
    "yaya": "ya-ya",
    "yayo": "ya-yo",
    "yebo": "ye-bo",
    "yeclana": "ye-cla-na",
    "yeclano": "ye-cla-no",
    "yeco": "ye-co",
    "yedgo": "yed-go",
    "yedra": "ye-dra",
    "yegua": "ye-gua",
    "yeguada": "ye-gua-da",
    "yeguar": "ye-guar",
    "yeguariza": "ye-gua-ri-za",
    "yeguarizo": "ye-gua-ri-zo",
    "yeguata": "ye-gua-ta",
    "yeguato": "ye-gua-to",
    "yegüera": "ye-güe-ra",
    "yegüería": "ye-güe-rí-a",
    "yegüerío": "ye-güe-rí-o",
    "yegüerizo": "ye-güe-ri-zo",
    "yegüero": "ye-güe-ro",
    "yeísmo": "ye-ís-mo",
    "yeísta": "ye-ís-ta",
    "yelgo": "yel-go",
    "yelmo": "yel-mo",
    "yema": "ye-ma",
    "yembe": "yem-be",
    "yemení": "ye-me-ní",
    "yemenita": "ye-me-ni-ta",
    "yemita": "ye-mi-ta",
    "yente": "yen-te",
    "yeral": "ye-ral",
    "yerba": "yer-ba",
    "yerbabuena": "yer-ba-bue-na",
    "yerbadulce": "yer-ba-dul-ce",
    "yerbajal": "yer-ba-jal",
    "yerbajo": "yer-ba-jo",
    "yerbal": "yer-bal",
    "yerbaluisa": "yer-ba-lui-sa",
    "yerbatal": "yer-ba-tal",
    "yerbatera": "yer-ba-te-ra",
    "yerbatero": "yer-ba-te-ro",
    "yerbazal": "yer-ba-zal",
    "yerbazo": "yer-ba-zo",
    "yerbeado": "yer-be-a-do",
    "yerbear": "yer-be-ar",
    "yerbera": "yer-be-ra",
    "yerbería": "yer-be-rí-a",
    "yerbero": "yer-be-ro",
    "yerbilla": "yer-bi-lla",
    "yerboso": "yer-bo-so",
    "yerma": "yer-ma",
    "yermar": "yer-mar",
    "yermo": "yer-mo",
    "yerna": "yer-na",
    "yerno": "yer-no",
    "yero": "ye-ro",
    "yerra": "ye-rra",
    "yerro": "ye-rro",
    "yérsey": "yér-sey",
    "yersi": "yer-si",
    "yerto": "yer-to",
    "yervo": "yer-vo",
    "yesal": "ye-sal",
    "yesar": "ye-sar",
    "yesca": "yes-ca",
    "yesera": "ye-se-ra",
    "yesería": "ye-se-rí-a",
    "yesero": "ye-se-ro",
    "yesista": "ye-sis-ta",
    "yeso": "ye-so",
    "yesón": "ye-són",
    "yesoso": "ye-so-so",
    "yesque": "yes-que",
    "yesquero": "yes-que-ro",
    "yeta": "ye-ta",
    "yetado": "ye-ta-do",
    "yetatore": "ye-ta-to-re",
    "yeti": "ye-ti",
    "yetudo": "ye-tu-do",
    "yeyé": "ye-yé",
    "yeyo": "ye-yo",
    "yeyuno": "ye-yu-no",
    "yezgo": "yez-go",
    "yibutiana": "yi-bu-tia-na",
    "yibutiano": "yi-bu-tia-no",
    "yiddish": "yid-dish",
    "yihad": "yi-had",
    "yina": "yi-na",
    "yipi": "yi-pi",
    "yira": "yi-ra",
    "yiro": "yi-ro",
    "yodación": "yo-da-ción",
    "yodado": "yo-da-do",
    "yodar": "yo-dar",
    "yodo": "yo-do",
    "yodoformo": "yo-do-for-mo",
    "yodurar": "yo-du-rar",
    "yoduro": "yo-du-ro",
    "yoga": "yo-ga",
    "yogar": "yo-gar",
    "yogo": "yo-go",
    "yogui": "yo-gui",
    "yóguico": "yó-gui-co",
    "yogur": "yo-gur",
    "yogurtera": "yo-gur-te-ra",
    "yoidad": "yoi-dad",
    "yola": "yo-la",
    "yolilla": "yo-li-lla",
    "yolillo": "yo-li-llo",
    "yoltamal": "yol-ta-mal",
    "yoltasca": "yol-tas-ca",
    "yonqui": "yon-qui",
    "yoquepierdismo": "yo-que-pier-dis-mo",
    "yoquepierdista": "yo-que-pier-dis-ta",
    "yóquey": "yó-quey",
    "yoqui": "yo-qui",
    "yoreña": "yo-re-ña",
    "yoreño": "yo-re-ño",
    "yori": "yo-ri",
    "yorkshire": "yorks-hi-re",
    "yoruba": "yo-ru-ba",
    "yotaleña": "yo-ta-le-ña",
    "yotaleño": "yo-ta-le-ño",
    "yoyo": "yo-yo",
    "yoyó": "yo-yó",
    "yubarta": "yu-bar-ta",
    "yubo": "yu-bo",
    "yuca": "yu-ca",
    "yucal": "yu-cal",
    "yucateca": "yu-ca-te-ca",
    "yucateco": "yu-ca-te-co",
    "yucazo": "yu-ca-zo",
    "yuchán": "yu-chán",
    "yucpa": "yuc-pa",
    "yucuma": "yu-cu-ma",
    "yudo": "yu-do",
    "yudoca": "yu-do-ca",
    "yudogui": "yu-do-gui",
    "yudoka": "yu-do-ka",
    "yugada": "yu-ga-da",
    "yugalán": "yu-ga-lán",
    "yuglandácea": "yu-glan-dá-ce-a",
    "yuglandáceo": "yu-glan-dá-ce-o",
    "yugo": "yu-go",
    "yugoeslava": "yu-go-es-la-va",
    "yugoeslavo": "yu-go-es-la-vo",
    "yugoslava": "yu-gos-la-va",
    "yugoslavo": "yu-gos-la-vo",
    "yuguero": "yu-gue-ro",
    "yugueta": "yu-gue-ta",
    "yugular": "yu-gu-lar",
    "yumba": "yum-ba",
    "yumbo": "yum-bo",
    "yumeco": "yu-me-co",
    "yunga": "yun-ga",
    "yungaina": "yun-gai-na",
    "yungaíno": "yun-ga-í-no",
    "yungueña": "yun-gue-ña",
    "yungueño": "yun-gue-ño",
    "yunguyina": "yun-gu-yi-na",
    "yunguyino": "yun-gu-yi-no",
    "yunque": "yun-que",
    "yunta": "yun-ta",
    "yuntar": "yun-tar",
    "yuntería": "yun-te-rí-a",
    "yuntero": "yun-te-ro",
    "yunto": "yun-to",
    "yuppie": "yup-pie",
    "yuquera": "yu-que-ra",
    "yuquerí": "yu-que-rí",
    "yuquero": "yu-que-ro",
    "yuquilla": "yu-qui-lla",
    "yuraguano": "yu-ra-gua-no",
    "yuras": "yu-ras",
    "yuré": "yu-ré",
    "yurro": "yu-rro",
    "yuruma": "yu-ru-ma",
    "yurumí": "yu-ru-mí",
    "yurumo": "yu-ru-mo",
    "yusano": "yu-sa-no",
    "yusera": "yu-se-ra",
    "yusero": "yu-se-ro",
    "yusivo": "yu-si-vo",
    "yuso": "yu-so",
    "yuta": "yu-ta",
    "yute": "yu-te",
    "yuto": "yu-to",
    "yutoazteca": "yu-to-az-te-ca",
    "yuxtalineal": "yux-ta-li-ne-al",
    "yuxtaponer": "yux-ta-po-ner",
    "yuxtaposición": "yux-ta-po-si-ción",
    "yuxtapuesto": "yux-ta-pues-to",
    "yuyal": "yu-yal",
    "yuyera": "yu-ye-ra",
    "yuyería": "yu-ye-rí-a",
    "yuyero": "yu-ye-ro",
    "yuyo": "yu-yo",
    "yuyuba": "yu-yu-ba",
    "zabalmedina": "za-bal-me-di-na",
    "zabarcera": "za-bar-ce-ra",
    "zabatán": "za-ba-tán",
    "zabazala": "za-ba-za-la",
    "zabazoque": "za-ba-zo-que",
    "zabeca": "za-be-ca",
    "zabida": "za-bi-da",
    "zabila": "za-bi-la",
    "zábila": "zá-bi-la",
    "zabiola": "za-bio-la",
    "zaborda": "za-bor-da",
    "zabordamiento": "za-bor-da-mien-to",
    "zabordar": "za-bor-dar",
    "zabordo": "za-bor-do",
    "zaborra": "za-bo-rra",
    "zaborrero": "za-bo-rre-ro",
    "zaborro": "za-bo-rro",
    "zaboyar": "za-bo-yar",
    "zabra": "za-bra",
    "zabro": "za-bro",
    "zabucar": "za-bu-car",
    "zabuir": "za-buir",
    "zabullida": "za-bu-lli-da",
    "zabullidor": "za-bu-lli-dor",
    "zabullidura": "za-bu-lli-du-ra",
    "zabullimiento": "za-bu-lli-mien-to",
    "zabullir": "za-bu-llir",
    "zabuquear": "za-bu-que-ar",
    "zabuqueo": "za-bu-que-o",
    "zaca": "za-ca",
    "zacahuil": "za-ca-huil",
    "zacamecate": "za-ca-me-ca-te",
    "zacapaneca": "za-ca-pa-ne-ca",
    "zacapaneco": "za-ca-pa-ne-co",
    "zacapela": "za-ca-pe-la",
    "zacapella": "za-ca-pe-lla",
    "zacapín": "za-ca-pín",
    "zacatal": "za-ca-tal",
    "zacataloso": "za-ca-ta-lo-so",
    "zacate": "za-ca-te",
    "zacateada": "za-ca-te-a-da",
    "zacatear": "za-ca-te-ar",
    "zacateca": "za-ca-te-ca",
    "zacatecana": "za-ca-te-ca-na",
    "zacatecano": "za-ca-te-ca-no",
    "zacateco": "za-ca-te-co",
    "zacatecoluquense": "za-ca-te-co-lu-quen-se",
    "zacatera": "za-ca-te-ra",
    "zacatero": "za-ca-te-ro",
    "zacatín": "za-ca-tín",
    "zacatón": "za-ca-tón",
    "zacatona": "za-ca-to-na",
    "zacatonal": "za-ca-to-nal",
    "zacatuste": "za-ca-tus-te",
    "zacear": "za-ce-ar",
    "zaceo": "za-ce-o",
    "zaceoso": "za-ce-o-so",
    "zacuto": "za-cu-to",
    "zade": "za-de",
    "zadorija": "za-do-ri-ja",
    "zafa": "za-fa",
    "zafacoca": "za-fa-co-ca",
    "zafacón": "za-fa-cón",
    "zafada": "za-fa-da",
    "zafado": "za-fa-do",
    "zafadura": "za-fa-du-ra",
    "zafaduría": "za-fa-du-rí-a",
    "zafar": "za-far",
    "zafarí": "za-fa-rí",
    "zafariche": "za-fa-ri-che",
    "zafarrancho": "za-fa-rran-cho",
    "zafero": "za-fe-ro",
    "zafiamente": "za-fia-men-te",
    "zafiedad": "za-fie-dad",
    "zafío": "za-fí-o",
    "zafio": "za-fio",
    "zafir": "za-fir",
    "zafira": "za-fi-ra",
    "zafíreo": "za-fí-re-o",
    "zafirina": "za-fi-ri-na",
    "zafirino": "za-fi-ri-no",
    "zafiro": "za-fi-ro",
    "zafo": "za-fo",
    "zafón": "za-fón",
    "zafra": "za-fra",
    "zafrán": "za-frán",
    "zafre": "za-fre",
    "zafrero": "za-fre-ro",
    "zaga": "za-ga",
    "zagadero": "za-ga-de-ro",
    "zagal": "za-gal",
    "zagala": "za-ga-la",
    "zagalejo": "za-ga-le-jo",
    "zagalesco": "za-ga-les-co",
    "zagaletón": "za-ga-le-tón",
    "zagaletona": "za-ga-le-to-na",
    "zagalón": "za-ga-lón",
    "zagalona": "za-ga-lo-na",
    "zagaya": "za-ga-ya",
    "zagua": "za-gua",
    "zagual": "za-gual",
    "zaguán": "za-guán",
    "zaguanete": "za-gua-ne-te",
    "zaguaque": "za-gua-que",
    "zaguaro": "za-gua-ro",
    "zaguera": "za-gue-ra",
    "zaguero": "za-gue-ro",
    "zagüía": "za-güí-a",
    "zahareño": "za-ha-re-ño",
    "zaharrón": "za-ha-rrón",
    "zahén": "za-hén",
    "zahena": "za-he-na",
    "zaheridor": "za-he-ri-dor",
    "zaheridora": "za-he-ri-do-ra",
    "zaherimiento": "za-he-ri-mien-to",
    "zaherío": "za-he-rí-o",
    "zaherir": "za-he-rir",
    "zahína": "za-hí-na",
    "zahinar": "zahi-nar",
    "zahón": "za-hón",
    "zahonado": "za-ho-na-do",
    "zahondar": "za-hon-dar",
    "zahora": "za-ho-ra",
    "zahorar": "za-ho-rar",
    "zahorí": "za-ho-rí",
    "zahoriar": "za-ho-riar",
    "zahorra": "za-ho-rra",
    "zahúrda": "za-húr-da",
    "zahúrna": "za-húr-na",
    "zaida": "zai-da",
    "zaina": "zai-na",
    "zaino": "zai-no",
    "zaireña": "zai-re-ña",
    "zaireño": "zai-re-ño",
    "zajarí": "za-ja-rí",
    "zajón": "za-jón",
    "zajurín": "za-ju-rín",
    "zalá": "za-lá",
    "zalacho": "za-la-cho",
    "zalagarda": "za-la-gar-da",
    "zalama": "za-la-ma",
    "zalamelé": "za-la-me-lé",
    "zalamera": "za-la-me-ra",
    "zalameramente": "za-la-me-ra-men-te",
    "zalamería": "za-la-me-rí-a",
    "zalamero": "za-la-me-ro",
    "zálamo": "zá-la-mo",
    "zalbo": "zal-bo",
    "zalea": "za-le-a",
    "zalear": "za-le-ar",
    "zalema": "za-le-ma",
    "zaleo": "za-le-o",
    "zallar": "za-llar",
    "zalmedina": "zal-me-di-na",
    "zaloma": "za-lo-ma",
    "zalona": "za-lo-na",
    "zamacuca": "za-ma-cu-ca",
    "zamacuco": "za-ma-cu-co",
    "zamacueca": "za-ma-cue-ca",
    "zamanca": "za-man-ca",
    "zamarra": "za-ma-rra",
    "zamarrada": "za-ma-rra-da",
    "zamarrazo": "za-ma-rra-zo",
    "zamarrear": "za-ma-rre-ar",
    "zamarreo": "za-ma-rre-o",
    "zamarrico": "za-ma-rri-co",
    "zamarriega": "za-ma-rrie-ga",
    "zamarriego": "za-ma-rrie-go",
    "zamarrilla": "za-ma-rri-lla",
    "zamarro": "za-ma-rro",
    "zamarrón": "za-ma-rrón",
    "zamarronear": "za-ma-rro-ne-ar",
    "zamarrudo": "za-ma-rru-do",
    "zamba": "zam-ba",
    "zambacueca": "zam-ba-cue-ca",
    "zambaiga": "zam-bai-ga",
    "zambaigo": "zam-bai-go",
    "zambapalo": "zam-ba-pa-lo",
    "zambarco": "zam-bar-co",
    "zambiana": "zam-bia-na",
    "zambiano": "zam-bia-no",
    "zámbiga": "zám-bi-ga",
    "zámbigo": "zám-bi-go",
    "zambiloco": "zam-bi-lo-co",
    "zambo": "zam-bo",
    "zamboa": "zam-bo-a",
    "zambomba": "zam-bom-ba",
    "zambombazo": "zam-bom-ba-zo",
    "zambombo": "zam-bom-bo",
    "zamborondón": "zam-bo-ron-dón",
    "zamborondona": "zam-bo-ron-do-na",
    "zamborotuda": "zam-bo-ro-tu-da",
    "zamborotudo": "zam-bo-ro-tu-do",
    "zamborrotuda": "zam-bo-rro-tu-da",
    "zamborrotudo": "zam-bo-rro-tu-do",
    "zambra": "zam-bra",
    "zambrano": "zam-bra-no",
    "zambucar": "zam-bu-car",
    "zambuco": "zam-bu-co",
    "zambullida": "zam-bu-lli-da",
    "zambullidor": "zam-bu-lli-dor",
    "zambullidura": "zam-bu-lli-du-ra",
    "zambullimiento": "zam-bu-lli-mien-to",
    "zambullir": "zam-bu-llir",
    "zambullo": "zam-bu-llo",
    "zambullón": "zam-bu-llón",
    "zambumbia": "zam-bum-bia",
    "zamburiña": "zam-bu-ri-ña",
    "zambutir": "zam-bu-tir",
    "zamina": "za-mi-na",
    "zaminar": "za-mi-nar",
    "zamorana": "za-mo-ra-na",
    "zamorano": "za-mo-ra-no",
    "zampa": "zam-pa",
    "zampabodigos": "zam-pa-bo-di-gos",
    "zampabollos": "zam-pa-bo-llos",
    "zampaboya": "zam-pa-bo-ya",
    "zampada": "zam-pa-da",
    "zampado": "zam-pa-do",
    "zampalimones": "zam-pa-li-mo-nes",
    "zampalimosnas": "zam-pa-li-mos-nas",
    "zampalopresto": "zam-pa-lo-pres-to",
    "zampapalo": "zam-pa-pa-lo",
    "zampar": "zam-par",
    "zampatortas": "zam-pa-tor-tas",
    "zampeado": "zam-pe-a-do",
    "zampear": "zam-pe-ar",
    "zampón": "zam-pón",
    "zampona": "zam-po-na",
    "zampoña": "zam-po-ña",
    "zampullín": "zam-pu-llín",
    "zampuzar": "zam-pu-zar",
    "zampuzo": "zam-pu-zo",
    "zamujo": "za-mu-jo",
    "zamurada": "za-mu-ra-da",
    "zamurera": "za-mu-re-ra",
    "zamuro": "za-mu-ro",
    "zana": "za-na",
    "zanaca": "za-na-ca",
    "zanaco": "za-na-co",
    "zanahoria": "za-na-ho-ria",
    "zanatal": "za-na-tal",
    "zanate": "za-na-te",
    "zanatear": "za-na-te-ar",
    "zanatera": "za-na-te-ra",
    "zanca": "zan-ca",
    "zancada": "zan-ca-da",
    "zancadilla": "zan-ca-di-lla",
    "zancadillear": "zan-ca-di-lle-ar",
    "zancado": "zan-ca-do",
    "zancajada": "zan-ca-ja-da",
    "zancajear": "zan-ca-je-ar",
    "zancajera": "zan-ca-je-ra",
    "zancajiento": "zan-ca-jien-to",
    "zancajo": "zan-ca-jo",
    "zancajoso": "zan-ca-jo-so",
    "zancarrón": "zan-ca-rrón",
    "zanco": "zan-co",
    "zancón": "zan-cón",
    "zancuda": "zan-cu-da",
    "zancudal": "zan-cu-dal",
    "zancudero": "zan-cu-de-ro",
    "zancudo": "zan-cu-do",
    "zandía": "zan-dí-a",
    "zandunga": "zan-dun-ga",
    "zanfona": "zan-fo-na",
    "zanfoña": "zan-fo-ña",
    "zanfonía": "zan-fo-ní-a",
    "zanga": "zan-ga",
    "zangaburra": "zan-ga-bu-rra",
    "zangala": "zan-ga-la",
    "zangamanga": "zan-ga-man-ga",
    "zángana": "zán-ga-na",
    "zanganada": "zan-ga-na-da",
    "zangandonga": "zan-gan-don-ga",
    "zangandongo": "zan-gan-don-go",
    "zangandulla": "zan-gan-du-lla",
    "zangandullo": "zan-gan-du-llo",
    "zangandunga": "zan-gan-dun-ga",
    "zangandungo": "zan-gan-dun-go",
    "zanganear": "zan-ga-ne-ar",
    "zanganería": "zan-ga-ne-rí-a",
    "zángano": "zán-ga-no",
    "zangarilleja": "zan-ga-ri-lle-ja",
    "zangarrear": "zan-ga-rre-ar",
    "zangarriana": "zan-ga-rria-na",
    "zangarro": "zan-ga-rro",
    "zangarrón": "zan-ga-rrón",
    "zangarullón": "zan-ga-ru-llón",
    "zangolotear": "zan-go-lo-te-ar",
    "zangoloteo": "zan-go-lo-te-o",
    "zangolotina": "zan-go-lo-ti-na",
    "zangolotino": "zan-go-lo-ti-no",
    "zangón": "zan-gón",
    "zangotear": "zan-go-te-ar",
    "zangoteo": "zan-go-te-o",
    "zanguanga": "zan-guan-ga",
    "zanguangada": "zan-guan-ga-da",
    "zanguango": "zan-guan-go",
    "zanguaraña": "zan-gua-ra-ña",
    "zanguayo": "zan-gua-yo",
    "zanja": "zan-ja",
    "zanjar": "zan-jar",
    "zanjo": "zan-jo",
    "zanjón": "zan-jón",
    "zanqueador": "zan-que-a-dor",
    "zanqueadora": "zan-que-a-do-ra",
    "zanqueamiento": "zan-que-a-mien-to",
    "zanquear": "zan-que-ar",
    "zanquilarga": "zan-qui-lar-ga",
    "zanquilargo": "zan-qui-lar-go",
    "zanquilla": "zan-qui-lla",
    "zanquilón": "zan-qui-lón",
    "zanquita": "zan-qui-ta",
    "zanquituerta": "zan-qui-tuer-ta",
    "zanquituerto": "zan-qui-tuer-to",
    "zanquivano": "zan-qui-va-no",
    "zapa": "za-pa",
    "zapador": "za-pa-dor",
    "zapalla": "za-pa-lla",
    "zapallada": "za-pa-lla-da",
    "zapallazo": "za-pa-lla-zo",
    "zapallito": "za-pa-lli-to",
    "zapallo": "za-pa-llo",
    "zapalota": "za-pa-lo-ta",
    "zapalote": "za-pa-lo-te",
    "zapando": "za-pan-do",
    "zapaneco": "za-pa-ne-co",
    "zapapico": "za-pa-pi-co",
    "zapar": "za-par",
    "zaparda": "za-par-da",
    "zaparrada": "za-pa-rra-da",
    "zaparrastrar": "za-pa-rras-trar",
    "zaparrastrosa": "za-pa-rras-tro-sa",
    "zaparrastroso": "za-pa-rras-tro-so",
    "zaparrazo": "za-pa-rra-zo",
    "zaparruco": "za-pa-rru-co",
    "zapata": "za-pa-ta",
    "zapatazo": "za-pa-ta-zo",
    "zapateado": "za-pa-te-a-do",
    "zapateador": "za-pa-te-a-dor",
    "zapateadora": "za-pa-te-a-do-ra",
    "zapatear": "za-pa-te-ar",
    "zapateo": "za-pa-te-o",
    "zapatera": "za-pa-te-ra",
    "zapatería": "za-pa-te-rí-a",
    "zapatero": "za-pa-te-ro",
    "zapateta": "za-pa-te-ta",
    "zapatiesta": "za-pa-ties-ta",
    "zapatilla": "za-pa-ti-lla",
    "zapatillazo": "za-pa-ti-lla-zo",
    "zapatillera": "za-pa-ti-lle-ra",
    "zapatillero": "za-pa-ti-lle-ro",
    "zapatismo": "za-pa-tis-mo",
    "zapatista": "za-pa-tis-ta",
    "zapato": "za-pa-to",
    "zapatudo": "za-pa-tu-do",
    "zapayolito": "za-pa-yo-li-to",
    "zape": "za-pe",
    "zapear": "za-pe-ar",
    "zapeo": "za-pe-o",
    "zaperoco": "za-pe-ro-co",
    "zapita": "za-pi-ta",
    "zapito": "za-pi-to",
    "zapotal": "za-po-tal",
    "zapotazo": "za-po-ta-zo",
    "zapote": "za-po-te",
    "zapoteca": "za-po-te-ca",
    "zapoteco": "za-po-te-co",
    "zapotero": "za-po-te-ro",
    "zapotillo": "za-po-ti-llo",
    "zapoyol": "za-po-yol",
    "zapoyolito": "za-po-yo-li-to",
    "zapping": "zap-ping",
    "zapuyul": "za-pu-yul",
    "zapuzar": "za-pu-zar",
    "zaque": "za-que",
    "zaquear": "za-que-ar",
    "zaquizamí": "za-qui-za-mí",
    "zara": "za-ra",
    "zarabanda": "za-ra-ban-da",
    "zarabandista": "za-ra-ban-dis-ta",
    "zarabando": "za-ra-ban-do",
    "zarabutear": "za-ra-bu-te-ar",
    "zarabutero": "za-ra-bu-te-ro",
    "zaracear": "za-ra-ce-ar",
    "zaragalla": "za-ra-ga-lla",
    "zaragata": "za-ra-ga-ta",
    "zaragate": "za-ra-ga-te",
    "zaragatear": "za-ra-ga-te-ar",
    "zaragatera": "za-ra-ga-te-ra",
    "zaragatero": "za-ra-ga-te-ro",
    "zaragatona": "za-ra-ga-to-na",
    "zaragocí": "za-ra-go-cí",
    "zaragozana": "za-ra-go-za-na",
    "zaragozano": "za-ra-go-za-no",
    "zaragüelles": "za-ra-güe-lles",
    "zaragutear": "za-ra-gu-te-ar",
    "zaragutera": "za-ra-gu-te-ra",
    "zaragutero": "za-ra-gu-te-ro",
    "zarajo": "za-ra-jo",
    "zaramagullón": "za-ra-ma-gu-llón",
    "zarambeque": "za-ram-be-que",
    "zaramullo": "za-ra-mu-llo",
    "zaranda": "za-ran-da",
    "zarandador": "za-ran-da-dor",
    "zarandadora": "za-ran-da-do-ra",
    "zarandaja": "za-ran-da-ja",
    "zarandajas": "za-ran-da-jas",
    "zarandajo": "za-ran-da-jo",
    "zarandalí": "za-ran-da-lí",
    "zarandar": "za-ran-dar",
    "zarandear": "za-ran-de-ar",
    "zarandeo": "za-ran-de-o",
    "zarandera": "za-ran-de-ra",
    "zarandero": "za-ran-de-ro",
    "zarandilla": "za-ran-di-lla",
    "zarandillo": "za-ran-di-llo",
    "zaranga": "za-ran-ga",
    "zarangollo": "za-ran-go-llo",
    "zarapatel": "za-ra-pa-tel",
    "zarape": "za-ra-pe",
    "zarapito": "za-ra-pi-to",
    "zarapón": "za-ra-pón",
    "zaratán": "za-ra-tán",
    "zarate": "za-ra-te",
    "zaratoso": "za-ra-to-so",
    "zaraza": "za-ra-za",
    "zarazas": "za-ra-zas",
    "zarazo": "za-ra-zo",
    "zarbo": "zar-bo",
    "zarcear": "zar-ce-ar",
    "zarceño": "zar-ce-ño",
    "zarceo": "zar-ce-o",
    "zarcera": "zar-ce-ra",
    "zarcero": "zar-ce-ro",
    "zarceta": "zar-ce-ta",
    "zarcil": "zar-cil",
    "zarcillitos": "zar-ci-lli-tos",
    "zarcillo": "zar-ci-llo",
    "zarco": "zar-co",
    "zarevich": "za-re-vich",
    "zarevitz": "za-re-vitz",
    "zargatona": "zar-ga-to-na",
    "zariano": "za-ria-no",
    "zarigüeya": "za-ri-güe-ya",
    "zarina": "za-ri-na",
    "zarismo": "za-ris-mo",
    "zarista": "za-ris-ta",
    "zarja": "zar-ja",
    "zaronda": "za-ron-da",
    "zarpa": "zar-pa",
    "zarpada": "zar-pa-da",
    "zarpado": "zar-pa-do",
    "zarpanel": "zar-pa-nel",
    "zarpar": "zar-par",
    "zarpazo": "zar-pa-zo",
    "zarpear": "zar-pe-ar",
    "zarposo": "zar-po-so",
    "zarracatería": "za-rra-ca-te-rí-a",
    "zarracatín": "za-rra-ca-tín",
    "zarracina": "za-rra-ci-na",
    "zarrampín": "za-rram-pín",
    "zarramplín": "za-rram-plín",
    "zarramplinada": "za-rram-pli-na-da",
    "zarrapastra": "za-rra-pas-tra",
    "zarrapastro": "za-rra-pas-tro",
    "zarrapastrón": "za-rra-pas-trón",
    "zarrapastrona": "za-rra-pas-tro-na",
    "zarrapastrosa": "za-rra-pas-tro-sa",
    "zarrapastrosamente": "za-rra-pas-tro-sa-men-te",
    "zarrapastroso": "za-rra-pas-tro-so",
    "zarria": "za-rria",
    "zarriento": "za-rrien-to",
    "zarrio": "za-rrio",
    "zarrioso": "za-rrio-so",
    "zarza": "zar-za",
    "zarzagán": "zar-za-gán",
    "zarzaganillo": "zar-za-ga-ni-llo",
    "zarzahán": "zar-za-hán",
    "zarzal": "zar-zal",
    "zarzaleño": "zar-za-le-ño",
    "zarzamora": "zar-za-mo-ra",
    "zarzaparrilla": "zar-za-pa-rri-lla",
    "zarzaparrillar": "zar-za-pa-rri-llar",
    "zarzaperruna": "zar-za-pe-rru-na",
    "zarzarrosa": "zar-za-rro-sa",
    "zarzo": "zar-zo",
    "zarzoso": "zar-zo-so",
    "zarzuela": "zar-zue-la",
    "zarzuelero": "zar-zue-le-ro",
    "zarzuelista": "zar-zue-lis-ta",
    "zascandil": "zas-can-dil",
    "zascandilear": "zas-can-di-le-ar",
    "zascandileo": "zas-can-di-le-o",
    "zata": "za-ta",
    "zatara": "za-ta-ra",
    "zatico": "za-ti-co",
    "zatillo": "za-ti-llo",
    "zatiquero": "za-ti-que-ro",
    "zaya": "za-ya",
    "zazo": "za-zo",
    "zazoso": "za-zo-so",
    "zebra": "ze-bra",
    "zeda": "ze-da",
    "zedilla": "ze-di-lla",
    "zegrí": "ze-grí",
    "zeína": "ze-í-na",
    "zéjel": "zé-jel",
    "zelandés": "ze-lan-dés",
    "zelandesa": "ze-lan-de-sa",
    "zelota": "ze-lo-ta",
    "zelote": "ze-lo-te",
    "zempasúchil": "zem-pa-sú-chil",
    "zendal": "zen-dal",
    "zendavesta": "zen-da-ves-ta",
    "zendo": "zen-do",
    "zenit": "ze-nit",
    "zenzontle": "zen-zon-tle",
    "zepelín": "ze-pe-lín",
    "zeta": "ze-ta",
    "zeugma": "zeug-ma",
    "zidovudina": "zi-do-vu-di-na",
    "zigofilácea": "zi-go-fi-lá-ce-a",
    "zigofiláceo": "zi-go-fi-lá-ce-o",
    "zigomorfo": "zi-go-mor-fo",
    "zigoto": "zi-go-to",
    "zigurat": "zi-gu-rat",
    "zigzag": "zig-zag",
    "zigzagueante": "zig-za-gue-an-te",
    "zigzaguear": "zig-za-gue-ar",
    "zigzagueo": "zig-za-gue-o",
    "zimabua": "zi-ma-bua",
    "zimabuo": "zi-ma-buo",
    "zimbabuense": "zim-ba-buen-se",
    "zimógeno": "zi-mó-ge-no",
    "zincuate": "zin-cua-te",
    "zíngaro": "zín-ga-ro",
    "zingiberácea": "zin-gi-be-rá-ce-a",
    "zingiberáceo": "zin-gi-be-rá-ce-o",
    "zinnia": "zin-nia",
    "zinzontle": "zin-zon-tle",
    "zíper": "zí-per",
    "zipizape": "zi-pi-za-pe",
    "ziranda": "zi-ran-da",
    "zircón": "zir-cón",
    "zircona": "zir-co-na",
    "zirconio": "zir-co-nio",
    "zirconita": "zir-co-ni-ta",
    "ziszás": "zis-zás",
    "zoantropía": "zo-an-tro-pí-a",
    "zoca": "zo-ca",
    "zocado": "zo-ca-do",
    "zócalo": "zó-ca-lo",
    "zocar": "zo-car",
    "zocas": "zo-cas",
    "zocata": "zo-ca-ta",
    "zocatear": "zo-ca-te-ar",
    "zocato": "zo-ca-to",
    "zoclo": "zo-clo",
    "zoco": "zo-co",
    "zocola": "zo-co-la",
    "zocolar": "zo-co-lar",
    "zódiac": "zó-diac",
    "zodiacal": "zo-dia-cal",
    "zodíaco": "zo-dí-a-co",
    "zodiaco": "zo-dia-co",
    "zofra": "zo-fra",
    "zoilo": "zoi-lo",
    "zoizo": "zoi-zo",
    "zolcuate": "zol-cua-te",
    "zolle": "zo-lle",
    "zollipar": "zo-lli-par",
    "zollipo": "zo-lli-po",
    "zolocha": "zo-lo-cha",
    "zolocho": "zo-lo-cho",
    "zoltaní": "zol-ta-ní",
    "zoma": "zo-ma",
    "zombi": "zom-bi",
    "zompantli": "zom-pan-tli",
    "zompo": "zom-po",
    "zompopa": "zom-po-pa",
    "zompopera": "zom-po-pe-ra",
    "zompopero": "zom-po-pe-ro",
    "zompopo": "zom-po-po",
    "zona": "zo-na",
    "zonación": "zo-na-ción",
    "zonal": "zo-nal",
    "zoncear": "zon-ce-ar",
    "zoncera": "zon-ce-ra",
    "zoncería": "zon-ce-rí-a",
    "zonchiche": "zon-chi-che",
    "zoncle": "zon-cle",
    "zonconeto": "zon-co-ne-to",
    "zoncuán": "zon-cuán",
    "zonda": "zon-da",
    "zonificación": "zo-ni-fi-ca-ción",
    "zonificar": "zo-ni-fi-car",
    "zononeco": "zo-no-ne-co",
    "zonote": "zo-no-te",
    "zonte": "zon-te",
    "zontear": "zon-te-ar",
    "zontle": "zon-tle",
    "zonto": "zon-to",
    "zonza": "zon-za",
    "zonzamente": "zon-za-men-te",
    "zonzapote": "zon-za-po-te",
    "zonzo": "zon-zo",
    "zonzoreco": "zon-zo-re-co",
    "zonzorrión": "zon-zo-rrión",
    "zonzorriona": "zon-zo-rrio-na",
    "zonzorro": "zon-zo-rro",
    "zoo": "zo-o",
    "zoófaga": "zo-ó-fa-ga",
    "zoófago": "zo-ó-fa-go",
    "zoófila": "zo-ó-fi-la",
    "zoofilia": "zo-o-fi-lia",
    "zoófilo": "zo-ó-fi-lo",
    "zoófito": "zo-ó-fi-to",
    "zooftirio": "zo-of-ti-rio",
    "zoogeografía": "zo-o-ge-o-gra-fí-a",
    "zoogeográfico": "zo-o-ge-o-grá-fi-co",
    "zoografía": "zo-o-gra-fí-a",
    "zoográfico": "zo-o-grá-fi-co",
    "zooide": "zo-oi-de",
    "zoólatra": "zo-ó-la-tra",
    "zoolatría": "zo-o-la-trí-a",
    "zoóloga": "zo-ó-lo-ga",
    "zoología": "zo-o-lo-gí-a",
    "zoológico": "zo-o-ló-gi-co",
    "zoólogo": "zo-ó-lo-go",
    "zoomórfico": "zo-o-mór-fi-co",
    "zoomorfo": "zo-o-mor-fo",
    "zoonosis": "zo-o-no-sis",
    "zooplancton": "zo-o-planc-ton",
    "zoopsicología": "zo-op-si-co-lo-gí-a",
    "zoosanitario": "zo-o-sa-ni-ta-rio",
    "zoosemiótica": "zo-o-se-mió-ti-ca",
    "zoospermo": "zo-os-per-mo",
    "zoospora": "zo-os-po-ra",
    "zootecnia": "zo-o-tec-nia",
    "zootécnico": "zo-o-téc-ni-co",
    "zootomía": "zo-o-to-mí-a",
    "zoótropo": "zo-ó-tro-po",
    "zopas": "zo-pas",
    "zope": "zo-pe",
    "zopenca": "zo-pen-ca",
    "zopenco": "zo-pen-co",
    "zopetero": "zo-pe-te-ro",
    "zopilotada": "zo-pi-lo-ta-da",
    "zopilote": "zo-pi-lo-te",
    "zopilotear": "zo-pi-lo-te-ar",
    "zopilotera": "zo-pi-lo-te-ra",
    "zopilotillo": "zo-pi-lo-ti-llo",
    "zopisa": "zo-pi-sa",
    "zopitas": "zo-pi-tas",
    "zopo": "zo-po",
    "zoque": "zo-que",
    "zoqueta": "zo-que-ta",
    "zoquetada": "zo-que-ta-da",
    "zoquetazo": "zo-que-ta-zo",
    "zoquete": "zo-que-te",
    "zoquetear": "zo-que-te-ar",
    "zoquetera": "zo-que-te-ra",
    "zoqueterismo": "zo-que-te-ris-mo",
    "zoquetero": "zo-que-te-ro",
    "zoquetudo": "zo-que-tu-do",
    "zorailón": "zo-rai-lón",
    "zorailona": "zo-rai-lo-na",
    "zorcico": "zor-ci-co",
    "zorenco": "zo-ren-co",
    "zorimbo": "zo-rim-bo",
    "zorito": "zo-ri-to",
    "zoroastra": "zo-ro-as-tra",
    "zoroástrico": "zo-ro-ás-tri-co",
    "zoroastrismo": "zo-ro-as-tris-mo",
    "zorocho": "zo-ro-cho",
    "zorollo": "zo-ro-llo",
    "zorondo": "zo-ron-do",
    "zorongo": "zo-ron-go",
    "zoropeta": "zo-ro-pe-ta",
    "zorra": "zo-rra",
    "zorrastrón": "zo-rras-trón",
    "zorrastrona": "zo-rras-tro-na",
    "zorreado": "zo-rre-a-do",
    "zorrear": "zo-rre-ar",
    "zorrera": "zo-rre-ra",
    "zorrería": "zo-rre-rí-a",
    "zorrero": "zo-rre-ro",
    "zorrillo": "zo-rri-llo",
    "zorrino": "zo-rri-no",
    "zorro": "zo-rro",
    "zorrocloco": "zo-rro-clo-co",
    "zorrón": "zo-rrón",
    "zorronga": "zo-rron-ga",
    "zorronglón": "zo-rron-glón",
    "zorronglona": "zo-rron-glo-na",
    "zorrongo": "zo-rron-go",
    "zorruno": "zo-rru-no",
    "zorrupia": "zo-rru-pia",
    "zorzal": "zor-zal",
    "zorzalear": "zor-za-le-ar",
    "zorzaleño": "zor-za-le-ño",
    "zorzalero": "zor-za-le-ro",
    "zóster": "zós-ter",
    "zotal": "zo-tal",
    "zote": "zo-te",
    "zotol": "zo-tol",
    "zozobra": "zo-zo-bra",
    "zozobrar": "zo-zo-brar",
    "zozobroso": "zo-zo-bro-so",
    "zúa": "zú-a",
    "zuaca": "zua-ca",
    "zuácate": "zuá-ca-te",
    "zuavo": "zua-vo",
    "zubia": "zu-bia",
    "zucarino": "zu-ca-ri-no",
    "zucurco": "zu-cur-co",
    "zuda": "zu-da",
    "zueca": "zue-ca",
    "zueco": "zue-co",
    "zuela": "zue-la",
    "zuindá": "zuin-dá",
    "zuiza": "zui-za",
    "zuizón": "zui-zón",
    "zulacar": "zu-la-car",
    "zulaque": "zu-la-que",
    "zulaquear": "zu-la-que-ar",
    "zuliana": "zu-lia-na",
    "zuliano": "zu-lia-no",
    "zulla": "zu-lla",
    "zullar": "zu-llar",
    "zullenco": "zu-llen-co",
    "zullón": "zu-llón",
    "zulo": "zu-lo",
    "zulú": "zu-lú",
    "zuma": "zu-ma",
    "zumacal": "zu-ma-cal",
    "zumacar": "zu-ma-car",
    "zumacaya": "zu-ma-ca-ya",
    "zumaque": "zu-ma-que",
    "zumaya": "zu-ma-ya",
    "zumba": "zum-ba",
    "zumbada": "zum-ba-da",
    "zumbado": "zum-ba-do",
    "zumbador": "zum-ba-dor",
    "zumbadora": "zum-ba-do-ra",
    "zumbar": "zum-bar",
    "zumbel": "zum-bel",
    "zumbido": "zum-bi-do",
    "zumbo": "zum-bo",
    "zumbón": "zum-bón",
    "zumbona": "zum-bo-na",
    "zumbonamente": "zum-bo-na-men-te",
    "zumiento": "zu-mien-to",
    "zumillo": "zu-mi-llo",
    "zumo": "zu-mo",
    "zumoso": "zu-mo-so",
    "zuna": "zu-na",
    "zunchar": "zun-char",
    "zuncho": "zun-cho",
    "zuncuán": "zun-cuán",
    "zuncunango": "zun-cu-nan-go",
    "zuncuya": "zun-cu-ya",
    "zuñido": "zu-ñi-do",
    "zuñir": "zu-ñir",
    "zuño": "zu-ño",
    "zunteco": "zun-te-co",
    "zunza": "zun-za",
    "zunzapote": "zun-za-po-te",
    "zunzún": "zun-zún",
    "zunzuncito": "zun-zun-ci-to",
    "zupia": "zu-pia",
    "zurano": "zu-ra-no",
    "zurba": "zur-ba",
    "zurcida": "zur-ci-da",
    "zurcidera": "zur-ci-de-ra",
    "zurcido": "zur-ci-do",
    "zurcidor": "zur-ci-dor",
    "zurcidora": "zur-ci-do-ra",
    "zurcidura": "zur-ci-du-ra",
    "zurcir": "zur-cir",
    "zurda": "zur-da",
    "zurdal": "zur-dal",
    "zurdamente": "zur-da-men-te",
    "zurdazo": "zur-da-zo",
    "zurdear": "zur-de-ar",
    "zurdera": "zur-de-ra",
    "zurdería": "zur-de-rí-a",
    "zurdir": "zur-dir",
    "zurdo": "zur-do",
    "zurear": "zu-re-ar",
    "zureo": "zu-re-o",
    "zuriqués": "zu-ri-qués",
    "zuriquesa": "zu-ri-que-sa",
    "zurita": "zu-ri-ta",
    "zurito": "zu-ri-to",
    "zuriza": "zu-ri-za",
    "zuro": "zu-ro",
    "zurra": "zu-rra",
    "zurracapote": "zu-rra-ca-po-te",
    "zurraco": "zu-rra-co",
    "zurrado": "zu-rra-do",
    "zurrador": "zu-rra-dor",
    "zurradora": "zu-rra-do-ra",
    "zurrapa": "zu-rra-pa",
    "zurrapiento": "zu-rra-pien-to",
    "zurraposo": "zu-rra-po-so",
    "zurrar": "zu-rrar",
    "zurraspa": "zu-rras-pa",
    "zurrear": "zu-rre-ar",
    "zurreta": "zu-rre-ta",
    "zurria": "zu-rria",
    "zurriaga": "zu-rria-ga",
    "zurriagar": "zu-rria-gar",
    "zurriagazo": "zu-rria-ga-zo",
    "zurriago": "zu-rria-go",
    "zurriar": "zu-rriar",
    "zurribanda": "zu-rri-ban-da",
    "zurriburri": "zu-rri-bu-rri",
    "zurrido": "zu-rri-do",
    "zurrir": "zu-rrir",
    "zurrón": "zu-rrón",
    "zurrona": "zu-rro-na",
    "zurronada": "zu-rro-na-da",
    "zurrumba": "zu-rrum-ba",
    "zurrumbera": "zu-rrum-be-ra",
    "zurrupia": "zu-rru-pia",
    "zurruscar": "zu-rrus-car",
    "zurrusco": "zu-rrus-co",
    "zurubí": "zu-ru-bí",
    "zurugía": "zu-ru-gí-a",
    "zurujano": "zu-ru-ja-no",
    "zurullo": "zu-ru-llo",
    "zurumbanco": "zu-rum-ban-co",
    "zurumbático": "zu-rum-bá-ti-co",
    "zurumbo": "zu-rum-bo",
    "zurupeto": "zu-ru-pe-to",
    "zutana": "zu-ta-na",
    "zutaneja": "zu-ta-ne-ja",
    "zutanejo": "zu-ta-ne-jo",
    "zutano": "zu-ta-no",
    "zutuhil": "zu-tuhil",
    "zutujil": "zu-tu-jil",
    "zuzar": "zu-zar",
    "zuzo": "zu-zo",
    "zuzón": "zu-zón"}


def test_syllabification_dictionary():
    for key in DICT_TEST:
        assert "-".join(syllabify(key)[0]) == DICT_TEST[key]
